export const $APP = {};
export const shadow$provide = {};
const shadow_esm_import = function(x) { return import(x) };
/*

 Copyright The Closure Library Authors.
 SPDX-License-Identifier: Apache-2.0
*/
var $$jscomp$arrayIteratorImpl$$,$$jscomp$getGlobal$$,$$jscomp$polyfill$$,$$jscomp$iteratorPrototype$$,$goog$module$$,$goog$isArrayLike$$,$goog$isObject$$,$goog$getUid$$,$goog$bindNative_$$,$goog$bindJs_$$,$goog$bind$$,$goog$globalEval$$,$goog$identity_$$,$module$contents$goog$debug$Error_DebugError$$,$goog$reflect$sinkValue$$,$module$contents$goog$math$Long_Long$fromBits$$,$module$contents$goog$math$Long_Long$fromNumber$$,$module$contents$goog$math$Long_Long$fromString$$,$JSCompiler_StaticMethods_negate$$,
$JSCompiler_StaticMethods_toNumber$$,$JSCompiler_StaticMethods_div$$,$JSCompiler_StaticMethods_shiftRight$$,$JSCompiler_StaticMethods_shiftRightUnsigned$$,$goog$functions$UNDEFINED$$,$goog$functions$error$$,$goog$functions$sequence$$,$module$contents$goog$html$SafeScript_SafeScript$createSafeScriptSecurityPrivateDoNotAccessOrElse$$,$module$contents$goog$html$SafeScript_SafeScript$unwrapTrustedScript$$,$goog$html$TrustedResourceUrl$unwrap$$,$goog$html$TrustedResourceUrl$unwrapTrustedScriptURL$$,$goog$string$internal$isEmptyOrWhitespace$$,
$goog$string$internal$compareVersions$$,$goog$string$internal$compareElements_$$,$module$contents$goog$object_forEach$$,$module$contents$goog$object_getValues$$,$module$contents$goog$object_getKeys$$,$module$contents$goog$object_getValueByKeys$$,$module$contents$goog$object_clone$$,$module$contents$goog$object_extend$$,$module$contents$goog$object_createSet$$,$module$contents$goog$labs$userAgent$util_getNativeUserAgentString$$,$module$contents$goog$labs$userAgent$util_matchUserAgent$$,$module$contents$goog$labs$userAgent$browser_matchIE$$,
$module$contents$goog$labs$userAgent$browser_matchFirefox$$,$module$contents$goog$labs$userAgent$browser_matchChrome$$,$module$contents$goog$labs$userAgent$browser_createVersionMap$$,$module$contents$goog$labs$userAgent$browser_getVersion$$,$module$contents$goog$array_insert$$,$module$contents$goog$array_remove$$,$module$contents$goog$array_toArray$$,$module$contents$goog$array_extend$$,$module$contents$goog$array_removeDuplicates$$,$module$contents$goog$array_stableSort$$,$module$contents$goog$array_defaultCompare$$,
$goog$dom$safe$setScriptSrc$$,$goog$string$isUnicodeChar$$,$goog$string$regExpEscape$$,$goog$string$padNumber$$,$goog$string$makeSafe$$,$goog$structs$getValues$$,$goog$structs$getKeys$$,$goog$structs$forEach$$,$goog$uri$utils$parseQueryData$$,$goog$Uri$$,$JSCompiler_StaticMethods_setScheme$$,$JSCompiler_StaticMethods_setPort$$,$JSCompiler_StaticMethods_setQueryData$$,$JSCompiler_StaticMethods_enforceReadOnly$$,$goog$Uri$decodeOrEmpty_$$,$goog$Uri$encodeSpecialChars_$$,$goog$Uri$encodeChar_$$,$goog$Uri$removeDoubleEncoding_$$,
$goog$Uri$QueryData$$,$JSCompiler_StaticMethods_ensureKeyMapInitialized_$$,$JSCompiler_StaticMethods_containsKey$$,$JSCompiler_StaticMethods_getKeyName_$$,$cljs$core$pr_opts$$,$cljs$core$enable_console_print_BANG_$$,$cljs$core$identical_QMARK_$$,$cljs$core$char_QMARK_$$,$cljs$core$type__GT_str$$,$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$01$$,$cljs$core$js_symbol_QMARK_$$,$cljs$core$Fn$$,$cljs$core$IFn$$,$cljs$core$_clone$$,$cljs$core$ICounted$$,$cljs$core$IEmptyableCollection$$,$cljs$core$_empty$$,
$cljs$core$ICollection$$,$cljs$core$IIndexed$$,$cljs$core$ISeq$$,$cljs$core$_first$$,$cljs$core$_rest$$,$cljs$core$INext$$,$cljs$core$_next$$,$cljs$core$ILookup$$,$cljs$core$IAssociative$$,$cljs$core$IFind$$,$cljs$core$_find$$,$cljs$core$IMap$$,$cljs$core$ISet$$,$cljs$core$_disjoin$$,$cljs$core$_peek$$,$cljs$core$_pop$$,$cljs$core$IVector$$,$cljs$core$_assoc_n$$,$cljs$core$_meta$$,$cljs$core$IReduce$$,$cljs$core$IKVReduce$$,$cljs$core$_equiv$$,$cljs$core$ISeqable$$,$cljs$core$_seq$$,$cljs$core$ISequential$$,
$cljs$core$IList$$,$cljs$core$IRecord$$,$cljs$core$IReversible$$,$cljs$core$_flush$$,$cljs$core$IPrintWithWriter$$,$cljs$core$IPending$$,$cljs$core$_realized_QMARK_$$,$cljs$core$_notify_watches$$,$cljs$core$_add_watch$$,$cljs$core$_remove_watch$$,$cljs$core$_conj_BANG_$$,$cljs$core$_assoc_BANG_$$,$cljs$core$_dissoc_BANG_$$,$cljs$core$_assoc_n_BANG_$$,$cljs$core$IComparable$$,$cljs$core$_drop_first$$,$cljs$core$_name$$,$cljs$core$_namespace$$,$cljs$core$_reset_BANG_$$,$cljs$core$IIterable$$,$cljs$core$_drop$$,
$cljs$core$StringBufferWriter$$,$cljs$core$m3_mix_K1$$,$cljs$core$m3_mix_H1$$,$cljs$core$m3_fmix$$,$cljs$core$hash_string$$,$cljs$core$hash_combine$$,$cljs$core$instance_QMARK_$$,$cljs$core$symbol_QMARK_$$,$cljs$core$hash_symbol$$,$cljs$core$compare_symbols$$,$cljs$core$iterable_QMARK_$$,$cljs$core$ES6Iterator$$,$cljs$core$ES6IteratorSeq$$,$cljs$core$es6_iterator_seq$$,$cljs$core$hash_ordered_coll$$,$cljs$core$Inst$$,$cljs$core$inst_QMARK_$$,$cljs$core$Reduced$$,$cljs$core$reduced_QMARK_$$,$cljs$core$unreduced$$,
$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs$core$array_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$array_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs$core$array_reduce$cljs$0core$0IFn$0_invoke$0arity$04$$,$cljs$core$counted_QMARK_$$,$cljs$core$indexed_QMARK_$$,$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs$core$IndexedSeqIterator$$,
$cljs$core$linear_traversal_nth$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs$core$nth$$,$cljs$core$MetaFn$$,$cljs$core$array_copy$$,$cljs$core$false_QMARK_$$,$cljs$core$ifn_QMARK_$$,$cljs$core$pos_int_QMARK_$$,$cljs$core$neg_int_QMARK_$$,$cljs$core$float_QMARK_$$,$cljs$core$double_QMARK_$$,$cljs$core$find$$,$cljs$core$compare_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$fn__GT_comparator$$,$cljs$core$seq_reduce$$,$cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$,
$cljs$core$iter_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$iter_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs$core$reduce$$,$cljs$core$completing$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$04$$,$cljs$core$bit_count$$,$cljs$core$_EQ__EQ_$$,$cljs$core$_EQ__EQ_$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$zero_QMARK_$$,$cljs$core$equiv_sequential$$,$cljs$core$EmptyList$$,$cljs$core$compare_keywords$$,
$cljs$core$keyword_QMARK_$$,$cljs$core$ident_QMARK_$$,$cljs$core$simple_ident_QMARK_$$,$cljs$core$qualified_ident_QMARK_$$,$cljs$core$simple_symbol_QMARK_$$,$cljs$core$qualified_symbol_QMARK_$$,$cljs$core$simple_keyword_QMARK_$$,$cljs$core$qualified_keyword_QMARK_$$,$JSCompiler_StaticMethods_sval$$,$cljs$core$ChunkBuffer$$,$cljs$core$ArrayChunk$$,$cljs$core$object_array$cljs$0core$0IFn$0_invoke$0arity$01$$,$cljs$core$bounded_count$$,$cljs$core$apply_to$$,$cljs$core$next_STAR_$$,$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$03$$,
$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$04$$,$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$05$$,$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$06$$,$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$cljs$core$t_cljs$0core23246$$,$cljs$core$StringIter$$,$cljs$core$ArrayIter$$,$cljs$core$iter$$,$cljs$core$Many$$,$cljs$core$Single$$,$cljs$core$Empty$$,$cljs$core$TransformerIterator$$,$cljs$core$transformer_iterator$$,$cljs$core$Atom$$,$cljs$core$Volatile$$,
$cljs$core$keep_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$,$cljs$core$every_pred$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$some_fn$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$split_at$$,$cljs$core$Repeat$$,$cljs$core$repeatedly$cljs$0core$0IFn$0_invoke$0arity$01$$,$cljs$core$repeatedly$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$Iterate$$,$cljs$core$iterate$$,$cljs$core$partition$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs$core$VectorNode$$,
$cljs$core$pv_fresh_node$$,$cljs$core$pv_clone_node$$,$cljs$core$tail_off$$,$cljs$core$new_path$$,$cljs$core$vector_index_out_of_bounds$$,$cljs$core$unchecked_array_for$$,$cljs$core$array_for$$,$cljs$core$RangedIterator$$,$cljs$core$ranged_iterator$$,$cljs$core$pv_reduce$cljs$0core$0IFn$0_invoke$0arity$04$$,$cljs$core$pv_reduce$cljs$0core$0IFn$0_invoke$0arity$05$$,$cljs$core$chunked_seq$$,$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$,$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$05$$,
$cljs$core$build_subvec$$,$cljs$core$tv_ensure_editable$$,$cljs$core$tv_editable_root$$,$cljs$core$tv_editable_tail$$,$cljs$core$TransientVector$$,$cljs$core$PersistentQueueIter$$,$cljs$core$PersistentQueueSeq$$,$cljs$core$PersistentQueue$$,$cljs$core$NeverEquiv$$,$cljs$core$ES6EntriesIterator$$,$cljs$core$ES6SetEntriesIterator$$,$cljs$core$es6_set_entries_iterator$$,$cljs$core$array_index_of$$,$cljs$core$PersistentArrayMapIterator$$,$cljs$core$key_test$$,$cljs$core$pam_new_size$$,$cljs$core$pam_grow_seed_array$$,
$cljs$core$PersistentArrayMap$createAsIfByAssocComplexPath$$,$cljs$core$TransientArrayMap$$,$cljs$core$array__GT_transient_hash_map$$,$cljs$core$Box$$,$cljs$core$clone_and_set$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs$core$remove_pair$$,$cljs$core$edit_and_set$cljs$0core$0IFn$0_invoke$0arity$04$$,$cljs$core$inode_kv_reduce$$,$cljs$core$NodeIterator$$,$cljs$core$BitmapIndexedNode$$,$JSCompiler_StaticMethods_edit_and_remove_pair$$,$cljs$core$pack_array_node$$,$cljs$core$ArrayNodeIterator$$,$cljs$core$ArrayNode$$,
$cljs$core$hash_collision_node_find_index$$,$cljs$core$HashCollisionNode$$,$cljs$core$create_node$$,$cljs$core$create_node$cljs$0core$0IFn$0_invoke$0arity$06$$,$cljs$core$create_node$cljs$0core$0IFn$0_invoke$0arity$07$$,$cljs$core$create_inode_seq$$,$cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$01$$,$cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs$core$create_array_node_seq$$,$cljs$core$create_array_node_seq$cljs$0core$0IFn$0_invoke$0arity$01$$,$cljs$core$create_array_node_seq$cljs$0core$0IFn$0_invoke$0arity$03$$,
$cljs$core$HashMapIter$$,$cljs$core$TransientHashMap$$,$JSCompiler_StaticMethods_assoc_BANG_$$,$cljs$core$tree_map_seq_push$$,$cljs$core$PersistentTreeMapSeq$$,$cljs$core$create_tree_map_seq$$,$cljs$core$balance_left$$,$cljs$core$balance_right$$,$cljs$core$balance_left_del$$,$cljs$core$balance_right_del$$,$JSCompiler_StaticMethods_entry_at$$,$cljs$core$KeySeq$$,$cljs$core$ValSeq$$,$cljs$core$HashSetIter$$,$cljs$core$TransientHashSet$$,$cljs$core$PersistentTreeSet$$,$cljs$core$sorted_set$$,$cljs$core$sorted_set_by$$,
$cljs$core$ArrayList$$,$cljs$core$IntegerRangeChunk$$,$cljs$core$RangeIterator$$,$cljs$core$IntegerRange$$,$cljs$core$Range$$,$JSCompiler_StaticMethods_forceChunk$$,$cljs$core$reductions$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs$core$dorun$cljs$0core$0IFn$0_invoke$0arity$01$$,$cljs$core$write_all$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$cljs$core$string_print$$,$cljs$core$quote_string$$,$cljs$core$print_meta_QMARK_$$,$cljs$core$pr_writer_impl$$,$cljs$core$pr_sb_with_opts$$,$cljs$core$pr_str_with_opts$$,
$cljs$core$strip_ns$$,$cljs$core$lift_ns$$,$cljs$core$print_prefix_map$$,$cljs$core$print_map$$,$cljs$core$preserving_reduced$$,$cljs$core$cat$$,$cljs$core$halt_when$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$Eduction$$,$cljs$core$IEncodeJS$$,$cljs$core$_clj__GT_js$$,$cljs$core$key__GT_js$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$IEncodeClojure$$,$cljs$core$_js__GT_clj$$,$cljs$core$rand_int$$,$cljs$core$isa_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs$core$parents$cljs$0core$0IFn$0_invoke$0arity$01$$,
$cljs$core$reset_cache$$,$cljs$core$dominates$$,$cljs$core$_add_method$$,$cljs$core$throw_no_method_error$$,$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$,$cljs$core$UUID$$,$cljs$core$random_uuid$$,$cljs$core$ex_cause$$,$cljs$core$Throwable__GT_map$$,$cljs$core$demunge_pattern$$,$cljs$core$demunge$$,$cljs$core$uri_QMARK_$$,$cljs$core$parsing_err$$,$cljs$core$parse_uuid$$,$clojure$string$replace_all$$,$clojure$string$replace_with$$,$clojure$string$lower_case$$,$clojure$string$split_with_empty_regex$$,
$clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$02$$,$clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs$tools$reader$reader_types$peek_char$$,$cljs$tools$reader$reader_types$get_column_number$$,$cljs$tools$reader$impl$inspect$inspect_STAR__col$$,$cljs$tools$reader$impl$inspect$inspect$cljs$0core$0IFn$0_invoke$0arity$01$$,$cljs$tools$reader$impl$errors$throw_ex$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$cljs$tools$reader$impl$errors$illegal_arg_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$cljs$tools$reader$impl$errors$eof_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$cljs$tools$reader$impl$errors$throw_bad_char$$,$cljs$tools$reader$impl$errors$duplicate_keys_error$$,$cljs$tools$reader$impl$commons$matches_QMARK_$$,$cljs$tools$reader$edn$macro_terminating_QMARK_$$,$cljs$tools$reader$edn$not_constituent_QMARK_$$,$cljs$tools$reader$edn$read_token$cljs$0core$0IFn$0_invoke$0arity$04$$,$cljs$tools$reader$edn$read_dispatch$$,$cljs$tools$reader$edn$read_unmatched_delimiter$$,$cljs$tools$reader$edn$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$04$$,
$cljs$tools$reader$edn$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$05$$,$cljs$tools$reader$edn$read_char_STAR_$$,$cljs$tools$reader$edn$starting_line_col_info$$,$cljs$tools$reader$edn$read_delimited$$,$cljs$tools$reader$edn$read_list$$,$cljs$tools$reader$edn$read_vector$$,$cljs$tools$reader$edn$read_map$$,$cljs$tools$reader$edn$read_number$$,$cljs$tools$reader$edn$escape_char$$,$cljs$tools$reader$edn$read_string_STAR_$$,$cljs$tools$reader$edn$read_symbol$$,$cljs$tools$reader$edn$read_keyword$$,
$cljs$tools$reader$edn$read_meta$$,$cljs$tools$reader$edn$read_set$$,$cljs$tools$reader$edn$read_discard$$,$cljs$tools$reader$edn$read_namespaced_map$$,$cljs$tools$reader$edn$read_symbolic_value$$,$cljs$tools$reader$edn$macros$$,$cljs$tools$reader$edn$dispatch_macros$$,$cljs$tools$reader$edn$read_tagged$$,$cljs$tools$reader$edn$read$$,$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$,$cljs$reader$parse_int$$,$cljs$reader$check$$,
$cljs$reader$parse_and_validate_timestamp$$,$cljs$reader$read_string$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$math$nan_QMARK_$$,$app$common$math$cubicroot$$,$app$common$math$round_to_zero$$,$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$math$max_abs$$,$clojure$set$bubble_max_key$$,$clojure$walk$walk$$,$cuerdas$core$word_QMARK_$$,$cuerdas$core$numeric_QMARK_$$,$cuerdas$core$str__GT_trim_re$$,$cuerdas$core$str__GT_rtrim_re$$,$cuerdas$core$rtrim$cljs$0core$0IFn$0_invoke$0arity$02$$,
$cuerdas$core$strip_prefix$$,$cuerdas$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$,$cuerdas$core$replace_all$$,$cuerdas$core$replace_with$$,$cuerdas$core$words$cljs$0core$0IFn$0_invoke$0arity$02$$,$cuerdas$core$interpolate_format$$,$cuerdas$core$indexed_format$$,$cuerdas$core$unsurround$$,$cuerdas$core$quote$cljs$0core$0IFn$0_invoke$0arity$01$$,$cuerdas$core$stylize_split$$,$cuerdas$core$camel$$,$cuerdas$core$pad$cljs$0core$0IFn$0_invoke$0arity$02$$,$linked$map$Node$$,$linked$map$LinkedMap$$,
$linked$map$assoc_STAR_$$,$linked$map$dissoc_STAR_$$,$linked$map$map_entry$$,$linked$map$seq_STAR_$$,$linked$map$rseq_STAR_$$,$linked$set$LinkedSet$$,$app$common$data$ordered_set_QMARK_$$,$app$common$data$oupdate_in$$,$app$common$data$oupdate_in$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$data$oreorder_before$$,$app$common$data$vec2$$,$app$common$data$transient_concat$$,$app$common$data$group_by$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$common$data$without_obj$$,$app$common$data$map_perm$cljs$0core$0IFn$0_invoke$0arity$04$$,
$app$common$data$assoc_in_when$$,$app$common$data$assoc_when$$,$app$common$data$with_prev_next$$,$app$common$data$add_at_index$$,$app$common$data$parse_percent$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$data$nilf$$,$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$common$data$safe_PLUS_$$,$app$common$data$any_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$data$unstable_sort$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$data$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$common$data$get_initials$$,$app$common$data$close_BANG_$$,$app$common$data$take_until$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$data$take_until$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$data$safe_subvec$cljs$0core$0IFn$0_invoke$0arity$03$$,$me$flowthing$pp$extract_map_ns$$,$me$flowthing$pp$close_delim$$,$me$flowthing$pp$write$$,$me$flowthing$pp$remaining$$,$me$flowthing$pp$nl$$,$me$flowthing$pp$write_into$$,$me$flowthing$pp$t_me$0flowthing$0pp24586$$,$me$flowthing$pp$open_delim_PLUS_form$$,
$me$flowthing$pp$meets_print_level_QMARK_$$,$me$flowthing$pp$_print_coll$$,$me$flowthing$pp$_print$$,$me$flowthing$pp$with_str_writer$$,$me$flowthing$pp$print_linear$cljs$0core$0IFn$0_invoke$0arity$02$$,$me$flowthing$pp$print_mode$$,$me$flowthing$pp$write_sep$$,$me$flowthing$pp$pprint_meta$$,$me$flowthing$pp$pprint_opts$$,$me$flowthing$pp$_pprint_coll$$,$me$flowthing$pp$_pprint_map_entry$$,$me$flowthing$pp$_pprint_seq$$,$me$flowthing$pp$_pprint_queue$$,$me$flowthing$pp$_pprint$$,$me$flowthing$pp$pprint$cljs$0core$0IFn$0_invoke$0arity$03$$,
$app$common$pprint$pprint$$,$app$common$pprint$pprint$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$pprint$pprint_str$$,$app$common$pprint$pprint_str$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$json$read_kebab_key$$,$app$common$json$__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$malli$impl$util$_map_valid$$,$malli$impl$util$_map_invalid$$,$malli$impl$util$_reduce_kv_valid$$,$malli$impl$util$_merge$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$04$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$,
$malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$,$malli$impl$util$_every_pred$$,$malli$impl$util$_some_pred$$,$malli$impl$regex$noncaching_park_validator_BANG_$$,$malli$impl$regex$park_validator_BANG_$$,$malli$impl$regex$noncaching_park_explainer_BANG_$$,$malli$impl$regex$park_explainer_BANG_$$,$malli$impl$regex$value_path$$,$malli$impl$regex$fail_BANG_$$,$malli$impl$regex$noncaching_park_transformer_BANG_$$,$malli$impl$regex$park_transformer_BANG_$$,$malli$impl$regex$item_validator$$,
$malli$impl$regex$item_explainer$$,$malli$impl$regex$item_encoder$$,$malli$impl$regex$item_decoder$$,$malli$impl$regex$item_transformer$$,$malli$impl$regex$end_validator$$,$malli$impl$regex$end_explainer$$,$malli$impl$regex$end_transformer$$,$malli$impl$regex$pure_parser$$,$malli$impl$regex$pure_unparser$$,$malli$impl$regex$fmap_parser$$,$malli$impl$regex$entry__GT_regex$$,$malli$impl$regex$_STAR__validator$$,$malli$impl$regex$_STAR__explainer$$,$malli$impl$regex$_STAR__parser$$,$malli$impl$regex$_STAR__unparser$$,
$malli$impl$regex$_STAR__transformer$$,$malli$impl$regex$_PLUS__parser$$,$malli$impl$regex$_PLUS__unparser$$,$malli$impl$regex$repeat_validator$$,$malli$impl$regex$repeat_explainer$$,$malli$impl$regex$repeat_parser$$,$malli$impl$regex$repeat_unparser$$,$malli$impl$regex$repeat_transformer$$,$malli$impl$regex$ensure_cached_BANG_$$,$malli$impl$regex$CacheEntry$$,$malli$impl$regex$Cache$$,$malli$impl$regex$CheckDriver$$,$JSCompiler_StaticMethods_malli$impl$regex$Driver$pop_thunk_BANG_$arity$1$$,$malli$impl$regex$ParseDriver$$,
$malli$impl$regex$validator$$,$malli$impl$regex$ExplanationDriver$$,$malli$impl$regex$explainer$$,$malli$impl$regex$transformer$$,$malli$registry$Registry$$,$malli$registry$_schema$$,$malli$registry$_schemas$$,$malli$registry$t_malli$0registry24964$$,$malli$registry$t_malli$0registry24972$$,$malli$registry$registry$$,$malli$registry$t_malli$0registry25009$$,$malli$registry$t_malli$0registry25037$$,$malli$registry$composite_registry$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$malli$registry$t_malli$0registry25073$$,
$malli$registry$t_malli$0registry25109$$,$borkdude$dynaload$LazyVar$$,$malli$core$_type$$,$malli$core$_type_properties$$,$malli$core$_into_schema$$,$malli$core$_validator$$,$malli$core$_explainer$$,$malli$core$_transformer$$,$malli$core$_walk$$,$malli$core$_properties$$,$malli$core$_options$$,$malli$core$_children$$,$malli$core$_parent$$,$malli$core$_form$$,$malli$core$_to_ast$$,$malli$core$_entry_keyset$$,$malli$core$_entry_children$$,$malli$core$_entry_entries$$,$malli$core$_entry_forms$$,$malli$core$_entries$$,
$malli$core$_entry_parser$$,$malli$core$_cache$$,$malli$core$_get$$,$malli$core$_set$$,$malli$core$_ref$$,$malli$core$_deref$$,$malli$core$_accept$$,$malli$core$_inner$$,$malli$core$_outer$$,$malli$core$_transformer_chain$$,$malli$core$_value_transformer$$,$malli$core$_regex_op_QMARK_$$,$malli$core$_regex_validator$$,$malli$core$_regex_explainer$$,$malli$core$_regex_transformer$$,$malli$core$_regex_min_max$$,$malli$core$_function_schema_QMARK_$$,$malli$core$_function_info$$,$malli$core$_instrument_f$$,
$malli$core$_distributive_schema_QMARK_$$,$malli$core$_distribute_to_children$$,$malli$core$_ref_schema_QMARK_$$,$malli$core$pr_writer_into_schema$$,$malli$core$pr_writer_schema$$,$malli$core$Tag$$,$malli$core$tag$$,$malli$core$tag_QMARK_$$,$malli$core$Tags$$,$malli$core$tags$$,$malli$core$tags_QMARK_$$,$malli$core$_exception$$,$malli$core$_safe_pred$$,$malli$core$_keyword__GT_string$$,$malli$core$_guard$$,$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$,$malli$core$_pointer$$,
$malli$core$_reference_QMARK_$$,$malli$core$_boolean_fn$$,$malli$core$_infer$$,$malli$core$_update$$,$malli$core$_equals$$,$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$,$malli$core$_memoize$$,$malli$core$_group_by_arity_BANG_$$,$malli$core$_re_min_max$$,$malli$core$_re_alt_min_max$$,$malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$,$malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$04$$,$malli$core$_registry$cljs$0core$0IFn$0_invoke$0arity$01$$,$malli$core$_property_registry$$,
$malli$core$_lookup$$,$malli$core$_lookup_BANG_$$,$malli$core$_create_cache$$,$malli$core$_cached$$,$malli$core$_create_form$$,$malli$core$_simple_form$$,$malli$core$_create_entry_form$$,$malli$core$_inner_indexed$$,$malli$core$_inner_entries$$,$malli$core$_walk_entries$$,$malli$core$_walk_indexed$$,$malli$core$_walk_leaf$$,$malli$core$_set_children$$,$malli$core$_set_assoc_children$$,$malli$core$_get_entries$$,$malli$core$t_malli$0core31774$$,$malli$core$_simple_entry_parser$$,$malli$core$_update_parsed$$,
$malli$core$_set_entries$$,$malli$core$_parse_entry$$,$malli$core$_eager_entry_parser$$,$malli$core$t_malli$0core31888$$,$malli$core$_lazy_entry_parser$$,$malli$core$_create_entry_parser$$,$malli$core$_default_entry$$,$malli$core$_default_entry_schema$$,$malli$core$t_malli$0core31908$$,$malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$01$$,$malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$02$$,$malli$core$_parent_children_transformer$$,$malli$core$_map_transformer$$,$malli$core$_tuple_transformer$$,
$malli$core$_collection_transformer$$,$malli$core$_or_transformer$$,$malli$core$_ast$$,$malli$core$_entry_ast$$,$malli$core$_to_child_ast$$,$malli$core$_from_value_ast$$,$malli$core$_to_value_ast$$,$malli$core$_to_type_ast$$,$malli$core$_min_max_pred$$,$malli$core$_safe_count$$,$malli$core$_validate_limits$$,$malli$core$_needed_bounded_checks$$,$malli$core$_validate_bounded_limits$$,$malli$core$t_malli$0core32221$$,$malli$core$t_malli$0core32192$$,$malli$core$t_malli$0core32354$$,$malli$core$t_malli$0core32315$$,
$malli$core$t_malli$0core32419$$,$malli$core$t_malli$0core32402$$,$malli$core$t_malli$0core32494$$,$malli$core$t_malli$0core32486$$,$malli$core$t_malli$0core32608$$,$malli$core$t_malli$0core32589$$,$malli$core$t_malli$0core32664$$,$malli$core$t_malli$0core32655$$,$malli$core$_val_schema$$,$malli$core$_val_schema$cljs$0core$0IFn$0_invoke$0arity$02$$,$malli$core$t_malli$0core32820$$,$malli$core$t_malli$0core32750$$,$malli$core$t_malli$0core32964$$,$malli$core$t_malli$0core32939$$,$malli$core$_safely_countable_QMARK_$$,
$malli$core$t_malli$0core33039$$,$malli$core$t_malli$0core33017$$,$malli$core$t_malli$0core33144$$,$malli$core$t_malli$0core33129$$,$malli$core$t_malli$0core33218$$,$malli$core$t_malli$0core33210$$,$malli$core$t_malli$0core33258$$,$malli$core$t_malli$0core33239$$,$malli$core$t_malli$0core33384$$,$malli$core$t_malli$0core33358$$,$malli$core$t_malli$0core33557$$,$malli$core$t_malli$0core33506$$,$malli$core$t_malli$0core33688$$,$malli$core$t_malli$0core33658$$,$malli$core$t_malli$0core33738$$,$malli$core$t_malli$0core33725$$,
$malli$core$_ref_schema$$,$malli$core$_ref_schema$cljs$0core$0IFn$0_invoke$0arity$01$$,$malli$core$t_malli$0core33751$$,$malli$core$t_malli$0core33747$$,$malli$core$_schema_schema$$,$malli$core$t_malli$0core33772$$,$malli$core$t_malli$0core33759$$,$malli$core$t_malli$0core33807$$,$malli$core$t_malli$0core33802$$,$malli$core$t_malli$0core33838$$,$malli$core$t_malli$0core33827$$,$malli$core$_proxy_schema$$,$malli$core$regex_transformer$$,$malli$core$t_malli$0core33873$$,$malli$core$t_malli$0core33861$$,
$malli$core$_sequence_schema$$,$malli$core$t_malli$0core33934$$,$malli$core$t_malli$0core33926$$,$malli$core$_sequence_entry_schema$$,$malli$core$into_schema_QMARK_$$,$malli$core$into_schema$$,$malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$03$$,$malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$04$$,$malli$core$schema_QMARK_$$,$malli$core$t_malli$0core34055$$,$malli$core$walk$cljs$0core$0IFn$0_invoke$0arity$03$$,$malli$core$validator$cljs$0core$0IFn$0_invoke$0arity$02$$,$malli$core$explain$cljs$0core$0IFn$0_invoke$0arity$03$$,
$malli$core$decoder$cljs$0core$0IFn$0_invoke$0arity$03$$,$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$,$malli$core$deref_all$cljs$0core$0IFn$0_invoke$0arity$01$$,$malli$core$ast$$,$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$,$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$02$$,$_fail_BANG__35958$$,$malli$core$eval$$,$malli$core$eval$cljs$0core$0IFn$0_invoke$0arity$02$$,$malli$core$_instrument$$,$malli$core$_instrument$cljs$0core$0IFn$0_invoke$0arity$02$$,$malli$core$_instrument$cljs$0core$0IFn$0_invoke$0arity$03$$,
$malli$util$_required_map_entry_QMARK_$$,$malli$util$t_malli$0util34488$$,$malli$util$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$malli$util$transform_entries$cljs$0core$0IFn$0_invoke$0arity$03$$,$malli$util$optional_keys$cljs$0core$0IFn$0_invoke$0arity$03$$,$malli$util$required_keys$cljs$0core$0IFn$0_invoke$0arity$03$$,$malli$util$keys$$,$malli$util$update_in$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$malli$util$_reducing$$,$malli$util$_merge$$,$malli$util$_union$$,$module$contents$goog$async$throwException_throwException$$,
$goog$crypt$textToByteArray$$,$lambdaisland$uri$platform$hex__GT_byte$$,$lambdaisland$uri$normalize$char_seq$cljs$0core$0IFn$0_invoke$0arity$02$$,$lambdaisland$uri$normalize$percent_encode$cljs$0core$0IFn$0_invoke$0arity$01$$,$lambdaisland$uri$normalize$percent_encode$cljs$0core$0IFn$0_invoke$0arity$02$$,$lambdaisland$uri$normalize$percent_decode$$,$lambdaisland$uri$URI$$,$lambdaisland$uri$parse$$,$lambdaisland$uri$uri$$,$lambdaisland$uri$remove_dot_segments$$,$lambdaisland$uri$join_STAR_$$,$lambdaisland$uri$decode_param_pair$$,
$lambdaisland$uri$query_encode$$,$lambdaisland$uri$encode_param_pair$$,$lambdaisland$uri$map__GT_query_string$$,$app$common$uri$default_encode_value$$,$app$common$uri$ensure_path_slash$$,$$jscomp$scope$624255649$2$bufferToHex$$,$$jscomp$scope$m1561621495$9$nextLong$$,$$jscomp$scope$m1561621495$4$setBigUint64$$,$app$common$uuid$uuid$$,$app$common$uuid$zero_QMARK_$$,$clojure$test$check$random$longs$bit_count_impl$bit_count$$,$clojure$test$check$random$longs$_STAR_$$,$clojure$test$check$random$rand_long$$,
$clojure$test$check$random$rand_double$$,$clojure$test$check$random$split$$,$clojure$test$check$random$split_n$$,$clojure$test$check$random$bxoubsr$$,$clojure$test$check$random$mix_64$$,$clojure$test$check$random$mix_gamma$$,$clojure$test$check$random$JavaUtilSplittableRandom$$,$clojure$test$check$random$make_java_util_splittable_random$$,$clojure$test$check$rose_tree$RoseTree$$,$clojure$test$check$rose_tree$root$$,$clojure$test$check$rose_tree$make_rose$$,$clojure$test$check$rose_tree$permutations$$,
$clojure$test$check$rose_tree$remove$$,$clojure$test$check$rose_tree$bifurcate$$,$clojure$test$check$rose_tree$shrink_vector_STAR_$$,$clojure$test$check$rose_tree$shrink_vector$$,$clojure$test$check$generators$Generator$$,$clojure$test$check$generators$make_gen$$,$clojure$test$check$generators$call_gen$$,$clojure$test$check$generators$gen_pure$$,$clojure$test$check$generators$gen_fmap$$,$clojure$test$check$generators$gen_bind$$,$clojure$test$check$generators$gen_tuple$$,$clojure$test$check$generators$fmap$$,
$clojure$test$check$generators$return$0$$,$clojure$test$check$generators$bind_helper$$,$clojure$test$check$generators$bind$$,$clojure$test$check$generators$halfs$$,$clojure$test$check$generators$shrink_int$$,$clojure$test$check$generators$rand_range$$,$clojure$test$check$generators$sized$$,$clojure$test$check$generators$resize$$,$clojure$test$check$generators$scale$$,$clojure$test$check$generators$choose$$,$clojure$test$check$generators$one_of$$,$clojure$test$check$generators$pick$$,$clojure$test$check$generators$frequency$$,
$clojure$test$check$generators$elements$$,$clojure$test$check$generators$such_that_helper$$,$clojure$test$check$generators$list$$,$clojure$test$check$generators$coll_distinct_by_STAR_$$,$clojure$test$check$generators$distinct_by_QMARK_$$,$clojure$test$check$generators$the_shuffle_fn$$,$clojure$test$check$generators$coll_distinct_by$$,$clojure$test$check$generators$vector_distinct_by$cljs$0core$0IFn$0_invoke$0arity$03$$,$clojure$test$check$generators$long__GT_large_integer$$,$clojure$test$check$generators$large_integer_STAR__STAR_$$,
$clojure$test$check$generators$large_integer_STAR_$$,$clojure$test$check$generators$get_exponent$$,$clojure$test$check$generators$double_exp_and_sign$$,$clojure$test$check$generators$double_finite$$,$clojure$test$check$generators$double_STAR_$$,$clojure$test$check$generators$resize_symbolish_generator$$,$clojure$test$check$generators$base_simple_type$$,$clojure$test$check$generators$hashable_QMARK_$$,$clojure$test$check$generators$randomized$$,$clojure$test$check$generators$recursive_gen$$,$cljs$spec$gen$alpha$LazyVar$$,
$cljs$spec$gen$alpha$list$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$cljs$spec$gen$alpha$map$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$cljs$spec$gen$alpha$set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$cljs$spec$gen$alpha$vector$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$cljs$spec$gen$alpha$fmap$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$cljs$spec$gen$alpha$elements$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$cljs$spec$gen$alpha$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$cljs$spec$gen$alpha$such_that$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$cljs$spec$gen$alpha$return$0$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$cljs$spec$gen$alpha$large_integer_STAR_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$cljs$spec$gen$alpha$any_printable$$,$cljs$spec$gen$alpha$boolean$0$$,$cljs$spec$gen$alpha$char$0$$,$cljs$spec$gen$alpha$double$0$$,$cljs$spec$gen$alpha$keyword$$,$cljs$spec$gen$alpha$keyword_ns$$,$cljs$spec$gen$alpha$large_integer$$,$cljs$spec$gen$alpha$simple_type_printable$$,$cljs$spec$gen$alpha$string_alphanumeric$$,$cljs$spec$gen$alpha$symbol$$,
$cljs$spec$gen$alpha$symbol_ns$$,$cljs$spec$gen$alpha$uuid$$,$cljs$spec$gen$alpha$qualified_QMARK_$$,$cljs$spec$gen$alpha$gen_for_pred$$,$malli$generator$_generator$$,$malli$generator$_child$$,$malli$generator$_child_gen$$,$malli$generator$_never_gen$$,$malli$generator$_unreachable_gen_QMARK_$$,$malli$generator$_not_unreachable$$,$malli$generator$_unreachable$$,$malli$generator$_min_max$$,$malli$generator$gen_fmap$$,$malli$generator$gen_fcat$$,$malli$generator$gen_tuple$$,$malli$generator$gen_maybe$$,
$malli$generator$gen_double$$,$malli$generator$gen_vector$$,$malli$generator$gen_vector_distinct_by$$,$malli$generator$_coll_gen$cljs$0core$0IFn$0_invoke$0arity$03$$,$malli$generator$_coll_distinct_gen$$,$malli$generator$__GT_such_that_opts$$,$malli$generator$gen_such_that$$,$malli$generator$gen_one_of$$,$malli$generator$_seqable_gen$$,$malli$generator$_or_gen$$,$malli$generator$_merge_keyword_dispatch_map_into_entries$$,$malli$generator$_multi_gen$$,$malli$generator$_build_map$$,$malli$generator$_entry_gen$$,
$malli$generator$_map_gen$$,$malli$generator$_map_of_gen$$,$malli$generator$_identify_ref_schema$$,$malli$generator$_ref_gen$$,$malli$generator$__EQ__GT__gen$$,$malli$generator$_function_gen$$,$malli$generator$_re_entry_gen$$,$malli$generator$_cat_gen$$,$malli$generator$_alt_gen$$,$malli$generator$_qualified_ident_gen$$,$malli$generator$gen_elements$$,$malli$generator$double_gen$$,$malli$generator$_create_from_fmap$$,$malli$generator$_create$$,$malli$generator$generator$$,$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$,
$malli$generator$generate$$,$malli$generator$generate$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$schema$generators$small_double$$,$app$common$schema$generators$small_double$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$schema$generators$small_int$$,$app$common$schema$generators$small_int$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$schema$generators$word_string$$,$app$common$schema$generators$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$app$common$schema$generators$fmap$$,$app$common$schema$generators$filter$$,$app$common$schema$generators$mcat$$,$app$common$schema$generators$tuple$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$schema$generators$set$$,$malli$error$_pr_str$$,$malli$error$_pred_min_max_error_fn$$,$malli$error$_en_humanize_negation$$,$malli$error$_forward_negation$$,$malli$error$_message$$,$malli$error$error_message$$,$cljs$math$floor$$,$cljs$math$round$$,$cljs$math$power_of_two$$,$goog$date$Interval$$,$goog$date$Date$$,
$JSCompiler_StaticMethods_buildDate_$$,$JSCompiler_StaticMethods_maybeFixDst_$$,$goog$date$DateTime$$,$goog$date$UtcDateTime$$,$malli$transform$_string__GT_long$$,$malli$transform$_string__GT_float$$,$malli$transform$_string__GT_double$$,$malli$transform$_number__GT_float$$,$malli$transform$_number__GT_double$$,$malli$transform$_number__GT_long$$,$malli$transform$_string__GT_keyword$$,$malli$transform$_string__GT_boolean$$,$malli$transform$_string__GT_uuid$$,$malli$transform$_string__GT_date$$,$malli$transform$_string__GT_symbol$$,
$malli$transform$_any__GT_string$$,$malli$transform$_date__GT_string$$,$malli$transform$_transform_map_keys$cljs$0core$0IFn$0_invoke$0arity$01$$,$malli$transform$_transform_if_valid$$,$malli$transform$_sequential__GT_set$$,$malli$transform$_sequential__GT_vector$$,$malli$transform$_sequential_or_set__GT_vector$$,$malli$transform$_sequential_or_set__GT_seq$$,$malli$transform$_infer_child_compiler$$,$malli$transform$_add_child_compilers$$,$malli$transform$_base_json_decoders$$,$malli$transform$_base_json_encoders$$,
$malli$transform$_string_decoders$$,$malli$transform$t_malli$0transform35235$$,$malli$transform$collection_transformer$$,$app$common$schema$form$$,$app$common$schema$keys$$,$app$common$schema$_transform_map_keys$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$schema$json_transformer$$,$app$common$schema$string_transformer$$,$app$common$schema$validator$$,$app$common$schema$encoder$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$schema$lazy_validator$$,$app$common$schema$lazy_decoder$$,$app$common$schema$humanize_explain$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$app$common$schema$check_fn$$,$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$schema$coercer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$schema$type_schema$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$schema$coll_schema$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$schema$parse_uuid$$,$app$common$schema$encode_uuid$$,
$app$common$schema$parse_long$$,$app$common$schema$parse_double$$,$app$common$schema$parse_boolean$$,$app$common$schema$parse_keyword$$,$app$common$schema$decode_uri$$,$cljs$spec$alpha$conform_STAR_$$,$cljs$spec$alpha$with_gen_STAR_$$,$cljs$spec$alpha$reg_resolve$$,$cljs$spec$alpha$reg_resolve_BANG_$$,$cljs$spec$alpha$spec_QMARK_$$,$cljs$spec$alpha$regex_QMARK_$$,$cljs$spec$alpha$with_name$$,$cljs$spec$alpha$spec_name$$,$cljs$spec$alpha$maybe_spec$$,$cljs$spec$alpha$the_spec$$,$cljs$spec$alpha$fn_sym$$,
$cljs$spec$alpha$invalid_QMARK_$$,$cljs$spec$alpha$with_gen$$,$cljs$spec$alpha$def_impl$$,$cljs$spec$alpha$dt$cljs$0core$0IFn$0_invoke$0arity$04$$,$cljs$spec$alpha$explain_1$$,$cljs$spec$alpha$t_cljs$0spec$0alpha34071$$,$cljs$spec$alpha$map_spec_impl$$,$cljs$spec$alpha$t_cljs$0spec$0alpha34147$$,$cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$04$$,$cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$05$$,$cljs$spec$alpha$and_preds$$,$cljs$spec$alpha$explain_pred_list$$,$cljs$spec$alpha$coll_prob$$,
$cljs$spec$alpha$t_cljs$0spec$0alpha34417$$,$cljs$spec$alpha$every_impl$cljs$0core$0IFn$0_invoke$0arity$04$$,$cljs$spec$alpha$accept$$,$cljs$spec$alpha$accept_QMARK_$$,$cljs$spec$alpha$rep_STAR_$$,$cljs$spec$alpha$filter_alt$$,$cljs$spec$alpha$alt_STAR_$$,$cljs$spec$alpha$alt2$$,$cljs$spec$alpha$add_ret$$,$cljs$spec$alpha$op_describe$$,$cljs$spec$alpha$re_conform$$,$cljs$spec$alpha$t_cljs$0spec$0alpha34794$$,$cljs$spec$alpha$regex_spec_impl$$,$app$common$exceptions$explain$$,$app$common$exceptions$explain$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$app$common$exceptions$format_throwable$$,$app$common$exceptions$format_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$exceptions$first_line$$,$app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$time$plus$$,$app$common$time$set_default_locale$$,$app$common$time$tpoint_ms$$,$promesa$protocols$_rejected_QMARK_$$,$promesa$protocols$_pending_QMARK_$$,$promesa$protocols$_promise$$,$promesa$protocols$_cancelled_QMARK_$$,$promesa$protocols$IExecutor$$,
$promesa$protocols$_exec_BANG_$$,$promesa$protocols$_schedule_BANG_$$,$$jscomp$scope$84173391$27$transition$$,$$jscomp$scope$84173391$26$resolveTask$$,$$jscomp$scope$84173391$25$processNextTick$$,$$jscomp$scope$84173391$24$process$$,$$jscomp$scope$84173391$23$completeDeferredFn$$,$$jscomp$scope$84173391$19$isThenable$$,$JSCompiler_StaticMethods_fbind$$,$promesa$impl$promise$rejected$$,$promesa$impl$promise$create$$,$promesa$exec$resolve_executor$cljs$0core$0IFn$0_invoke$0arity$01$$,$promesa$exec$exec_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$,
$promesa$exec$schedule_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$,$promesa$exec$Scheduler$$,$promesa$exec$scheduled_executor$$,$promesa$exec$t_promesa$0exec35644$$,$promesa$exec$current_thread_executor$$,$promesa$exec$t_promesa$0exec35651$$,$promesa$exec$microtask_executor$$,$app$common$logging$get_parent_logger$$,$app$common$logging$level__GT_color$$,$app$common$logging$level__GT_name$$,$app$common$logging$get_special_props$$,$cljs_bean$from$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$,
$cljs_bean$from$cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs_bean$from$cljs$core$equiv_sequential$$,$cljs_bean$from$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs_bean$from$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$,$cljs_bean$core$primitive_QMARK_$$,$cljs_bean$core$__GT_val$$,$cljs_bean$core$unwrap$$,$cljs_bean$core$snapshot$$,$cljs_bean$core$snapshot_arr$$,$cljs_bean$core$indexed_entry$$,$cljs_bean$core$compatible_key_QMARK_$$,$cljs_bean$core$compatible_value_QMARK_$$,
$cljs_bean$core$TransientBean$$,$cljs_bean$core$BeanIterator$$,$cljs_bean$core$BeanSeq$$,$cljs_bean$core$Bean$$,$cljs_bean$core$TransientArrayVector$$,$cljs_bean$core$ArrayVectorIterator$$,$cljs_bean$core$ArrayVectorSeq$$,$cljs_bean$core$ArrayVector$$,$cljs_bean$core$default_key__GT_prop$$,$cljs_bean$core$__GT_clj$$,$cljs_bean$core$__GT_clj$cljs$0core$0IFn$0_invoke$0arity$01$$,$cljs_bean$core$__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$rumext$v2$util$ident__GT_key$$,$rumext$v2$util$map__GT_props$cljs$0core$0IFn$0_invoke$0arity$02$$,
$rumext$v2$util$prop__GT_key$$,$rumext$v2$util$key__GT_prop$$,$promesa$impl$coerce$$,$promesa$impl$extend_promise_BANG_$$,$module$contents$goog$Thenable_Thenable$isImplementedBy$$,$module$contents$goog$labs$userAgent$platform_isIphone$$,$module$contents$goog$labs$userAgent$platform_isIos$$,$goog$dom$getElementHelper_$$,$goog$dom$setProperties$$,$goog$dom$append_$$,$goog$dom$createElement_$$,$goog$dom$removeNode$$,$goog$dom$DomHelper$$,$goog$async$nextTick$getNextTickImpl_$$,$goog$Promise$$,$goog$Promise$CallbackEntry_$$,
$goog$Promise$getCallbackEntry_$$,$JSCompiler_StaticMethods_cancelInternal_$$,$JSCompiler_StaticMethods_addCallbackEntry_$$,$JSCompiler_StaticMethods_addChildPromise_$$,$JSCompiler_StaticMethods_resolve_$$,$goog$Promise$tryThen_$$,$JSCompiler_StaticMethods_scheduleCallbacks_$$,$JSCompiler_StaticMethods_popEntry_$$,$JSCompiler_StaticMethods_executeCallback_$$,$goog$Promise$invokeCallback_$$,$goog$Promise$addUnhandledRejection_$$,$goog$Promise$CancellationError$$,$goog$async$Deferred$$,$JSCompiler_StaticMethods_updateResult_$$,
$JSCompiler_StaticMethods_check_$$,$JSCompiler_StaticMethods_hasErrback_$$,$JSCompiler_StaticMethods_fire_$$,$goog$async$Deferred$AlreadyCalledError$$,$goog$async$Deferred$CanceledError$$,$goog$async$Deferred$Error_$$,$$jscomp$scope$1087077126$0$createMockedEventEmitter$$,$app$util$globals$event$$,$app$util$globals$dispatch_BANG_$$,$app$util$globals$unlisten$$,$com$cognitect$transit$util$randHex$$,$com$cognitect$transit$caching$isCacheable$$,$com$cognitect$transit$caching$idxToCode$$,$com$cognitect$transit$caching$WriteCache$$,
$com$cognitect$transit$caching$ReadCache$$,$com$cognitect$transit$eq$equals$$,$com$cognitect$transit$eq$hashCombine$$,$com$cognitect$transit$eq$hashMapLike$$,$com$cognitect$transit$eq$hashArrayLike$$,$com$cognitect$transit$eq$hashCode$$,$com$cognitect$transit$types$TaggedValue$$,$com$cognitect$transit$types$taggedValue$$,$com$cognitect$transit$types$Keyword$$,$com$cognitect$transit$types$Symbol$$,$com$cognitect$transit$types$hexFor$$,$com$cognitect$transit$types$UUID$$,$com$cognitect$transit$types$TransitArrayMapIterator$$,
$com$cognitect$transit$types$TransitMapIterator$$,$com$cognitect$transit$types$mapEquals$$,$com$cognitect$transit$types$print$$,$com$cognitect$transit$types$printMap$$,$com$cognitect$transit$types$printSet$$,$com$cognitect$transit$types$TransitArrayMap$$,$JSCompiler_StaticMethods_convert$$,$com$cognitect$transit$types$TransitMap$$,$com$cognitect$transit$types$map$$,$com$cognitect$transit$types$TransitSet$$,$com$cognitect$transit$types$set$$,$com$cognitect$transit$impl$decoder$Tag$$,$com$cognitect$transit$impl$decoder$Decoder$$,
$JSCompiler_StaticMethods_decodeArray$$,$JSCompiler_StaticMethods_parseString$$,$com$cognitect$transit$impl$reader$JSONUnmarshaller$$,$com$cognitect$transit$impl$reader$Reader$$,$com$cognitect$transit$handlers$typeTag$$,$com$cognitect$transit$handlers$padZeros$$,$com$cognitect$transit$handlers$NilHandler$$,$com$cognitect$transit$handlers$StringHandler$$,$com$cognitect$transit$handlers$NumberHandler$$,$com$cognitect$transit$handlers$IntegerHandler$$,$com$cognitect$transit$handlers$BooleanHandler$$,
$com$cognitect$transit$handlers$ArrayHandler$$,$com$cognitect$transit$handlers$MapHandler$$,$com$cognitect$transit$handlers$VerboseDateHandler$$,$com$cognitect$transit$handlers$DateHandler$$,$com$cognitect$transit$handlers$UUIDHandler$$,$com$cognitect$transit$handlers$KeywordHandler$$,$com$cognitect$transit$handlers$SymbolHandler$$,$com$cognitect$transit$handlers$TaggedHandler$$,$com$cognitect$transit$handlers$TransitSetHandler$$,$com$cognitect$transit$handlers$TransitArrayMapHandler$$,$com$cognitect$transit$handlers$TransitMapHandler$$,
$com$cognitect$transit$handlers$BufferHandler$$,$com$cognitect$transit$handlers$Uint8ArrayHandler$$,$com$cognitect$transit$handlers$Handlers$$,$com$cognitect$transit$impl$writer$JSONMarshaller$$,$JSCompiler_StaticMethods_emitString$$,$com$cognitect$transit$impl$writer$emitObjects$$,$com$cognitect$transit$impl$writer$isStringableKey$$,$com$cognitect$transit$impl$writer$stringableKeys$$,$com$cognitect$transit$impl$writer$isForeignObject$$,$com$cognitect$transit$impl$writer$emitMap$$,$com$cognitect$transit$impl$writer$marshal$$,
$com$cognitect$transit$impl$writer$Writer$$,$com$cognitect$transit$reader$$,$com$cognitect$transit$writer$$,$cognitect$transit$opts_merge$$,$cognitect$transit$MapBuilder$$,$cognitect$transit$VectorBuilder$$,$cognitect$transit$reader$cljs$0core$0IFn$0_invoke$0arity$02$$,$cognitect$transit$KeywordHandler$$,$cognitect$transit$SymbolHandler$$,$cognitect$transit$ListHandler$$,$cognitect$transit$MapHandler$$,$cognitect$transit$SetHandler$$,$cognitect$transit$VectorHandler$$,$cognitect$transit$UUIDHandler$$,
$cognitect$transit$WithMeta$$,$cognitect$transit$WithMetaHandler$$,$cognitect$transit$writer$cljs$0core$0IFn$0_invoke$0arity$02$$,$cognitect$transit$fn_or_val$$,$cognitect$transit$t_cognitect$0transit40239$$,$cognitect$transit$write_handler$cljs$0core$0IFn$0_invoke$0arity$04$$,$cognitect$transit$write_meta$$,$app$common$transit$Pointer$$,$beicon$v2$operators$scheduler$$,$beicon$v2$operators$filter$$,$beicon$v2$operators$map$$,$beicon$v2$operators$merge_map$cljs$0core$0IFn$0_invoke$0arity$01$$,$beicon$v2$operators$switch_map$$,
$beicon$v2$operators$mapcat$$,$beicon$v2$operators$take_while$$,$beicon$v2$operators$reduce$cljs$0core$0IFn$0_invoke$0arity$01$$,$beicon$v2$operators$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$,$beicon$v2$operators$scan$cljs$0core$0IFn$0_invoke$0arity$02$$,$beicon$v2$operators$with_latest$$,$beicon$v2$operators$catch$0$$,$beicon$v2$operators$timeout$cljs$0core$0IFn$0_invoke$0arity$02$$,$beicon$v2$operators$comp$$,$beicon$v2$operators$observe_on$cljs$0core$0IFn$0_invoke$0arity$01$$,$beicon$v2$core$push_BANG_$$,
$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$,$beicon$v2$core$if_empty$$,$beicon$v2$core$merge_all$cljs$0core$0IFn$0_invoke$0arity$02$$,$beicon$v2$core$concat_all$$,$beicon$v2$core$take_while$$,$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$,$beicon$v2$core$sample$$,$app$util$rxops$throttle$$,$okulary$util$doiter$$,$app$util$storage$encode_key$$,$app$util$storage$load_data$$,$app$util$storage$set_item$$,$app$util$storage$get_item$$,$app$util$storage$t_app$0util$0storage43623$$,
$app$util$storage$create_storage$$,$app$util$timers$t_app$0util$0timers42504$$,$app$util$timers$dispose_BANG_$$,$app$util$timers$t_app$0util$0timers42521$$,$app$util$timers$t_app$0util$0timers42549$$,$app$config$resolve_href$$,$cljs$pprint$prn$$,$cljs$pprint$char_code$$,$cljs$pprint$map_passing_context$$,$cljs$pprint$consume$$,$cljs$pprint$unzip_map$$,$cljs$pprint$tuple_map$$,$cljs$pprint$_ppflush$$,$cljs$pprint$get_field$$,$cljs$pprint$set_field$$,$cljs$pprint$get_column$$,$cljs$pprint$get_max_column$$,
$cljs$pprint$c_write_char$$,$cljs$pprint$t_cljs$0pprint43189$$,$cljs$pprint$logical_block$$,$cljs$pprint$ancestor_QMARK_$$,$cljs$pprint$buffer_blob$$,$cljs$pprint$nl_t$$,$cljs$pprint$start_block_t$$,$cljs$pprint$end_block_t$$,$cljs$pprint$indent_t$$,$cljs$pprint$write_tokens$$,$cljs$pprint$tokens_fit_QMARK_$$,$cljs$pprint$linear_nl_QMARK_$$,$cljs$pprint$miser_nl_QMARK_$$,$cljs$pprint$get_section$$,$cljs$pprint$get_sub_section$$,$cljs$pprint$emit_nl$$,$cljs$pprint$split_at_newline$$,$cljs$pprint$write_line$$,
$cljs$pprint$add_to_buffer$$,$cljs$pprint$write_white_space$$,$cljs$pprint$write_initial_lines$$,$cljs$pprint$t_cljs$0pprint43666$$,$cljs$pprint$pretty_writer$$,$cljs$pprint$start_block$$,$cljs$pprint$end_block$$,$cljs$pprint$pretty_writer_QMARK_$$,$cljs$pprint$write_out$$,$cljs$pprint$check_enumerated_arg$$,$cljs$pprint$level_exceeded$$,$cljs$pprint$pprint_newline$$,$cljs$pprint$pprint_indent$$,$cljs$pprint$cl_format$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$cljs$pprint$format_error$$,$cljs$pprint$arg_navigator$$,
$cljs$pprint$init_navigator$$,$cljs$pprint$next_arg$$,$cljs$pprint$get_format_arg$$,$cljs$pprint$absolute_reposition$$,$cljs$pprint$relative_reposition$$,$cljs$pprint$compiled_directive$$,$cljs$pprint$realize_parameter$$,$cljs$pprint$realize_parameter_list$$,$cljs$pprint$format_ascii$$,$cljs$pprint$remainders$$,$cljs$pprint$base_str$$,$cljs$pprint$group_by_STAR_$$,$cljs$pprint$format_integer$$,$cljs$pprint$format_simple_cardinal$$,$cljs$pprint$add_english_scales$$,$cljs$pprint$format_roman$$,$cljs$pprint$pretty_character$$,
$cljs$pprint$readable_character$$,$cljs$pprint$plain_character$$,$cljs$pprint$abort_QMARK_$$,$cljs$pprint$execute_sub_format$$,$cljs$pprint$float_parts$$,$cljs$pprint$round_str$$,$cljs$pprint$get_fixed$$,$cljs$pprint$insert_scaled_decimal$$,$cljs$pprint$fixed_float$$,$cljs$pprint$exponential_float$$,$cljs$pprint$general_float$$,$cljs$pprint$dollar_float$$,$cljs$pprint$choice_conditional$$,$cljs$pprint$boolean_conditional$$,$cljs$pprint$check_arg_conditional$$,$cljs$pprint$iterate_sublist$$,$cljs$pprint$iterate_list_of_sublists$$,
$cljs$pprint$iterate_main_list$$,$cljs$pprint$iterate_main_sublists$$,$cljs$pprint$logical_block_or_justify$$,$cljs$pprint$render_clauses$$,$cljs$pprint$justify_clauses$$,$cljs$pprint$t_cljs$0pprint44851$$,$cljs$pprint$downcase_writer$$,$cljs$pprint$t_cljs$0pprint44871$$,$cljs$pprint$upcase_writer$$,$cljs$pprint$capitalize_string$$,$cljs$pprint$t_cljs$0pprint44886$$,$cljs$pprint$capitalize_word_writer$$,$cljs$pprint$t_cljs$0pprint44899$$,$cljs$pprint$init_cap_writer$$,$cljs$pprint$set_indent$$,$cljs$pprint$conditional_newline$$,
$cljs$pprint$extract_param$$,$cljs$pprint$translate_param$$,$cljs$pprint$extract_flags$$,$cljs$pprint$check_flags$$,$cljs$pprint$map_params$$,$cljs$pprint$compile_directive$$,$cljs$pprint$compile_raw_string$$,$cljs$pprint$process_bracket$$,$cljs$pprint$process_clause$$,$cljs$pprint$collect_clauses$$,$cljs$pprint$process_nesting$$,$cljs$pprint$compile_format$$,$cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$pprint$pprint_reader_macro$$,$cljs$pprint$pprint_vector$$,$cljs$pprint$pprint_map$$,
$cljs$pprint$pprint_simple_default$$,$cljs$pprint$type_dispatcher$$,$cljs$pprint$brackets$$,$cljs$pprint$pprint_ns_reference$$,$cljs$pprint$single_defn$$,$cljs$pprint$multi_defn$$,$cljs$pprint$pprint_defn$$,$cljs$pprint$pprint_binding_form$$,$cljs$pprint$pprint_let$$,$cljs$pprint$pprint_simple_code_list$$,$app$common$geom$point$Point$$,$app$common$geom$point$map__GT_Point$$,$app$common$geom$point$point_QMARK_$$,$app$common$geom$point$decode_point$$,$app$common$geom$point$close_QMARK_$$,$app$common$geom$point$signed_angle_with_other$$,
$app$common$geom$point$round_step$$,$app$common$geom$point$transform_BANG_$$,$app$common$geom$point$perpendicular$$,$app$common$geom$point$project$$,$app$common$geom$point$center_points$$,$app$common$geom$point$lerp$$,$app$common$geom$rect$Rect$$,$app$common$geom$rect$map__GT_Rect$$,$app$common$geom$rect$rect_QMARK_$$,$app$common$geom$rect$close_rect_QMARK_$$,$app$common$geom$rect$contains_point_QMARK_$$,$app$common$geom$rect$corners__GT_rect$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$common$geom$rect$fix_aspect_ratio$$,
$app$common$media$format__GT_mtype$$,$app$common$media$mtype__GT_extension$$,$app$common$media$font_weight__GT_name$$,$promesa$core$create$cljs$0core$0IFn$0_invoke$0arity$01$$,$promesa$core$mcat$cljs$0core$0IFn$0_invoke$0arity$02$$,$promesa$core$fnly$cljs$0core$0IFn$0_invoke$0arity$02$$,$promesa$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$util$webapi$get_selection$$,$app$util$webapi$set_cursor_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$util$webapi$set_cursor_after_BANG_$$,$okulary$core$Atom$$,
$okulary$core$atom$$,$okulary$core$DerivedAtom$$,$potok$v2$core$UpdateEvent$$,$potok$v2$core$update$$,$potok$v2$core$WatchEvent$$,$potok$v2$core$watch$$,$potok$v2$core$EffectEvent$$,$potok$v2$core$effect$$,$potok$v2$core$Event$$,$potok$v2$core$_type$$,$potok$v2$core$update_QMARK_$$,$potok$v2$core$watch_QMARK_$$,$potok$v2$core$effect_QMARK_$$,$potok$v2$core$event_QMARK_$$,$potok$v2$core$promise_QMARK_$$,$potok$v2$core$event$cljs$0core$0IFn$0_invoke$0arity$02$$,$potok$v2$core$repr_event$$,$module$contents$goog$dispose_dispose$$,
$module$contents$goog$disposeAll_disposeAll$$,$goog$Disposable$$,$goog$events$EventId$$,$app$util$dom$get_parent_at$$,$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$util$dom$escape_html$$,$app$util$dom$set_html_BANG_$$,$app$util$dom$insert_after_BANG_$$,$app$util$dom$is_bounding_rect_outside_QMARK_$$,$app$util$dom$get_boolean_data$$,$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$util$dom$browser_back$$,$app$util$dom$seq_nodes$$,$app$util$cache$with_cache$$,
$goog$module$BaseModule$$,$goog$module$ModuleLoadCallback$$,$goog$module$ModuleInfo$$,$JSCompiler_StaticMethods_registerErrback$$,$JSCompiler_StaticMethods_callCallbacks_$$,$goog$loader$AbstractModuleManager$$,$JSCompiler_StaticMethods_getEffectiveLevel$$,$JSCompiler_StaticMethods_getLogRegistryEntry$$,$goog$log$log$classdecl$var5$getInstance$$,$goog$log$getLogger$$,$goog$log$log$$,$goog$log$error$$,$goog$log$info$$,$goog$log$fine$$,$JSCompiler_StaticMethods_getReadableError_$$,$goog$module$ModuleManager$$,
$goog$module$ModuleManager$ModuleFailureError$$,$JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$$,$JSCompiler_StaticMethods_registerModuleLoadCallbacks_$$,$JSCompiler_StaticMethods_processModulesForLoad_$$,$JSCompiler_StaticMethods_getNotYetLoadedTransitiveDepIds_$$,$JSCompiler_StaticMethods_isModuleLoading$$,$JSCompiler_StaticMethods_addUserInitiatedLoadingModule_$$,$JSCompiler_StaticMethods_requeueBatchOrDispatchFailure_$$,$JSCompiler_StaticMethods_dispatchModuleLoadFailed_$$,$JSCompiler_StaticMethods_loadNextModules_$$,
$goog$events$Listenable$isImplementedBy$$,$goog$events$Listener$$,$JSCompiler_StaticMethods_markAsRemoved$$,$goog$events$ListenerMap$$,$JSCompiler_StaticMethods_removeByKey$$,$goog$events$ListenerMap$findListenerIndex_$$,$goog$events$listen_$$,$goog$events$getProxy$$,$goog$events$listenOnce$$,$goog$events$getOnString_$$,$goog$events$handleBrowserEvent_$$,$goog$events$getListenerMap_$$,$goog$events$wrapListener$$,$goog$events$EventHandler$$,$JSCompiler_StaticMethods_listenOnce_$$,$JSCompiler_StaticMethods_fireListeners$$,
$goog$net$BulkLoaderHelper$$,$goog$Timer$callOnce$$,$goog$net$XmlHttpFactory$$,$JSCompiler_StaticMethods_getOptions$$,$goog$net$DefaultXmlHttpFactory$$,$JSCompiler_StaticMethods_createInstance$$,$JSCompiler_StaticMethods_getProgId_$$,$goog$net$XhrIo$$,$goog$net$XhrIo$shouldUseXhr2Timeout_$$,$JSCompiler_StaticMethods_dispatchErrors_$$,$JSCompiler_StaticMethods_onReadyStateChangeHelper_$$,$goog$net$XhrIo$buildProgressEvent_$$,$JSCompiler_StaticMethods_cleanUpXhr_$$,$JSCompiler_StaticMethods_cleanUpTimeoutTimer_$$,
$JSCompiler_StaticMethods_isSuccess$$,$JSCompiler_StaticMethods_getReadyState$$,$JSCompiler_StaticMethods_getStatus$$,$JSCompiler_StaticMethods_formatMsg_$$,$goog$net$BulkLoader$$,$goog$net$BulkLoader$LoadErrorEvent$$,$goog$net$jsloader$safeLoadMany$$,$goog$net$jsloader$safeLoad$$,$goog$net$jsloader$getScriptParentElement_$$,$goog$net$jsloader$cancel_$$,$goog$net$jsloader$cleanup_$$,$goog$net$jsloader$Error$$,$module$contents$goog$module$ModuleLoader_ModuleLoader$$,$module$contents$goog$module$ModuleLoader_ModuleLoader$createScriptElement_$$,
$JSCompiler_StaticMethods_evaluateCode_$$,$JSCompiler_StaticMethods_downloadModules_$$,$JSCompiler_StaticMethods_loadWithNonAsyncScriptTag_$$,$JSCompiler_StaticMethods_handleErrorHelper_$$,$module$contents$goog$module$ModuleLoader_ModuleLoader$EvaluateCodeEvent$$,$module$contents$goog$module$ModuleLoader_ModuleLoader$RequestSuccessEvent$$,$module$contents$goog$module$ModuleLoader_ModuleLoader$RequestErrorEvent$$,$module$contents$goog$module$ModuleLoader_ModuleLoader$LoadStatus$$,$rumext$v2$use_ssr_effect$$,
$rumext$v2$State$$,$rumext$v2$element$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$util$perf$install_long_task_observer$$,$app$util$perf$start_event_loop_stall_logger$$,$app$util$perf$setup$$,$app$util$http$_update_headers$$,$app$util$http$_get_body_data$$,$app$util$http$translate_method$$,$app$util$http$response__GT_map$$,$app$util$http$process_response_type$$,$app$util$http$form_data$$,$app$util$http$conditional_decode_transit$$,$app$util$http$conditional_error_decode_transit$$,$app$common$geom$matrix$Matrix$$,
$app$common$geom$matrix$pos__GT_Matrix$$,$app$common$geom$matrix$map__GT_Matrix$$,$app$common$geom$matrix$matrix_QMARK_$$,$app$common$geom$matrix$str__GT_matrix$$,$app$common$geom$matrix$decode_matrix$$,$app$common$geom$matrix$close_QMARK_$$,$app$common$geom$matrix$unit_QMARK_$$,$app$common$geom$matrix$multiply_BANG_$$,$app$common$geom$matrix$translate_matrix_neg$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$geom$matrix$scale$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$geom$matrix$translate_BANG_$$,
$app$common$geom$matrix$inverse$$,$app$common$geom$shapes$common$invalid_geometry_QMARK_$$,$app$common$geom$shapes$common$shape__GT_points$$,$app$common$files$helpers$image_shape_QMARK_$$,$app$common$files$helpers$has_layout_QMARK_$$,$app$common$files$helpers$get_selected_type$$,$app$common$files$helpers$get_shape_type$$,$app$common$files$helpers$get_children_ids_with_self$$,$app$common$files$helpers$get_children$$,$app$common$files$helpers$get_parent$$,$app$common$files$helpers$get_parent_seq$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$common$files$helpers$get_parent_seq$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$files$helpers$get_parents_with_self$$,$app$common$files$helpers$get_parent_ids_with_index$$,$app$common$files$helpers$get_siblings_ids$$,$app$common$files$helpers$get_position_on_parent$$,$app$common$files$helpers$get_prev_sibling$$,$app$common$files$helpers$get_base_shape$$,$app$common$files$helpers$page_QMARK_$$,$app$common$files$helpers$components_nesting_loop_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$files$helpers$components_nesting_loop_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$common$files$helpers$name_seq$$,$app$common$files$helpers$append_at_the_end$$,$app$common$files$helpers$indexed_shapes$$,$app$common$files$helpers$order_by_indexed_shapes$$,$app$common$files$helpers$collect_shape_media_refs$$,$app$common$files$helpers$reduce_objects$cljs$0core$0IFn$0_invoke$0arity$05$$,$app$common$files$helpers$fixed_scroll_QMARK_$$,$app$common$files$helpers$fixed_QMARK_$$,$app$common$geom$shapes$corners$zero_div$$,$app$common$geom$shapes$corners$shape_corners_1$$,$app$common$geom$shapes$corners$shape_corners_4$$,
$app$common$geom$shapes$effects$update_shadows_scale$$,$app$common$geom$shapes$strokes$update_strokes_width$$,$app$common$geom$shapes$grid_layout$areas$area__GT_cell_props$$,$app$common$geom$shapes$grid_layout$areas$make_area$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$geom$shapes$grid_layout$areas$make_area$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$common$geom$shapes$grid_layout$areas$contains_QMARK_$$,$app$common$geom$shapes$grid_layout$areas$intersects_QMARK_$$,$app$common$geom$shapes$grid_layout$areas$top_rect$$,
$app$common$geom$shapes$grid_layout$areas$bottom_rect$$,$app$common$geom$shapes$grid_layout$areas$left_rect$$,$app$common$geom$shapes$grid_layout$areas$right_rect$$,$app$common$geom$shapes$grid_layout$areas$difference$$,$app$common$types$shape$layout$wrap_QMARK_$$,$app$common$types$shape$layout$fill_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$types$shape$layout$auto_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$types$shape$layout$paddings$$,$app$common$types$shape$layout$child_min_width$$,
$app$common$types$shape$layout$child_max_width$$,$app$common$types$shape$layout$child_min_height$$,$app$common$types$shape$layout$child_max_height$$,$app$common$types$shape$layout$child_margins$$,$app$common$types$shape$layout$child_height_margin$$,$app$common$types$shape$layout$child_width_margin$$,$app$common$types$shape$layout$h_start_QMARK_$$,$app$common$types$shape$layout$h_center_QMARK_$$,$app$common$types$shape$layout$h_end_QMARK_$$,$app$common$types$shape$layout$v_start_QMARK_$$,$app$common$types$shape$layout$v_center_QMARK_$$,
$app$common$types$shape$layout$v_end_QMARK_$$,$app$common$types$shape$layout$content_center_QMARK_$$,$app$common$types$shape$layout$content_end_QMARK_$$,$app$common$types$shape$layout$content_around_QMARK_$$,$app$common$types$shape$layout$content_evenly_QMARK_$$,$app$common$types$shape$layout$content_stretch_QMARK_$$,$app$common$types$shape$layout$align_items_center_QMARK_$$,$app$common$types$shape$layout$align_items_end_QMARK_$$,$app$common$types$shape$layout$space_between_QMARK_$$,$app$common$types$shape$layout$space_around_QMARK_$$,
$app$common$types$shape$layout$space_evenly_QMARK_$$,$app$common$types$shape$layout$align_self_start_QMARK_$$,$app$common$types$shape$layout$align_self_end_QMARK_$$,$app$common$types$shape$layout$align_self_center_QMARK_$$,$app$common$types$shape$layout$layout_z_index$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$types$shape$layout$comparator_layout_z_index$$,$app$common$types$shape$layout$change_h_sizing_QMARK_$$,$app$common$types$shape$layout$change_v_sizing_QMARK_$$,$app$common$types$shape$layout$remove_layout_item_data$$,
$app$common$types$shape$layout$update_grid_scale$$,$app$common$types$shape$layout$add_grid_track$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$common$types$shape$layout$make_remove_cell$$,$app$common$types$shape$layout$make_decrease_track_num$$,$app$common$types$shape$layout$remove_grid_column$$,$app$common$types$shape$layout$remove_grid_row$$,$app$common$types$shape$layout$cells_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$types$shape$layout$get_free_cells$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$common$types$shape$layout$check_deassigned_cells$$,$app$common$types$shape$layout$reassign_positions$$,$app$common$types$shape$layout$position_auto_shapes$$,$app$common$types$shape$layout$assign_cell_positions$$,$app$common$types$shape$layout$free_cell_push$$,$app$common$types$shape$layout$in_cell_QMARK_$$,$app$common$types$shape$layout$cell_by_row_column$$,$app$common$types$shape$layout$seek_indexed_cell$$,$app$common$types$shape$layout$free_cell_shapes$$,$app$common$types$shape$layout$push_into_cell$$,
$app$common$types$shape$layout$create_cells$$,$app$common$types$shape$layout$swap_shapes$$,$app$common$types$shape$layout$add_children_to_cell$$,$app$common$types$shape$layout$get_cell_by_index$$,$app$common$types$shape$layout$reorder_grid_children$$,$app$common$types$shape$layout$merge_cells$$,$app$common$types$shape$layout$toggle_fix_if_auto$$,$app$common$types$color$has_valid_color_attrs_QMARK_$$,$app$common$types$color$hex_color_string_QMARK_$$,$app$common$types$color$shadow__GT_color$$,$app$common$types$color$grid__GT_color$$,
$app$common$types$color$parse_rgb$$,$app$common$types$color$hex__GT_rgba$$,$app$common$types$color$format_hsla$$,$app$common$types$color$format_rgba$$,$JSCompiler_StaticMethods__findEntry$$,$app$common$weak$weak_key$$,$app$common$buffer$wrap$$,$app$common$buffer$equals_QMARK_$$,$app$common$types$fills$impl$_write_to$$,$app$common$types$fills$impl$_get_byte_size$$,$app$common$types$fills$impl$_get_image_ids$$,$app$common$types$fills$impl$hex__GT_rgb$$,$app$common$types$fills$impl$write_solid_fill$$,
$app$common$types$fills$impl$write_gradient_fill$$,$app$common$types$fills$impl$write_image_fill$$,$app$common$types$fills$impl$write_metadata$$,$app$common$types$fills$impl$read_fill$$,$app$common$types$fills$impl$Fills$$,$app$common$types$fills$impl$fills_QMARK_$$,$app$common$types$fills$has_valid_fill_attrs_QMARK_$$,$app$common$types$fills$coerce$$,$app$common$types$fills$get_image_ids$$,$app$common$types$fills$assoc$$,$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$types$text$update_text_content$$,
$app$common$types$text$equal_attrs_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$types$text$get_first_paragraph_text_attrs$$,$app$common$types$text$get_diff_type$$,$app$common$types$text$get_diff_attrs$$,$app$common$types$modifiers$Modifiers$$,$app$common$types$modifiers$safe_size_rect_QMARK_$$,$app$common$types$modifiers$safe_size_rect$$,$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$06$$,$app$common$types$modifiers$remove_children$$,
$app$common$types$modifiers$add_children$$,$app$common$types$modifiers$concat_geometry$$,$app$common$types$modifiers$increase_order$$,$app$common$types$modifiers$add_modifiers$$,$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$types$modifiers$empty_QMARK_$$,$app$common$types$modifiers$child_modifiers_QMARK_$$,$app$common$types$modifiers$has_geometry_QMARK_$$,$app$common$types$modifiers$has_structure_QMARK_$$,$app$common$types$modifiers$only_move_QMARK_$$,
$app$common$types$modifiers$select_child$$,$app$common$types$modifiers$select_structure$$,$app$common$types$modifiers$select_geometry$$,$app$common$types$modifiers$added_children_frames$$,$app$common$types$modifiers$transform_BANG_$$,$app$common$types$modifiers$modifiers__GT_transform1$$,$app$common$types$modifiers$modifiers__GT_transform$$,$app$common$types$modifiers$transform_text_node$$,$app$common$types$modifiers$transform_paragraph_node$$,$app$common$types$modifiers$scale_text_content$$,$app$common$types$modifiers$apply_scale_content$$,
$app$common$types$modifiers$remove_children_set$$,$app$common$types$modifiers$apply_modifier$$,$app$common$types$path$helpers$make_move_to$$,$app$common$types$path$helpers$make_line_to$$,$app$common$types$path$helpers$make_curve_params$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$types$path$helpers$make_curve_params$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$types$path$helpers$update_curve_to$$,$app$common$types$path$helpers$make_curve_to$$,$app$common$types$path$helpers$prefix__GT_coords$$,
$app$common$types$path$helpers$command__GT_line$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$types$path$helpers$command__GT_bezier$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$types$path$helpers$line_values$$,$app$common$types$path$helpers$curve_values$$,$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$types$path$helpers$solve_roots_STAR_$$,$app$common$types$path$helpers$curve_extremities$$,$app$common$types$path$helpers$curve_extremities$cljs$0core$0IFn$0_invoke$0arity$01$$,
$app$common$types$path$helpers$curve_extremities$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$common$types$path$helpers$calculate_curve_extremities$$,$app$common$types$path$helpers$curve_tangent$$,$app$common$types$path$helpers$curve_split$cljs$0core$0IFn$0_invoke$0arity$05$$,$app$common$types$path$helpers$subcurve_range$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$types$path$helpers$subcurve_range$cljs$0core$0IFn$0_invoke$0arity$06$$,$app$common$types$path$helpers$split_line_to_ranges$$,$app$common$types$path$helpers$split_curve_to_ranges$$,
$app$common$types$path$helpers$get_line_tval$$,$app$common$types$path$helpers$curve_range__GT_rect$$,$app$common$types$path$helpers$line_has_point_QMARK_$$,$app$common$types$path$helpers$curve_has_point_QMARK_$$,$app$common$types$path$helpers$curve_roots$cljs$0core$0IFn$0_invoke$0arity$05$$,$app$common$types$path$helpers$line_line_crossing$$,$app$common$types$path$helpers$line_curve_crossing$$,$app$common$types$path$helpers$line_curve_intersect$$,$app$common$types$path$helpers$ray_overlaps_QMARK_$$,
$app$common$types$path$helpers$ray_curve_intersect$$,$app$common$types$path$helpers$curve_curve_intersect$$,$app$common$types$path$helpers$is_point_in_geom_data_QMARK_$$,$app$common$types$path$helpers$is_point_in_border_QMARK_$$,$app$common$schema$openapi$minmax_properties$$,$app$common$schema$openapi$unlift_keys$$,$app$common$schema$openapi$transform_STAR_$$,$validCommand$$module$app$common$svg$path$parser$$,$JSCompiler_StaticMethods__skipOptionalSpaces$$,$JSCompiler_StaticMethods__parseNumber$$,
$JSCompiler_StaticMethods__parseArcFlag$$,$JSCompiler_StaticMethods__isCurrentSpace$$,$JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$$,$unitVectorAngle$$module$app$common$svg$path$parser$$,$arcToBeziers$$module$app$common$svg$path$parser$$,$app$common$types$path$impl$normalize_coord$$,$app$common$types$path$impl$_write_to$$,$app$common$types$path$impl$_get_byte_size$$,$app$common$types$path$impl$_transform$$,$app$common$types$path$impl$_lookup$$,$app$common$types$path$impl$_walk$$,$app$common$types$path$impl$_reduce$$,
$app$common$types$path$impl$impl_walk$$,$app$common$types$path$impl$impl_reduce$$,$app$common$types$path$impl$impl_lookup$$,$app$common$types$path$impl$read_segment$$,$app$common$types$path$impl$PathData$$,$app$common$types$path$impl$path_data_QMARK_$$,$app$common$types$path$impl$from_string$$,$app$common$types$path$segment$update_handler$$,$app$common$types$path$segment$point_indices$$,$app$common$types$path$segment$handler_indices$$,$app$common$types$path$segment$opposite_index$$,$app$common$types$path$segment$get_points$$,
$app$common$types$path$segment$remove_line_curves$$,$app$common$types$path$segment$make_corner_point$$,$app$common$types$path$segment$line__GT_curve$$,$app$common$types$path$segment$make_curve_point$$,$app$common$types$path$segment$next_node$$,$app$common$types$path$segment$remove_nodes$$,$app$common$types$path$segment$join_nodes$$,$app$common$types$path$segment$separate_nodes$$,$app$common$types$path$segment$add_to_set$$,$app$common$types$path$segment$join_sets$$,$app$common$types$path$segment$group_segments$$,
$app$common$types$path$segment$calculate_merge_points$$,$app$common$types$path$segment$replace_points$$,$app$common$types$path$segment$transform_content$$,$app$common$types$path$segment$calculate_extremities$$,$app$common$types$path$segment$content__GT_selrect$$,$app$common$types$path$segment$points__GT_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$types$path$subpath$pt_EQ_$$,$app$common$types$path$subpath$make_subpath$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$types$path$subpath$add_subpath_command$$,
$app$common$types$path$subpath$reverse_subpath$$,$app$common$types$path$subpath$get_subpaths$$,$app$common$types$path$subpath$subpaths_join$$,$app$common$types$path$subpath$merge_paths$$,$app$common$types$path$subpath$is_closed_QMARK_$$,$app$common$types$path$subpath$join_adjacent$$,$app$common$types$path$subpath$close_subpaths$$,$app$common$types$path$subpath$clockwise_QMARK_$$,$app$common$types$path$bool$add_previous$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$types$path$bool$add_previous$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$common$types$path$bool$close_paths$$,$app$common$types$path$bool$split_ts$$,$app$common$types$path$bool$content_intersect_split$$,$app$common$types$path$bool$is_segment_QMARK_$$,$app$common$types$path$bool$contains_segment_QMARK_$$,$app$common$types$path$bool$overlap_segment_QMARK_$$,$app$common$types$path$bool$fix_move_to$$,$app$common$types$path$bool$remove_duplicated_segments$$,$app$common$types$path$bool$close_content$$,$app$common$types$path$bool$content__GT_geom_data$$,$app$common$types$path$bool$create_union$$,
$app$common$types$path$bool$create_difference$$,$app$common$types$path$bool$create_intersection$$,$app$common$types$path$bool$content_bool_pair$$,$app$common$types$path$bool$calculate_content$$,$app$common$types$shape$radius$can_get_border_radius_QMARK_$$,$app$common$types$shape$radius$all_equal_QMARK_$$,$app$common$types$shape$radius$set_radius_for_corners$$,$app$common$types$path$shape_to_path$make_corner_arc$$,$app$common$types$path$shape_to_path$circle__GT_path$$,$app$common$types$path$shape_to_path$draw_rounded_rect_path$cljs$0core$0IFn$0_invoke$0arity$08$$,
$app$common$types$path$shape_to_path$rect__GT_path$$,$app$common$types$path$shape_to_path$fix_first_relative$$,$app$common$types$path$shape_to_path$group_to_path$$,$app$common$types$path$shape_to_path$bool_to_path$$,$app$common$types$path$shape_to_path$convert_to_path$$,$app$common$types$path$close_subpaths$$,$app$common$types$path$transform_content$$,$app$common$types$path$move_content$$,$app$common$types$path$point_indices$$,$app$common$types$path$handler_indices$$,$app$common$types$path$append_segment$$,
$app$common$types$path$points__GT_content$$,$app$common$types$path$make_corner_point$$,$app$common$types$path$make_curve_point$$,$app$common$types$path$calc_bool_content_STAR_$$,$app$common$types$path$calc_bool_content$$,$app$common$geom$shapes$transforms$valid_point_QMARK_$$,$app$common$geom$shapes$transforms$move_selrect$$,$app$common$geom$shapes$transforms$move_points$$,$app$common$geom$shapes$transforms$move_position_data$$,$app$common$geom$shapes$transforms$transform_position_data$$,$app$common$geom$shapes$transforms$move$$,
$app$common$geom$shapes$transforms$absolute_move$$,$app$common$geom$shapes$transforms$transform_matrix$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$geom$shapes$transforms$inverse_transform_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$geom$shapes$transforms$inverse_transform_matrix$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$geom$shapes$transforms$transform_str$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$geom$shapes$transforms$transform_rect$$,$app$common$geom$shapes$transforms$calculate_selrect$$,
$app$common$geom$shapes$transforms$calculate_transform$$,$app$common$geom$shapes$transforms$calculate_geometry$$,$app$common$geom$shapes$transforms$update_group_viewbox$$,$app$common$geom$shapes$transforms$apply_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$geom$shapes$transforms$transform_bounds$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$geom$shapes$transforms$transform_bounds$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$geom$shapes$intersect$line_line_intersect$$,
$app$common$geom$shapes$points$pad_points$$,$app$common$geom$shapes$points$axis_aligned_QMARK_$$,$app$common$geom$shapes$points$merge_parent_coords_bounds$$,$app$common$geom$shapes$points$center$$,$app$common$geom$shapes$constraints$right_vector$$,$app$common$geom$shapes$constraints$left_vector$$,$app$common$geom$shapes$constraints$top_vector$$,$app$common$geom$shapes$constraints$bottom_vector$$,$app$common$geom$shapes$constraints$center_horizontal_vector$$,$app$common$geom$shapes$constraints$center_vertical_vector$$,
$app$common$geom$shapes$constraints$start_vector$$,$app$common$geom$shapes$constraints$end_vector$$,$app$common$geom$shapes$constraints$center_vector$$,$app$common$geom$shapes$constraints$displacement$$,$app$common$geom$shapes$constraints$side_vector$$,$app$common$geom$shapes$constraints$normalize_modifiers$$,$app$common$geom$shapes$bounds$shape_stroke_margin$$,$app$common$geom$shapes$bounds$apply_filters$$,$app$common$geom$shapes$bounds$shape__GT_filters$$,$app$common$geom$shapes$bounds$calculate_filter_bounds$$,
$app$common$geom$shapes$bounds$get_rect_filter_bounds$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$geom$shapes$bounds$get_rect_filter_bounds$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$common$geom$shapes$bounds$get_shape_filter_bounds$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$geom$shapes$bounds$calculate_padding$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$geom$shapes$bounds$calculate_base_bounds$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$geom$shapes$left_bound$$,$app$common$geom$shapes$top_bound$$,
$app$common$geom$shapes$fully_contained_QMARK_$$,$app$common$geom$shapes$close_attrs_QMARK_$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$common$geom$shapes$move$$,$app$common$geom$shapes$absolute_move$$,$app$common$geom$shapes$move_position_data$$,$app$main$data$helpers$process_selected$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$helpers$process_selected$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$helpers$get_selected_ids$$,$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$helpers$lookup_shape$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$helpers$lookup_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$helpers$lookup_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$helpers$update_page$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$helpers$update_page$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$helpers$update_page$cljs$0core$0IFn$0_invoke$0arity$04$$,
$app$main$data$helpers$filter_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$helpers$select_bool_children$$,$app$common$geom$proportions$setup_proportions_image$$,$app$common$geom$proportions$setup_proportions_size$$,$app$common$geom$proportions$setup_proportions$$,$app$common$types$shape$interactions$calc_overlay_position$$,$app$common$types$shape$interactions$remove_interaction$$,$app$common$types$shape$interactions$update_interaction$$,$app$common$types$shape$interactions$remap_interactions$$,
$app$common$types$shape$interactions$actionable_QMARK_$$,$app$common$types$token$schema_keys$$,$app$common$types$token$token_attr__GT_shape_attr$$,$app$common$types$token$unapply_layout_item_tokens$$,$app$common$types$token$valid_text_decoration$$,$app$common$types$token$valid_font_weight_variant$$,$app$common$path_names$split_group_name$$,$app$common$types$variant$next_property_number$$,$app$common$types$variant$add_new_prop$$,$app$common$types$variant$add_new_props$$,$app$common$types$variant$path_to_properties$cljs$0core$0IFn$0_invoke$0arity$03$$,
$app$common$types$variant$properties_map__GT_formula$$,$app$common$types$variant$properties_formula__GT_map$$,$app$common$types$variant$valid_properties_formula_QMARK_$$,$app$common$types$variant$find_properties_to_remove$$,$app$common$types$variant$find_properties_to_update$$,$app$common$types$variant$find_properties_to_add$$,$app$common$types$variant$split_base_name_and_number$$,$app$common$types$variant$group_numbers_by_base_name$$,$app$common$types$variant$update_number_in_repeated_item$$,$app$common$types$variant$update_number_in_repeated_prop_names$$,
$app$common$types$variant$find_index_for_property_name$$,$app$common$types$variant$matching_indices$$,$app$common$types$variant$find_index_by_name$$,$app$common$types$variant$merge_properties$$,$app$common$types$variant$distance$$,$app$common$types$variant$variant_name_to_name$$,$app$common$types$shape$Shape$$,$app$common$types$shape$map__GT_Shape$$,$app$common$types$shape$create_shape$$,$app$common$types$shape$is_allowed_switch_keep_attr_QMARK_$$,$app$common$types$shape$get_minimal_shape$$,$app$common$types$shape$make_minimal_shape$$,
$app$common$types$shape$setup_rect$$,$app$common$types$shape$extract_props$$,$app$common$types$shape$patch_props$$,$app$common$types$shape$set_fill_color$$,$app$common$types$shape$attach_fill_color$$,$app$common$types$shape$detach_fill_color$$,$app$common$types$shape$set_stroke_color$$,$app$common$types$shape$attach_stroke_color$$,$app$common$types$shape$detach_stroke_color$$,$app$common$types$shape$set_shadow_color$$,$app$common$types$shape$attach_shadow_color$$,$app$common$types$shape$detach_shadow_color$$,
$app$common$types$shape$set_grid_color$$,$app$common$types$shape$attach_grid_color$$,$app$common$types$shape$detach_grid_color$$,$app$common$types$shape$process_shape_colors$$,$app$common$types$shape$get_all_colors$$,$app$common$types$shape$uses_library_color_QMARK_$$,$app$common$types$shape$uses_library_colors_QMARK_$$,$app$common$types$page$make_empty_page$$,$app$common$types$component$resolve_sync_group$$,$app$common$types$component$subinstance_head_QMARK_$$,$app$common$types$component$instance_of_QMARK_$$,
$app$common$types$component$in_component_copy_not_head_QMARK_$$,$app$common$types$component$set_touched_group$$,$app$common$types$component$touched_group_QMARK_$$,$app$common$types$component$swap_slot_QMARK_$$,$app$common$types$component$normal_touched_groups$$,$app$common$types$component$set_swap_slot$$,$app$common$types$component$remove_swap_slot$$,$app$common$types$component$uses_library_components_QMARK_$$,$app$common$types$component$detach_shape$$,$app$common$types$component$unhead_shape$$,$app$common$types$component$rehead_shape$$,
$app$common$types$component$diff_components$$,$app$common$types$shape_tree$add_shape$$,$app$common$types$shape_tree$get_shape$$,$app$common$types$shape_tree$fix_broken_children$$,$app$common$types$shape_tree$get_root_objects$$,$app$common$types$shape_tree$is_shape_over_shape_QMARK_$$,$app$common$types$shape_tree$sort_z_index_objects$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$types$shape_tree$sort_z_index_objects$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$types$shape_tree$get_frame_by_position$cljs$0core$0IFn$0_invoke$0arity$03$$,
$app$common$types$shape_tree$get_frame_id_by_position$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$types$shape_tree$get_frame_id_by_position$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$types$shape_tree$start_page_index$$,$app$common$types$shape_tree$update_page_index$$,$clojure$core$protocols$datafy$$,$clojure$datafy$datify_ref$$,$app$common$types$tokens_lib$valid_QMARK_$$,$app$common$types$tokens_lib$Token$$,$app$common$types$tokens_lib$map__GT_Token$$,$app$common$types$tokens_lib$make_token$$,
$app$common$types$tokens_lib$add_token_$$,$app$common$types$tokens_lib$update_token_$$,$app$common$types$tokens_lib$delete_token_$$,$app$common$types$tokens_lib$get_token_$$,$app$common$types$tokens_lib$token_set_QMARK_$$,$app$common$types$tokens_lib$map__GT_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$types$tokens_lib$make_token_set$$,$app$common$types$tokens_lib$add_set_path_group_prefix$$,$app$common$types$tokens_lib$set_full_path__GT_set_prefixed_full_path$$,$app$common$types$tokens_lib$get_set_prefixed_path$$,
$app$common$types$tokens_lib$backtrace_tokens_tree$$,$app$common$types$tokens_lib$update_set$$,$app$common$types$tokens_lib$delete_set$$,$app$common$types$tokens_lib$move_set$$,$app$common$types$tokens_lib$move_set_group$$,$app$common$types$tokens_lib$rename_set_group$$,$app$common$types$tokens_lib$set_sets$$,$app$common$types$tokens_lib$hidden_theme_QMARK_$$,$app$common$types$tokens_lib$TokenTheme$$,$JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenTheme$update_set_name$arity$3$$,$app$common$types$tokens_lib$map__GT_TokenTheme$$,
$app$common$types$tokens_lib$top_level_theme_group_QMARK_$$,$app$common$types$tokens_lib$make_hidden_theme$$,$app$common$types$tokens_lib$join_theme_path$$,$app$common$types$tokens_lib$add_theme$$,$app$common$types$tokens_lib$update_theme$$,$app$common$types$tokens_lib$delete_theme$$,$app$common$types$tokens_lib$get_theme_tree$$,$app$common$types$tokens_lib$get_theme_by_name$$,$app$common$types$tokens_lib$get_theme_groups$$,$app$common$types$tokens_lib$get_active_theme_paths$$,$app$common$types$tokens_lib$set_active_themes$$,
$app$common$types$tokens_lib$toggle_theme_active$$,$app$common$types$tokens_lib$get_hidden_theme$$,$app$common$types$tokens_lib$add_token$$,$app$common$types$tokens_lib$update_token$$,$app$common$types$tokens_lib$delete_token$$,$app$common$types$tokens_lib$TokensLib$$,$JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenThemes$get_active_themes$arity$1$$,$app$common$types$tokens_lib$ensure_hidden_theme$$,$app$common$types$tokens_lib$map__GT_tokens_lib$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$app$common$types$tokens_lib$make_tokens_lib$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$types$tokens_lib$ensure_tokens_lib$$,$app$common$types$tokens_lib$token_name__GT_path_selector$$,$app$common$types$tokens_lib$read_multi_set_dtcg$$,$app$common$types$tokens_lib$typography_token__GT_dtcg_token$$,$app$common$types$tokens_lib$shadow_token__GT_dtcg_token$$,$app$main$store$measure_time_to_render$$,$app$main$store$async_emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$util$keyboard$keyboard_event_QMARK_$$,
$app$util$keyboard$key_up_event_QMARK_$$,$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$util$mouse$blur_event_QMARK_$$,$app$util$mouse$mouse_down_event_QMARK_$$,$app$util$mouse$mouse_up_event_QMARK_$$,$app$main$refs$workspace_page_object_by_id$$,$app$main$refs$children_objects$$,$app$main$refs$all_children_objects$$,$app$main$refs$workspace_modifiers_by_frame_id$$,$app$main$refs$select_bool_children$$,$app$main$refs$is_child_selected_QMARK_$$,$app$util$sse$read_stream$$,
$app$main$repo$with_retry$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$repo$send_BANG_$$,$app$common$i18n$c$$,$shadow$esm$dynamic_import$$,$shadow$esm$add_loadable$$,$app$util$i18n$parse_locale$$,$app$util$i18n$autodetect$$,$app$util$i18n$set_locale$$,$app$util$i18n$C$$,$app$util$i18n$c_QMARK_$$,$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$03$$,$reitit$impl$form_encode$$,$reitit$impl$query_parameter$$,$reitit$impl$query_string$$,$app$main$router$navigate$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$app$main$router$nav_back$$,$app$main$router$nav_back_local$$,$app$main$router$nav_root$$,$app$main$data$common$force_reload_BANG_$$,$app$main$data$common$hide_notifications_BANG_$$,$app$main$data$common$get_change_role_msg$$,$app$main$data$common$go_to_dashboard_search$$,$app$main$data$common$go_to_dashboard_search$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$common$go_to_dashboard_libraries$$,$app$main$data$common$go_to_dashboard_libraries$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$app$main$data$common$go_to_dashboard_fonts$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$common$go_to_dashboard_members$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$common$go_to_dashboard_invitations$$,$app$main$data$common$go_to_dashboard_invitations$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$common$go_to_dashboard_webhooks$$,$app$main$data$common$go_to_dashboard_webhooks$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$common$go_to_dashboard_settings$$,
$app$main$data$common$go_to_dashboard_settings$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$common$go_to_workspace$$,$app$main$data$common$go_to_viewer$$,$app$common$schema$desc_native$describe_STAR_$$,$app$common$types$components_list$components$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$types$components_list$touch$$,$app$common$types$components_list$mod_component$$,$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$types$components_list$update_component$$,
$app$common$types$components_list$update_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$types$components_list$mark_component_deleted$$,$app$common$types$components_list$mark_component_undeleted$$,$app$common$types$components_list$get_component_annotation$$,$app$common$types$pages_list$add_page$$,$app$common$types$pages_list$delete_page$$,$app$common$types$container$make_container$$,$app$common$types$container$get_direct_children$$,$app$common$types$container$get_children_in_instance$$,
$app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$types$container$get_head_shape$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$types$container$get_parent_heads$$,$app$common$types$container$get_parent_copy_heads$$,$app$common$types$container$get_nesting_level_delta$$,$app$common$types$container$remove_swap_keep_attrs$$,$app$common$types$container$get_component_from_shape$$,$app$common$types$container$invalid_structure_for_component_QMARK_$$,$app$common$types$container$parent_validation_cache$$,
$app$common$types$container$find_valid_parent_and_frame_ids$cljs$0core$0IFn$0_invoke$0arity$05$$,$app$common$types$container$find_valid_parent_and_frame_ids$cljs$0core$0IFn$0_invoke$0arity$06$$,$app$common$types$container$get_token_groups$$,$app$common$types$container$set_shape_attr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$features$check_paste_features_BANG_$$,$app$common$geom$shapes$tree_seq$get_reflow_root$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$geom$shapes$tree_seq$search_common_roots$$,
$app$common$geom$shapes$tree_seq$resolve_tree$$,$app$common$geom$shapes$tree_seq$resolve_subtree$$,$app$common$types$library$get_colors$$,$app$common$types$library$used_colors_changed_since$$,$app$common$types$library$sync_colors$$,$app$common$types$typographies_list$update_typography$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$types$typographies_list$used_typographies_changed_since$$,$app$common$types$typography$uses_library_typographies_QMARK_$$,$app$common$types$typography$uses_library_typography_QMARK_$$,
$app$common$types$typography$remove_typography_from_node$$,$app$common$types$typography$remove_external_typographies$$,$app$common$types$file$containers_seq$$,$app$common$types$file$find_component_file$$,$app$common$types$file$get_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$types$file$get_component_container_from_head$$,$app$common$types$file$get_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$types$file$find_ref_shape$$,$app$common$types$file$find_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$app$common$types$file$advance_shape_ref$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$types$file$find_ref_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$types$file$find_swap_slot$cljs$0core$0IFn$0_invoke$0arity$05$$,$app$common$types$file$match_swap_slot_QMARK_$$,$app$common$types$file$get_component_shapes$$,$app$common$types$file$is_main_of_known_component_QMARK_$$,$app$common$types$file$delete_component$$,$app$common$types$file$restore_component$$,$app$common$types$file$used_assets_changed_since$$,
$app$common$types$file$dump_shape_component_info$$,$app$common$types$file$dump_component$$,$app$common$types$file$dump_page$$,$app$common$types$file$dump_library$$,$app$common$types$file$dump_tree$$,$app$common$types$file$dump_subtree$$,$app$common$types$file$get_touched_from_ref_chain_until_target_ref$$,$app$common$files$changes$process_touched_change$$,$app$common$files$changes$collect_shape_media_refs$$,$app$common$files$changes$process_operations$$,$app$common$files$changes$process_children_reordering$$,
$app$common$files$changes$parents_frames$$,$app$common$files$focus$filter_not_focus$$,$app$main$data$render_wasm$context_lost$$,$app$main$data$render_wasm$context_restored$$,$app$main$fonts$register_BANG_$$,$app$main$fonts$add_font_css_BANG_$$,$app$main$fonts$generate_gfonts_url$$,$app$main$fonts$process_gfont_css$$,$app$main$fonts$fetch_gfont_css$$,$app$main$fonts$generate_custom_font_variant_css$$,$app$main$fonts$generate_custom_font_css$$,$app$main$fonts$find_closest_variant$$,$app$main$fonts$get_content_fonts$$,
$app$main$fonts$get_font_style_id$$,$app$main$fonts$get_font_styles_by_font_ref$$,$app$main$ui$formats$format_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$util$color$gradient__GT_css$$,$app$util$color$color__GT_background$$,$app$util$color$color__GT_format__GT_background$$,$app$main$ui$shapes$text$styles$generate_root_styles$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$ui$shapes$text$styles$generate_paragraph_set_styles$$,$app$main$ui$shapes$text$fo_text$render_text$$,$app$main$ui$shapes$text$fo_text$render_root$$,
$app$main$ui$shapes$text$fo_text$render_paragraph_set$$,$app$main$ui$shapes$text$fo_text$render_paragraph$$,$app$main$ui$shapes$text$fo_text$fill__GT_color$$,$app$main$ui$shapes$text$fo_text$retrieve_colors$$,$app$common$svg$camelize$$,$app$common$svg$prop_key$$,$app$common$svg$parse_style$$,$app$common$svg$format_styles$$,$app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$svg$update_attr_ids$$,$app$common$svg$replace_attrs_ids$$,
$app$common$svg$generate_id_mapping$$,$app$common$svg$find_def_references$$,$app$common$svg$svg_transform_matrix$$,$app$common$svg$to_matrix$$,$app$common$svg$parse_transform$$,$app$common$svg$format_line$$,$app$common$svg$points__GT_path$$,$app$common$svg$add_transform$$,$app$common$svg$inherit_attributes$$,$app$common$svg$fix_default_values$$,$app$common$svg$calculate_ratio$$,$app$common$svg$fix_percents$$,$app$common$svg$collect_images$$,$app$main$ui$shapes$attrs$calculate_dasharray$$,$app$main$ui$shapes$attrs$add_border_props_BANG_$$,
$app$main$ui$shapes$attrs$add_fill_BANG_$cljs$0core$0IFn$0_invoke$0arity$06$$,$app$main$ui$shapes$attrs$add_stroke_BANG_$$,$app$main$ui$shapes$attrs$get_svg_props$$,$app$main$ui$shapes$attrs$add_fill_props_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$ui$shapes$attrs$add_fill_props_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$main$broadcast$BroadcastMessage$$,$app$main$broadcast$map__GT_BroadcastMessage$$,$app$main$broadcast$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$shortcuts$a_mod$$,
$app$main$data$shortcuts$alt$$,$app$main$data$shortcuts$meta_shift$$,$app$main$data$shortcuts$enter$$,$app$main$data$shortcuts$wrap_cb$$,$app$main$data$shortcuts$bind_BANG_$$,$app$main$data$shortcuts$reset_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$util$dom$dnd$drop_side$$,$app$main$ui$hooks$use_render_id$$,$app$main$ui$hooks$cancel_timer$$,$app$main$ui$shapes$embed$use_data_uris$$,$app$main$ui$shapes$export$0$touched__GT_str$$,$app$main$ui$shapes$export$0$add_factory$$,$app$main$ui$shapes$export$0$add_data$$,
$app$main$ui$shapes$export$0$prefix_keys$$,$app$main$ui$shapes$export$0$export_grid_data$$,$app$main$ui$shapes$export$0$export_flows$$,$app$main$ui$shapes$export$0$export_guides$$,$app$main$ui$shapes$export$0$export_shadow_data$$,$app$main$ui$shapes$export$0$export_exports_data$$,$app$main$ui$shapes$export$0$str__GT_style$$,$app$main$ui$shapes$export$0$style__GT_str$$,$app$main$ui$shapes$export$0$export_svg_data$$,$app$main$ui$shapes$export$0$export_fills_data$$,$app$main$ui$shapes$export$0$export_strokes_data$$,
$app$main$ui$shapes$export$0$export_interactions_data$$,$app$main$ui$shapes$export$0$export_layout_container_data$$,$app$main$ui$shapes$export$0$export_data$$,$app$main$ui$shapes$gradients$add_metadata_BANG_$$,$app$main$ui$shapes$gradients$linear_gradient$$,$app$main$ui$shapes$gradients$radial_gradient$$,$app$main$ui$shapes$gradients$gradient$$,$app$main$ui$shapes$custom_stroke$inner_stroke_clip_path$$,$app$main$ui$shapes$custom_stroke$outer_stroke_mask$$,$app$main$ui$shapes$custom_stroke$cap_markers$$,
$app$main$ui$shapes$custom_stroke$stroke_defs$$,$app$main$ui$shapes$custom_stroke$outer_stroke$$,$app$main$ui$shapes$custom_stroke$inner_stroke$$,$app$main$ui$shapes$custom_stroke$shape_custom_stroke$$,$app$main$ui$shapes$custom_stroke$build_stroke_element$$,$app$main$ui$shapes$custom_stroke$shape_fills$$,$app$main$ui$shapes$custom_stroke$shape_strokes$$,$app$main$ui$shapes$custom_stroke$shape_custom_strokes$$,$app$main$ui$shapes$fills$internal_fills$$,$app$main$ui$shapes$fills$fills$$,$app$main$ui$shapes$text$svg_text$set_white_fill$$,
$app$main$ui$shapes$text$load_fonts_BANG_$$,$app$render_wasm$wasm$module_ready_QMARK_$$,$app$render_wasm$wasm$reset_context_state_BANG_$$,$app$render_wasm$api$fonts$google_font_id__GT_uuid$$,$app$render_wasm$api$fonts$font_backend$$,$app$render_wasm$api$fonts$font_db_data$$,$app$render_wasm$api$fonts$font_id__GT_uuid$$,$app$render_wasm$api$fonts$uuid__GT_font_id$$,$app$render_wasm$api$fonts$font_id__GT_asset_id$$,$app$render_wasm$api$fonts$update_text_layout$$,$app$render_wasm$api$fonts$fetch_font$$,
$app$render_wasm$api$fonts$font_stored_QMARK_$$,$app$render_wasm$api$fonts$serialize_font_style$$,$app$render_wasm$api$fonts$normalize_font_id$$,$app$render_wasm$api$fonts$normalize_span_font$$,$app$render_wasm$api$fonts$normalize_paragraph_font$$,$app$render_wasm$api$fonts$serialize_font_size$$,$app$render_wasm$api$fonts$serialize_font_weight$$,$app$render_wasm$api$fonts$serialize_line_height$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$render_wasm$api$fonts$serialize_line_height$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$render_wasm$api$fonts$serialize_letter_spacing$$,$app$render_wasm$api$fonts$make_font_data$$,$app$render_wasm$api$fonts$get_content_fonts$$,$app$render_wasm$api$fonts$store_fonts$$,$app$render_wasm$api$fonts$add_noto_fonts$$,$app$render_wasm$mem$__GT_offset_32$$,$app$render_wasm$mem$get_heap_f32$$,$app$render_wasm$mem$slice$$,$app$render_wasm$mem$write_u8$$,$app$render_wasm$mem$write_f32$$,$app$render_wasm$mem$write_i32$$,$app$render_wasm$mem$write_u32$$,$app$render_wasm$mem$write_uuid$$,$app$render_wasm$mem$assert_written$$,
$app$render_wasm$serializers$translate_shape_type$$,$app$render_wasm$serializers$translate_stroke_linecap$$,$app$render_wasm$serializers$translate_stroke_linejoin$$,$app$render_wasm$serializers$translate_fill_rule$$,$app$render_wasm$serializers$translate_stroke_style$$,$app$render_wasm$serializers$translate_stroke_cap$$,$app$render_wasm$serializers$translate_blend_mode$$,$app$render_wasm$serializers$translate_bool_type$$,$app$render_wasm$serializers$translate_layout_align_items$$,$app$render_wasm$serializers$translate_layout_align_content$$,
$app$render_wasm$serializers$translate_layout_justify_items$$,$app$render_wasm$serializers$translate_layout_justify_content$$,$app$render_wasm$serializers$translate_layout_sizing$$,$app$render_wasm$serializers$translate_align_self$$,$app$render_wasm$serializers$translate_text_transform$$,$app$render_wasm$serializers$translate_text_decoration$$,$app$render_wasm$serializers$translate_text_direction$$,$app$render_wasm$serializers$translate_font_style$$,$app$render_wasm$serializers$translate_browser$$,
$app$render_wasm$api$shapes$write_uuid_to_heap$$,$app$render_wasm$api$shapes$serialize_transform$$,$app$render_wasm$api$shapes$serialize_selrect$$,$app$render_wasm$api$shapes$set_shape_base_props$$,$app$render_wasm$api$texts$encode_text$$,$app$render_wasm$api$texts$write_span_fills$$,$app$render_wasm$api$texts$write_paragraph$$,$app$render_wasm$api$texts$write_spans$$,$app$render_wasm$api$texts$write_shape_text$$,$app$render_wasm$api$texts$contains_emoji_QMARK_$$,$app$render_wasm$api$texts$collect_used_languages$$,
$app$render_wasm$deserializers$read_selection_rect$$,$app$render_wasm$mem$heap32$write_u32$$,$app$render_wasm$mem$heap32$write_matrix$$,$app$render_wasm$svg_fills$trim_fill_value$$,$app$render_wasm$svg_fills$parse_length$$,$app$render_wasm$svg_fills$parse_offset$$,$app$render_wasm$svg_fills$parse_opacity$$,$app$render_wasm$svg_fills$shape__GT_selrect$$,$app$render_wasm$svg_fills$apply_svg_transform$$,$app$render_wasm$svg_fills$apply_viewbox_transform$$,$app$render_wasm$svg_fills$normalize_point$$,
$app$render_wasm$svg_fills$normalize_attrs$$,$app$render_wasm$svg_fills$id_candidates$$,$app$render_wasm$svg_fills$svg_def_by_id$$,$app$render_wasm$svg_fills$normalize_gradient_id$$,$app$render_wasm$svg_fills$attr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$render_wasm$svg_fills$resolve_gradient_node$$,$app$render_wasm$svg_fills$parse_gradient_stop$$,$app$render_wasm$svg_fills$apply_gradient_transform$$,$app$render_wasm$svg_fills$build_linear_gradient$$,$app$render_wasm$svg_fills$build_radial_gradient$$,
$app$render_wasm$svg_fills$svg_gradient__GT_fill$$,$app$render_wasm$svg_fills$parse_svg_fill$$,$app$render_wasm$svg_fills$svg_fill__GT_fills$$,$app$render_wasm$svg_filters$find_filter_element$$,$app$render_wasm$svg_filters$find_filter_def$$,$app$render_wasm$svg_filters$build_blur$$,$app$render_wasm$svg_filters$build_drop_shadow$$,$app$render_wasm$svg_filters$apply_svg_filters$$,$app$render_wasm$svg_filters$apply_svg_derived$$,$app$render_wasm$text_editor$rgba__GT_fill_color$$,$app$render_wasm$text_editor$rgba__GT_opacity$$,
$app$render_wasm$text_editor$read_fill_from_heap$$,$app$render_wasm$text_editor$text_editor_get_style_property$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$render_wasm$text_editor$text_editor_translate_text_align$$,$app$render_wasm$text_editor$text_editor_translate_text_direction$$,$app$render_wasm$text_editor$text_editor_translate_text_transform$$,$app$render_wasm$text_editor$text_editor_translate_text_decoration$$,$app$render_wasm$text_editor$text_editor_translate_font_style$$,$app$render_wasm$text_editor$text_editor_compute_font_variant_id$$,
$app$render_wasm$text_editor$text_editor_get_current_styles$$,$app$render_wasm$text_editor$text_editor_has_selection_QMARK_$$,$app$render_wasm$text_editor$normalize_selection$$,$app$render_wasm$text_editor$apply_attrs_to_paragraph$$,$app$render_wasm$text_editor$para_char_count$$,$app$render_wasm$text_editor$apply_styles_to_selection$$,$app$util$debug$handle_change$$,$app$util$text$content$styles$encode$$,$app$util$text$content$styles$decode$$,$app$util$text$content$styles$normalize_attr_value$$,$app$util$text$content$styles$attr__GT_style$$,
$app$util$text$content$styles$attrs__GT_styles$$,$app$util$text$content$styles$get_styles_from_style_declaration$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$util$text$content$from_dom$is_element$$,$app$util$text$content$from_dom$get_attrs_from_styles$$,$app$util$text$content$from_dom$create_text_span$$,$app$util$text$content$from_dom$create_paragraph$$,$app$util$text$content$v2_default_text_content$$,$app$render_wasm$api$end_context_loss_overlay_BANG_$$,$app$render_wasm$api$listen_tiles_render_complete_once_BANG_$$,
$app$render_wasm$api$start_canvas_snapshot_listener_BANG_$$,$app$render_wasm$api$yield_to_browser$$,$app$render_wasm$api$object_svg$$,$app$render_wasm$api$get_static_markup$$,$app$render_wasm$api$build_reload_payload$$,$app$render_wasm$api$render_sync_shape$$,$app$render_wasm$api$begin_shapes_loading_BANG_$$,$app$render_wasm$api$end_shapes_loading_BANG_$$,$app$render_wasm$api$apply_styles_to_selection$$,$app$render_wasm$api$set_parent_id$$,$app$render_wasm$api$set_shape_clip_content$$,$app$render_wasm$api$set_shape_type$$,
$app$render_wasm$api$set_masked$$,$app$render_wasm$api$set_shape_selrect$$,$app$render_wasm$api$set_shape_transform$$,$app$render_wasm$api$set_shape_rotation$$,$app$render_wasm$api$set_shape_children$$,$app$render_wasm$api$retrieve_image$$,$app$render_wasm$api$fetch_image$$,$app$render_wasm$api$get_fill_images$$,$app$render_wasm$api$set_shape_text_images$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$render_wasm$api$set_shape_fills$$,$app$render_wasm$api$set_shape_strokes$$,$app$render_wasm$api$set_shape_svg_attrs$$,
$app$render_wasm$api$set_shape_path_content$$,$app$render_wasm$api$set_shape_svg_raw_content$$,$app$render_wasm$api$set_shape_vertical_align$$,$app$render_wasm$api$set_shape_opacity$$,$app$render_wasm$api$set_constraints_h$$,$app$render_wasm$api$set_constraints_v$$,$app$render_wasm$api$set_shape_hidden$$,$app$render_wasm$api$set_shape_bool_type$$,$app$render_wasm$api$set_shape_blur$$,$app$render_wasm$api$set_shape_corners$$,$app$render_wasm$api$set_flex_layout$$,$app$render_wasm$api$set_grid_layout_data$$,
$app$render_wasm$api$set_grid_layout_rows$$,$app$render_wasm$api$set_grid_layout_columns$$,$app$render_wasm$api$set_grid_layout_cells$$,$app$render_wasm$api$set_grid_layout$$,$app$render_wasm$api$set_layout_data$$,$app$render_wasm$api$clear_layout$$,$app$render_wasm$api$set_shape_shadows$$,$app$render_wasm$api$set_shape_grow_type$$,$app$render_wasm$api$process_pending$$,$app$render_wasm$api$process_object$$,$app$render_wasm$api$process_shapes_chunk$$,$app$render_wasm$api$set_objects_async$$,$app$render_wasm$api$set_objects_sync$$,
$app$render_wasm$api$shapes_in_tree_order$$,$app$render_wasm$api$set_objects$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$render_wasm$api$set_objects$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$render_wasm$api$set_structure_modifiers$$,$app$render_wasm$api$propagate_modifiers$$,$app$render_wasm$api$get_selection_rect$$,$app$render_wasm$api$clean_modifiers$$,$app$render_wasm$api$set_modifiers_start$$,$app$render_wasm$api$set_modifiers$$,$app$render_wasm$api$run_resource_callbacks_BANG_$$,$app$render_wasm$api$derive_font_resources$$,
$app$render_wasm$api$replay_image_resources_BANG_$$,$app$render_wasm$api$wait_next_frame_BANG_$$,$app$render_wasm$api$set_canvas_size$$,$app$render_wasm$api$on_webgl_context_lost$$,$app$render_wasm$api$on_webgl_context_restored$$,$app$render_wasm$api$reload_renderer_BANG_$$,$app$render_wasm$api$calculate_bool_STAR_$$,$app$render_wasm$api$calculate_bool$$,$app$render_wasm$api$render_shape_pixels$$,$app$render_wasm$api$get_shape_extrect$$,$app$render_wasm$api$init_wasm_module$$,$app$render_wasm$shape$shape_in_current_page_QMARK_$$,
$app$render_wasm$shape$ShapeProxy$$,$app$render_wasm$shape$set_wasm_attr_BANG_$$,$app$render_wasm$shape$process_shape_BANG_$$,$app$render_wasm$shape$process_shape_changes_BANG_$$,$app$render_wasm$shape$impl_assoc$$,$app$render_wasm$shape$impl_dissoc$$,$app$render_wasm$shape$impl_conj$$,$app$render_wasm$shape$create_shape$$,$app$render_wasm$initialize$$,$app$main$features$setup_wasm_features$$,$app$util$worker$handle_response$$,$app$main$data$changes$fix_page_id$$,$app$main$data$changes$update_indexes$$,
$app$main$data$changes$get_pending_commits$$,$app$main$data$changes$redo_changes_need_wasm_object_sync_QMARK_$$,$app$main$data$changes$sync_wasm_structural_changes$$,$app$main$data$changes$apply_changes_localy$$,$app$main$data$changes$commit$$,$app$main$data$persistence$force_persist_QMARK_$$,$app$common$files$changes_builder$set_stack_undo_QMARK_$$,$app$common$files$changes_builder$set_translation_QMARK_$$,$app$common$files$changes_builder$amend_last_change$$,$app$common$files$changes_builder$amend_changes$$,
$app$common$files$changes_builder$lookup_objects$$,$app$common$files$changes_builder$apply_changes_local$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$files$changes_builder$mod_page$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$files$changes_builder$set_flow$$,$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$05$$,
$app$common$files$changes_builder$changed_attrs$$,$app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$files$changes_builder$add_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$files$changes_builder$restore_component$$,$app$common$files$changes_builder$set_token_theme$$,$app$common$files$changes_builder$set_active_token_themes$$,$app$common$files$changes_builder$set_text_content$$,
$app$plugins$register$get_plugin$$,$app$plugins$register$parse_manifest$$,$app$plugins$register$save_to_store$$,$app$plugins$register$remove_plugin_BANG_$$,$app$main$data$profile$on_fetch_profile_exception$$,$app$main$data$profile$fetch_profile$$,$app$main$data$profile$persist_profile$$,$app$main$data$profile$request_profile_recovery$$,$app$main$data$profile$access_tokens_fetched$$,$hasSvgItem$$module$app$util$clipboard$$,$parseText$$module$app$util$clipboard$$,$filterAllowedTypes$$module$app$util$clipboard$$,
$filterAllowedItems$$module$app$util$clipboard$$,$sortTypes$$module$app$util$clipboard$$,$sortItems$$module$app$util$clipboard$$,$fromDataTransfer$$module$app$util$clipboard$$,$app$main$data$team$teams_fetched$$,$app$main$data$team$members_fetched$$,$app$main$data$team$invitations_fetched$$,$app$main$data$team$update_member_role$$,$app$main$data$team$delete_member$$,$app$main$data$team$webhooks_fetched$$,$app$main$data$team$update_team$$,$app$main$data$team$team_leaved$$,$app$main$data$team$leave_current_team$$,
$app$main$data$team$copy_invitation_link$$,$app$main$data$team$update_invitation_role$$,$app$main$data$team$team_deleted$$,$app$main$data$team$delete_team$$,$app$main$data$team$delete_webhook$$,$app$main$data$team$update_webhook$$,$app$main$data$team$create_webhook$$,$app$main$data$team$shared_files_fetched$$,$goog$net$WebSocket$$,$goog$net$WebSocket$EXPONENTIAL_BACKOFF_$$,$goog$net$WebSocket$ClosedEvent$$,$goog$net$WebSocket$MessageEvent$$,$goog$net$WebSocket$ErrorEvent$$,$app$util$websocket$_stream$$,
$app$util$websocket$_send$$,$app$util$websocket$_close$$,$app$util$websocket$t_app$0util$0websocket54423$$,$app$util$websocket$create$$,$app$util$websocket$message_event_QMARK_$$,$app$util$websocket$opened_event_QMARK_$$,$app$main$data$websocket$prepare_uri$$,$app$main$data$websocket$send$$,$app$main$data$websocket$finalize$$,$app$main$data$auth$login_with_ldap$$,$app$main$data$auth$login_with_sso$$,$app$main$data$auth$logout$$,$app$main$errors$flash$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$errors$redirect_to_dashboard$$,
$app$main$errors$is_ignorable_exception_QMARK_$$,$app$main$errors$from_plugin_QMARK_$$,$app$common$schema$messages$translate_code$$,$app$common$schema$messages$handle_error_fn$$,$app$common$schema$messages$handle_error_code$$,$app$common$schema$messages$apply_validators$$,$app$plugins$flags$clear$$,$app$main$data$plugins$save_current_plugin$$,$app$main$data$plugins$remove_current_plugin$$,$app$main$data$plugins$start_plugin_BANG_$$,$app$main$data$plugins$load_plugin_BANG_$$,$app$main$data$plugins$close_plugin_BANG_$$,
$app$main$data$plugins$close_current_plugin$$,$app$main$data$plugins$close_current_plugin$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$plugins$check_open_plugin$$,$app$common$attrs$get_attr$$,$app$common$attrs$default_equal$$,$app$common$geom$align$align_to_parent$$,$app$common$geom$align$calc_align_pos$$,$app$common$geom$align$distribute_space$$,$app$main$data$comments$extract_mentions$$,$app$main$data$comments$created_thread_on_workspace$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$comments$update_comment_thread_status$$,
$app$main$data$comments$add_comment$$,$app$main$data$comments$update_comment$$,$app$main$data$comments$delete_comment_thread_on_viewer$$,$app$main$data$comments$delete_comment$$,$app$main$data$comments$refresh_comment_thread$$,$app$main$data$comments$comment_threads_fetched$$,$app$main$data$comments$retrieve_comments$$,$app$main$data$comments$retrieve_unread_comment_threads$$,$app$main$data$comments$mark_all_threads_as_read$$,$app$main$data$comments$update_filters$$,$app$main$data$comments$update_options$$,
$app$main$data$comments$update_draft_thread$$,$app$main$data$comments$toggle_comment_options$$,$app$main$data$comments$hide_comment_options$$,$app$main$data$comments$group_threads_by_page$$,$app$main$data$comments$group_threads_by_file_and_page$$,$app$main$data$comments$detach_comment_thread$$,$app$main$data$comments$fetch_profiles$$,$app$main$data$uploads$upload_blob_chunked$$,$app$main$data$project$project_fetched$$,$app$main$data$project$fetch_project$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$project$initialize_project$$,
$app$common$logic$variant_properties$generate_update_property_name$$,$app$common$logic$variant_properties$generate_remove_property$$,$app$common$logic$variant_properties$generate_update_property_value$$,$app$common$logic$variant_properties$generate_set_variant_error$$,$app$common$logic$variant_properties$generate_add_new_property$$,$app$common$logic$variant_properties$generate_add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$logic$variant_properties$generate_make_shape_no_variant$$,
$app$common$logic$variant_properties$generate_make_shapes_variant$$,$app$common$types$shape$token$font_weight_applied_QMARK_$$,$app$common$logic$shapes$generate_unapply_tokens$$,$app$common$logic$shapes$generate_update_shapes$$,$app$common$logic$shapes$generate_update_shape_flags$$,$app$common$logic$shapes$generate_delete_shapes$cljs$0core$0IFn$0_invoke$0arity$06$$,$app$common$logic$shapes$generate_delete_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$logic$shapes$generate_relocate$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$app$common$logic$libraries$enabled_container_QMARK_$$,$app$common$logic$libraries$pretty_file$$,$app$common$logic$libraries$duplicate_component$$,$app$common$logic$libraries$generate_instantiate_component$cljs$0core$0IFn$0_invoke$0arity$012$$,$app$common$logic$libraries$generate_detach_instance$$,$app$common$logic$libraries$generate_advance_nesting_level$$,$app$common$logic$libraries$generate_detach_immediate$$,$app$common$logic$libraries$generate_sync_file$$,$app$common$logic$libraries$generate_sync_library$$,
$app$common$logic$libraries$generate_sync_container$$,$app$common$logic$libraries$generate_sync_text_shape$$,$app$common$logic$libraries$find_main_container$$,$app$common$logic$libraries$add_shape_to_instance$$,$app$common$logic$libraries$update_tokens$$,$app$common$logic$libraries$generate_update_tokens$$,$app$common$logic$libraries$add_update_attr_changes$$,$app$common$logic$libraries$text_change_value$$,$app$common$logic$libraries$add_update_attr_operations$$,$app$common$logic$libraries$check_detached_main$$,
$app$common$logic$libraries$check_swapped_main$$,$app$common$logic$libraries$switch_path_change_value$$,$app$common$logic$libraries$switch_text_change_value$$,$app$common$logic$libraries$switch_fixed_layout_geom_change_value$$,$app$common$logic$libraries$equal_geometry_QMARK_$$,$app$common$logic$libraries$update_attrs_on_switch$$,$app$common$logic$libraries$update_flex_child_copy_attrs$$,$app$common$logic$libraries$update_grid_copy_attrs$$,$app$common$logic$libraries$generate_add_component_changes$$,
$app$common$logic$libraries$generate_add_component$$,$app$common$logic$libraries$generate_detach_component$$,$app$common$logic$libraries$generate_new_shape_for_swap$$,$app$common$logic$libraries$generate_component_swap$$,$app$common$logic$libraries$generate_sync_file_changes$$,$app$common$logic$libraries$generate_duplicate_flows$$,$app$common$logic$libraries$generate_duplicate_guides$$,$app$common$logic$libraries$duplicate_variant$$,$app$common$logic$libraries$generate_duplicate_component_change$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$app$common$logic$libraries$generate_duplicate_shape_change$cljs$0core$0IFn$0_invoke$0arity$019$$,$app$main$data$workspace$collapse$expand_all_parents$$,$app$main$data$workspace$collapse$toggle_collapse$$,$app$main$data$workspace$collapse$expand_collapse$$,$app$main$data$workspace$collapse$collapse_all$$,$app$main$data$workspace$collapse$expand_subtree$$,$app$main$data$workspace$path$state$get_path_location$$,$app$main$data$workspace$path$state$get_path_location$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$app$main$data$workspace$path$state$get_path$$,$app$main$data$workspace$path$common$clean_edit_state$$,$app$main$data$workspace$edition$interrupt_QMARK_$$,$app$main$data$workspace$undo$conj_undo_entry$$,$app$main$data$workspace$undo$materialize_undo$$,$app$main$data$workspace$undo$add_undo_entry$$,$app$main$data$workspace$undo$stack_undo_entry$$,$app$main$data$workspace$undo$accumulate_undo_entry$$,$app$main$data$workspace$undo$append_undo$$,$app$main$data$workspace$undo$start_undo_transaction$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$app$main$data$workspace$undo$add_transaction_undo_entry$$,$app$main$data$workspace$undo$check_open_transactions$$,$app$main$data$workspace$undo$restore_selection$$,$app$main$data$workspace$undo$assure_valid_current_page$$,$app$main$data$workspace$zoom$impl_update_zoom$$,$app$main$data$workspace$zoom$increase_zoom$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$zoom$decrease_zoom$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$main$data$workspace$selection$select_prev_shape$$,$app$main$data$workspace$selection$select_next_shape$$,$app$main$data$workspace$selection$shift_select_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$selection$clear_memorize_duplicated$$,$app$main$data$workspace$selection$memorize_duplicated$$,$app$main$data$workspace$selection$calc_duplicate_delta$$,$app$main$data$workspace$selection$duplicate_selected$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$selection$update_focus_shapes$$,
$app$common$files$shapes_helpers$prepare_move_shapes_into_frame$$,$app$main$data$workspace$shapes$add_undo_group$$,$app$main$data$workspace$shapes$update_shapes_buffer_start$$,$app$main$data$workspace$shapes$update_shapes_buffer_stop$$,$app$main$data$workspace$shapes$update_shapes_buffer_commit$$,$app$main$data$workspace$shapes$lookup_changed_objects$$,$app$main$data$workspace$shapes$update_shapes_buffer$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$shapes$add_shape$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$main$data$workspace$shapes$move_shapes_into_frame$$,$app$main$data$workspace$shapes$create_and_add_shape$cljs$0core$0IFn$0_invoke$0arity$05$$,$app$main$data$workspace$shapes$create_artboard_from_shapes$cljs$0core$0IFn$0_invoke$0arity$07$$,$app$main$data$workspace$shapes$create_artboard_from_selection$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$main$data$workspace$shapes$update_shape_flags$$,$app$main$data$workspace$shapes$toggle_visibility_selected$$,$app$main$data$workspace$shapes$toggle_lock_selected$$,
$app$main$data$workspace$shapes$relocate_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$workspace$bool$create_bool_shape$$,$app$common$geom$shapes$grid_layout$layout_data$child_min_width$$,$app$common$geom$shapes$grid_layout$layout_data$child_min_height$$,$app$common$geom$shapes$grid_layout$layout_data$layout_bounds$$,$app$common$geom$shapes$grid_layout$layout_data$calculate_initial_track_size$$,$app$common$geom$shapes$grid_layout$layout_data$set_auto_base_size$$,$app$common$geom$shapes$grid_layout$layout_data$tracks_total_size$$,
$app$common$geom$shapes$grid_layout$layout_data$tracks_total_frs$$,$app$common$geom$shapes$grid_layout$layout_data$tracks_total_autos$$,$app$common$geom$shapes$grid_layout$layout_data$set_fr_value$$,$app$common$geom$shapes$grid_layout$layout_data$stretch_tracks$$,$app$common$geom$shapes$grid_layout$layout_data$has_flex_track_QMARK_$$,$app$common$geom$shapes$grid_layout$layout_data$size_to_allocate$$,$app$common$geom$shapes$grid_layout$layout_data$allocate_auto_tracks$$,$app$common$geom$shapes$grid_layout$layout_data$allocate_flex_tracks$$,
$app$common$geom$shapes$grid_layout$layout_data$set_auto_multi_span$$,$app$common$geom$shapes$grid_layout$layout_data$set_flex_multi_span$$,$app$common$geom$shapes$grid_layout$layout_data$min_fr_value$$,$app$common$geom$shapes$grid_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$05$$,$app$common$geom$shapes$grid_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$06$$,$app$common$geom$shapes$grid_layout$params$rect__GT_range$$,$app$common$geom$shapes$grid_layout$params$size_range$$,
$app$common$geom$shapes$grid_layout$params$calculate_tracks$$,$app$common$geom$shapes$grid_layout$params$assign_shape_cells$$,$app$common$geom$shapes$grid_layout$params$calculate_params$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$geom$shapes$grid_layout$positions$calc_fill_width_data$$,$app$common$geom$shapes$grid_layout$positions$calc_fill_height_data$$,$app$common$geom$shapes$grid_layout$positions$fill_modifiers$$,$app$common$geom$shapes$grid_layout$positions$child_position_delta$$,$app$common$geom$shapes$grid_layout$positions$get_drop_cell$$,
$app$common$geom$shapes$grid_layout$get_cell_data$$,$app$common$files$shapes_builder$assert_valid_num$$,$app$common$files$shapes_builder$assert_valid_pos_num$$,$app$common$files$shapes_builder$assert_valid_blend_mode$$,$app$common$files$shapes_builder$svg_dimensions$$,$app$common$files$shapes_builder$process_gradient_stops$$,$app$common$files$shapes_builder$resolve_gradient_href$$,$app$common$files$shapes_builder$create_svg_root$$,$app$common$files$shapes_builder$stroke_only_svg_path_QMARK_$$,$app$common$files$shapes_builder$create_path_shape$$,
$app$common$files$shapes_builder$calculate_rect_metadata$$,$app$common$files$shapes_builder$parse_rect_attrs$$,$app$common$files$shapes_builder$setup_fill$$,$app$common$files$shapes_builder$setup_stroke$$,$app$common$files$shapes_builder$setup_opacity$$,$app$common$files$shapes_builder$setup_other$$,$app$common$files$shapes_builder$filter_valid_def_references$$,$app$common$files$shapes_builder$resolve_element_name$$,$app$main$data$workspace$svg_upload$extract_name$$,$tubax$core$push_node$$,$tubax$core$pop_node$$,
$tubax$core$push_text$$,$tubax$core$create_parser$$,$tubax$core$xml__GT_clj$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$media$image_uploaded$$,$app$main$data$workspace$media$svg_uploaded$$,$app$main$data$workspace$media$upload_blob_chunked$$,$app$main$data$workspace$media$process_uris$$,$app$main$data$workspace$layout$load_layout_flags$$,$app$main$data$workspace$layout$persist_layout_flags_BANG_$$,$app$main$data$workspace$layout$load_layout_state$$,$app$main$data$workspace$common$show_toolbar$$,
$app$common$logic$variants$add_unique_path$$,$app$common$logic$variants$keep_swapped_item$$,$app$common$logic$variants$child_of_swapped_QMARK_$$,$app$common$logic$variants$generate_keep_touched$$,$app$main$data$workspace$groups$shapes_for_grouping$$,$app$main$data$workspace$groups$get_empty_groups_after_group_creation$$,$app$main$data$workspace$groups$prepare_create_group$$,$app$main$data$workspace$groups$remove_group_changes$$,$app$main$data$workspace$groups$remove_frame_changes$$,$app$main$rasterizer$replace_uris$$,
$app$main$ui$shapes$filters$filter_str$$,$app$main$ui$shapes$filters$color_matrix$$,$app$main$ui$shapes$filters$drop_shadow_filter$$,$app$main$ui$shapes$filters$inner_shadow_filter$$,$app$main$ui$shapes$filters$background_blur_filter$$,$app$main$ui$shapes$filters$layer_blur_filter$$,$app$main$ui$shapes$filters$image_fix_filter$$,$app$main$ui$shapes$filters$blend_filters$$,$app$main$ui$shapes$filters$filter_entry$$,$app$main$ui$shapes$filters$change_filter_in$$,$app$main$ui$shapes$filters$filter_coords$$,
$app$main$ui$shapes$filters$filters$$,$app$main$ui$shapes$frame$frame_clip_id$$,$app$main$ui$shapes$frame$frame_clip_def$$,$app$main$ui$shapes$frame$frame_container$$,$app$main$ui$shapes$frame$frame_thumbnail_image$$,$app$main$ui$shapes$frame$frame_thumbnail$$,$app$main$ui$shapes$grid_layout_viewer$grid_cell_area_label$$,$app$main$ui$shapes$grid_layout_viewer$grid_cell$$,$app$main$ui$shapes$grid_layout_viewer$grid_layout_viewer$$,$app$main$ui$shapes$mask$point__GT_str$$,$app$main$ui$shapes$mask$mask_factory$$,
$app$main$ui$shapes$svg_defs$add_matrix$$,$app$main$ui$shapes$svg_defs$svg_defs$$,$app$main$ui$shapes$shape$propagate_wrapper_styles_child$$,$app$main$ui$shapes$shape$propagate_wrapper_styles$$,$app$main$ui$shapes$svg_raw$svg_root$$,$app$main$ui$shapes$svg_raw$svg_element$$,$app$main$ui$shapes$text$fontfaces$use_fonts_css$$,$app$main$ui$shapes$text$fontfaces$shape__GT_fonts$$,$app$util$thumbnails$get_proportional_size$cljs$0core$0IFn$0_invoke$0arity$06$$,$app$util$thumbnails$get_relative_size$$,$app$main$render$calculate_dimensions$$,
$app$main$render$bool_wrapper_factory$$,$app$main$render$svg_raw_wrapper_factory$$,$app$main$render$frame_imposter$$,$app$main$render$empty_grids$$,$app$main$render$render_to_canvas$$,$app$main$render$render_frame$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$util$queue$next_process_time$$,$app$util$queue$cancel_process_BANG_$$,$app$util$queue$process$$,$app$util$queue$request_process$$,$app$main$data$workspace$thumbnails$clear_queue_BANG_$$,$app$main$data$workspace$thumbnails$render_thumbnail$$,$app$main$data$workspace$thumbnails$request_thumbnail$$,
$app$main$data$workspace$thumbnails$clear_thumbnail$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$main$data$workspace$thumbnails$clear_thumbnail$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$thumbnails$assoc_thumbnail$$,$app$main$data$workspace$thumbnails$update_thumbnail$$,$app$main$data$workspace$thumbnails$extract_frame_changes$$,$app$main$data$workspace$thumbnails$watch_state_changes$$,$app$main$data$workspace$thumbnails_wasm$png_bytes__GT_data_uri$$,$app$main$data$workspace$thumbnails_wasm$render_component_pixels$$,
$app$main$data$workspace$thumbnails_wasm$render_thumbnail$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$workspace$thumbnails_wasm$persist_thumbnail$$,$app$common$geom$bounds_map$objects__GT_bounds_map$$,$app$common$geom$bounds_map$create_bounds$cljs$0core$0IFn$0_invoke$0arity$05$$,$app$common$geom$bounds_map$resolve_modif_tree_ids$$,$app$common$geom$bounds_map$transform_bounds_map$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$common$geom$modif_tree$add_modifiers$$,$app$common$geom$modif_tree$merge_modif_tree$$,
$app$common$geom$modif_tree$apply_structure_modifiers$$,$app$common$geom$shapes$flex_layout$bounds$child_min_width$$,$app$common$geom$shapes$flex_layout$bounds$child_min_height$$,$app$common$geom$shapes$flex_layout$bounds$child_layout_bound_points$cljs$0core$0IFn$0_invoke$0arity$07$$,$app$common$geom$shapes$flex_layout$positions$get_base_line$$,$app$common$geom$shapes$flex_layout$positions$get_child_position$$,$app$common$geom$shapes$flex_layout$layout_data$child_min_width$$,$app$common$geom$shapes$flex_layout$layout_data$child_min_height$$,
$app$common$geom$shapes$flex_layout$layout_data$layout_bounds$$,$app$common$geom$shapes$flex_layout$layout_data$init_layout_lines$$,$app$common$geom$shapes$flex_layout$layout_data$add_space_to_items$$,$app$common$geom$shapes$flex_layout$layout_data$distribute_space$$,$app$common$geom$shapes$flex_layout$layout_data$add_lines_positions$$,$app$common$geom$shapes$flex_layout$layout_data$add_line_spacing$$,$app$common$geom$shapes$flex_layout$layout_data$add_children_resizes$$,$app$common$geom$shapes$flex_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$05$$,
$app$common$geom$shapes$flex_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$06$$,$app$common$geom$shapes$flex_layout$drop_area$drop_line_area$$,$app$common$geom$shapes$flex_layout$drop_area$layout_drop_areas$$,$app$common$geom$shapes$flex_layout$drop_area$get_flip_modifiers$$,$app$common$geom$shapes$flex_layout$drop_area$get_drop_index$$,$app$common$geom$shapes$flex_layout$modifiers$calc_fill_width_data$$,$app$common$geom$shapes$flex_layout$modifiers$calc_fill_height_data$$,$app$common$geom$shapes$flex_layout$modifiers$fill_modifiers$$,
$app$common$geom$shapes$flex_layout$params$calculate_params$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$geom$shapes$pixel_precision$set_pixel_precision$$,$app$common$geom$shapes$pixel_precision$adjust_pixel_precision$$,$app$common$geom$modifiers$set_children_modifiers$$,$app$common$geom$modifiers$set_flex_layout_modifiers$$,$app$common$geom$modifiers$set_grid_layout_modifiers$$,$app$common$geom$modifiers$set_modifiers_constraints$$,$app$common$geom$modifiers$set_modifiers_layout$cljs$0core$0IFn$0_invoke$0arity$05$$,
$app$common$geom$modifiers$propagate_modifiers_constraints$cljs$0core$0IFn$0_invoke$0arity$05$$,$app$common$geom$modifiers$propagate_modifiers_layouts$cljs$0core$0IFn$0_invoke$0arity$05$$,$app$common$geom$modifiers$calc_auto_modifiers$$,$app$common$geom$modifiers$find_auto_layouts$$,$app$common$geom$modifiers$sizing_auto_modifiers$$,$app$common$geom$modifiers$filter_layouts_ids$$,$app$main$data$workspace$modifiers$check_delta$$,$app$main$data$workspace$modifiers$calculate_ignore_tree$$,$app$main$data$workspace$modifiers$calculate_ignore_tree_wasm$$,
$app$main$data$workspace$modifiers$set_wasm_props_BANG_$$,$app$main$data$workspace$modifiers$clear_local_transform$$,$app$main$data$workspace$modifiers$modifier_remove_from_parent$$,$app$main$data$workspace$modifiers$add_grid_children_modifiers$$,$app$main$data$workspace$modifiers$build_change_frame_modifiers$$,$app$main$data$workspace$modifiers$calculate_modifiers$cljs$0core$0IFn$0_invoke$0arity$06$$,$app$main$data$workspace$modifiers$parse_structure_modifiers$$,$app$main$data$workspace$modifiers$extract_property_changes$$,
$app$main$data$workspace$modifiers$set_temporary_selrect$$,$app$main$data$workspace$modifiers$set_temporary_modifiers$$,$app$main$data$workspace$modifiers$translate_selrect$$,$app$main$data$workspace$modifiers$cached_translation_selrect$$,$app$main$data$workspace$modifiers$propagate_structure_modifiers$$,$app$main$data$workspace$modifiers$set_delta_rotation_modifiers$$,$app$main$data$workspace$modifiers$apply_modifiers_STAR_$$,$$jscomp$scope$236007416$20$recToString$$,$$jscomp$scope$236007416$19$recHeight$$,
$$jscomp$scope$236007416$18$flipColors$$,$$jscomp$scope$236007416$15$moveRedLeft$$,$$jscomp$scope$236007416$14$balance$$,$$jscomp$scope$236007416$13$rotateRight$$,$$jscomp$scope$236007416$12$rotateLeft$$,$$jscomp$scope$236007416$11$recRangeQuery$$,$$jscomp$scope$236007416$10$recUpdate$$,$$jscomp$scope$236007416$9$recGet$$,$$jscomp$scope$236007416$8$recRemoveNode$$,$$jscomp$scope$236007416$7$recRemoveData$$,$$jscomp$scope$236007416$6$recRemoveMin$$,$$jscomp$scope$236007416$5$searchMin$$,$$jscomp$scope$236007416$4$recInsert$$,
$$jscomp$scope$236007416$3$isRed$$,$JSCompiler_StaticMethods_insert$$,$app$main$snap$calculate_distance$$,$app$main$snap$get_min_distance_snap$$,$app$main$snap$snap_accuracy_ranges$$,$app$main$snap$snap__GT_vector$$,$app$main$snap$closest_snap$$,$app$main$snap$sr_distance$$,$app$main$snap$calculate_snap$$,$app$main$snap$search_snap_distance$$,$app$main$snap$closest_distance_snap$$,$app$main$snap$closest_snap_move$$,$app$main$snap$query_delta_point$$,$app$main$snap$min_match$$,$app$main$snap$correct_snap_point$$,
$app$util$array$conj$$,$app$main$data$workspace$transforms$update_dimensions$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$transforms$update_dimensions$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$main$data$workspace$transforms$start_move_selected$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$transforms$start_move_duplicate$$,$app$main$data$workspace$transforms$set_ghost_displacement$$,$app$main$data$workspace$transforms$start_move$$,$app$main$data$workspace$transforms$start_move$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$main$data$workspace$transforms$start_move$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$transforms$reorder_selected_layout_child$$,$app$main$data$workspace$transforms$move_selected$$,$app$main$data$workspace$transforms$calculate_delta$$,$app$main$data$workspace$transforms$update_position$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$transforms$update_positions$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$transforms$position_shapes$$,$app$main$data$workspace$transforms$cleanup_invalid_moving_shapes$$,
$app$main$data$workspace$transforms$get_displacement$$,$app$main$data$workspace$transforms$flip_horizontal_selected$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$transforms$flip_vertical_selected$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$wasm_text$resize_wasm_text$$,$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_commit$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$main$features$pointer_map$resolve_file$$,$app$main$data$workspace$libraries$do_update_tipography$$,$app$main$data$workspace$libraries$rename_component_and_main_instance$$,$app$main$data$workspace$libraries$library_thumbnails_fetched$$,$app$main$data$workspace$libraries$fetch_library_thumbnails$$,$app$main$data$workspace$libraries$ext_library_changed$$,$app$main$data$workspace$libraries$render_component_thumbnail_event$$,$app$main$data$workspace$libraries$launch_component_sync$cljs$0core$0IFn$0_invoke$0arity$03$$,
$app$main$data$workspace$libraries$update_component_thumbnail$$,$app$main$data$workspace$libraries$find_shape_index$$,$app$main$data$workspace$libraries$notify_sync_file$$,$app$main$data$workspace$libraries$touch_component$$,$app$main$data$workspace$libraries$component_changed$$,$app$main$data$workspace$libraries$watch_component_changes$$,$app$main$data$workspace$libraries$libraries_fetched$$,$app$main$data$workspace$libraries$load_library_file$$,$app$common$text$encode_style$$,$app$common$text$convert_to_draft$$,
$app$common$text$content__GT_text_PLUS_styles$$,$app$common$text$index_content$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$text$index_content$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$util$text_editor$update_editor_current_inline_styles$$,$app$util$text_editor$update_editor_current_inline_styles_fn$$,$app$main$data$workspace$texts$v2_content_has_text_QMARK_$$,$app$main$data$workspace$texts$shape_current_values$$,$app$main$data$workspace$texts$v3_current_text_values$$,$app$main$data$workspace$texts$v2_current_text_values$$,
$app$main$data$workspace$texts$update_root_attrs$$,$app$main$data$workspace$texts$update_paragraph_attrs$$,$app$main$data$workspace$texts$migrate_node$$,$app$main$data$workspace$texts$font_loaded_event_QMARK_$$,$app$main$data$workspace$texts$add_geometry_undo_to_commit$$,$app$main$data$workspace$texts$build_finalize_commit_changes$$,$app$main$data$workspace$texts$v2_update_text_shape_content$$,$app$util$code_gen$markup_svg$generate_single_svg$$,$app$util$code_gen$common$shape__GT_selector$$,$app$util$code_gen$common$svg_markup_QMARK_$$,
$app$util$code_gen$common$has_wrapper_QMARK_$$,$app$util$code_gen$style_css_formats$format_color_value$$,$app$util$code_gen$style_css_formats$format_shadow__GT_css$$,$app$util$code_gen$style_css_formats$format_color$$,$app$util$code_gen$style_css_formats$format_color_array$$,$app$util$code_gen$style_css_formats$format_tracks$$,$app$util$code_gen$style_css_formats$format_shadow$$,$app$util$code_gen$style_css_formats$format_value$$,$app$util$code_gen$style_css_values$get_shape_position$$,$app$util$code_gen$style_css_values$get_shape_size$$,
$app$util$code_gen$style_css_values$get_stroke_data$$,$app$util$code_gen$style_css_values$area_cell_QMARK_$$,$app$util$code_gen$style_css_values$get_grid_coord$$,$app$util$code_gen$style_css_values$get_grid_template_areas$$,$app$util$code_gen$style_css_values$get_value$$,$app$util$code_gen$style_css$shape__GT_css_property$$,$app$util$code_gen$style_css$shape__GT_css_properties$$,$app$util$code_gen$style_css$format_css_property$$,$app$util$code_gen$style_css$format_css_properties$$,$app$util$code_gen$style_css$get_shape_properties_css$cljs$0core$0IFn$0_invoke$0arity$03$$,
$app$util$code_gen$style_css$get_shape_properties_css$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$util$code_gen$style_css$format_js_styles$$,$app$util$code_gen$style_css$generate_text_css$$,$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$main$data$workspace$clipboard$clipboard_permission_error_QMARK_$$,$app$main$data$workspace$clipboard$on_clipboard_permission_error$$,$app$main$data$workspace$clipboard$paste_from_clipboard$cljs$0core$0IFn$0_invoke$0arity$01$$,
$app$main$data$workspace$clipboard$selected_frame_QMARK_$$,$app$main$data$workspace$clipboard$get_tree_root_shapes$$,$app$main$data$workspace$clipboard$any_same_frame_from_selected_QMARK_$$,$app$main$data$workspace$clipboard$frame_same_size_QMARK_$$,$app$main$data$workspace$clipboard$paste_transit_shapes$$,$app$main$data$workspace$clipboard$paste_transit_props$$,$app$main$data$workspace$clipboard$paste_shapes$$,$app$main$data$workspace$clipboard$as_content$$,$app$main$data$workspace$clipboard$calculate_paste_position$$,
$app$main$data$workspace$clipboard$paste_html_text$$,$app$main$data$workspace$clipboard$paste_text$$,$app$main$data$workspace$clipboard$paste_svg_text$$,$app$main$data$workspace$clipboard$paste_image$$,$app$main$data$workspace$colors$split_text_shapes$$,$app$main$data$workspace$colors$update_shape_stroke_color$$,$app$main$data$workspace$colors$change_shadow$$,$app$main$data$workspace$colors$picker_for_selected_shape$$,$app$main$data$workspace$colors$color_att__GT_text$$,$app$main$data$workspace$colors$change_text_color$$,
$app$main$data$workspace$colors$stroke__GT_color_att$$,$app$main$data$workspace$colors$shadow__GT_color_attr$$,$app$main$data$workspace$colors$extract_text_colors$$,$app$main$data$workspace$colors$fill__GT_color_att$$,$app$main$data$workspace$drawing$common$handle_finish_drawing$$,$app$main$data$workspace$drawing$box$resize_shape$$,$app$main$data$workspace$drawing$box$move_drawing$$,$app$main$data$workspace$drawing$box$handle_drawing$$,$$jscomp$scope$m1503283874$3$simplifyDPStep$$,$app$main$data$workspace$drawing$curve$setup_frame$$,
$app$main$data$workspace$drawing$curve$insert_point$$,$app$main$data$workspace$drawing$curve$finish_drawing$$,$app$main$data$workspace$drawing$curve$handle_drawing$$,$app$main$data$workspace$path$changes$generate_path_changes$$,$app$main$data$workspace$path$helpers$append_node$$,$app$main$data$workspace$path$streams$dragging_QMARK_$$,$app$common$data$undo_stack$peek$$,$app$common$data$undo_stack$append$$,$app$common$data$undo_stack$undo$$,$app$main$data$workspace$path$undo$load_entry$$,$app$main$data$workspace$path$undo$undo_path$$,
$app$main$data$workspace$path$undo$redo_path$$,$app$main$data$workspace$path$undo$merge_head$$,$app$main$data$workspace$path$undo$add_undo_entry$$,$app$main$data$workspace$path$undo$end_path_undo$$,$app$main$data$workspace$path$undo$stop_undo_QMARK_$$,$app$main$data$workspace$path$undo$start_path_undo$$,$app$main$data$workspace$path$drawing$preview_next_point$$,$app$main$data$workspace$path$drawing$make_node_events_stream$$,$app$main$data$workspace$path$drawing$make_drag_stream$$,$app$main$data$workspace$path$drawing$start_edition$$,
$app$main$data$workspace$path$drawing$setup_frame$$,$app$main$data$workspace$path$drawing$handle_drawing_end$$,$app$main$data$workspace$path$drawing$handle_drawing$$,$app$main$data$workspace$path$drawing$start_draw_mode$$,$app$main$data$workspace$path$drawing$check_changed_content$$,$app$main$data$workspace$path$selection$update_selection$$,$app$main$data$workspace$path$edition$set_move_modifier$$,$app$main$data$workspace$path$edition$get_displacement$$,$app$main$data$workspace$path$edition$finish_move_selected$$,
$app$main$data$workspace$path$edition$start_path_edit$$,$app$main$data$workspace$path$edition$stop_path_edit$$,$app$main$data$workspace$path$tools$make_corner$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$path$tools$make_curve$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$drawing$handle_drawing$$,$app$main$data$workspace$comments$center_to_comment_thread$$,$app$main$data$workspace$comments$update_comment_thread_position$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$comments$move_frame_comment_threads$$,
$app$main$data$workspace$comments$overlap_bubbles_QMARK_$$,$app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles$$,$app$main$data$workspace$comments$navigate_to_comment_from_dashboard$$,$app$main$data$workspace$comments$navigate_to_comment$$,$app$main$data$workspace$comments$navigate_to_comment_id$$,$app$main$data$workspace$fix_deleted_fonts$calculate_alternative_font_id$$,$app$main$data$workspace$fix_deleted_fonts$has_invalid_font_family_QMARK_$$,$app$main$data$workspace$fix_deleted_fonts$fix_deleted_font$$,
$app$main$data$workspace$fix_deleted_fonts$generate_page_changes$$,$app$main$data$workspace$fix_deleted_fonts$generate_library_changes$$,$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_local_library$$,$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_page$$,$app$main$data$workspace$guides$remove_guides$$,$app$main$data$workspace$layers$calculate_opacity$$,$app$main$data$workspace$layers$set_opacity$$,$app$main$data$workspace$mcp$finalize_workspace_QMARK_$$,$app$main$data$workspace$mcp$set_mcp_active$$,
$app$main$data$workspace$mcp$start_reconnect_watcher_BANG_$$,$app$main$data$workspace$mcp$handle_pong$$,$app$main$data$workspace$mcp$handle_ping$$,$app$main$data$workspace$mcp$notify_other_tabs_disconnect$$,$app$main$data$workspace$mcp$update_mcp_status$$,$app$main$data$workspace$mcp$update_mcp_connection_status$$,$app$main$data$workspace$mcp$manage_mcp_notification$$,$app$main$data$workspace$mcp$init_mcp$$,$app$main$data$workspace$notifications$initialize$$,$app$main$data$workspace$notifications$handle_change_team_role$$,
$app$main$data$workspace$notifications$process_message$$,$app$main$data$workspace$notifications$handle_pointer_send$$,$app$main$data$workspace$notifications$handle_presence$$,$app$main$data$workspace$notifications$handle_pointer_update$$,$app$main$data$workspace$notifications$handle_file_change$$,$app$main$data$workspace$notifications$handle_file_deleted$$,$app$main$data$workspace$notifications$handle_file_restored$$,$app$main$data$workspace$notifications$handle_library_change$$,$app$main$data$workspace$pages$select_frame_tool$$,
$app$main$data$workspace$pages$initialize_page_STAR_$$,$app$main$data$workspace$pages$update_page_root$$,$app$main$data$workspace$path$shapes_to_path$make_stroke_paths$$,$app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$shape_layout$get_layout_initializer$$,$app$main$data$workspace$shape_layout$update_layout_positions$$,$app$main$data$workspace$shape_layout$initialize_shape_layout$$,$app$main$data$workspace$shape_layout$create_layout_from_id$$,
$app$main$data$workspace$shape_layout$create_layout_from_selection$$,$app$main$data$workspace$shape_layout$toggle_layout$$,$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$shape_layout$fix_child_sizing$$,$app$main$data$workspace$shape_layout$fix_parent_sizing$$,$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$variants$update_properties_names_and_values$$,$app$main$data$workspace$variants$remove_empty_properties$$,
$app$main$data$workspace$variants$set_variant_id$$,$app$main$data$workspace$variants$focus_property$$,$app$main$data$workspace$variants$resposition_and_resize_variant$$,$app$main$data$workspace$variants$transform_in_variant$cljs$0core$0IFn$0_invoke$0arity$07$$,$app$main$data$workspace$variants$add_component_or_variant$$,$app$main$data$workspace$variants$rename_variant$$,$app$main$data$workspace$variants$bounding_rect$$,$app$main$data$workspace$variants$common_prefix$$,$app$main$data$workspace$variants$variant_switch$$,
$app$main$data$workspace$viewport$calculate_centered_viewbox$$,$app$main$data$workspace$viewport$update_viewport_position_center$$,$app$main$data$workspace$datauri__GT_blob_uri$$,$app$main$data$workspace$get_file_object_thumbnails$$,$app$main$data$workspace$resolve_file$$,$app$main$data$workspace$check_libraries_synchronization$$,$app$main$data$workspace$library_resolved$$,$app$main$data$workspace$fetch_libraries$$,$app$main$data$workspace$workspace_initialized$$,$app$main$data$workspace$bundle_fetched$$,
$app$main$data$workspace$zoom_to_frame$$,$app$main$data$workspace$fetch_bundle$$,$app$main$data$workspace$initialize_file$$,$app$main$data$workspace$reload_current_file$$,$app$main$data$workspace$update_shape$$,$app$main$data$workspace$relocate_selected_shapes$$,$app$main$data$workspace$select_parent_layer$$,$app$main$data$workspace$align_objects_list$$,$app$main$data$workspace$toggle_proportion_lock$$,$app$main$data$workspace$toggle_distances_display$$,$app$main$data$workspace$find_orphan_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$main$data$workspace$fix_orphan_shapes$$,$app$main$data$workspace$find_components_norefs$$,$app$main$data$workspace$highlight_shape$$,$app$main$data$workspace$dehighlight_shape$$,$app$main$ui$ds$product$loader$get_tips$$,$app$main$ui$ds$product$loader$loader_icon_STAR_$$,$app$main$ui$hooks$resize$update_persistent_state$$,$app$main$ui$modal$on_pop_state$$,$app$main$ui$components$dropdown$dropdown_content_STAR_$$,$app$main$ui$components$select$as_key_value$$,$app$main$ui$components$select$rotate_index_forward$$,
$app$main$ui$components$select$rotate_index_backward$$,$app$main$ui$ds$layout$tab_switcher$tab_STAR_$$,$app$common$files$tokens$token_value_empty_fn$$,$app$common$files$tokens$remove_attributes_for_token$$,$app$common$files$tokens$token_applied_QMARK_$$,$app$main$data$tokenscript$structured_token__GT_penpot_map$$,$app$main$data$tokenscript$create_token_builder$$,$app$main$data$workspace$tokens$warnings$warning_with_value$$,$app$main$data$style_dictionary$parse_sd_token_color_value$$,$app$main$data$style_dictionary$with_units$$,
$app$main$data$style_dictionary$parse_sd_token_number_value$$,$app$main$data$style_dictionary$parse_sd_token_general_value$$,$app$main$data$style_dictionary$parse_sd_token_typography_line_height$$,$app$main$data$style_dictionary$parse_atomic_typography_value$$,$app$main$data$style_dictionary$parse_composite_typography_value$$,$app$main$data$style_dictionary$parse_sd_token_shadow_inset$$,$app$main$data$style_dictionary$parse_sd_token_shadow_blur$$,$app$main$data$style_dictionary$parse_sd_token_shadow_spread$$,
$app$main$data$style_dictionary$parse_single_shadow$$,$app$main$data$style_dictionary$parse_sd_token_shadow_value$$,$app$main$data$style_dictionary$process_sd_tokens$$,$app$main$data$style_dictionary$add_tokens$$,$app$main$data$style_dictionary$build_dictionary$$,$app$main$data$style_dictionary$resolve_tokens_tree$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$style_dictionary$merge_name_collisions$$,$app$main$data$style_dictionary$resolve_tokens$$,$app$main$data$style_dictionary$use_resolved_tokens_STAR_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$app$main$data$workspace$tokens$application$value__GT_shadow$$,$app$main$data$workspace$tokens$application$shape_ids_with_layout$$,$app$main$data$workspace$tokens$application$shape_ids_with_layout_parent$$,$app$main$data$workspace$tokens$application$generate_text_shape_update$$,$app$main$data$workspace$tokens$application$warn_font_variant_not_found_BANG_$$,$app$main$data$workspace$tokens$application$update_closest_font_variant_id_by_weight$$,$app$main$data$workspace$tokens$application$generate_font_family_text_shape_update$$,
$app$main$data$workspace$tokens$application$create_font_family_text_attrs$$,$app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update$$,$app$main$data$workspace$tokens$application$apply_functions_map$$,$app$main$data$workspace$tokens$application$update_shape_dimensions$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$main$data$workspace$tokens$application$attributes__GT_actions$$,$app$main$data$workspace$tokens$application$all_attrs_appliable_for_token_QMARK_$$,$app$common$logic$tokens$generate_toggle_token_set$$,
$app$common$logic$tokens$generate_toggle_token_theme$$,$clojure$data$atom_diff$$,$clojure$data$vectorize$$,$clojure$data$diff_associative_key$$,$clojure$data$diff_sequential$$,$clojure$data$diff_set$$,$clojure$data$equality_partition$$,$clojure$data$diff_similar$$,$clojure$data$diff$$,$app$main$data$workspace$tokens$propagation$invert_collect_key_vals$$,$app$main$data$workspace$tokens$propagation$split_attribute_groups$$,$app$main$data$workspace$tokens$propagation$shape_ids_by_values$$,$app$main$data$workspace$tokens$propagation$collect_shapes_update_info$$,
$app$main$data$workspace$tokens$propagation$actionize_shapes_update_info$$,$app$main$data$workspace$tokens$propagation$propagate_tokens$$,$app$main$data$workspace$tokens$library_edit$create_token_with_set$$,$app$main$ui$ds$tooltip$tooltip$has_descendant_tooltip_QMARK_$$,$app$main$ui$ds$tooltip$tooltip$clear_schedule$$,$app$main$ui$ds$tooltip$tooltip$add_schedule$$,$app$main$ui$ds$tooltip$tooltip$calculate_placement_bounding_rect$$,$app$main$ui$ds$tooltip$tooltip$get_fallback_order$$,$app$main$ui$ds$controls$utilities$hint_message$hint_message_STAR_$$,
$app$main$ui$ds$utilities$swatch$color_title$$,$goog$string$format$$,$app$main$ui$components$color_bullet$color_title$$,$app$main$data$exports$assets$toggle_detail_visibililty$$,$app$main$data$exports$assets$clear_export_state$$,$app$main$data$exports$assets$show_viewer_export_dialog$$,$app$main$data$exports$assets$initialize_export_status$$,$app$main$data$exports$assets$update_export_status$$,$app$main$data$exports$assets$request_multiple_export$$,$app$main$data$exports$assets$retry_last_export$$,
$app$main$ui$shapes$text$html_text$render_text$$,$app$main$ui$shapes$text$html_text$render_root$$,$app$main$ui$shapes$text$html_text$render_paragraph_set$$,$app$main$ui$shapes$text$html_text$render_paragraph$$,$app$util$code_gen$markup_html$generate_html$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$util$code_gen$markup_html$generate_markup$$,$app$main$data$preview$shapes__GT_fonts$$,$app$main$data$preview$update_preview$$,$app$main$data$preview$open_preview_selected$$,$app$main$data$workspace$text$shortcuts$is_bold_QMARK_$$,
$app$main$data$workspace$text$shortcuts$is_italic_QMARK_$$,$app$main$data$workspace$text$shortcuts$generate_variant_props$$,$app$main$data$workspace$text$shortcuts$calculate_text_values$$,$app$main$data$workspace$text$shortcuts$blend_props$$,$app$main$data$workspace$text$shortcuts$update_attrs_when_no_readonly$$,$app$main$data$workspace$shortcuts$toggle_layout_flag$$,$app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$ui$components$context_menu_a11y$generate_ids_group$$,
$app$main$ui$components$context_menu_a11y$context_menu_inner_STAR_$$,$app$main$ui$components$title_bar$inspect_title_bar_STAR_$$,$app$util$shape_icon$get_bool_icon$$,$app$main$data$dashboard$project_duplicated$$,$app$main$data$dashboard$duplicate_project$$,$app$main$data$dashboard$move_project$$,$app$main$data$dashboard$delete_project$$,$app$main$data$dashboard$create_element$$,$app$main$ui$ds$notifications$shared$notification_pill$icons_by_level$$,$app$main$ui$workspace$plugins$normalize_plugin_url$$,
$app$main$ui$workspace$plugins$icon_url$$,$app$main$ui$workspace$plugins$plugin_entry$$,$app$main$ui$workspace$plugins$plugin_management_dialog$$,$app$main$ui$workspace$plugins$plugins_permission_list_STAR_$$,$app$main$ui$workspace$plugins$plugins_permissions_dialog$$,$app$main$ui$workspace$plugins$plugins_permissions_updated_dialog$$,$app$main$ui$workspace$plugins$plugins_try_out_dialog$$,$app$main$ui$comments$parse_urls$$,$app$main$ui$comments$parse_comment$$,$app$main$ui$comments$parse_nodes$$,
$app$main$ui$comments$create_text_node$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$ui$comments$create_mention_node$$,$app$main$ui$comments$current_text_node_STAR_$$,$app$main$ui$comments$current_text_node$$,$app$main$ui$comments$absolute_offset$$,$app$main$ui$comments$get_prev_node$$,$app$main$ui$comments$blank_content_QMARK_$$,$app$main$ui$comments$comment_content_STAR_$$,$app$main$ui$comments$comment_input_STAR_$$,$app$main$ui$comments$mentions_panel_STAR_$$,$app$main$ui$comments$mentions_button_STAR_$$,
$app$main$ui$comments$comment_avatar_STAR_$$,$app$main$ui$comments$comment_info_STAR_$$,$app$main$ui$comments$comment_form_buttons_STAR_$$,$app$main$ui$comments$exceeds_length_QMARK_$$,$app$main$ui$comments$comment_reply_form_STAR_$$,$app$main$ui$comments$comment_edit_form_STAR_$$,$app$main$ui$comments$offset_position$$,$app$main$ui$comments$comment_floating_thread_header_STAR_$$,$app$main$ui$comments$comment_floating_thread_item_STAR_$$,$app$main$ui$comments$inside_vbox_QMARK_$$,$app$main$ui$comments$comment_sidebar_thread_item_STAR_$$,
$app$main$ui$comments$comment_sidebar_thread_group_STAR_$$,$app$main$ui$comments$comment_dashboard_thread_item_STAR_$$,$app$main$ui$comments$comment_dashboard_thread_group_STAR_$$,$app$main$ui$workspace$comments$sidebar_options$$,$app$main$ui$components$dropdown_menu$internal_dropdown_menu_STAR_$$,$app$main$data$nitrate$go_to_nitrate_cc_create_org$$,$app$main$data$nitrate$leave_org$$,$app$main$ui$dashboard$subscription$cta_power_up_STAR_$$,$app$main$ui$dashboard$subscription$subscription_sidebar_STAR_$$,
$app$main$ui$dashboard$subscription$nitrate_sidebar_STAR_$$,$app$main$ui$dashboard$subscription$nitrate_current_plan_STAR_$$,$app$main$ui$dashboard$subscription$menu_team_icon_STAR_$$,$app$main$ui$dashboard$subscription$dashboard_cta_STAR_$$,$app$main$ui$dashboard$subscription$show_subscription_dashboard_banner_QMARK_$$,$app$util$forms$use_rerender_fn$$,$app$util$forms$wrap_update_schema_fn$$,$app$util$forms$make_initial_state$$,$app$util$forms$t_app$0util$0forms73504$$,$app$util$forms$update_input_value_BANG_$$,
$app$main$ui$components$forms$conj_dedup$$,$app$main$ui$dashboard$change_owner$leave_and_reassign_modal$$,$app$main$ui$dashboard$change_owner$team_member_select_STAR_$$,$app$main$ui$dashboard$change_owner$make_leave_org_modal_form_schema$$,$app$main$ui$dashboard$team_form$on_create_success$$,$app$main$ui$dashboard$team_form$on_update_success$$,$app$main$ui$dashboard$team_form$on_error$$,$app$main$ui$dashboard$team_form$on_submit$$,$app$main$ui$dashboard$team_form$team_form_modal$$,$app$main$ui$ds$controls$shared$option$option_STAR_$$,
$app$main$ui$ds$controls$shared$token_option$token_option_STAR_$$,$app$main$ui$ds$controls$select$handle_selection$$,$app$main$ui$notifications$context_notification$get_icon_by_level$$,$app$main$ui$dashboard$team$invite_members_modal$$,$app$main$ui$dashboard$team$member_info$$,$app$main$ui$dashboard$team$rol_info_STAR_$$,$app$main$ui$dashboard$team$member_actions_STAR_$$,$app$main$ui$dashboard$team$set_role_BANG_$$,$app$main$ui$dashboard$team$invitation_role_selector_STAR_$$,$app$main$ui$dashboard$team$invitation_actions_STAR_$$,
$app$main$ui$dashboard$team$invitation_modal$$,$app$main$ui$dashboard$team$render_org_combobox_avatar_STAR_$$,$app$main$ui$dashboard$team$select_organization_modal$$,$app$main$ui$dashboard$team$webhook_modal$$,$app$main$ui$dashboard$team$webhook_actions_STAR_$$,$app$main$ui$workspace$shapes$debug$debug_bounding_boxes$$,$app$main$ui$workspace$shapes$debug$debug_text_bounds$$,$app$main$ui$workspace$shapes$debug$debug_bool_shape$$,$app$main$ui$workspace$shapes$debug$shape_debug$$,$app$main$ui$workspace$shapes$common$check_shape_props$$,
$app$main$ui$workspace$shapes$common$generic_wrapper_factory$$,$app$main$ui$workspace$viewport$utils$left_QMARK_$$,$app$main$ui$workspace$viewport$utils$top_QMARK_$$,$app$main$ui$workspace$viewport$utils$right_QMARK_$$,$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_shape_node$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_nodes$$,$app$main$ui$workspace$shapes$frame$dynamic_modifiers$transform_region_BANG_$$,$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$,
$app$main$ui$workspace$shapes$frame$dynamic_modifiers$override_transform_att_BANG_$$,$app$main$ui$workspace$shapes$frame$dynamic_modifiers$add_masking_child_QMARK_$$,$app$main$ui$workspace$shapes$frame$frame_shape_factory$$,$app$main$ui$workspace$shapes$frame$check_props$$,$app$main$ui$workspace$shapes$path$make_content_modifiers_ref$$,$app$main$ui$workspace$shapes$path$path_wrapper$$,$app$main$ui$workspace$shapes$text$text_wrapper$$,$app$main$ui$workspace$shapes$make_is_frame_overlap$$,$app$main$ui$exports$assets$export_multiple_dialog_STAR_$$,
$app$main$ui$exports$assets$shapes_no_selection$$,$app$main$ui$exports$assets$export_shapes_dialog$$,$app$main$ui$exports$assets$export_frames$$,$app$common$files$repair$repair_file$$,$app$common$files$validate$build_children_sets$$,$app$common$files$validate$find_ref_shape_STAR_$$,$app$common$files$validate$library_exists_QMARK_$$,$app$common$files$validate$report_error$$,$app$common$files$validate$report_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$files$validate$check_geometry$$,
$app$common$files$validate$check_parent_children$$,$app$common$files$validate$check_frame$$,$app$common$files$validate$check_component_main_head$$,$app$common$files$validate$check_component_not_main_head$$,$app$common$files$validate$check_component_not_main_not_head$$,$app$common$files$validate$check_component_root$$,$app$common$files$validate$check_component_not_root$$,$app$common$files$validate$check_component_ref$$,$app$common$files$validate$check_component_not_ref$$,$app$common$files$validate$check_ref_is_not_head$$,
$app$common$files$validate$check_ref_is_head$$,$app$common$files$validate$check_ref_component_id$$,$app$common$files$validate$check_empty_swap_slot$$,$app$common$files$validate$has_duplicate_swap_slot_QMARK_$$,$app$common$files$validate$check_duplicate_swap_slot$$,$app$common$files$validate$check_required_swap_slot$$,$app$common$files$validate$check_valid_touched$$,$app$common$files$validate$check_shape_main_root_top$$,$app$common$files$validate$check_shape_main_root_nested$$,$app$common$files$validate$check_shape_copy_root_top$$,
$app$common$files$validate$check_shape_copy_root_nested$$,$app$common$files$validate$check_shape_main_not_root$$,$app$common$files$validate$check_shape_copy_not_root$$,$app$common$files$validate$check_shape_not_component$$,$app$common$files$validate$check_variant_container$$,$app$common$files$validate$check_variant$$,$app$common$files$validate$check_shape$$,$app$common$files$validate$check_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$files$validate$check_ref_cycles$$,$app$common$files$validate$get_orphan_shapes$$,
$app$common$files$validate$validate_file$$,$app$main$data$viewer$set_interactions_mode$$,$app$main$data$viewer$flash_interactions$$,$app$main$data$viewer$set_nav_scroll$$,$app$main$data$viewer$open_overlay_STAR_$$,$app$main$data$viewer$close_overlay_STAR_$$,$app$main$data$viewer$open_overlay$$,$app$main$data$viewer$toggle_overlay$$,$app$main$data$viewer$select_all$$,$app$main$data$viewer$go_to_dashboard$$,$app$main$data$viewer$go_to_page$$,$app$main$data$viewer$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$01$$,
$app$main$data$viewer$shortcuts$get_tooltip$$,$app$main$data$workspace$path$shortcuts$esc_pressed$$,$debug$tap$$,$debug$wasm_read_len_prefixed_utf8$$,$debug$get_object$$,$debug$get_selected$$,$debug$dump_tree_SINGLEQUOTE_$cljs$0core$0IFn$0_invoke$0arity$04$$,$debug$apply_changes$$,$debug$modif__GT_js$$,$debug$set_shape_ref_STAR_$$,$app$main$ui$workspace$sidebar$layer_name$layer_name_STAR_$$,$app$main$ui$workspace$sidebar$layer_item$schedule_sidebar_hover_flush$$,$app$main$ui$components$copy_button$copy_button_STAR_$$,
$app$main$ui$inspect$annotation$annotation$$,$app$main$ui$inspect$attributes$blur$has_blur_QMARK_$$,$app$main$ui$inspect$attributes$blur$blur_css_property$$,$app$main$ui$inspect$attributes$blur$blur_panel$$,$app$main$ui$inspect$common$colors$make_colors_library_ref$$,$app$main$ui$inspect$common$colors$use_colors_library$$,$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$,$app$main$ui$inspect$attributes$common$color_row$$,$app$main$ui$inspect$attributes$fill$has_fill_QMARK_$$,$app$main$ui$inspect$attributes$fill$fill_block$$,
$app$main$ui$inspect$attributes$fill$fill_block_styles_STAR_$$,$app$main$ui$inspect$attributes$fill$fill_panel_STAR_$$,$app$main$ui$inspect$attributes$geometry$geometry_block$$,$app$main$ui$inspect$attributes$geometry$geometry_panel$$,$app$main$ui$inspect$attributes$layout$layout_block$$,$app$main$ui$inspect$attributes$layout$layout_panel$$,$app$main$ui$inspect$attributes$layout_element$layout_element_block$$,$app$main$ui$inspect$attributes$layout_element$layout_element_panel$$,$app$main$ui$inspect$attributes$shadow$has_shadow_QMARK_$$,
$app$main$ui$inspect$attributes$shadow$copy_color_data$$,$app$main$ui$inspect$attributes$shadow$shadow_block$$,$app$main$ui$inspect$attributes$shadow$shadow_panel$$,$app$main$ui$inspect$attributes$stroke$stroke__GT_color$$,$app$main$ui$inspect$attributes$stroke$has_stroke_QMARK_$$,$app$main$ui$inspect$attributes$stroke$stroke_block$$,$app$main$ui$inspect$attributes$stroke$stroke_block_styles_STAR_$$,$app$main$ui$inspect$attributes$stroke$stroke_panel_STAR_$$,$app$main$ui$inspect$attributes$svg$map__GT_css$$,
$app$main$ui$inspect$attributes$svg$svg_block$$,$app$main$ui$inspect$attributes$svg$svg_panel$$,$app$main$ui$inspect$common$typography$make_typographies_library_ref$$,$app$main$ui$inspect$common$typography$get_typography$$,$app$main$ui$inspect$attributes$text$has_text_QMARK_$$,$app$main$ui$inspect$attributes$text$copy_style_data$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$ui$inspect$attributes$text$typography_block$$,$app$main$ui$inspect$attributes$text$text_block$$,$app$main$ui$inspect$attributes$text$text_panel$$,
$app$main$ui$inspect$attributes$variant$variant_block_STAR_$$,$app$main$ui$inspect$attributes$variant$variant_panel_STAR_$$,$app$main$ui$inspect$attributes$visibility$has_visibility_props_QMARK_$$,$app$main$ui$inspect$attributes$visibility$visibility_block_STAR_$$,$app$main$ui$inspect$attributes$visibility$visibility_panel_STAR_$$,$app$main$ui$inspect$attributes$attributes_STAR_$$,$app$main$ui$inspect$code$get_viewer_objects$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$ui$inspect$code$use_objects$$,
$app$main$ui$inspect$code$shapes__GT_images$$,$app$main$ui$inspect$code$replace_map$$,$app$main$ui$inspect$code$code_STAR_$$,$app$main$ui$measurements$calculate_guides$$,$app$main$ui$measurements$calculate_distance_lines$$,$app$main$ui$measurements$distance_display_pill$$,$app$main$ui$measurements$selection_rect$$,$app$main$ui$measurements$selection_guides$$,$app$main$data$workspace$tokens$format$format_map_entries$$,$app$main$ui$inspect$styles$property_detail_copiable$property_detail_copiable_STAR_$$,
$app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,$app$main$ui$inspect$styles$panels$blur$blur_panel_STAR_$$,$app$main$ui$inspect$styles$rows$color_properties_row$color_properties_row_STAR_$$,$app$main$ui$inspect$styles$panels$fill$generate_fill_shorthand$$,$app$main$ui$inspect$styles$panels$fill$fill_panel_STAR_$$,$app$main$ui$inspect$styles$panels$geometry$has_border_radius_QMARK_$$,$app$main$ui$inspect$styles$panels$geometry$generate_geometry_shorthand$$,$app$main$ui$inspect$styles$panels$geometry$geometry_panel_STAR_$$,
$app$main$ui$inspect$styles$panels$layout$has_padding_QMARK_$$,$app$main$ui$inspect$styles$panels$layout$generate_layout_shorthand$$,$app$main$ui$inspect$styles$panels$layout$layout_panel_STAR_$$,$app$main$ui$inspect$styles$panels$layout_element$has_margin_QMARK_$$,$app$main$ui$inspect$styles$panels$layout_element$generate_layout_element_shorthand$$,$app$main$ui$inspect$styles$panels$layout_element$layout_element_panel_STAR_$$,$app$main$ui$inspect$styles$panels$shadow$get_resolved_token$$,$app$main$ui$inspect$styles$panels$shadow$generate_shadow_shorthand$$,
$app$main$ui$inspect$styles$panels$shadow$shadow_panel_STAR_$$,$app$main$ui$inspect$styles$panels$stroke$generate_stroke_shorthand$$,$app$main$ui$inspect$styles$panels$stroke$stroke_panel_STAR_$$,$app$main$ui$inspect$styles$panels$svg$map__GT_css$$,$app$main$ui$inspect$styles$panels$svg$svg_panel_STAR_$$,$app$main$ui$inspect$styles$panels$text$get_resolved_token$$,$app$main$ui$inspect$styles$panels$text$get_style_text$$,$app$main$ui$inspect$styles$panels$text$generate_typography_shorthand$$,$app$main$ui$inspect$styles$panels$text$typography_name_block_STAR_$$,
$app$main$ui$inspect$styles$panels$text$typography_color_row_STAR_$$,$app$main$ui$inspect$styles$panels$text$style_text_block_STAR_$$,$app$main$ui$inspect$styles$panels$text$text_panel_STAR_$$,$app$main$ui$inspect$styles$panels$tokens_panel$tokens_panel_STAR_$$,$app$main$ui$inspect$styles$panels$variants_panel$variants_panel_STAR_$$,$app$main$ui$inspect$styles$panels$visibility$visibility_panel_STAR_$$,$app$main$ui$inspect$styles$style_box$panel__GT_title$$,$app$main$ui$inspect$styles$style_box$style_box_STAR_$$,
$app$main$ui$inspect$styles$has_fill_QMARK_$$,$app$main$ui$inspect$styles$has_stroke_QMARK_$$,$app$main$ui$inspect$styles$has_blur_QMARK_$$,$app$main$ui$inspect$styles$has_text_QMARK_$$,$app$main$ui$inspect$styles$has_shadow_QMARK_$$,$app$main$ui$inspect$styles$get_shape_type$$,$app$main$ui$inspect$styles$styles_tab_STAR_$$,$app$main$ui$inspect$right_sidebar$get_libraries$$,$app$main$ui$dashboard$import$0$update_entry_name$$,$app$main$ui$dashboard$import$0$remove_entry$$,$app$main$ui$dashboard$import$0$update_with_analyze_result$$,
$app$main$ui$dashboard$import$0$update_entry_status$$,$app$main$ui$dashboard$import$0$parse_progress_message$$,$app$main$ui$dashboard$import$0$has_status_analyze_QMARK_$$,$app$main$ui$dashboard$import$0$has_status_import_success_QMARK_$$,$app$main$ui$dashboard$import$0$has_status_error_QMARK_$$,$app$main$ui$dashboard$import$0$has_status_ready_QMARK_$$,$app$main$ui$dashboard$import$0$analyze_entries$$,$app$main$ui$dashboard$import$0$import_files$$,$app$main$ui$dashboard$import$0$initialize_state$$,
$app$main$ui$dashboard$import$0$import_dialog$$,$app$main$ui$dashboard$comments$comments_icon_STAR_$$,$app$main$ui$dashboard$comments$comments_section$$,$app$main$ui$nitrate$nitrate_activation_success_modal$nitrate_activation_success_modal_STAR_$$,$app$main$ui$nitrate$nitrate_code_activation_modal$nitrate_code_activation_modal_STAR_$$,$app$main$ui$nitrate$nitrate_form$nitrate_form_modal_STAR_$$,$app$main$ui$dashboard$sidebar$sidebar_project_STAR_$$,$app$main$ui$dashboard$sidebar$sidebar_search_STAR_$$,
$app$main$ui$dashboard$sidebar$organizations_selector_dropdown_STAR_$$,$app$main$ui$dashboard$sidebar$teams_selector_dropdown_STAR_$$,$app$main$ui$dashboard$sidebar$team_options_dropdown_STAR_$$,$app$main$ui$dashboard$sidebar$org_options_dropdown_STAR_$$,$app$main$ui$dashboard$sidebar$sidebar_org_switch_STAR_$$,$app$main$ui$dashboard$sidebar$sidebar_team_switch_STAR_$$,$app$main$ui$dashboard$sidebar$sidebar_content_STAR_$$,$app$main$ui$dashboard$sidebar$help_learning_menu_STAR_$$,$app$main$ui$dashboard$sidebar$community_contributions_menu_STAR_$$,
$app$main$ui$dashboard$sidebar$about_penpot_menu_STAR_$$,$app$main$ui$components$button_link$button_link$$,$app$main$ui$auth$login$login_with_sso$$,$app$main$ui$auth$login$login_form_STAR_$$,$app$main$ui$auth$login$login_sso_buttons_STAR_$$,$app$main$ui$auth$recovery_request$recovery_form$$,$app$main$ui$viewer$shapes$ignore_frame_shape$$,$app$main$ui$viewer$shapes$activate_interaction$$,$app$main$ui$viewer$shapes$deactivate_interaction$$,$app$main$ui$viewer$shapes$on_pointer_down$$,$app$main$ui$viewer$shapes$on_pointer_up$$,
$app$main$ui$viewer$shapes$on_pointer_enter$$,$app$main$ui$viewer$shapes$on_pointer_leave$$,$app$main$ui$viewer$shapes$on_load$$,$app$main$ui$viewer$shapes$interaction$$,$app$main$ui$viewer$shapes$generic_wrapper_factory$$,$app$main$ui$viewer$shapes$frame_container_factory$$,$app$main$ui$viewer$shapes$group_container_factory$$,$app$main$ui$viewer$shapes$bool_container_factory$$,$app$main$ui$viewer$shapes$svg_raw_container_factory$$,$app$main$ui$viewer$shapes$shape_container_factory$$,$app$main$ui$viewer$interactions$get_fixed_ids$$,
$app$main$ui$viewer$interactions$interactions_menu_STAR_$$,$app$main$ui$viewer$header$open_login_dialog$$,$app$main$ui$viewer$header$header_options$$,$app$main$ui$viewer$header$header_sitemap$$,$$jscomp$defineProperty$$,$$jscomp$global$$,$goog$$,$goog$VALID_MODULE_RE_$$;$$jscomp$arrayIteratorImpl$$=function($array$jscomp$6$$){var $index$jscomp$101$$=0;return function(){return $index$jscomp$101$$<$array$jscomp$6$$.length?{done:!1,value:$array$jscomp$6$$[$index$jscomp$101$$++]}:{done:!0}}};
$$jscomp$getGlobal$$=function($passedInThis_possibleGlobals$$){$passedInThis_possibleGlobals$$=["object"==typeof globalThis&&globalThis,$passedInThis_possibleGlobals$$,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var $i$jscomp$3$$=0;$i$jscomp$3$$<$passedInThis_possibleGlobals$$.length;++$i$jscomp$3$$){var $maybeGlobal$$=$passedInThis_possibleGlobals$$[$i$jscomp$3$$];if($maybeGlobal$$&&$maybeGlobal$$.Math==Math)return $maybeGlobal$$}throw Error("Cannot find global object");
};
$$jscomp$polyfill$$=function($property$jscomp$inline_2275_split$jscomp$inline_2272_target$jscomp$94$$,$impl$jscomp$inline_2277_polyfill$jscomp$1$$){if($impl$jscomp$inline_2277_polyfill$jscomp$1$$)a:{var $obj$jscomp$inline_2271$$=$$jscomp$global$$;$property$jscomp$inline_2275_split$jscomp$inline_2272_target$jscomp$94$$=$property$jscomp$inline_2275_split$jscomp$inline_2272_target$jscomp$94$$.split(".");for(var $i$jscomp$inline_2273_orig$jscomp$inline_2276$$=0;$i$jscomp$inline_2273_orig$jscomp$inline_2276$$<$property$jscomp$inline_2275_split$jscomp$inline_2272_target$jscomp$94$$.length-
1;$i$jscomp$inline_2273_orig$jscomp$inline_2276$$++){var $key$jscomp$inline_2274$$=$property$jscomp$inline_2275_split$jscomp$inline_2272_target$jscomp$94$$[$i$jscomp$inline_2273_orig$jscomp$inline_2276$$];if(!($key$jscomp$inline_2274$$ in $obj$jscomp$inline_2271$$))break a;$obj$jscomp$inline_2271$$=$obj$jscomp$inline_2271$$[$key$jscomp$inline_2274$$]}$property$jscomp$inline_2275_split$jscomp$inline_2272_target$jscomp$94$$=$property$jscomp$inline_2275_split$jscomp$inline_2272_target$jscomp$94$$[$property$jscomp$inline_2275_split$jscomp$inline_2272_target$jscomp$94$$.length-
1];$i$jscomp$inline_2273_orig$jscomp$inline_2276$$=$obj$jscomp$inline_2271$$[$property$jscomp$inline_2275_split$jscomp$inline_2272_target$jscomp$94$$];$impl$jscomp$inline_2277_polyfill$jscomp$1$$=$impl$jscomp$inline_2277_polyfill$jscomp$1$$($i$jscomp$inline_2273_orig$jscomp$inline_2276$$);$impl$jscomp$inline_2277_polyfill$jscomp$1$$!=$i$jscomp$inline_2273_orig$jscomp$inline_2276$$&&$impl$jscomp$inline_2277_polyfill$jscomp$1$$!=null&&$$jscomp$defineProperty$$($obj$jscomp$inline_2271$$,$property$jscomp$inline_2275_split$jscomp$inline_2272_target$jscomp$94$$,
{configurable:!0,writable:!0,value:$impl$jscomp$inline_2277_polyfill$jscomp$1$$})}};$$jscomp$iteratorPrototype$$=function($iterator$jscomp$6_next$$){$iterator$jscomp$6_next$$={next:$iterator$jscomp$6_next$$};$iterator$jscomp$6_next$$[Symbol.iterator]=function(){return this};return $iterator$jscomp$6_next$$};
$goog$module$$=function($name$jscomp$82$$){if(typeof $name$jscomp$82$$!=="string"||!$name$jscomp$82$$||$name$jscomp$82$$.search($goog$VALID_MODULE_RE_$$)==-1)throw Error("Invalid module identifier");if(!$goog$moduleLoaderState_$$||$goog$moduleLoaderState_$$.type!="goog")throw Error("Module "+$name$jscomp$82$$+" has been loaded incorrectly. Note, modules cannot be loaded as normal scripts. They require some kind of pre-processing step. You're likely trying to load a module via a script tag or as a part of a concatenated bundle without rewriting the module. For more info see: https://github.com/google/closure-library/wiki/goog.module:-an-ES6-module-like-alternative-to-goog.provide.");
if($goog$moduleLoaderState_$$.$moduleName$)throw Error("goog.module may only be called once per module.");$goog$moduleLoaderState_$$.$moduleName$=$name$jscomp$82$$};$APP.$goog$typeOf$$=function($value$jscomp$102$$){var $s$jscomp$5$$=typeof $value$jscomp$102$$;return $s$jscomp$5$$!="object"?$s$jscomp$5$$:$value$jscomp$102$$?Array.isArray($value$jscomp$102$$)?"array":$s$jscomp$5$$:"null"};
$goog$isArrayLike$$=function($val$jscomp$7$$){var $type$jscomp$165$$=$APP.$goog$typeOf$$($val$jscomp$7$$);return $type$jscomp$165$$=="array"||$type$jscomp$165$$=="object"&&typeof $val$jscomp$7$$.length=="number"};$goog$isObject$$=function($val$jscomp$9$$){var $type$jscomp$166$$=typeof $val$jscomp$9$$;return $type$jscomp$166$$=="object"&&$val$jscomp$9$$!=null||$type$jscomp$166$$=="function"};
$goog$getUid$$=function($obj$jscomp$31$$){return Object.prototype.hasOwnProperty.call($obj$jscomp$31$$,$goog$UID_PROPERTY_$$)&&$obj$jscomp$31$$[$goog$UID_PROPERTY_$$]||($obj$jscomp$31$$[$goog$UID_PROPERTY_$$]=++$goog$uidCounter_$$)};$goog$bindNative_$$=function($fn$$,$selfObj$jscomp$2$$,$var_args$jscomp$35$$){return $fn$$.call.apply($fn$$.bind,arguments)};
$goog$bindJs_$$=function($fn$jscomp$1$$,$selfObj$jscomp$3$$,$var_args$jscomp$36$$){if(!$fn$jscomp$1$$)throw Error();if(arguments.length>2){var $boundArgs$$=Array.prototype.slice.call(arguments,2);return function(){var $newArgs$$=Array.prototype.slice.call(arguments);Array.prototype.unshift.apply($newArgs$$,$boundArgs$$);return $fn$jscomp$1$$.apply($selfObj$jscomp$3$$,$newArgs$$)}}return function(){return $fn$jscomp$1$$.apply($selfObj$jscomp$3$$,arguments)}};
$goog$bind$$=function($fn$jscomp$2$$,$selfObj$jscomp$4$$,$var_args$jscomp$37$$){$goog$bind$$=Function.prototype.bind&&Function.prototype.bind.toString().indexOf("native code")!=-1?$goog$bindNative_$$:$goog$bindJs_$$;return $goog$bind$$.apply(null,arguments)};
$APP.$goog$partial$$=function($fn$jscomp$3$$,$var_args$jscomp$38$$){var $args$jscomp$3$$=Array.prototype.slice.call(arguments,1);return function(){var $newArgs$jscomp$1$$=$args$jscomp$3$$.slice();$newArgs$jscomp$1$$.push.apply($newArgs$jscomp$1$$,arguments);return $fn$jscomp$3$$.apply(this,$newArgs$jscomp$1$$)}};$goog$globalEval$$=function($script$jscomp$1$$){(0,eval)($script$jscomp$1$$)};
$APP.$goog$exportSymbol$$=function($parts$jscomp$inline_2283_publicPath$$,$object$jscomp$2$$){$parts$jscomp$inline_2283_publicPath$$=$parts$jscomp$inline_2283_publicPath$$.split(".");var $cur$jscomp$inline_2284$$=$APP.$goog$global$$;$parts$jscomp$inline_2283_publicPath$$[0]in $cur$jscomp$inline_2284$$||typeof $cur$jscomp$inline_2284$$.execScript=="undefined"||$cur$jscomp$inline_2284$$.execScript("var "+$parts$jscomp$inline_2283_publicPath$$[0]);for(var $part$jscomp$inline_2285$$;$parts$jscomp$inline_2283_publicPath$$.length&&
($part$jscomp$inline_2285$$=$parts$jscomp$inline_2283_publicPath$$.shift());)$parts$jscomp$inline_2283_publicPath$$.length||$object$jscomp$2$$===void 0?$cur$jscomp$inline_2284$$=$cur$jscomp$inline_2284$$[$part$jscomp$inline_2285$$]&&$cur$jscomp$inline_2284$$[$part$jscomp$inline_2285$$]!==Object.prototype[$part$jscomp$inline_2285$$]?$cur$jscomp$inline_2284$$[$part$jscomp$inline_2285$$]:$cur$jscomp$inline_2284$$[$part$jscomp$inline_2285$$]={}:$cur$jscomp$inline_2284$$[$part$jscomp$inline_2285$$]=$object$jscomp$2$$};
$APP.$goog$inherits$$=function($childCtor$jscomp$1$$,$parentCtor$jscomp$1$$){function $tempCtor$$(){}$tempCtor$$.prototype=$parentCtor$jscomp$1$$.prototype;$childCtor$jscomp$1$$.$superClass_$=$parentCtor$jscomp$1$$.prototype;$childCtor$jscomp$1$$.prototype=new $tempCtor$$;$childCtor$jscomp$1$$.prototype.constructor=$childCtor$jscomp$1$$;$childCtor$jscomp$1$$.$base$=function($me$jscomp$1$$,$methodName$$,$var_args$jscomp$39$$){for(var $args$jscomp$4$$=Array(arguments.length-2),$i$jscomp$11$$=2;$i$jscomp$11$$<
arguments.length;$i$jscomp$11$$++)$args$jscomp$4$$[$i$jscomp$11$$-2]=arguments[$i$jscomp$11$$];return $parentCtor$jscomp$1$$.prototype[$methodName$$].apply($me$jscomp$1$$,$args$jscomp$4$$)}};$goog$identity_$$=function($s$jscomp$6$$){return $s$jscomp$6$$};
$module$contents$goog$debug$Error_DebugError$$=function($msg$jscomp$1$$,$cause$$){if(Error.captureStackTrace)Error.captureStackTrace(this,$module$contents$goog$debug$Error_DebugError$$);else{const $stack$$=Error().stack;$stack$$&&(this.stack=$stack$$)}$msg$jscomp$1$$&&(this.message=String($msg$jscomp$1$$));$cause$$!==void 0&&(this.cause=$cause$$)};$goog$reflect$sinkValue$$=function($x$jscomp$94$$){$goog$reflect$sinkValue$$[" "]($x$jscomp$94$$);return $x$jscomp$94$$};
$module$contents$goog$math$Long_Long$fromBits$$=function($lowBits$$,$highBits$$){return new $module$contents$goog$math$Long_Long$$($lowBits$$,$highBits$$)};
$module$contents$goog$math$Long_Long$fromNumber$$=function($value$jscomp$115$$){return $value$jscomp$115$$>0?$value$jscomp$115$$>=0x7fffffffffffffff?$module$contents$goog$math$Long_MAX_VALUE_$$:new $module$contents$goog$math$Long_Long$$($value$jscomp$115$$,$value$jscomp$115$$/4294967296):$value$jscomp$115$$<0?$value$jscomp$115$$<=-0x7fffffffffffffff?$module$contents$goog$math$Long_MIN_VALUE_$$:$JSCompiler_StaticMethods_negate$$(new $module$contents$goog$math$Long_Long$$(-$value$jscomp$115$$,-$value$jscomp$115$$/
4294967296)):$module$contents$goog$math$Long_ZERO_$$};
$module$contents$goog$math$Long_Long$fromString$$=function($str$jscomp$8$$,$opt_radix$jscomp$3_radix$jscomp$4$$){if($str$jscomp$8$$.charAt(0)=="-")return $JSCompiler_StaticMethods_negate$$($module$contents$goog$math$Long_Long$fromString$$($str$jscomp$8$$.substring(1),$opt_radix$jscomp$3_radix$jscomp$4$$));var $numberValue_radixToPower$jscomp$1$$=parseInt($str$jscomp$8$$,$opt_radix$jscomp$3_radix$jscomp$4$$||10);if($numberValue_radixToPower$jscomp$1$$<=9007199254740991)return new $module$contents$goog$math$Long_Long$$($numberValue_radixToPower$jscomp$1$$%
4294967296|0,$numberValue_radixToPower$jscomp$1$$/4294967296|0);if($str$jscomp$8$$.length==0)throw Error("number format error: empty string");if($str$jscomp$8$$.indexOf("-")>=0)throw Error('number format error: interior "-" character: '+$str$jscomp$8$$);$opt_radix$jscomp$3_radix$jscomp$4$$=$opt_radix$jscomp$3_radix$jscomp$4$$||10;if($opt_radix$jscomp$3_radix$jscomp$4$$<2||36<$opt_radix$jscomp$3_radix$jscomp$4$$)throw Error("radix out of range: "+$opt_radix$jscomp$3_radix$jscomp$4$$);$numberValue_radixToPower$jscomp$1$$=
$module$contents$goog$math$Long_Long$fromNumber$$(Math.pow($opt_radix$jscomp$3_radix$jscomp$4$$,8));for(var $result$jscomp$3$$=$module$contents$goog$math$Long_ZERO_$$,$i$jscomp$23$$=0;$i$jscomp$23$$<$str$jscomp$8$$.length;$i$jscomp$23$$+=8){var $power_size$jscomp$21$$=Math.min(8,$str$jscomp$8$$.length-$i$jscomp$23$$),$value$jscomp$116$$=parseInt($str$jscomp$8$$.substring($i$jscomp$23$$,$i$jscomp$23$$+$power_size$jscomp$21$$),$opt_radix$jscomp$3_radix$jscomp$4$$);$power_size$jscomp$21$$<8?($power_size$jscomp$21$$=
$module$contents$goog$math$Long_Long$fromNumber$$(Math.pow($opt_radix$jscomp$3_radix$jscomp$4$$,$power_size$jscomp$21$$)),$result$jscomp$3$$=$result$jscomp$3$$.multiply($power_size$jscomp$21$$).add($module$contents$goog$math$Long_Long$fromNumber$$($value$jscomp$116$$))):($result$jscomp$3$$=$result$jscomp$3$$.multiply($numberValue_radixToPower$jscomp$1$$),$result$jscomp$3$$=$result$jscomp$3$$.add($module$contents$goog$math$Long_Long$fromNumber$$($value$jscomp$116$$)))}return $result$jscomp$3$$};
$JSCompiler_StaticMethods_negate$$=function($JSCompiler_StaticMethods_negate$self$$){var $negLow$$=~$JSCompiler_StaticMethods_negate$self$$.$low_$+1|0;return $module$contents$goog$math$Long_Long$fromBits$$($negLow$$,~$JSCompiler_StaticMethods_negate$self$$.$high_$+!$negLow$$|0)};$JSCompiler_StaticMethods_toNumber$$=function($JSCompiler_StaticMethods_toNumber$self$$){return $JSCompiler_StaticMethods_toNumber$self$$.$high_$*4294967296+($JSCompiler_StaticMethods_toNumber$self$$.$low_$>>>0)};
$JSCompiler_StaticMethods_div$$=function($JSCompiler_StaticMethods_div$self_rem$$,$other$jscomp$21$$){if($other$jscomp$21$$.$isZero$())throw Error("division by zero");if($JSCompiler_StaticMethods_div$self_rem$$.$high_$<0){if($JSCompiler_StaticMethods_div$self_rem$$.equals($module$contents$goog$math$Long_MIN_VALUE_$$)){if($other$jscomp$21$$.equals($module$contents$goog$math$Long_ONE_$$)||$other$jscomp$21$$.equals($module$contents$goog$math$Long_NEG_ONE_$$))return $module$contents$goog$math$Long_MIN_VALUE_$$;
if($other$jscomp$21$$.equals($module$contents$goog$math$Long_MIN_VALUE_$$))return $module$contents$goog$math$Long_ONE_$$;var $approx$$=$JSCompiler_StaticMethods_div$$($JSCompiler_StaticMethods_shiftRight$$($JSCompiler_StaticMethods_div$self_rem$$,1),$other$jscomp$21$$).shiftLeft(1);if($approx$$.equals($module$contents$goog$math$Long_ZERO_$$))return $other$jscomp$21$$.$high_$<0?$module$contents$goog$math$Long_ONE_$$:$module$contents$goog$math$Long_NEG_ONE_$$;var $other$jscomp$inline_2289_res$$=$other$jscomp$21$$.multiply($approx$$);
$JSCompiler_StaticMethods_div$self_rem$$=$JSCompiler_StaticMethods_div$self_rem$$.add($JSCompiler_StaticMethods_negate$$($other$jscomp$inline_2289_res$$));return $approx$$.add($JSCompiler_StaticMethods_div$$($JSCompiler_StaticMethods_div$self_rem$$,$other$jscomp$21$$))}return $other$jscomp$21$$.$high_$<0?$JSCompiler_StaticMethods_div$$($JSCompiler_StaticMethods_negate$$($JSCompiler_StaticMethods_div$self_rem$$),$JSCompiler_StaticMethods_negate$$($other$jscomp$21$$)):$JSCompiler_StaticMethods_negate$$($JSCompiler_StaticMethods_div$$($JSCompiler_StaticMethods_negate$$($JSCompiler_StaticMethods_div$self_rem$$),
$other$jscomp$21$$))}if($JSCompiler_StaticMethods_div$self_rem$$.$isZero$())return $module$contents$goog$math$Long_ZERO_$$;if($other$jscomp$21$$.$high_$<0)return $other$jscomp$21$$.equals($module$contents$goog$math$Long_MIN_VALUE_$$)?$module$contents$goog$math$Long_ZERO_$$:$JSCompiler_StaticMethods_negate$$($JSCompiler_StaticMethods_div$$($JSCompiler_StaticMethods_div$self_rem$$,$JSCompiler_StaticMethods_negate$$($other$jscomp$21$$)));for($other$jscomp$inline_2289_res$$=$module$contents$goog$math$Long_ZERO_$$;$JSCompiler_StaticMethods_div$self_rem$$.compare($other$jscomp$21$$)>=
0;){$approx$$=Math.max(1,Math.floor($JSCompiler_StaticMethods_toNumber$$($JSCompiler_StaticMethods_div$self_rem$$)/$JSCompiler_StaticMethods_toNumber$$($other$jscomp$21$$)));var $delta$jscomp$3_log2$$=Math.ceil(Math.log($approx$$)/Math.LN2);$delta$jscomp$3_log2$$=$delta$jscomp$3_log2$$<=48?1:Math.pow(2,$delta$jscomp$3_log2$$-48);for(var $approxRes$$=$module$contents$goog$math$Long_Long$fromNumber$$($approx$$),$approxRem$$=$approxRes$$.multiply($other$jscomp$21$$);$approxRem$$.$high_$<0||$approxRem$$.compare($JSCompiler_StaticMethods_div$self_rem$$)>
0;)$approx$$-=$delta$jscomp$3_log2$$,$approxRes$$=$module$contents$goog$math$Long_Long$fromNumber$$($approx$$),$approxRem$$=$approxRes$$.multiply($other$jscomp$21$$);$approxRes$$.$isZero$()&&($approxRes$$=$module$contents$goog$math$Long_ONE_$$);$other$jscomp$inline_2289_res$$=$other$jscomp$inline_2289_res$$.add($approxRes$$);$JSCompiler_StaticMethods_div$self_rem$$=$JSCompiler_StaticMethods_div$self_rem$$.add($JSCompiler_StaticMethods_negate$$($approxRem$$))}return $other$jscomp$inline_2289_res$$};
$JSCompiler_StaticMethods_shiftRight$$=function($JSCompiler_StaticMethods_shiftRight$self$$,$numBits$jscomp$1$$){$numBits$jscomp$1$$&=63;if($numBits$jscomp$1$$==0)return $JSCompiler_StaticMethods_shiftRight$self$$;var $high$jscomp$2$$=$JSCompiler_StaticMethods_shiftRight$self$$.$high_$;return $numBits$jscomp$1$$<32?$module$contents$goog$math$Long_Long$fromBits$$($JSCompiler_StaticMethods_shiftRight$self$$.$low_$>>>$numBits$jscomp$1$$|$high$jscomp$2$$<<32-$numBits$jscomp$1$$,$high$jscomp$2$$>>$numBits$jscomp$1$$):
$module$contents$goog$math$Long_Long$fromBits$$($high$jscomp$2$$>>$numBits$jscomp$1$$-32,$high$jscomp$2$$>=0?0:-1)};
$JSCompiler_StaticMethods_shiftRightUnsigned$$=function($JSCompiler_StaticMethods_shiftRightUnsigned$self$$,$numBits$jscomp$2$$){$numBits$jscomp$2$$&=63;if($numBits$jscomp$2$$==0)return $JSCompiler_StaticMethods_shiftRightUnsigned$self$$;var $high$jscomp$3$$=$JSCompiler_StaticMethods_shiftRightUnsigned$self$$.$high_$;return $numBits$jscomp$2$$<32?$module$contents$goog$math$Long_Long$fromBits$$($JSCompiler_StaticMethods_shiftRightUnsigned$self$$.$low_$>>>$numBits$jscomp$2$$|$high$jscomp$3$$<<32-$numBits$jscomp$2$$,
$high$jscomp$3$$>>>$numBits$jscomp$2$$):$numBits$jscomp$2$$==32?$module$contents$goog$math$Long_Long$fromBits$$($high$jscomp$3$$,0):$module$contents$goog$math$Long_Long$fromBits$$($high$jscomp$3$$>>>$numBits$jscomp$2$$-32,0)};$goog$functions$UNDEFINED$$=function(){};$goog$functions$error$$=function($message$jscomp$41$$){return function(){throw Error($message$jscomp$41$$);}};
$goog$functions$sequence$$=function($var_args$jscomp$56$$){const $functions$jscomp$1$$=arguments,$length$jscomp$17$$=$functions$jscomp$1$$.length;return function(){let $result$jscomp$8$$;for(let $i$jscomp$40$$=0;$i$jscomp$40$$<$length$jscomp$17$$;$i$jscomp$40$$++)$result$jscomp$8$$=$functions$jscomp$1$$[$i$jscomp$40$$].apply(this,arguments);return $result$jscomp$8$$}};
$APP.$goog$functions$debounce$$=function($f$jscomp$5$$,$interval$$){let $timeout$jscomp$3$$=0;return function($var_args$jscomp$60$$){$APP.$goog$global$$.clearTimeout($timeout$jscomp$3$$);const $args$jscomp$7$$=arguments;$timeout$jscomp$3$$=$APP.$goog$global$$.setTimeout(function(){$f$jscomp$5$$.apply(void 0,$args$jscomp$7$$)},$interval$$)}};
$module$contents$goog$html$SafeScript_SafeScript$createSafeScriptSecurityPrivateDoNotAccessOrElse$$=function($noinlineScript_script$jscomp$8_trustedScript$$){if($goog$html$trustedtypes$cachedPolicy_$$===void 0){var $JSCompiler_inline_result$jscomp$10628_policy$jscomp$inline_14096$$=null;var $policyFactory$jscomp$inline_14097$$=$APP.$goog$global$$.trustedTypes;if($policyFactory$jscomp$inline_14097$$&&$policyFactory$jscomp$inline_14097$$.createPolicy)try{$JSCompiler_inline_result$jscomp$10628_policy$jscomp$inline_14096$$=
$policyFactory$jscomp$inline_14097$$.createPolicy("goog#html",{createHTML:$goog$identity_$$,createScript:$goog$identity_$$,createScriptURL:$goog$identity_$$})}catch($e$jscomp$inline_14098$$){$APP.$goog$global$$.console&&$APP.$goog$global$$.console.error($e$jscomp$inline_14098$$.message)}$goog$html$trustedtypes$cachedPolicy_$$=$JSCompiler_inline_result$jscomp$10628_policy$jscomp$inline_14096$$}$noinlineScript_script$jscomp$8_trustedScript$$=($JSCompiler_inline_result$jscomp$10628_policy$jscomp$inline_14096$$=
$goog$html$trustedtypes$cachedPolicy_$$)?$JSCompiler_inline_result$jscomp$10628_policy$jscomp$inline_14096$$.createScript($noinlineScript_script$jscomp$8_trustedScript$$):$noinlineScript_script$jscomp$8_trustedScript$$;return new $module$contents$goog$html$SafeScript_SafeScript$$($noinlineScript_script$jscomp$8_trustedScript$$,$module$contents$goog$html$SafeScript_CONSTRUCTOR_TOKEN_PRIVATE$$)};
$module$contents$goog$html$SafeScript_SafeScript$unwrapTrustedScript$$=function($safeScript$jscomp$1$$){if($safeScript$jscomp$1$$ instanceof $module$contents$goog$html$SafeScript_SafeScript$$&&$safeScript$jscomp$1$$.constructor===$module$contents$goog$html$SafeScript_SafeScript$$)return $safeScript$jscomp$1$$.$privateDoNotAccessOrElseSafeScriptWrappedValue_$;$APP.$goog$typeOf$$($safeScript$jscomp$1$$);return"type_error:SafeScript"};$goog$html$TrustedResourceUrl$unwrap$$=function($trustedResourceUrl$$){return $goog$html$TrustedResourceUrl$unwrapTrustedScriptURL$$($trustedResourceUrl$$).toString()};
$goog$html$TrustedResourceUrl$unwrapTrustedScriptURL$$=function($trustedResourceUrl$jscomp$1$$){if($trustedResourceUrl$jscomp$1$$ instanceof $goog$html$TrustedResourceUrl$$&&$trustedResourceUrl$jscomp$1$$.constructor===$goog$html$TrustedResourceUrl$$)return $trustedResourceUrl$jscomp$1$$.$privateDoNotAccessOrElseTrustedResourceUrlWrappedValue_$;$APP.$goog$typeOf$$($trustedResourceUrl$jscomp$1$$);return"type_error:TrustedResourceUrl"};
$APP.$goog$string$internal$startsWith$$=function($str$jscomp$11$$,$prefix$jscomp$3$$){return $str$jscomp$11$$.lastIndexOf($prefix$jscomp$3$$,0)==0};$APP.$goog$string$internal$endsWith$$=function($str$jscomp$12$$,$suffix$$){const $l$jscomp$1$$=$str$jscomp$12$$.length-$suffix$$.length;return $l$jscomp$1$$>=0&&$str$jscomp$12$$.indexOf($suffix$$,$l$jscomp$1$$)==$l$jscomp$1$$};$goog$string$internal$isEmptyOrWhitespace$$=function($str$jscomp$15$$){return/^[\s\xa0]*$/.test($str$jscomp$15$$)};
$goog$string$internal$compareVersions$$=function(){var $v1Subs_version1$$=$module$contents$goog$labs$userAgent$browser_getVersion$$();let $order$$=0;$v1Subs_version1$$=$goog$string$internal$trim$$(String($v1Subs_version1$$)).split(".");const $v2Subs$$=$goog$string$internal$trim$$("36").split("."),$subCount$$=Math.max($v1Subs_version1$$.length,$v2Subs$$.length);for(let $subIdx$$=0;$order$$==0&&$subIdx$$<$subCount$$;$subIdx$$++){var $v1Comp_v1Sub$$=$v1Subs_version1$$[$subIdx$$]||"",$v2Comp_v2Sub$$=
$v2Subs$$[$subIdx$$]||"";do{$v1Comp_v1Sub$$=/(\d*)(\D*)(.*)/.exec($v1Comp_v1Sub$$)||["","","",""];$v2Comp_v2Sub$$=/(\d*)(\D*)(.*)/.exec($v2Comp_v2Sub$$)||["","","",""];if($v1Comp_v1Sub$$[0].length==0&&$v2Comp_v2Sub$$[0].length==0)break;$order$$=$goog$string$internal$compareElements_$$($v1Comp_v1Sub$$[1].length==0?0:parseInt($v1Comp_v1Sub$$[1],10),$v2Comp_v2Sub$$[1].length==0?0:parseInt($v2Comp_v2Sub$$[1],10))||$goog$string$internal$compareElements_$$($v1Comp_v1Sub$$[2].length==0,$v2Comp_v2Sub$$[2].length==
0)||$goog$string$internal$compareElements_$$($v1Comp_v1Sub$$[2],$v2Comp_v2Sub$$[2]);$v1Comp_v1Sub$$=$v1Comp_v1Sub$$[3];$v2Comp_v2Sub$$=$v2Comp_v2Sub$$[3]}while($order$$==0)}return $order$$};$goog$string$internal$compareElements_$$=function($left$jscomp$2$$,$right$jscomp$2$$){return $left$jscomp$2$$<$right$jscomp$2$$?-1:$left$jscomp$2$$>$right$jscomp$2$$?1:0};
$module$contents$goog$object_forEach$$=function($obj$jscomp$38$$,$f$jscomp$8$$,$opt_obj$jscomp$1$$){for(const $key$jscomp$52$$ in $obj$jscomp$38$$)$f$jscomp$8$$.call($opt_obj$jscomp$1$$,$obj$jscomp$38$$[$key$jscomp$52$$],$key$jscomp$52$$,$obj$jscomp$38$$)};$module$contents$goog$object_getValues$$=function($obj$jscomp$47$$){const $res$jscomp$5$$=[];let $i$jscomp$49$$=0;for(const $key$jscomp$60$$ in $obj$jscomp$47$$)$res$jscomp$5$$[$i$jscomp$49$$++]=$obj$jscomp$47$$[$key$jscomp$60$$];return $res$jscomp$5$$};
$module$contents$goog$object_getKeys$$=function($obj$jscomp$48$$){const $res$jscomp$6$$=[];let $i$jscomp$50$$=0;for(const $key$jscomp$61$$ in $obj$jscomp$48$$)$res$jscomp$6$$[$i$jscomp$50$$++]=$key$jscomp$61$$;return $res$jscomp$6$$};
$module$contents$goog$object_getValueByKeys$$=function($obj$jscomp$49$$,$var_args$jscomp$65$$){var $i$jscomp$51_isArrayLike$$=$goog$isArrayLike$$($var_args$jscomp$65$$);const $keys$$=$i$jscomp$51_isArrayLike$$?$var_args$jscomp$65$$:arguments;for($i$jscomp$51_isArrayLike$$=$i$jscomp$51_isArrayLike$$?0:1;$i$jscomp$51_isArrayLike$$<$keys$$.length;$i$jscomp$51_isArrayLike$$++){if($obj$jscomp$49$$==null)return;$obj$jscomp$49$$=$obj$jscomp$49$$[$keys$$[$i$jscomp$51_isArrayLike$$]]}return $obj$jscomp$49$$};
$APP.$module$contents$goog$object_get$$=function($obj$jscomp$58$$,$key$jscomp$69$$,$val$jscomp$24$$){return $obj$jscomp$58$$!==null&&$key$jscomp$69$$ in $obj$jscomp$58$$?$obj$jscomp$58$$[$key$jscomp$69$$]:$val$jscomp$24$$};$module$contents$goog$object_clone$$=function($obj$jscomp$62$$){const $res$jscomp$7$$={};for(const $key$jscomp$73$$ in $obj$jscomp$62$$)$res$jscomp$7$$[$key$jscomp$73$$]=$obj$jscomp$62$$[$key$jscomp$73$$];return $res$jscomp$7$$};
$module$contents$goog$object_extend$$=function($target$jscomp$101$$,$var_args$jscomp$66$$){let $key$jscomp$76$$,$source$jscomp$18$$;for(let $i$jscomp$53$$=1;$i$jscomp$53$$<arguments.length;$i$jscomp$53$$++){$source$jscomp$18$$=arguments[$i$jscomp$53$$];for($key$jscomp$76$$ in $source$jscomp$18$$)$target$jscomp$101$$[$key$jscomp$76$$]=$source$jscomp$18$$[$key$jscomp$76$$];for(let $j$jscomp$1$$=0;$j$jscomp$1$$<$module$contents$goog$object_PROTOTYPE_FIELDS$$.length;$j$jscomp$1$$++)$key$jscomp$76$$=$module$contents$goog$object_PROTOTYPE_FIELDS$$[$j$jscomp$1$$],
Object.prototype.hasOwnProperty.call($source$jscomp$18$$,$key$jscomp$76$$)&&($target$jscomp$101$$[$key$jscomp$76$$]=$source$jscomp$18$$[$key$jscomp$76$$])}};
$module$contents$goog$object_createSet$$=function($var_args$jscomp$68$$){const $argLength$jscomp$1$$=arguments.length;if($argLength$jscomp$1$$==1&&Array.isArray(arguments[0]))return $module$contents$goog$object_createSet$$.apply(null,arguments[0]);const $rv$jscomp$3$$={};for(let $i$jscomp$55$$=0;$i$jscomp$55$$<$argLength$jscomp$1$$;$i$jscomp$55$$++)$rv$jscomp$3$$[arguments[$i$jscomp$55$$]]=!0;return $rv$jscomp$3$$};
$module$contents$goog$labs$userAgent$util_getNativeUserAgentString$$=function(){var $navigator$jscomp$1_userAgent$jscomp$1$$=$APP.$goog$global$$.navigator;return $navigator$jscomp$1_userAgent$jscomp$1$$&&($navigator$jscomp$1_userAgent$jscomp$1$$=$navigator$jscomp$1_userAgent$jscomp$1$$.userAgent)?$navigator$jscomp$1_userAgent$jscomp$1$$:""};
$module$contents$goog$labs$userAgent$util_matchUserAgent$$=function($str$jscomp$25$$){return $module$contents$goog$labs$userAgent$util_getNativeUserAgentString$$().indexOf($str$jscomp$25$$)!=-1};$module$contents$goog$labs$userAgent$browser_matchIE$$=function(){return $module$contents$goog$labs$userAgent$util_matchUserAgent$$("Trident")||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("MSIE")};
$module$contents$goog$labs$userAgent$browser_matchFirefox$$=function(){return $module$contents$goog$labs$userAgent$util_matchUserAgent$$("Firefox")||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("FxiOS")};
$module$contents$goog$labs$userAgent$browser_matchChrome$$=function(){return($module$contents$goog$labs$userAgent$util_matchUserAgent$$("Chrome")||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("CriOS"))&&!$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Edge")||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Silk")};
$module$contents$goog$labs$userAgent$browser_createVersionMap$$=function($versionTuples$$){const $versionMap$$={};$versionTuples$$.forEach($tuple$$=>{$versionMap$$[$tuple$$[0]]=$tuple$$[1]});return $keys$jscomp$1$$=>$versionMap$$[$keys$jscomp$1$$.find($key$jscomp$79$$=>$key$jscomp$79$$ in $versionMap$$)]||""};
$module$contents$goog$labs$userAgent$browser_getVersion$$=function(){var $JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$=$module$contents$goog$labs$userAgent$util_getNativeUserAgentString$$();if($module$contents$goog$labs$userAgent$browser_matchIE$$()){var $data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$=/rv: *([\d\.]*)/.exec($JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$);
if($data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$&&$data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$[1])$JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$=$data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$[1];else{$data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$="";var $msie$jscomp$inline_2299_versionRegExp$jscomp$inline_2303$$=
/MSIE +([\d\.]+)/.exec($JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$);if($msie$jscomp$inline_2299_versionRegExp$jscomp$inline_2303$$&&$msie$jscomp$inline_2299_versionRegExp$jscomp$inline_2303$$[1])if($JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$=/Trident\/(\d.\d)/.exec($JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$),
$msie$jscomp$inline_2299_versionRegExp$jscomp$inline_2303$$[1]=="7.0")if($JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$&&$JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$[1])switch($JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$[1]){case "4.0":$data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$=
"8.0";break;case "5.0":$data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$="9.0";break;case "6.0":$data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$="10.0";break;case "7.0":$data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$="11.0"}else $data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$="7.0";else $data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$=$msie$jscomp$inline_2299_versionRegExp$jscomp$inline_2303$$[1];
$JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$=$data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$}return $JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$}$msie$jscomp$inline_2299_versionRegExp$jscomp$inline_2303$$=RegExp("([A-Z][\\w ]+)/([^\\s]+)\\s*(?:\\((.*?)\\))?","g");$data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$=
[];let $match$jscomp$inline_2305$$;for(;$match$jscomp$inline_2305$$=$msie$jscomp$inline_2299_versionRegExp$jscomp$inline_2303$$.exec($JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$);)$data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$.push([$match$jscomp$inline_2305$$[1],$match$jscomp$inline_2305$$[2],$match$jscomp$inline_2305$$[3]||void 0]);$JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$=
$module$contents$goog$labs$userAgent$browser_createVersionMap$$($data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$);return $module$contents$goog$labs$userAgent$util_matchUserAgent$$("Opera")?$JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$(["Version","Opera"]):$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Edge")?$JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$(["Edge"]):
$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Edg/")?$JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$(["Edg"]):$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Silk")?$JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$(["Silk"]):$module$contents$goog$labs$userAgent$browser_matchChrome$$()?$JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$(["Chrome",
"CriOS","HeadlessChrome"]):($JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$=$data$jscomp$inline_2304_rv$jscomp$inline_2297_version$jscomp$inline_2298$$[2])&&$JSCompiler_inline_result$jscomp$65_lookUpValueWithKeys_tridentVersion$jscomp$inline_2300_tuple$jscomp$1_userAgentString$$[1]||""};
$module$contents$goog$array_insert$$=function($arr$jscomp$38$$,$obj$jscomp$73$$){$module$contents$goog$array_indexOf$$($arr$jscomp$38$$,$obj$jscomp$73$$)>=0||$arr$jscomp$38$$.push($obj$jscomp$73$$)};
$module$contents$goog$array_remove$$=function($arr$jscomp$42$$,$i$jscomp$72_obj$jscomp$76$$){$i$jscomp$72_obj$jscomp$76$$=$module$contents$goog$array_indexOf$$($arr$jscomp$42$$,$i$jscomp$72_obj$jscomp$76$$);let $rv$jscomp$5$$;($rv$jscomp$5$$=$i$jscomp$72_obj$jscomp$76$$>=0)&&Array.prototype.splice.call($arr$jscomp$42$$,$i$jscomp$72_obj$jscomp$76$$,1);return $rv$jscomp$5$$};
$module$contents$goog$array_toArray$$=function($object$jscomp$6$$){const $length$jscomp$20$$=$object$jscomp$6$$.length;if($length$jscomp$20$$>0){const $rv$jscomp$6$$=Array($length$jscomp$20$$);for(let $i$jscomp$76$$=0;$i$jscomp$76$$<$length$jscomp$20$$;$i$jscomp$76$$++)$rv$jscomp$6$$[$i$jscomp$76$$]=$object$jscomp$6$$[$i$jscomp$76$$];return $rv$jscomp$6$$}return[]};
$module$contents$goog$array_extend$$=function($arr1$$,$var_args$jscomp$72$$){for(let $i$jscomp$77$$=1;$i$jscomp$77$$<arguments.length;$i$jscomp$77$$++){const $arr2$jscomp$8$$=arguments[$i$jscomp$77$$];if($goog$isArrayLike$$($arr2$jscomp$8$$)){const $len1$$=$arr1$$.length||0,$len2$$=$arr2$jscomp$8$$.length||0;$arr1$$.length=$len1$$+$len2$$;for(let $j$jscomp$2$$=0;$j$jscomp$2$$<$len2$$;$j$jscomp$2$$++)$arr1$$[$len1$$+$j$jscomp$2$$]=$arr2$jscomp$8$$[$j$jscomp$2$$]}else $arr1$$.push($arr2$jscomp$8$$)}};
$module$contents$goog$array_removeDuplicates$$=function($arr$jscomp$49$$,$opt_rv_returnArray$$){$opt_rv_returnArray$$=$opt_rv_returnArray$$||$arr$jscomp$49$$;let $cursorInsert$$=0,$cursorRead$$=0;const $seen$$={};for(;$cursorRead$$<$arr$jscomp$49$$.length;){const $current$$=$arr$jscomp$49$$[$cursorRead$$++],$key$jscomp$80$$=$goog$isObject$$($current$$)?"o"+$goog$getUid$$($current$$):(typeof $current$$).charAt(0)+$current$$;Object.prototype.hasOwnProperty.call($seen$$,$key$jscomp$80$$)||($seen$$[$key$jscomp$80$$]=
!0,$opt_rv_returnArray$$[$cursorInsert$$++]=$current$$)}$opt_rv_returnArray$$.length=$cursorInsert$$};$APP.$module$contents$goog$array_sort$$=function($arr$jscomp$53$$,$opt_compareFn$jscomp$2$$){$arr$jscomp$53$$.sort($opt_compareFn$jscomp$2$$||$module$contents$goog$array_defaultCompare$$)};
$module$contents$goog$array_stableSort$$=function($arr$jscomp$54$$,$i$jscomp$79_opt_compareFn$jscomp$3$$){const $compArr$$=Array($arr$jscomp$54$$.length);for(let $i$jscomp$78$$=0;$i$jscomp$78$$<$arr$jscomp$54$$.length;$i$jscomp$78$$++)$compArr$$[$i$jscomp$78$$]={index:$i$jscomp$78$$,value:$arr$jscomp$54$$[$i$jscomp$78$$]};const $valueCompareFn$$=$i$jscomp$79_opt_compareFn$jscomp$3$$||$module$contents$goog$array_defaultCompare$$;$APP.$module$contents$goog$array_sort$$($compArr$$,function($obj1$$,$obj2$$){return $valueCompareFn$$($obj1$$.value,
$obj2$$.value)||$obj1$$.index-$obj2$$.index});for($i$jscomp$79_opt_compareFn$jscomp$3$$=0;$i$jscomp$79_opt_compareFn$jscomp$3$$<$arr$jscomp$54$$.length;$i$jscomp$79_opt_compareFn$jscomp$3$$++)$arr$jscomp$54$$[$i$jscomp$79_opt_compareFn$jscomp$3$$]=$compArr$$[$i$jscomp$79_opt_compareFn$jscomp$3$$].value};$module$contents$goog$array_defaultCompare$$=function($a$jscomp$5$$,$b$jscomp$4$$){return $a$jscomp$5$$>$b$jscomp$4$$?1:$a$jscomp$5$$<$b$jscomp$4$$?-1:0};
$goog$dom$safe$setScriptSrc$$=function($script$jscomp$11$$,$url$jscomp$61$$){a:{var $JSCompiler_inline_result$jscomp$14038_doc$jscomp$inline_14104_el$jscomp$inline_14105_nonce$jscomp$inline_14106_nonce$jscomp$inline_2308$$=($script$jscomp$11$$.ownerDocument&&$script$jscomp$11$$.ownerDocument.defaultView||$APP.$goog$global$$).document;if($JSCompiler_inline_result$jscomp$14038_doc$jscomp$inline_14104_el$jscomp$inline_14105_nonce$jscomp$inline_14106_nonce$jscomp$inline_2308$$.querySelector&&($JSCompiler_inline_result$jscomp$14038_doc$jscomp$inline_14104_el$jscomp$inline_14105_nonce$jscomp$inline_14106_nonce$jscomp$inline_2308$$=
$JSCompiler_inline_result$jscomp$14038_doc$jscomp$inline_14104_el$jscomp$inline_14105_nonce$jscomp$inline_14106_nonce$jscomp$inline_2308$$.querySelector("script[nonce]"))&&($JSCompiler_inline_result$jscomp$14038_doc$jscomp$inline_14104_el$jscomp$inline_14105_nonce$jscomp$inline_14106_nonce$jscomp$inline_2308$$=$JSCompiler_inline_result$jscomp$14038_doc$jscomp$inline_14104_el$jscomp$inline_14105_nonce$jscomp$inline_14106_nonce$jscomp$inline_2308$$.nonce||$JSCompiler_inline_result$jscomp$14038_doc$jscomp$inline_14104_el$jscomp$inline_14105_nonce$jscomp$inline_14106_nonce$jscomp$inline_2308$$.getAttribute("nonce"))&&
$goog$dom$safe$NONCE_PATTERN_$$.test($JSCompiler_inline_result$jscomp$14038_doc$jscomp$inline_14104_el$jscomp$inline_14105_nonce$jscomp$inline_14106_nonce$jscomp$inline_2308$$))break a;$JSCompiler_inline_result$jscomp$14038_doc$jscomp$inline_14104_el$jscomp$inline_14105_nonce$jscomp$inline_14106_nonce$jscomp$inline_2308$$=""}$JSCompiler_inline_result$jscomp$14038_doc$jscomp$inline_14104_el$jscomp$inline_14105_nonce$jscomp$inline_14106_nonce$jscomp$inline_2308$$&&$script$jscomp$11$$.setAttribute("nonce",
$JSCompiler_inline_result$jscomp$14038_doc$jscomp$inline_14104_el$jscomp$inline_14105_nonce$jscomp$inline_14106_nonce$jscomp$inline_2308$$);$script$jscomp$11$$.src=$goog$html$TrustedResourceUrl$unwrapTrustedScriptURL$$($url$jscomp$61$$)};$goog$string$isUnicodeChar$$=function($ch$jscomp$2$$){return $ch$jscomp$2$$.length==1&&$ch$jscomp$2$$>=" "&&$ch$jscomp$2$$<="~"||$ch$jscomp$2$$>=""&&$ch$jscomp$2$$<="�"};
$goog$string$regExpEscape$$=function($s$jscomp$17$$){return String($s$jscomp$17$$).replace(/([-()\[\]{}+?*.$\^|,:#<!\\])/g,"\\$1").replace(/\x08/g,"\\x08")};
$goog$string$padNumber$$=function($num$jscomp$6_s$jscomp$18$$,$length$jscomp$24$$){if(!Number.isFinite($num$jscomp$6_s$jscomp$18$$))return String($num$jscomp$6_s$jscomp$18$$);$num$jscomp$6_s$jscomp$18$$=String($num$jscomp$6_s$jscomp$18$$);let $index$jscomp$115$$=$num$jscomp$6_s$jscomp$18$$.indexOf(".");$index$jscomp$115$$===-1&&($index$jscomp$115$$=$num$jscomp$6_s$jscomp$18$$.length);const $sign$jscomp$1$$=$num$jscomp$6_s$jscomp$18$$[0]==="-"?"-":"";$sign$jscomp$1$$&&($num$jscomp$6_s$jscomp$18$$=
$num$jscomp$6_s$jscomp$18$$.substring(1));return $sign$jscomp$1$$+$goog$string$repeat$$("0",Math.max(0,$length$jscomp$24$$-$index$jscomp$115$$))+$num$jscomp$6_s$jscomp$18$$};$goog$string$makeSafe$$=function($obj$jscomp$79$$){return $obj$jscomp$79$$==null?"":String($obj$jscomp$79$$)};
$goog$structs$getValues$$=function($col$jscomp$1$$){if($col$jscomp$1$$.$getValues$&&typeof $col$jscomp$1$$.$getValues$=="function")return $col$jscomp$1$$.$getValues$();if(typeof Map!=="undefined"&&$col$jscomp$1$$ instanceof Map||typeof Set!=="undefined"&&$col$jscomp$1$$ instanceof Set)return Array.from($col$jscomp$1$$.values());if(typeof $col$jscomp$1$$==="string")return $col$jscomp$1$$.split("");if($goog$isArrayLike$$($col$jscomp$1$$)){for(var $rv$jscomp$8$$=[],$l$jscomp$12$$=$col$jscomp$1$$.length,
$i$jscomp$103$$=0;$i$jscomp$103$$<$l$jscomp$12$$;$i$jscomp$103$$++)$rv$jscomp$8$$.push($col$jscomp$1$$[$i$jscomp$103$$]);return $rv$jscomp$8$$}return $module$contents$goog$object_getValues$$($col$jscomp$1$$)};
$goog$structs$getKeys$$=function($col$jscomp$2_l$jscomp$13$$){if($col$jscomp$2_l$jscomp$13$$.$getKeys$&&typeof $col$jscomp$2_l$jscomp$13$$.$getKeys$=="function")return $col$jscomp$2_l$jscomp$13$$.$getKeys$();if(!$col$jscomp$2_l$jscomp$13$$.$getValues$||typeof $col$jscomp$2_l$jscomp$13$$.$getValues$!="function"){if(typeof Map!=="undefined"&&$col$jscomp$2_l$jscomp$13$$ instanceof Map)return Array.from($col$jscomp$2_l$jscomp$13$$.keys());if(!(typeof Set!=="undefined"&&$col$jscomp$2_l$jscomp$13$$ instanceof
Set)){if($goog$isArrayLike$$($col$jscomp$2_l$jscomp$13$$)||typeof $col$jscomp$2_l$jscomp$13$$==="string"){var $rv$jscomp$9$$=[];$col$jscomp$2_l$jscomp$13$$=$col$jscomp$2_l$jscomp$13$$.length;for(var $i$jscomp$104$$=0;$i$jscomp$104$$<$col$jscomp$2_l$jscomp$13$$;$i$jscomp$104$$++)$rv$jscomp$9$$.push($i$jscomp$104$$);return $rv$jscomp$9$$}return $module$contents$goog$object_getKeys$$($col$jscomp$2_l$jscomp$13$$)}}};
$goog$structs$forEach$$=function($col$jscomp$6$$,$f$jscomp$39$$,$opt_obj$jscomp$32$$){if($col$jscomp$6$$.forEach&&typeof $col$jscomp$6$$.forEach=="function")$col$jscomp$6$$.forEach($f$jscomp$39$$,$opt_obj$jscomp$32$$);else if($goog$isArrayLike$$($col$jscomp$6$$)||typeof $col$jscomp$6$$==="string")Array.prototype.forEach.call($col$jscomp$6$$,$f$jscomp$39$$,$opt_obj$jscomp$32$$);else for(var $keys$jscomp$2$$=$goog$structs$getKeys$$($col$jscomp$6$$),$values$jscomp$12$$=$goog$structs$getValues$$($col$jscomp$6$$),
$l$jscomp$14$$=$values$jscomp$12$$.length,$i$jscomp$105$$=0;$i$jscomp$105$$<$l$jscomp$14$$;$i$jscomp$105$$++)$f$jscomp$39$$.call($opt_obj$jscomp$32$$,$values$jscomp$12$$[$i$jscomp$105$$],$keys$jscomp$2$$&&$keys$jscomp$2$$[$i$jscomp$105$$],$col$jscomp$6$$)};
$goog$uri$utils$parseQueryData$$=function($encodedQuery_pairs$$,$callback$jscomp$71$$){if($encodedQuery_pairs$$){$encodedQuery_pairs$$=$encodedQuery_pairs$$.split("\x26");for(var $i$jscomp$110$$=0;$i$jscomp$110$$<$encodedQuery_pairs$$.length;$i$jscomp$110$$++){var $indexOfEquals$$=$encodedQuery_pairs$$[$i$jscomp$110$$].indexOf("\x3d"),$value$jscomp$189$$=null;if($indexOfEquals$$>=0){var $name$jscomp$97$$=$encodedQuery_pairs$$[$i$jscomp$110$$].substring(0,$indexOfEquals$$);$value$jscomp$189$$=$encodedQuery_pairs$$[$i$jscomp$110$$].substring($indexOfEquals$$+
1)}else $name$jscomp$97$$=$encodedQuery_pairs$$[$i$jscomp$110$$];$callback$jscomp$71$$($name$jscomp$97$$,$value$jscomp$189$$?decodeURIComponent($value$jscomp$189$$.replace(/\+/g," ")):"")}}};
$goog$Uri$$=function($newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$){this.$domain_$=this.$userInfo_$=this.$scheme_$="";this.$port_$=null;this.$fragment_$=this.$path_$="";this.$ignoreCase_$=this.$isReadOnly_$=!1;if($newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$ instanceof
$goog$Uri$$){this.$ignoreCase_$=$newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$.$ignoreCase_$;$JSCompiler_StaticMethods_setScheme$$(this,$newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$.$scheme_$);var $m_newDomain$jscomp$inline_11103_newPath$jscomp$inline_11107_newUserInfo$jscomp$inline_11099$$=
$newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$.$userInfo_$;$JSCompiler_StaticMethods_enforceReadOnly$$(this);this.$userInfo_$=$m_newDomain$jscomp$inline_11103_newPath$jscomp$inline_11107_newUserInfo$jscomp$inline_11099$$;$m_newDomain$jscomp$inline_11103_newPath$jscomp$inline_11107_newUserInfo$jscomp$inline_11099$$=$newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$.$domain_$;
$JSCompiler_StaticMethods_enforceReadOnly$$(this);this.$domain_$=$m_newDomain$jscomp$inline_11103_newPath$jscomp$inline_11107_newUserInfo$jscomp$inline_11099$$;$JSCompiler_StaticMethods_setPort$$(this,$newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$.$port_$);$m_newDomain$jscomp$inline_11103_newPath$jscomp$inline_11107_newUserInfo$jscomp$inline_11099$$=$newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$.$path_$;
$JSCompiler_StaticMethods_enforceReadOnly$$(this);this.$path_$=$m_newDomain$jscomp$inline_11103_newPath$jscomp$inline_11107_newUserInfo$jscomp$inline_11099$$;$JSCompiler_StaticMethods_setQueryData$$(this,$newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$.$queryData_$.clone());$newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$=
$newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$.$fragment_$;$JSCompiler_StaticMethods_enforceReadOnly$$(this);this.$fragment_$=$newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$}else $newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$&&
($m_newDomain$jscomp$inline_11103_newPath$jscomp$inline_11107_newUserInfo$jscomp$inline_11099$$=String($newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$).match($goog$uri$utils$splitRe_$$))?(this.$ignoreCase_$=!1,$JSCompiler_StaticMethods_setScheme$$(this,$m_newDomain$jscomp$inline_11103_newPath$jscomp$inline_11107_newUserInfo$jscomp$inline_11099$$[1]||"",!0),$newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$=
$m_newDomain$jscomp$inline_11103_newPath$jscomp$inline_11107_newUserInfo$jscomp$inline_11099$$[2]||"",$JSCompiler_StaticMethods_enforceReadOnly$$(this),this.$userInfo_$=$goog$Uri$decodeOrEmpty_$$($newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$),$newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$=
$m_newDomain$jscomp$inline_11103_newPath$jscomp$inline_11107_newUserInfo$jscomp$inline_11099$$[3]||"",$JSCompiler_StaticMethods_enforceReadOnly$$(this),this.$domain_$=$goog$Uri$decodeOrEmpty_$$($newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$,!0),$JSCompiler_StaticMethods_setPort$$(this,$m_newDomain$jscomp$inline_11103_newPath$jscomp$inline_11107_newUserInfo$jscomp$inline_11099$$[4]),
$newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$=$m_newDomain$jscomp$inline_11103_newPath$jscomp$inline_11107_newUserInfo$jscomp$inline_11099$$[5]||"",$JSCompiler_StaticMethods_enforceReadOnly$$(this),this.$path_$=$goog$Uri$decodeOrEmpty_$$($newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$,
!0),$JSCompiler_StaticMethods_setQueryData$$(this,$m_newDomain$jscomp$inline_11103_newPath$jscomp$inline_11107_newUserInfo$jscomp$inline_11099$$[6]||"",!0),$newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$=$m_newDomain$jscomp$inline_11103_newPath$jscomp$inline_11107_newUserInfo$jscomp$inline_11099$$[7]||"",$JSCompiler_StaticMethods_enforceReadOnly$$(this),this.$fragment_$=$goog$Uri$decodeOrEmpty_$$($newDomain$jscomp$inline_11119_newFragment$jscomp$inline_11111_newFragment$jscomp$inline_11127_newPath$jscomp$inline_11123_newUserInfo$jscomp$inline_11115_opt_uri$$)):
(this.$ignoreCase_$=!1,this.$queryData_$=new $goog$Uri$QueryData$$(null,this.$ignoreCase_$))};
$JSCompiler_StaticMethods_setScheme$$=function($JSCompiler_StaticMethods_setScheme$self$$,$newScheme$$,$opt_decode$$){$JSCompiler_StaticMethods_enforceReadOnly$$($JSCompiler_StaticMethods_setScheme$self$$);$JSCompiler_StaticMethods_setScheme$self$$.$scheme_$=$opt_decode$$?$goog$Uri$decodeOrEmpty_$$($newScheme$$,!0):$newScheme$$;$JSCompiler_StaticMethods_setScheme$self$$.$scheme_$&&($JSCompiler_StaticMethods_setScheme$self$$.$scheme_$=$JSCompiler_StaticMethods_setScheme$self$$.$scheme_$.replace(/:$/,
""))};$JSCompiler_StaticMethods_setPort$$=function($JSCompiler_StaticMethods_setPort$self$$,$newPort$$){$JSCompiler_StaticMethods_enforceReadOnly$$($JSCompiler_StaticMethods_setPort$self$$);if($newPort$$){$newPort$$=Number($newPort$$);if(isNaN($newPort$$)||$newPort$$<0)throw Error("Bad port number "+$newPort$$);$JSCompiler_StaticMethods_setPort$self$$.$port_$=$newPort$$}else $JSCompiler_StaticMethods_setPort$self$$.$port_$=null};
$JSCompiler_StaticMethods_setQueryData$$=function($JSCompiler_StaticMethods_setQueryData$self$$,$queryData$jscomp$6$$,$opt_decode$jscomp$4$$){$JSCompiler_StaticMethods_enforceReadOnly$$($JSCompiler_StaticMethods_setQueryData$self$$);$queryData$jscomp$6$$ instanceof $goog$Uri$QueryData$$?($JSCompiler_StaticMethods_setQueryData$self$$.$queryData_$=$queryData$jscomp$6$$,$JSCompiler_StaticMethods_setQueryData$self$$.$queryData_$.$setIgnoreCase$($JSCompiler_StaticMethods_setQueryData$self$$.$ignoreCase_$)):
($opt_decode$jscomp$4$$||($queryData$jscomp$6$$=$goog$Uri$encodeSpecialChars_$$($queryData$jscomp$6$$,$goog$Uri$reDisallowedInQuery_$$)),$JSCompiler_StaticMethods_setQueryData$self$$.$queryData_$=new $goog$Uri$QueryData$$($queryData$jscomp$6$$,$JSCompiler_StaticMethods_setQueryData$self$$.$ignoreCase_$))};
$JSCompiler_StaticMethods_enforceReadOnly$$=function($JSCompiler_StaticMethods_enforceReadOnly$self$$){if($JSCompiler_StaticMethods_enforceReadOnly$self$$.$isReadOnly_$)throw Error("Tried to modify a read-only Uri");};$goog$Uri$decodeOrEmpty_$$=function($val$jscomp$38$$,$opt_preserveReserved$jscomp$1$$){return $val$jscomp$38$$?$opt_preserveReserved$jscomp$1$$?decodeURI($val$jscomp$38$$.replace(/%25/g,"%2525")):decodeURIComponent($val$jscomp$38$$):""};
$goog$Uri$encodeSpecialChars_$$=function($encoded_unescapedPart$$,$extra$$,$opt_removeDoubleEncoding$$){return typeof $encoded_unescapedPart$$==="string"?($encoded_unescapedPart$$=encodeURI($encoded_unescapedPart$$).replace($extra$$,$goog$Uri$encodeChar_$$),$opt_removeDoubleEncoding$$&&($encoded_unescapedPart$$=$goog$Uri$removeDoubleEncoding_$$($encoded_unescapedPart$$)),$encoded_unescapedPart$$):null};
$goog$Uri$encodeChar_$$=function($ch$jscomp$4_n$jscomp$7$$){$ch$jscomp$4_n$jscomp$7$$=$ch$jscomp$4_n$jscomp$7$$.charCodeAt(0);return"%"+($ch$jscomp$4_n$jscomp$7$$>>4&15).toString(16)+($ch$jscomp$4_n$jscomp$7$$&15).toString(16)};$goog$Uri$removeDoubleEncoding_$$=function($doubleEncodedString$$){return $doubleEncodedString$$.replace(/%25([0-9a-fA-F]{2})/g,"%$1")};
$goog$Uri$QueryData$$=function($opt_query$jscomp$1$$,$opt_ignoreCase$jscomp$3$$){this.$count_$=this.$keyMap_$=null;this.$encodedQuery_$=$opt_query$jscomp$1$$||null;this.$ignoreCase_$=!!$opt_ignoreCase$jscomp$3$$};
$JSCompiler_StaticMethods_ensureKeyMapInitialized_$$=function($JSCompiler_StaticMethods_ensureKeyMapInitialized_$self$$){$JSCompiler_StaticMethods_ensureKeyMapInitialized_$self$$.$keyMap_$||($JSCompiler_StaticMethods_ensureKeyMapInitialized_$self$$.$keyMap_$=new Map,$JSCompiler_StaticMethods_ensureKeyMapInitialized_$self$$.$count_$=0,$JSCompiler_StaticMethods_ensureKeyMapInitialized_$self$$.$encodedQuery_$&&$goog$uri$utils$parseQueryData$$($JSCompiler_StaticMethods_ensureKeyMapInitialized_$self$$.$encodedQuery_$,
function($name$jscomp$100$$,$value$jscomp$194$$){$JSCompiler_StaticMethods_ensureKeyMapInitialized_$self$$.add(decodeURIComponent($name$jscomp$100$$.replace(/\+/g," ")),$value$jscomp$194$$)}))};
$JSCompiler_StaticMethods_containsKey$$=function($JSCompiler_StaticMethods_containsKey$self$$,$key$jscomp$100$$){$JSCompiler_StaticMethods_ensureKeyMapInitialized_$$($JSCompiler_StaticMethods_containsKey$self$$);$key$jscomp$100$$=$JSCompiler_StaticMethods_getKeyName_$$($JSCompiler_StaticMethods_containsKey$self$$,$key$jscomp$100$$);return $JSCompiler_StaticMethods_containsKey$self$$.$keyMap_$.has($key$jscomp$100$$)};
$JSCompiler_StaticMethods_getKeyName_$$=function($JSCompiler_StaticMethods_getKeyName_$self$$,$arg$jscomp$10_keyName$$){$arg$jscomp$10_keyName$$=String($arg$jscomp$10_keyName$$);$JSCompiler_StaticMethods_getKeyName_$self$$.$ignoreCase_$&&($arg$jscomp$10_keyName$$=$arg$jscomp$10_keyName$$.toLowerCase());return $arg$jscomp$10_keyName$$};$APP.$goog$string$StringBuffer$$=function($opt_a1$$,$var_args$jscomp$80$$){$opt_a1$$!=null&&this.append.apply(this,arguments)};
$cljs$core$pr_opts$$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$0$flush_on_newline$$,!0,$cljs$cst$1$readably$$,$cljs$core$_STAR_print_readably_STAR_$$,$cljs$cst$2$meta$$,!1,$cljs$cst$3$dup$$,$cljs$core$_STAR_print_dup_STAR_$$,$cljs$cst$4$print_length$$,$cljs$core$_STAR_print_length_STAR_$$],null)};
$cljs$core$enable_console_print_BANG_$$=function(){$APP.$cljs$core$_STAR_print_newline_STAR_$$=!1;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function(){var $xs$$=arguments;return console.log.apply(console,$module$contents$goog$array_toArray$$($xs$$))}};$APP.$cljs$core$truth_$$=function($x$jscomp$97$$){return $x$jscomp$97$$!=null&&$x$jscomp$97$$!==!1};$cljs$core$identical_QMARK_$$=function($x$jscomp$98$$,$y$jscomp$79$$){return $x$jscomp$98$$===$y$jscomp$79$$};
$APP.$cljs$core$nil_QMARK_$$=function($x$jscomp$99$$){return $x$jscomp$99$$==null};$APP.$cljs$core$array_QMARK_$$=function($x$jscomp$100$$){return $x$jscomp$100$$ instanceof Array};$APP.$cljs$core$number_QMARK_$$=function($x$jscomp$101$$){return typeof $x$jscomp$101$$==="number"};$APP.$cljs$core$not$$=function($x$jscomp$102$$){return $x$jscomp$102$$==null?!0:$x$jscomp$102$$===!1?!0:!1};$APP.$cljs$core$some_QMARK_$$=function($x$jscomp$103$$){return $x$jscomp$103$$!=null};
$APP.$cljs$core$object_QMARK_$$=function($x$jscomp$104$$){return $x$jscomp$104$$!=null?$x$jscomp$104$$.constructor===Object:!1};$APP.$cljs$core$string_QMARK_$$=function($x$jscomp$105$$){return"string"===$APP.$goog$typeOf$$($x$jscomp$105$$)};$cljs$core$char_QMARK_$$=function($x$jscomp$106$$){return typeof $x$jscomp$106$$==="string"&&1===$x$jscomp$106$$.length};$APP.$cljs$core$any_QMARK_$$=function(){return!0};
$APP.$cljs$core$native_satisfies_QMARK_$$=function($p$jscomp$1$$,$x$jscomp$108$$){return $p$jscomp$1$$[$APP.$goog$typeOf$$($x$jscomp$108$$==null?null:$x$jscomp$108$$)]?!0:$p$jscomp$1$$._?!0:!1};$APP.$cljs$core$type$$=function($x$jscomp$110$$){return $x$jscomp$110$$==null?null:$x$jscomp$110$$.constructor};
$APP.$cljs$core$missing_protocol$$=function($proto$jscomp$7$$,$obj$jscomp$81$$){var $ty$jscomp$3_ty__$1$$=$APP.$cljs$core$type$$($obj$jscomp$81$$);$ty$jscomp$3_ty__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($ty$jscomp$3_ty__$1$$)?$ty$jscomp$3_ty__$1$$.$cljs$lang$type$:$ty$jscomp$3_ty__$1$$)?$ty$jscomp$3_ty__$1$$.$cljs$lang$ctorStr$:$APP.$goog$typeOf$$($obj$jscomp$81$$);return Error(["No protocol method ",$proto$jscomp$7$$," defined for type ",$ty$jscomp$3_ty__$1$$,": ",$obj$jscomp$81$$].join(""))};
$cljs$core$type__GT_str$$=function($ty$jscomp$4$$){var $temp__5823__auto__$$=$ty$jscomp$4$$.$cljs$lang$ctorStr$;return $APP.$cljs$core$truth_$$($temp__5823__auto__$$)?$temp__5823__auto__$$:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ty$jscomp$4$$)};
$APP.$cljs$core$aclone$$=function($arr$jscomp$64$$){for(var $len$jscomp$9$$=$arr$jscomp$64$$.length,$new_arr$$=Array($len$jscomp$9$$),$i_24360$$=0;;)if($i_24360$$<$len$jscomp$9$$)$new_arr$$[$i_24360$$]=$arr$jscomp$64$$[$i_24360$$],$i_24360$$+=1;else break;return $new_arr$$};
$APP.$cljs$core$array$$=function($var_args$jscomp$83$$){for(var $a$jscomp$11$$=Array(arguments.length),$i$jscomp$119$$=0;;)if($i$jscomp$119$$<$a$jscomp$11$$.length)$a$jscomp$11$$[$i$jscomp$119$$]=arguments[$i$jscomp$119$$],$i$jscomp$119$$+=1;else return $a$jscomp$11$$};$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$01$$=function($aseq$$){return $APP.$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$02$$($aseq$$)};
$APP.$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$02$$=function($aseq$jscomp$1$$){function $G__22800$$($a$jscomp$12$$,$x$jscomp$111$$){$a$jscomp$12$$.push($x$jscomp$111$$);return $a$jscomp$12$$}var $G__22801$$=[];return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($G__22800$$,$G__22801$$,$aseq$jscomp$1$$):$cljs$core$reduce$$($G__22800$$,$G__22801$$,$aseq$jscomp$1$$)};
$cljs$core$js_symbol_QMARK_$$=function($x$jscomp$112$$){return $APP.$goog$typeOf$$($x$jscomp$112$$)==="symbol"||typeof Symbol!=="undefined"&&$x$jscomp$112$$ instanceof Symbol};$cljs$core$Fn$$=function(){};$cljs$core$IFn$$=function(){};
$cljs$core$_clone$$=function($JSCompiler_temp$jscomp$67_value$jscomp$204$$){if($JSCompiler_temp$jscomp$67_value$jscomp$204$$!=null&&$JSCompiler_temp$jscomp$67_value$jscomp$204$$.$cljs$core$ICloneable$_clone$arity$1$!=null)$JSCompiler_temp$jscomp$67_value$jscomp$204$$=$JSCompiler_temp$jscomp$67_value$jscomp$204$$.$cljs$core$ICloneable$_clone$arity$1$($JSCompiler_temp$jscomp$67_value$jscomp$204$$);else{var $m__5372__auto__$jscomp$inline_2323_m__5374__auto__$jscomp$inline_2322$$=$cljs$core$_clone$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$67_value$jscomp$204$$==
null?null:$JSCompiler_temp$jscomp$67_value$jscomp$204$$)];if($m__5372__auto__$jscomp$inline_2323_m__5374__auto__$jscomp$inline_2322$$!=null)$JSCompiler_temp$jscomp$67_value$jscomp$204$$=$m__5372__auto__$jscomp$inline_2323_m__5374__auto__$jscomp$inline_2322$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2323_m__5374__auto__$jscomp$inline_2322$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$67_value$jscomp$204$$):$m__5372__auto__$jscomp$inline_2323_m__5374__auto__$jscomp$inline_2322$$($JSCompiler_temp$jscomp$67_value$jscomp$204$$);
else if($m__5372__auto__$jscomp$inline_2323_m__5374__auto__$jscomp$inline_2322$$=$cljs$core$_clone$$._,$m__5372__auto__$jscomp$inline_2323_m__5374__auto__$jscomp$inline_2322$$!=null)$JSCompiler_temp$jscomp$67_value$jscomp$204$$=$m__5372__auto__$jscomp$inline_2323_m__5374__auto__$jscomp$inline_2322$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2323_m__5374__auto__$jscomp$inline_2322$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$67_value$jscomp$204$$):$m__5372__auto__$jscomp$inline_2323_m__5374__auto__$jscomp$inline_2322$$($JSCompiler_temp$jscomp$67_value$jscomp$204$$);
else throw $APP.$cljs$core$missing_protocol$$("ICloneable.-clone",$JSCompiler_temp$jscomp$67_value$jscomp$204$$);}return $JSCompiler_temp$jscomp$67_value$jscomp$204$$};$cljs$core$ICounted$$=function(){};
$APP.$cljs$core$_count$$=function($JSCompiler_temp$jscomp$68_coll$jscomp$1$$){if($JSCompiler_temp$jscomp$68_coll$jscomp$1$$!=null&&$JSCompiler_temp$jscomp$68_coll$jscomp$1$$.$cljs$core$ICounted$_count$arity$1$!=null)$JSCompiler_temp$jscomp$68_coll$jscomp$1$$=$JSCompiler_temp$jscomp$68_coll$jscomp$1$$.$cljs$core$ICounted$_count$arity$1$($JSCompiler_temp$jscomp$68_coll$jscomp$1$$);else{var $m__5372__auto__$jscomp$inline_2327_m__5374__auto__$jscomp$inline_2326$$=$APP.$cljs$core$_count$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$68_coll$jscomp$1$$==
null?null:$JSCompiler_temp$jscomp$68_coll$jscomp$1$$)];if($m__5372__auto__$jscomp$inline_2327_m__5374__auto__$jscomp$inline_2326$$!=null)$JSCompiler_temp$jscomp$68_coll$jscomp$1$$=$m__5372__auto__$jscomp$inline_2327_m__5374__auto__$jscomp$inline_2326$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2327_m__5374__auto__$jscomp$inline_2326$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$68_coll$jscomp$1$$):$m__5372__auto__$jscomp$inline_2327_m__5374__auto__$jscomp$inline_2326$$($JSCompiler_temp$jscomp$68_coll$jscomp$1$$);
else if($m__5372__auto__$jscomp$inline_2327_m__5374__auto__$jscomp$inline_2326$$=$APP.$cljs$core$_count$$._,$m__5372__auto__$jscomp$inline_2327_m__5374__auto__$jscomp$inline_2326$$!=null)$JSCompiler_temp$jscomp$68_coll$jscomp$1$$=$m__5372__auto__$jscomp$inline_2327_m__5374__auto__$jscomp$inline_2326$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2327_m__5374__auto__$jscomp$inline_2326$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$68_coll$jscomp$1$$):$m__5372__auto__$jscomp$inline_2327_m__5374__auto__$jscomp$inline_2326$$($JSCompiler_temp$jscomp$68_coll$jscomp$1$$);
else throw $APP.$cljs$core$missing_protocol$$("ICounted.-count",$JSCompiler_temp$jscomp$68_coll$jscomp$1$$);}return $JSCompiler_temp$jscomp$68_coll$jscomp$1$$};$cljs$core$IEmptyableCollection$$=function(){};
$cljs$core$_empty$$=function($JSCompiler_temp$jscomp$69_coll$jscomp$3$$){if($JSCompiler_temp$jscomp$69_coll$jscomp$3$$!=null&&$JSCompiler_temp$jscomp$69_coll$jscomp$3$$.$cljs$core$IEmptyableCollection$_empty$arity$1$!=null)$JSCompiler_temp$jscomp$69_coll$jscomp$3$$=$JSCompiler_temp$jscomp$69_coll$jscomp$3$$.$cljs$core$IEmptyableCollection$_empty$arity$1$($JSCompiler_temp$jscomp$69_coll$jscomp$3$$);else{var $m__5372__auto__$jscomp$inline_2331_m__5374__auto__$jscomp$inline_2330$$=$cljs$core$_empty$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$69_coll$jscomp$3$$==
null?null:$JSCompiler_temp$jscomp$69_coll$jscomp$3$$)];if($m__5372__auto__$jscomp$inline_2331_m__5374__auto__$jscomp$inline_2330$$!=null)$JSCompiler_temp$jscomp$69_coll$jscomp$3$$=$m__5372__auto__$jscomp$inline_2331_m__5374__auto__$jscomp$inline_2330$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2331_m__5374__auto__$jscomp$inline_2330$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$69_coll$jscomp$3$$):$m__5372__auto__$jscomp$inline_2331_m__5374__auto__$jscomp$inline_2330$$($JSCompiler_temp$jscomp$69_coll$jscomp$3$$);
else if($m__5372__auto__$jscomp$inline_2331_m__5374__auto__$jscomp$inline_2330$$=$cljs$core$_empty$$._,$m__5372__auto__$jscomp$inline_2331_m__5374__auto__$jscomp$inline_2330$$!=null)$JSCompiler_temp$jscomp$69_coll$jscomp$3$$=$m__5372__auto__$jscomp$inline_2331_m__5374__auto__$jscomp$inline_2330$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2331_m__5374__auto__$jscomp$inline_2330$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$69_coll$jscomp$3$$):$m__5372__auto__$jscomp$inline_2331_m__5374__auto__$jscomp$inline_2330$$($JSCompiler_temp$jscomp$69_coll$jscomp$3$$);
else throw $APP.$cljs$core$missing_protocol$$("IEmptyableCollection.-empty",$JSCompiler_temp$jscomp$69_coll$jscomp$3$$);}return $JSCompiler_temp$jscomp$69_coll$jscomp$3$$};$cljs$core$ICollection$$=function(){};
$APP.$cljs$core$_conj$$=function($JSCompiler_temp$jscomp$70_coll$jscomp$5$$,$o$jscomp$18$$){if($JSCompiler_temp$jscomp$70_coll$jscomp$5$$!=null&&$JSCompiler_temp$jscomp$70_coll$jscomp$5$$.$cljs$core$ICollection$_conj$arity$2$!=null)$JSCompiler_temp$jscomp$70_coll$jscomp$5$$=$JSCompiler_temp$jscomp$70_coll$jscomp$5$$.$cljs$core$ICollection$_conj$arity$2$($JSCompiler_temp$jscomp$70_coll$jscomp$5$$,$o$jscomp$18$$);else{var $m__5372__auto__$jscomp$inline_2336_m__5374__auto__$jscomp$inline_2335$$=$APP.$cljs$core$_conj$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$70_coll$jscomp$5$$==
null?null:$JSCompiler_temp$jscomp$70_coll$jscomp$5$$)];if($m__5372__auto__$jscomp$inline_2336_m__5374__auto__$jscomp$inline_2335$$!=null)$JSCompiler_temp$jscomp$70_coll$jscomp$5$$=$m__5372__auto__$jscomp$inline_2336_m__5374__auto__$jscomp$inline_2335$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2336_m__5374__auto__$jscomp$inline_2335$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$70_coll$jscomp$5$$,$o$jscomp$18$$):$m__5372__auto__$jscomp$inline_2336_m__5374__auto__$jscomp$inline_2335$$($JSCompiler_temp$jscomp$70_coll$jscomp$5$$,
$o$jscomp$18$$);else if($m__5372__auto__$jscomp$inline_2336_m__5374__auto__$jscomp$inline_2335$$=$APP.$cljs$core$_conj$$._,$m__5372__auto__$jscomp$inline_2336_m__5374__auto__$jscomp$inline_2335$$!=null)$JSCompiler_temp$jscomp$70_coll$jscomp$5$$=$m__5372__auto__$jscomp$inline_2336_m__5374__auto__$jscomp$inline_2335$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2336_m__5374__auto__$jscomp$inline_2335$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$70_coll$jscomp$5$$,$o$jscomp$18$$):
$m__5372__auto__$jscomp$inline_2336_m__5374__auto__$jscomp$inline_2335$$($JSCompiler_temp$jscomp$70_coll$jscomp$5$$,$o$jscomp$18$$);else throw $APP.$cljs$core$missing_protocol$$("ICollection.-conj",$JSCompiler_temp$jscomp$70_coll$jscomp$5$$);}return $JSCompiler_temp$jscomp$70_coll$jscomp$5$$};$cljs$core$IIndexed$$=function(){};$cljs$core$ISeq$$=function(){};
$cljs$core$_first$$=function($JSCompiler_temp$jscomp$71_coll$jscomp$12$$){if($JSCompiler_temp$jscomp$71_coll$jscomp$12$$!=null&&$JSCompiler_temp$jscomp$71_coll$jscomp$12$$.$cljs$core$ISeq$_first$arity$1$!=null)$JSCompiler_temp$jscomp$71_coll$jscomp$12$$=$JSCompiler_temp$jscomp$71_coll$jscomp$12$$.$cljs$core$ISeq$_first$arity$1$($JSCompiler_temp$jscomp$71_coll$jscomp$12$$);else{var $m__5372__auto__$jscomp$inline_2340_m__5374__auto__$jscomp$inline_2339$$=$cljs$core$_first$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$71_coll$jscomp$12$$==
null?null:$JSCompiler_temp$jscomp$71_coll$jscomp$12$$)];if($m__5372__auto__$jscomp$inline_2340_m__5374__auto__$jscomp$inline_2339$$!=null)$JSCompiler_temp$jscomp$71_coll$jscomp$12$$=$m__5372__auto__$jscomp$inline_2340_m__5374__auto__$jscomp$inline_2339$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2340_m__5374__auto__$jscomp$inline_2339$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$71_coll$jscomp$12$$):$m__5372__auto__$jscomp$inline_2340_m__5374__auto__$jscomp$inline_2339$$($JSCompiler_temp$jscomp$71_coll$jscomp$12$$);
else if($m__5372__auto__$jscomp$inline_2340_m__5374__auto__$jscomp$inline_2339$$=$cljs$core$_first$$._,$m__5372__auto__$jscomp$inline_2340_m__5374__auto__$jscomp$inline_2339$$!=null)$JSCompiler_temp$jscomp$71_coll$jscomp$12$$=$m__5372__auto__$jscomp$inline_2340_m__5374__auto__$jscomp$inline_2339$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2340_m__5374__auto__$jscomp$inline_2339$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$71_coll$jscomp$12$$):$m__5372__auto__$jscomp$inline_2340_m__5374__auto__$jscomp$inline_2339$$($JSCompiler_temp$jscomp$71_coll$jscomp$12$$);
else throw $APP.$cljs$core$missing_protocol$$("ISeq.-first",$JSCompiler_temp$jscomp$71_coll$jscomp$12$$);}return $JSCompiler_temp$jscomp$71_coll$jscomp$12$$};
$cljs$core$_rest$$=function($JSCompiler_temp$jscomp$72_coll$jscomp$14$$){if($JSCompiler_temp$jscomp$72_coll$jscomp$14$$!=null&&$JSCompiler_temp$jscomp$72_coll$jscomp$14$$.$cljs$core$ISeq$_rest$arity$1$!=null)$JSCompiler_temp$jscomp$72_coll$jscomp$14$$=$JSCompiler_temp$jscomp$72_coll$jscomp$14$$.$cljs$core$ISeq$_rest$arity$1$($JSCompiler_temp$jscomp$72_coll$jscomp$14$$);else{var $m__5372__auto__$jscomp$inline_2344_m__5374__auto__$jscomp$inline_2343$$=$cljs$core$_rest$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$72_coll$jscomp$14$$==
null?null:$JSCompiler_temp$jscomp$72_coll$jscomp$14$$)];if($m__5372__auto__$jscomp$inline_2344_m__5374__auto__$jscomp$inline_2343$$!=null)$JSCompiler_temp$jscomp$72_coll$jscomp$14$$=$m__5372__auto__$jscomp$inline_2344_m__5374__auto__$jscomp$inline_2343$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2344_m__5374__auto__$jscomp$inline_2343$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$72_coll$jscomp$14$$):$m__5372__auto__$jscomp$inline_2344_m__5374__auto__$jscomp$inline_2343$$($JSCompiler_temp$jscomp$72_coll$jscomp$14$$);
else if($m__5372__auto__$jscomp$inline_2344_m__5374__auto__$jscomp$inline_2343$$=$cljs$core$_rest$$._,$m__5372__auto__$jscomp$inline_2344_m__5374__auto__$jscomp$inline_2343$$!=null)$JSCompiler_temp$jscomp$72_coll$jscomp$14$$=$m__5372__auto__$jscomp$inline_2344_m__5374__auto__$jscomp$inline_2343$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2344_m__5374__auto__$jscomp$inline_2343$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$72_coll$jscomp$14$$):$m__5372__auto__$jscomp$inline_2344_m__5374__auto__$jscomp$inline_2343$$($JSCompiler_temp$jscomp$72_coll$jscomp$14$$);
else throw $APP.$cljs$core$missing_protocol$$("ISeq.-rest",$JSCompiler_temp$jscomp$72_coll$jscomp$14$$);}return $JSCompiler_temp$jscomp$72_coll$jscomp$14$$};$cljs$core$INext$$=function(){};
$cljs$core$_next$$=function($JSCompiler_temp$jscomp$73_coll$jscomp$16$$){if($JSCompiler_temp$jscomp$73_coll$jscomp$16$$!=null&&$JSCompiler_temp$jscomp$73_coll$jscomp$16$$.$cljs$core$INext$_next$arity$1$!=null)$JSCompiler_temp$jscomp$73_coll$jscomp$16$$=$JSCompiler_temp$jscomp$73_coll$jscomp$16$$.$cljs$core$INext$_next$arity$1$($JSCompiler_temp$jscomp$73_coll$jscomp$16$$);else{var $m__5372__auto__$jscomp$inline_2348_m__5374__auto__$jscomp$inline_2347$$=$cljs$core$_next$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$73_coll$jscomp$16$$==
null?null:$JSCompiler_temp$jscomp$73_coll$jscomp$16$$)];if($m__5372__auto__$jscomp$inline_2348_m__5374__auto__$jscomp$inline_2347$$!=null)$JSCompiler_temp$jscomp$73_coll$jscomp$16$$=$m__5372__auto__$jscomp$inline_2348_m__5374__auto__$jscomp$inline_2347$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2348_m__5374__auto__$jscomp$inline_2347$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$73_coll$jscomp$16$$):$m__5372__auto__$jscomp$inline_2348_m__5374__auto__$jscomp$inline_2347$$($JSCompiler_temp$jscomp$73_coll$jscomp$16$$);
else if($m__5372__auto__$jscomp$inline_2348_m__5374__auto__$jscomp$inline_2347$$=$cljs$core$_next$$._,$m__5372__auto__$jscomp$inline_2348_m__5374__auto__$jscomp$inline_2347$$!=null)$JSCompiler_temp$jscomp$73_coll$jscomp$16$$=$m__5372__auto__$jscomp$inline_2348_m__5374__auto__$jscomp$inline_2347$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2348_m__5374__auto__$jscomp$inline_2347$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$73_coll$jscomp$16$$):$m__5372__auto__$jscomp$inline_2348_m__5374__auto__$jscomp$inline_2347$$($JSCompiler_temp$jscomp$73_coll$jscomp$16$$);
else throw $APP.$cljs$core$missing_protocol$$("INext.-next",$JSCompiler_temp$jscomp$73_coll$jscomp$16$$);}return $JSCompiler_temp$jscomp$73_coll$jscomp$16$$};$cljs$core$ILookup$$=function(){};$cljs$core$IAssociative$$=function(){};
$APP.$cljs$core$_contains_key_QMARK_$$=function($JSCompiler_temp$jscomp$74_coll$jscomp$18$$,$k$jscomp$32$$){if($JSCompiler_temp$jscomp$74_coll$jscomp$18$$!=null&&$JSCompiler_temp$jscomp$74_coll$jscomp$18$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$!=null)$JSCompiler_temp$jscomp$74_coll$jscomp$18$$=$JSCompiler_temp$jscomp$74_coll$jscomp$18$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$($JSCompiler_temp$jscomp$74_coll$jscomp$18$$,$k$jscomp$32$$);else{var $m__5372__auto__$jscomp$inline_2353_m__5374__auto__$jscomp$inline_2352$$=
$APP.$cljs$core$_contains_key_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$74_coll$jscomp$18$$==null?null:$JSCompiler_temp$jscomp$74_coll$jscomp$18$$)];if($m__5372__auto__$jscomp$inline_2353_m__5374__auto__$jscomp$inline_2352$$!=null)$JSCompiler_temp$jscomp$74_coll$jscomp$18$$=$m__5372__auto__$jscomp$inline_2353_m__5374__auto__$jscomp$inline_2352$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2353_m__5374__auto__$jscomp$inline_2352$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$74_coll$jscomp$18$$,
$k$jscomp$32$$):$m__5372__auto__$jscomp$inline_2353_m__5374__auto__$jscomp$inline_2352$$($JSCompiler_temp$jscomp$74_coll$jscomp$18$$,$k$jscomp$32$$);else if($m__5372__auto__$jscomp$inline_2353_m__5374__auto__$jscomp$inline_2352$$=$APP.$cljs$core$_contains_key_QMARK_$$._,$m__5372__auto__$jscomp$inline_2353_m__5374__auto__$jscomp$inline_2352$$!=null)$JSCompiler_temp$jscomp$74_coll$jscomp$18$$=$m__5372__auto__$jscomp$inline_2353_m__5374__auto__$jscomp$inline_2352$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2353_m__5374__auto__$jscomp$inline_2352$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$74_coll$jscomp$18$$,
$k$jscomp$32$$):$m__5372__auto__$jscomp$inline_2353_m__5374__auto__$jscomp$inline_2352$$($JSCompiler_temp$jscomp$74_coll$jscomp$18$$,$k$jscomp$32$$);else throw $APP.$cljs$core$missing_protocol$$("IAssociative.-contains-key?",$JSCompiler_temp$jscomp$74_coll$jscomp$18$$);}return $JSCompiler_temp$jscomp$74_coll$jscomp$18$$};
$APP.$cljs$core$_assoc$$=function($JSCompiler_temp$jscomp$75_coll$jscomp$20$$,$k$jscomp$34$$,$v$jscomp$3$$){if($JSCompiler_temp$jscomp$75_coll$jscomp$20$$!=null&&$JSCompiler_temp$jscomp$75_coll$jscomp$20$$.$cljs$core$IAssociative$_assoc$arity$3$!=null)$JSCompiler_temp$jscomp$75_coll$jscomp$20$$=$JSCompiler_temp$jscomp$75_coll$jscomp$20$$.$cljs$core$IAssociative$_assoc$arity$3$($JSCompiler_temp$jscomp$75_coll$jscomp$20$$,$k$jscomp$34$$,$v$jscomp$3$$);else{var $m__5372__auto__$jscomp$inline_2359_m__5374__auto__$jscomp$inline_2358$$=
$APP.$cljs$core$_assoc$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$75_coll$jscomp$20$$==null?null:$JSCompiler_temp$jscomp$75_coll$jscomp$20$$)];if($m__5372__auto__$jscomp$inline_2359_m__5374__auto__$jscomp$inline_2358$$!=null)$JSCompiler_temp$jscomp$75_coll$jscomp$20$$=$m__5372__auto__$jscomp$inline_2359_m__5374__auto__$jscomp$inline_2358$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_2359_m__5374__auto__$jscomp$inline_2358$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$75_coll$jscomp$20$$,
$k$jscomp$34$$,$v$jscomp$3$$):$m__5372__auto__$jscomp$inline_2359_m__5374__auto__$jscomp$inline_2358$$($JSCompiler_temp$jscomp$75_coll$jscomp$20$$,$k$jscomp$34$$,$v$jscomp$3$$);else if($m__5372__auto__$jscomp$inline_2359_m__5374__auto__$jscomp$inline_2358$$=$APP.$cljs$core$_assoc$$._,$m__5372__auto__$jscomp$inline_2359_m__5374__auto__$jscomp$inline_2358$$!=null)$JSCompiler_temp$jscomp$75_coll$jscomp$20$$=$m__5372__auto__$jscomp$inline_2359_m__5374__auto__$jscomp$inline_2358$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_2359_m__5374__auto__$jscomp$inline_2358$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$75_coll$jscomp$20$$,$k$jscomp$34$$,$v$jscomp$3$$):$m__5372__auto__$jscomp$inline_2359_m__5374__auto__$jscomp$inline_2358$$($JSCompiler_temp$jscomp$75_coll$jscomp$20$$,$k$jscomp$34$$,$v$jscomp$3$$);else throw $APP.$cljs$core$missing_protocol$$("IAssociative.-assoc",$JSCompiler_temp$jscomp$75_coll$jscomp$20$$);}return $JSCompiler_temp$jscomp$75_coll$jscomp$20$$};
$cljs$core$IFind$$=function(){};
$cljs$core$_find$$=function($JSCompiler_temp$jscomp$76_coll$jscomp$22$$,$k$jscomp$36$$){if($JSCompiler_temp$jscomp$76_coll$jscomp$22$$!=null&&$JSCompiler_temp$jscomp$76_coll$jscomp$22$$.$cljs$core$IFind$_find$arity$2$!=null)$JSCompiler_temp$jscomp$76_coll$jscomp$22$$=$JSCompiler_temp$jscomp$76_coll$jscomp$22$$.$cljs$core$IFind$_find$arity$2$($JSCompiler_temp$jscomp$76_coll$jscomp$22$$,$k$jscomp$36$$);else{var $m__5372__auto__$jscomp$inline_2364_m__5374__auto__$jscomp$inline_2363$$=$cljs$core$_find$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$76_coll$jscomp$22$$==
null?null:$JSCompiler_temp$jscomp$76_coll$jscomp$22$$)];if($m__5372__auto__$jscomp$inline_2364_m__5374__auto__$jscomp$inline_2363$$!=null)$JSCompiler_temp$jscomp$76_coll$jscomp$22$$=$m__5372__auto__$jscomp$inline_2364_m__5374__auto__$jscomp$inline_2363$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2364_m__5374__auto__$jscomp$inline_2363$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$76_coll$jscomp$22$$,$k$jscomp$36$$):$m__5372__auto__$jscomp$inline_2364_m__5374__auto__$jscomp$inline_2363$$($JSCompiler_temp$jscomp$76_coll$jscomp$22$$,
$k$jscomp$36$$);else if($m__5372__auto__$jscomp$inline_2364_m__5374__auto__$jscomp$inline_2363$$=$cljs$core$_find$$._,$m__5372__auto__$jscomp$inline_2364_m__5374__auto__$jscomp$inline_2363$$!=null)$JSCompiler_temp$jscomp$76_coll$jscomp$22$$=$m__5372__auto__$jscomp$inline_2364_m__5374__auto__$jscomp$inline_2363$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2364_m__5374__auto__$jscomp$inline_2363$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$76_coll$jscomp$22$$,$k$jscomp$36$$):
$m__5372__auto__$jscomp$inline_2364_m__5374__auto__$jscomp$inline_2363$$($JSCompiler_temp$jscomp$76_coll$jscomp$22$$,$k$jscomp$36$$);else throw $APP.$cljs$core$missing_protocol$$("IFind.-find",$JSCompiler_temp$jscomp$76_coll$jscomp$22$$);}return $JSCompiler_temp$jscomp$76_coll$jscomp$22$$};$cljs$core$IMap$$=function(){};
$APP.$cljs$core$_dissoc$$=function($JSCompiler_temp$jscomp$77_coll$jscomp$24$$,$k$jscomp$38$$){if($JSCompiler_temp$jscomp$77_coll$jscomp$24$$!=null&&$JSCompiler_temp$jscomp$77_coll$jscomp$24$$.$cljs$core$IMap$_dissoc$arity$2$!=null)$JSCompiler_temp$jscomp$77_coll$jscomp$24$$=$JSCompiler_temp$jscomp$77_coll$jscomp$24$$.$cljs$core$IMap$_dissoc$arity$2$($JSCompiler_temp$jscomp$77_coll$jscomp$24$$,$k$jscomp$38$$);else{var $m__5372__auto__$jscomp$inline_2369_m__5374__auto__$jscomp$inline_2368$$=$APP.$cljs$core$_dissoc$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$77_coll$jscomp$24$$==
null?null:$JSCompiler_temp$jscomp$77_coll$jscomp$24$$)];if($m__5372__auto__$jscomp$inline_2369_m__5374__auto__$jscomp$inline_2368$$!=null)$JSCompiler_temp$jscomp$77_coll$jscomp$24$$=$m__5372__auto__$jscomp$inline_2369_m__5374__auto__$jscomp$inline_2368$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2369_m__5374__auto__$jscomp$inline_2368$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$77_coll$jscomp$24$$,$k$jscomp$38$$):$m__5372__auto__$jscomp$inline_2369_m__5374__auto__$jscomp$inline_2368$$($JSCompiler_temp$jscomp$77_coll$jscomp$24$$,
$k$jscomp$38$$);else if($m__5372__auto__$jscomp$inline_2369_m__5374__auto__$jscomp$inline_2368$$=$APP.$cljs$core$_dissoc$$._,$m__5372__auto__$jscomp$inline_2369_m__5374__auto__$jscomp$inline_2368$$!=null)$JSCompiler_temp$jscomp$77_coll$jscomp$24$$=$m__5372__auto__$jscomp$inline_2369_m__5374__auto__$jscomp$inline_2368$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2369_m__5374__auto__$jscomp$inline_2368$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$77_coll$jscomp$24$$,
$k$jscomp$38$$):$m__5372__auto__$jscomp$inline_2369_m__5374__auto__$jscomp$inline_2368$$($JSCompiler_temp$jscomp$77_coll$jscomp$24$$,$k$jscomp$38$$);else throw $APP.$cljs$core$missing_protocol$$("IMap.-dissoc",$JSCompiler_temp$jscomp$77_coll$jscomp$24$$);}return $JSCompiler_temp$jscomp$77_coll$jscomp$24$$};
$APP.$cljs$core$_key$$=function($JSCompiler_temp$jscomp$78_coll$jscomp$26$$){if($JSCompiler_temp$jscomp$78_coll$jscomp$26$$!=null&&$JSCompiler_temp$jscomp$78_coll$jscomp$26$$.$cljs$core$IMapEntry$_key$arity$1$!=null)$JSCompiler_temp$jscomp$78_coll$jscomp$26$$=$JSCompiler_temp$jscomp$78_coll$jscomp$26$$.key;else{var $m__5372__auto__$jscomp$inline_2373_m__5374__auto__$jscomp$inline_2372$$=$APP.$cljs$core$_key$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$78_coll$jscomp$26$$==null?null:$JSCompiler_temp$jscomp$78_coll$jscomp$26$$)];
if($m__5372__auto__$jscomp$inline_2373_m__5374__auto__$jscomp$inline_2372$$!=null)$JSCompiler_temp$jscomp$78_coll$jscomp$26$$=$m__5372__auto__$jscomp$inline_2373_m__5374__auto__$jscomp$inline_2372$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2373_m__5374__auto__$jscomp$inline_2372$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$78_coll$jscomp$26$$):$m__5372__auto__$jscomp$inline_2373_m__5374__auto__$jscomp$inline_2372$$($JSCompiler_temp$jscomp$78_coll$jscomp$26$$);else if($m__5372__auto__$jscomp$inline_2373_m__5374__auto__$jscomp$inline_2372$$=
$APP.$cljs$core$_key$$._,$m__5372__auto__$jscomp$inline_2373_m__5374__auto__$jscomp$inline_2372$$!=null)$JSCompiler_temp$jscomp$78_coll$jscomp$26$$=$m__5372__auto__$jscomp$inline_2373_m__5374__auto__$jscomp$inline_2372$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2373_m__5374__auto__$jscomp$inline_2372$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$78_coll$jscomp$26$$):$m__5372__auto__$jscomp$inline_2373_m__5374__auto__$jscomp$inline_2372$$($JSCompiler_temp$jscomp$78_coll$jscomp$26$$);
else throw $APP.$cljs$core$missing_protocol$$("IMapEntry.-key",$JSCompiler_temp$jscomp$78_coll$jscomp$26$$);}return $JSCompiler_temp$jscomp$78_coll$jscomp$26$$};
$APP.$cljs$core$_val$$=function($JSCompiler_temp$jscomp$79_coll$jscomp$28$$){if($JSCompiler_temp$jscomp$79_coll$jscomp$28$$!=null&&$JSCompiler_temp$jscomp$79_coll$jscomp$28$$.$cljs$core$IMapEntry$_val$arity$1$!=null)$JSCompiler_temp$jscomp$79_coll$jscomp$28$$=$JSCompiler_temp$jscomp$79_coll$jscomp$28$$.$cljs$core$IMapEntry$_val$arity$1$($JSCompiler_temp$jscomp$79_coll$jscomp$28$$);else{var $m__5372__auto__$jscomp$inline_2377_m__5374__auto__$jscomp$inline_2376$$=$APP.$cljs$core$_val$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$79_coll$jscomp$28$$==
null?null:$JSCompiler_temp$jscomp$79_coll$jscomp$28$$)];if($m__5372__auto__$jscomp$inline_2377_m__5374__auto__$jscomp$inline_2376$$!=null)$JSCompiler_temp$jscomp$79_coll$jscomp$28$$=$m__5372__auto__$jscomp$inline_2377_m__5374__auto__$jscomp$inline_2376$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2377_m__5374__auto__$jscomp$inline_2376$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$79_coll$jscomp$28$$):$m__5372__auto__$jscomp$inline_2377_m__5374__auto__$jscomp$inline_2376$$($JSCompiler_temp$jscomp$79_coll$jscomp$28$$);
else if($m__5372__auto__$jscomp$inline_2377_m__5374__auto__$jscomp$inline_2376$$=$APP.$cljs$core$_val$$._,$m__5372__auto__$jscomp$inline_2377_m__5374__auto__$jscomp$inline_2376$$!=null)$JSCompiler_temp$jscomp$79_coll$jscomp$28$$=$m__5372__auto__$jscomp$inline_2377_m__5374__auto__$jscomp$inline_2376$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2377_m__5374__auto__$jscomp$inline_2376$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$79_coll$jscomp$28$$):$m__5372__auto__$jscomp$inline_2377_m__5374__auto__$jscomp$inline_2376$$($JSCompiler_temp$jscomp$79_coll$jscomp$28$$);
else throw $APP.$cljs$core$missing_protocol$$("IMapEntry.-val",$JSCompiler_temp$jscomp$79_coll$jscomp$28$$);}return $JSCompiler_temp$jscomp$79_coll$jscomp$28$$};$cljs$core$ISet$$=function(){};
$cljs$core$_disjoin$$=function($JSCompiler_temp$jscomp$80_coll$jscomp$30$$,$v$jscomp$5$$){if($JSCompiler_temp$jscomp$80_coll$jscomp$30$$!=null&&$JSCompiler_temp$jscomp$80_coll$jscomp$30$$.$cljs$core$ISet$_disjoin$arity$2$!=null)$JSCompiler_temp$jscomp$80_coll$jscomp$30$$=$JSCompiler_temp$jscomp$80_coll$jscomp$30$$.$cljs$core$ISet$_disjoin$arity$2$($JSCompiler_temp$jscomp$80_coll$jscomp$30$$,$v$jscomp$5$$);else{var $m__5372__auto__$jscomp$inline_2382_m__5374__auto__$jscomp$inline_2381$$=$cljs$core$_disjoin$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$80_coll$jscomp$30$$==
null?null:$JSCompiler_temp$jscomp$80_coll$jscomp$30$$)];if($m__5372__auto__$jscomp$inline_2382_m__5374__auto__$jscomp$inline_2381$$!=null)$JSCompiler_temp$jscomp$80_coll$jscomp$30$$=$m__5372__auto__$jscomp$inline_2382_m__5374__auto__$jscomp$inline_2381$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2382_m__5374__auto__$jscomp$inline_2381$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$80_coll$jscomp$30$$,$v$jscomp$5$$):$m__5372__auto__$jscomp$inline_2382_m__5374__auto__$jscomp$inline_2381$$($JSCompiler_temp$jscomp$80_coll$jscomp$30$$,
$v$jscomp$5$$);else if($m__5372__auto__$jscomp$inline_2382_m__5374__auto__$jscomp$inline_2381$$=$cljs$core$_disjoin$$._,$m__5372__auto__$jscomp$inline_2382_m__5374__auto__$jscomp$inline_2381$$!=null)$JSCompiler_temp$jscomp$80_coll$jscomp$30$$=$m__5372__auto__$jscomp$inline_2382_m__5374__auto__$jscomp$inline_2381$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2382_m__5374__auto__$jscomp$inline_2381$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$80_coll$jscomp$30$$,$v$jscomp$5$$):
$m__5372__auto__$jscomp$inline_2382_m__5374__auto__$jscomp$inline_2381$$($JSCompiler_temp$jscomp$80_coll$jscomp$30$$,$v$jscomp$5$$);else throw $APP.$cljs$core$missing_protocol$$("ISet.-disjoin",$JSCompiler_temp$jscomp$80_coll$jscomp$30$$);}return $JSCompiler_temp$jscomp$80_coll$jscomp$30$$};
$cljs$core$_peek$$=function($JSCompiler_temp$jscomp$81_coll$jscomp$32$$){if($JSCompiler_temp$jscomp$81_coll$jscomp$32$$!=null&&$JSCompiler_temp$jscomp$81_coll$jscomp$32$$.$cljs$core$IStack$_peek$arity$1$!=null)$JSCompiler_temp$jscomp$81_coll$jscomp$32$$=$JSCompiler_temp$jscomp$81_coll$jscomp$32$$.$cljs$core$IStack$_peek$arity$1$($JSCompiler_temp$jscomp$81_coll$jscomp$32$$);else{var $m__5372__auto__$jscomp$inline_2386_m__5374__auto__$jscomp$inline_2385$$=$cljs$core$_peek$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$81_coll$jscomp$32$$==
null?null:$JSCompiler_temp$jscomp$81_coll$jscomp$32$$)];if($m__5372__auto__$jscomp$inline_2386_m__5374__auto__$jscomp$inline_2385$$!=null)$JSCompiler_temp$jscomp$81_coll$jscomp$32$$=$m__5372__auto__$jscomp$inline_2386_m__5374__auto__$jscomp$inline_2385$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2386_m__5374__auto__$jscomp$inline_2385$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$81_coll$jscomp$32$$):$m__5372__auto__$jscomp$inline_2386_m__5374__auto__$jscomp$inline_2385$$($JSCompiler_temp$jscomp$81_coll$jscomp$32$$);
else if($m__5372__auto__$jscomp$inline_2386_m__5374__auto__$jscomp$inline_2385$$=$cljs$core$_peek$$._,$m__5372__auto__$jscomp$inline_2386_m__5374__auto__$jscomp$inline_2385$$!=null)$JSCompiler_temp$jscomp$81_coll$jscomp$32$$=$m__5372__auto__$jscomp$inline_2386_m__5374__auto__$jscomp$inline_2385$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2386_m__5374__auto__$jscomp$inline_2385$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$81_coll$jscomp$32$$):$m__5372__auto__$jscomp$inline_2386_m__5374__auto__$jscomp$inline_2385$$($JSCompiler_temp$jscomp$81_coll$jscomp$32$$);
else throw $APP.$cljs$core$missing_protocol$$("IStack.-peek",$JSCompiler_temp$jscomp$81_coll$jscomp$32$$);}return $JSCompiler_temp$jscomp$81_coll$jscomp$32$$};
$cljs$core$_pop$$=function($JSCompiler_temp$jscomp$82_coll$jscomp$34$$){if($JSCompiler_temp$jscomp$82_coll$jscomp$34$$!=null&&$JSCompiler_temp$jscomp$82_coll$jscomp$34$$.$cljs$core$IStack$_pop$arity$1$!=null)$JSCompiler_temp$jscomp$82_coll$jscomp$34$$=$JSCompiler_temp$jscomp$82_coll$jscomp$34$$.$cljs$core$IStack$_pop$arity$1$($JSCompiler_temp$jscomp$82_coll$jscomp$34$$);else{var $m__5372__auto__$jscomp$inline_2390_m__5374__auto__$jscomp$inline_2389$$=$cljs$core$_pop$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$82_coll$jscomp$34$$==
null?null:$JSCompiler_temp$jscomp$82_coll$jscomp$34$$)];if($m__5372__auto__$jscomp$inline_2390_m__5374__auto__$jscomp$inline_2389$$!=null)$JSCompiler_temp$jscomp$82_coll$jscomp$34$$=$m__5372__auto__$jscomp$inline_2390_m__5374__auto__$jscomp$inline_2389$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2390_m__5374__auto__$jscomp$inline_2389$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$82_coll$jscomp$34$$):$m__5372__auto__$jscomp$inline_2390_m__5374__auto__$jscomp$inline_2389$$($JSCompiler_temp$jscomp$82_coll$jscomp$34$$);
else if($m__5372__auto__$jscomp$inline_2390_m__5374__auto__$jscomp$inline_2389$$=$cljs$core$_pop$$._,$m__5372__auto__$jscomp$inline_2390_m__5374__auto__$jscomp$inline_2389$$!=null)$JSCompiler_temp$jscomp$82_coll$jscomp$34$$=$m__5372__auto__$jscomp$inline_2390_m__5374__auto__$jscomp$inline_2389$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2390_m__5374__auto__$jscomp$inline_2389$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$82_coll$jscomp$34$$):$m__5372__auto__$jscomp$inline_2390_m__5374__auto__$jscomp$inline_2389$$($JSCompiler_temp$jscomp$82_coll$jscomp$34$$);
else throw $APP.$cljs$core$missing_protocol$$("IStack.-pop",$JSCompiler_temp$jscomp$82_coll$jscomp$34$$);}return $JSCompiler_temp$jscomp$82_coll$jscomp$34$$};$cljs$core$IVector$$=function(){};
$cljs$core$_assoc_n$$=function($JSCompiler_temp$jscomp$83_coll$jscomp$36$$,$n$jscomp$31$$,$val$jscomp$45$$){if($JSCompiler_temp$jscomp$83_coll$jscomp$36$$!=null&&$JSCompiler_temp$jscomp$83_coll$jscomp$36$$.$cljs$core$IVector$_assoc_n$arity$3$!=null)$JSCompiler_temp$jscomp$83_coll$jscomp$36$$=$JSCompiler_temp$jscomp$83_coll$jscomp$36$$.$cljs$core$IVector$_assoc_n$arity$3$($JSCompiler_temp$jscomp$83_coll$jscomp$36$$,$n$jscomp$31$$,$val$jscomp$45$$);else{var $m__5372__auto__$jscomp$inline_2396_m__5374__auto__$jscomp$inline_2395$$=
$cljs$core$_assoc_n$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$83_coll$jscomp$36$$==null?null:$JSCompiler_temp$jscomp$83_coll$jscomp$36$$)];if($m__5372__auto__$jscomp$inline_2396_m__5374__auto__$jscomp$inline_2395$$!=null)$JSCompiler_temp$jscomp$83_coll$jscomp$36$$=$m__5372__auto__$jscomp$inline_2396_m__5374__auto__$jscomp$inline_2395$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_2396_m__5374__auto__$jscomp$inline_2395$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$83_coll$jscomp$36$$,
$n$jscomp$31$$,$val$jscomp$45$$):$m__5372__auto__$jscomp$inline_2396_m__5374__auto__$jscomp$inline_2395$$($JSCompiler_temp$jscomp$83_coll$jscomp$36$$,$n$jscomp$31$$,$val$jscomp$45$$);else if($m__5372__auto__$jscomp$inline_2396_m__5374__auto__$jscomp$inline_2395$$=$cljs$core$_assoc_n$$._,$m__5372__auto__$jscomp$inline_2396_m__5374__auto__$jscomp$inline_2395$$!=null)$JSCompiler_temp$jscomp$83_coll$jscomp$36$$=$m__5372__auto__$jscomp$inline_2396_m__5374__auto__$jscomp$inline_2395$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_2396_m__5374__auto__$jscomp$inline_2395$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$83_coll$jscomp$36$$,$n$jscomp$31$$,$val$jscomp$45$$):$m__5372__auto__$jscomp$inline_2396_m__5374__auto__$jscomp$inline_2395$$($JSCompiler_temp$jscomp$83_coll$jscomp$36$$,$n$jscomp$31$$,$val$jscomp$45$$);else throw $APP.$cljs$core$missing_protocol$$("IVector.-assoc-n",$JSCompiler_temp$jscomp$83_coll$jscomp$36$$);}return $JSCompiler_temp$jscomp$83_coll$jscomp$36$$};
$APP.$cljs$core$IDeref$$=function(){};
$APP.$cljs$core$_deref$$=function($JSCompiler_temp$jscomp$84_o$jscomp$25$$){if($JSCompiler_temp$jscomp$84_o$jscomp$25$$!=null&&$JSCompiler_temp$jscomp$84_o$jscomp$25$$.$cljs$core$IDeref$_deref$arity$1$!=null)$JSCompiler_temp$jscomp$84_o$jscomp$25$$=$JSCompiler_temp$jscomp$84_o$jscomp$25$$.$cljs$core$IDeref$_deref$arity$1$($JSCompiler_temp$jscomp$84_o$jscomp$25$$);else{var $m__5372__auto__$jscomp$inline_2400_m__5374__auto__$jscomp$inline_2399$$=$APP.$cljs$core$_deref$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$84_o$jscomp$25$$==null?
null:$JSCompiler_temp$jscomp$84_o$jscomp$25$$)];if($m__5372__auto__$jscomp$inline_2400_m__5374__auto__$jscomp$inline_2399$$!=null)$JSCompiler_temp$jscomp$84_o$jscomp$25$$=$m__5372__auto__$jscomp$inline_2400_m__5374__auto__$jscomp$inline_2399$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2400_m__5374__auto__$jscomp$inline_2399$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$84_o$jscomp$25$$):$m__5372__auto__$jscomp$inline_2400_m__5374__auto__$jscomp$inline_2399$$($JSCompiler_temp$jscomp$84_o$jscomp$25$$);
else if($m__5372__auto__$jscomp$inline_2400_m__5374__auto__$jscomp$inline_2399$$=$APP.$cljs$core$_deref$$._,$m__5372__auto__$jscomp$inline_2400_m__5374__auto__$jscomp$inline_2399$$!=null)$JSCompiler_temp$jscomp$84_o$jscomp$25$$=$m__5372__auto__$jscomp$inline_2400_m__5374__auto__$jscomp$inline_2399$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2400_m__5374__auto__$jscomp$inline_2399$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$84_o$jscomp$25$$):$m__5372__auto__$jscomp$inline_2400_m__5374__auto__$jscomp$inline_2399$$($JSCompiler_temp$jscomp$84_o$jscomp$25$$);
else throw $APP.$cljs$core$missing_protocol$$("IDeref.-deref",$JSCompiler_temp$jscomp$84_o$jscomp$25$$);}return $JSCompiler_temp$jscomp$84_o$jscomp$25$$};$APP.$cljs$core$IMeta$$=function(){};
$cljs$core$_meta$$=function($JSCompiler_temp$jscomp$85_o$jscomp$29$$){if($JSCompiler_temp$jscomp$85_o$jscomp$29$$!=null&&$JSCompiler_temp$jscomp$85_o$jscomp$29$$.$cljs$core$IMeta$_meta$arity$1$!=null)$JSCompiler_temp$jscomp$85_o$jscomp$29$$=$JSCompiler_temp$jscomp$85_o$jscomp$29$$.$cljs$core$IMeta$_meta$arity$1$($JSCompiler_temp$jscomp$85_o$jscomp$29$$);else{var $m__5372__auto__$jscomp$inline_2404_m__5374__auto__$jscomp$inline_2403$$=$cljs$core$_meta$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$85_o$jscomp$29$$==
null?null:$JSCompiler_temp$jscomp$85_o$jscomp$29$$)];if($m__5372__auto__$jscomp$inline_2404_m__5374__auto__$jscomp$inline_2403$$!=null)$JSCompiler_temp$jscomp$85_o$jscomp$29$$=$m__5372__auto__$jscomp$inline_2404_m__5374__auto__$jscomp$inline_2403$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2404_m__5374__auto__$jscomp$inline_2403$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$85_o$jscomp$29$$):$m__5372__auto__$jscomp$inline_2404_m__5374__auto__$jscomp$inline_2403$$($JSCompiler_temp$jscomp$85_o$jscomp$29$$);
else if($m__5372__auto__$jscomp$inline_2404_m__5374__auto__$jscomp$inline_2403$$=$cljs$core$_meta$$._,$m__5372__auto__$jscomp$inline_2404_m__5374__auto__$jscomp$inline_2403$$!=null)$JSCompiler_temp$jscomp$85_o$jscomp$29$$=$m__5372__auto__$jscomp$inline_2404_m__5374__auto__$jscomp$inline_2403$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2404_m__5374__auto__$jscomp$inline_2403$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$85_o$jscomp$29$$):$m__5372__auto__$jscomp$inline_2404_m__5374__auto__$jscomp$inline_2403$$($JSCompiler_temp$jscomp$85_o$jscomp$29$$);
else throw $APP.$cljs$core$missing_protocol$$("IMeta.-meta",$JSCompiler_temp$jscomp$85_o$jscomp$29$$);}return $JSCompiler_temp$jscomp$85_o$jscomp$29$$};$APP.$cljs$core$IWithMeta$$=function(){};
$APP.$cljs$core$_with_meta$$=function($JSCompiler_temp$jscomp$86_o$jscomp$31$$,$meta$jscomp$1$$){if($JSCompiler_temp$jscomp$86_o$jscomp$31$$!=null&&$JSCompiler_temp$jscomp$86_o$jscomp$31$$.$cljs$core$IWithMeta$_with_meta$arity$2$!=null)$JSCompiler_temp$jscomp$86_o$jscomp$31$$=$JSCompiler_temp$jscomp$86_o$jscomp$31$$.$cljs$core$IWithMeta$_with_meta$arity$2$($JSCompiler_temp$jscomp$86_o$jscomp$31$$,$meta$jscomp$1$$);else{var $m__5372__auto__$jscomp$inline_2409_m__5374__auto__$jscomp$inline_2408$$=$APP.$cljs$core$_with_meta$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$86_o$jscomp$31$$==
null?null:$JSCompiler_temp$jscomp$86_o$jscomp$31$$)];if($m__5372__auto__$jscomp$inline_2409_m__5374__auto__$jscomp$inline_2408$$!=null)$JSCompiler_temp$jscomp$86_o$jscomp$31$$=$m__5372__auto__$jscomp$inline_2409_m__5374__auto__$jscomp$inline_2408$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2409_m__5374__auto__$jscomp$inline_2408$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$86_o$jscomp$31$$,$meta$jscomp$1$$):$m__5372__auto__$jscomp$inline_2409_m__5374__auto__$jscomp$inline_2408$$($JSCompiler_temp$jscomp$86_o$jscomp$31$$,
$meta$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_2409_m__5374__auto__$jscomp$inline_2408$$=$APP.$cljs$core$_with_meta$$._,$m__5372__auto__$jscomp$inline_2409_m__5374__auto__$jscomp$inline_2408$$!=null)$JSCompiler_temp$jscomp$86_o$jscomp$31$$=$m__5372__auto__$jscomp$inline_2409_m__5374__auto__$jscomp$inline_2408$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2409_m__5374__auto__$jscomp$inline_2408$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$86_o$jscomp$31$$,
$meta$jscomp$1$$):$m__5372__auto__$jscomp$inline_2409_m__5374__auto__$jscomp$inline_2408$$($JSCompiler_temp$jscomp$86_o$jscomp$31$$,$meta$jscomp$1$$);else throw $APP.$cljs$core$missing_protocol$$("IWithMeta.-with-meta",$JSCompiler_temp$jscomp$86_o$jscomp$31$$);}return $JSCompiler_temp$jscomp$86_o$jscomp$31$$};$cljs$core$IReduce$$=function(){};$cljs$core$IKVReduce$$=function(){};
$APP.$cljs$core$_kv_reduce$$=function($JSCompiler_temp$jscomp$87_coll$jscomp$43$$,$f$jscomp$87$$,$init$jscomp$20$$){if($JSCompiler_temp$jscomp$87_coll$jscomp$43$$!=null&&$JSCompiler_temp$jscomp$87_coll$jscomp$43$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$!=null)$JSCompiler_temp$jscomp$87_coll$jscomp$43$$=$JSCompiler_temp$jscomp$87_coll$jscomp$43$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$($JSCompiler_temp$jscomp$87_coll$jscomp$43$$,$f$jscomp$87$$,$init$jscomp$20$$);else{var $m__5372__auto__$jscomp$inline_2415_m__5374__auto__$jscomp$inline_2414$$=
$APP.$cljs$core$_kv_reduce$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$87_coll$jscomp$43$$==null?null:$JSCompiler_temp$jscomp$87_coll$jscomp$43$$)];if($m__5372__auto__$jscomp$inline_2415_m__5374__auto__$jscomp$inline_2414$$!=null)$JSCompiler_temp$jscomp$87_coll$jscomp$43$$=$m__5372__auto__$jscomp$inline_2415_m__5374__auto__$jscomp$inline_2414$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_2415_m__5374__auto__$jscomp$inline_2414$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$87_coll$jscomp$43$$,
$f$jscomp$87$$,$init$jscomp$20$$):$m__5372__auto__$jscomp$inline_2415_m__5374__auto__$jscomp$inline_2414$$($JSCompiler_temp$jscomp$87_coll$jscomp$43$$,$f$jscomp$87$$,$init$jscomp$20$$);else if($m__5372__auto__$jscomp$inline_2415_m__5374__auto__$jscomp$inline_2414$$=$APP.$cljs$core$_kv_reduce$$._,$m__5372__auto__$jscomp$inline_2415_m__5374__auto__$jscomp$inline_2414$$!=null)$JSCompiler_temp$jscomp$87_coll$jscomp$43$$=$m__5372__auto__$jscomp$inline_2415_m__5374__auto__$jscomp$inline_2414$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_2415_m__5374__auto__$jscomp$inline_2414$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$87_coll$jscomp$43$$,$f$jscomp$87$$,$init$jscomp$20$$):$m__5372__auto__$jscomp$inline_2415_m__5374__auto__$jscomp$inline_2414$$($JSCompiler_temp$jscomp$87_coll$jscomp$43$$,$f$jscomp$87$$,$init$jscomp$20$$);else throw $APP.$cljs$core$missing_protocol$$("IKVReduce.-kv-reduce",$JSCompiler_temp$jscomp$87_coll$jscomp$43$$);}return $JSCompiler_temp$jscomp$87_coll$jscomp$43$$};
$cljs$core$_equiv$$=function($JSCompiler_temp$jscomp$88_o$jscomp$33$$,$other$jscomp$45$$){if($JSCompiler_temp$jscomp$88_o$jscomp$33$$!=null&&$JSCompiler_temp$jscomp$88_o$jscomp$33$$.$cljs$core$IEquiv$_equiv$arity$2$!=null)$JSCompiler_temp$jscomp$88_o$jscomp$33$$=$JSCompiler_temp$jscomp$88_o$jscomp$33$$.$cljs$core$IEquiv$_equiv$arity$2$($JSCompiler_temp$jscomp$88_o$jscomp$33$$,$other$jscomp$45$$);else{var $m__5372__auto__$jscomp$inline_2420_m__5374__auto__$jscomp$inline_2419$$=$cljs$core$_equiv$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$88_o$jscomp$33$$==
null?null:$JSCompiler_temp$jscomp$88_o$jscomp$33$$)];if($m__5372__auto__$jscomp$inline_2420_m__5374__auto__$jscomp$inline_2419$$!=null)$JSCompiler_temp$jscomp$88_o$jscomp$33$$=$m__5372__auto__$jscomp$inline_2420_m__5374__auto__$jscomp$inline_2419$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2420_m__5374__auto__$jscomp$inline_2419$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$88_o$jscomp$33$$,$other$jscomp$45$$):$m__5372__auto__$jscomp$inline_2420_m__5374__auto__$jscomp$inline_2419$$($JSCompiler_temp$jscomp$88_o$jscomp$33$$,
$other$jscomp$45$$);else if($m__5372__auto__$jscomp$inline_2420_m__5374__auto__$jscomp$inline_2419$$=$cljs$core$_equiv$$._,$m__5372__auto__$jscomp$inline_2420_m__5374__auto__$jscomp$inline_2419$$!=null)$JSCompiler_temp$jscomp$88_o$jscomp$33$$=$m__5372__auto__$jscomp$inline_2420_m__5374__auto__$jscomp$inline_2419$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2420_m__5374__auto__$jscomp$inline_2419$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$88_o$jscomp$33$$,$other$jscomp$45$$):
$m__5372__auto__$jscomp$inline_2420_m__5374__auto__$jscomp$inline_2419$$($JSCompiler_temp$jscomp$88_o$jscomp$33$$,$other$jscomp$45$$);else throw $APP.$cljs$core$missing_protocol$$("IEquiv.-equiv",$JSCompiler_temp$jscomp$88_o$jscomp$33$$);}return $JSCompiler_temp$jscomp$88_o$jscomp$33$$};
$APP.$cljs$core$_hash$$=function($JSCompiler_temp$jscomp$89_o$jscomp$35$$){if($JSCompiler_temp$jscomp$89_o$jscomp$35$$!=null&&$JSCompiler_temp$jscomp$89_o$jscomp$35$$.$cljs$core$IHash$_hash$arity$1$!=null)$JSCompiler_temp$jscomp$89_o$jscomp$35$$=$JSCompiler_temp$jscomp$89_o$jscomp$35$$.$cljs$core$IHash$_hash$arity$1$($JSCompiler_temp$jscomp$89_o$jscomp$35$$);else{var $m__5372__auto__$jscomp$inline_2424_m__5374__auto__$jscomp$inline_2423$$=$APP.$cljs$core$_hash$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$89_o$jscomp$35$$==
null?null:$JSCompiler_temp$jscomp$89_o$jscomp$35$$)];if($m__5372__auto__$jscomp$inline_2424_m__5374__auto__$jscomp$inline_2423$$!=null)$JSCompiler_temp$jscomp$89_o$jscomp$35$$=$m__5372__auto__$jscomp$inline_2424_m__5374__auto__$jscomp$inline_2423$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2424_m__5374__auto__$jscomp$inline_2423$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$89_o$jscomp$35$$):$m__5372__auto__$jscomp$inline_2424_m__5374__auto__$jscomp$inline_2423$$($JSCompiler_temp$jscomp$89_o$jscomp$35$$);
else if($m__5372__auto__$jscomp$inline_2424_m__5374__auto__$jscomp$inline_2423$$=$APP.$cljs$core$_hash$$._,$m__5372__auto__$jscomp$inline_2424_m__5374__auto__$jscomp$inline_2423$$!=null)$JSCompiler_temp$jscomp$89_o$jscomp$35$$=$m__5372__auto__$jscomp$inline_2424_m__5374__auto__$jscomp$inline_2423$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2424_m__5374__auto__$jscomp$inline_2423$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$89_o$jscomp$35$$):$m__5372__auto__$jscomp$inline_2424_m__5374__auto__$jscomp$inline_2423$$($JSCompiler_temp$jscomp$89_o$jscomp$35$$);
else throw $APP.$cljs$core$missing_protocol$$("IHash.-hash",$JSCompiler_temp$jscomp$89_o$jscomp$35$$);}return $JSCompiler_temp$jscomp$89_o$jscomp$35$$};$cljs$core$ISeqable$$=function(){};
$cljs$core$_seq$$=function($JSCompiler_temp$jscomp$90_o$jscomp$37$$){if($JSCompiler_temp$jscomp$90_o$jscomp$37$$!=null&&$JSCompiler_temp$jscomp$90_o$jscomp$37$$.$cljs$core$ISeqable$_seq$arity$1$!=null)$JSCompiler_temp$jscomp$90_o$jscomp$37$$=$JSCompiler_temp$jscomp$90_o$jscomp$37$$.$cljs$core$ISeqable$_seq$arity$1$($JSCompiler_temp$jscomp$90_o$jscomp$37$$);else{var $m__5372__auto__$jscomp$inline_2428_m__5374__auto__$jscomp$inline_2427$$=$cljs$core$_seq$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$90_o$jscomp$37$$==
null?null:$JSCompiler_temp$jscomp$90_o$jscomp$37$$)];if($m__5372__auto__$jscomp$inline_2428_m__5374__auto__$jscomp$inline_2427$$!=null)$JSCompiler_temp$jscomp$90_o$jscomp$37$$=$m__5372__auto__$jscomp$inline_2428_m__5374__auto__$jscomp$inline_2427$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2428_m__5374__auto__$jscomp$inline_2427$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$90_o$jscomp$37$$):$m__5372__auto__$jscomp$inline_2428_m__5374__auto__$jscomp$inline_2427$$($JSCompiler_temp$jscomp$90_o$jscomp$37$$);
else if($m__5372__auto__$jscomp$inline_2428_m__5374__auto__$jscomp$inline_2427$$=$cljs$core$_seq$$._,$m__5372__auto__$jscomp$inline_2428_m__5374__auto__$jscomp$inline_2427$$!=null)$JSCompiler_temp$jscomp$90_o$jscomp$37$$=$m__5372__auto__$jscomp$inline_2428_m__5374__auto__$jscomp$inline_2427$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2428_m__5374__auto__$jscomp$inline_2427$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$90_o$jscomp$37$$):$m__5372__auto__$jscomp$inline_2428_m__5374__auto__$jscomp$inline_2427$$($JSCompiler_temp$jscomp$90_o$jscomp$37$$);
else throw $APP.$cljs$core$missing_protocol$$("ISeqable.-seq",$JSCompiler_temp$jscomp$90_o$jscomp$37$$);}return $JSCompiler_temp$jscomp$90_o$jscomp$37$$};$cljs$core$ISequential$$=function(){};$cljs$core$IList$$=function(){};$cljs$core$IRecord$$=function(){};$cljs$core$IReversible$$=function(){};
$APP.$cljs$core$_rseq$$=function($JSCompiler_temp$jscomp$91_coll$jscomp$45$$){if($JSCompiler_temp$jscomp$91_coll$jscomp$45$$!=null&&$JSCompiler_temp$jscomp$91_coll$jscomp$45$$.$cljs$core$IReversible$_rseq$arity$1$!=null)$JSCompiler_temp$jscomp$91_coll$jscomp$45$$=$JSCompiler_temp$jscomp$91_coll$jscomp$45$$.$cljs$core$IReversible$_rseq$arity$1$($JSCompiler_temp$jscomp$91_coll$jscomp$45$$);else{var $m__5372__auto__$jscomp$inline_2432_m__5374__auto__$jscomp$inline_2431$$=$APP.$cljs$core$_rseq$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$91_coll$jscomp$45$$==
null?null:$JSCompiler_temp$jscomp$91_coll$jscomp$45$$)];if($m__5372__auto__$jscomp$inline_2432_m__5374__auto__$jscomp$inline_2431$$!=null)$JSCompiler_temp$jscomp$91_coll$jscomp$45$$=$m__5372__auto__$jscomp$inline_2432_m__5374__auto__$jscomp$inline_2431$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2432_m__5374__auto__$jscomp$inline_2431$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$91_coll$jscomp$45$$):$m__5372__auto__$jscomp$inline_2432_m__5374__auto__$jscomp$inline_2431$$($JSCompiler_temp$jscomp$91_coll$jscomp$45$$);
else if($m__5372__auto__$jscomp$inline_2432_m__5374__auto__$jscomp$inline_2431$$=$APP.$cljs$core$_rseq$$._,$m__5372__auto__$jscomp$inline_2432_m__5374__auto__$jscomp$inline_2431$$!=null)$JSCompiler_temp$jscomp$91_coll$jscomp$45$$=$m__5372__auto__$jscomp$inline_2432_m__5374__auto__$jscomp$inline_2431$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2432_m__5374__auto__$jscomp$inline_2431$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$91_coll$jscomp$45$$):$m__5372__auto__$jscomp$inline_2432_m__5374__auto__$jscomp$inline_2431$$($JSCompiler_temp$jscomp$91_coll$jscomp$45$$);
else throw $APP.$cljs$core$missing_protocol$$("IReversible.-rseq",$JSCompiler_temp$jscomp$91_coll$jscomp$45$$);}return $JSCompiler_temp$jscomp$91_coll$jscomp$45$$};
$APP.$cljs$core$_write$$=function($JSCompiler_temp$jscomp$92_writer$jscomp$1$$,$s$jscomp$30$$){if($JSCompiler_temp$jscomp$92_writer$jscomp$1$$!=null&&$JSCompiler_temp$jscomp$92_writer$jscomp$1$$.$cljs$core$IWriter$_write$arity$2$!=null)$JSCompiler_temp$jscomp$92_writer$jscomp$1$$=$JSCompiler_temp$jscomp$92_writer$jscomp$1$$.$cljs$core$IWriter$_write$arity$2$($JSCompiler_temp$jscomp$92_writer$jscomp$1$$,$s$jscomp$30$$);else{var $m__5372__auto__$jscomp$inline_2437_m__5374__auto__$jscomp$inline_2436$$=
$APP.$cljs$core$_write$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$92_writer$jscomp$1$$==null?null:$JSCompiler_temp$jscomp$92_writer$jscomp$1$$)];if($m__5372__auto__$jscomp$inline_2437_m__5374__auto__$jscomp$inline_2436$$!=null)$JSCompiler_temp$jscomp$92_writer$jscomp$1$$=$m__5372__auto__$jscomp$inline_2437_m__5374__auto__$jscomp$inline_2436$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2437_m__5374__auto__$jscomp$inline_2436$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$92_writer$jscomp$1$$,
$s$jscomp$30$$):$m__5372__auto__$jscomp$inline_2437_m__5374__auto__$jscomp$inline_2436$$($JSCompiler_temp$jscomp$92_writer$jscomp$1$$,$s$jscomp$30$$);else if($m__5372__auto__$jscomp$inline_2437_m__5374__auto__$jscomp$inline_2436$$=$APP.$cljs$core$_write$$._,$m__5372__auto__$jscomp$inline_2437_m__5374__auto__$jscomp$inline_2436$$!=null)$JSCompiler_temp$jscomp$92_writer$jscomp$1$$=$m__5372__auto__$jscomp$inline_2437_m__5374__auto__$jscomp$inline_2436$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2437_m__5374__auto__$jscomp$inline_2436$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$92_writer$jscomp$1$$,
$s$jscomp$30$$):$m__5372__auto__$jscomp$inline_2437_m__5374__auto__$jscomp$inline_2436$$($JSCompiler_temp$jscomp$92_writer$jscomp$1$$,$s$jscomp$30$$);else throw $APP.$cljs$core$missing_protocol$$("IWriter.-write",$JSCompiler_temp$jscomp$92_writer$jscomp$1$$);}return $JSCompiler_temp$jscomp$92_writer$jscomp$1$$};
$cljs$core$_flush$$=function($JSCompiler_temp$jscomp$93_writer$jscomp$3$$){if($JSCompiler_temp$jscomp$93_writer$jscomp$3$$!=null&&$JSCompiler_temp$jscomp$93_writer$jscomp$3$$.$cljs$core$IWriter$_flush$arity$1$!=null)$JSCompiler_temp$jscomp$93_writer$jscomp$3$$=$JSCompiler_temp$jscomp$93_writer$jscomp$3$$.$cljs$core$IWriter$_flush$arity$1$($JSCompiler_temp$jscomp$93_writer$jscomp$3$$);else{var $m__5372__auto__$jscomp$inline_2441_m__5374__auto__$jscomp$inline_2440$$=$cljs$core$_flush$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$93_writer$jscomp$3$$==
null?null:$JSCompiler_temp$jscomp$93_writer$jscomp$3$$)];if($m__5372__auto__$jscomp$inline_2441_m__5374__auto__$jscomp$inline_2440$$!=null)$JSCompiler_temp$jscomp$93_writer$jscomp$3$$=$m__5372__auto__$jscomp$inline_2441_m__5374__auto__$jscomp$inline_2440$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2441_m__5374__auto__$jscomp$inline_2440$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$93_writer$jscomp$3$$):$m__5372__auto__$jscomp$inline_2441_m__5374__auto__$jscomp$inline_2440$$($JSCompiler_temp$jscomp$93_writer$jscomp$3$$);
else if($m__5372__auto__$jscomp$inline_2441_m__5374__auto__$jscomp$inline_2440$$=$cljs$core$_flush$$._,$m__5372__auto__$jscomp$inline_2441_m__5374__auto__$jscomp$inline_2440$$!=null)$JSCompiler_temp$jscomp$93_writer$jscomp$3$$=$m__5372__auto__$jscomp$inline_2441_m__5374__auto__$jscomp$inline_2440$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2441_m__5374__auto__$jscomp$inline_2440$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$93_writer$jscomp$3$$):$m__5372__auto__$jscomp$inline_2441_m__5374__auto__$jscomp$inline_2440$$($JSCompiler_temp$jscomp$93_writer$jscomp$3$$);
else throw $APP.$cljs$core$missing_protocol$$("IWriter.-flush",$JSCompiler_temp$jscomp$93_writer$jscomp$3$$);}return $JSCompiler_temp$jscomp$93_writer$jscomp$3$$};$cljs$core$IPrintWithWriter$$=function(){};
$APP.$cljs$core$_pr_writer$$=function($JSCompiler_temp$jscomp$94_o$jscomp$39$$,$writer$jscomp$5$$,$opts$jscomp$1$$){if($JSCompiler_temp$jscomp$94_o$jscomp$39$$!=null&&$JSCompiler_temp$jscomp$94_o$jscomp$39$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$!=null)$JSCompiler_temp$jscomp$94_o$jscomp$39$$=$JSCompiler_temp$jscomp$94_o$jscomp$39$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$($JSCompiler_temp$jscomp$94_o$jscomp$39$$,$writer$jscomp$5$$,$opts$jscomp$1$$);else{var $m__5372__auto__$jscomp$inline_2447_m__5374__auto__$jscomp$inline_2446$$=
$APP.$cljs$core$_pr_writer$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$94_o$jscomp$39$$==null?null:$JSCompiler_temp$jscomp$94_o$jscomp$39$$)];if($m__5372__auto__$jscomp$inline_2447_m__5374__auto__$jscomp$inline_2446$$!=null)$JSCompiler_temp$jscomp$94_o$jscomp$39$$=$m__5372__auto__$jscomp$inline_2447_m__5374__auto__$jscomp$inline_2446$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_2447_m__5374__auto__$jscomp$inline_2446$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$94_o$jscomp$39$$,
$writer$jscomp$5$$,$opts$jscomp$1$$):$m__5372__auto__$jscomp$inline_2447_m__5374__auto__$jscomp$inline_2446$$($JSCompiler_temp$jscomp$94_o$jscomp$39$$,$writer$jscomp$5$$,$opts$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_2447_m__5374__auto__$jscomp$inline_2446$$=$APP.$cljs$core$_pr_writer$$._,$m__5372__auto__$jscomp$inline_2447_m__5374__auto__$jscomp$inline_2446$$!=null)$JSCompiler_temp$jscomp$94_o$jscomp$39$$=$m__5372__auto__$jscomp$inline_2447_m__5374__auto__$jscomp$inline_2446$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_2447_m__5374__auto__$jscomp$inline_2446$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$94_o$jscomp$39$$,$writer$jscomp$5$$,$opts$jscomp$1$$):$m__5372__auto__$jscomp$inline_2447_m__5374__auto__$jscomp$inline_2446$$($JSCompiler_temp$jscomp$94_o$jscomp$39$$,$writer$jscomp$5$$,$opts$jscomp$1$$);else throw $APP.$cljs$core$missing_protocol$$("IPrintWithWriter.-pr-writer",$JSCompiler_temp$jscomp$94_o$jscomp$39$$);}return $JSCompiler_temp$jscomp$94_o$jscomp$39$$};
$cljs$core$IPending$$=function(){};
$cljs$core$_realized_QMARK_$$=function($JSCompiler_temp$jscomp$95_x$jscomp$114$$){if($JSCompiler_temp$jscomp$95_x$jscomp$114$$!=null&&$JSCompiler_temp$jscomp$95_x$jscomp$114$$.$cljs$core$IPending$_realized_QMARK_$arity$1$!=null)$JSCompiler_temp$jscomp$95_x$jscomp$114$$=$JSCompiler_temp$jscomp$95_x$jscomp$114$$.$cljs$core$IPending$_realized_QMARK_$arity$1$($JSCompiler_temp$jscomp$95_x$jscomp$114$$);else{var $m__5372__auto__$jscomp$inline_2451_m__5374__auto__$jscomp$inline_2450$$=$cljs$core$_realized_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$95_x$jscomp$114$$==
null?null:$JSCompiler_temp$jscomp$95_x$jscomp$114$$)];if($m__5372__auto__$jscomp$inline_2451_m__5374__auto__$jscomp$inline_2450$$!=null)$JSCompiler_temp$jscomp$95_x$jscomp$114$$=$m__5372__auto__$jscomp$inline_2451_m__5374__auto__$jscomp$inline_2450$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2451_m__5374__auto__$jscomp$inline_2450$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$95_x$jscomp$114$$):$m__5372__auto__$jscomp$inline_2451_m__5374__auto__$jscomp$inline_2450$$($JSCompiler_temp$jscomp$95_x$jscomp$114$$);
else if($m__5372__auto__$jscomp$inline_2451_m__5374__auto__$jscomp$inline_2450$$=$cljs$core$_realized_QMARK_$$._,$m__5372__auto__$jscomp$inline_2451_m__5374__auto__$jscomp$inline_2450$$!=null)$JSCompiler_temp$jscomp$95_x$jscomp$114$$=$m__5372__auto__$jscomp$inline_2451_m__5374__auto__$jscomp$inline_2450$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2451_m__5374__auto__$jscomp$inline_2450$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$95_x$jscomp$114$$):$m__5372__auto__$jscomp$inline_2451_m__5374__auto__$jscomp$inline_2450$$($JSCompiler_temp$jscomp$95_x$jscomp$114$$);
else throw $APP.$cljs$core$missing_protocol$$("IPending.-realized?",$JSCompiler_temp$jscomp$95_x$jscomp$114$$);}return $JSCompiler_temp$jscomp$95_x$jscomp$114$$};
$cljs$core$_notify_watches$$=function($JSCompiler_temp$jscomp$96_this$$jscomp$46$$,$oldval$jscomp$1$$,$newval$jscomp$1$$){if($JSCompiler_temp$jscomp$96_this$$jscomp$46$$!=null&&$JSCompiler_temp$jscomp$96_this$$jscomp$46$$.$cljs$core$IWatchable$_notify_watches$arity$3$!=null)$JSCompiler_temp$jscomp$96_this$$jscomp$46$$=$JSCompiler_temp$jscomp$96_this$$jscomp$46$$.$cljs$core$IWatchable$_notify_watches$arity$3$($JSCompiler_temp$jscomp$96_this$$jscomp$46$$,$oldval$jscomp$1$$,$newval$jscomp$1$$);else{var $m__5372__auto__$jscomp$inline_2457_m__5374__auto__$jscomp$inline_2456$$=
$cljs$core$_notify_watches$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$96_this$$jscomp$46$$==null?null:$JSCompiler_temp$jscomp$96_this$$jscomp$46$$)];if($m__5372__auto__$jscomp$inline_2457_m__5374__auto__$jscomp$inline_2456$$!=null)$JSCompiler_temp$jscomp$96_this$$jscomp$46$$=$m__5372__auto__$jscomp$inline_2457_m__5374__auto__$jscomp$inline_2456$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_2457_m__5374__auto__$jscomp$inline_2456$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$96_this$$jscomp$46$$,
$oldval$jscomp$1$$,$newval$jscomp$1$$):$m__5372__auto__$jscomp$inline_2457_m__5374__auto__$jscomp$inline_2456$$($JSCompiler_temp$jscomp$96_this$$jscomp$46$$,$oldval$jscomp$1$$,$newval$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_2457_m__5374__auto__$jscomp$inline_2456$$=$cljs$core$_notify_watches$$._,$m__5372__auto__$jscomp$inline_2457_m__5374__auto__$jscomp$inline_2456$$!=null)$JSCompiler_temp$jscomp$96_this$$jscomp$46$$=$m__5372__auto__$jscomp$inline_2457_m__5374__auto__$jscomp$inline_2456$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_2457_m__5374__auto__$jscomp$inline_2456$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$96_this$$jscomp$46$$,$oldval$jscomp$1$$,$newval$jscomp$1$$):$m__5372__auto__$jscomp$inline_2457_m__5374__auto__$jscomp$inline_2456$$($JSCompiler_temp$jscomp$96_this$$jscomp$46$$,$oldval$jscomp$1$$,$newval$jscomp$1$$);else throw $APP.$cljs$core$missing_protocol$$("IWatchable.-notify-watches",$JSCompiler_temp$jscomp$96_this$$jscomp$46$$);}return $JSCompiler_temp$jscomp$96_this$$jscomp$46$$};
$cljs$core$_add_watch$$=function($JSCompiler_temp$jscomp$97_this$$jscomp$48$$,$key$jscomp$110$$,$f$jscomp$89$$){if($JSCompiler_temp$jscomp$97_this$$jscomp$48$$!=null&&$JSCompiler_temp$jscomp$97_this$$jscomp$48$$.$cljs$core$IWatchable$_add_watch$arity$3$!=null)$JSCompiler_temp$jscomp$97_this$$jscomp$48$$=$JSCompiler_temp$jscomp$97_this$$jscomp$48$$.$cljs$core$IWatchable$_add_watch$arity$3$($JSCompiler_temp$jscomp$97_this$$jscomp$48$$,$key$jscomp$110$$,$f$jscomp$89$$);else{var $m__5372__auto__$jscomp$inline_2463_m__5374__auto__$jscomp$inline_2462$$=
$cljs$core$_add_watch$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$97_this$$jscomp$48$$==null?null:$JSCompiler_temp$jscomp$97_this$$jscomp$48$$)];if($m__5372__auto__$jscomp$inline_2463_m__5374__auto__$jscomp$inline_2462$$!=null)$JSCompiler_temp$jscomp$97_this$$jscomp$48$$=$m__5372__auto__$jscomp$inline_2463_m__5374__auto__$jscomp$inline_2462$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_2463_m__5374__auto__$jscomp$inline_2462$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$97_this$$jscomp$48$$,
$key$jscomp$110$$,$f$jscomp$89$$):$m__5372__auto__$jscomp$inline_2463_m__5374__auto__$jscomp$inline_2462$$($JSCompiler_temp$jscomp$97_this$$jscomp$48$$,$key$jscomp$110$$,$f$jscomp$89$$);else if($m__5372__auto__$jscomp$inline_2463_m__5374__auto__$jscomp$inline_2462$$=$cljs$core$_add_watch$$._,$m__5372__auto__$jscomp$inline_2463_m__5374__auto__$jscomp$inline_2462$$!=null)$JSCompiler_temp$jscomp$97_this$$jscomp$48$$=$m__5372__auto__$jscomp$inline_2463_m__5374__auto__$jscomp$inline_2462$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_2463_m__5374__auto__$jscomp$inline_2462$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$97_this$$jscomp$48$$,$key$jscomp$110$$,$f$jscomp$89$$):$m__5372__auto__$jscomp$inline_2463_m__5374__auto__$jscomp$inline_2462$$($JSCompiler_temp$jscomp$97_this$$jscomp$48$$,$key$jscomp$110$$,$f$jscomp$89$$);else throw $APP.$cljs$core$missing_protocol$$("IWatchable.-add-watch",$JSCompiler_temp$jscomp$97_this$$jscomp$48$$);}return $JSCompiler_temp$jscomp$97_this$$jscomp$48$$};
$cljs$core$_remove_watch$$=function($JSCompiler_temp$jscomp$98_this$$jscomp$50$$,$key$jscomp$112$$){if($JSCompiler_temp$jscomp$98_this$$jscomp$50$$!=null&&$JSCompiler_temp$jscomp$98_this$$jscomp$50$$.$cljs$core$IWatchable$_remove_watch$arity$2$!=null)$JSCompiler_temp$jscomp$98_this$$jscomp$50$$=$JSCompiler_temp$jscomp$98_this$$jscomp$50$$.$cljs$core$IWatchable$_remove_watch$arity$2$($JSCompiler_temp$jscomp$98_this$$jscomp$50$$,$key$jscomp$112$$);else{var $m__5372__auto__$jscomp$inline_2468_m__5374__auto__$jscomp$inline_2467$$=
$cljs$core$_remove_watch$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$98_this$$jscomp$50$$==null?null:$JSCompiler_temp$jscomp$98_this$$jscomp$50$$)];if($m__5372__auto__$jscomp$inline_2468_m__5374__auto__$jscomp$inline_2467$$!=null)$JSCompiler_temp$jscomp$98_this$$jscomp$50$$=$m__5372__auto__$jscomp$inline_2468_m__5374__auto__$jscomp$inline_2467$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2468_m__5374__auto__$jscomp$inline_2467$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$98_this$$jscomp$50$$,
$key$jscomp$112$$):$m__5372__auto__$jscomp$inline_2468_m__5374__auto__$jscomp$inline_2467$$($JSCompiler_temp$jscomp$98_this$$jscomp$50$$,$key$jscomp$112$$);else if($m__5372__auto__$jscomp$inline_2468_m__5374__auto__$jscomp$inline_2467$$=$cljs$core$_remove_watch$$._,$m__5372__auto__$jscomp$inline_2468_m__5374__auto__$jscomp$inline_2467$$!=null)$JSCompiler_temp$jscomp$98_this$$jscomp$50$$=$m__5372__auto__$jscomp$inline_2468_m__5374__auto__$jscomp$inline_2467$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2468_m__5374__auto__$jscomp$inline_2467$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$98_this$$jscomp$50$$,
$key$jscomp$112$$):$m__5372__auto__$jscomp$inline_2468_m__5374__auto__$jscomp$inline_2467$$($JSCompiler_temp$jscomp$98_this$$jscomp$50$$,$key$jscomp$112$$);else throw $APP.$cljs$core$missing_protocol$$("IWatchable.-remove-watch",$JSCompiler_temp$jscomp$98_this$$jscomp$50$$);}return $JSCompiler_temp$jscomp$98_this$$jscomp$50$$};
$APP.$cljs$core$_as_transient$$=function($JSCompiler_temp$jscomp$99_coll$jscomp$55$$){if($JSCompiler_temp$jscomp$99_coll$jscomp$55$$!=null&&$JSCompiler_temp$jscomp$99_coll$jscomp$55$$.$cljs$core$IEditableCollection$_as_transient$arity$1$!=null)$JSCompiler_temp$jscomp$99_coll$jscomp$55$$=$JSCompiler_temp$jscomp$99_coll$jscomp$55$$.$cljs$core$IEditableCollection$_as_transient$arity$1$($JSCompiler_temp$jscomp$99_coll$jscomp$55$$);else{var $m__5372__auto__$jscomp$inline_2472_m__5374__auto__$jscomp$inline_2471$$=
$APP.$cljs$core$_as_transient$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$99_coll$jscomp$55$$==null?null:$JSCompiler_temp$jscomp$99_coll$jscomp$55$$)];if($m__5372__auto__$jscomp$inline_2472_m__5374__auto__$jscomp$inline_2471$$!=null)$JSCompiler_temp$jscomp$99_coll$jscomp$55$$=$m__5372__auto__$jscomp$inline_2472_m__5374__auto__$jscomp$inline_2471$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2472_m__5374__auto__$jscomp$inline_2471$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$99_coll$jscomp$55$$):
$m__5372__auto__$jscomp$inline_2472_m__5374__auto__$jscomp$inline_2471$$($JSCompiler_temp$jscomp$99_coll$jscomp$55$$);else if($m__5372__auto__$jscomp$inline_2472_m__5374__auto__$jscomp$inline_2471$$=$APP.$cljs$core$_as_transient$$._,$m__5372__auto__$jscomp$inline_2472_m__5374__auto__$jscomp$inline_2471$$!=null)$JSCompiler_temp$jscomp$99_coll$jscomp$55$$=$m__5372__auto__$jscomp$inline_2472_m__5374__auto__$jscomp$inline_2471$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2472_m__5374__auto__$jscomp$inline_2471$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$99_coll$jscomp$55$$):
$m__5372__auto__$jscomp$inline_2472_m__5374__auto__$jscomp$inline_2471$$($JSCompiler_temp$jscomp$99_coll$jscomp$55$$);else throw $APP.$cljs$core$missing_protocol$$("IEditableCollection.-as-transient",$JSCompiler_temp$jscomp$99_coll$jscomp$55$$);}return $JSCompiler_temp$jscomp$99_coll$jscomp$55$$};
$cljs$core$_conj_BANG_$$=function($JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$,$val$jscomp$47$$){if($JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$!=null&&$JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$.$cljs$core$ITransientCollection$_conj_BANG_$arity$2$!=null)$JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$=$JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$.$cljs$core$ITransientCollection$_conj_BANG_$arity$2$($JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$,$val$jscomp$47$$);else{var $m__5372__auto__$jscomp$inline_2477_m__5374__auto__$jscomp$inline_2476$$=
$cljs$core$_conj_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$==null?null:$JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$)];if($m__5372__auto__$jscomp$inline_2477_m__5374__auto__$jscomp$inline_2476$$!=null)$JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$=$m__5372__auto__$jscomp$inline_2477_m__5374__auto__$jscomp$inline_2476$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2477_m__5374__auto__$jscomp$inline_2476$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$,
$val$jscomp$47$$):$m__5372__auto__$jscomp$inline_2477_m__5374__auto__$jscomp$inline_2476$$($JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$,$val$jscomp$47$$);else if($m__5372__auto__$jscomp$inline_2477_m__5374__auto__$jscomp$inline_2476$$=$cljs$core$_conj_BANG_$$._,$m__5372__auto__$jscomp$inline_2477_m__5374__auto__$jscomp$inline_2476$$!=null)$JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$=$m__5372__auto__$jscomp$inline_2477_m__5374__auto__$jscomp$inline_2476$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2477_m__5374__auto__$jscomp$inline_2476$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$,
$val$jscomp$47$$):$m__5372__auto__$jscomp$inline_2477_m__5374__auto__$jscomp$inline_2476$$($JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$,$val$jscomp$47$$);else throw $APP.$cljs$core$missing_protocol$$("ITransientCollection.-conj!",$JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$);}return $JSCompiler_temp$jscomp$100_tcoll$jscomp$1$$};
$APP.$cljs$core$_persistent_BANG_$$=function($JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$){if($JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$!=null&&$JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$.$cljs$core$ITransientCollection$_persistent_BANG_$arity$1$!=null)$JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$=$JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$.$cljs$core$ITransientCollection$_persistent_BANG_$arity$1$($JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$);else{var $m__5372__auto__$jscomp$inline_2481_m__5374__auto__$jscomp$inline_2480$$=
$APP.$cljs$core$_persistent_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$==null?null:$JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$)];if($m__5372__auto__$jscomp$inline_2481_m__5374__auto__$jscomp$inline_2480$$!=null)$JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$=$m__5372__auto__$jscomp$inline_2481_m__5374__auto__$jscomp$inline_2480$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2481_m__5374__auto__$jscomp$inline_2480$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$):
$m__5372__auto__$jscomp$inline_2481_m__5374__auto__$jscomp$inline_2480$$($JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$);else if($m__5372__auto__$jscomp$inline_2481_m__5374__auto__$jscomp$inline_2480$$=$APP.$cljs$core$_persistent_BANG_$$._,$m__5372__auto__$jscomp$inline_2481_m__5374__auto__$jscomp$inline_2480$$!=null)$JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$=$m__5372__auto__$jscomp$inline_2481_m__5374__auto__$jscomp$inline_2480$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2481_m__5374__auto__$jscomp$inline_2480$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$):
$m__5372__auto__$jscomp$inline_2481_m__5374__auto__$jscomp$inline_2480$$($JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$);else throw $APP.$cljs$core$missing_protocol$$("ITransientCollection.-persistent!",$JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$);}return $JSCompiler_temp$jscomp$101_tcoll$jscomp$3$$};
$cljs$core$_assoc_BANG_$$=function($JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$,$key$jscomp$114$$,$val$jscomp$49$$){if($JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$!=null&&$JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$!=null)$JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$=$JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$($JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$,$key$jscomp$114$$,$val$jscomp$49$$);
else{var $m__5372__auto__$jscomp$inline_2487_m__5374__auto__$jscomp$inline_2486$$=$cljs$core$_assoc_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$==null?null:$JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$)];if($m__5372__auto__$jscomp$inline_2487_m__5374__auto__$jscomp$inline_2486$$!=null)$JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$=$m__5372__auto__$jscomp$inline_2487_m__5374__auto__$jscomp$inline_2486$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_2487_m__5374__auto__$jscomp$inline_2486$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$,
$key$jscomp$114$$,$val$jscomp$49$$):$m__5372__auto__$jscomp$inline_2487_m__5374__auto__$jscomp$inline_2486$$($JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$,$key$jscomp$114$$,$val$jscomp$49$$);else if($m__5372__auto__$jscomp$inline_2487_m__5374__auto__$jscomp$inline_2486$$=$cljs$core$_assoc_BANG_$$._,$m__5372__auto__$jscomp$inline_2487_m__5374__auto__$jscomp$inline_2486$$!=null)$JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$=$m__5372__auto__$jscomp$inline_2487_m__5374__auto__$jscomp$inline_2486$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_2487_m__5374__auto__$jscomp$inline_2486$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$,$key$jscomp$114$$,$val$jscomp$49$$):$m__5372__auto__$jscomp$inline_2487_m__5374__auto__$jscomp$inline_2486$$($JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$,$key$jscomp$114$$,$val$jscomp$49$$);else throw $APP.$cljs$core$missing_protocol$$("ITransientAssociative.-assoc!",$JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$);}return $JSCompiler_temp$jscomp$102_tcoll$jscomp$5$$};
$cljs$core$_dissoc_BANG_$$=function($JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$,$key$jscomp$116$$){if($JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$!=null&&$JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$.$cljs$core$ITransientMap$_dissoc_BANG_$arity$2$!=null)$JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$=$JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$.$cljs$core$ITransientMap$_dissoc_BANG_$arity$2$($JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$,$key$jscomp$116$$);else{var $m__5372__auto__$jscomp$inline_2492_m__5374__auto__$jscomp$inline_2491$$=
$cljs$core$_dissoc_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$==null?null:$JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$)];if($m__5372__auto__$jscomp$inline_2492_m__5374__auto__$jscomp$inline_2491$$!=null)$JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$=$m__5372__auto__$jscomp$inline_2492_m__5374__auto__$jscomp$inline_2491$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2492_m__5374__auto__$jscomp$inline_2491$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$,
$key$jscomp$116$$):$m__5372__auto__$jscomp$inline_2492_m__5374__auto__$jscomp$inline_2491$$($JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$,$key$jscomp$116$$);else if($m__5372__auto__$jscomp$inline_2492_m__5374__auto__$jscomp$inline_2491$$=$cljs$core$_dissoc_BANG_$$._,$m__5372__auto__$jscomp$inline_2492_m__5374__auto__$jscomp$inline_2491$$!=null)$JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$=$m__5372__auto__$jscomp$inline_2492_m__5374__auto__$jscomp$inline_2491$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2492_m__5374__auto__$jscomp$inline_2491$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$,
$key$jscomp$116$$):$m__5372__auto__$jscomp$inline_2492_m__5374__auto__$jscomp$inline_2491$$($JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$,$key$jscomp$116$$);else throw $APP.$cljs$core$missing_protocol$$("ITransientMap.-dissoc!",$JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$);}return $JSCompiler_temp$jscomp$103_tcoll$jscomp$7$$};
$cljs$core$_assoc_n_BANG_$$=function($JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$,$n$jscomp$33$$,$val$jscomp$51$$){if($JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$!=null&&$JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$.$cljs$core$ITransientVector$_assoc_n_BANG_$arity$3$!=null)$JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$=$JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$.$cljs$core$ITransientVector$_assoc_n_BANG_$arity$3$($JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$,$n$jscomp$33$$,$val$jscomp$51$$);else{var $m__5372__auto__$jscomp$inline_2498_m__5374__auto__$jscomp$inline_2497$$=
$cljs$core$_assoc_n_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$==null?null:$JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$)];if($m__5372__auto__$jscomp$inline_2498_m__5374__auto__$jscomp$inline_2497$$!=null)$JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$=$m__5372__auto__$jscomp$inline_2498_m__5374__auto__$jscomp$inline_2497$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_2498_m__5374__auto__$jscomp$inline_2497$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$,
$n$jscomp$33$$,$val$jscomp$51$$):$m__5372__auto__$jscomp$inline_2498_m__5374__auto__$jscomp$inline_2497$$($JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$,$n$jscomp$33$$,$val$jscomp$51$$);else if($m__5372__auto__$jscomp$inline_2498_m__5374__auto__$jscomp$inline_2497$$=$cljs$core$_assoc_n_BANG_$$._,$m__5372__auto__$jscomp$inline_2498_m__5374__auto__$jscomp$inline_2497$$!=null)$JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$=$m__5372__auto__$jscomp$inline_2498_m__5374__auto__$jscomp$inline_2497$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_2498_m__5374__auto__$jscomp$inline_2497$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$,$n$jscomp$33$$,$val$jscomp$51$$):$m__5372__auto__$jscomp$inline_2498_m__5374__auto__$jscomp$inline_2497$$($JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$,$n$jscomp$33$$,$val$jscomp$51$$);else throw $APP.$cljs$core$missing_protocol$$("ITransientVector.-assoc-n!",$JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$);}return $JSCompiler_temp$jscomp$104_tcoll$jscomp$9$$};
$cljs$core$IComparable$$=function(){};
$APP.$cljs$core$_compare$$=function($JSCompiler_temp$jscomp$105_x$jscomp$116$$,$y$jscomp$81$$){if($JSCompiler_temp$jscomp$105_x$jscomp$116$$!=null&&$JSCompiler_temp$jscomp$105_x$jscomp$116$$.$cljs$core$IComparable$_compare$arity$2$!=null)$JSCompiler_temp$jscomp$105_x$jscomp$116$$=$JSCompiler_temp$jscomp$105_x$jscomp$116$$.$cljs$core$IComparable$_compare$arity$2$($JSCompiler_temp$jscomp$105_x$jscomp$116$$,$y$jscomp$81$$);else{var $m__5372__auto__$jscomp$inline_2503_m__5374__auto__$jscomp$inline_2502$$=$APP.$cljs$core$_compare$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$105_x$jscomp$116$$==
null?null:$JSCompiler_temp$jscomp$105_x$jscomp$116$$)];if($m__5372__auto__$jscomp$inline_2503_m__5374__auto__$jscomp$inline_2502$$!=null)$JSCompiler_temp$jscomp$105_x$jscomp$116$$=$m__5372__auto__$jscomp$inline_2503_m__5374__auto__$jscomp$inline_2502$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2503_m__5374__auto__$jscomp$inline_2502$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$105_x$jscomp$116$$,$y$jscomp$81$$):$m__5372__auto__$jscomp$inline_2503_m__5374__auto__$jscomp$inline_2502$$($JSCompiler_temp$jscomp$105_x$jscomp$116$$,
$y$jscomp$81$$);else if($m__5372__auto__$jscomp$inline_2503_m__5374__auto__$jscomp$inline_2502$$=$APP.$cljs$core$_compare$$._,$m__5372__auto__$jscomp$inline_2503_m__5374__auto__$jscomp$inline_2502$$!=null)$JSCompiler_temp$jscomp$105_x$jscomp$116$$=$m__5372__auto__$jscomp$inline_2503_m__5374__auto__$jscomp$inline_2502$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2503_m__5374__auto__$jscomp$inline_2502$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$105_x$jscomp$116$$,
$y$jscomp$81$$):$m__5372__auto__$jscomp$inline_2503_m__5374__auto__$jscomp$inline_2502$$($JSCompiler_temp$jscomp$105_x$jscomp$116$$,$y$jscomp$81$$);else throw $APP.$cljs$core$missing_protocol$$("IComparable.-compare",$JSCompiler_temp$jscomp$105_x$jscomp$116$$);}return $JSCompiler_temp$jscomp$105_x$jscomp$116$$};
$cljs$core$_drop_first$$=function($JSCompiler_temp$jscomp$106_coll$jscomp$57$$){if($JSCompiler_temp$jscomp$106_coll$jscomp$57$$!=null&&$JSCompiler_temp$jscomp$106_coll$jscomp$57$$.$cljs$core$IChunk$_drop_first$arity$1$!=null)$JSCompiler_temp$jscomp$106_coll$jscomp$57$$=$JSCompiler_temp$jscomp$106_coll$jscomp$57$$.$cljs$core$IChunk$_drop_first$arity$1$($JSCompiler_temp$jscomp$106_coll$jscomp$57$$);else{var $m__5372__auto__$jscomp$inline_2507_m__5374__auto__$jscomp$inline_2506$$=$cljs$core$_drop_first$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$106_coll$jscomp$57$$==
null?null:$JSCompiler_temp$jscomp$106_coll$jscomp$57$$)];if($m__5372__auto__$jscomp$inline_2507_m__5374__auto__$jscomp$inline_2506$$!=null)$JSCompiler_temp$jscomp$106_coll$jscomp$57$$=$m__5372__auto__$jscomp$inline_2507_m__5374__auto__$jscomp$inline_2506$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2507_m__5374__auto__$jscomp$inline_2506$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$106_coll$jscomp$57$$):$m__5372__auto__$jscomp$inline_2507_m__5374__auto__$jscomp$inline_2506$$($JSCompiler_temp$jscomp$106_coll$jscomp$57$$);
else if($m__5372__auto__$jscomp$inline_2507_m__5374__auto__$jscomp$inline_2506$$=$cljs$core$_drop_first$$._,$m__5372__auto__$jscomp$inline_2507_m__5374__auto__$jscomp$inline_2506$$!=null)$JSCompiler_temp$jscomp$106_coll$jscomp$57$$=$m__5372__auto__$jscomp$inline_2507_m__5374__auto__$jscomp$inline_2506$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2507_m__5374__auto__$jscomp$inline_2506$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$106_coll$jscomp$57$$):$m__5372__auto__$jscomp$inline_2507_m__5374__auto__$jscomp$inline_2506$$($JSCompiler_temp$jscomp$106_coll$jscomp$57$$);
else throw $APP.$cljs$core$missing_protocol$$("IChunk.-drop-first",$JSCompiler_temp$jscomp$106_coll$jscomp$57$$);}return $JSCompiler_temp$jscomp$106_coll$jscomp$57$$};
$APP.$cljs$core$_chunked_first$$=function($JSCompiler_temp$jscomp$107_coll$jscomp$59$$){if($JSCompiler_temp$jscomp$107_coll$jscomp$59$$!=null&&$JSCompiler_temp$jscomp$107_coll$jscomp$59$$.$cljs$core$IChunkedSeq$_chunked_first$arity$1$!=null)$JSCompiler_temp$jscomp$107_coll$jscomp$59$$=$JSCompiler_temp$jscomp$107_coll$jscomp$59$$.$cljs$core$IChunkedSeq$_chunked_first$arity$1$($JSCompiler_temp$jscomp$107_coll$jscomp$59$$);else{var $m__5372__auto__$jscomp$inline_2511_m__5374__auto__$jscomp$inline_2510$$=
$APP.$cljs$core$_chunked_first$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$107_coll$jscomp$59$$==null?null:$JSCompiler_temp$jscomp$107_coll$jscomp$59$$)];if($m__5372__auto__$jscomp$inline_2511_m__5374__auto__$jscomp$inline_2510$$!=null)$JSCompiler_temp$jscomp$107_coll$jscomp$59$$=$m__5372__auto__$jscomp$inline_2511_m__5374__auto__$jscomp$inline_2510$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2511_m__5374__auto__$jscomp$inline_2510$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$107_coll$jscomp$59$$):
$m__5372__auto__$jscomp$inline_2511_m__5374__auto__$jscomp$inline_2510$$($JSCompiler_temp$jscomp$107_coll$jscomp$59$$);else if($m__5372__auto__$jscomp$inline_2511_m__5374__auto__$jscomp$inline_2510$$=$APP.$cljs$core$_chunked_first$$._,$m__5372__auto__$jscomp$inline_2511_m__5374__auto__$jscomp$inline_2510$$!=null)$JSCompiler_temp$jscomp$107_coll$jscomp$59$$=$m__5372__auto__$jscomp$inline_2511_m__5374__auto__$jscomp$inline_2510$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2511_m__5374__auto__$jscomp$inline_2510$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$107_coll$jscomp$59$$):
$m__5372__auto__$jscomp$inline_2511_m__5374__auto__$jscomp$inline_2510$$($JSCompiler_temp$jscomp$107_coll$jscomp$59$$);else throw $APP.$cljs$core$missing_protocol$$("IChunkedSeq.-chunked-first",$JSCompiler_temp$jscomp$107_coll$jscomp$59$$);}return $JSCompiler_temp$jscomp$107_coll$jscomp$59$$};
$APP.$cljs$core$_chunked_rest$$=function($JSCompiler_temp$jscomp$108_coll$jscomp$61$$){if($JSCompiler_temp$jscomp$108_coll$jscomp$61$$!=null&&$JSCompiler_temp$jscomp$108_coll$jscomp$61$$.$cljs$core$IChunkedSeq$_chunked_rest$arity$1$!=null)$JSCompiler_temp$jscomp$108_coll$jscomp$61$$=$JSCompiler_temp$jscomp$108_coll$jscomp$61$$.$cljs$core$IChunkedSeq$_chunked_rest$arity$1$($JSCompiler_temp$jscomp$108_coll$jscomp$61$$);else{var $m__5372__auto__$jscomp$inline_2515_m__5374__auto__$jscomp$inline_2514$$=
$APP.$cljs$core$_chunked_rest$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$108_coll$jscomp$61$$==null?null:$JSCompiler_temp$jscomp$108_coll$jscomp$61$$)];if($m__5372__auto__$jscomp$inline_2515_m__5374__auto__$jscomp$inline_2514$$!=null)$JSCompiler_temp$jscomp$108_coll$jscomp$61$$=$m__5372__auto__$jscomp$inline_2515_m__5374__auto__$jscomp$inline_2514$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2515_m__5374__auto__$jscomp$inline_2514$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$108_coll$jscomp$61$$):
$m__5372__auto__$jscomp$inline_2515_m__5374__auto__$jscomp$inline_2514$$($JSCompiler_temp$jscomp$108_coll$jscomp$61$$);else if($m__5372__auto__$jscomp$inline_2515_m__5374__auto__$jscomp$inline_2514$$=$APP.$cljs$core$_chunked_rest$$._,$m__5372__auto__$jscomp$inline_2515_m__5374__auto__$jscomp$inline_2514$$!=null)$JSCompiler_temp$jscomp$108_coll$jscomp$61$$=$m__5372__auto__$jscomp$inline_2515_m__5374__auto__$jscomp$inline_2514$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2515_m__5374__auto__$jscomp$inline_2514$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$108_coll$jscomp$61$$):
$m__5372__auto__$jscomp$inline_2515_m__5374__auto__$jscomp$inline_2514$$($JSCompiler_temp$jscomp$108_coll$jscomp$61$$);else throw $APP.$cljs$core$missing_protocol$$("IChunkedSeq.-chunked-rest",$JSCompiler_temp$jscomp$108_coll$jscomp$61$$);}return $JSCompiler_temp$jscomp$108_coll$jscomp$61$$};
$cljs$core$_name$$=function($JSCompiler_temp$jscomp$109_x$jscomp$118$$){if($JSCompiler_temp$jscomp$109_x$jscomp$118$$!=null&&$JSCompiler_temp$jscomp$109_x$jscomp$118$$.$cljs$core$INamed$_name$arity$1$!=null)$JSCompiler_temp$jscomp$109_x$jscomp$118$$=$JSCompiler_temp$jscomp$109_x$jscomp$118$$.$cljs$core$INamed$_name$arity$1$($JSCompiler_temp$jscomp$109_x$jscomp$118$$);else{var $m__5372__auto__$jscomp$inline_2519_m__5374__auto__$jscomp$inline_2518$$=$cljs$core$_name$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$109_x$jscomp$118$$==
null?null:$JSCompiler_temp$jscomp$109_x$jscomp$118$$)];if($m__5372__auto__$jscomp$inline_2519_m__5374__auto__$jscomp$inline_2518$$!=null)$JSCompiler_temp$jscomp$109_x$jscomp$118$$=$m__5372__auto__$jscomp$inline_2519_m__5374__auto__$jscomp$inline_2518$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2519_m__5374__auto__$jscomp$inline_2518$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$109_x$jscomp$118$$):$m__5372__auto__$jscomp$inline_2519_m__5374__auto__$jscomp$inline_2518$$($JSCompiler_temp$jscomp$109_x$jscomp$118$$);
else if($m__5372__auto__$jscomp$inline_2519_m__5374__auto__$jscomp$inline_2518$$=$cljs$core$_name$$._,$m__5372__auto__$jscomp$inline_2519_m__5374__auto__$jscomp$inline_2518$$!=null)$JSCompiler_temp$jscomp$109_x$jscomp$118$$=$m__5372__auto__$jscomp$inline_2519_m__5374__auto__$jscomp$inline_2518$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2519_m__5374__auto__$jscomp$inline_2518$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$109_x$jscomp$118$$):$m__5372__auto__$jscomp$inline_2519_m__5374__auto__$jscomp$inline_2518$$($JSCompiler_temp$jscomp$109_x$jscomp$118$$);
else throw $APP.$cljs$core$missing_protocol$$("INamed.-name",$JSCompiler_temp$jscomp$109_x$jscomp$118$$);}return $JSCompiler_temp$jscomp$109_x$jscomp$118$$};
$cljs$core$_namespace$$=function($JSCompiler_temp$jscomp$110_x$jscomp$120$$){if($JSCompiler_temp$jscomp$110_x$jscomp$120$$!=null&&$JSCompiler_temp$jscomp$110_x$jscomp$120$$.$cljs$core$INamed$_namespace$arity$1$!=null)$JSCompiler_temp$jscomp$110_x$jscomp$120$$=$JSCompiler_temp$jscomp$110_x$jscomp$120$$.$cljs$core$INamed$_namespace$arity$1$($JSCompiler_temp$jscomp$110_x$jscomp$120$$);else{var $m__5372__auto__$jscomp$inline_2523_m__5374__auto__$jscomp$inline_2522$$=$cljs$core$_namespace$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$110_x$jscomp$120$$==
null?null:$JSCompiler_temp$jscomp$110_x$jscomp$120$$)];if($m__5372__auto__$jscomp$inline_2523_m__5374__auto__$jscomp$inline_2522$$!=null)$JSCompiler_temp$jscomp$110_x$jscomp$120$$=$m__5372__auto__$jscomp$inline_2523_m__5374__auto__$jscomp$inline_2522$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2523_m__5374__auto__$jscomp$inline_2522$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$110_x$jscomp$120$$):$m__5372__auto__$jscomp$inline_2523_m__5374__auto__$jscomp$inline_2522$$($JSCompiler_temp$jscomp$110_x$jscomp$120$$);
else if($m__5372__auto__$jscomp$inline_2523_m__5374__auto__$jscomp$inline_2522$$=$cljs$core$_namespace$$._,$m__5372__auto__$jscomp$inline_2523_m__5374__auto__$jscomp$inline_2522$$!=null)$JSCompiler_temp$jscomp$110_x$jscomp$120$$=$m__5372__auto__$jscomp$inline_2523_m__5374__auto__$jscomp$inline_2522$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2523_m__5374__auto__$jscomp$inline_2522$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$110_x$jscomp$120$$):$m__5372__auto__$jscomp$inline_2523_m__5374__auto__$jscomp$inline_2522$$($JSCompiler_temp$jscomp$110_x$jscomp$120$$);
else throw $APP.$cljs$core$missing_protocol$$("INamed.-namespace",$JSCompiler_temp$jscomp$110_x$jscomp$120$$);}return $JSCompiler_temp$jscomp$110_x$jscomp$120$$};
$cljs$core$_reset_BANG_$$=function($JSCompiler_temp$jscomp$111_o$jscomp$41$$,$new_value$jscomp$1$$){if($JSCompiler_temp$jscomp$111_o$jscomp$41$$!=null&&$JSCompiler_temp$jscomp$111_o$jscomp$41$$.$cljs$core$IReset$_reset_BANG_$arity$2$!=null)$JSCompiler_temp$jscomp$111_o$jscomp$41$$=$JSCompiler_temp$jscomp$111_o$jscomp$41$$.$cljs$core$IReset$_reset_BANG_$arity$2$($JSCompiler_temp$jscomp$111_o$jscomp$41$$,$new_value$jscomp$1$$);else{var $m__5372__auto__$jscomp$inline_2528_m__5374__auto__$jscomp$inline_2527$$=
$cljs$core$_reset_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$111_o$jscomp$41$$==null?null:$JSCompiler_temp$jscomp$111_o$jscomp$41$$)];if($m__5372__auto__$jscomp$inline_2528_m__5374__auto__$jscomp$inline_2527$$!=null)$JSCompiler_temp$jscomp$111_o$jscomp$41$$=$m__5372__auto__$jscomp$inline_2528_m__5374__auto__$jscomp$inline_2527$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2528_m__5374__auto__$jscomp$inline_2527$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$111_o$jscomp$41$$,
$new_value$jscomp$1$$):$m__5372__auto__$jscomp$inline_2528_m__5374__auto__$jscomp$inline_2527$$($JSCompiler_temp$jscomp$111_o$jscomp$41$$,$new_value$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_2528_m__5374__auto__$jscomp$inline_2527$$=$cljs$core$_reset_BANG_$$._,$m__5372__auto__$jscomp$inline_2528_m__5374__auto__$jscomp$inline_2527$$!=null)$JSCompiler_temp$jscomp$111_o$jscomp$41$$=$m__5372__auto__$jscomp$inline_2528_m__5374__auto__$jscomp$inline_2527$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2528_m__5374__auto__$jscomp$inline_2527$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$111_o$jscomp$41$$,
$new_value$jscomp$1$$):$m__5372__auto__$jscomp$inline_2528_m__5374__auto__$jscomp$inline_2527$$($JSCompiler_temp$jscomp$111_o$jscomp$41$$,$new_value$jscomp$1$$);else throw $APP.$cljs$core$missing_protocol$$("IReset.-reset!",$JSCompiler_temp$jscomp$111_o$jscomp$41$$);}return $JSCompiler_temp$jscomp$111_o$jscomp$41$$};
$APP.$cljs$core$_vreset_BANG_$$=function($JSCompiler_temp$jscomp$112_o$jscomp$52$$,$new_value$jscomp$3$$){if($JSCompiler_temp$jscomp$112_o$jscomp$52$$!=null&&$JSCompiler_temp$jscomp$112_o$jscomp$52$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$!=null)$JSCompiler_temp$jscomp$112_o$jscomp$52$$=$JSCompiler_temp$jscomp$112_o$jscomp$52$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$($JSCompiler_temp$jscomp$112_o$jscomp$52$$,$new_value$jscomp$3$$);else{var $m__5372__auto__$jscomp$inline_2533_m__5374__auto__$jscomp$inline_2532$$=
$APP.$cljs$core$_vreset_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$112_o$jscomp$52$$==null?null:$JSCompiler_temp$jscomp$112_o$jscomp$52$$)];if($m__5372__auto__$jscomp$inline_2533_m__5374__auto__$jscomp$inline_2532$$!=null)$JSCompiler_temp$jscomp$112_o$jscomp$52$$=$m__5372__auto__$jscomp$inline_2533_m__5374__auto__$jscomp$inline_2532$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2533_m__5374__auto__$jscomp$inline_2532$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$112_o$jscomp$52$$,
$new_value$jscomp$3$$):$m__5372__auto__$jscomp$inline_2533_m__5374__auto__$jscomp$inline_2532$$($JSCompiler_temp$jscomp$112_o$jscomp$52$$,$new_value$jscomp$3$$);else if($m__5372__auto__$jscomp$inline_2533_m__5374__auto__$jscomp$inline_2532$$=$APP.$cljs$core$_vreset_BANG_$$._,$m__5372__auto__$jscomp$inline_2533_m__5374__auto__$jscomp$inline_2532$$!=null)$JSCompiler_temp$jscomp$112_o$jscomp$52$$=$m__5372__auto__$jscomp$inline_2533_m__5374__auto__$jscomp$inline_2532$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_2533_m__5374__auto__$jscomp$inline_2532$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$112_o$jscomp$52$$,$new_value$jscomp$3$$):$m__5372__auto__$jscomp$inline_2533_m__5374__auto__$jscomp$inline_2532$$($JSCompiler_temp$jscomp$112_o$jscomp$52$$,$new_value$jscomp$3$$);else throw $APP.$cljs$core$missing_protocol$$("IVolatile.-vreset!",$JSCompiler_temp$jscomp$112_o$jscomp$52$$);}return $JSCompiler_temp$jscomp$112_o$jscomp$52$$};$cljs$core$IIterable$$=function(){};
$APP.$cljs$core$_iterator$$=function($JSCompiler_temp$jscomp$113_coll$jscomp$65$$){if($JSCompiler_temp$jscomp$113_coll$jscomp$65$$!=null&&$JSCompiler_temp$jscomp$113_coll$jscomp$65$$.$cljs$core$IIterable$_iterator$arity$1$!=null)$JSCompiler_temp$jscomp$113_coll$jscomp$65$$=$JSCompiler_temp$jscomp$113_coll$jscomp$65$$.$cljs$core$IIterable$_iterator$arity$1$($JSCompiler_temp$jscomp$113_coll$jscomp$65$$);else{var $m__5372__auto__$jscomp$inline_2537_m__5374__auto__$jscomp$inline_2536$$=$APP.$cljs$core$_iterator$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$113_coll$jscomp$65$$==
null?null:$JSCompiler_temp$jscomp$113_coll$jscomp$65$$)];if($m__5372__auto__$jscomp$inline_2537_m__5374__auto__$jscomp$inline_2536$$!=null)$JSCompiler_temp$jscomp$113_coll$jscomp$65$$=$m__5372__auto__$jscomp$inline_2537_m__5374__auto__$jscomp$inline_2536$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2537_m__5374__auto__$jscomp$inline_2536$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$113_coll$jscomp$65$$):$m__5372__auto__$jscomp$inline_2537_m__5374__auto__$jscomp$inline_2536$$($JSCompiler_temp$jscomp$113_coll$jscomp$65$$);
else if($m__5372__auto__$jscomp$inline_2537_m__5374__auto__$jscomp$inline_2536$$=$APP.$cljs$core$_iterator$$._,$m__5372__auto__$jscomp$inline_2537_m__5374__auto__$jscomp$inline_2536$$!=null)$JSCompiler_temp$jscomp$113_coll$jscomp$65$$=$m__5372__auto__$jscomp$inline_2537_m__5374__auto__$jscomp$inline_2536$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2537_m__5374__auto__$jscomp$inline_2536$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$113_coll$jscomp$65$$):$m__5372__auto__$jscomp$inline_2537_m__5374__auto__$jscomp$inline_2536$$($JSCompiler_temp$jscomp$113_coll$jscomp$65$$);
else throw $APP.$cljs$core$missing_protocol$$("IIterable.-iterator",$JSCompiler_temp$jscomp$113_coll$jscomp$65$$);}return $JSCompiler_temp$jscomp$113_coll$jscomp$65$$};
$cljs$core$_drop$$=function($JSCompiler_temp$jscomp$114_coll$jscomp$67$$,$n$jscomp$35$$){if($JSCompiler_temp$jscomp$114_coll$jscomp$67$$!=null&&$JSCompiler_temp$jscomp$114_coll$jscomp$67$$.$cljs$core$IDrop$_drop$arity$2$!=null)$JSCompiler_temp$jscomp$114_coll$jscomp$67$$=$JSCompiler_temp$jscomp$114_coll$jscomp$67$$.$cljs$core$IDrop$_drop$arity$2$($JSCompiler_temp$jscomp$114_coll$jscomp$67$$,$n$jscomp$35$$);else{var $m__5372__auto__$jscomp$inline_2542_m__5374__auto__$jscomp$inline_2541$$=$cljs$core$_drop$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$114_coll$jscomp$67$$==
null?null:$JSCompiler_temp$jscomp$114_coll$jscomp$67$$)];if($m__5372__auto__$jscomp$inline_2542_m__5374__auto__$jscomp$inline_2541$$!=null)$JSCompiler_temp$jscomp$114_coll$jscomp$67$$=$m__5372__auto__$jscomp$inline_2542_m__5374__auto__$jscomp$inline_2541$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2542_m__5374__auto__$jscomp$inline_2541$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$114_coll$jscomp$67$$,$n$jscomp$35$$):$m__5372__auto__$jscomp$inline_2542_m__5374__auto__$jscomp$inline_2541$$($JSCompiler_temp$jscomp$114_coll$jscomp$67$$,
$n$jscomp$35$$);else if($m__5372__auto__$jscomp$inline_2542_m__5374__auto__$jscomp$inline_2541$$=$cljs$core$_drop$$._,$m__5372__auto__$jscomp$inline_2542_m__5374__auto__$jscomp$inline_2541$$!=null)$JSCompiler_temp$jscomp$114_coll$jscomp$67$$=$m__5372__auto__$jscomp$inline_2542_m__5374__auto__$jscomp$inline_2541$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2542_m__5374__auto__$jscomp$inline_2541$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$114_coll$jscomp$67$$,$n$jscomp$35$$):
$m__5372__auto__$jscomp$inline_2542_m__5374__auto__$jscomp$inline_2541$$($JSCompiler_temp$jscomp$114_coll$jscomp$67$$,$n$jscomp$35$$);else throw $APP.$cljs$core$missing_protocol$$("IDrop.-drop",$JSCompiler_temp$jscomp$114_coll$jscomp$67$$);}return $JSCompiler_temp$jscomp$114_coll$jscomp$67$$};$cljs$core$StringBufferWriter$$=function($sb$jscomp$3$$){this.sb=$sb$jscomp$3$$;this.$cljs$lang$protocol_mask$partition0$$=1073741824;this.$cljs$lang$protocol_mask$partition1$$=0};
$APP.$cljs$core$pr_str_STAR_$$=function($obj$jscomp$83$$){var $sb$jscomp$5$$=new $APP.$goog$string$StringBuffer$$,$writer$jscomp$6$$=new $cljs$core$StringBufferWriter$$($sb$jscomp$5$$);$obj$jscomp$83$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$(null,$writer$jscomp$6$$,$cljs$core$pr_opts$$());$writer$jscomp$6$$.$cljs$core$IWriter$_flush$arity$1$(null);return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$5$$)};
$cljs$core$m3_mix_K1$$=function($k1_x$jscomp$inline_2544$$){$k1_x$jscomp$inline_2544$$=(0,$APP.$cljs$core$imul$$)($k1_x$jscomp$inline_2544$$|0,-862048943);return(0,$APP.$cljs$core$imul$$)($k1_x$jscomp$inline_2544$$<<15|$k1_x$jscomp$inline_2544$$>>>-15,461845907)};
$cljs$core$m3_mix_H1$$=function($h1_x$jscomp$inline_2547$$,$k1$jscomp$1$$){$h1_x$jscomp$inline_2547$$=($h1_x$jscomp$inline_2547$$|0)^($k1$jscomp$1$$|0);return(0,$APP.$cljs$core$imul$$)($h1_x$jscomp$inline_2547$$<<13|$h1_x$jscomp$inline_2547$$>>>-13,5)+-430675100|0};
$cljs$core$m3_fmix$$=function($h1$jscomp$1_h1__$2_h1__$4_h1__$6$$,$len$jscomp$10$$){$h1$jscomp$1_h1__$2_h1__$4_h1__$6$$=($h1$jscomp$1_h1__$2_h1__$4_h1__$6$$|0)^$len$jscomp$10$$;$h1$jscomp$1_h1__$2_h1__$4_h1__$6$$=(0,$APP.$cljs$core$imul$$)($h1$jscomp$1_h1__$2_h1__$4_h1__$6$$^$h1$jscomp$1_h1__$2_h1__$4_h1__$6$$>>>16,-2048144789);$h1$jscomp$1_h1__$2_h1__$4_h1__$6$$=(0,$APP.$cljs$core$imul$$)($h1$jscomp$1_h1__$2_h1__$4_h1__$6$$^$h1$jscomp$1_h1__$2_h1__$4_h1__$6$$>>>13,-1028477387);return $h1$jscomp$1_h1__$2_h1__$4_h1__$6$$^
$h1$jscomp$1_h1__$2_h1__$4_h1__$6$$>>>16};
$cljs$core$hash_string$$=function($JSCompiler_temp$jscomp$121_k$jscomp$42$$){$cljs$core$string_hash_cache_count$$>255&&($cljs$core$string_hash_cache$$={},$cljs$core$string_hash_cache_count$$=0);if($JSCompiler_temp$jscomp$121_k$jscomp$42$$==null)return 0;var $h$jscomp$39_h$jscomp$inline_2561_len$jscomp$inline_11161$$=$cljs$core$string_hash_cache$$[$JSCompiler_temp$jscomp$121_k$jscomp$42$$];if(typeof $h$jscomp$39_h$jscomp$inline_2561_len$jscomp$inline_11161$$==="number")$JSCompiler_temp$jscomp$121_k$jscomp$42$$=
$h$jscomp$39_h$jscomp$inline_2561_len$jscomp$inline_11161$$;else{a:if($JSCompiler_temp$jscomp$121_k$jscomp$42$$!=null)if($h$jscomp$39_h$jscomp$inline_2561_len$jscomp$inline_11161$$=$JSCompiler_temp$jscomp$121_k$jscomp$42$$.length,$h$jscomp$39_h$jscomp$inline_2561_len$jscomp$inline_11161$$>0){for(var $i$jscomp$inline_11162$$=0,$G__24635$jscomp$inline_11164_hash$jscomp$inline_11163$$=0;;)if($i$jscomp$inline_11162$$<$h$jscomp$39_h$jscomp$inline_2561_len$jscomp$inline_11161$$)$G__24635$jscomp$inline_11164_hash$jscomp$inline_11163$$=
(0,$APP.$cljs$core$imul$$)(31,$G__24635$jscomp$inline_11164_hash$jscomp$inline_11163$$)+$JSCompiler_temp$jscomp$121_k$jscomp$42$$.charCodeAt($i$jscomp$inline_11162$$),$i$jscomp$inline_11162$$+=1;else{$h$jscomp$39_h$jscomp$inline_2561_len$jscomp$inline_11161$$=$G__24635$jscomp$inline_11164_hash$jscomp$inline_11163$$;break a}$h$jscomp$39_h$jscomp$inline_2561_len$jscomp$inline_11161$$=void 0}else $h$jscomp$39_h$jscomp$inline_2561_len$jscomp$inline_11161$$=0;else $h$jscomp$39_h$jscomp$inline_2561_len$jscomp$inline_11161$$=
0;$cljs$core$string_hash_cache$$[$JSCompiler_temp$jscomp$121_k$jscomp$42$$]=$h$jscomp$39_h$jscomp$inline_2561_len$jscomp$inline_11161$$;$cljs$core$string_hash_cache_count$$+=1;$JSCompiler_temp$jscomp$121_k$jscomp$42$$=$h$jscomp$39_h$jscomp$inline_2561_len$jscomp$inline_11161$$}return $JSCompiler_temp$jscomp$121_k$jscomp$42$$};
$APP.$cljs$core$hash$$=function($JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$){if($JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$!=null&&($JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$.$cljs$lang$protocol_mask$partition0$$&
4194304||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$.$cljs$core$IHash$$))return $JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$.$cljs$core$IHash$_hash$arity$1$(null)^0;if(typeof $JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$===
"number"){if(isFinite($JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$)){if(Number.isSafeInteger($JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$))$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$=
Math.floor($JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$)%2147483647;else{var $G__22816$jscomp$inline_11171_buf$jscomp$inline_11172_low$jscomp$inline_11174$$=new Float64Array(1);$G__22816$jscomp$inline_11171_buf$jscomp$inline_11172_low$jscomp$inline_11174$$[0]=$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$;
$G__22816$jscomp$inline_11171_buf$jscomp$inline_11172_low$jscomp$inline_11174$$=$G__22816$jscomp$inline_11171_buf$jscomp$inline_11172_low$jscomp$inline_11174$$.buffer;$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$=(new DataView($G__22816$jscomp$inline_11171_buf$jscomp$inline_11172_low$jscomp$inline_11174$$,0,4)).getInt32();$G__22816$jscomp$inline_11171_buf$jscomp$inline_11172_low$jscomp$inline_11174$$=
(new DataView($G__22816$jscomp$inline_11171_buf$jscomp$inline_11172_low$jscomp$inline_11174$$,4,4)).getInt32();$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$^=$G__22816$jscomp$inline_11171_buf$jscomp$inline_11172_low$jscomp$inline_11174$$}return $JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$}switch($JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$){case Infinity:return 2146435072;
case -Infinity:return-1048576;default:return 2146959360}}else return $JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$===!0?$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$=1231:$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$===
!1?$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$=1237:typeof $JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$==="string"?($JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$=
$cljs$core$hash_string$$($JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$),$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$=$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$===
0?$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$:$cljs$core$m3_fmix$$($cljs$core$m3_mix_H1$$(0,$cljs$core$m3_mix_K1$$($JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$)),4)):$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$=
$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$ instanceof Date?$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$.valueOf()^0:$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$==
null?0:$APP.$cljs$core$_hash$$($JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$)^0,$JSCompiler_temp$jscomp$10634_JSCompiler_temp$jscomp$117_JSCompiler_temp$jscomp$118_JSCompiler_temp$jscomp$119_high$jscomp$inline_11173_in$$jscomp$inline_2563_o$jscomp$53$$};
$cljs$core$hash_combine$$=function($seed$$,$hash$jscomp$2$$){return $seed$$^$hash$jscomp$2$$+2654435769+($seed$$<<6)+($seed$$>>2)};$cljs$core$instance_QMARK_$$=function($c$jscomp$43$$,$x$jscomp$122$$){return $x$jscomp$122$$ instanceof $c$jscomp$43$$};$cljs$core$symbol_QMARK_$$=function($x$jscomp$123$$){return $x$jscomp$123$$ instanceof $APP.$cljs$core$Symbol$$};
$cljs$core$hash_symbol$$=function($sym$jscomp$2$$){var $in$$jscomp$inline_11176$$=$sym$jscomp$2$$.name;a:{var $h1$jscomp$inline_11177_i$jscomp$inline_11178$$=1;for(var $G__24633$jscomp$inline_11180_h1$jscomp$inline_11179$$=0;;)if($h1$jscomp$inline_11177_i$jscomp$inline_11178$$<$in$$jscomp$inline_11176$$.length)$G__24633$jscomp$inline_11180_h1$jscomp$inline_11179$$=$cljs$core$m3_mix_H1$$($G__24633$jscomp$inline_11180_h1$jscomp$inline_11179$$,$cljs$core$m3_mix_K1$$($in$$jscomp$inline_11176$$.charCodeAt($h1$jscomp$inline_11177_i$jscomp$inline_11178$$-
1)|$in$$jscomp$inline_11176$$.charCodeAt($h1$jscomp$inline_11177_i$jscomp$inline_11178$$)<<16)),$h1$jscomp$inline_11177_i$jscomp$inline_11178$$+=2;else{$h1$jscomp$inline_11177_i$jscomp$inline_11178$$=$G__24633$jscomp$inline_11180_h1$jscomp$inline_11179$$;break a}$h1$jscomp$inline_11177_i$jscomp$inline_11178$$=void 0}return $cljs$core$hash_combine$$($cljs$core$m3_fmix$$(($in$$jscomp$inline_11176$$.length&1)===1?$h1$jscomp$inline_11177_i$jscomp$inline_11178$$^$cljs$core$m3_mix_K1$$($in$$jscomp$inline_11176$$.charCodeAt($in$$jscomp$inline_11176$$.length-
1)):$h1$jscomp$inline_11177_i$jscomp$inline_11178$$,(0,$APP.$cljs$core$imul$$)(2,$in$$jscomp$inline_11176$$.length)),$cljs$core$hash_string$$($sym$jscomp$2$$.ns))};
$cljs$core$compare_symbols$$=function($a$jscomp$65$$,$b$jscomp$58$$){if($a$jscomp$65$$.$str$===$b$jscomp$58$$.$str$)return 0;var $and__5023__auto__$jscomp$inline_2565_nsc$$=$APP.$cljs$core$not$$($a$jscomp$65$$.ns);if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_2565_nsc$$?$b$jscomp$58$$.ns:$and__5023__auto__$jscomp$inline_2565_nsc$$))return-1;if($APP.$cljs$core$truth_$$($a$jscomp$65$$.ns)){if($APP.$cljs$core$not$$($b$jscomp$58$$.ns))return 1;$and__5023__auto__$jscomp$inline_2565_nsc$$=
$module$contents$goog$array_defaultCompare$$($a$jscomp$65$$.ns,$b$jscomp$58$$.ns);return 0===$and__5023__auto__$jscomp$inline_2565_nsc$$?$module$contents$goog$array_defaultCompare$$($a$jscomp$65$$.name,$b$jscomp$58$$.name):$and__5023__auto__$jscomp$inline_2565_nsc$$}return $module$contents$goog$array_defaultCompare$$($a$jscomp$65$$.name,$b$jscomp$58$$.name)};
$APP.$cljs$core$Symbol$$=function($ns$jscomp$1$$,$name$jscomp$101$$,$str$jscomp$66$$,$_hash$$,$_meta$$){this.ns=$ns$jscomp$1$$;this.name=$name$jscomp$101$$;this.$str$=$str$jscomp$66$$;this.$_hash$=$_hash$$;this.$_meta$=$_meta$$;this.$cljs$lang$protocol_mask$partition0$$=2154168321;this.$cljs$lang$protocol_mask$partition1$$=4096};
$APP.$cljs$core$Var$$=function($val$jscomp$52$$,$sym$jscomp$6$$,$_meta$jscomp$2$$){this.$val$=$val$jscomp$52$$;this.$sym$=$sym$jscomp$6$$;this.$_meta$=$_meta$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=6717441;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$core$iterable_QMARK_$$=function($x$jscomp$124$$){return $x$jscomp$124$$!=null?$x$jscomp$124$$.$cljs$lang$protocol_mask$partition1$$&131072||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$124$$.$cljs$core$IIterable$$?!0:$x$jscomp$124$$.$cljs$lang$protocol_mask$partition1$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IIterable$$,$x$jscomp$124$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IIterable$$,$x$jscomp$124$$)};
$APP.$cljs$core$seq$$=function($G__22877_coll$jscomp$70$$){if($G__22877_coll$jscomp$70$$==null)return null;if($G__22877_coll$jscomp$70$$!=null&&($G__22877_coll$jscomp$70$$.$cljs$lang$protocol_mask$partition0$$&8388608||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$G__22877_coll$jscomp$70$$.$cljs$core$ISeqable$$))return $G__22877_coll$jscomp$70$$.$cljs$core$ISeqable$_seq$arity$1$(null);if($APP.$cljs$core$array_QMARK_$$($G__22877_coll$jscomp$70$$)||typeof $G__22877_coll$jscomp$70$$==="string")return $G__22877_coll$jscomp$70$$.length===
0?null:new $APP.$cljs$core$IndexedSeq$$($G__22877_coll$jscomp$70$$,0,null);if($G__22877_coll$jscomp$70$$!=null&&$G__22877_coll$jscomp$70$$[$APP.$cljs$core$ITER_SYMBOL$$]!=null)return $G__22877_coll$jscomp$70$$=$APP.$module$contents$goog$object_get$$($G__22877_coll$jscomp$70$$,$APP.$cljs$core$ITER_SYMBOL$$).call($G__22877_coll$jscomp$70$$),$cljs$core$es6_iterator_seq$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$core$es6_iterator_seq$$.$cljs$core$IFn$_invoke$arity$1$($G__22877_coll$jscomp$70$$):$cljs$core$es6_iterator_seq$$($G__22877_coll$jscomp$70$$);
if($APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ISeqable$$,$G__22877_coll$jscomp$70$$))return $cljs$core$_seq$$($G__22877_coll$jscomp$70$$);throw Error([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__22877_coll$jscomp$70$$)," is not ISeqable"].join(""));};
$APP.$cljs$core$first$$=function($coll$jscomp$71_s$jscomp$36$$){if($coll$jscomp$71_s$jscomp$36$$==null)return null;if($coll$jscomp$71_s$jscomp$36$$!=null&&($coll$jscomp$71_s$jscomp$36$$.$cljs$lang$protocol_mask$partition0$$&64||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$71_s$jscomp$36$$.$cljs$core$ISeq$$))return $coll$jscomp$71_s$jscomp$36$$.$cljs$core$ISeq$_first$arity$1$(null);$coll$jscomp$71_s$jscomp$36$$=$APP.$cljs$core$seq$$($coll$jscomp$71_s$jscomp$36$$);return $coll$jscomp$71_s$jscomp$36$$==
null?null:$cljs$core$_first$$($coll$jscomp$71_s$jscomp$36$$)};
$APP.$cljs$core$rest$$=function($coll$jscomp$72_s$jscomp$37$$){return $coll$jscomp$72_s$jscomp$37$$!=null?$coll$jscomp$72_s$jscomp$37$$!=null&&($coll$jscomp$72_s$jscomp$37$$.$cljs$lang$protocol_mask$partition0$$&64||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$72_s$jscomp$37$$.$cljs$core$ISeq$$)?$coll$jscomp$72_s$jscomp$37$$.$cljs$core$ISeq$_rest$arity$1$(null):($coll$jscomp$72_s$jscomp$37$$=$APP.$cljs$core$seq$$($coll$jscomp$72_s$jscomp$37$$))?$coll$jscomp$72_s$jscomp$37$$.$cljs$core$ISeq$_rest$arity$1$(null):
$APP.$cljs$core$List$EMPTY$$:$APP.$cljs$core$List$EMPTY$$};$APP.$cljs$core$next$$=function($coll$jscomp$73$$){return $coll$jscomp$73$$==null?null:$coll$jscomp$73$$!=null&&($coll$jscomp$73$$.$cljs$lang$protocol_mask$partition0$$&128||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$73$$.$cljs$core$INext$$)?$coll$jscomp$73$$.$cljs$core$INext$_next$arity$1$(null):$APP.$cljs$core$seq$$($APP.$cljs$core$rest$$($coll$jscomp$73$$))};$cljs$core$ES6Iterator$$=function($s$jscomp$38$$){this.s=$s$jscomp$38$$};
$APP.$cljs$core$es6_iterator$$=function($coll$jscomp$74$$){return new $cljs$core$ES6Iterator$$($APP.$cljs$core$seq$$($coll$jscomp$74$$))};$cljs$core$ES6IteratorSeq$$=function($value$jscomp$207$$,$iter$jscomp$1$$){this.value=$value$jscomp$207$$;this.$iter$=$iter$jscomp$1$$;this.$_rest$=null;this.$cljs$lang$protocol_mask$partition0$$=8388672;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$core$es6_iterator_seq$$=function($iter$jscomp$3$$){var $v$jscomp$9$$=$iter$jscomp$3$$.next();return $APP.$cljs$core$truth_$$($v$jscomp$9$$.done)?null:new $cljs$core$ES6IteratorSeq$$($v$jscomp$9$$.value,$iter$jscomp$3$$)};$APP.$cljs$core$mix_collection_hash$$=function($hash_basis$$,$count$jscomp$41$$){return $cljs$core$m3_fmix$$($cljs$core$m3_mix_H1$$(0,$cljs$core$m3_mix_K1$$($hash_basis$$)),$count$jscomp$41$$)};
$cljs$core$hash_ordered_coll$$=function($G__24797_coll$jscomp$75_coll__$1$$){var $G__24795_n$jscomp$45$$=0,$G__24796_hash_code$$=1;for($G__24797_coll$jscomp$75_coll__$1$$=$APP.$cljs$core$seq$$($G__24797_coll$jscomp$75_coll__$1$$);;)if($G__24797_coll$jscomp$75_coll__$1$$!=null)$G__24795_n$jscomp$45$$+=1,$G__24796_hash_code$$=(0,$APP.$cljs$core$imul$$)(31,$G__24796_hash_code$$)+$APP.$cljs$core$hash$$($APP.$cljs$core$first$$($G__24797_coll$jscomp$75_coll__$1$$))|0,$G__24797_coll$jscomp$75_coll__$1$$=
$APP.$cljs$core$next$$($G__24797_coll$jscomp$75_coll__$1$$);else return $APP.$cljs$core$mix_collection_hash$$($G__24796_hash_code$$,$G__24795_n$jscomp$45$$)};
$APP.$cljs$core$hash_unordered_coll$$=function($G__24802_coll$jscomp$76_coll__$1$jscomp$1$$){var $G__24800_n$jscomp$46$$=0,$G__24801_hash_code$jscomp$1$$=0;for($G__24802_coll$jscomp$76_coll__$1$jscomp$1$$=$APP.$cljs$core$seq$$($G__24802_coll$jscomp$76_coll__$1$jscomp$1$$);;)if($G__24802_coll$jscomp$76_coll__$1$jscomp$1$$!=null)$G__24800_n$jscomp$46$$+=1,$G__24801_hash_code$jscomp$1$$=$G__24801_hash_code$jscomp$1$$+$APP.$cljs$core$hash$$($APP.$cljs$core$first$$($G__24802_coll$jscomp$76_coll__$1$jscomp$1$$))|
0,$G__24802_coll$jscomp$76_coll__$1$jscomp$1$$=$APP.$cljs$core$next$$($G__24802_coll$jscomp$76_coll__$1$jscomp$1$$);else return $APP.$cljs$core$mix_collection_hash$$($G__24801_hash_code$jscomp$1$$,$G__24800_n$jscomp$46$$)};$cljs$core$Inst$$=function(){};
$APP.$cljs$core$inst_ms_STAR_$$=function($JSCompiler_temp$jscomp$123_inst$jscomp$1$$){if($JSCompiler_temp$jscomp$123_inst$jscomp$1$$!=null&&$JSCompiler_temp$jscomp$123_inst$jscomp$1$$.$cljs$core$Inst$inst_ms_STAR_$arity$1$!=null)$JSCompiler_temp$jscomp$123_inst$jscomp$1$$=$JSCompiler_temp$jscomp$123_inst$jscomp$1$$.$cljs$core$Inst$inst_ms_STAR_$arity$1$($JSCompiler_temp$jscomp$123_inst$jscomp$1$$);else{var $m__5372__auto__$jscomp$inline_2569_m__5374__auto__$jscomp$inline_2568$$=$APP.$cljs$core$inst_ms_STAR_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$123_inst$jscomp$1$$==
null?null:$JSCompiler_temp$jscomp$123_inst$jscomp$1$$)];if($m__5372__auto__$jscomp$inline_2569_m__5374__auto__$jscomp$inline_2568$$!=null)$JSCompiler_temp$jscomp$123_inst$jscomp$1$$=$m__5372__auto__$jscomp$inline_2569_m__5374__auto__$jscomp$inline_2568$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2569_m__5374__auto__$jscomp$inline_2568$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$123_inst$jscomp$1$$):$m__5372__auto__$jscomp$inline_2569_m__5374__auto__$jscomp$inline_2568$$($JSCompiler_temp$jscomp$123_inst$jscomp$1$$);
else if($m__5372__auto__$jscomp$inline_2569_m__5374__auto__$jscomp$inline_2568$$=$APP.$cljs$core$inst_ms_STAR_$$._,$m__5372__auto__$jscomp$inline_2569_m__5374__auto__$jscomp$inline_2568$$!=null)$JSCompiler_temp$jscomp$123_inst$jscomp$1$$=$m__5372__auto__$jscomp$inline_2569_m__5374__auto__$jscomp$inline_2568$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2569_m__5374__auto__$jscomp$inline_2568$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$123_inst$jscomp$1$$):$m__5372__auto__$jscomp$inline_2569_m__5374__auto__$jscomp$inline_2568$$($JSCompiler_temp$jscomp$123_inst$jscomp$1$$);
else throw $APP.$cljs$core$missing_protocol$$("Inst.inst-ms*",$JSCompiler_temp$jscomp$123_inst$jscomp$1$$);}return $JSCompiler_temp$jscomp$123_inst$jscomp$1$$};$APP.$cljs$core$inst_ms$$=function($inst$jscomp$3$$){return $APP.$cljs$core$inst_ms_STAR_$$($inst$jscomp$3$$)};
$cljs$core$inst_QMARK_$$=function($x$jscomp$130$$){return $x$jscomp$130$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$130$$.$cljs$core$Inst$$?!0:$x$jscomp$130$$.$cljs$lang$protocol_mask$partition$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$Inst$$,$x$jscomp$130$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$Inst$$,$x$jscomp$130$$)};$APP.$cljs$core$inc$$=function($x$jscomp$132$$){return $x$jscomp$132$$+1};
$cljs$core$Reduced$$=function($val$jscomp$54$$){this.$val$=$val$jscomp$54$$;this.$cljs$lang$protocol_mask$partition0$$=32768;this.$cljs$lang$protocol_mask$partition1$$=0};$APP.$cljs$core$reduced$$=function($x$jscomp$133$$){return new $cljs$core$Reduced$$($x$jscomp$133$$)};$cljs$core$reduced_QMARK_$$=function($r$jscomp$15$$){return $r$jscomp$15$$ instanceof $cljs$core$Reduced$$};
$cljs$core$unreduced$$=function($x$jscomp$135$$){return $cljs$core$reduced_QMARK_$$($x$jscomp$135$$)?$APP.$cljs$core$deref$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$deref$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$135$$):$APP.$cljs$core$_deref$$($x$jscomp$135$$):$x$jscomp$135$$};$APP.$cljs$core$deref$$=function($o$jscomp$67$$){return $APP.$cljs$core$_deref$$($o$jscomp$67$$)};
$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$=function($cicoll$$,$f$jscomp$116$$){var $cnt$$=$cicoll$$.$cljs$core$ICounted$_count$arity$1$(null);if($cnt$$===0)return $f$jscomp$116$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$116$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$116$$();for(var $G__22889$jscomp$inline_2571_nval_val$jscomp$56$$=$cicoll$$.$cljs$core$IIndexed$_nth$arity$2$(null,0),$G__24829_n$jscomp$47$$=1;;)if($G__24829_n$jscomp$47$$<$cnt$$){var $G__22890$jscomp$inline_2572$$=
$cicoll$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__24829_n$jscomp$47$$);$G__22889$jscomp$inline_2571_nval_val$jscomp$56$$=$f$jscomp$116$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$116$$.$cljs$core$IFn$_invoke$arity$2$($G__22889$jscomp$inline_2571_nval_val$jscomp$56$$,$G__22890$jscomp$inline_2572$$):$f$jscomp$116$$($G__22889$jscomp$inline_2571_nval_val$jscomp$56$$,$G__22890$jscomp$inline_2572$$);if($cljs$core$reduced_QMARK_$$($G__22889$jscomp$inline_2571_nval_val$jscomp$56$$))return $APP.$cljs$core$_deref$$($G__22889$jscomp$inline_2571_nval_val$jscomp$56$$);
$G__24829_n$jscomp$47$$+=1}else return $G__22889$jscomp$inline_2571_nval_val$jscomp$56$$};
$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$=function($cicoll$jscomp$1$$,$f$jscomp$117$$,$G__24838_n$jscomp$48_val$jscomp$57$$){var $cnt$jscomp$1$$=$cicoll$jscomp$1$$.$cljs$core$ICounted$_count$arity$1$(null),$G__22891$jscomp$inline_2574_nval$jscomp$1_val__$1$$=$G__24838_n$jscomp$48_val$jscomp$57$$;for($G__24838_n$jscomp$48_val$jscomp$57$$=0;;)if($G__24838_n$jscomp$48_val$jscomp$57$$<$cnt$jscomp$1$$){var $G__22892$jscomp$inline_2575$$=$cicoll$jscomp$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$G__24838_n$jscomp$48_val$jscomp$57$$);$G__22891$jscomp$inline_2574_nval$jscomp$1_val__$1$$=$f$jscomp$117$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$117$$.$cljs$core$IFn$_invoke$arity$2$($G__22891$jscomp$inline_2574_nval$jscomp$1_val__$1$$,$G__22892$jscomp$inline_2575$$):$f$jscomp$117$$($G__22891$jscomp$inline_2574_nval$jscomp$1_val__$1$$,$G__22892$jscomp$inline_2575$$);if($cljs$core$reduced_QMARK_$$($G__22891$jscomp$inline_2574_nval$jscomp$1_val__$1$$))return $APP.$cljs$core$_deref$$($G__22891$jscomp$inline_2574_nval$jscomp$1_val__$1$$);
$G__24838_n$jscomp$48_val$jscomp$57$$+=1}else return $G__22891$jscomp$inline_2574_nval$jscomp$1_val__$1$$};
$cljs$core$array_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$=function($arr$jscomp$66$$,$f$jscomp$118$$){var $cnt$jscomp$2$$=$arr$jscomp$66$$.length;if($arr$jscomp$66$$.length===0)return $f$jscomp$118$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$118$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$118$$();for(var $G__22895$jscomp$inline_2577_nval$jscomp$2_val$jscomp$58$$=$arr$jscomp$66$$[0],$G__24841_n$jscomp$49$$=1;;)if($G__24841_n$jscomp$49$$<$cnt$jscomp$2$$){var $G__22896$jscomp$inline_2578$$=$arr$jscomp$66$$[$G__24841_n$jscomp$49$$];
$G__22895$jscomp$inline_2577_nval$jscomp$2_val$jscomp$58$$=$f$jscomp$118$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$118$$.$cljs$core$IFn$_invoke$arity$2$($G__22895$jscomp$inline_2577_nval$jscomp$2_val$jscomp$58$$,$G__22896$jscomp$inline_2578$$):$f$jscomp$118$$($G__22895$jscomp$inline_2577_nval$jscomp$2_val$jscomp$58$$,$G__22896$jscomp$inline_2578$$);if($cljs$core$reduced_QMARK_$$($G__22895$jscomp$inline_2577_nval$jscomp$2_val$jscomp$58$$))return $APP.$cljs$core$_deref$$($G__22895$jscomp$inline_2577_nval$jscomp$2_val$jscomp$58$$);
$G__24841_n$jscomp$49$$+=1}else return $G__22895$jscomp$inline_2577_nval$jscomp$2_val$jscomp$58$$};
$cljs$core$array_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$=function($arr$jscomp$67$$,$f$jscomp$119$$,$G__24843_n$jscomp$50_val$jscomp$59$$){var $cnt$jscomp$3$$=$arr$jscomp$67$$.length,$G__22897$jscomp$inline_2580_nval$jscomp$3_val__$1$jscomp$1$$=$G__24843_n$jscomp$50_val$jscomp$59$$;for($G__24843_n$jscomp$50_val$jscomp$59$$=0;;)if($G__24843_n$jscomp$50_val$jscomp$59$$<$cnt$jscomp$3$$){var $G__22898$jscomp$inline_2581$$=$arr$jscomp$67$$[$G__24843_n$jscomp$50_val$jscomp$59$$];$G__22897$jscomp$inline_2580_nval$jscomp$3_val__$1$jscomp$1$$=
$f$jscomp$119$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$119$$.$cljs$core$IFn$_invoke$arity$2$($G__22897$jscomp$inline_2580_nval$jscomp$3_val__$1$jscomp$1$$,$G__22898$jscomp$inline_2581$$):$f$jscomp$119$$($G__22897$jscomp$inline_2580_nval$jscomp$3_val__$1$jscomp$1$$,$G__22898$jscomp$inline_2581$$);if($cljs$core$reduced_QMARK_$$($G__22897$jscomp$inline_2580_nval$jscomp$3_val__$1$jscomp$1$$))return $APP.$cljs$core$_deref$$($G__22897$jscomp$inline_2580_nval$jscomp$3_val__$1$jscomp$1$$);$G__24843_n$jscomp$50_val$jscomp$59$$+=
1}else return $G__22897$jscomp$inline_2580_nval$jscomp$3_val__$1$jscomp$1$$};
$cljs$core$array_reduce$cljs$0core$0IFn$0_invoke$0arity$04$$=function($arr$jscomp$68$$,$f$jscomp$120$$,$G__22899$jscomp$inline_2583_nval$jscomp$4_val$jscomp$60_val__$1$jscomp$2$$,$G__24845_idx$jscomp$13_n$jscomp$51$$){for(var $cnt$jscomp$4$$=$arr$jscomp$68$$.length;;)if($G__24845_idx$jscomp$13_n$jscomp$51$$<$cnt$jscomp$4$$){var $G__22900$jscomp$inline_2584$$=$arr$jscomp$68$$[$G__24845_idx$jscomp$13_n$jscomp$51$$];$G__22899$jscomp$inline_2583_nval$jscomp$4_val$jscomp$60_val__$1$jscomp$2$$=$f$jscomp$120$$.$cljs$core$IFn$_invoke$arity$2$?
$f$jscomp$120$$.$cljs$core$IFn$_invoke$arity$2$($G__22899$jscomp$inline_2583_nval$jscomp$4_val$jscomp$60_val__$1$jscomp$2$$,$G__22900$jscomp$inline_2584$$):$f$jscomp$120$$($G__22899$jscomp$inline_2583_nval$jscomp$4_val$jscomp$60_val__$1$jscomp$2$$,$G__22900$jscomp$inline_2584$$);if($cljs$core$reduced_QMARK_$$($G__22899$jscomp$inline_2583_nval$jscomp$4_val$jscomp$60_val__$1$jscomp$2$$))return $APP.$cljs$core$_deref$$($G__22899$jscomp$inline_2583_nval$jscomp$4_val$jscomp$60_val__$1$jscomp$2$$);$G__24845_idx$jscomp$13_n$jscomp$51$$+=
1}else return $G__22899$jscomp$inline_2583_nval$jscomp$4_val$jscomp$60_val__$1$jscomp$2$$};
$cljs$core$counted_QMARK_$$=function($x$jscomp$136$$){return $x$jscomp$136$$!=null?$x$jscomp$136$$.$cljs$lang$protocol_mask$partition0$$&2||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$136$$.$cljs$core$ICounted$$?!0:$x$jscomp$136$$.$cljs$lang$protocol_mask$partition0$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ICounted$$,$x$jscomp$136$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ICounted$$,$x$jscomp$136$$)};
$cljs$core$indexed_QMARK_$$=function($x$jscomp$137$$){return $x$jscomp$137$$!=null?$x$jscomp$137$$.$cljs$lang$protocol_mask$partition0$$&16||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$137$$.$cljs$core$IIndexed$$?!0:$x$jscomp$137$$.$cljs$lang$protocol_mask$partition0$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IIndexed$$,$x$jscomp$137$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IIndexed$$,$x$jscomp$137$$)};
$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$=function($coll$jscomp$78$$,$x$jscomp$139$$,$JSCompiler_temp$jscomp$124_JSCompiler_temp$jscomp$125_idx$jscomp$14_start$jscomp$19_y__5111__auto__$jscomp$inline_2586$$){var $len$jscomp$12$$=$APP.$cljs$core$count$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$count$$.$cljs$core$IFn$_invoke$arity$1$($coll$jscomp$78$$):$APP.$cljs$core$count$$($coll$jscomp$78$$);if($JSCompiler_temp$jscomp$124_JSCompiler_temp$jscomp$125_idx$jscomp$14_start$jscomp$19_y__5111__auto__$jscomp$inline_2586$$>=
$len$jscomp$12$$)return-1;!($JSCompiler_temp$jscomp$124_JSCompiler_temp$jscomp$125_idx$jscomp$14_start$jscomp$19_y__5111__auto__$jscomp$inline_2586$$>0)&&$JSCompiler_temp$jscomp$124_JSCompiler_temp$jscomp$125_idx$jscomp$14_start$jscomp$19_y__5111__auto__$jscomp$inline_2586$$<0&&($JSCompiler_temp$jscomp$124_JSCompiler_temp$jscomp$125_idx$jscomp$14_start$jscomp$19_y__5111__auto__$jscomp$inline_2586$$+=$len$jscomp$12$$,$JSCompiler_temp$jscomp$124_JSCompiler_temp$jscomp$125_idx$jscomp$14_start$jscomp$19_y__5111__auto__$jscomp$inline_2586$$=
0>$JSCompiler_temp$jscomp$124_JSCompiler_temp$jscomp$125_idx$jscomp$14_start$jscomp$19_y__5111__auto__$jscomp$inline_2586$$?0:$JSCompiler_temp$jscomp$124_JSCompiler_temp$jscomp$125_idx$jscomp$14_start$jscomp$19_y__5111__auto__$jscomp$inline_2586$$);for(;;)if($JSCompiler_temp$jscomp$124_JSCompiler_temp$jscomp$125_idx$jscomp$14_start$jscomp$19_y__5111__auto__$jscomp$inline_2586$$<$len$jscomp$12$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$?
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($coll$jscomp$78$$,$JSCompiler_temp$jscomp$124_JSCompiler_temp$jscomp$125_idx$jscomp$14_start$jscomp$19_y__5111__auto__$jscomp$inline_2586$$):$cljs$core$nth$$($coll$jscomp$78$$,$JSCompiler_temp$jscomp$124_JSCompiler_temp$jscomp$125_idx$jscomp$14_start$jscomp$19_y__5111__auto__$jscomp$inline_2586$$),$x$jscomp$139$$))return $JSCompiler_temp$jscomp$124_JSCompiler_temp$jscomp$125_idx$jscomp$14_start$jscomp$19_y__5111__auto__$jscomp$inline_2586$$;
$JSCompiler_temp$jscomp$124_JSCompiler_temp$jscomp$125_idx$jscomp$14_start$jscomp$19_y__5111__auto__$jscomp$inline_2586$$+=1}else return-1};
$cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$=function($coll$jscomp$80$$,$x$jscomp$141$$,$JSCompiler_temp$jscomp$126_idx$jscomp$15_start$jscomp$20$$){var $len$jscomp$13_x__5113__auto__$jscomp$inline_2588$$=$APP.$cljs$core$count$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$count$$.$cljs$core$IFn$_invoke$arity$1$($coll$jscomp$80$$):$APP.$cljs$core$count$$($coll$jscomp$80$$);if($len$jscomp$13_x__5113__auto__$jscomp$inline_2588$$===0)return-1;$JSCompiler_temp$jscomp$126_idx$jscomp$15_start$jscomp$20$$>
0?(--$len$jscomp$13_x__5113__auto__$jscomp$inline_2588$$,$JSCompiler_temp$jscomp$126_idx$jscomp$15_start$jscomp$20$$=$len$jscomp$13_x__5113__auto__$jscomp$inline_2588$$<$JSCompiler_temp$jscomp$126_idx$jscomp$15_start$jscomp$20$$?$len$jscomp$13_x__5113__auto__$jscomp$inline_2588$$:$JSCompiler_temp$jscomp$126_idx$jscomp$15_start$jscomp$20$$):$JSCompiler_temp$jscomp$126_idx$jscomp$15_start$jscomp$20$$=$JSCompiler_temp$jscomp$126_idx$jscomp$15_start$jscomp$20$$<0?$len$jscomp$13_x__5113__auto__$jscomp$inline_2588$$+
$JSCompiler_temp$jscomp$126_idx$jscomp$15_start$jscomp$20$$:$JSCompiler_temp$jscomp$126_idx$jscomp$15_start$jscomp$20$$;for(;;)if($JSCompiler_temp$jscomp$126_idx$jscomp$15_start$jscomp$20$$>=0){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($coll$jscomp$80$$,$JSCompiler_temp$jscomp$126_idx$jscomp$15_start$jscomp$20$$):$cljs$core$nth$$($coll$jscomp$80$$,$JSCompiler_temp$jscomp$126_idx$jscomp$15_start$jscomp$20$$),
$x$jscomp$141$$))return $JSCompiler_temp$jscomp$126_idx$jscomp$15_start$jscomp$20$$;--$JSCompiler_temp$jscomp$126_idx$jscomp$15_start$jscomp$20$$}else return-1};$cljs$core$IndexedSeqIterator$$=function($arr$jscomp$69$$,$i$jscomp$162$$){this.$arr$=$arr$jscomp$69$$;this.i=$i$jscomp$162$$};
$APP.$cljs$core$IndexedSeq$$=function($arr$jscomp$71$$,$i$jscomp$164$$,$meta$jscomp$2$$){this.$arr$=$arr$jscomp$71$$;this.i=$i$jscomp$164$$;this.$meta$=$meta$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=166592766;this.$cljs$lang$protocol_mask$partition1$$=401408};$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$=function($prim$jscomp$1$$){return 0<$prim$jscomp$1$$.length?new $APP.$cljs$core$IndexedSeq$$($prim$jscomp$1$$,0,null):null};
$APP.$cljs$core$RSeq$$=function($ci$$,$i$jscomp$168$$,$meta$jscomp$4$$){this.ci=$ci$$;this.i=$i$jscomp$168$$;this.$meta$=$meta$jscomp$4$$;this.$cljs$lang$protocol_mask$partition0$$=32374990;this.$cljs$lang$protocol_mask$partition1$$=8192};$APP.$cljs$core$second$$=function($coll$jscomp$115$$){return $APP.$cljs$core$first$$($APP.$cljs$core$next$$($coll$jscomp$115$$))};$APP.$cljs$core$ffirst$$=function($coll$jscomp$116$$){return $APP.$cljs$core$first$$($APP.$cljs$core$first$$($coll$jscomp$116$$))};
$APP.$cljs$core$fnext$$=function($coll$jscomp$118$$){return $APP.$cljs$core$first$$($APP.$cljs$core$next$$($coll$jscomp$118$$))};$APP.$cljs$core$last$$=function($s$jscomp$40$$){for(;;){var $sn$$=$APP.$cljs$core$next$$($s$jscomp$40$$);if($sn$$!=null)$s$jscomp$40$$=$sn$$;else return $APP.$cljs$core$first$$($s$jscomp$40$$)}};
$APP.$cljs$core$empty$$=function($coll$jscomp$123$$){return $coll$jscomp$123$$==null?null:$coll$jscomp$123$$!=null&&($coll$jscomp$123$$.$cljs$lang$protocol_mask$partition0$$&4||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$123$$.$cljs$core$IEmptyableCollection$$)?$coll$jscomp$123$$.$cljs$core$IEmptyableCollection$_empty$arity$1$(null):($coll$jscomp$123$$!=null?$coll$jscomp$123$$.$cljs$lang$protocol_mask$partition0$$&4||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$123$$.$cljs$core$IEmptyableCollection$$||
($coll$jscomp$123$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IEmptyableCollection$$,$coll$jscomp$123$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IEmptyableCollection$$,$coll$jscomp$123$$))?$cljs$core$_empty$$($coll$jscomp$123$$):null};
$APP.$cljs$core$count$$=function($G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$){if($G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$!=null)if($G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$!=
null&&($G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$.$cljs$lang$protocol_mask$partition0$$&2||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$.$cljs$core$ICounted$$))$G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$=
$G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$.$cljs$core$ICounted$_count$arity$1$(null);else if($APP.$cljs$core$array_QMARK_$$($G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$))$G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$=
$G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$.length;else if(typeof $G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$==="string")$G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$=
$G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$.length;else if($G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$!=null&&($G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$.$cljs$lang$protocol_mask$partition0$$&
8388608||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$.$cljs$core$ISeqable$$))a:{$G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$=$APP.$cljs$core$seq$$($G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$);
for(var $G__24894$jscomp$inline_2594_acc$jscomp$inline_2592$$=0;;){if($cljs$core$counted_QMARK_$$($G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$)){$G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$=
$G__24894$jscomp$inline_2594_acc$jscomp$inline_2592$$+$APP.$cljs$core$_count$$($G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$);break a}$G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$=$APP.$cljs$core$next$$($G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$);
$G__24894$jscomp$inline_2594_acc$jscomp$inline_2592$$+=1}$G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$=void 0}else $G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$=$APP.$cljs$core$_count$$($G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$);
else $G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$=0;return $G__24893$jscomp$inline_2593_JSCompiler_temp$jscomp$127_JSCompiler_temp$jscomp$128_JSCompiler_temp$jscomp$129_JSCompiler_temp$jscomp$130_JSCompiler_temp$jscomp$131_coll$jscomp$125_s$jscomp$inline_2591$$};
$cljs$core$linear_traversal_nth$cljs$0core$0IFn$0_invoke$0arity$03$$=function($G__24898_coll$jscomp$127$$,$G__24899_n$jscomp$56$$,$G__24900_not_found$jscomp$8$$){for(;;){if($G__24898_coll$jscomp$127$$==null)return $G__24900_not_found$jscomp$8$$;if($G__24899_n$jscomp$56$$===0)return $APP.$cljs$core$seq$$($G__24898_coll$jscomp$127$$)?$APP.$cljs$core$first$$($G__24898_coll$jscomp$127$$):$G__24900_not_found$jscomp$8$$;if($cljs$core$indexed_QMARK_$$($G__24898_coll$jscomp$127$$))return $APP.$cljs$core$_nth$$($G__24898_coll$jscomp$127$$,
$G__24899_n$jscomp$56$$,$G__24900_not_found$jscomp$8$$);if($APP.$cljs$core$seq$$($G__24898_coll$jscomp$127$$))$G__24898_coll$jscomp$127$$=$APP.$cljs$core$next$$($G__24898_coll$jscomp$127$$),--$G__24899_n$jscomp$56$$;else return $G__24900_not_found$jscomp$8$$}};
$cljs$core$nth$$=function($var_args$jscomp$107$$){switch(arguments.length){case 2:return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);case 3:return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$=function($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$,$G__24897$jscomp$inline_11186_n$jscomp$57_n$jscomp$inline_11184$$){if(typeof $G__24897$jscomp$inline_11186_n$jscomp$57_n$jscomp$inline_11184$$!=="number")throw Error("Index argument to nth must be a number");if($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$==null)return $G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$;
if($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$!=null&&($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$.$cljs$lang$protocol_mask$partition0$$&16||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$.$cljs$core$IIndexed$$))return $G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$G__24897$jscomp$inline_11186_n$jscomp$57_n$jscomp$inline_11184$$);if($APP.$cljs$core$array_QMARK_$$($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$)){if(-1<$G__24897$jscomp$inline_11186_n$jscomp$57_n$jscomp$inline_11184$$&&$G__24897$jscomp$inline_11186_n$jscomp$57_n$jscomp$inline_11184$$<$G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$.length)return $G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$[$G__24897$jscomp$inline_11186_n$jscomp$57_n$jscomp$inline_11184$$|
0];throw Error("Index out of bounds");}if(typeof $G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$==="string"){if(-1<$G__24897$jscomp$inline_11186_n$jscomp$57_n$jscomp$inline_11184$$&&$G__24897$jscomp$inline_11186_n$jscomp$57_n$jscomp$inline_11184$$<$G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$.length)return $G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$.charAt($G__24897$jscomp$inline_11186_n$jscomp$57_n$jscomp$inline_11184$$|
0);throw Error("Index out of bounds");}if($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$!=null&&($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$.$cljs$lang$protocol_mask$partition0$$&64||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$.$cljs$core$ISeq$$)||$G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$!=
null&&($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$.$cljs$lang$protocol_mask$partition0$$&16777216||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$.$cljs$core$ISequential$$)){if($G__24897$jscomp$inline_11186_n$jscomp$57_n$jscomp$inline_11184$$<0)throw Error("Index out of bounds");a:{for(;;){if($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$==
null)throw Error("Index out of bounds");if($G__24897$jscomp$inline_11186_n$jscomp$57_n$jscomp$inline_11184$$===0){if($APP.$cljs$core$seq$$($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$)){$G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$=$APP.$cljs$core$first$$($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$);break a}throw Error("Index out of bounds");
}if($cljs$core$indexed_QMARK_$$($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$)){$G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$=$APP.$cljs$core$_nth$$($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$,$G__24897$jscomp$inline_11186_n$jscomp$57_n$jscomp$inline_11184$$);break a}if($APP.$cljs$core$seq$$($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$))$G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$=
$APP.$cljs$core$next$$($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$),--$G__24897$jscomp$inline_11186_n$jscomp$57_n$jscomp$inline_11184$$;else throw Error("Index out of bounds");}$G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$=void 0}return $G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$}if($APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IIndexed$$,
$G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$))return $APP.$cljs$core$_nth$$($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$,$G__24897$jscomp$inline_11186_n$jscomp$57_n$jscomp$inline_11184$$);throw Error(["nth not supported on this type ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$core$type__GT_str$$($APP.$cljs$core$type$$($G__24896$jscomp$inline_11185_JSCompiler_inline_result$jscomp$10636_coll$jscomp$128_coll$jscomp$inline_11183$$)))].join(""));
};
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$=function($coll$jscomp$129$$,$n$jscomp$58$$,$not_found$jscomp$9$$){if(typeof $n$jscomp$58$$!=="number")throw Error("Index argument to nth must be a number.");if($coll$jscomp$129$$==null)return $not_found$jscomp$9$$;if($coll$jscomp$129$$!=null&&($coll$jscomp$129$$.$cljs$lang$protocol_mask$partition0$$&16||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$129$$.$cljs$core$IIndexed$$))return $coll$jscomp$129$$.$cljs$core$IIndexed$_nth$arity$3$(null,$n$jscomp$58$$,
$not_found$jscomp$9$$);if($APP.$cljs$core$array_QMARK_$$($coll$jscomp$129$$))return-1<$n$jscomp$58$$&&$n$jscomp$58$$<$coll$jscomp$129$$.length?$coll$jscomp$129$$[$n$jscomp$58$$|0]:$not_found$jscomp$9$$;if(typeof $coll$jscomp$129$$==="string")return-1<$n$jscomp$58$$&&$n$jscomp$58$$<$coll$jscomp$129$$.length?$coll$jscomp$129$$.charAt($n$jscomp$58$$|0):$not_found$jscomp$9$$;if($coll$jscomp$129$$!=null&&($coll$jscomp$129$$.$cljs$lang$protocol_mask$partition0$$&64||$APP.$cljs$core$PROTOCOL_SENTINEL$$===
$coll$jscomp$129$$.$cljs$core$ISeq$$)||$coll$jscomp$129$$!=null&&($coll$jscomp$129$$.$cljs$lang$protocol_mask$partition0$$&16777216||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$129$$.$cljs$core$ISequential$$))return $n$jscomp$58$$<0?$not_found$jscomp$9$$:$cljs$core$linear_traversal_nth$cljs$0core$0IFn$0_invoke$0arity$03$$($coll$jscomp$129$$,$n$jscomp$58$$,$not_found$jscomp$9$$);if($APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IIndexed$$,$coll$jscomp$129$$))return $APP.$cljs$core$_nth$$($coll$jscomp$129$$,
$n$jscomp$58$$,$not_found$jscomp$9$$);throw Error(["nth not supported on this type ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$core$type__GT_str$$($APP.$cljs$core$type$$($coll$jscomp$129$$)))].join(""));};
$APP.$cljs$core$fn_QMARK_$$=function($f$jscomp$125$$){var $or__5025__auto__$jscomp$3$$=typeof $f$jscomp$125$$==="function";return $or__5025__auto__$jscomp$3$$?$or__5025__auto__$jscomp$3$$:$f$jscomp$125$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$f$jscomp$125$$.$cljs$core$Fn$$?!0:$f$jscomp$125$$.$cljs$lang$protocol_mask$partition$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$Fn$$,$f$jscomp$125$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$Fn$$,$f$jscomp$125$$)};
$cljs$core$MetaFn$$=function($afn$$,$meta$jscomp$6$$){this.$afn$=$afn$$;this.$meta$=$meta$jscomp$6$$;this.$cljs$lang$protocol_mask$partition0$$=393217;this.$cljs$lang$protocol_mask$partition1$$=0};$APP.$cljs$core$with_meta$$=function($o$jscomp$80$$,$meta$jscomp$8$$){return typeof $o$jscomp$80$$==="function"?new $cljs$core$MetaFn$$($o$jscomp$80$$,$meta$jscomp$8$$):$o$jscomp$80$$==null?null:$APP.$cljs$core$_with_meta$$($o$jscomp$80$$,$meta$jscomp$8$$)};
$APP.$cljs$core$meta$$=function($o$jscomp$81$$){var $and__5023__auto__$jscomp$inline_2600$$=$o$jscomp$81$$!=null;return($and__5023__auto__$jscomp$inline_2600$$?$o$jscomp$81$$!=null?$o$jscomp$81$$.$cljs$lang$protocol_mask$partition0$$&131072||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$o$jscomp$81$$.$cljs$core$IMeta$$||($o$jscomp$81$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IMeta$$,$o$jscomp$81$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IMeta$$,
$o$jscomp$81$$):$and__5023__auto__$jscomp$inline_2600$$)?$cljs$core$_meta$$($o$jscomp$81$$):null};$APP.$cljs$core$peek$$=function($coll$jscomp$136$$){return $coll$jscomp$136$$==null?null:$cljs$core$_peek$$($coll$jscomp$136$$)};$APP.$cljs$core$pop$$=function($coll$jscomp$137$$){return $coll$jscomp$137$$==null?null:$cljs$core$_pop$$($coll$jscomp$137$$)};
$APP.$cljs$core$empty_QMARK_$$=function($coll$jscomp$141$$){return $coll$jscomp$141$$==null?!0:($coll$jscomp$141$$!=null?$coll$jscomp$141$$.$cljs$lang$protocol_mask$partition0$$&2||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$141$$.$cljs$core$ICounted$$||($coll$jscomp$141$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ICounted$$,$coll$jscomp$141$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ICounted$$,$coll$jscomp$141$$))?$APP.$cljs$core$_count$$($coll$jscomp$141$$)===
0:$APP.$cljs$core$not$$($APP.$cljs$core$seq$$($coll$jscomp$141$$))};
$APP.$cljs$core$coll_QMARK_$$=function($x$jscomp$157$$){return $x$jscomp$157$$==null?!1:$x$jscomp$157$$!=null?$x$jscomp$157$$.$cljs$lang$protocol_mask$partition0$$&8||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$157$$.$cljs$core$ICollection$$?!0:$x$jscomp$157$$.$cljs$lang$protocol_mask$partition0$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ICollection$$,$x$jscomp$157$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ICollection$$,$x$jscomp$157$$)};
$APP.$cljs$core$set_QMARK_$$=function($x$jscomp$158$$){return $x$jscomp$158$$==null?!1:$x$jscomp$158$$!=null?$x$jscomp$158$$.$cljs$lang$protocol_mask$partition0$$&4096||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$158$$.$cljs$core$ISet$$?!0:$x$jscomp$158$$.$cljs$lang$protocol_mask$partition0$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ISet$$,$x$jscomp$158$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ISet$$,$x$jscomp$158$$)};
$APP.$cljs$core$associative_QMARK_$$=function($x$jscomp$159$$){return $x$jscomp$159$$!=null?$x$jscomp$159$$.$cljs$lang$protocol_mask$partition0$$&512||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$159$$.$cljs$core$IAssociative$$?!0:$x$jscomp$159$$.$cljs$lang$protocol_mask$partition0$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IAssociative$$,$x$jscomp$159$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IAssociative$$,$x$jscomp$159$$)};
$APP.$cljs$core$sequential_QMARK_$$=function($x$jscomp$161$$){return $x$jscomp$161$$!=null?$x$jscomp$161$$.$cljs$lang$protocol_mask$partition0$$&16777216||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$161$$.$cljs$core$ISequential$$?!0:$x$jscomp$161$$.$cljs$lang$protocol_mask$partition0$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ISequential$$,$x$jscomp$161$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ISequential$$,$x$jscomp$161$$)};
$APP.$cljs$core$map_QMARK_$$=function($x$jscomp$164$$){return $x$jscomp$164$$==null?!1:$x$jscomp$164$$!=null?$x$jscomp$164$$.$cljs$lang$protocol_mask$partition0$$&1024||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$164$$.$cljs$core$IMap$$?!0:$x$jscomp$164$$.$cljs$lang$protocol_mask$partition0$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IMap$$,$x$jscomp$164$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IMap$$,$x$jscomp$164$$)};
$APP.$cljs$core$record_QMARK_$$=function($x$jscomp$165$$){return $x$jscomp$165$$!=null?$x$jscomp$165$$.$cljs$lang$protocol_mask$partition0$$&67108864||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$165$$.$cljs$core$IRecord$$?!0:$x$jscomp$165$$.$cljs$lang$protocol_mask$partition0$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IRecord$$,$x$jscomp$165$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IRecord$$,$x$jscomp$165$$)};
$APP.$cljs$core$vector_QMARK_$$=function($x$jscomp$166$$){return $x$jscomp$166$$!=null?$x$jscomp$166$$.$cljs$lang$protocol_mask$partition0$$&16384||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$166$$.$cljs$core$IVector$$?!0:$x$jscomp$166$$.$cljs$lang$protocol_mask$partition0$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IVector$$,$x$jscomp$166$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IVector$$,$x$jscomp$166$$)};
$APP.$cljs$core$chunked_seq_QMARK_$$=function($x$jscomp$167$$){return $x$jscomp$167$$!=null?$x$jscomp$167$$.$cljs$lang$protocol_mask$partition1$$&512||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$167$$.$cljs$core$IChunkedSeq$$?!0:!1:!1};
$cljs$core$array_copy$$=function($from$$,$i$jscomp$183_i__$1$jscomp$2$$,$to$$,$G__25064_j$jscomp$59_j__$1$$,$G__25065_len$jscomp$14_len__$1$$){for(;;){if($G__25065_len$jscomp$14_len__$1$$===0)return $to$$;$to$$[$G__25064_j$jscomp$59_j__$1$$]=$from$$[$i$jscomp$183_i__$1$jscomp$2$$];$G__25064_j$jscomp$59_j__$1$$+=1;--$G__25065_len$jscomp$14_len__$1$$;$i$jscomp$183_i__$1$jscomp$2$$+=1}};$cljs$core$false_QMARK_$$=function($x$jscomp$168$$){return $x$jscomp$168$$===!1};
$APP.$cljs$core$true_QMARK_$$=function($x$jscomp$169$$){return $x$jscomp$169$$===!0};$APP.$cljs$core$boolean_QMARK_$$=function($x$jscomp$170$$){return $x$jscomp$170$$===!0||$x$jscomp$170$$===!1};
$APP.$cljs$core$seq_QMARK_$$=function($s$jscomp$45$$){return $s$jscomp$45$$==null?!1:$s$jscomp$45$$!=null?$s$jscomp$45$$.$cljs$lang$protocol_mask$partition0$$&64||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$s$jscomp$45$$.$cljs$core$ISeq$$?!0:$s$jscomp$45$$.$cljs$lang$protocol_mask$partition0$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ISeq$$,$s$jscomp$45$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ISeq$$,$s$jscomp$45$$)};
$APP.$cljs$core$seqable_QMARK_$$=function($s$jscomp$46$$){var $or__5025__auto__$jscomp$4_or__5025__auto____$1$$=$s$jscomp$46$$==null;return $or__5025__auto__$jscomp$4_or__5025__auto____$1$$?$or__5025__auto__$jscomp$4_or__5025__auto____$1$$:($or__5025__auto__$jscomp$4_or__5025__auto____$1$$=$s$jscomp$46$$!=null?$s$jscomp$46$$.$cljs$lang$protocol_mask$partition0$$&8388608||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$s$jscomp$46$$.$cljs$core$ISeqable$$?!0:$s$jscomp$46$$.$cljs$lang$protocol_mask$partition0$$?
!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ISeqable$$,$s$jscomp$46$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ISeqable$$,$s$jscomp$46$$))?$or__5025__auto__$jscomp$4_or__5025__auto____$1$$:$s$jscomp$46$$!=null&&$s$jscomp$46$$[$APP.$cljs$core$ITER_SYMBOL$$]!=null||$APP.$cljs$core$array_QMARK_$$($s$jscomp$46$$)||typeof $s$jscomp$46$$==="string"};$APP.$cljs$core$boolean$0$$=function($x$jscomp$172$$){return $x$jscomp$172$$==null?!1:$x$jscomp$172$$===!1?!1:!0};
$cljs$core$ifn_QMARK_$$=function($f$jscomp$142$$){var $or__5025__auto__$jscomp$5$$=$APP.$cljs$core$fn_QMARK_$$($f$jscomp$142$$);return $or__5025__auto__$jscomp$5$$?$or__5025__auto__$jscomp$5$$:$f$jscomp$142$$!=null?$f$jscomp$142$$.$cljs$lang$protocol_mask$partition0$$&1||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$f$jscomp$142$$.$cljs$core$IFn$$?!0:$f$jscomp$142$$.$cljs$lang$protocol_mask$partition0$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IFn$$,$f$jscomp$142$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IFn$$,
$f$jscomp$142$$)};$APP.$cljs$core$integer_QMARK_$$=function($n$jscomp$68$$){return typeof $n$jscomp$68$$==="number"&&!isNaN($n$jscomp$68$$)&&$n$jscomp$68$$!==Infinity&&parseFloat($n$jscomp$68$$)===parseInt($n$jscomp$68$$,10)};$APP.$cljs$core$int_QMARK_$$=function($x$jscomp$173$$){return $APP.$cljs$core$integer_QMARK_$$($x$jscomp$173$$)||$x$jscomp$173$$ instanceof $module$contents$goog$math$Long_Long$$};
$cljs$core$pos_int_QMARK_$$=function($x$jscomp$174$$){return $APP.$cljs$core$integer_QMARK_$$($x$jscomp$174$$)?$x$jscomp$174$$>0:$x$jscomp$174$$ instanceof $module$contents$goog$math$Long_Long$$?$APP.$cljs$core$not$$($x$jscomp$174$$.$high_$<0)&&$APP.$cljs$core$not$$($x$jscomp$174$$.$isZero$()):!1};
$cljs$core$neg_int_QMARK_$$=function($x$jscomp$175$$){return $APP.$cljs$core$integer_QMARK_$$($x$jscomp$175$$)?$x$jscomp$175$$<0:$x$jscomp$175$$ instanceof $module$contents$goog$math$Long_Long$$?$x$jscomp$175$$.$high_$<0:!1};$APP.$cljs$core$nat_int_QMARK_$$=function($x$jscomp$176$$){return $APP.$cljs$core$integer_QMARK_$$($x$jscomp$176$$)?!($x$jscomp$176$$<0):$x$jscomp$176$$ instanceof $module$contents$goog$math$Long_Long$$?$APP.$cljs$core$not$$($x$jscomp$176$$.$high_$<0):!1};
$cljs$core$float_QMARK_$$=function($x$jscomp$177$$){return typeof $x$jscomp$177$$==="number"};$cljs$core$double_QMARK_$$=function($x$jscomp$178$$){return typeof $x$jscomp$178$$==="number"};
$APP.$cljs$core$contains_QMARK_$$=function($coll$jscomp$142$$,$v$jscomp$12$$){return $coll$jscomp$142$$!=null&&($coll$jscomp$142$$.$cljs$lang$protocol_mask$partition0$$&512||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$142$$.$cljs$core$IAssociative$$)?$coll$jscomp$142$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$(null,$v$jscomp$12$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IAssociative$$,$coll$jscomp$142$$)?$APP.$cljs$core$_contains_key_QMARK_$$($coll$jscomp$142$$,$v$jscomp$12$$):
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($coll$jscomp$142$$,$v$jscomp$12$$,$cljs$core$lookup_sentinel$$)===$cljs$core$lookup_sentinel$$?!1:!0};
$cljs$core$find$$=function($coll$jscomp$143$$,$k$jscomp$73$$){return($coll$jscomp$143$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$143$$.$cljs$core$IFind$$||($coll$jscomp$143$$.$cljs$lang$protocol_mask$partition$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IFind$$,$coll$jscomp$143$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IFind$$,$coll$jscomp$143$$))?$cljs$core$_find$$($coll$jscomp$143$$,$k$jscomp$73$$):$coll$jscomp$143$$!=null&&$APP.$cljs$core$associative_QMARK_$$($coll$jscomp$143$$)&&
$APP.$cljs$core$contains_QMARK_$$($coll$jscomp$143$$,$k$jscomp$73$$)?new $APP.$cljs$core$MapEntry$$($k$jscomp$73$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($coll$jscomp$143$$,$k$jscomp$73$$),null):null};
$APP.$cljs$core$compare$$=function($x$jscomp$183$$,$y$jscomp$86$$){if($x$jscomp$183$$===$y$jscomp$86$$)return 0;if($x$jscomp$183$$==null)return-1;if($y$jscomp$86$$==null)return 1;if(typeof $x$jscomp$183$$==="number"){if(typeof $y$jscomp$86$$==="number")return $module$contents$goog$array_defaultCompare$$($x$jscomp$183$$,$y$jscomp$86$$);throw Error(["Cannot compare ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$183$$)," to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$86$$)].join(""));
}if($x$jscomp$183$$!=null?$x$jscomp$183$$.$cljs$lang$protocol_mask$partition1$$&2048||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$183$$.$cljs$core$IComparable$$||($x$jscomp$183$$.$cljs$lang$protocol_mask$partition1$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IComparable$$,$x$jscomp$183$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IComparable$$,$x$jscomp$183$$))return $APP.$cljs$core$_compare$$($x$jscomp$183$$,$y$jscomp$86$$);if(typeof $x$jscomp$183$$!=="string"&&!$APP.$cljs$core$array_QMARK_$$($x$jscomp$183$$)&&
$x$jscomp$183$$!==!0&&$x$jscomp$183$$!==!1||$APP.$cljs$core$type$$($x$jscomp$183$$)!==$APP.$cljs$core$type$$($y$jscomp$86$$))throw Error(["Cannot compare ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$183$$)," to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$86$$)].join(""));return $module$contents$goog$array_defaultCompare$$($x$jscomp$183$$,$y$jscomp$86$$)};
$cljs$core$compare_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$=function($JSCompiler_temp$jscomp$136_JSCompiler_temp$jscomp$137_JSCompiler_temp$jscomp$138_xs$jscomp$8$$,$ys$$){var $xl$$=$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$136_JSCompiler_temp$jscomp$137_JSCompiler_temp$jscomp$138_xs$jscomp$8$$),$n$jscomp$inline_2607_yl$$=$APP.$cljs$core$count$$($ys$$);if($xl$$<$n$jscomp$inline_2607_yl$$)$JSCompiler_temp$jscomp$136_JSCompiler_temp$jscomp$137_JSCompiler_temp$jscomp$138_xs$jscomp$8$$=-1;else if($xl$$>
$n$jscomp$inline_2607_yl$$)$JSCompiler_temp$jscomp$136_JSCompiler_temp$jscomp$137_JSCompiler_temp$jscomp$138_xs$jscomp$8$$=1;else if($xl$$===0)$JSCompiler_temp$jscomp$136_JSCompiler_temp$jscomp$137_JSCompiler_temp$jscomp$138_xs$jscomp$8$$=0;else a:{for($n$jscomp$inline_2607_yl$$=0;;){var $d$jscomp$inline_2608$$=$APP.$cljs$core$compare$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$136_JSCompiler_temp$jscomp$137_JSCompiler_temp$jscomp$138_xs$jscomp$8$$,$n$jscomp$inline_2607_yl$$),
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($ys$$,$n$jscomp$inline_2607_yl$$));if($d$jscomp$inline_2608$$===0&&$n$jscomp$inline_2607_yl$$+1<$xl$$)$n$jscomp$inline_2607_yl$$+=1;else{$JSCompiler_temp$jscomp$136_JSCompiler_temp$jscomp$137_JSCompiler_temp$jscomp$138_xs$jscomp$8$$=$d$jscomp$inline_2608$$;break a}}$JSCompiler_temp$jscomp$136_JSCompiler_temp$jscomp$137_JSCompiler_temp$jscomp$138_xs$jscomp$8$$=void 0}return $JSCompiler_temp$jscomp$136_JSCompiler_temp$jscomp$137_JSCompiler_temp$jscomp$138_xs$jscomp$8$$};
$cljs$core$fn__GT_comparator$$=function($f$jscomp$143$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$143$$,$APP.$cljs$core$compare$$)?$APP.$cljs$core$compare$$:function($x$jscomp$184$$,$y$jscomp$87$$){var $r$jscomp$20$$=$f$jscomp$143$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$143$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$184$$,$y$jscomp$87$$):$f$jscomp$143$$($x$jscomp$184$$,$y$jscomp$87$$);return typeof $r$jscomp$20$$==="number"?$r$jscomp$20$$:$APP.$cljs$core$truth_$$($r$jscomp$20$$)?
-1:$APP.$cljs$core$truth_$$($f$jscomp$143$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$143$$.$cljs$core$IFn$_invoke$arity$2$($y$jscomp$87$$,$x$jscomp$184$$):$f$jscomp$143$$($y$jscomp$87$$,$x$jscomp$184$$))?1:0}};
$APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$02$$=function($comp$$,$coll$jscomp$145$$){if($APP.$cljs$core$seq$$($coll$jscomp$145$$)){var $a$jscomp$108$$=$APP.$cljs$core$to_array$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$to_array$$.$cljs$core$IFn$_invoke$arity$1$($coll$jscomp$145$$):$APP.$cljs$core$to_array$$($coll$jscomp$145$$);$module$contents$goog$array_stableSort$$($a$jscomp$108$$,$cljs$core$fn__GT_comparator$$($comp$$));return $APP.$cljs$core$with_meta$$($APP.$cljs$core$seq$$($a$jscomp$108$$),
$APP.$cljs$core$meta$$($coll$jscomp$145$$))}return $APP.$cljs$core$List$EMPTY$$};$cljs$core$seq_reduce$$=function($var_args$jscomp$117$$){switch(arguments.length){case 2:return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);case 3:return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$144$$,$G__22997_coll$jscomp$148$$){var $G__22998_temp__5823__auto__$jscomp$2$$=$APP.$cljs$core$seq$$($G__22997_coll$jscomp$148$$);return $G__22998_temp__5823__auto__$jscomp$2$$?($G__22997_coll$jscomp$148$$=$APP.$cljs$core$first$$($G__22998_temp__5823__auto__$jscomp$2$$),$G__22998_temp__5823__auto__$jscomp$2$$=$APP.$cljs$core$next$$($G__22998_temp__5823__auto__$jscomp$2$$),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$?
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$144$$,$G__22997_coll$jscomp$148$$,$G__22998_temp__5823__auto__$jscomp$2$$):$cljs$core$reduce$$($f$jscomp$144$$,$G__22997_coll$jscomp$148$$,$G__22998_temp__5823__auto__$jscomp$2$$)):$f$jscomp$144$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$144$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$144$$()};
$cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$=function($f$jscomp$145$$,$G__22999$jscomp$inline_2610_G__25181_nval$jscomp$5_val$jscomp$61_val__$1$jscomp$3$$,$G__25182_coll$jscomp$149_coll__$1$jscomp$26$$){for($G__25182_coll$jscomp$149_coll__$1$jscomp$26$$=$APP.$cljs$core$seq$$($G__25182_coll$jscomp$149_coll__$1$jscomp$26$$);;)if($G__25182_coll$jscomp$149_coll__$1$jscomp$26$$){var $G__23000$jscomp$inline_2611$$=$APP.$cljs$core$first$$($G__25182_coll$jscomp$149_coll__$1$jscomp$26$$);$G__22999$jscomp$inline_2610_G__25181_nval$jscomp$5_val$jscomp$61_val__$1$jscomp$3$$=
$f$jscomp$145$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$145$$.$cljs$core$IFn$_invoke$arity$2$($G__22999$jscomp$inline_2610_G__25181_nval$jscomp$5_val$jscomp$61_val__$1$jscomp$3$$,$G__23000$jscomp$inline_2611$$):$f$jscomp$145$$($G__22999$jscomp$inline_2610_G__25181_nval$jscomp$5_val$jscomp$61_val__$1$jscomp$3$$,$G__23000$jscomp$inline_2611$$);if($cljs$core$reduced_QMARK_$$($G__22999$jscomp$inline_2610_G__25181_nval$jscomp$5_val$jscomp$61_val__$1$jscomp$3$$))return $APP.$cljs$core$_deref$$($G__22999$jscomp$inline_2610_G__25181_nval$jscomp$5_val$jscomp$61_val__$1$jscomp$3$$);
$G__25182_coll$jscomp$149_coll__$1$jscomp$26$$=$APP.$cljs$core$next$$($G__25182_coll$jscomp$149_coll__$1$jscomp$26$$)}else return $G__22999$jscomp$inline_2610_G__25181_nval$jscomp$5_val$jscomp$61_val__$1$jscomp$3$$};
$cljs$core$iter_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$=function($coll$jscomp$151_iter$jscomp$4$$,$f$jscomp$146$$){$coll$jscomp$151_iter$jscomp$4$$=$APP.$cljs$core$_iterator$$($coll$jscomp$151_iter$jscomp$4$$);if($APP.$cljs$core$truth_$$($coll$jscomp$151_iter$jscomp$4$$.hasNext()))for(var $G__23003$jscomp$inline_2613_acc$jscomp$1_nacc$$=$coll$jscomp$151_iter$jscomp$4$$.next();;)if($coll$jscomp$151_iter$jscomp$4$$.hasNext()){var $G__23004$jscomp$inline_2614$$=$coll$jscomp$151_iter$jscomp$4$$.next();
$G__23003$jscomp$inline_2613_acc$jscomp$1_nacc$$=$f$jscomp$146$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$146$$.$cljs$core$IFn$_invoke$arity$2$($G__23003$jscomp$inline_2613_acc$jscomp$1_nacc$$,$G__23004$jscomp$inline_2614$$):$f$jscomp$146$$($G__23003$jscomp$inline_2613_acc$jscomp$1_nacc$$,$G__23004$jscomp$inline_2614$$);if($cljs$core$reduced_QMARK_$$($G__23003$jscomp$inline_2613_acc$jscomp$1_nacc$$))return $APP.$cljs$core$_deref$$($G__23003$jscomp$inline_2613_acc$jscomp$1_nacc$$)}else return $G__23003$jscomp$inline_2613_acc$jscomp$1_nacc$$;
else return $f$jscomp$146$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$146$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$146$$()};
$cljs$core$iter_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$=function($coll$jscomp$152_iter$jscomp$5$$,$f$jscomp$147$$,$G__23005$jscomp$inline_2616_acc$jscomp$2_init$jscomp$22_nacc$jscomp$1$$){for($coll$jscomp$152_iter$jscomp$5$$=$APP.$cljs$core$_iterator$$($coll$jscomp$152_iter$jscomp$5$$);;)if($coll$jscomp$152_iter$jscomp$5$$.hasNext()){var $G__23006$jscomp$inline_2617$$=$coll$jscomp$152_iter$jscomp$5$$.next();$G__23005$jscomp$inline_2616_acc$jscomp$2_init$jscomp$22_nacc$jscomp$1$$=$f$jscomp$147$$.$cljs$core$IFn$_invoke$arity$2$?
$f$jscomp$147$$.$cljs$core$IFn$_invoke$arity$2$($G__23005$jscomp$inline_2616_acc$jscomp$2_init$jscomp$22_nacc$jscomp$1$$,$G__23006$jscomp$inline_2617$$):$f$jscomp$147$$($G__23005$jscomp$inline_2616_acc$jscomp$2_init$jscomp$22_nacc$jscomp$1$$,$G__23006$jscomp$inline_2617$$);if($cljs$core$reduced_QMARK_$$($G__23005$jscomp$inline_2616_acc$jscomp$2_init$jscomp$22_nacc$jscomp$1$$))return $APP.$cljs$core$_deref$$($G__23005$jscomp$inline_2616_acc$jscomp$2_init$jscomp$22_nacc$jscomp$1$$)}else return $G__23005$jscomp$inline_2616_acc$jscomp$2_init$jscomp$22_nacc$jscomp$1$$};
$cljs$core$reduce$$=function($var_args$jscomp$119$$){switch(arguments.length){case 2:return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);case 3:return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$148$$,$coll$jscomp$153$$){return $coll$jscomp$153$$!=null&&($coll$jscomp$153$$.$cljs$lang$protocol_mask$partition0$$&524288||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$153$$.$cljs$core$IReduce$$)?$coll$jscomp$153$$.$cljs$core$IReduce$_reduce$arity$2$(null,$f$jscomp$148$$):$APP.$cljs$core$array_QMARK_$$($coll$jscomp$153$$)?$cljs$core$array_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($coll$jscomp$153$$,$f$jscomp$148$$):
typeof $coll$jscomp$153$$==="string"?$cljs$core$array_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($coll$jscomp$153$$,$f$jscomp$148$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IReduce$$,$coll$jscomp$153$$)?$cljs$core$_reduce$$($coll$jscomp$153$$,$f$jscomp$148$$):$cljs$core$iterable_QMARK_$$($coll$jscomp$153$$)?$cljs$core$iter_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($coll$jscomp$153$$,$f$jscomp$148$$):$cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$148$$,$coll$jscomp$153$$)};
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$=function($f$jscomp$149$$,$val$jscomp$62$$,$coll$jscomp$154$$){return $coll$jscomp$154$$!=null&&($coll$jscomp$154$$.$cljs$lang$protocol_mask$partition0$$&524288||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$154$$.$cljs$core$IReduce$$)?$coll$jscomp$154$$.$cljs$core$IReduce$_reduce$arity$3$(null,$f$jscomp$149$$,$val$jscomp$62$$):$APP.$cljs$core$array_QMARK_$$($coll$jscomp$154$$)?$cljs$core$array_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($coll$jscomp$154$$,
$f$jscomp$149$$,$val$jscomp$62$$):typeof $coll$jscomp$154$$==="string"?$cljs$core$array_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($coll$jscomp$154$$,$f$jscomp$149$$,$val$jscomp$62$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IReduce$$,$coll$jscomp$154$$)?$cljs$core$_reduce$$($coll$jscomp$154$$,$f$jscomp$149$$,$val$jscomp$62$$):$cljs$core$iterable_QMARK_$$($coll$jscomp$154$$)?$cljs$core$iter_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($coll$jscomp$154$$,$f$jscomp$149$$,$val$jscomp$62$$):
$cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$149$$,$val$jscomp$62$$,$coll$jscomp$154$$)};
$APP.$cljs$core$reduce_kv$$=function($f$jscomp$150$$,$init$jscomp$23$$,$coll$jscomp$155$$){return($coll$jscomp$155$$!=null?$coll$jscomp$155$$.$cljs$lang$protocol_mask$partition0$$&1048576||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$155$$.$cljs$core$IKVReduce$$||($coll$jscomp$155$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IKVReduce$$,$coll$jscomp$155$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IKVReduce$$,$coll$jscomp$155$$))?
$APP.$cljs$core$_kv_reduce$$($coll$jscomp$155$$,$f$jscomp$150$$,$init$jscomp$23$$):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret$jscomp$5$$,$G__23014_me__$1$$){var $G__23013$$=$APP.$cljs$core$_key$$($G__23014_me__$1$$);$G__23014_me__$1$$=$APP.$cljs$core$_val$$($G__23014_me__$1$$);return $f$jscomp$150$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$150$$.$cljs$core$IFn$_invoke$arity$3$($ret$jscomp$5$$,$G__23013$$,$G__23014_me__$1$$):$f$jscomp$150$$($ret$jscomp$5$$,$G__23013$$,
$G__23014_me__$1$$)},$init$jscomp$23$$,$coll$jscomp$155$$)};$APP.$cljs$core$identity$$=function($x$jscomp$186$$){return $x$jscomp$186$$};
$cljs$core$completing$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$152$$){return function(){function $G__25210__2$$($x$jscomp$188$$,$y$jscomp$89$$){return $f$jscomp$152$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$152$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$188$$,$y$jscomp$89$$):$f$jscomp$152$$($x$jscomp$188$$,$y$jscomp$89$$)}function $G__25210__1$$($x$jscomp$187$$){return $APP.$cljs$core$identity$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$identity$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$187$$):
$x$jscomp$187$$}function $G__25210__0$$(){return $f$jscomp$152$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$152$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$152$$()}var $G__25210$$=null;$G__25210$$=function($x$jscomp$189$$,$y$jscomp$90$$){switch(arguments.length){case 0:return $G__25210__0$$.call(this);case 1:return $G__25210__1$$.call(this,$x$jscomp$189$$);case 2:return $G__25210__2$$.call(this,$x$jscomp$189$$,$y$jscomp$90$$)}throw Error("Invalid arity: "+arguments.length);};$G__25210$$.$cljs$core$IFn$_invoke$arity$0$=
$G__25210__0$$;$G__25210$$.$cljs$core$IFn$_invoke$arity$1$=$G__25210__1$$;$G__25210$$.$cljs$core$IFn$_invoke$arity$2$=$G__25210__2$$;return $G__25210$$}()};$cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$03$$=function($xform$$,$f$jscomp$153$$,$coll$jscomp$156$$){return $cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$04$$($xform$$,$f$jscomp$153$$,$f$jscomp$153$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$153$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$153$$(),$coll$jscomp$156$$)};
$cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$04$$=function($f__$1_xform$jscomp$1$$,$f$jscomp$154$$,$init$jscomp$24_ret$jscomp$6$$,$coll$jscomp$157$$){$f__$1_xform$jscomp$1$$=$f__$1_xform$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$f__$1_xform$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($f$jscomp$154$$):$f__$1_xform$jscomp$1$$($f$jscomp$154$$);$init$jscomp$24_ret$jscomp$6$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($f__$1_xform$jscomp$1$$,$init$jscomp$24_ret$jscomp$6$$,$coll$jscomp$157$$);
return $f__$1_xform$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$f__$1_xform$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($init$jscomp$24_ret$jscomp$6$$):$f__$1_xform$jscomp$1$$($init$jscomp$24_ret$jscomp$6$$)};$APP.$cljs$core$dec$$=function($x$jscomp$214$$){return $x$jscomp$214$$-1};$APP.$cljs$core$abs$$=function($a$jscomp$110$$){return Math.abs($a$jscomp$110$$)};
$APP.$cljs$core$char$0$$=function($x$jscomp$222$$){if(typeof $x$jscomp$222$$==="number")return String.fromCharCode($x$jscomp$222$$);if(typeof $x$jscomp$222$$==="string"&&$x$jscomp$222$$.length===1)return $x$jscomp$222$$;throw Error("Argument to char must be a character or number");};$APP.$cljs$core$fix$$=function($q$jscomp$21$$){return $q$jscomp$21$$>=0?Math.floor($q$jscomp$21$$):Math.ceil($q$jscomp$21$$)};
$APP.$cljs$core$mod$$=function($n$jscomp$72$$,$d$jscomp$75$$){return($n$jscomp$72$$%$d$jscomp$75$$+$d$jscomp$75$$)%$d$jscomp$75$$};$APP.$cljs$core$quot$$=function($n$jscomp$73$$,$d$jscomp$76$$){return $APP.$cljs$core$fix$$(($n$jscomp$73$$-$n$jscomp$73$$%$d$jscomp$76$$)/$d$jscomp$76$$)};$APP.$cljs$core$rem$$=function($n$jscomp$74$$,$d$jscomp$77$$){return $n$jscomp$74$$-$d$jscomp$77$$*$APP.$cljs$core$quot$$($n$jscomp$74$$,$d$jscomp$77$$)};
$cljs$core$bit_count$$=function($v$jscomp$13_v__$1_v__$2$$){$v$jscomp$13_v__$1_v__$2$$-=$v$jscomp$13_v__$1_v__$2$$>>1&1431655765;$v$jscomp$13_v__$1_v__$2$$=($v$jscomp$13_v__$1_v__$2$$&858993459)+($v$jscomp$13_v__$1_v__$2$$>>2&858993459);return($v$jscomp$13_v__$1_v__$2$$+($v$jscomp$13_v__$1_v__$2$$>>4)&252645135)*16843009>>24};
$cljs$core$_EQ__EQ_$$=function($var_args$jscomp$143$$){switch(arguments.length){case 1:return!0;case 2:return $cljs$core$_equiv$$(arguments[0],arguments[1]);default:for(var $G__25532$jscomp$inline_2624_args_arr__5774__auto__$jscomp$35_more$jscomp$inline_2621$$=[],$G__25530$jscomp$inline_2622_JSCompiler_inline_result$jscomp$139_len__5749__auto___25517_x$jscomp$inline_2619$$=arguments.length,$G__25531$jscomp$inline_2623_i__5750__auto___25518_y$jscomp$inline_2620$$=0;;)if($G__25531$jscomp$inline_2623_i__5750__auto___25518_y$jscomp$inline_2620$$<
$G__25530$jscomp$inline_2622_JSCompiler_inline_result$jscomp$139_len__5749__auto___25517_x$jscomp$inline_2619$$)$G__25532$jscomp$inline_2624_args_arr__5774__auto__$jscomp$35_more$jscomp$inline_2621$$.push(arguments[$G__25531$jscomp$inline_2623_i__5750__auto___25518_y$jscomp$inline_2620$$]),$G__25531$jscomp$inline_2623_i__5750__auto___25518_y$jscomp$inline_2620$$+=1;else break;a:{$G__25530$jscomp$inline_2622_JSCompiler_inline_result$jscomp$139_len__5749__auto___25517_x$jscomp$inline_2619$$=arguments[0];
$G__25531$jscomp$inline_2623_i__5750__auto___25518_y$jscomp$inline_2620$$=arguments[1];for($G__25532$jscomp$inline_2624_args_arr__5774__auto__$jscomp$35_more$jscomp$inline_2621$$=2<$G__25532$jscomp$inline_2624_args_arr__5774__auto__$jscomp$35_more$jscomp$inline_2621$$.length?new $APP.$cljs$core$IndexedSeq$$($G__25532$jscomp$inline_2624_args_arr__5774__auto__$jscomp$35_more$jscomp$inline_2621$$.slice(2),0,null):null;;){if($G__25530$jscomp$inline_2622_JSCompiler_inline_result$jscomp$139_len__5749__auto___25517_x$jscomp$inline_2619$$===
$G__25531$jscomp$inline_2623_i__5750__auto___25518_y$jscomp$inline_2620$$)if($APP.$cljs$core$next$$($G__25532$jscomp$inline_2624_args_arr__5774__auto__$jscomp$35_more$jscomp$inline_2621$$)){$G__25530$jscomp$inline_2622_JSCompiler_inline_result$jscomp$139_len__5749__auto___25517_x$jscomp$inline_2619$$=$G__25531$jscomp$inline_2623_i__5750__auto___25518_y$jscomp$inline_2620$$;$G__25531$jscomp$inline_2623_i__5750__auto___25518_y$jscomp$inline_2620$$=$APP.$cljs$core$first$$($G__25532$jscomp$inline_2624_args_arr__5774__auto__$jscomp$35_more$jscomp$inline_2621$$);
$G__25532$jscomp$inline_2624_args_arr__5774__auto__$jscomp$35_more$jscomp$inline_2621$$=$APP.$cljs$core$next$$($G__25532$jscomp$inline_2624_args_arr__5774__auto__$jscomp$35_more$jscomp$inline_2621$$);continue}else{$G__25530$jscomp$inline_2622_JSCompiler_inline_result$jscomp$139_len__5749__auto___25517_x$jscomp$inline_2619$$=$G__25531$jscomp$inline_2623_i__5750__auto___25518_y$jscomp$inline_2620$$===$APP.$cljs$core$first$$($G__25532$jscomp$inline_2624_args_arr__5774__auto__$jscomp$35_more$jscomp$inline_2621$$);
break a}else{$G__25530$jscomp$inline_2622_JSCompiler_inline_result$jscomp$139_len__5749__auto___25517_x$jscomp$inline_2619$$=!1;break a}break}$G__25530$jscomp$inline_2622_JSCompiler_inline_result$jscomp$139_len__5749__auto___25517_x$jscomp$inline_2619$$=void 0}return $G__25530$jscomp$inline_2622_JSCompiler_inline_result$jscomp$139_len__5749__auto___25517_x$jscomp$inline_2619$$}};
$cljs$core$_EQ__EQ_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($x$jscomp$289$$,$y$jscomp$133$$){return $cljs$core$_equiv$$($x$jscomp$289$$,$y$jscomp$133$$)};$APP.$cljs$core$pos_QMARK_$$=function($x$jscomp$291$$){return $x$jscomp$291$$>0};$cljs$core$zero_QMARK_$$=function($x$jscomp$292$$){return $x$jscomp$292$$===0};
$cljs$core$equiv_sequential$$=function($G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$,$G__25562$jscomp$inline_2629_y$jscomp$135_ys$jscomp$inline_2627$$){if($APP.$cljs$core$sequential_QMARK_$$($G__25562$jscomp$inline_2629_y$jscomp$135_ys$jscomp$inline_2627$$))if($cljs$core$counted_QMARK_$$($G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$)&&$cljs$core$counted_QMARK_$$($G__25562$jscomp$inline_2629_y$jscomp$135_ys$jscomp$inline_2627$$)&&
$APP.$cljs$core$count$$($G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$)!==$APP.$cljs$core$count$$($G__25562$jscomp$inline_2629_y$jscomp$135_ys$jscomp$inline_2627$$))$G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$=!1;else a:{$G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$=$APP.$cljs$core$seq$$($G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$);
for($G__25562$jscomp$inline_2629_y$jscomp$135_ys$jscomp$inline_2627$$=$APP.$cljs$core$seq$$($G__25562$jscomp$inline_2629_y$jscomp$135_ys$jscomp$inline_2627$$);;){if($G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$==null){$G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$=$G__25562$jscomp$inline_2629_y$jscomp$135_ys$jscomp$inline_2627$$==null;break a}if($G__25562$jscomp$inline_2629_y$jscomp$135_ys$jscomp$inline_2627$$!=
null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$),$APP.$cljs$core$first$$($G__25562$jscomp$inline_2629_y$jscomp$135_ys$jscomp$inline_2627$$)))$G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$=$APP.$cljs$core$next$$($G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$),
$G__25562$jscomp$inline_2629_y$jscomp$135_ys$jscomp$inline_2627$$=$APP.$cljs$core$next$$($G__25562$jscomp$inline_2629_y$jscomp$135_ys$jscomp$inline_2627$$);else{$G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$=!1;break a}}$G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$=void 0}else $G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$=
null;return $APP.$cljs$core$boolean$0$$($G__25561$jscomp$inline_2628_JSCompiler_temp$jscomp$140_JSCompiler_temp$jscomp$141_x$jscomp$296_xs$jscomp$inline_2626$$)};
$APP.$cljs$core$List$$=function($meta$jscomp$9$$,$first$jscomp$4$$,$rest$jscomp$5$$,$count$jscomp$42$$,$__hash$$){this.$meta$=$meta$jscomp$9$$;this.first=$first$jscomp$4$$;this.$rest$=$rest$jscomp$5$$;this.count=$count$jscomp$42$$;this.$__hash$=$__hash$$;this.$cljs$lang$protocol_mask$partition0$$=65937646;this.$cljs$lang$protocol_mask$partition1$$=8192};
$APP.$cljs$core$list_QMARK_$$=function($x$jscomp$303$$){return $x$jscomp$303$$!=null?$x$jscomp$303$$.$cljs$lang$protocol_mask$partition0$$&33554432||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$303$$.$cljs$core$IList$$?!0:$x$jscomp$303$$.$cljs$lang$protocol_mask$partition0$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IList$$,$x$jscomp$303$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IList$$,$x$jscomp$303$$)};
$cljs$core$EmptyList$$=function($meta$jscomp$11$$){this.$meta$=$meta$jscomp$11$$;this.$cljs$lang$protocol_mask$partition0$$=65937614;this.$cljs$lang$protocol_mask$partition1$$=8192};
$APP.$cljs$core$reverse$$=function($coll$jscomp$201_or__5025__auto__$jscomp$6$$){return($coll$jscomp$201_or__5025__auto__$jscomp$6$$!=null?$coll$jscomp$201_or__5025__auto__$jscomp$6$$.$cljs$lang$protocol_mask$partition0$$&134217728||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$201_or__5025__auto__$jscomp$6$$.$cljs$core$IReversible$$||($coll$jscomp$201_or__5025__auto__$jscomp$6$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IReversible$$,$coll$jscomp$201_or__5025__auto__$jscomp$6$$)):
$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IReversible$$,$coll$jscomp$201_or__5025__auto__$jscomp$6$$))?($coll$jscomp$201_or__5025__auto__$jscomp$6$$=$APP.$cljs$core$_rseq$$($coll$jscomp$201_or__5025__auto__$jscomp$6$$))?$coll$jscomp$201_or__5025__auto__$jscomp$6$$:$APP.$cljs$core$List$EMPTY$$:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$List$EMPTY$$,$coll$jscomp$201_or__5025__auto__$jscomp$6$$)};
$APP.$cljs$core$Cons$$=function($meta$jscomp$13$$,$first$jscomp$6$$,$rest$jscomp$7$$,$__hash$jscomp$2$$){this.$meta$=$meta$jscomp$13$$;this.first=$first$jscomp$6$$;this.$rest$=$rest$jscomp$7$$;this.$__hash$=$__hash$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=65929452;this.$cljs$lang$protocol_mask$partition1$$=8192};
$APP.$cljs$core$cons$$=function($x$jscomp$316$$,$coll$jscomp$219$$){return $coll$jscomp$219$$==null?new $APP.$cljs$core$List$$(null,$x$jscomp$316$$,null,1,null):$coll$jscomp$219$$!=null&&($coll$jscomp$219$$.$cljs$lang$protocol_mask$partition0$$&64||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$219$$.$cljs$core$ISeq$$)?new $APP.$cljs$core$Cons$$(null,$x$jscomp$316$$,$coll$jscomp$219$$,null):new $APP.$cljs$core$Cons$$(null,$x$jscomp$316$$,$APP.$cljs$core$seq$$($coll$jscomp$219$$),null)};
$cljs$core$compare_keywords$$=function($a$jscomp$111$$,$b$jscomp$99$$){if($a$jscomp$111$$.$fqn$===$b$jscomp$99$$.$fqn$)return 0;var $and__5023__auto__$jscomp$inline_2636_nsc$jscomp$1$$=$APP.$cljs$core$not$$($a$jscomp$111$$.ns);if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_2636_nsc$jscomp$1$$?$b$jscomp$99$$.ns:$and__5023__auto__$jscomp$inline_2636_nsc$jscomp$1$$))return-1;if($APP.$cljs$core$truth_$$($a$jscomp$111$$.ns)){if($APP.$cljs$core$not$$($b$jscomp$99$$.ns))return 1;$and__5023__auto__$jscomp$inline_2636_nsc$jscomp$1$$=
$module$contents$goog$array_defaultCompare$$($a$jscomp$111$$.ns,$b$jscomp$99$$.ns);return 0===$and__5023__auto__$jscomp$inline_2636_nsc$jscomp$1$$?$module$contents$goog$array_defaultCompare$$($a$jscomp$111$$.name,$b$jscomp$99$$.name):$and__5023__auto__$jscomp$inline_2636_nsc$jscomp$1$$}return $module$contents$goog$array_defaultCompare$$($a$jscomp$111$$.name,$b$jscomp$99$$.name)};
$APP.$cljs$core$Keyword$$=function($ns$jscomp$4$$,$name$jscomp$105$$,$fqn$$,$_hash$jscomp$2$$){this.ns=$ns$jscomp$4$$;this.name=$name$jscomp$105$$;this.$fqn$=$fqn$$;this.$_hash$=$_hash$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2153775105;this.$cljs$lang$protocol_mask$partition1$$=4096};$cljs$core$keyword_QMARK_$$=function($x$jscomp$317$$){return $x$jscomp$317$$ instanceof $APP.$cljs$core$Keyword$$};
$APP.$cljs$core$keyword_identical_QMARK_$$=function($x$jscomp$318$$,$y$jscomp$136$$){return $x$jscomp$318$$===$y$jscomp$136$$?!0:$x$jscomp$318$$ instanceof $APP.$cljs$core$Keyword$$&&$y$jscomp$136$$ instanceof $APP.$cljs$core$Keyword$$?$x$jscomp$318$$.$fqn$===$y$jscomp$136$$.$fqn$:!1};
$APP.$cljs$core$namespace$$=function($x$jscomp$320$$){if($x$jscomp$320$$!=null&&($x$jscomp$320$$.$cljs$lang$protocol_mask$partition1$$&4096||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$320$$.$cljs$core$INamed$$))return $x$jscomp$320$$.$cljs$core$INamed$_namespace$arity$1$(null);throw Error(["Doesn't support namespace: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$320$$)].join(""));};
$cljs$core$ident_QMARK_$$=function($x$jscomp$321$$){return $x$jscomp$321$$ instanceof $APP.$cljs$core$Keyword$$||$x$jscomp$321$$ instanceof $APP.$cljs$core$Symbol$$};$cljs$core$simple_ident_QMARK_$$=function($x$jscomp$322$$){return $cljs$core$ident_QMARK_$$($x$jscomp$322$$)&&$APP.$cljs$core$namespace$$($x$jscomp$322$$)==null};
$cljs$core$qualified_ident_QMARK_$$=function($JSCompiler_inline_result$jscomp$145_and__5023__auto____$1$jscomp$inline_2639_x$jscomp$323$$){var $and__5023__auto__$jscomp$inline_2638$$=$cljs$core$ident_QMARK_$$($JSCompiler_inline_result$jscomp$145_and__5023__auto____$1$jscomp$inline_2639_x$jscomp$323$$);$and__5023__auto__$jscomp$inline_2638$$?($JSCompiler_inline_result$jscomp$145_and__5023__auto____$1$jscomp$inline_2639_x$jscomp$323$$=$APP.$cljs$core$namespace$$($JSCompiler_inline_result$jscomp$145_and__5023__auto____$1$jscomp$inline_2639_x$jscomp$323$$),
$JSCompiler_inline_result$jscomp$145_and__5023__auto____$1$jscomp$inline_2639_x$jscomp$323$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$145_and__5023__auto____$1$jscomp$inline_2639_x$jscomp$323$$)?!0:$JSCompiler_inline_result$jscomp$145_and__5023__auto____$1$jscomp$inline_2639_x$jscomp$323$$):$JSCompiler_inline_result$jscomp$145_and__5023__auto____$1$jscomp$inline_2639_x$jscomp$323$$=$and__5023__auto__$jscomp$inline_2638$$;return $APP.$cljs$core$boolean$0$$($JSCompiler_inline_result$jscomp$145_and__5023__auto____$1$jscomp$inline_2639_x$jscomp$323$$)};
$cljs$core$simple_symbol_QMARK_$$=function($x$jscomp$324$$){return $x$jscomp$324$$ instanceof $APP.$cljs$core$Symbol$$&&$APP.$cljs$core$namespace$$($x$jscomp$324$$)==null};
$cljs$core$qualified_symbol_QMARK_$$=function($JSCompiler_inline_result$jscomp$146_and__5023__auto____$1$jscomp$inline_2642_x$jscomp$325$$){var $and__5023__auto__$jscomp$inline_2641$$=$JSCompiler_inline_result$jscomp$146_and__5023__auto____$1$jscomp$inline_2642_x$jscomp$325$$ instanceof $APP.$cljs$core$Symbol$$;$and__5023__auto__$jscomp$inline_2641$$?($JSCompiler_inline_result$jscomp$146_and__5023__auto____$1$jscomp$inline_2642_x$jscomp$325$$=$APP.$cljs$core$namespace$$($JSCompiler_inline_result$jscomp$146_and__5023__auto____$1$jscomp$inline_2642_x$jscomp$325$$),
$JSCompiler_inline_result$jscomp$146_and__5023__auto____$1$jscomp$inline_2642_x$jscomp$325$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$146_and__5023__auto____$1$jscomp$inline_2642_x$jscomp$325$$)?!0:$JSCompiler_inline_result$jscomp$146_and__5023__auto____$1$jscomp$inline_2642_x$jscomp$325$$):$JSCompiler_inline_result$jscomp$146_and__5023__auto____$1$jscomp$inline_2642_x$jscomp$325$$=$and__5023__auto__$jscomp$inline_2641$$;return $APP.$cljs$core$boolean$0$$($JSCompiler_inline_result$jscomp$146_and__5023__auto____$1$jscomp$inline_2642_x$jscomp$325$$)};
$cljs$core$simple_keyword_QMARK_$$=function($x$jscomp$326$$){return $x$jscomp$326$$ instanceof $APP.$cljs$core$Keyword$$&&$APP.$cljs$core$namespace$$($x$jscomp$326$$)==null};
$cljs$core$qualified_keyword_QMARK_$$=function($JSCompiler_inline_result$jscomp$147_and__5023__auto____$1$jscomp$inline_2645_x$jscomp$327$$){var $and__5023__auto__$jscomp$inline_2644$$=$JSCompiler_inline_result$jscomp$147_and__5023__auto____$1$jscomp$inline_2645_x$jscomp$327$$ instanceof $APP.$cljs$core$Keyword$$;$and__5023__auto__$jscomp$inline_2644$$?($JSCompiler_inline_result$jscomp$147_and__5023__auto____$1$jscomp$inline_2645_x$jscomp$327$$=$APP.$cljs$core$namespace$$($JSCompiler_inline_result$jscomp$147_and__5023__auto____$1$jscomp$inline_2645_x$jscomp$327$$),
$JSCompiler_inline_result$jscomp$147_and__5023__auto____$1$jscomp$inline_2645_x$jscomp$327$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$147_and__5023__auto____$1$jscomp$inline_2645_x$jscomp$327$$)?!0:$JSCompiler_inline_result$jscomp$147_and__5023__auto____$1$jscomp$inline_2645_x$jscomp$327$$):$JSCompiler_inline_result$jscomp$147_and__5023__auto____$1$jscomp$inline_2645_x$jscomp$327$$=$and__5023__auto__$jscomp$inline_2644$$;return $APP.$cljs$core$boolean$0$$($JSCompiler_inline_result$jscomp$147_and__5023__auto____$1$jscomp$inline_2645_x$jscomp$327$$)};
$APP.$cljs$core$LazySeq$$=function($meta$jscomp$15$$,$fn$jscomp$8$$,$s$jscomp$54$$,$__hash$jscomp$4$$){this.$meta$=$meta$jscomp$15$$;this.fn=$fn$jscomp$8$$;this.s=$s$jscomp$54$$;this.$__hash$=$__hash$jscomp$4$$;this.$cljs$lang$protocol_mask$partition0$$=32374988;this.$cljs$lang$protocol_mask$partition1$$=1};
$JSCompiler_StaticMethods_sval$$=function($JSCompiler_StaticMethods_sval$self$$){$JSCompiler_StaticMethods_sval$self$$.fn!=null&&($JSCompiler_StaticMethods_sval$self$$.s=$JSCompiler_StaticMethods_sval$self$$.fn.$cljs$core$IFn$_invoke$arity$0$?$JSCompiler_StaticMethods_sval$self$$.fn.$cljs$core$IFn$_invoke$arity$0$():$JSCompiler_StaticMethods_sval$self$$.fn(),$JSCompiler_StaticMethods_sval$self$$.fn=null);return $JSCompiler_StaticMethods_sval$self$$.s};
$cljs$core$ChunkBuffer$$=function($buf$jscomp$1$$){this.$buf$=$buf$jscomp$1$$;this.end=0;this.$cljs$lang$protocol_mask$partition0$$=2;this.$cljs$lang$protocol_mask$partition1$$=0};$APP.$cljs$core$chunk_buffer$$=function($capacity$$){return new $cljs$core$ChunkBuffer$$(Array($capacity$$))};
$cljs$core$ArrayChunk$$=function($arr$jscomp$75$$,$off$$,$end$jscomp$15$$){this.$arr$=$arr$jscomp$75$$;this.$off$=$off$$;this.end=$end$jscomp$15$$;this.$cljs$lang$protocol_mask$partition0$$=524306;this.$cljs$lang$protocol_mask$partition1$$=0};
$APP.$cljs$core$ChunkedCons$$=function($chunk$jscomp$9$$,$more$jscomp$25$$,$meta$jscomp$17$$,$__hash$jscomp$6$$){this.$chunk$=$chunk$jscomp$9$$;this.$more$=$more$jscomp$25$$;this.$meta$=$meta$jscomp$17$$;this.$__hash$=$__hash$jscomp$6$$;this.$cljs$lang$protocol_mask$partition0$$=31850732;this.$cljs$lang$protocol_mask$partition1$$=1536};
$APP.$cljs$core$chunk_cons$$=function($chunk$jscomp$11$$,$rest$jscomp$9$$){return $APP.$cljs$core$_count$$($chunk$jscomp$11$$)===0?$rest$jscomp$9$$:new $APP.$cljs$core$ChunkedCons$$($chunk$jscomp$11$$,$rest$jscomp$9$$,null,null)};$APP.$cljs$core$chunk_append$$=function($b$jscomp$100$$,$x$jscomp$340$$){$b$jscomp$100$$.add($x$jscomp$340$$)};$APP.$cljs$core$chunk$$=function($b$jscomp$101$$){return $b$jscomp$101$$.$chunk$()};
$APP.$cljs$core$to_array$$=function($coll$jscomp$263_s$jscomp$59$$){var $ary$$=[];for($coll$jscomp$263_s$jscomp$59$$=$APP.$cljs$core$seq$$($coll$jscomp$263_s$jscomp$59$$);;)if($coll$jscomp$263_s$jscomp$59$$!=null)$ary$$.push($APP.$cljs$core$first$$($coll$jscomp$263_s$jscomp$59$$)),$coll$jscomp$263_s$jscomp$59$$=$APP.$cljs$core$next$$($coll$jscomp$263_s$jscomp$59$$);else return $ary$$};
$cljs$core$object_array$cljs$0core$0IFn$0_invoke$0arity$01$$=function($JSCompiler_temp$jscomp$149_size_or_seq$jscomp$3$$){if(typeof $JSCompiler_temp$jscomp$149_size_or_seq$jscomp$3$$==="number")a:{var $a$jscomp$inline_2649$$=Array($JSCompiler_temp$jscomp$149_size_or_seq$jscomp$3$$);if($APP.$cljs$core$seq_QMARK_$$(null)){for(var $G__25847$jscomp$inline_2652_i$jscomp$inline_2650_i_25850$jscomp$inline_2654$$=0,$G__25848$jscomp$inline_2653_s__$1$jscomp$inline_2651$$=$APP.$cljs$core$seq$$(null);;)if($G__25848$jscomp$inline_2653_s__$1$jscomp$inline_2651$$&&
$G__25847$jscomp$inline_2652_i$jscomp$inline_2650_i_25850$jscomp$inline_2654$$<$JSCompiler_temp$jscomp$149_size_or_seq$jscomp$3$$)$a$jscomp$inline_2649$$[$G__25847$jscomp$inline_2652_i$jscomp$inline_2650_i_25850$jscomp$inline_2654$$]=$APP.$cljs$core$first$$($G__25848$jscomp$inline_2653_s__$1$jscomp$inline_2651$$),$G__25847$jscomp$inline_2652_i$jscomp$inline_2650_i_25850$jscomp$inline_2654$$+=1,$G__25848$jscomp$inline_2653_s__$1$jscomp$inline_2651$$=$APP.$cljs$core$next$$($G__25848$jscomp$inline_2653_s__$1$jscomp$inline_2651$$);
else{$JSCompiler_temp$jscomp$149_size_or_seq$jscomp$3$$=$a$jscomp$inline_2649$$;break a}$JSCompiler_temp$jscomp$149_size_or_seq$jscomp$3$$=void 0}else{for($G__25847$jscomp$inline_2652_i$jscomp$inline_2650_i_25850$jscomp$inline_2654$$=0;;)if($G__25847$jscomp$inline_2652_i$jscomp$inline_2650_i_25850$jscomp$inline_2654$$<$JSCompiler_temp$jscomp$149_size_or_seq$jscomp$3$$)$a$jscomp$inline_2649$$[$G__25847$jscomp$inline_2652_i$jscomp$inline_2650_i_25850$jscomp$inline_2654$$]=null,$G__25847$jscomp$inline_2652_i$jscomp$inline_2650_i_25850$jscomp$inline_2654$$+=
1;else break;$JSCompiler_temp$jscomp$149_size_or_seq$jscomp$3$$=$a$jscomp$inline_2649$$}}else $JSCompiler_temp$jscomp$149_size_or_seq$jscomp$3$$=$APP.$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$149_size_or_seq$jscomp$3$$);return $JSCompiler_temp$jscomp$149_size_or_seq$jscomp$3$$};
$cljs$core$bounded_count$$=function($n$jscomp$84$$,$G__25859_coll$jscomp$265_s$jscomp$64$$){if($cljs$core$counted_QMARK_$$($G__25859_coll$jscomp$265_s$jscomp$64$$))return $APP.$cljs$core$count$$($G__25859_coll$jscomp$265_s$jscomp$64$$);var $G__25858_i$jscomp$192$$=0;for($G__25859_coll$jscomp$265_s$jscomp$64$$=$APP.$cljs$core$seq$$($G__25859_coll$jscomp$265_s$jscomp$64$$);;)if($G__25859_coll$jscomp$265_s$jscomp$64$$!=null&&$G__25858_i$jscomp$192$$<$n$jscomp$84$$)$G__25858_i$jscomp$192$$+=1,$G__25859_coll$jscomp$265_s$jscomp$64$$=
$APP.$cljs$core$next$$($G__25859_coll$jscomp$265_s$jscomp$64$$);else return $G__25858_i$jscomp$192$$};$APP.$cljs$core$transient$0$$=function($coll$jscomp$266$$){return $APP.$cljs$core$_as_transient$$($coll$jscomp$266$$)};$APP.$cljs$core$persistent_BANG_$$=function($tcoll$jscomp$14$$){return $APP.$cljs$core$_persistent_BANG_$$($tcoll$jscomp$14$$)};
$cljs$core$apply_to$$=function($f$jscomp$165$$,$argc$$,$a3580_args$jscomp$16$$){var $args__$1_b3581$$=$APP.$cljs$core$seq$$($a3580_args$jscomp$16$$);if($argc$$===0)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$165$$();$a3580_args$jscomp$16$$=$cljs$core$_first$$($args__$1_b3581$$);var $args__$2_c3582$$=$cljs$core$_rest$$($args__$1_b3581$$);if($argc$$===1)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$1$($a3580_args$jscomp$16$$):
$f$jscomp$165$$($a3580_args$jscomp$16$$);$args__$1_b3581$$=$cljs$core$_first$$($args__$2_c3582$$);var $args__$3_d3583$$=$cljs$core$_rest$$($args__$2_c3582$$);if($argc$$===2)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$2$($a3580_args$jscomp$16$$,$args__$1_b3581$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$);$args__$2_c3582$$=$cljs$core$_first$$($args__$3_d3583$$);var $args__$4_e3584$$=$cljs$core$_rest$$($args__$3_d3583$$);if($argc$$===
3)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$3$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$);$args__$3_d3583$$=$cljs$core$_first$$($args__$4_e3584$$);var $args__$5_f3585$$=$cljs$core$_rest$$($args__$4_e3584$$);if($argc$$===4)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$4$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$4$($a3580_args$jscomp$16$$,
$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$);$args__$4_e3584$$=$cljs$core$_first$$($args__$5_f3585$$);var $args__$6_g3586$$=$cljs$core$_rest$$($args__$5_f3585$$);if($argc$$===5)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$5$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$5$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,
$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$);$args__$5_f3585$$=$cljs$core$_first$$($args__$6_g3586$$);var $args__$7_h3587$$=$cljs$core$_rest$$($args__$6_g3586$$);if($argc$$===6)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$6$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$6$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,
$args__$4_e3584$$,$args__$5_f3585$$);$args__$6_g3586$$=$cljs$core$_first$$($args__$7_h3587$$);var $args__$8_i3588$$=$cljs$core$_rest$$($args__$7_h3587$$);if($argc$$===7)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$7$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$7$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,
$args__$5_f3585$$,$args__$6_g3586$$);$args__$7_h3587$$=$cljs$core$_first$$($args__$8_i3588$$);var $args__$9_j3589$$=$cljs$core$_rest$$($args__$8_i3588$$);if($argc$$===8)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$8$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$8$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,
$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$);$args__$8_i3588$$=$cljs$core$_first$$($args__$9_j3589$$);var $args__$10_k3590$$=$cljs$core$_rest$$($args__$9_j3589$$);if($argc$$===9)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$9$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$9$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,
$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$);$args__$9_j3589$$=$cljs$core$_first$$($args__$10_k3590$$);var $args__$11_l3591$$=$cljs$core$_rest$$($args__$10_k3590$$);if($argc$$===10)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$10$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$10$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,
$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$);$args__$10_k3590$$=$cljs$core$_first$$($args__$11_l3591$$);var $args__$12_m3592$$=$cljs$core$_rest$$($args__$11_l3591$$);if($argc$$===11)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$11$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$11$($a3580_args$jscomp$16$$,
$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$);$args__$11_l3591$$=$cljs$core$_first$$($args__$12_m3592$$);var $args__$13_n3593$$=$cljs$core$_rest$$($args__$12_m3592$$);
if($argc$$===12)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$12$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$12$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,
$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$);$args__$12_m3592$$=$cljs$core$_first$$($args__$13_n3593$$);var $args__$14_o3594$$=$cljs$core$_rest$$($args__$13_n3593$$);if($argc$$===13)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$13$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$13$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,
$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$);$args__$13_n3593$$=$cljs$core$_first$$($args__$14_o3594$$);var $args__$15_p3595$$=$cljs$core$_rest$$($args__$14_o3594$$);if($argc$$===14)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$14$?
$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$14$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$,$args__$13_n3593$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,
$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$,$args__$13_n3593$$);$args__$14_o3594$$=$cljs$core$_first$$($args__$15_p3595$$);var $args__$16_q3596$$=$cljs$core$_rest$$($args__$15_p3595$$);if($argc$$===15)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$15$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$15$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,
$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$,$args__$13_n3593$$,$args__$14_o3594$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$,$args__$13_n3593$$,$args__$14_o3594$$);$args__$15_p3595$$=$cljs$core$_first$$($args__$16_q3596$$);var $args__$17_r3597$$=$cljs$core$_rest$$($args__$16_q3596$$);
if($argc$$===16)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$16$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$16$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$,$args__$13_n3593$$,$args__$14_o3594$$,$args__$15_p3595$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,
$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$,$args__$13_n3593$$,$args__$14_o3594$$,$args__$15_p3595$$);$args__$16_q3596$$=$cljs$core$_first$$($args__$17_r3597$$);var $args__$18_s3598$$=$cljs$core$_rest$$($args__$17_r3597$$);if($argc$$===17)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$17$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$17$($a3580_args$jscomp$16$$,$args__$1_b3581$$,
$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$,$args__$13_n3593$$,$args__$14_o3594$$,$args__$15_p3595$$,$args__$16_q3596$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$,
$args__$12_m3592$$,$args__$13_n3593$$,$args__$14_o3594$$,$args__$15_p3595$$,$args__$16_q3596$$);$args__$17_r3597$$=$cljs$core$_first$$($args__$18_s3598$$);var $args__$19_args__$20$$=$cljs$core$_rest$$($args__$18_s3598$$);if($argc$$===18)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$18$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$18$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,
$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$,$args__$13_n3593$$,$args__$14_o3594$$,$args__$15_p3595$$,$args__$16_q3596$$,$args__$17_r3597$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$,$args__$13_n3593$$,$args__$14_o3594$$,$args__$15_p3595$$,$args__$16_q3596$$,
$args__$17_r3597$$);$args__$18_s3598$$=$cljs$core$_first$$($args__$19_args__$20$$);$args__$19_args__$20$$=$cljs$core$_rest$$($args__$19_args__$20$$);if($argc$$===19)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$19$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$19$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$,
$args__$13_n3593$$,$args__$14_o3594$$,$args__$15_p3595$$,$args__$16_q3596$$,$args__$17_r3597$$,$args__$18_s3598$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$,$args__$13_n3593$$,$args__$14_o3594$$,$args__$15_p3595$$,$args__$16_q3596$$,$args__$17_r3597$$,$args__$18_s3598$$);var $t3599$$=
$cljs$core$_first$$($args__$19_args__$20$$);$cljs$core$_rest$$($args__$19_args__$20$$);if($argc$$===20)return $f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$20$?$f$jscomp$165$$.$cljs$core$IFn$_invoke$arity$20$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$,$args__$13_n3593$$,$args__$14_o3594$$,$args__$15_p3595$$,
$args__$16_q3596$$,$args__$17_r3597$$,$args__$18_s3598$$,$t3599$$):$f$jscomp$165$$($a3580_args$jscomp$16$$,$args__$1_b3581$$,$args__$2_c3582$$,$args__$3_d3583$$,$args__$4_e3584$$,$args__$5_f3585$$,$args__$6_g3586$$,$args__$7_h3587$$,$args__$8_i3588$$,$args__$9_j3589$$,$args__$10_k3590$$,$args__$11_l3591$$,$args__$12_m3592$$,$args__$13_n3593$$,$args__$14_o3594$$,$args__$15_p3595$$,$args__$16_q3596$$,$args__$17_r3597$$,$args__$18_s3598$$,$t3599$$);throw Error("Only up to 20 arguments supported on functions");
};$cljs$core$next_STAR_$$=function($coll$jscomp$267$$){return $coll$jscomp$267$$!=null&&($coll$jscomp$267$$.$cljs$lang$protocol_mask$partition0$$&128||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$267$$.$cljs$core$INext$$)?$coll$jscomp$267$$.$cljs$core$INext$_next$arity$1$(null):$APP.$cljs$core$seq$$($APP.$cljs$core$rest$$($coll$jscomp$267$$))};
$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$03$$=function($f$jscomp$167$$,$a0$jscomp$2$$,$args$jscomp$18$$){return $args$jscomp$18$$==null?$f$jscomp$167$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$167$$.$cljs$core$IFn$_invoke$arity$1$($a0$jscomp$2$$):$f$jscomp$167$$.call($f$jscomp$167$$,$a0$jscomp$2$$):$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$04$$($f$jscomp$167$$,$a0$jscomp$2$$,$cljs$core$_first$$($args$jscomp$18$$),$cljs$core$next_STAR_$$($args$jscomp$18$$))};
$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$04$$=function($f$jscomp$168$$,$a0$jscomp$3$$,$a1$jscomp$3$$,$args$jscomp$19$$){return $args$jscomp$19$$==null?$f$jscomp$168$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$168$$.$cljs$core$IFn$_invoke$arity$2$($a0$jscomp$3$$,$a1$jscomp$3$$):$f$jscomp$168$$.call($f$jscomp$168$$,$a0$jscomp$3$$,$a1$jscomp$3$$):$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$05$$($f$jscomp$168$$,$a0$jscomp$3$$,$a1$jscomp$3$$,$cljs$core$_first$$($args$jscomp$19$$),
$cljs$core$next_STAR_$$($args$jscomp$19$$))};
$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$05$$=function($f$jscomp$169$$,$a0$jscomp$4$$,$a1$jscomp$4$$,$a2$$,$args$jscomp$20$$){return $args$jscomp$20$$==null?$f$jscomp$169$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$169$$.$cljs$core$IFn$_invoke$arity$3$($a0$jscomp$4$$,$a1$jscomp$4$$,$a2$$):$f$jscomp$169$$.call($f$jscomp$169$$,$a0$jscomp$4$$,$a1$jscomp$4$$,$a2$$):$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$06$$($f$jscomp$169$$,$a0$jscomp$4$$,$a1$jscomp$4$$,$a2$$,$cljs$core$_first$$($args$jscomp$20$$),
$cljs$core$next_STAR_$$($args$jscomp$20$$))};
$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$06$$=function($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a5_args$jscomp$21$$){if($a5_args$jscomp$21$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$4$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$4$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,
$a2$jscomp$1$$,$a3$$);var $a4$$=$cljs$core$_first$$($a5_args$jscomp$21$$),$a6_next_4$$=$APP.$cljs$core$next$$($a5_args$jscomp$21$$);if($a6_next_4$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$5$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$5$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$);$a5_args$jscomp$21$$=
$cljs$core$_first$$($a6_next_4$$);var $a7_next_5$$=$APP.$cljs$core$next$$($a6_next_4$$);if($a7_next_5$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$6$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$6$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$);$a6_next_4$$=
$cljs$core$_first$$($a7_next_5$$);var $a8_next_6$$=$APP.$cljs$core$next$$($a7_next_5$$);if($a8_next_6$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$7$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$7$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$);
$a7_next_5$$=$cljs$core$_first$$($a8_next_6$$);var $a9_next_7$$=$APP.$cljs$core$next$$($a8_next_6$$);if($a9_next_7$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$8$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$8$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,
$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$);$a8_next_6$$=$cljs$core$_first$$($a9_next_7$$);var $a10_next_8$$=$APP.$cljs$core$next$$($a9_next_7$$);if($a10_next_8$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$9$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$9$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,
$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$);$a9_next_7$$=$cljs$core$_first$$($a10_next_8$$);var $a11_next_9$$=$APP.$cljs$core$next$$($a10_next_8$$);if($a11_next_9$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$10$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$10$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,
$a8_next_6$$,$a9_next_7$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$);$a10_next_8$$=$cljs$core$_first$$($a11_next_9$$);var $a12_next_10$$=$APP.$cljs$core$next$$($a11_next_9$$);if($a12_next_10$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$11$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$11$($a0$jscomp$5_arr__5664__auto__$$,
$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$);$a11_next_9$$=$cljs$core$_first$$($a12_next_10$$);var $a13_next_11$$=$APP.$cljs$core$next$$($a12_next_10$$);if($a13_next_11$$==
null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$12$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$12$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,
$a9_next_7$$,$a10_next_8$$,$a11_next_9$$);$a12_next_10$$=$cljs$core$_first$$($a13_next_11$$);var $a14_next_12$$=$APP.$cljs$core$next$$($a13_next_11$$);if($a14_next_12$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$13$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$13$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$):$f$jscomp$170$$.call($f$jscomp$170$$,
$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$);$a13_next_11$$=$cljs$core$_first$$($a14_next_12$$);var $a15_next_13$$=$APP.$cljs$core$next$$($a14_next_12$$);if($a15_next_13$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$14$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$14$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,
$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,$a13_next_11$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,$a13_next_11$$);$a14_next_12$$=$cljs$core$_first$$($a15_next_13$$);var $a16$jscomp$2_next_14$$=
$APP.$cljs$core$next$$($a15_next_13$$);if($a16$jscomp$2_next_14$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$15$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$15$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,$a13_next_11$$,$a14_next_12$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,
$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,$a13_next_11$$,$a14_next_12$$);$a15_next_13$$=$cljs$core$_first$$($a16$jscomp$2_next_14$$);var $a17_next_15$$=$APP.$cljs$core$next$$($a16$jscomp$2_next_14$$);if($a17_next_15$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$16$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$16$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,
$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,$a13_next_11$$,$a14_next_12$$,$a15_next_13$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,$a13_next_11$$,$a14_next_12$$,$a15_next_13$$);$a16$jscomp$2_next_14$$=$cljs$core$_first$$($a17_next_15$$);
var $a18_next_16$$=$APP.$cljs$core$next$$($a17_next_15$$);if($a18_next_16$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$17$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$17$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,$a13_next_11$$,$a14_next_12$$,$a15_next_13$$,$a16$jscomp$2_next_14$$):$f$jscomp$170$$.call($f$jscomp$170$$,
$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,$a13_next_11$$,$a14_next_12$$,$a15_next_13$$,$a16$jscomp$2_next_14$$);$a17_next_15$$=$cljs$core$_first$$($a18_next_16$$);var $a19_next_17$$=$APP.$cljs$core$next$$($a18_next_16$$);if($a19_next_17$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$18$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$18$($a0$jscomp$5_arr__5664__auto__$$,
$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,$a13_next_11$$,$a14_next_12$$,$a15_next_13$$,$a16$jscomp$2_next_14$$,$a17_next_15$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,
$a13_next_11$$,$a14_next_12$$,$a15_next_13$$,$a16$jscomp$2_next_14$$,$a17_next_15$$);$a18_next_16$$=$cljs$core$_first$$($a19_next_17$$);var $next_18_next_19$$=$APP.$cljs$core$next$$($a19_next_17$$);if($next_18_next_19$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$19$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$19$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,
$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,$a13_next_11$$,$a14_next_12$$,$a15_next_13$$,$a16$jscomp$2_next_14$$,$a17_next_15$$,$a18_next_16$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,$a13_next_11$$,$a14_next_12$$,$a15_next_13$$,$a16$jscomp$2_next_14$$,$a17_next_15$$,$a18_next_16$$);$a19_next_17$$=
$cljs$core$_first$$($next_18_next_19$$);$next_18_next_19$$=$APP.$cljs$core$next$$($next_18_next_19$$);if($next_18_next_19$$==null)return $f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$20$?$f$jscomp$170$$.$cljs$core$IFn$_invoke$arity$20$($a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,$a13_next_11$$,$a14_next_12$$,$a15_next_13$$,$a16$jscomp$2_next_14$$,
$a17_next_15$$,$a18_next_16$$,$a19_next_17$$):$f$jscomp$170$$.call($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,$a13_next_11$$,$a14_next_12$$,$a15_next_13$$,$a16$jscomp$2_next_14$$,$a17_next_15$$,$a18_next_16$$,$a19_next_17$$);$a0$jscomp$5_arr__5664__auto__$$=[$a0$jscomp$5_arr__5664__auto__$$,$a1$jscomp$5_s__5665__auto___25980$$,
$a2$jscomp$1$$,$a3$$,$a4$$,$a5_args$jscomp$21$$,$a6_next_4$$,$a7_next_5$$,$a8_next_6$$,$a9_next_7$$,$a10_next_8$$,$a11_next_9$$,$a12_next_10$$,$a13_next_11$$,$a14_next_12$$,$a15_next_13$$,$a16$jscomp$2_next_14$$,$a17_next_15$$,$a18_next_16$$,$a19_next_17$$];for($a1$jscomp$5_s__5665__auto___25980$$=$next_18_next_19$$;;)if($a1$jscomp$5_s__5665__auto___25980$$)$a0$jscomp$5_arr__5664__auto__$$.push($cljs$core$_first$$($a1$jscomp$5_s__5665__auto___25980$$)),$a1$jscomp$5_s__5665__auto___25980$$=$APP.$cljs$core$next$$($a1$jscomp$5_s__5665__auto___25980$$);
else break;return $f$jscomp$170$$.apply($f$jscomp$170$$,$a0$jscomp$5_arr__5664__auto__$$)};
$APP.$cljs$core$__destructure_map$$=function($gmap$$){return $gmap$$!=null&&($gmap$$.$cljs$lang$protocol_mask$partition0$$&64||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$gmap$$.$cljs$core$ISeq$$)?$APP.$cljs$core$next$$($gmap$$)?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$($APP.$cljs$core$to_array$$($gmap$$)):$APP.$cljs$core$seq$$($gmap$$)?$APP.$cljs$core$first$$($gmap$$):$APP.$cljs$core$PersistentArrayMap$EMPTY$$:$gmap$$};
$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$=function($obj$jscomp$89$$,$JSCompiler_inline_result$jscomp$151_a$jscomp$122$$,$b$jscomp$106$$){var $G__23229$jscomp$inline_2659$$=$APP.$cljs$core$meta$$($obj$jscomp$89$$);$JSCompiler_inline_result$jscomp$151_a$jscomp$122$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__23229$jscomp$inline_2659$$,$JSCompiler_inline_result$jscomp$151_a$jscomp$122$$,$b$jscomp$106$$):$APP.$cljs$core$assoc$$($G__23229$jscomp$inline_2659$$,
$JSCompiler_inline_result$jscomp$151_a$jscomp$122$$,$b$jscomp$106$$);return $APP.$cljs$core$with_meta$$($obj$jscomp$89$$,$JSCompiler_inline_result$jscomp$151_a$jscomp$122$$)};
$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$06$$=function($obj$jscomp$91$$,$JSCompiler_inline_result$jscomp$152_f$jscomp$180$$,$a$jscomp$124$$,$b$jscomp$108$$,$c$jscomp$87$$,$d$jscomp$80$$){var $G__23236$jscomp$inline_2661$$=$APP.$cljs$core$meta$$($obj$jscomp$91$$);$JSCompiler_inline_result$jscomp$152_f$jscomp$180$$=$JSCompiler_inline_result$jscomp$152_f$jscomp$180$$.$cljs$core$IFn$_invoke$arity$5$?$JSCompiler_inline_result$jscomp$152_f$jscomp$180$$.$cljs$core$IFn$_invoke$arity$5$($G__23236$jscomp$inline_2661$$,
$a$jscomp$124$$,$b$jscomp$108$$,$c$jscomp$87$$,$d$jscomp$80$$):$JSCompiler_inline_result$jscomp$152_f$jscomp$180$$($G__23236$jscomp$inline_2661$$,$a$jscomp$124$$,$b$jscomp$108$$,$c$jscomp$87$$,$d$jscomp$80$$);return $APP.$cljs$core$with_meta$$($obj$jscomp$91$$,$JSCompiler_inline_result$jscomp$152_f$jscomp$180$$)};
$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($obj$jscomp$92$$,$f$jscomp$181$$,$a$jscomp$125$$,$b$jscomp$109$$,$c$jscomp$88$$,$d$jscomp$81$$,$args$jscomp$27$$){return $APP.$cljs$core$with_meta$$($obj$jscomp$92$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$($f$jscomp$181$$,$APP.$cljs$core$meta$$($obj$jscomp$92$$),$a$jscomp$125$$,$b$jscomp$109$$,$c$jscomp$88$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$d$jscomp$81$$,$args$jscomp$27$$])))};
$APP.$cljs$core$not_empty$$=function($coll$jscomp$268$$){return $APP.$cljs$core$seq$$($coll$jscomp$268$$)?$coll$jscomp$268$$:null};$cljs$core$t_cljs$0core23246$$=function($meta23247$$){this.$meta23247$=$meta23247$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};$APP.$cljs$core$nil_iter$$=function(){return new $cljs$core$t_cljs$0core23246$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$core$StringIter$$=function($s$jscomp$66$$){this.s=$s$jscomp$66$$;this.i=0};$cljs$core$ArrayIter$$=function($arr$jscomp$80$$){this.$arr$=$arr$jscomp$80$$;this.i=0};$APP.$cljs$core$SeqIter$$=function($_next$$){this.$_seq$=$cljs$core$INIT$$;this.$_next$=$_next$$};
$cljs$core$iter$$=function($coll$jscomp$270$$){if($cljs$core$iterable_QMARK_$$($coll$jscomp$270$$))return $APP.$cljs$core$_iterator$$($coll$jscomp$270$$);if($coll$jscomp$270$$==null)return $APP.$cljs$core$nil_iter$$();if(typeof $coll$jscomp$270$$==="string")return new $cljs$core$StringIter$$($coll$jscomp$270$$);if($APP.$cljs$core$array_QMARK_$$($coll$jscomp$270$$))return new $cljs$core$ArrayIter$$($coll$jscomp$270$$);if($APP.$cljs$core$seqable_QMARK_$$($coll$jscomp$270$$))return new $APP.$cljs$core$SeqIter$$($coll$jscomp$270$$);
throw Error(["Cannot create iterator from ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($coll$jscomp$270$$)].join(""));};$cljs$core$Many$$=function($vals$jscomp$4$$){this.$vals$=$vals$jscomp$4$$};$cljs$core$Single$$=function($val$jscomp$69$$){this.$val$=$val$jscomp$69$$};$cljs$core$Empty$$=function(){};
$cljs$core$TransformerIterator$$=function($sourceIter$$){this.buffer=$cljs$core$EMPTY$$;this.$_next$=$cljs$core$NONE$$;this.completed=!1;this.xf=null;this.$sourceIter$=$sourceIter$$;this.$multi$=!1};
$cljs$core$transformer_iterator$$=function($xform$jscomp$2$$,$sourceIter$jscomp$2$$){var $iterator$jscomp$8$$=new $cljs$core$TransformerIterator$$($sourceIter$jscomp$2$$);$iterator$jscomp$8$$.xf=function(){var $G__23251$$=function(){function $G__26067__2$$($acc$jscomp$4$$,$o$jscomp$92$$){$iterator$jscomp$8$$.buffer=$iterator$jscomp$8$$.buffer.add($o$jscomp$92$$);return $acc$jscomp$4$$}var $G__26067$$=null;$G__26067$$=function($acc$jscomp$5$$,$o$jscomp$93$$){switch(arguments.length){case 0:return null;
case 1:return $acc$jscomp$5$$;case 2:return $G__26067__2$$.call(this,$acc$jscomp$5$$,$o$jscomp$93$$)}throw Error("Invalid arity: "+arguments.length);};$G__26067$$.$cljs$core$IFn$_invoke$arity$0$=function(){return null};$G__26067$$.$cljs$core$IFn$_invoke$arity$1$=function($acc$jscomp$3$$){return $acc$jscomp$3$$};$G__26067$$.$cljs$core$IFn$_invoke$arity$2$=$G__26067__2$$;return $G__26067$$}();return $xform$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$xform$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__23251$$):
$xform$jscomp$2$$($G__23251$$)}();return $iterator$jscomp$8$$};$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$01$$=function($coll$jscomp$271_or__5025__auto__$jscomp$7$$){return $APP.$cljs$core$seq_QMARK_$$($coll$jscomp$271_or__5025__auto__$jscomp$7$$)?$coll$jscomp$271_or__5025__auto__$jscomp$7$$:($coll$jscomp$271_or__5025__auto__$jscomp$7$$=$APP.$cljs$core$seq$$($coll$jscomp$271_or__5025__auto__$jscomp$7$$))?$coll$jscomp$271_or__5025__auto__$jscomp$7$$:$APP.$cljs$core$List$EMPTY$$};
$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$=function($JSCompiler_inline_result$jscomp$155_or__5025__auto__$jscomp$8_xform$jscomp$5$$,$coll$jscomp$272_source$jscomp$inline_2668$$){$coll$jscomp$272_source$jscomp$inline_2668$$=$cljs$core$iter$$($coll$jscomp$272_source$jscomp$inline_2668$$);$JSCompiler_inline_result$jscomp$155_or__5025__auto__$jscomp$8_xform$jscomp$5$$=$cljs$core$transformer_iterator$$($JSCompiler_inline_result$jscomp$155_or__5025__auto__$jscomp$8_xform$jscomp$5$$,$coll$jscomp$272_source$jscomp$inline_2668$$);
$JSCompiler_inline_result$jscomp$155_or__5025__auto__$jscomp$8_xform$jscomp$5$$=$cljs$core$chunkIteratorSeq$$($JSCompiler_inline_result$jscomp$155_or__5025__auto__$jscomp$8_xform$jscomp$5$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$155_or__5025__auto__$jscomp$8_xform$jscomp$5$$)?$JSCompiler_inline_result$jscomp$155_or__5025__auto__$jscomp$8_xform$jscomp$5$$:$APP.$cljs$core$List$EMPTY$$};
$APP.$cljs$core$every_QMARK_$$=function($G__26098_pred$$,$G__26099_coll$jscomp$274$$){for(;;){if($APP.$cljs$core$seq$$($G__26099_coll$jscomp$274$$)==null)return!0;var $G__23259$jscomp$inline_2670_JSCompiler_inline_result$jscomp$157$$=$APP.$cljs$core$first$$($G__26099_coll$jscomp$274$$);$G__23259$jscomp$inline_2670_JSCompiler_inline_result$jscomp$157$$=$G__26098_pred$$.$cljs$core$IFn$_invoke$arity$1$?$G__26098_pred$$.$cljs$core$IFn$_invoke$arity$1$($G__23259$jscomp$inline_2670_JSCompiler_inline_result$jscomp$157$$):
$G__26098_pred$$($G__23259$jscomp$inline_2670_JSCompiler_inline_result$jscomp$157$$);if($APP.$cljs$core$truth_$$($G__23259$jscomp$inline_2670_JSCompiler_inline_result$jscomp$157$$))$G__26099_coll$jscomp$274$$=$APP.$cljs$core$next$$($G__26099_coll$jscomp$274$$);else return!1}};
$APP.$cljs$core$some$$=function($G__26105_pred$jscomp$2$$,$G__26106_coll$jscomp$276_s$jscomp$68_temp__5825__auto__$$){for(;;)if($G__26106_coll$jscomp$276_s$jscomp$68_temp__5825__auto__$$=$APP.$cljs$core$seq$$($G__26106_coll$jscomp$276_s$jscomp$68_temp__5825__auto__$$)){var $G__23260$jscomp$inline_2672_or__5025__auto__$jscomp$10$$=$APP.$cljs$core$first$$($G__26106_coll$jscomp$276_s$jscomp$68_temp__5825__auto__$$);$G__23260$jscomp$inline_2672_or__5025__auto__$jscomp$10$$=$G__26105_pred$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?
$G__26105_pred$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__23260$jscomp$inline_2672_or__5025__auto__$jscomp$10$$):$G__26105_pred$jscomp$2$$($G__23260$jscomp$inline_2672_or__5025__auto__$jscomp$10$$);if($APP.$cljs$core$truth_$$($G__23260$jscomp$inline_2672_or__5025__auto__$jscomp$10$$))return $G__23260$jscomp$inline_2672_or__5025__auto__$jscomp$10$$;$G__26106_coll$jscomp$276_s$jscomp$68_temp__5825__auto__$$=$APP.$cljs$core$next$$($G__26106_coll$jscomp$276_s$jscomp$68_temp__5825__auto__$$)}else return null};
$APP.$cljs$core$even_QMARK_$$=function($n$jscomp$87$$){if($APP.$cljs$core$integer_QMARK_$$($n$jscomp$87$$))return($n$jscomp$87$$&1)===0;throw Error(["Argument must be an integer: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$87$$)].join(""));};$APP.$cljs$core$odd_QMARK_$$=function($n$jscomp$88$$){return!$APP.$cljs$core$even_QMARK_$$($n$jscomp$88$$)};
$APP.$cljs$core$complement$$=function($f$jscomp$182$$){return function(){function $G__26117__2$$($x$jscomp$353$$,$y$jscomp$144$$){return $APP.$cljs$core$not$$($f$jscomp$182$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$182$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$353$$,$y$jscomp$144$$):$f$jscomp$182$$($x$jscomp$353$$,$y$jscomp$144$$))}function $G__26117__1$$($x$jscomp$352$$){return $APP.$cljs$core$not$$($f$jscomp$182$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$182$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$352$$):
$f$jscomp$182$$($x$jscomp$352$$))}function $G__26117__0$$(){return $APP.$cljs$core$not$$($f$jscomp$182$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$182$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$182$$())}var $G__26117$$=null,$G__26117__3$$=function(){function $G__26123$$($x$jscomp$355$$,$y$jscomp$146$$,$var_args$jscomp$164$$){var $G__26132__i_zs$jscomp$2$$=null;if(arguments.length>2){$G__26132__i_zs$jscomp$2$$=0;for(var $G__26132__a$$=Array(arguments.length-2);$G__26132__i_zs$jscomp$2$$<$G__26132__a$$.length;)$G__26132__a$$[$G__26132__i_zs$jscomp$2$$]=
arguments[$G__26132__i_zs$jscomp$2$$+2],++$G__26132__i_zs$jscomp$2$$;$G__26132__i_zs$jscomp$2$$=new $APP.$cljs$core$IndexedSeq$$($G__26132__a$$,0,null)}return $G__26123__delegate$$.call(this,$x$jscomp$355$$,$y$jscomp$146$$,$G__26132__i_zs$jscomp$2$$)}function $G__26123__delegate$$($x$jscomp$354$$,$y$jscomp$145$$,$zs$jscomp$1$$){return $APP.$cljs$core$not$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$4$($f$jscomp$182$$,$x$jscomp$354$$,$y$jscomp$145$$,$zs$jscomp$1$$))}$G__26123$$.$cljs$lang$maxFixedArity$=
2;$G__26123$$.$cljs$lang$applyTo$=function($arglist__26133_zs$jscomp$3$$){var $x$jscomp$356$$=$APP.$cljs$core$first$$($arglist__26133_zs$jscomp$3$$);$arglist__26133_zs$jscomp$3$$=$APP.$cljs$core$next$$($arglist__26133_zs$jscomp$3$$);var $y$jscomp$147$$=$APP.$cljs$core$first$$($arglist__26133_zs$jscomp$3$$);$arglist__26133_zs$jscomp$3$$=$APP.$cljs$core$rest$$($arglist__26133_zs$jscomp$3$$);return $G__26123__delegate$$($x$jscomp$356$$,$y$jscomp$147$$,$arglist__26133_zs$jscomp$3$$)};$G__26123$$.$cljs$core$IFn$_invoke$arity$variadic$=
$G__26123__delegate$$;return $G__26123$$}();$G__26117$$=function($x$jscomp$357$$,$y$jscomp$148$$,$var_args$jscomp$165$$){switch(arguments.length){case 0:return $G__26117__0$$.call(this);case 1:return $G__26117__1$$.call(this,$x$jscomp$357$$);case 2:return $G__26117__2$$.call(this,$x$jscomp$357$$,$y$jscomp$148$$);default:var $G__26135_G__26136__i$$=null;if(arguments.length>2){$G__26135_G__26136__i$$=0;for(var $G__26136__a$$=Array(arguments.length-2);$G__26135_G__26136__i$$<$G__26136__a$$.length;)$G__26136__a$$[$G__26135_G__26136__i$$]=
arguments[$G__26135_G__26136__i$$+2],++$G__26135_G__26136__i$$;$G__26135_G__26136__i$$=new $APP.$cljs$core$IndexedSeq$$($G__26136__a$$,0,null)}return $G__26117__3$$.$cljs$core$IFn$_invoke$arity$variadic$($x$jscomp$357$$,$y$jscomp$148$$,$G__26135_G__26136__i$$)}throw Error("Invalid arity: "+arguments.length);};$G__26117$$.$cljs$lang$maxFixedArity$=2;$G__26117$$.$cljs$lang$applyTo$=$G__26117__3$$.$cljs$lang$applyTo$;$G__26117$$.$cljs$core$IFn$_invoke$arity$0$=$G__26117__0$$;$G__26117$$.$cljs$core$IFn$_invoke$arity$1$=
$G__26117__1$$;$G__26117$$.$cljs$core$IFn$_invoke$arity$2$=$G__26117__2$$;$G__26117$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26117__3$$.$cljs$core$IFn$_invoke$arity$variadic$;return $G__26117$$}()};
$APP.$cljs$core$constantly$$=function($x$jscomp$358$$){return function(){function $G__26152$$($var_args$jscomp$166$$){if(arguments.length>0)for(var $G__26153__i$$=0,$G__26153__a$$=Array(arguments.length-0);$G__26153__i$$<$G__26153__a$$.length;)$G__26153__a$$[$G__26153__i$$]=arguments[$G__26153__i$$+0],++$G__26153__i$$;return $x$jscomp$358$$}$G__26152$$.$cljs$lang$maxFixedArity$=0;$G__26152$$.$cljs$lang$applyTo$=function($arglist__26155$$){$APP.$cljs$core$seq$$($arglist__26155$$);return $x$jscomp$358$$};
$G__26152$$.$cljs$core$IFn$_invoke$arity$variadic$=function(){return $x$jscomp$358$$};return $G__26152$$}()};
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$187$$,$arg1$jscomp$1$$){return function(){function $G__26266__3$$($x$jscomp$375$$,$y$jscomp$162$$,$z$jscomp$28$$){return $f$jscomp$187$$.$cljs$core$IFn$_invoke$arity$4$?$f$jscomp$187$$.$cljs$core$IFn$_invoke$arity$4$($arg1$jscomp$1$$,$x$jscomp$375$$,$y$jscomp$162$$,$z$jscomp$28$$):$f$jscomp$187$$($arg1$jscomp$1$$,$x$jscomp$375$$,$y$jscomp$162$$,$z$jscomp$28$$)}function $G__26266__2$$($x$jscomp$374$$,$y$jscomp$161$$){return $f$jscomp$187$$.$cljs$core$IFn$_invoke$arity$3$?
$f$jscomp$187$$.$cljs$core$IFn$_invoke$arity$3$($arg1$jscomp$1$$,$x$jscomp$374$$,$y$jscomp$161$$):$f$jscomp$187$$($arg1$jscomp$1$$,$x$jscomp$374$$,$y$jscomp$161$$)}function $G__26266__1$$($x$jscomp$373$$){return $f$jscomp$187$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$187$$.$cljs$core$IFn$_invoke$arity$2$($arg1$jscomp$1$$,$x$jscomp$373$$):$f$jscomp$187$$($arg1$jscomp$1$$,$x$jscomp$373$$)}function $G__26266__0$$(){return $f$jscomp$187$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$187$$.$cljs$core$IFn$_invoke$arity$1$($arg1$jscomp$1$$):
$f$jscomp$187$$($arg1$jscomp$1$$)}var $G__26266$$=null,$G__26266__4$$=function(){function $G__26267$$($x$jscomp$377$$,$y$jscomp$164$$,$z$jscomp$30$$,$var_args$jscomp$174$$){var $G__26269__i_args$jscomp$43$$=null;if(arguments.length>3){$G__26269__i_args$jscomp$43$$=0;for(var $G__26269__a$$=Array(arguments.length-3);$G__26269__i_args$jscomp$43$$<$G__26269__a$$.length;)$G__26269__a$$[$G__26269__i_args$jscomp$43$$]=arguments[$G__26269__i_args$jscomp$43$$+3],++$G__26269__i_args$jscomp$43$$;$G__26269__i_args$jscomp$43$$=
new $APP.$cljs$core$IndexedSeq$$($G__26269__a$$,0,null)}return $G__26267__delegate$$.call(this,$x$jscomp$377$$,$y$jscomp$164$$,$z$jscomp$30$$,$G__26269__i_args$jscomp$43$$)}function $G__26267__delegate$$($x$jscomp$376$$,$y$jscomp$163$$,$z$jscomp$29$$,$args$jscomp$42$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$($f$jscomp$187$$,$arg1$jscomp$1$$,$x$jscomp$376$$,$y$jscomp$163$$,$z$jscomp$29$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$args$jscomp$42$$]))}
$G__26267$$.$cljs$lang$maxFixedArity$=3;$G__26267$$.$cljs$lang$applyTo$=function($arglist__26270_args$jscomp$44$$){var $x$jscomp$378$$=$APP.$cljs$core$first$$($arglist__26270_args$jscomp$44$$);$arglist__26270_args$jscomp$44$$=$APP.$cljs$core$next$$($arglist__26270_args$jscomp$44$$);var $y$jscomp$165$$=$APP.$cljs$core$first$$($arglist__26270_args$jscomp$44$$);$arglist__26270_args$jscomp$44$$=$APP.$cljs$core$next$$($arglist__26270_args$jscomp$44$$);var $z$jscomp$31$$=$APP.$cljs$core$first$$($arglist__26270_args$jscomp$44$$);
$arglist__26270_args$jscomp$44$$=$APP.$cljs$core$rest$$($arglist__26270_args$jscomp$44$$);return $G__26267__delegate$$($x$jscomp$378$$,$y$jscomp$165$$,$z$jscomp$31$$,$arglist__26270_args$jscomp$44$$)};$G__26267$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26267__delegate$$;return $G__26267$$}();$G__26266$$=function($x$jscomp$379$$,$y$jscomp$166$$,$z$jscomp$32$$,$var_args$jscomp$175$$){switch(arguments.length){case 0:return $G__26266__0$$.call(this);case 1:return $G__26266__1$$.call(this,$x$jscomp$379$$);
case 2:return $G__26266__2$$.call(this,$x$jscomp$379$$,$y$jscomp$166$$);case 3:return $G__26266__3$$.call(this,$x$jscomp$379$$,$y$jscomp$166$$,$z$jscomp$32$$);default:var $G__26271_G__26272__i$$=null;if(arguments.length>3){$G__26271_G__26272__i$$=0;for(var $G__26272__a$$=Array(arguments.length-3);$G__26271_G__26272__i$$<$G__26272__a$$.length;)$G__26272__a$$[$G__26271_G__26272__i$$]=arguments[$G__26271_G__26272__i$$+3],++$G__26271_G__26272__i$$;$G__26271_G__26272__i$$=new $APP.$cljs$core$IndexedSeq$$($G__26272__a$$,
0,null)}return $G__26266__4$$.$cljs$core$IFn$_invoke$arity$variadic$($x$jscomp$379$$,$y$jscomp$166$$,$z$jscomp$32$$,$G__26271_G__26272__i$$)}throw Error("Invalid arity: "+arguments.length);};$G__26266$$.$cljs$lang$maxFixedArity$=3;$G__26266$$.$cljs$lang$applyTo$=$G__26266__4$$.$cljs$lang$applyTo$;$G__26266$$.$cljs$core$IFn$_invoke$arity$0$=$G__26266__0$$;$G__26266$$.$cljs$core$IFn$_invoke$arity$1$=$G__26266__1$$;$G__26266$$.$cljs$core$IFn$_invoke$arity$2$=$G__26266__2$$;$G__26266$$.$cljs$core$IFn$_invoke$arity$3$=
$G__26266__3$$;$G__26266$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26266__4$$.$cljs$core$IFn$_invoke$arity$variadic$;return $G__26266$$}()};
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$=function($f$jscomp$188$$,$arg1$jscomp$2$$,$arg2$jscomp$1$$){return function(){function $G__26273__3$$($x$jscomp$382$$,$y$jscomp$168$$,$z$jscomp$33$$){return $f$jscomp$188$$.$cljs$core$IFn$_invoke$arity$5$?$f$jscomp$188$$.$cljs$core$IFn$_invoke$arity$5$($arg1$jscomp$2$$,$arg2$jscomp$1$$,$x$jscomp$382$$,$y$jscomp$168$$,$z$jscomp$33$$):$f$jscomp$188$$($arg1$jscomp$2$$,$arg2$jscomp$1$$,$x$jscomp$382$$,$y$jscomp$168$$,$z$jscomp$33$$)}function $G__26273__2$$($x$jscomp$381$$,
$y$jscomp$167$$){return $f$jscomp$188$$.$cljs$core$IFn$_invoke$arity$4$?$f$jscomp$188$$.$cljs$core$IFn$_invoke$arity$4$($arg1$jscomp$2$$,$arg2$jscomp$1$$,$x$jscomp$381$$,$y$jscomp$167$$):$f$jscomp$188$$($arg1$jscomp$2$$,$arg2$jscomp$1$$,$x$jscomp$381$$,$y$jscomp$167$$)}function $G__26273__1$$($x$jscomp$380$$){return $f$jscomp$188$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$188$$.$cljs$core$IFn$_invoke$arity$3$($arg1$jscomp$2$$,$arg2$jscomp$1$$,$x$jscomp$380$$):$f$jscomp$188$$($arg1$jscomp$2$$,$arg2$jscomp$1$$,
$x$jscomp$380$$)}function $G__26273__0$$(){return $f$jscomp$188$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$188$$.$cljs$core$IFn$_invoke$arity$2$($arg1$jscomp$2$$,$arg2$jscomp$1$$):$f$jscomp$188$$($arg1$jscomp$2$$,$arg2$jscomp$1$$)}var $G__26273$$=null,$G__26273__4$$=function(){function $G__26275$$($x$jscomp$384$$,$y$jscomp$170$$,$z$jscomp$35$$,$var_args$jscomp$176$$){var $G__26287__i_args$jscomp$47$$=null;if(arguments.length>3){$G__26287__i_args$jscomp$47$$=0;for(var $G__26287__a$$=Array(arguments.length-
3);$G__26287__i_args$jscomp$47$$<$G__26287__a$$.length;)$G__26287__a$$[$G__26287__i_args$jscomp$47$$]=arguments[$G__26287__i_args$jscomp$47$$+3],++$G__26287__i_args$jscomp$47$$;$G__26287__i_args$jscomp$47$$=new $APP.$cljs$core$IndexedSeq$$($G__26287__a$$,0,null)}return $G__26275__delegate$$.call(this,$x$jscomp$384$$,$y$jscomp$170$$,$z$jscomp$35$$,$G__26287__i_args$jscomp$47$$)}function $G__26275__delegate$$($x$jscomp$383$$,$y$jscomp$169$$,$z$jscomp$34$$,$args$jscomp$46$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$($f$jscomp$188$$,
$arg1$jscomp$2$$,$arg2$jscomp$1$$,$x$jscomp$383$$,$y$jscomp$169$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$z$jscomp$34$$,$args$jscomp$46$$]))}$G__26275$$.$cljs$lang$maxFixedArity$=3;$G__26275$$.$cljs$lang$applyTo$=function($arglist__26291_args$jscomp$48$$){var $x$jscomp$385$$=$APP.$cljs$core$first$$($arglist__26291_args$jscomp$48$$);$arglist__26291_args$jscomp$48$$=$APP.$cljs$core$next$$($arglist__26291_args$jscomp$48$$);var $y$jscomp$171$$=$APP.$cljs$core$first$$($arglist__26291_args$jscomp$48$$);
$arglist__26291_args$jscomp$48$$=$APP.$cljs$core$next$$($arglist__26291_args$jscomp$48$$);var $z$jscomp$36$$=$APP.$cljs$core$first$$($arglist__26291_args$jscomp$48$$);$arglist__26291_args$jscomp$48$$=$APP.$cljs$core$rest$$($arglist__26291_args$jscomp$48$$);return $G__26275__delegate$$($x$jscomp$385$$,$y$jscomp$171$$,$z$jscomp$36$$,$arglist__26291_args$jscomp$48$$)};$G__26275$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26275__delegate$$;return $G__26275$$}();$G__26273$$=function($x$jscomp$386$$,$y$jscomp$172$$,
$z$jscomp$37$$,$var_args$jscomp$177$$){switch(arguments.length){case 0:return $G__26273__0$$.call(this);case 1:return $G__26273__1$$.call(this,$x$jscomp$386$$);case 2:return $G__26273__2$$.call(this,$x$jscomp$386$$,$y$jscomp$172$$);case 3:return $G__26273__3$$.call(this,$x$jscomp$386$$,$y$jscomp$172$$,$z$jscomp$37$$);default:var $G__26303_G__26304__i$$=null;if(arguments.length>3){$G__26303_G__26304__i$$=0;for(var $G__26304__a$$=Array(arguments.length-3);$G__26303_G__26304__i$$<$G__26304__a$$.length;)$G__26304__a$$[$G__26303_G__26304__i$$]=
arguments[$G__26303_G__26304__i$$+3],++$G__26303_G__26304__i$$;$G__26303_G__26304__i$$=new $APP.$cljs$core$IndexedSeq$$($G__26304__a$$,0,null)}return $G__26273__4$$.$cljs$core$IFn$_invoke$arity$variadic$($x$jscomp$386$$,$y$jscomp$172$$,$z$jscomp$37$$,$G__26303_G__26304__i$$)}throw Error("Invalid arity: "+arguments.length);};$G__26273$$.$cljs$lang$maxFixedArity$=3;$G__26273$$.$cljs$lang$applyTo$=$G__26273__4$$.$cljs$lang$applyTo$;$G__26273$$.$cljs$core$IFn$_invoke$arity$0$=$G__26273__0$$;$G__26273$$.$cljs$core$IFn$_invoke$arity$1$=
$G__26273__1$$;$G__26273$$.$cljs$core$IFn$_invoke$arity$2$=$G__26273__2$$;$G__26273$$.$cljs$core$IFn$_invoke$arity$3$=$G__26273__3$$;$G__26273$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26273__4$$.$cljs$core$IFn$_invoke$arity$variadic$;return $G__26273$$}()};
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$=function($f$jscomp$189$$,$arg1$jscomp$3$$,$arg2$jscomp$2$$,$arg3$$){return function(){function $G__26306__3$$($x$jscomp$389$$,$y$jscomp$174$$,$z$jscomp$38$$){return $f$jscomp$189$$.$cljs$core$IFn$_invoke$arity$6$?$f$jscomp$189$$.$cljs$core$IFn$_invoke$arity$6$($arg1$jscomp$3$$,$arg2$jscomp$2$$,$arg3$$,$x$jscomp$389$$,$y$jscomp$174$$,$z$jscomp$38$$):$f$jscomp$189$$($arg1$jscomp$3$$,$arg2$jscomp$2$$,$arg3$$,$x$jscomp$389$$,$y$jscomp$174$$,
$z$jscomp$38$$)}function $G__26306__2$$($x$jscomp$388$$,$y$jscomp$173$$){return $f$jscomp$189$$.$cljs$core$IFn$_invoke$arity$5$?$f$jscomp$189$$.$cljs$core$IFn$_invoke$arity$5$($arg1$jscomp$3$$,$arg2$jscomp$2$$,$arg3$$,$x$jscomp$388$$,$y$jscomp$173$$):$f$jscomp$189$$($arg1$jscomp$3$$,$arg2$jscomp$2$$,$arg3$$,$x$jscomp$388$$,$y$jscomp$173$$)}function $G__26306__1$$($x$jscomp$387$$){return $f$jscomp$189$$.$cljs$core$IFn$_invoke$arity$4$?$f$jscomp$189$$.$cljs$core$IFn$_invoke$arity$4$($arg1$jscomp$3$$,
$arg2$jscomp$2$$,$arg3$$,$x$jscomp$387$$):$f$jscomp$189$$($arg1$jscomp$3$$,$arg2$jscomp$2$$,$arg3$$,$x$jscomp$387$$)}function $G__26306__0$$(){return $f$jscomp$189$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$189$$.$cljs$core$IFn$_invoke$arity$3$($arg1$jscomp$3$$,$arg2$jscomp$2$$,$arg3$$):$f$jscomp$189$$($arg1$jscomp$3$$,$arg2$jscomp$2$$,$arg3$$)}var $G__26306$$=null,$G__26306__4$$=function(){function $G__26308$$($x$jscomp$391$$,$y$jscomp$176$$,$z$jscomp$40$$,$var_args$jscomp$178$$){var $G__26309__i_args$jscomp$51$$=
null;if(arguments.length>3){$G__26309__i_args$jscomp$51$$=0;for(var $G__26309__a$$=Array(arguments.length-3);$G__26309__i_args$jscomp$51$$<$G__26309__a$$.length;)$G__26309__a$$[$G__26309__i_args$jscomp$51$$]=arguments[$G__26309__i_args$jscomp$51$$+3],++$G__26309__i_args$jscomp$51$$;$G__26309__i_args$jscomp$51$$=new $APP.$cljs$core$IndexedSeq$$($G__26309__a$$,0,null)}return $G__26308__delegate$$.call(this,$x$jscomp$391$$,$y$jscomp$176$$,$z$jscomp$40$$,$G__26309__i_args$jscomp$51$$)}function $G__26308__delegate$$($x$jscomp$390$$,
$y$jscomp$175$$,$z$jscomp$39$$,$args$jscomp$50$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$($f$jscomp$189$$,$arg1$jscomp$3$$,$arg2$jscomp$2$$,$arg3$$,$x$jscomp$390$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$y$jscomp$175$$,$z$jscomp$39$$,$args$jscomp$50$$]))}$G__26308$$.$cljs$lang$maxFixedArity$=3;$G__26308$$.$cljs$lang$applyTo$=function($arglist__26310_args$jscomp$52$$){var $x$jscomp$392$$=$APP.$cljs$core$first$$($arglist__26310_args$jscomp$52$$);
$arglist__26310_args$jscomp$52$$=$APP.$cljs$core$next$$($arglist__26310_args$jscomp$52$$);var $y$jscomp$177$$=$APP.$cljs$core$first$$($arglist__26310_args$jscomp$52$$);$arglist__26310_args$jscomp$52$$=$APP.$cljs$core$next$$($arglist__26310_args$jscomp$52$$);var $z$jscomp$41$$=$APP.$cljs$core$first$$($arglist__26310_args$jscomp$52$$);$arglist__26310_args$jscomp$52$$=$APP.$cljs$core$rest$$($arglist__26310_args$jscomp$52$$);return $G__26308__delegate$$($x$jscomp$392$$,$y$jscomp$177$$,$z$jscomp$41$$,
$arglist__26310_args$jscomp$52$$)};$G__26308$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26308__delegate$$;return $G__26308$$}();$G__26306$$=function($x$jscomp$393$$,$y$jscomp$178$$,$z$jscomp$42$$,$var_args$jscomp$179$$){switch(arguments.length){case 0:return $G__26306__0$$.call(this);case 1:return $G__26306__1$$.call(this,$x$jscomp$393$$);case 2:return $G__26306__2$$.call(this,$x$jscomp$393$$,$y$jscomp$178$$);case 3:return $G__26306__3$$.call(this,$x$jscomp$393$$,$y$jscomp$178$$,$z$jscomp$42$$);
default:var $G__26311_G__26312__i$$=null;if(arguments.length>3){$G__26311_G__26312__i$$=0;for(var $G__26312__a$$=Array(arguments.length-3);$G__26311_G__26312__i$$<$G__26312__a$$.length;)$G__26312__a$$[$G__26311_G__26312__i$$]=arguments[$G__26311_G__26312__i$$+3],++$G__26311_G__26312__i$$;$G__26311_G__26312__i$$=new $APP.$cljs$core$IndexedSeq$$($G__26312__a$$,0,null)}return $G__26306__4$$.$cljs$core$IFn$_invoke$arity$variadic$($x$jscomp$393$$,$y$jscomp$178$$,$z$jscomp$42$$,$G__26311_G__26312__i$$)}throw Error("Invalid arity: "+
arguments.length);};$G__26306$$.$cljs$lang$maxFixedArity$=3;$G__26306$$.$cljs$lang$applyTo$=$G__26306__4$$.$cljs$lang$applyTo$;$G__26306$$.$cljs$core$IFn$_invoke$arity$0$=$G__26306__0$$;$G__26306$$.$cljs$core$IFn$_invoke$arity$1$=$G__26306__1$$;$G__26306$$.$cljs$core$IFn$_invoke$arity$2$=$G__26306__2$$;$G__26306$$.$cljs$core$IFn$_invoke$arity$3$=$G__26306__3$$;$G__26306$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26306__4$$.$cljs$core$IFn$_invoke$arity$variadic$;return $G__26306$$}()};
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($f$jscomp$190$$,$arg1$jscomp$4$$,$arg2$jscomp$3$$,$arg3$jscomp$1$$,$more$jscomp$29$$){return function(){function $G__26313$$($var_args$jscomp$180$$){var $G__26315__i_args$jscomp$55$$=null;if(arguments.length>0){$G__26315__i_args$jscomp$55$$=0;for(var $G__26315__a$$=Array(arguments.length-0);$G__26315__i_args$jscomp$55$$<$G__26315__a$$.length;)$G__26315__a$$[$G__26315__i_args$jscomp$55$$]=arguments[$G__26315__i_args$jscomp$55$$+
0],++$G__26315__i_args$jscomp$55$$;$G__26315__i_args$jscomp$55$$=new $APP.$cljs$core$IndexedSeq$$($G__26315__a$$,0,null)}return $G__26313__delegate$$.call(this,$G__26315__i_args$jscomp$55$$)}function $G__26313__delegate$$($args$jscomp$54$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($f$jscomp$190$$,$arg1$jscomp$4$$,$arg2$jscomp$3$$,$arg3$jscomp$1$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($more$jscomp$29$$,$args$jscomp$54$$))}$G__26313$$.$cljs$lang$maxFixedArity$=
0;$G__26313$$.$cljs$lang$applyTo$=function($arglist__26327_args$jscomp$56$$){$arglist__26327_args$jscomp$56$$=$APP.$cljs$core$seq$$($arglist__26327_args$jscomp$56$$);return $G__26313__delegate$$($arglist__26327_args$jscomp$56$$)};$G__26313$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26313__delegate$$;return $G__26313$$}()};
$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$191$$,$x$jscomp$394$$){return function(){function $G__26347__3$$($G__23295_a$jscomp$128$$,$b$jscomp$111$$,$c$jscomp$89$$){$G__23295_a$jscomp$128$$=$G__23295_a$jscomp$128$$==null?$x$jscomp$394$$:$G__23295_a$jscomp$128$$;return $f$jscomp$191$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$191$$.$cljs$core$IFn$_invoke$arity$3$($G__23295_a$jscomp$128$$,$b$jscomp$111$$,$c$jscomp$89$$):$f$jscomp$191$$($G__23295_a$jscomp$128$$,$b$jscomp$111$$,
$c$jscomp$89$$)}function $G__26347__2$$($G__23293_a$jscomp$127$$,$b$jscomp$110$$){$G__23293_a$jscomp$127$$=$G__23293_a$jscomp$127$$==null?$x$jscomp$394$$:$G__23293_a$jscomp$127$$;return $f$jscomp$191$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$191$$.$cljs$core$IFn$_invoke$arity$2$($G__23293_a$jscomp$127$$,$b$jscomp$110$$):$f$jscomp$191$$($G__23293_a$jscomp$127$$,$b$jscomp$110$$)}function $G__26347__1$$($G__23292_a$jscomp$126$$){$G__23292_a$jscomp$126$$=$G__23292_a$jscomp$126$$==null?$x$jscomp$394$$:
$G__23292_a$jscomp$126$$;return $f$jscomp$191$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$191$$.$cljs$core$IFn$_invoke$arity$1$($G__23292_a$jscomp$126$$):$f$jscomp$191$$($G__23292_a$jscomp$126$$)}var $G__26347$$=null,$G__26347__4$$=function(){function $G__26348$$($a$jscomp$130$$,$b$jscomp$113$$,$c$jscomp$91$$,$var_args$jscomp$182$$){var $G__26349__i_ds$jscomp$1$$=null;if(arguments.length>3){$G__26349__i_ds$jscomp$1$$=0;for(var $G__26349__a$$=Array(arguments.length-3);$G__26349__i_ds$jscomp$1$$<$G__26349__a$$.length;)$G__26349__a$$[$G__26349__i_ds$jscomp$1$$]=
arguments[$G__26349__i_ds$jscomp$1$$+3],++$G__26349__i_ds$jscomp$1$$;$G__26349__i_ds$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__26349__a$$,0,null)}return $G__26348__delegate$$.call(this,$a$jscomp$130$$,$b$jscomp$113$$,$c$jscomp$91$$,$G__26349__i_ds$jscomp$1$$)}function $G__26348__delegate$$($a$jscomp$129$$,$b$jscomp$112$$,$c$jscomp$90$$,$ds$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($f$jscomp$191$$,$a$jscomp$129$$==null?$x$jscomp$394$$:$a$jscomp$129$$,$b$jscomp$112$$,$c$jscomp$90$$,
$ds$$)}$G__26348$$.$cljs$lang$maxFixedArity$=3;$G__26348$$.$cljs$lang$applyTo$=function($arglist__26350_ds$jscomp$2$$){var $a$jscomp$131$$=$APP.$cljs$core$first$$($arglist__26350_ds$jscomp$2$$);$arglist__26350_ds$jscomp$2$$=$APP.$cljs$core$next$$($arglist__26350_ds$jscomp$2$$);var $b$jscomp$114$$=$APP.$cljs$core$first$$($arglist__26350_ds$jscomp$2$$);$arglist__26350_ds$jscomp$2$$=$APP.$cljs$core$next$$($arglist__26350_ds$jscomp$2$$);var $c$jscomp$92$$=$APP.$cljs$core$first$$($arglist__26350_ds$jscomp$2$$);
$arglist__26350_ds$jscomp$2$$=$APP.$cljs$core$rest$$($arglist__26350_ds$jscomp$2$$);return $G__26348__delegate$$($a$jscomp$131$$,$b$jscomp$114$$,$c$jscomp$92$$,$arglist__26350_ds$jscomp$2$$)};$G__26348$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26348__delegate$$;return $G__26348$$}();$G__26347$$=function($a$jscomp$132$$,$b$jscomp$115$$,$c$jscomp$93$$,$var_args$jscomp$183$$){switch(arguments.length){case 1:return $G__26347__1$$.call(this,$a$jscomp$132$$);case 2:return $G__26347__2$$.call(this,$a$jscomp$132$$,
$b$jscomp$115$$);case 3:return $G__26347__3$$.call(this,$a$jscomp$132$$,$b$jscomp$115$$,$c$jscomp$93$$);default:var $G__26352_G__26353__i$$=null;if(arguments.length>3){$G__26352_G__26353__i$$=0;for(var $G__26353__a$$=Array(arguments.length-3);$G__26352_G__26353__i$$<$G__26353__a$$.length;)$G__26353__a$$[$G__26352_G__26353__i$$]=arguments[$G__26352_G__26353__i$$+3],++$G__26352_G__26353__i$$;$G__26352_G__26353__i$$=new $APP.$cljs$core$IndexedSeq$$($G__26353__a$$,0,null)}return $G__26347__4$$.$cljs$core$IFn$_invoke$arity$variadic$($a$jscomp$132$$,
$b$jscomp$115$$,$c$jscomp$93$$,$G__26352_G__26353__i$$)}throw Error("Invalid arity: "+arguments.length);};$G__26347$$.$cljs$lang$maxFixedArity$=3;$G__26347$$.$cljs$lang$applyTo$=$G__26347__4$$.$cljs$lang$applyTo$;$G__26347$$.$cljs$core$IFn$_invoke$arity$1$=$G__26347__1$$;$G__26347$$.$cljs$core$IFn$_invoke$arity$2$=$G__26347__2$$;$G__26347$$.$cljs$core$IFn$_invoke$arity$3$=$G__26347__3$$;$G__26347$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26347__4$$.$cljs$core$IFn$_invoke$arity$variadic$;return $G__26347$$}()};
$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$=function($f$jscomp$194$$){return function($rf$$){var $i$jscomp$197$$=$APP.$cljs$core$volatile_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$volatile_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(-1):$APP.$cljs$core$volatile_BANG_$$(-1);return function(){function $G__26430__2$$($result$jscomp$23$$,$G__23311_input$jscomp$11$$){var $G__23312$jscomp$inline_2688$$=$APP.$cljs$core$_vreset_BANG_$$($i$jscomp$197$$,$APP.$cljs$core$_deref$$($i$jscomp$197$$)+
1);$G__23311_input$jscomp$11$$=$f$jscomp$194$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$194$$.$cljs$core$IFn$_invoke$arity$2$($G__23312$jscomp$inline_2688$$,$G__23311_input$jscomp$11$$):$f$jscomp$194$$($G__23312$jscomp$inline_2688$$,$G__23311_input$jscomp$11$$);return $rf$$.$cljs$core$IFn$_invoke$arity$2$?$rf$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$23$$,$G__23311_input$jscomp$11$$):$rf$$($result$jscomp$23$$,$G__23311_input$jscomp$11$$)}function $G__26430__1$$($result$jscomp$22$$){return $rf$$.$cljs$core$IFn$_invoke$arity$1$?
$rf$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$22$$):$rf$$($result$jscomp$22$$)}function $G__26430__0$$(){return $rf$$.$cljs$core$IFn$_invoke$arity$0$?$rf$$.$cljs$core$IFn$_invoke$arity$0$():$rf$$()}var $G__26430$$=null;$G__26430$$=function($result$jscomp$24$$,$input$jscomp$12$$){switch(arguments.length){case 0:return $G__26430__0$$.call(this);case 1:return $G__26430__1$$.call(this,$result$jscomp$24$$);case 2:return $G__26430__2$$.call(this,$result$jscomp$24$$,$input$jscomp$12$$)}throw Error("Invalid arity: "+
arguments.length);};$G__26430$$.$cljs$core$IFn$_invoke$arity$0$=$G__26430__0$$;$G__26430$$.$cljs$core$IFn$_invoke$arity$1$=$G__26430__1$$;$G__26430$$.$cljs$core$IFn$_invoke$arity$2$=$G__26430__2$$;return $G__26430$$}()}};
$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$195$$,$coll$jscomp$278$$){return function $cljs$core$mapi$$($idx$jscomp$16$$,$coll__$1$jscomp$99$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $temp__5825__auto__$jscomp$1$$=$APP.$cljs$core$seq$$($coll__$1$jscomp$99$$);if($temp__5825__auto__$jscomp$1$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($temp__5825__auto__$jscomp$1$$)){for(var $c$jscomp$104$$=$APP.$cljs$core$_chunked_first$$($temp__5825__auto__$jscomp$1$$),
$size$jscomp$30$$=$APP.$cljs$core$count$$($c$jscomp$104$$),$b$jscomp$128$$=$APP.$cljs$core$chunk_buffer$$($size$jscomp$30$$),$i_26465$$=0;;)if($i_26465$$<$size$jscomp$30$$)$APP.$cljs$core$chunk_append$$($b$jscomp$128$$,function(){var $G__23318$$=$idx$jscomp$16$$+$i_26465$$,$G__23319$$=$APP.$cljs$core$_nth$$($c$jscomp$104$$,$i_26465$$);return $f$jscomp$195$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$195$$.$cljs$core$IFn$_invoke$arity$2$($G__23318$$,$G__23319$$):$f$jscomp$195$$($G__23318$$,$G__23319$$)}()),
$i_26465$$+=1;else break;return $APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b$jscomp$128$$),$cljs$core$mapi$$($idx$jscomp$16$$+$size$jscomp$30$$,$APP.$cljs$core$_chunked_rest$$($temp__5825__auto__$jscomp$1$$)))}return $APP.$cljs$core$cons$$(function(){var $G__23321$$=$APP.$cljs$core$first$$($temp__5825__auto__$jscomp$1$$);return $f$jscomp$195$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$195$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$16$$,$G__23321$$):$f$jscomp$195$$($idx$jscomp$16$$,$G__23321$$)}(),
$cljs$core$mapi$$($idx$jscomp$16$$+1,$APP.$cljs$core$rest$$($temp__5825__auto__$jscomp$1$$)))}return null},null,null)}(0,$coll$jscomp$278$$)};
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$=function($f$jscomp$196$$){return function($rf$jscomp$1$$){return function(){function $G__26474__2$$($result$jscomp$26$$,$input$jscomp$13_v$jscomp$14$$){$input$jscomp$13_v$jscomp$14$$=$f$jscomp$196$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$196$$.$cljs$core$IFn$_invoke$arity$1$($input$jscomp$13_v$jscomp$14$$):$f$jscomp$196$$($input$jscomp$13_v$jscomp$14$$);return $input$jscomp$13_v$jscomp$14$$==null?$result$jscomp$26$$:$rf$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?
$rf$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$26$$,$input$jscomp$13_v$jscomp$14$$):$rf$jscomp$1$$($result$jscomp$26$$,$input$jscomp$13_v$jscomp$14$$)}function $G__26474__1$$($result$jscomp$25$$){return $rf$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$25$$):$rf$jscomp$1$$($result$jscomp$25$$)}function $G__26474__0$$(){return $rf$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$rf$jscomp$1$$()}
var $G__26474$$=null;$G__26474$$=function($result$jscomp$27$$,$input$jscomp$14$$){switch(arguments.length){case 0:return $G__26474__0$$.call(this);case 1:return $G__26474__1$$.call(this,$result$jscomp$27$$);case 2:return $G__26474__2$$.call(this,$result$jscomp$27$$,$input$jscomp$14$$)}throw Error("Invalid arity: "+arguments.length);};$G__26474$$.$cljs$core$IFn$_invoke$arity$0$=$G__26474__0$$;$G__26474$$.$cljs$core$IFn$_invoke$arity$1$=$G__26474__1$$;$G__26474$$.$cljs$core$IFn$_invoke$arity$2$=$G__26474__2$$;
return $G__26474$$}()}};
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$197$$,$coll$jscomp$279$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $temp__5825__auto__$jscomp$2$$=$APP.$cljs$core$seq$$($coll$jscomp$279$$);if($temp__5825__auto__$jscomp$2$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($temp__5825__auto__$jscomp$2$$)){for(var $c$jscomp$105$$=$APP.$cljs$core$_chunked_first$$($temp__5825__auto__$jscomp$2$$),$size$jscomp$31_x$jscomp$397$$=$APP.$cljs$core$count$$($c$jscomp$105$$),$b$jscomp$129$$=
$APP.$cljs$core$chunk_buffer$$($size$jscomp$31_x$jscomp$397$$),$i_26494$$=0;;)if($i_26494$$<$size$jscomp$31_x$jscomp$397$$){var $x_26495$$=function(){var $G__23324$$=$APP.$cljs$core$_nth$$($c$jscomp$105$$,$i_26494$$);return $f$jscomp$197$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$197$$.$cljs$core$IFn$_invoke$arity$1$($G__23324$$):$f$jscomp$197$$($G__23324$$)}();$x_26495$$!=null&&$b$jscomp$129$$.add($x_26495$$);$i_26494$$+=1}else break;return $APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b$jscomp$129$$),
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$197$$,$APP.$cljs$core$_chunked_rest$$($temp__5825__auto__$jscomp$2$$)))}$size$jscomp$31_x$jscomp$397$$=function(){var $G__23325$$=$APP.$cljs$core$first$$($temp__5825__auto__$jscomp$2$$);return $f$jscomp$197$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$197$$.$cljs$core$IFn$_invoke$arity$1$($G__23325$$):$f$jscomp$197$$($G__23325$$)}();return $size$jscomp$31_x$jscomp$397$$==null?$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$197$$,
$APP.$cljs$core$rest$$($temp__5825__auto__$jscomp$2$$)):$APP.$cljs$core$cons$$($size$jscomp$31_x$jscomp$397$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$197$$,$APP.$cljs$core$rest$$($temp__5825__auto__$jscomp$2$$)))}return null},null,null)};$cljs$core$Atom$$=function($state$jscomp$2$$){this.state=$state$jscomp$2$$;this.$watches$=this.validator=this.$meta$=null;this.$cljs$lang$protocol_mask$partition1$$=16386;this.$cljs$lang$protocol_mask$partition0$$=6455296};
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$=function($x$jscomp$398$$){return new $cljs$core$Atom$$($x$jscomp$398$$)};
$APP.$cljs$core$reset_BANG_$$=function($a$jscomp$145$$,$new_value$jscomp$4$$){if($a$jscomp$145$$ instanceof $cljs$core$Atom$$){var $old_value_validate$$=$a$jscomp$145$$.validator;if($old_value_validate$$!=null&&!$APP.$cljs$core$truth_$$($old_value_validate$$.$cljs$core$IFn$_invoke$arity$1$?$old_value_validate$$.$cljs$core$IFn$_invoke$arity$1$($new_value$jscomp$4$$):$old_value_validate$$($new_value$jscomp$4$$)))throw Error("Validator rejected reference state");$old_value_validate$$=$a$jscomp$145$$.state;
$a$jscomp$145$$.state=$new_value$jscomp$4$$;$a$jscomp$145$$.$watches$!=null&&$a$jscomp$145$$.$cljs$core$IWatchable$_notify_watches$arity$3$(null,$old_value_validate$$,$new_value$jscomp$4$$);return $new_value$jscomp$4$$}return $cljs$core$_reset_BANG_$$($a$jscomp$145$$,$new_value$jscomp$4$$)};
$APP.$cljs$core$compare_and_set_BANG_$$=function($a$jscomp$155$$,$oldval$jscomp$3$$,$newval$jscomp$3$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$155$$.$cljs$core$IDeref$_deref$arity$1$(null),$oldval$jscomp$3$$)?($APP.$cljs$core$reset_BANG_$$($a$jscomp$155$$,$newval$jscomp$3$$),!0):!1};$cljs$core$Volatile$$=function($state$jscomp$4$$){this.state=$state$jscomp$4$$;this.$cljs$lang$protocol_mask$partition0$$=32768;this.$cljs$lang$protocol_mask$partition1$$=0};
$APP.$cljs$core$volatile_BANG_$$=function($val$jscomp$72$$){return new $cljs$core$Volatile$$($val$jscomp$72$$)};$APP.$cljs$core$vreset_BANG_$$=function($vol$$,$newval$jscomp$4$$){return $APP.$cljs$core$_vreset_BANG_$$($vol$$,$newval$jscomp$4$$)};
$cljs$core$keep_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$=function($f$jscomp$208$$){return function($rf$jscomp$2$$){var $ia$$=$APP.$cljs$core$volatile_BANG_$$(-1);return function(){function $G__26690__2$$($result$jscomp$29$$,$input$jscomp$15_v$jscomp$15$$){var $i$jscomp$198$$=$ia$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$ia$$.$cljs$core$IDeref$_deref$arity$1$(null)+1);$input$jscomp$15_v$jscomp$15$$=$f$jscomp$208$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$208$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$198$$,
$input$jscomp$15_v$jscomp$15$$):$f$jscomp$208$$($i$jscomp$198$$,$input$jscomp$15_v$jscomp$15$$);return $input$jscomp$15_v$jscomp$15$$==null?$result$jscomp$29$$:$rf$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$29$$,$input$jscomp$15_v$jscomp$15$$):$rf$jscomp$2$$($result$jscomp$29$$,$input$jscomp$15_v$jscomp$15$$)}function $G__26690__1$$($result$jscomp$28$$){return $rf$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$28$$):
$rf$jscomp$2$$($result$jscomp$28$$)}function $G__26690__0$$(){return $rf$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$rf$jscomp$2$$()}var $G__26690$$=null;$G__26690$$=function($result$jscomp$30$$,$input$jscomp$16$$){switch(arguments.length){case 0:return $G__26690__0$$.call(this);case 1:return $G__26690__1$$.call(this,$result$jscomp$30$$);case 2:return $G__26690__2$$.call(this,$result$jscomp$30$$,$input$jscomp$16$$)}throw Error("Invalid arity: "+arguments.length);
};$G__26690$$.$cljs$core$IFn$_invoke$arity$0$=$G__26690__0$$;$G__26690$$.$cljs$core$IFn$_invoke$arity$1$=$G__26690__1$$;$G__26690$$.$cljs$core$IFn$_invoke$arity$2$=$G__26690__2$$;return $G__26690$$}()}};
$cljs$core$every_pred$cljs$0core$0IFn$0_invoke$0arity$02$$=function($p1$jscomp$1$$,$p2$jscomp$1$$){return function(){function $cljs$core$ep2__3$$($x$jscomp$417$$,$y$jscomp$192$$,$z$jscomp$49$$){return $APP.$cljs$core$boolean$0$$(function(){var $and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$=$p1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$p1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$417$$):$p1$jscomp$1$$($x$jscomp$417$$);
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$)?($and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$=$p1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$p1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$192$$):$p1$jscomp$1$$($y$jscomp$192$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$)?
($and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$=$p1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$p1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($z$jscomp$49$$):$p1$jscomp$1$$($z$jscomp$49$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$)?($and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$=
$p2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$p2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$417$$):$p2$jscomp$1$$($x$jscomp$417$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$)?($and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$=$p2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$p2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$192$$):
$p2$jscomp$1$$($y$jscomp$192$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$)?$p2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$p2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($z$jscomp$49$$):$p2$jscomp$1$$($z$jscomp$49$$):$and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$):$and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$):
$and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$):$and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$):$and__5023__auto__$jscomp$14_and__5023__auto____$1$jscomp$5_and__5023__auto____$2$jscomp$1_and__5023__auto____$3_and__5023__auto____$4$$}())}function $cljs$core$ep2__2$$($x$jscomp$416$$,$y$jscomp$191$$){return $APP.$cljs$core$boolean$0$$(function(){var $and__5023__auto__$jscomp$13_and__5023__auto____$1$jscomp$4_and__5023__auto____$2$$=
$p1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$p1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$416$$):$p1$jscomp$1$$($x$jscomp$416$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$13_and__5023__auto____$1$jscomp$4_and__5023__auto____$2$$)?($and__5023__auto__$jscomp$13_and__5023__auto____$1$jscomp$4_and__5023__auto____$2$$=$p1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$p1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$191$$):$p1$jscomp$1$$($y$jscomp$191$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$13_and__5023__auto____$1$jscomp$4_and__5023__auto____$2$$)?
($and__5023__auto__$jscomp$13_and__5023__auto____$1$jscomp$4_and__5023__auto____$2$$=$p2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$p2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$416$$):$p2$jscomp$1$$($x$jscomp$416$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$13_and__5023__auto____$1$jscomp$4_and__5023__auto____$2$$)?$p2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$p2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$191$$):$p2$jscomp$1$$($y$jscomp$191$$):$and__5023__auto__$jscomp$13_and__5023__auto____$1$jscomp$4_and__5023__auto____$2$$):
$and__5023__auto__$jscomp$13_and__5023__auto____$1$jscomp$4_and__5023__auto____$2$$):$and__5023__auto__$jscomp$13_and__5023__auto____$1$jscomp$4_and__5023__auto____$2$$}())}function $cljs$core$ep2__1$$($JSCompiler_inline_result$jscomp$164_x$jscomp$415$$){var $and__5023__auto__$jscomp$inline_2696$$=$p1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$p1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$164_x$jscomp$415$$):$p1$jscomp$1$$($JSCompiler_inline_result$jscomp$164_x$jscomp$415$$);
$JSCompiler_inline_result$jscomp$164_x$jscomp$415$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_2696$$)?$p2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$p2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$164_x$jscomp$415$$):$p2$jscomp$1$$($JSCompiler_inline_result$jscomp$164_x$jscomp$415$$):$and__5023__auto__$jscomp$inline_2696$$;return $APP.$cljs$core$boolean$0$$($JSCompiler_inline_result$jscomp$164_x$jscomp$415$$)}var $cljs$core$ep2$$=null,$cljs$core$ep2__4$$=
function(){function $G__26797$$($x$jscomp$419$$,$y$jscomp$194$$,$z$jscomp$51$$,$var_args$jscomp$197$$){var $G__26827__i_args$jscomp$62$$=null;if(arguments.length>3){$G__26827__i_args$jscomp$62$$=0;for(var $G__26827__a$$=Array(arguments.length-3);$G__26827__i_args$jscomp$62$$<$G__26827__a$$.length;)$G__26827__a$$[$G__26827__i_args$jscomp$62$$]=arguments[$G__26827__i_args$jscomp$62$$+3],++$G__26827__i_args$jscomp$62$$;$G__26827__i_args$jscomp$62$$=new $APP.$cljs$core$IndexedSeq$$($G__26827__a$$,0,null)}return $G__26797__delegate$$.call(this,
$x$jscomp$419$$,$y$jscomp$194$$,$z$jscomp$51$$,$G__26827__i_args$jscomp$62$$)}function $G__26797__delegate$$($x$jscomp$418$$,$y$jscomp$193$$,$z$jscomp$50$$,$args$jscomp$61$$){return $APP.$cljs$core$boolean$0$$(function(){var $and__5023__auto__$jscomp$15$$=$cljs$core$ep2$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$418$$,$y$jscomp$193$$,$z$jscomp$50$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$15$$)?$APP.$cljs$core$every_QMARK_$$(function($p1__23385_SHARP_$$){var $and__5023__auto____$1$jscomp$6$$=
$p1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$p1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($p1__23385_SHARP_$$):$p1$jscomp$1$$($p1__23385_SHARP_$$);return $APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$6$$)?$p2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$p2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($p1__23385_SHARP_$$):$p2$jscomp$1$$($p1__23385_SHARP_$$):$and__5023__auto____$1$jscomp$6$$},$args$jscomp$61$$):$and__5023__auto__$jscomp$15$$}())}$G__26797$$.$cljs$lang$maxFixedArity$=3;$G__26797$$.$cljs$lang$applyTo$=
function($arglist__26828_args$jscomp$63$$){var $x$jscomp$420$$=$APP.$cljs$core$first$$($arglist__26828_args$jscomp$63$$);$arglist__26828_args$jscomp$63$$=$APP.$cljs$core$next$$($arglist__26828_args$jscomp$63$$);var $y$jscomp$195$$=$APP.$cljs$core$first$$($arglist__26828_args$jscomp$63$$);$arglist__26828_args$jscomp$63$$=$APP.$cljs$core$next$$($arglist__26828_args$jscomp$63$$);var $z$jscomp$52$$=$APP.$cljs$core$first$$($arglist__26828_args$jscomp$63$$);$arglist__26828_args$jscomp$63$$=$APP.$cljs$core$rest$$($arglist__26828_args$jscomp$63$$);
return $G__26797__delegate$$($x$jscomp$420$$,$y$jscomp$195$$,$z$jscomp$52$$,$arglist__26828_args$jscomp$63$$)};$G__26797$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26797__delegate$$;return $G__26797$$}();$cljs$core$ep2$$=function($x$jscomp$421$$,$y$jscomp$196$$,$z$jscomp$53$$,$var_args$jscomp$198$$){switch(arguments.length){case 0:return!0;case 1:return $cljs$core$ep2__1$$.call(this,$x$jscomp$421$$);case 2:return $cljs$core$ep2__2$$.call(this,$x$jscomp$421$$,$y$jscomp$196$$);case 3:return $cljs$core$ep2__3$$.call(this,
$x$jscomp$421$$,$y$jscomp$196$$,$z$jscomp$53$$);default:var $G__26829_G__26830__i$$=null;if(arguments.length>3){$G__26829_G__26830__i$$=0;for(var $G__26830__a$$=Array(arguments.length-3);$G__26829_G__26830__i$$<$G__26830__a$$.length;)$G__26830__a$$[$G__26829_G__26830__i$$]=arguments[$G__26829_G__26830__i$$+3],++$G__26829_G__26830__i$$;$G__26829_G__26830__i$$=new $APP.$cljs$core$IndexedSeq$$($G__26830__a$$,0,null)}return $cljs$core$ep2__4$$.$cljs$core$IFn$_invoke$arity$variadic$($x$jscomp$421$$,$y$jscomp$196$$,
$z$jscomp$53$$,$G__26829_G__26830__i$$)}throw Error("Invalid arity: "+arguments.length);};$cljs$core$ep2$$.$cljs$lang$maxFixedArity$=3;$cljs$core$ep2$$.$cljs$lang$applyTo$=$cljs$core$ep2__4$$.$cljs$lang$applyTo$;$cljs$core$ep2$$.$cljs$core$IFn$_invoke$arity$0$=function(){return!0};$cljs$core$ep2$$.$cljs$core$IFn$_invoke$arity$1$=$cljs$core$ep2__1$$;$cljs$core$ep2$$.$cljs$core$IFn$_invoke$arity$2$=$cljs$core$ep2__2$$;$cljs$core$ep2$$.$cljs$core$IFn$_invoke$arity$3$=$cljs$core$ep2__3$$;$cljs$core$ep2$$.$cljs$core$IFn$_invoke$arity$variadic$=
$cljs$core$ep2__4$$.$cljs$core$IFn$_invoke$arity$variadic$;return $cljs$core$ep2$$}()};
$cljs$core$some_fn$cljs$0core$0IFn$0_invoke$0arity$02$$=function($p1$jscomp$4$$,$p2$jscomp$4$$){return function(){function $cljs$core$sp2__3$$($or__5025__auto____$3_x$jscomp$445$$,$or__5025__auto____$4_y$jscomp$216$$,$z$jscomp$69$$){var $or__5025__auto__$jscomp$16_or__5025__auto____$1$jscomp$3_or__5025__auto____$2$jscomp$1$$=$p1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$p1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$3_x$jscomp$445$$):$p1$jscomp$4$$($or__5025__auto____$3_x$jscomp$445$$);
if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$16_or__5025__auto____$1$jscomp$3_or__5025__auto____$2$jscomp$1$$))return $or__5025__auto__$jscomp$16_or__5025__auto____$1$jscomp$3_or__5025__auto____$2$jscomp$1$$;$or__5025__auto__$jscomp$16_or__5025__auto____$1$jscomp$3_or__5025__auto____$2$jscomp$1$$=$p1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$p1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$4_y$jscomp$216$$):$p1$jscomp$4$$($or__5025__auto____$4_y$jscomp$216$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$16_or__5025__auto____$1$jscomp$3_or__5025__auto____$2$jscomp$1$$))return $or__5025__auto__$jscomp$16_or__5025__auto____$1$jscomp$3_or__5025__auto____$2$jscomp$1$$;
$or__5025__auto__$jscomp$16_or__5025__auto____$1$jscomp$3_or__5025__auto____$2$jscomp$1$$=$p1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$p1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($z$jscomp$69$$):$p1$jscomp$4$$($z$jscomp$69$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$16_or__5025__auto____$1$jscomp$3_or__5025__auto____$2$jscomp$1$$))return $or__5025__auto__$jscomp$16_or__5025__auto____$1$jscomp$3_or__5025__auto____$2$jscomp$1$$;$or__5025__auto____$3_x$jscomp$445$$=$p2$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?
$p2$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$3_x$jscomp$445$$):$p2$jscomp$4$$($or__5025__auto____$3_x$jscomp$445$$);if($APP.$cljs$core$truth_$$($or__5025__auto____$3_x$jscomp$445$$))return $or__5025__auto____$3_x$jscomp$445$$;$or__5025__auto____$4_y$jscomp$216$$=$p2$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$p2$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$4_y$jscomp$216$$):$p2$jscomp$4$$($or__5025__auto____$4_y$jscomp$216$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$4_y$jscomp$216$$)?
$or__5025__auto____$4_y$jscomp$216$$:$p2$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$p2$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($z$jscomp$69$$):$p2$jscomp$4$$($z$jscomp$69$$)}function $cljs$core$sp2__2$$($or__5025__auto____$2_x$jscomp$444$$,$y$jscomp$215$$){var $or__5025__auto__$jscomp$15_or__5025__auto____$1$jscomp$2$$=$p1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$p1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$2_x$jscomp$444$$):$p1$jscomp$4$$($or__5025__auto____$2_x$jscomp$444$$);
if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$15_or__5025__auto____$1$jscomp$2$$))return $or__5025__auto__$jscomp$15_or__5025__auto____$1$jscomp$2$$;$or__5025__auto__$jscomp$15_or__5025__auto____$1$jscomp$2$$=$p1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$p1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$215$$):$p1$jscomp$4$$($y$jscomp$215$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$15_or__5025__auto____$1$jscomp$2$$))return $or__5025__auto__$jscomp$15_or__5025__auto____$1$jscomp$2$$;
$or__5025__auto____$2_x$jscomp$444$$=$p2$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$p2$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$2_x$jscomp$444$$):$p2$jscomp$4$$($or__5025__auto____$2_x$jscomp$444$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$2_x$jscomp$444$$)?$or__5025__auto____$2_x$jscomp$444$$:$p2$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$p2$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$215$$):$p2$jscomp$4$$($y$jscomp$215$$)}function $cljs$core$sp2__1$$($x$jscomp$443$$){var $or__5025__auto__$jscomp$14$$=
$p1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$p1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$443$$):$p1$jscomp$4$$($x$jscomp$443$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$14$$)?$or__5025__auto__$jscomp$14$$:$p2$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$p2$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$443$$):$p2$jscomp$4$$($x$jscomp$443$$)}var $cljs$core$sp2$$=null,$cljs$core$sp2__4$$=function(){function $G__26918$$($x$jscomp$447$$,$y$jscomp$218$$,$z$jscomp$71$$,
$var_args$jscomp$206$$){var $G__26924__i_args$jscomp$78$$=null;if(arguments.length>3){$G__26924__i_args$jscomp$78$$=0;for(var $G__26924__a$$=Array(arguments.length-3);$G__26924__i_args$jscomp$78$$<$G__26924__a$$.length;)$G__26924__a$$[$G__26924__i_args$jscomp$78$$]=arguments[$G__26924__i_args$jscomp$78$$+3],++$G__26924__i_args$jscomp$78$$;$G__26924__i_args$jscomp$78$$=new $APP.$cljs$core$IndexedSeq$$($G__26924__a$$,0,null)}return $G__26918__delegate$$.call(this,$x$jscomp$447$$,$y$jscomp$218$$,$z$jscomp$71$$,
$G__26924__i_args$jscomp$78$$)}function $G__26918__delegate$$($or__5025__auto__$jscomp$17_x$jscomp$446$$,$y$jscomp$217$$,$z$jscomp$70$$,$args$jscomp$77$$){$or__5025__auto__$jscomp$17_x$jscomp$446$$=$cljs$core$sp2$$.$cljs$core$IFn$_invoke$arity$3$($or__5025__auto__$jscomp$17_x$jscomp$446$$,$y$jscomp$217$$,$z$jscomp$70$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$17_x$jscomp$446$$)?$or__5025__auto__$jscomp$17_x$jscomp$446$$:$APP.$cljs$core$some$$(function($p1__23397_SHARP_$$){var $or__5025__auto____$1$jscomp$4$$=
$p1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$p1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($p1__23397_SHARP_$$):$p1$jscomp$4$$($p1__23397_SHARP_$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$4$$)?$or__5025__auto____$1$jscomp$4$$:$p2$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$p2$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($p1__23397_SHARP_$$):$p2$jscomp$4$$($p1__23397_SHARP_$$)},$args$jscomp$77$$)}$G__26918$$.$cljs$lang$maxFixedArity$=3;$G__26918$$.$cljs$lang$applyTo$=function($arglist__26925_args$jscomp$79$$){var $x$jscomp$448$$=
$APP.$cljs$core$first$$($arglist__26925_args$jscomp$79$$);$arglist__26925_args$jscomp$79$$=$APP.$cljs$core$next$$($arglist__26925_args$jscomp$79$$);var $y$jscomp$219$$=$APP.$cljs$core$first$$($arglist__26925_args$jscomp$79$$);$arglist__26925_args$jscomp$79$$=$APP.$cljs$core$next$$($arglist__26925_args$jscomp$79$$);var $z$jscomp$72$$=$APP.$cljs$core$first$$($arglist__26925_args$jscomp$79$$);$arglist__26925_args$jscomp$79$$=$APP.$cljs$core$rest$$($arglist__26925_args$jscomp$79$$);return $G__26918__delegate$$($x$jscomp$448$$,
$y$jscomp$219$$,$z$jscomp$72$$,$arglist__26925_args$jscomp$79$$)};$G__26918$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26918__delegate$$;return $G__26918$$}();$cljs$core$sp2$$=function($x$jscomp$449$$,$y$jscomp$220$$,$z$jscomp$73$$,$var_args$jscomp$207$$){switch(arguments.length){case 0:return null;case 1:return $cljs$core$sp2__1$$.call(this,$x$jscomp$449$$);case 2:return $cljs$core$sp2__2$$.call(this,$x$jscomp$449$$,$y$jscomp$220$$);case 3:return $cljs$core$sp2__3$$.call(this,$x$jscomp$449$$,$y$jscomp$220$$,
$z$jscomp$73$$);default:var $G__26926_G__26927__i$$=null;if(arguments.length>3){$G__26926_G__26927__i$$=0;for(var $G__26927__a$$=Array(arguments.length-3);$G__26926_G__26927__i$$<$G__26927__a$$.length;)$G__26927__a$$[$G__26926_G__26927__i$$]=arguments[$G__26926_G__26927__i$$+3],++$G__26926_G__26927__i$$;$G__26926_G__26927__i$$=new $APP.$cljs$core$IndexedSeq$$($G__26927__a$$,0,null)}return $cljs$core$sp2__4$$.$cljs$core$IFn$_invoke$arity$variadic$($x$jscomp$449$$,$y$jscomp$220$$,$z$jscomp$73$$,$G__26926_G__26927__i$$)}throw Error("Invalid arity: "+
arguments.length);};$cljs$core$sp2$$.$cljs$lang$maxFixedArity$=3;$cljs$core$sp2$$.$cljs$lang$applyTo$=$cljs$core$sp2__4$$.$cljs$lang$applyTo$;$cljs$core$sp2$$.$cljs$core$IFn$_invoke$arity$0$=function(){return null};$cljs$core$sp2$$.$cljs$core$IFn$_invoke$arity$1$=$cljs$core$sp2__1$$;$cljs$core$sp2$$.$cljs$core$IFn$_invoke$arity$2$=$cljs$core$sp2__2$$;$cljs$core$sp2$$.$cljs$core$IFn$_invoke$arity$3$=$cljs$core$sp2__3$$;$cljs$core$sp2$$.$cljs$core$IFn$_invoke$arity$variadic$=$cljs$core$sp2__4$$.$cljs$core$IFn$_invoke$arity$variadic$;
return $cljs$core$sp2$$}()};
$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$=function($n$jscomp$92$$,$coll$jscomp$283$$){if($coll$jscomp$283$$!=null&&($coll$jscomp$283$$.$cljs$lang$protocol_mask$partition1$$&262144||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$283$$.$cljs$core$IDrop$$)){var $or__5025__auto__$jscomp$25$$=$n$jscomp$92$$>0?$coll$jscomp$283$$.$cljs$core$IDrop$_drop$arity$2$(null,Math.ceil($n$jscomp$92$$)):$APP.$cljs$core$seq$$($coll$jscomp$283$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$25$$)?$or__5025__auto__$jscomp$25$$:
$APP.$cljs$core$List$EMPTY$$}return new $APP.$cljs$core$LazySeq$$(null,function(){a:{var $G__27068$jscomp$inline_2708_JSCompiler_inline_result$jscomp$169_n__$1$jscomp$inline_2705$$=$n$jscomp$92$$;for(var $G__27069$jscomp$inline_2709_coll__$1$jscomp$inline_2706_s$jscomp$inline_2707$$=$coll$jscomp$283$$;;)if($G__27069$jscomp$inline_2709_coll__$1$jscomp$inline_2706_s$jscomp$inline_2707$$=$APP.$cljs$core$seq$$($G__27069$jscomp$inline_2709_coll__$1$jscomp$inline_2706_s$jscomp$inline_2707$$),$G__27068$jscomp$inline_2708_JSCompiler_inline_result$jscomp$169_n__$1$jscomp$inline_2705$$>
0&&$G__27069$jscomp$inline_2709_coll__$1$jscomp$inline_2706_s$jscomp$inline_2707$$)--$G__27068$jscomp$inline_2708_JSCompiler_inline_result$jscomp$169_n__$1$jscomp$inline_2705$$,$G__27069$jscomp$inline_2709_coll__$1$jscomp$inline_2706_s$jscomp$inline_2707$$=$APP.$cljs$core$rest$$($G__27069$jscomp$inline_2709_coll__$1$jscomp$inline_2706_s$jscomp$inline_2707$$);else{$G__27068$jscomp$inline_2708_JSCompiler_inline_result$jscomp$169_n__$1$jscomp$inline_2705$$=$G__27069$jscomp$inline_2709_coll__$1$jscomp$inline_2706_s$jscomp$inline_2707$$;
break a}$G__27068$jscomp$inline_2708_JSCompiler_inline_result$jscomp$169_n__$1$jscomp$inline_2705$$=void 0}return $G__27068$jscomp$inline_2708_JSCompiler_inline_result$jscomp$169_n__$1$jscomp$inline_2705$$},null,null)};$APP.$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$01$$=function($s$jscomp$75$$){return $cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$02$$(1,$s$jscomp$75$$)};
$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$02$$=function($n$jscomp$93$$,$s$jscomp$76$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(function($x$jscomp$464$$){return $x$jscomp$464$$},$s$jscomp$76$$,$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($n$jscomp$93$$,$s$jscomp$76$$))};
$APP.$cljs$core$drop_while$cljs$0core$0IFn$0_invoke$0arity$02$$=function($pred$jscomp$5$$,$coll$jscomp$285$$){return new $APP.$cljs$core$LazySeq$$(null,function(){a:{var $G__27107$jscomp$inline_11197_JSCompiler_inline_result$jscomp$10646_pred__$1$jscomp$inline_11191$$=$pred$jscomp$5$$;for(var $G__27108$jscomp$inline_11198_coll__$1$jscomp$inline_11192_s$jscomp$inline_11193$$=$coll$jscomp$285$$;;){$G__27108$jscomp$inline_11198_coll__$1$jscomp$inline_11192_s$jscomp$inline_11193$$=$APP.$cljs$core$seq$$($G__27108$jscomp$inline_11198_coll__$1$jscomp$inline_11192_s$jscomp$inline_11193$$);
var $G__23437$jscomp$inline_11196_JSCompiler_inline_result$jscomp$inline_11194_and__5023__auto__$jscomp$inline_11195$$;if($G__23437$jscomp$inline_11196_JSCompiler_inline_result$jscomp$inline_11194_and__5023__auto__$jscomp$inline_11195$$=$G__27108$jscomp$inline_11198_coll__$1$jscomp$inline_11192_s$jscomp$inline_11193$$)$G__23437$jscomp$inline_11196_JSCompiler_inline_result$jscomp$inline_11194_and__5023__auto__$jscomp$inline_11195$$=$APP.$cljs$core$first$$($G__27108$jscomp$inline_11198_coll__$1$jscomp$inline_11192_s$jscomp$inline_11193$$),
$G__23437$jscomp$inline_11196_JSCompiler_inline_result$jscomp$inline_11194_and__5023__auto__$jscomp$inline_11195$$=$G__27107$jscomp$inline_11197_JSCompiler_inline_result$jscomp$10646_pred__$1$jscomp$inline_11191$$.$cljs$core$IFn$_invoke$arity$1$?$G__27107$jscomp$inline_11197_JSCompiler_inline_result$jscomp$10646_pred__$1$jscomp$inline_11191$$.$cljs$core$IFn$_invoke$arity$1$($G__23437$jscomp$inline_11196_JSCompiler_inline_result$jscomp$inline_11194_and__5023__auto__$jscomp$inline_11195$$):$G__27107$jscomp$inline_11197_JSCompiler_inline_result$jscomp$10646_pred__$1$jscomp$inline_11191$$($G__23437$jscomp$inline_11196_JSCompiler_inline_result$jscomp$inline_11194_and__5023__auto__$jscomp$inline_11195$$);
if($APP.$cljs$core$truth_$$($G__23437$jscomp$inline_11196_JSCompiler_inline_result$jscomp$inline_11194_and__5023__auto__$jscomp$inline_11195$$))$G__27108$jscomp$inline_11198_coll__$1$jscomp$inline_11192_s$jscomp$inline_11193$$=$APP.$cljs$core$rest$$($G__27108$jscomp$inline_11198_coll__$1$jscomp$inline_11192_s$jscomp$inline_11193$$);else{$G__27107$jscomp$inline_11197_JSCompiler_inline_result$jscomp$10646_pred__$1$jscomp$inline_11191$$=$G__27108$jscomp$inline_11198_coll__$1$jscomp$inline_11192_s$jscomp$inline_11193$$;
break a}}$G__27107$jscomp$inline_11197_JSCompiler_inline_result$jscomp$10646_pred__$1$jscomp$inline_11191$$=void 0}return $G__27107$jscomp$inline_11197_JSCompiler_inline_result$jscomp$10646_pred__$1$jscomp$inline_11191$$},null,null)};
$cljs$core$split_at$$=function($n$jscomp$95$$,$coll$jscomp$300$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($n$jscomp$95$$,$coll$jscomp$300$$),$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($n$jscomp$95$$,$coll$jscomp$300$$)],null)};
$cljs$core$Repeat$$=function($meta$jscomp$24$$,$count$jscomp$44$$,$val$jscomp$73$$,$next$jscomp$1$$,$__hash$jscomp$8$$){this.$meta$=$meta$jscomp$24$$;this.count=$count$jscomp$44$$;this.$val$=$val$jscomp$73$$;this.next=$next$jscomp$1$$;this.$__hash$=$__hash$jscomp$8$$;this.$cljs$lang$protocol_mask$partition0$$=32374988;this.$cljs$lang$protocol_mask$partition1$$=262145};
$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$=function($x$jscomp$471$$){return new $cljs$core$Repeat$$(null,-1,$x$jscomp$471$$,null,null)};$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$=function($n$jscomp$97$$,$x$jscomp$472$$){return $n$jscomp$97$$>0?new $cljs$core$Repeat$$(null,$n$jscomp$97$$,$x$jscomp$472$$,null,null):$APP.$cljs$core$List$EMPTY$$};
$cljs$core$repeatedly$cljs$0core$0IFn$0_invoke$0arity$01$$=function($f$jscomp$219$$){return new $APP.$cljs$core$LazySeq$$(null,function(){return $APP.$cljs$core$cons$$($f$jscomp$219$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$219$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$219$$(),$cljs$core$repeatedly$cljs$0core$0IFn$0_invoke$0arity$01$$($f$jscomp$219$$))},null,null)};
$cljs$core$repeatedly$cljs$0core$0IFn$0_invoke$0arity$02$$=function($n$jscomp$99$$,$f$jscomp$220$$){return $APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($n$jscomp$99$$,$cljs$core$repeatedly$cljs$0core$0IFn$0_invoke$0arity$01$$($f$jscomp$220$$))};
$cljs$core$Iterate$$=function($meta$jscomp$26$$,$f$jscomp$221$$,$prev_seed$$,$seed$jscomp$1$$,$next$jscomp$3$$){this.$meta$=$meta$jscomp$26$$;this.f=$f$jscomp$221$$;this.$prev_seed$=$prev_seed$$;this.seed=$seed$jscomp$1$$;this.next=$next$jscomp$3$$;this.$cljs$lang$protocol_mask$partition0$$=26083532;this.$cljs$lang$protocol_mask$partition1$$=1};$cljs$core$iterate$$=function($f$jscomp$223$$,$x$jscomp$474$$){return new $cljs$core$Iterate$$(null,$f$jscomp$223$$,null,$x$jscomp$474$$,null)};
$APP.$cljs$core$interpose$cljs$0core$0IFn$0_invoke$0arity$02$$=function($sep$jscomp$1$$,$coll$jscomp$332$$){return $APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$(1,$APP.$cljs$core$interleave$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$($sep$jscomp$1$$),$coll$jscomp$332$$))};
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$=function($f$jscomp$224$$){return $APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($f$jscomp$224$$),$cljs$core$cat$$)};
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($f$jscomp$225$$,$colls$jscomp$4$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$map$$,$f$jscomp$225$$,$colls$jscomp$4$$))};
$APP.$cljs$core$tree_seq$$=function($branch_QMARK_$$,$children$jscomp$2$$,$root$jscomp$4$$){return function $cljs$core$tree_seq_$_walk$$($node$jscomp$6$$){return new $APP.$cljs$core$LazySeq$$(null,function(){return $APP.$cljs$core$cons$$($node$jscomp$6$$,$APP.$cljs$core$truth_$$($branch_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$branch_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$6$$):$branch_QMARK_$$($node$jscomp$6$$))?$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cljs$core$tree_seq_$_walk$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$children$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$children$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$6$$):$children$jscomp$2$$($node$jscomp$6$$)])):null)},null,null)}($root$jscomp$4$$)};
$APP.$cljs$core$flatten$$=function($x$jscomp$475$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__23464_SHARP_$$){return!$APP.$cljs$core$sequential_QMARK_$$($p1__23464_SHARP_$$)},$APP.$cljs$core$rest$$($APP.$cljs$core$tree_seq$$($APP.$cljs$core$sequential_QMARK_$$,$APP.$cljs$core$seq$$,$x$jscomp$475$$)))};
$APP.$cljs$core$filterv$$=function($pred$jscomp$10$$,$coll$jscomp$340$$){return $APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($v$jscomp$21$$,$o$jscomp$99$$){return $APP.$cljs$core$truth_$$($pred$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$($o$jscomp$99$$):$pred$jscomp$10$$($o$jscomp$99$$))?$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$21$$,$o$jscomp$99$$):$v$jscomp$21$$},
$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$coll$jscomp$340$$))};$APP.$cljs$core$partition$cljs$0core$0IFn$0_invoke$0arity$02$$=function($coll$jscomp$341$$){return $cljs$core$partition$cljs$0core$0IFn$0_invoke$0arity$03$$(2,2,$coll$jscomp$341$$)};
$cljs$core$partition$cljs$0core$0IFn$0_invoke$0arity$03$$=function($n$jscomp$101$$,$step$jscomp$4$$,$coll$jscomp$342$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $temp__5825__auto__$jscomp$8$$=$APP.$cljs$core$seq$$($coll$jscomp$342$$);if($temp__5825__auto__$jscomp$8$$){var $p$jscomp$29$$=$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($n$jscomp$101$$,$temp__5825__auto__$jscomp$8$$);return $n$jscomp$101$$===$APP.$cljs$core$count$$($p$jscomp$29$$)?$APP.$cljs$core$cons$$($p$jscomp$29$$,
$cljs$core$partition$cljs$0core$0IFn$0_invoke$0arity$03$$($n$jscomp$101$$,$step$jscomp$4$$,$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($step$jscomp$4$$,$temp__5825__auto__$jscomp$8$$))):null}return null},null,null)};$cljs$core$VectorNode$$=function($edit$$,$arr$jscomp$83$$){this.$edit$=$edit$$;this.$arr$=$arr$jscomp$83$$};
$cljs$core$pv_fresh_node$$=function($edit$jscomp$2$$){return new $cljs$core$VectorNode$$($edit$jscomp$2$$,[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null])};$cljs$core$pv_clone_node$$=function($node$jscomp$9$$){return new $cljs$core$VectorNode$$($node$jscomp$9$$.$edit$,$APP.$cljs$core$aclone$$($node$jscomp$9$$.$arr$))};
$cljs$core$tail_off$$=function($cnt$jscomp$5_pv$$){$cnt$jscomp$5_pv$$=$cnt$jscomp$5_pv$$.$cnt$;return $cnt$jscomp$5_pv$$<32?0:$cnt$jscomp$5_pv$$-1>>>5<<5};
$cljs$core$new_path$$=function($edit$jscomp$3$$,$level$jscomp$19_ll$$,$G__27472_node$jscomp$10_ret$jscomp$20$$){for(;;){if($level$jscomp$19_ll$$===0)return $G__27472_node$jscomp$10_ret$jscomp$20$$;var $r$jscomp$23$$=$cljs$core$pv_fresh_node$$($edit$jscomp$3$$);$r$jscomp$23$$.$arr$[0]=$G__27472_node$jscomp$10_ret$jscomp$20$$;$G__27472_node$jscomp$10_ret$jscomp$20$$=$r$jscomp$23$$;$level$jscomp$19_ll$$-=5}};
$cljs$core$vector_index_out_of_bounds$$=function($i$jscomp$201$$,$cnt$jscomp$6$$){throw Error(["No item ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($i$jscomp$201$$)," in vector of length ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cnt$jscomp$6$$)].join(""));};
$cljs$core$unchecked_array_for$$=function($level$jscomp$22_pv$jscomp$3$$,$i$jscomp$202$$){if($i$jscomp$202$$>=$cljs$core$tail_off$$($level$jscomp$22_pv$jscomp$3$$))return $level$jscomp$22_pv$jscomp$3$$.$tail$;var $node$jscomp$12$$=$level$jscomp$22_pv$jscomp$3$$.root;for($level$jscomp$22_pv$jscomp$3$$=$level$jscomp$22_pv$jscomp$3$$.shift;;)if($level$jscomp$22_pv$jscomp$3$$>0){var $G__27483$$=$level$jscomp$22_pv$jscomp$3$$-5;$node$jscomp$12$$=$node$jscomp$12$$.$arr$[$i$jscomp$202$$>>>$level$jscomp$22_pv$jscomp$3$$&
31];$level$jscomp$22_pv$jscomp$3$$=$G__27483$$}else return $node$jscomp$12$$.$arr$};$cljs$core$array_for$$=function($pv$jscomp$4$$,$i$jscomp$203$$){return 0<=$i$jscomp$203$$&&$i$jscomp$203$$<$pv$jscomp$4$$.$cnt$?$cljs$core$unchecked_array_for$$($pv$jscomp$4$$,$i$jscomp$203$$):$cljs$core$vector_index_out_of_bounds$$($i$jscomp$203$$,$pv$jscomp$4$$.$cnt$)};
$cljs$core$RangedIterator$$=function($i$jscomp$205$$,$base$jscomp$5$$,$arr$jscomp$85$$,$v$jscomp$23$$,$start$jscomp$65$$,$end$jscomp$18$$){this.i=$i$jscomp$205$$;this.$base$=$base$jscomp$5$$;this.$arr$=$arr$jscomp$85$$;this.v=$v$jscomp$23$$;this.start=$start$jscomp$65$$;this.end=$end$jscomp$18$$};
$cljs$core$ranged_iterator$$=function($v$jscomp$25$$,$start$jscomp$67$$,$end$jscomp$20$$){return new $cljs$core$RangedIterator$$($start$jscomp$67$$,$start$jscomp$67$$-$start$jscomp$67$$%32,$start$jscomp$67$$<$APP.$cljs$core$count$$($v$jscomp$25$$)?$cljs$core$unchecked_array_for$$($v$jscomp$25$$,$start$jscomp$67$$):null,$v$jscomp$25$$,$start$jscomp$67$$,$end$jscomp$20$$)};
$cljs$core$pv_reduce$cljs$0core$0IFn$0_invoke$0arity$04$$=function($pv$jscomp$7$$,$f$jscomp$241$$,$start$jscomp$68$$,$end$jscomp$21$$){return $start$jscomp$68$$<$end$jscomp$21$$?$cljs$core$pv_reduce$cljs$0core$0IFn$0_invoke$0arity$05$$($pv$jscomp$7$$,$f$jscomp$241$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($pv$jscomp$7$$,$start$jscomp$68$$),$start$jscomp$68$$+1,$end$jscomp$21$$):$f$jscomp$241$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$241$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$241$$()};
$cljs$core$pv_reduce$cljs$0core$0IFn$0_invoke$0arity$05$$=function($pv$jscomp$8$$,$f$jscomp$242$$,$G__27505_i$jscomp$208_init$jscomp$25$$,$G__27506_arr$jscomp$87_arr__$1_start$jscomp$69$$,$end$jscomp$22$$){var $G__23559$jscomp$inline_2742_acc$jscomp$6_nacc$jscomp$2$$=$G__27505_i$jscomp$208_init$jscomp$25$$;$G__27505_i$jscomp$208_init$jscomp$25$$=$G__27506_arr$jscomp$87_arr__$1_start$jscomp$69$$;for($G__27506_arr$jscomp$87_arr__$1_start$jscomp$69$$=$cljs$core$unchecked_array_for$$($pv$jscomp$8$$,$G__27506_arr$jscomp$87_arr__$1_start$jscomp$69$$);;)if($G__27505_i$jscomp$208_init$jscomp$25$$<
$end$jscomp$22$$){var $G__23560$jscomp$inline_2743_j$jscomp$61$$=$G__27505_i$jscomp$208_init$jscomp$25$$&31;$G__27506_arr$jscomp$87_arr__$1_start$jscomp$69$$=$G__23560$jscomp$inline_2743_j$jscomp$61$$===0?$cljs$core$unchecked_array_for$$($pv$jscomp$8$$,$G__27505_i$jscomp$208_init$jscomp$25$$):$G__27506_arr$jscomp$87_arr__$1_start$jscomp$69$$;$G__23560$jscomp$inline_2743_j$jscomp$61$$=$G__27506_arr$jscomp$87_arr__$1_start$jscomp$69$$[$G__23560$jscomp$inline_2743_j$jscomp$61$$];$G__23559$jscomp$inline_2742_acc$jscomp$6_nacc$jscomp$2$$=
$f$jscomp$242$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$242$$.$cljs$core$IFn$_invoke$arity$2$($G__23559$jscomp$inline_2742_acc$jscomp$6_nacc$jscomp$2$$,$G__23560$jscomp$inline_2743_j$jscomp$61$$):$f$jscomp$242$$($G__23559$jscomp$inline_2742_acc$jscomp$6_nacc$jscomp$2$$,$G__23560$jscomp$inline_2743_j$jscomp$61$$);if($cljs$core$reduced_QMARK_$$($G__23559$jscomp$inline_2742_acc$jscomp$6_nacc$jscomp$2$$))return $APP.$cljs$core$_deref$$($G__23559$jscomp$inline_2742_acc$jscomp$6_nacc$jscomp$2$$);$G__27505_i$jscomp$208_init$jscomp$25$$+=
1}else return $G__23559$jscomp$inline_2742_acc$jscomp$6_nacc$jscomp$2$$};$APP.$cljs$core$PersistentVector$$=function($meta$jscomp$28$$,$cnt$jscomp$7$$,$shift$$,$root$jscomp$5$$,$tail$$,$__hash$jscomp$10$$){this.$meta$=$meta$jscomp$28$$;this.$cnt$=$cnt$jscomp$7$$;this.shift=$shift$$;this.root=$root$jscomp$5$$;this.$tail$=$tail$$;this.$__hash$=$__hash$jscomp$10$$;this.$cljs$lang$protocol_mask$partition0$$=167666463;this.$cljs$lang$protocol_mask$partition1$$=401412};
$APP.$cljs$core$PersistentVector$fromArray$$=function($xs$jscomp$13_xs__$1$jscomp$2$$,$i$jscomp$211_no_clone$$){var $l$jscomp$60$$=$xs$jscomp$13_xs__$1$jscomp$2$$.length;$xs$jscomp$13_xs__$1$jscomp$2$$=$i$jscomp$211_no_clone$$?$xs$jscomp$13_xs__$1$jscomp$2$$:$APP.$cljs$core$aclone$$($xs$jscomp$13_xs__$1$jscomp$2$$);if($l$jscomp$60$$<32)return new $APP.$cljs$core$PersistentVector$$(null,$l$jscomp$60$$,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$xs$jscomp$13_xs__$1$jscomp$2$$,null);$i$jscomp$211_no_clone$$=
32;for(var $G__27571_out$jscomp$5$$=(new $APP.$cljs$core$PersistentVector$$(null,32,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$xs$jscomp$13_xs__$1$jscomp$2$$.slice(0,32),null)).$cljs$core$IEditableCollection$_as_transient$arity$1$(null);;)if($i$jscomp$211_no_clone$$<$l$jscomp$60$$){var $G__27570$$=$i$jscomp$211_no_clone$$+1;$G__27571_out$jscomp$5$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__27571_out$jscomp$5$$,$xs$jscomp$13_xs__$1$jscomp$2$$[$i$jscomp$211_no_clone$$]);
$i$jscomp$211_no_clone$$=$G__27570$$}else return $APP.$cljs$core$_persistent_BANG_$$($G__27571_out$jscomp$5$$)};
$APP.$cljs$core$vec$$=function($coll$jscomp$371$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$map_entry_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$map_entry_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($coll$jscomp$371$$):$APP.$cljs$core$map_entry_QMARK_$$($coll$jscomp$371$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$key$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$key$$.$cljs$core$IFn$_invoke$arity$1$($coll$jscomp$371$$):
$APP.$cljs$core$_key$$($coll$jscomp$371$$),$APP.$cljs$core$val$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$val$$.$cljs$core$IFn$_invoke$arity$1$($coll$jscomp$371$$):$APP.$cljs$core$_val$$($coll$jscomp$371$$)],null):$APP.$cljs$core$vector_QMARK_$$($coll$jscomp$371$$)?$APP.$cljs$core$with_meta$$($coll$jscomp$371$$,null):$APP.$cljs$core$array_QMARK_$$($coll$jscomp$371$$)?$APP.$cljs$core$PersistentVector$fromArray$$($coll$jscomp$371$$,!0):$APP.$cljs$core$_persistent_BANG_$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($cljs$core$_conj_BANG_$$,
$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$coll$jscomp$371$$))};$APP.$cljs$core$ChunkedSeq$$=function($vec$$,$node$jscomp$16$$,$i$jscomp$212$$,$off$jscomp$4$$,$meta$jscomp$30$$,$__hash$jscomp$12$$){this.$vec$=$vec$$;this.node=$node$jscomp$16$$;this.i=$i$jscomp$212$$;this.$off$=$off$jscomp$4$$;this.$meta$=$meta$jscomp$30$$;this.$__hash$=$__hash$jscomp$12$$;this.$cljs$lang$protocol_mask$partition0$$=32375020;this.$cljs$lang$protocol_mask$partition1$$=263680};
$cljs$core$chunked_seq$$=function($var_args$jscomp$234$$){switch(arguments.length){case 3:var $vec$jscomp$inline_2772$$=arguments[0],$i$jscomp$inline_2773$$=arguments[1],$off$jscomp$inline_2774$$=arguments[2];return new $APP.$cljs$core$ChunkedSeq$$($vec$jscomp$inline_2772$$,$cljs$core$array_for$$($vec$jscomp$inline_2772$$,$i$jscomp$inline_2773$$),$i$jscomp$inline_2773$$,$off$jscomp$inline_2774$$,null,null);case 4:return $cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$(arguments[0],arguments[1],
arguments[2],arguments[3]);case 5:return $cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$05$$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$=function($vec$jscomp$3$$,$node$jscomp$18$$,$i$jscomp$215$$,$off$jscomp$7$$){return new $APP.$cljs$core$ChunkedSeq$$($vec$jscomp$3$$,$node$jscomp$18$$,$i$jscomp$215$$,$off$jscomp$7$$,null,null)};
$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$05$$=function($vec$jscomp$4$$,$node$jscomp$19$$,$i$jscomp$216$$,$off$jscomp$8$$,$meta$jscomp$32$$){return new $APP.$cljs$core$ChunkedSeq$$($vec$jscomp$4$$,$node$jscomp$19$$,$i$jscomp$216$$,$off$jscomp$8$$,$meta$jscomp$32$$,null)};
$APP.$cljs$core$Subvec$$=function($meta$jscomp$33$$,$v$jscomp$31$$,$start$jscomp$79$$,$end$jscomp$25$$,$__hash$jscomp$14$$){this.$meta$=$meta$jscomp$33$$;this.v=$v$jscomp$31$$;this.start=$start$jscomp$79$$;this.end=$end$jscomp$25$$;this.$__hash$=$__hash$jscomp$14$$;this.$cljs$lang$protocol_mask$partition0$$=167666463;this.$cljs$lang$protocol_mask$partition1$$=139264};
$cljs$core$build_subvec$$=function($meta$jscomp$35$$,$v$jscomp$33$$,$G__27637_start$jscomp$81$$,$G__27638_end$jscomp$27$$,$G__27639___hash$jscomp$16$$){for(;;)if($v$jscomp$33$$ instanceof $APP.$cljs$core$Subvec$$)$G__27637_start$jscomp$81$$=$v$jscomp$33$$.start+$G__27637_start$jscomp$81$$,$G__27638_end$jscomp$27$$=$v$jscomp$33$$.start+$G__27638_end$jscomp$27$$,$v$jscomp$33$$=$v$jscomp$33$$.v;else{if(!$APP.$cljs$core$vector_QMARK_$$($v$jscomp$33$$))throw Error("v must satisfy IVector");if($G__27637_start$jscomp$81$$<
0||$G__27638_end$jscomp$27$$<$G__27637_start$jscomp$81$$||$G__27638_end$jscomp$27$$>$APP.$cljs$core$count$$($v$jscomp$33$$))throw Error("Index out of bounds");return new $APP.$cljs$core$Subvec$$($meta$jscomp$35$$,$v$jscomp$33$$,$G__27637_start$jscomp$81$$,$G__27638_end$jscomp$27$$,$G__27639___hash$jscomp$16$$)}};
$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$=function($v$jscomp$34$$,$start$jscomp$82$$){return $APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$34$$,$start$jscomp$82$$,$APP.$cljs$core$count$$($v$jscomp$34$$))};$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$=function($v$jscomp$35$$,$start$jscomp$83$$,$end$jscomp$28$$){return $cljs$core$build_subvec$$(null,$v$jscomp$35$$,$start$jscomp$83$$|0,$end$jscomp$28$$|0,null)};
$cljs$core$tv_ensure_editable$$=function($edit$jscomp$4$$,$node$jscomp$20$$){return $edit$jscomp$4$$===$node$jscomp$20$$.$edit$?$node$jscomp$20$$:new $cljs$core$VectorNode$$($edit$jscomp$4$$,$APP.$cljs$core$aclone$$($node$jscomp$20$$.$arr$))};$cljs$core$tv_editable_root$$=function($node$jscomp$21$$){return new $cljs$core$VectorNode$$({},$APP.$cljs$core$aclone$$($node$jscomp$21$$.$arr$))};
$cljs$core$tv_editable_tail$$=function($tl$$){var $ret$jscomp$25$$=[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];$cljs$core$array_copy$$($tl$$,0,$ret$jscomp$25$$,0,$tl$$.length);return $ret$jscomp$25$$};
$cljs$core$TransientVector$$=function($cnt$jscomp$9$$,$shift$jscomp$2$$,$root$jscomp$8$$,$tail$jscomp$2$$){this.$cnt$=$cnt$jscomp$9$$;this.shift=$shift$jscomp$2$$;this.root=$root$jscomp$8$$;this.$tail$=$tail$jscomp$2$$;this.$cljs$lang$protocol_mask$partition1$$=88;this.$cljs$lang$protocol_mask$partition0$$=275};$cljs$core$PersistentQueueIter$$=function($fseq$$,$riter$$){this.$fseq$=$fseq$$;this.$riter$=$riter$$};
$cljs$core$PersistentQueueSeq$$=function($meta$jscomp$36$$,$front$$,$rear$$,$__hash$jscomp$17$$){this.$meta$=$meta$jscomp$36$$;this.$front$=$front$$;this.$rear$=$rear$$;this.$__hash$=$__hash$jscomp$17$$;this.$cljs$lang$protocol_mask$partition0$$=31850700;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$core$PersistentQueue$$=function($meta$jscomp$38$$,$count$jscomp$46$$,$front$jscomp$2$$,$rear$jscomp$2$$,$__hash$jscomp$19$$){this.$meta$=$meta$jscomp$38$$;this.count=$count$jscomp$46$$;this.$front$=$front$jscomp$2$$;this.$rear$=$rear$jscomp$2$$;this.$__hash$=$__hash$jscomp$19$$;this.$cljs$lang$protocol_mask$partition1$$=139264;this.$cljs$lang$protocol_mask$partition0$$=31858766};
$cljs$core$NeverEquiv$$=function(){this.$cljs$lang$protocol_mask$partition0$$=2097152;this.$cljs$lang$protocol_mask$partition1$$=0};
$APP.$cljs$core$equiv_map$$=function($x$jscomp$511$$,$y$jscomp$237$$){return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$map_QMARK_$$($y$jscomp$237$$)&&!$APP.$cljs$core$record_QMARK_$$($y$jscomp$237$$)?$APP.$cljs$core$count$$($x$jscomp$511$$)===$APP.$cljs$core$count$$($y$jscomp$237$$)?($x$jscomp$511$$!=null?$x$jscomp$511$$.$cljs$lang$protocol_mask$partition0$$&1048576||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$511$$.$cljs$core$IKVReduce$$||($x$jscomp$511$$.$cljs$lang$protocol_mask$partition0$$?
0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IKVReduce$$,$x$jscomp$511$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IKVReduce$$,$x$jscomp$511$$))?$APP.$cljs$core$reduce_kv$$(function($_$jscomp$111$$,$k$jscomp$99$$,$v$jscomp$36$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($y$jscomp$237$$,$k$jscomp$99$$,$cljs$core$never_equiv$$),$v$jscomp$36$$)?!0:$APP.$cljs$core$reduced$$(!1)},!0,$x$jscomp$511$$):$APP.$cljs$core$every_QMARK_$$(function($xkv$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($y$jscomp$237$$,
$APP.$cljs$core$first$$($xkv$$),$cljs$core$never_equiv$$),$APP.$cljs$core$second$$($xkv$$))},$x$jscomp$511$$):null:null)};$APP.$cljs$core$RecordIter$$=function($record$$,$base_count$$,$fields$$,$ext_map_iter$$){this.i=0;this.$record$=$record$$;this.$base_count$=$base_count$$;this.$fields$=$fields$$;this.$ext_map_iter$=$ext_map_iter$$};$cljs$core$ES6EntriesIterator$$=function($s$jscomp$86$$){this.s=$s$jscomp$86$$};$APP.$cljs$core$es6_entries_iterator$$=function($coll$jscomp$483$$){return new $cljs$core$ES6EntriesIterator$$($APP.$cljs$core$seq$$($coll$jscomp$483$$))};
$cljs$core$ES6SetEntriesIterator$$=function($s$jscomp$88$$){this.s=$s$jscomp$88$$};$cljs$core$es6_set_entries_iterator$$=function($coll$jscomp$484$$){return new $cljs$core$ES6SetEntriesIterator$$($APP.$cljs$core$seq$$($coll$jscomp$484$$))};
$cljs$core$array_index_of$$=function($JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$,$k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$){if($k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$ instanceof $APP.$cljs$core$Keyword$$)a:{var $i$jscomp$inline_2809_len$jscomp$inline_2792_len$jscomp$inline_2798_len$jscomp$inline_2803_len$jscomp$inline_2813$$=$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$.length;
$k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$=$k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$.$fqn$;for(var $i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$=0;;){if($i$jscomp$inline_2809_len$jscomp$inline_2792_len$jscomp$inline_2798_len$jscomp$inline_2803_len$jscomp$inline_2813$$<=$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$){$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=
-1;break a}if($JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$[$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$]instanceof $APP.$cljs$core$Keyword$$&&$k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$===$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$[$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$].$fqn$){$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=
$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$;break a}$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$+=2}$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=void 0}else if(typeof $k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$==="string"||typeof $k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$===
"number")a:{$i$jscomp$inline_2809_len$jscomp$inline_2792_len$jscomp$inline_2798_len$jscomp$inline_2803_len$jscomp$inline_2813$$=$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$.length;for($i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$=0;;){if($i$jscomp$inline_2809_len$jscomp$inline_2792_len$jscomp$inline_2798_len$jscomp$inline_2803_len$jscomp$inline_2813$$<=$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$){$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=
-1;break a}if($k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$===$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$[$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$]){$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$;
break a}$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$+=2}$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=void 0}else if($k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$ instanceof $APP.$cljs$core$Symbol$$)a:{$i$jscomp$inline_2809_len$jscomp$inline_2792_len$jscomp$inline_2798_len$jscomp$inline_2803_len$jscomp$inline_2813$$=$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$.length;
$k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$=$k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$.$str$;for($i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$=0;;){if($i$jscomp$inline_2809_len$jscomp$inline_2792_len$jscomp$inline_2798_len$jscomp$inline_2803_len$jscomp$inline_2813$$<=$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$){$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=
-1;break a}if($JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$[$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$]instanceof $APP.$cljs$core$Symbol$$&&$k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$===$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$[$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$].$str$){$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=
$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$;break a}$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$+=2}$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=void 0}else if($k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$==null)a:{$k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$=
$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$.length;for($i$jscomp$inline_2809_len$jscomp$inline_2792_len$jscomp$inline_2798_len$jscomp$inline_2803_len$jscomp$inline_2813$$=0;;){if($k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$<=$i$jscomp$inline_2809_len$jscomp$inline_2792_len$jscomp$inline_2798_len$jscomp$inline_2803_len$jscomp$inline_2813$$){$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=
-1;break a}if($JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$[$i$jscomp$inline_2809_len$jscomp$inline_2792_len$jscomp$inline_2798_len$jscomp$inline_2803_len$jscomp$inline_2813$$]==null){$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=$i$jscomp$inline_2809_len$jscomp$inline_2792_len$jscomp$inline_2798_len$jscomp$inline_2803_len$jscomp$inline_2813$$;
break a}$i$jscomp$inline_2809_len$jscomp$inline_2792_len$jscomp$inline_2798_len$jscomp$inline_2803_len$jscomp$inline_2813$$+=2}$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=void 0}else a:{$i$jscomp$inline_2809_len$jscomp$inline_2792_len$jscomp$inline_2798_len$jscomp$inline_2803_len$jscomp$inline_2813$$=$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$.length;
for($i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$=0;;){if($i$jscomp$inline_2809_len$jscomp$inline_2792_len$jscomp$inline_2798_len$jscomp$inline_2803_len$jscomp$inline_2813$$<=$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$){$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=-1;break a}if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$117_kstr$jscomp$inline_2793_kstr$jscomp$inline_2804_len$jscomp$inline_2808$$,
$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$[$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$])){$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$;break a}$i$jscomp$inline_2794_i$jscomp$inline_2799_i$jscomp$inline_2805_i$jscomp$inline_2814$$+=
2}$JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$=void 0}return $JSCompiler_temp$jscomp$212_JSCompiler_temp$jscomp$213_JSCompiler_temp$jscomp$214_JSCompiler_temp$jscomp$215_arr$jscomp$95$$};
$APP.$cljs$core$MapEntry$$=function($key$jscomp$128$$,$val$jscomp$82$$,$__hash$jscomp$23$$){this.key=$key$jscomp$128$$;this.$val$=$val$jscomp$82$$;this.$__hash$=$__hash$jscomp$23$$;this.$cljs$lang$protocol_mask$partition0$$=166619935;this.$cljs$lang$protocol_mask$partition1$$=0};
$APP.$cljs$core$map_entry_QMARK_$$=function($x$jscomp$519$$){return $x$jscomp$519$$!=null?$x$jscomp$519$$.$cljs$lang$protocol_mask$partition0$$&2048||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$519$$.$cljs$core$IMapEntry$$?!0:!1:!1};
$APP.$cljs$core$PersistentArrayMapSeq$$=function($arr$jscomp$97$$,$i$jscomp$229$$,$_meta$jscomp$4$$){this.$arr$=$arr$jscomp$97$$;this.i=$i$jscomp$229$$;this.$_meta$=$_meta$jscomp$4$$;this.$cljs$lang$protocol_mask$partition0$$=32374990;this.$cljs$lang$protocol_mask$partition1$$=262144};$cljs$core$PersistentArrayMapIterator$$=function($arr$jscomp$100$$,$cnt$jscomp$11$$){this.$arr$=$arr$jscomp$100$$;this.i=0;this.$cnt$=$cnt$jscomp$11$$};
$APP.$cljs$core$PersistentArrayMap$$=function($meta$jscomp$43$$,$cnt$jscomp$13$$,$arr$jscomp$102$$,$__hash$jscomp$25$$){this.$meta$=$meta$jscomp$43$$;this.$cnt$=$cnt$jscomp$13$$;this.$arr$=$arr$jscomp$102$$;this.$__hash$=$__hash$jscomp$25$$;this.$cljs$lang$protocol_mask$partition0$$=16647951;this.$cljs$lang$protocol_mask$partition1$$=401412};
$APP.$cljs$core$PersistentArrayMap$fromArray$$=function($JSCompiler_temp$jscomp$217_arr$jscomp$104_arr__$1$jscomp$2_arr__$2$$,$i_27871$jscomp$inline_2827_no_clone$jscomp$1$$,$no_check_ret$jscomp$inline_2826$$){$JSCompiler_temp$jscomp$217_arr$jscomp$104_arr__$1$jscomp$2_arr__$2$$=$i_27871$jscomp$inline_2827_no_clone$jscomp$1$$?$JSCompiler_temp$jscomp$217_arr$jscomp$104_arr__$1$jscomp$2_arr__$2$$:$APP.$cljs$core$aclone$$($JSCompiler_temp$jscomp$217_arr$jscomp$104_arr__$1$jscomp$2_arr__$2$$);if(!$no_check_ret$jscomp$inline_2826$$){$no_check_ret$jscomp$inline_2826$$=
[];for($i_27871$jscomp$inline_2827_no_clone$jscomp$1$$=0;;)if($i_27871$jscomp$inline_2827_no_clone$jscomp$1$$<$JSCompiler_temp$jscomp$217_arr$jscomp$104_arr__$1$jscomp$2_arr__$2$$.length){var $k_27872$jscomp$inline_2828$$=$JSCompiler_temp$jscomp$217_arr$jscomp$104_arr__$1$jscomp$2_arr__$2$$[$i_27871$jscomp$inline_2827_no_clone$jscomp$1$$],$v_27873$jscomp$inline_2829$$=$JSCompiler_temp$jscomp$217_arr$jscomp$104_arr__$1$jscomp$2_arr__$2$$[$i_27871$jscomp$inline_2827_no_clone$jscomp$1$$+1];$cljs$core$array_index_of$$($no_check_ret$jscomp$inline_2826$$,
$k_27872$jscomp$inline_2828$$)===-1&&($no_check_ret$jscomp$inline_2826$$.push($k_27872$jscomp$inline_2828$$),$no_check_ret$jscomp$inline_2826$$.push($v_27873$jscomp$inline_2829$$));$i_27871$jscomp$inline_2827_no_clone$jscomp$1$$+=2}else break;$JSCompiler_temp$jscomp$217_arr$jscomp$104_arr__$1$jscomp$2_arr__$2$$=$no_check_ret$jscomp$inline_2826$$}return new $APP.$cljs$core$PersistentArrayMap$$(null,$JSCompiler_temp$jscomp$217_arr$jscomp$104_arr__$1$jscomp$2_arr__$2$$.length/2,$JSCompiler_temp$jscomp$217_arr$jscomp$104_arr__$1$jscomp$2_arr__$2$$,
null)};$cljs$core$key_test$$=function($key$jscomp$130$$,$other$jscomp$90$$){return $key$jscomp$130$$===$other$jscomp$90$$?!0:$APP.$cljs$core$keyword_identical_QMARK_$$($key$jscomp$130$$,$other$jscomp$90$$)?!0:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$130$$,$other$jscomp$90$$)};
$cljs$core$pam_new_size$$=function($arr$jscomp$107$$){for(var $i$jscomp$237$$=0,$G__27888_n$jscomp$121$$=0;;)if($i$jscomp$237$$<$arr$jscomp$107$$.length){var $JSCompiler_inline_result$jscomp$218_j$jscomp$inline_2834$$;a:{for($JSCompiler_inline_result$jscomp$218_j$jscomp$inline_2834$$=0;;)if($JSCompiler_inline_result$jscomp$218_j$jscomp$inline_2834$$<$i$jscomp$237$$){var $or__5025__auto__$jscomp$inline_2835$$=$cljs$core$key_test$$($arr$jscomp$107$$[$i$jscomp$237$$],$arr$jscomp$107$$[$JSCompiler_inline_result$jscomp$218_j$jscomp$inline_2834$$]);
if($or__5025__auto__$jscomp$inline_2835$$){$JSCompiler_inline_result$jscomp$218_j$jscomp$inline_2834$$=$or__5025__auto__$jscomp$inline_2835$$;break a}$JSCompiler_inline_result$jscomp$218_j$jscomp$inline_2834$$=2+$JSCompiler_inline_result$jscomp$218_j$jscomp$inline_2834$$}else{$JSCompiler_inline_result$jscomp$218_j$jscomp$inline_2834$$=!1;break a}$JSCompiler_inline_result$jscomp$218_j$jscomp$inline_2834$$=void 0}$G__27888_n$jscomp$121$$=$JSCompiler_inline_result$jscomp$218_j$jscomp$inline_2834$$?$G__27888_n$jscomp$121$$:
$G__27888_n$jscomp$121$$+2;$i$jscomp$237$$=2+$i$jscomp$237$$}else return $G__27888_n$jscomp$121$$};
$cljs$core$pam_grow_seed_array$$=function($ret__$1$jscomp$4_seed$jscomp$3$$,$G__27892_extra_kvs_extra_kvs__$1_trailing$$){var $G__27891_i$jscomp$238_seed_cnt$$=$ret__$1$jscomp$4_seed$jscomp$3$$.length-1;$G__27892_extra_kvs_extra_kvs__$1_trailing$$=$APP.$cljs$core$seq$$($G__27892_extra_kvs_extra_kvs__$1_trailing$$);var $kv_ret$jscomp$32$$=Array($G__27891_i$jscomp$238_seed_cnt$$+2*$APP.$cljs$core$count$$($G__27892_extra_kvs_extra_kvs__$1_trailing$$));for($ret__$1$jscomp$4_seed$jscomp$3$$=$cljs$core$array_copy$$($ret__$1$jscomp$4_seed$jscomp$3$$,
0,$kv_ret$jscomp$32$$,0,$G__27891_i$jscomp$238_seed_cnt$$);;)if($G__27892_extra_kvs_extra_kvs__$1_trailing$$)$kv_ret$jscomp$32$$=$APP.$cljs$core$first$$($G__27892_extra_kvs_extra_kvs__$1_trailing$$),$ret__$1$jscomp$4_seed$jscomp$3$$[$G__27891_i$jscomp$238_seed_cnt$$]=$APP.$cljs$core$_key$$($kv_ret$jscomp$32$$),$ret__$1$jscomp$4_seed$jscomp$3$$[$G__27891_i$jscomp$238_seed_cnt$$+1]=$APP.$cljs$core$_val$$($kv_ret$jscomp$32$$),$G__27891_i$jscomp$238_seed_cnt$$=2+$G__27891_i$jscomp$238_seed_cnt$$,$G__27892_extra_kvs_extra_kvs__$1_trailing$$=
$APP.$cljs$core$next$$($G__27892_extra_kvs_extra_kvs__$1_trailing$$);else return $ret__$1$jscomp$4_seed$jscomp$3$$};
$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$=function($init$jscomp$32$$){var $len$jscomp$31$$=$init$jscomp$32$$.length,$has_trailing_QMARK_$$=1===($len$jscomp$31$$&1),$JSCompiler_temp$jscomp$10647_i$jscomp$inline_11275$$;if(!($JSCompiler_temp$jscomp$10647_i$jscomp$inline_11275$$=$has_trailing_QMARK_$$))a:{for($JSCompiler_temp$jscomp$10647_i$jscomp$inline_11275$$=0;;)if($JSCompiler_temp$jscomp$10647_i$jscomp$inline_11275$$<$init$jscomp$32$$.length){var $j$jscomp$inline_11277_or__5025__auto__$jscomp$inline_11276$$;
b:{for($j$jscomp$inline_11277_or__5025__auto__$jscomp$inline_11276$$=0;;)if($j$jscomp$inline_11277_or__5025__auto__$jscomp$inline_11276$$<$JSCompiler_temp$jscomp$10647_i$jscomp$inline_11275$$){var $or__5025__auto__$jscomp$inline_11278$$=$cljs$core$key_test$$($init$jscomp$32$$[$JSCompiler_temp$jscomp$10647_i$jscomp$inline_11275$$],$init$jscomp$32$$[$j$jscomp$inline_11277_or__5025__auto__$jscomp$inline_11276$$]);if($or__5025__auto__$jscomp$inline_11278$$){$j$jscomp$inline_11277_or__5025__auto__$jscomp$inline_11276$$=
$or__5025__auto__$jscomp$inline_11278$$;break b}$j$jscomp$inline_11277_or__5025__auto__$jscomp$inline_11276$$=2+$j$jscomp$inline_11277_or__5025__auto__$jscomp$inline_11276$$}else{$j$jscomp$inline_11277_or__5025__auto__$jscomp$inline_11276$$=!1;break b}$j$jscomp$inline_11277_or__5025__auto__$jscomp$inline_11276$$=void 0}if($j$jscomp$inline_11277_or__5025__auto__$jscomp$inline_11276$$){$JSCompiler_temp$jscomp$10647_i$jscomp$inline_11275$$=$j$jscomp$inline_11277_or__5025__auto__$jscomp$inline_11276$$;
break a}$JSCompiler_temp$jscomp$10647_i$jscomp$inline_11275$$=2+$JSCompiler_temp$jscomp$10647_i$jscomp$inline_11275$$}else{$JSCompiler_temp$jscomp$10647_i$jscomp$inline_11275$$=!1;break a}$JSCompiler_temp$jscomp$10647_i$jscomp$inline_11275$$=void 0}return $JSCompiler_temp$jscomp$10647_i$jscomp$inline_11275$$?$cljs$core$PersistentArrayMap$createAsIfByAssocComplexPath$$($init$jscomp$32$$,$has_trailing_QMARK_$$):new $APP.$cljs$core$PersistentArrayMap$$(null,$len$jscomp$31$$/2,$init$jscomp$32$$,null)};
$cljs$core$PersistentArrayMap$createAsIfByAssocComplexPath$$=function($init$jscomp$33_n$jscomp$122_nodups$$,$G__27902_G__27904_has_trailing_QMARK_$jscomp$1_j_27899$$){var $init__$1$jscomp$5$$=$G__27902_G__27904_has_trailing_QMARK_$jscomp$1_j_27899$$?$cljs$core$pam_grow_seed_array$$($init$jscomp$33_n$jscomp$122_nodups$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$init$jscomp$33_n$jscomp$122_nodups$$[$init$jscomp$33_n$jscomp$122_nodups$$.length-
1])):$init$jscomp$33_n$jscomp$122_nodups$$;$init$jscomp$33_n$jscomp$122_nodups$$=$cljs$core$pam_new_size$$($init__$1$jscomp$5$$);var $len$jscomp$32$$=$init__$1$jscomp$5$$.length;if($init$jscomp$33_n$jscomp$122_nodups$$<$len$jscomp$32$$){$init$jscomp$33_n$jscomp$122_nodups$$=Array($init$jscomp$33_n$jscomp$122_nodups$$);for(var $i_27895$$=0,$m_27896$$=0;;)if($i_27895$$<$len$jscomp$32$$)(function(){for(var $j$jscomp$67$$=0;;)if($j$jscomp$67$$<$m_27896$$){var $or__5025__auto__$jscomp$35$$=$cljs$core$key_test$$($init__$1$jscomp$5$$[$i_27895$$],
$init__$1$jscomp$5$$[$j$jscomp$67$$]);if($or__5025__auto__$jscomp$35$$)return $or__5025__auto__$jscomp$35$$;$j$jscomp$67$$=2+$j$jscomp$67$$}else return!1})()?($G__27902_G__27904_has_trailing_QMARK_$jscomp$1_j_27899$$=$m_27896$$,$i_27895$$=2+$i_27895$$,$m_27896$$=$G__27902_G__27904_has_trailing_QMARK_$jscomp$1_j_27899$$):($G__27902_G__27904_has_trailing_QMARK_$jscomp$1_j_27899$$=function(){for(var $j_27899$jscomp$1$$=$len$jscomp$32$$-2;;)if($j_27899$jscomp$1$$>=$i_27895$$){if($cljs$core$key_test$$($init__$1$jscomp$5$$[$i_27895$$],
$init__$1$jscomp$5$$[$j_27899$jscomp$1$$]))return $j_27899$jscomp$1$$;$j_27899$jscomp$1$$-=2}else return $j_27899$jscomp$1$$}(),$init$jscomp$33_n$jscomp$122_nodups$$[$m_27896$$]=$init__$1$jscomp$5$$[$i_27895$$],$init$jscomp$33_n$jscomp$122_nodups$$[$m_27896$$+1]=$init__$1$jscomp$5$$[$G__27902_G__27904_has_trailing_QMARK_$jscomp$1_j_27899$$+1],$G__27902_G__27904_has_trailing_QMARK_$jscomp$1_j_27899$$=2+$m_27896$$,$i_27895$$=2+$i_27895$$,$m_27896$$=$G__27902_G__27904_has_trailing_QMARK_$jscomp$1_j_27899$$);
else break;return new $APP.$cljs$core$PersistentArrayMap$$(null,$init$jscomp$33_n$jscomp$122_nodups$$.length/2,$init$jscomp$33_n$jscomp$122_nodups$$,null)}return new $APP.$cljs$core$PersistentArrayMap$$(null,$init__$1$jscomp$5$$.length/2,$init__$1$jscomp$5$$,null)};
$cljs$core$TransientArrayMap$$=function($len$jscomp$33$$,$arr$jscomp$108$$){this.$editable_QMARK_$={};this.$len$=$len$jscomp$33$$;this.$arr$=$arr$jscomp$108$$;this.$cljs$lang$protocol_mask$partition0$$=259;this.$cljs$lang$protocol_mask$partition1$$=56};
$cljs$core$array__GT_transient_hash_map$$=function($len$jscomp$35$$,$arr$jscomp$110$$){for(var $G__27927_out$jscomp$7$$=$APP.$cljs$core$_as_transient$$($cljs$core$PersistentHashMap$EMPTY$$),$G__27928_i$jscomp$239$$=0;;)if($G__27928_i$jscomp$239$$<$len$jscomp$35$$)$G__27927_out$jscomp$7$$=$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($G__27927_out$jscomp$7$$,$arr$jscomp$110$$[$G__27928_i$jscomp$239$$],$arr$jscomp$110$$[$G__27928_i$jscomp$239$$+1]),$G__27928_i$jscomp$239$$+=2;else return $G__27927_out$jscomp$7$$};
$cljs$core$Box$$=function(){this.$val$=!1};$cljs$core$clone_and_set$cljs$0core$0IFn$0_invoke$0arity$03$$=function($G__23683_arr$jscomp$111$$,$i$jscomp$240$$,$a$jscomp$161$$){$G__23683_arr$jscomp$111$$=$APP.$cljs$core$aclone$$($G__23683_arr$jscomp$111$$);$G__23683_arr$jscomp$111$$[$i$jscomp$240$$]=$a$jscomp$161$$;return $G__23683_arr$jscomp$111$$};
$cljs$core$remove_pair$$=function($arr$jscomp$113$$,$i$jscomp$242$$){var $new_arr$jscomp$2$$=Array($arr$jscomp$113$$.length-2);$cljs$core$array_copy$$($arr$jscomp$113$$,0,$new_arr$jscomp$2$$,0,2*$i$jscomp$242$$);$cljs$core$array_copy$$($arr$jscomp$113$$,2*($i$jscomp$242$$+1),$new_arr$jscomp$2$$,2*$i$jscomp$242$$,$new_arr$jscomp$2$$.length-2*$i$jscomp$242$$);return $new_arr$jscomp$2$$};
$cljs$core$edit_and_set$cljs$0core$0IFn$0_invoke$0arity$04$$=function($editable_inode$$,$edit$jscomp$5$$,$i$jscomp$243$$,$a$jscomp$163$$){$editable_inode$$=$editable_inode$$.$ensure_editable$($edit$jscomp$5$$);$editable_inode$$.$arr$[$i$jscomp$243$$]=$a$jscomp$163$$;return $editable_inode$$};
$cljs$core$inode_kv_reduce$$=function($arr$jscomp$114$$,$f$jscomp$260$$,$G__27960_init$jscomp$34_init__$2$jscomp$7_k$jscomp$inline_2837_node$jscomp$inline_2840$$){for(var $len$jscomp$36$$=$arr$jscomp$114$$.length,$i$jscomp$245$$=0,$G__23687$jscomp$inline_2838_init__$1$jscomp$6$$=$G__27960_init$jscomp$34_init__$2$jscomp$7_k$jscomp$inline_2837_node$jscomp$inline_2840$$;;)if($i$jscomp$245$$<$len$jscomp$36$$){$G__27960_init$jscomp$34_init__$2$jscomp$7_k$jscomp$inline_2837_node$jscomp$inline_2840$$=$arr$jscomp$114$$[$i$jscomp$245$$];
if($G__27960_init$jscomp$34_init__$2$jscomp$7_k$jscomp$inline_2837_node$jscomp$inline_2840$$!=null){var $G__23689$jscomp$inline_2839$$=$arr$jscomp$114$$[$i$jscomp$245$$+1];$G__27960_init$jscomp$34_init__$2$jscomp$7_k$jscomp$inline_2837_node$jscomp$inline_2840$$=$f$jscomp$260$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$260$$.$cljs$core$IFn$_invoke$arity$3$($G__23687$jscomp$inline_2838_init__$1$jscomp$6$$,$G__27960_init$jscomp$34_init__$2$jscomp$7_k$jscomp$inline_2837_node$jscomp$inline_2840$$,$G__23689$jscomp$inline_2839$$):
$f$jscomp$260$$($G__23687$jscomp$inline_2838_init__$1$jscomp$6$$,$G__27960_init$jscomp$34_init__$2$jscomp$7_k$jscomp$inline_2837_node$jscomp$inline_2840$$,$G__23689$jscomp$inline_2839$$)}else $G__27960_init$jscomp$34_init__$2$jscomp$7_k$jscomp$inline_2837_node$jscomp$inline_2840$$=$arr$jscomp$114$$[$i$jscomp$245$$+1],$G__27960_init$jscomp$34_init__$2$jscomp$7_k$jscomp$inline_2837_node$jscomp$inline_2840$$=$G__27960_init$jscomp$34_init__$2$jscomp$7_k$jscomp$inline_2837_node$jscomp$inline_2840$$!=null?
$G__27960_init$jscomp$34_init__$2$jscomp$7_k$jscomp$inline_2837_node$jscomp$inline_2840$$.$kv_reduce$($f$jscomp$260$$,$G__23687$jscomp$inline_2838_init__$1$jscomp$6$$):$G__23687$jscomp$inline_2838_init__$1$jscomp$6$$;if($cljs$core$reduced_QMARK_$$($G__27960_init$jscomp$34_init__$2$jscomp$7_k$jscomp$inline_2837_node$jscomp$inline_2840$$))return $G__27960_init$jscomp$34_init__$2$jscomp$7_k$jscomp$inline_2837_node$jscomp$inline_2840$$;$i$jscomp$245$$+=2;$G__23687$jscomp$inline_2838_init__$1$jscomp$6$$=
$G__27960_init$jscomp$34_init__$2$jscomp$7_k$jscomp$inline_2837_node$jscomp$inline_2840$$}else return $G__23687$jscomp$inline_2838_init__$1$jscomp$6$$};$cljs$core$NodeIterator$$=function($arr$jscomp$115$$){this.$arr$=$arr$jscomp$115$$;this.i=0;this.$next_iter$=this.$next_entry$=null};
$cljs$core$BitmapIndexedNode$$=function($edit$jscomp$7$$,$bitmap$jscomp$2$$,$arr$jscomp$117$$){this.$edit$=$edit$jscomp$7$$;this.$bitmap$=$bitmap$jscomp$2$$;this.$arr$=$arr$jscomp$117$$;this.$cljs$lang$protocol_mask$partition1$$=131072;this.$cljs$lang$protocol_mask$partition0$$=0};
$JSCompiler_StaticMethods_edit_and_remove_pair$$=function($JSCompiler_StaticMethods_edit_and_remove_pair$self_editable$jscomp$2$$,$e$jscomp$90_earr$$,$bit$jscomp$3$$,$i$jscomp$248$$){if($JSCompiler_StaticMethods_edit_and_remove_pair$self_editable$jscomp$2$$.$bitmap$===$bit$jscomp$3$$)return null;$JSCompiler_StaticMethods_edit_and_remove_pair$self_editable$jscomp$2$$=$JSCompiler_StaticMethods_edit_and_remove_pair$self_editable$jscomp$2$$.$ensure_editable$($e$jscomp$90_earr$$);$e$jscomp$90_earr$$=$JSCompiler_StaticMethods_edit_and_remove_pair$self_editable$jscomp$2$$.$arr$;
var $len$jscomp$38$$=$e$jscomp$90_earr$$.length;$JSCompiler_StaticMethods_edit_and_remove_pair$self_editable$jscomp$2$$.$bitmap$^=$bit$jscomp$3$$;$cljs$core$array_copy$$($e$jscomp$90_earr$$,2*($i$jscomp$248$$+1),$e$jscomp$90_earr$$,2*$i$jscomp$248$$,$len$jscomp$38$$-2*($i$jscomp$248$$+1));$e$jscomp$90_earr$$[$len$jscomp$38$$-2]=null;$e$jscomp$90_earr$$[$len$jscomp$38$$-1]=null;return $JSCompiler_StaticMethods_edit_and_remove_pair$self_editable$jscomp$2$$};
$cljs$core$pack_array_node$$=function($array_node_new_arr$jscomp$6$$,$edit$jscomp$9$$,$idx$jscomp$34$$){var $arr$jscomp$119$$=$array_node_new_arr$jscomp$6$$.$arr$,$len$jscomp$39$$=$arr$jscomp$119$$.length;$array_node_new_arr$jscomp$6$$=Array(2*($array_node_new_arr$jscomp$6$$.$cnt$-1));for(var $i$jscomp$249$$=0,$G__28004_G__28007_j$jscomp$70$$=1,$G__28005_G__28008_bitmap$jscomp$4$$=0;;)if($i$jscomp$249$$<$len$jscomp$39$$)$i$jscomp$249$$!==$idx$jscomp$34$$&&$arr$jscomp$119$$[$i$jscomp$249$$]!=null?
($array_node_new_arr$jscomp$6$$[$G__28004_G__28007_j$jscomp$70$$]=$arr$jscomp$119$$[$i$jscomp$249$$],$G__28004_G__28007_j$jscomp$70$$+=2,$G__28005_G__28008_bitmap$jscomp$4$$|=1<<$i$jscomp$249$$,$i$jscomp$249$$+=1):$i$jscomp$249$$+=1;else return new $cljs$core$BitmapIndexedNode$$($edit$jscomp$9$$,$G__28005_G__28008_bitmap$jscomp$4$$,$array_node_new_arr$jscomp$6$$)};$cljs$core$ArrayNodeIterator$$=function($arr$jscomp$120$$){this.$arr$=$arr$jscomp$120$$;this.i=0;this.$next_iter$=null};
$cljs$core$ArrayNode$$=function($edit$jscomp$10$$,$cnt$jscomp$17$$,$arr$jscomp$122$$){this.$edit$=$edit$jscomp$10$$;this.$cnt$=$cnt$jscomp$17$$;this.$arr$=$arr$jscomp$122$$;this.$cljs$lang$protocol_mask$partition1$$=131072;this.$cljs$lang$protocol_mask$partition0$$=0};
$cljs$core$hash_collision_node_find_index$$=function($arr$jscomp$124$$,$cnt$jscomp$19_lim$$,$key$jscomp$148$$){$cnt$jscomp$19_lim$$*=2;for(var $i$jscomp$253$$=0;;)if($i$jscomp$253$$<$cnt$jscomp$19_lim$$){if($cljs$core$key_test$$($key$jscomp$148$$,$arr$jscomp$124$$[$i$jscomp$253$$]))return $i$jscomp$253$$;$i$jscomp$253$$+=2}else return-1};
$cljs$core$HashCollisionNode$$=function($edit$jscomp$12$$,$collision_hash$$,$cnt$jscomp$20$$,$arr$jscomp$125$$){this.$edit$=$edit$jscomp$12$$;this.$collision_hash$=$collision_hash$$;this.$cnt$=$cnt$jscomp$20$$;this.$arr$=$arr$jscomp$125$$;this.$cljs$lang$protocol_mask$partition1$$=131072;this.$cljs$lang$protocol_mask$partition0$$=0};
$cljs$core$create_node$$=function($var_args$jscomp$238$$){switch(arguments.length){case 6:return $cljs$core$create_node$cljs$0core$0IFn$0_invoke$0arity$06$$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5]);case 7:return $cljs$core$create_node$cljs$0core$0IFn$0_invoke$0arity$07$$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};
$cljs$core$create_node$cljs$0core$0IFn$0_invoke$0arity$06$$=function($shift$jscomp$24$$,$key1$$,$val1$$,$key2hash$$,$key2$$,$val2$$){var $key1hash$$=$APP.$cljs$core$hash$$($key1$$);if($key1hash$$===$key2hash$$)return new $cljs$core$HashCollisionNode$$(null,$key1hash$$,2,[$key1$$,$val1$$,$key2$$,$val2$$]);var $added_leaf_QMARK_$jscomp$6$$=new $cljs$core$Box$$;return $cljs$core$BitmapIndexedNode$EMPTY$$.$inode_assoc$($shift$jscomp$24$$,$key1hash$$,$key1$$,$val1$$,$added_leaf_QMARK_$jscomp$6$$).$inode_assoc$($shift$jscomp$24$$,$key2hash$$,
$key2$$,$val2$$,$added_leaf_QMARK_$jscomp$6$$)};
$cljs$core$create_node$cljs$0core$0IFn$0_invoke$0arity$07$$=function($edit$jscomp$14$$,$shift$jscomp$25$$,$key1$jscomp$1$$,$val1$jscomp$1$$,$key2hash$jscomp$1$$,$key2$jscomp$1$$,$val2$jscomp$1$$){var $key1hash$jscomp$1$$=$APP.$cljs$core$hash$$($key1$jscomp$1$$);if($key1hash$jscomp$1$$===$key2hash$jscomp$1$$)return new $cljs$core$HashCollisionNode$$(null,$key1hash$jscomp$1$$,2,[$key1$jscomp$1$$,$val1$jscomp$1$$,$key2$jscomp$1$$,$val2$jscomp$1$$]);var $added_leaf_QMARK_$jscomp$7$$=new $cljs$core$Box$$;
return $cljs$core$BitmapIndexedNode$EMPTY$$.$inode_assoc_BANG_$($edit$jscomp$14$$,$shift$jscomp$25$$,$key1hash$jscomp$1$$,$key1$jscomp$1$$,$val1$jscomp$1$$,$added_leaf_QMARK_$jscomp$7$$).$inode_assoc_BANG_$($edit$jscomp$14$$,$shift$jscomp$25$$,$key2hash$jscomp$1$$,$key2$jscomp$1$$,$val2$jscomp$1$$,$added_leaf_QMARK_$jscomp$7$$)};
$APP.$cljs$core$NodeSeq$$=function($meta$jscomp$45$$,$nodes$jscomp$20$$,$i$jscomp$254$$,$s$jscomp$92$$,$__hash$jscomp$27$$){this.$meta$=$meta$jscomp$45$$;this.$nodes$=$nodes$jscomp$20$$;this.i=$i$jscomp$254$$;this.s=$s$jscomp$92$$;this.$__hash$=$__hash$jscomp$27$$;this.$cljs$lang$protocol_mask$partition0$$=32374988;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$core$create_inode_seq$$=function($var_args$jscomp$239$$){switch(arguments.length){case 1:return $cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$01$$(arguments[0]);case 3:return $cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$01$$=function($nodes$jscomp$22$$){return $cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$03$$($nodes$jscomp$22$$,0,null)};
$cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$03$$=function($nodes$jscomp$23$$,$i$jscomp$256_j$jscomp$71$$,$len$jscomp$44_s$jscomp$94$$){if($len$jscomp$44_s$jscomp$94$$==null)for($len$jscomp$44_s$jscomp$94$$=$nodes$jscomp$23$$.length;;)if($i$jscomp$256_j$jscomp$71$$<$len$jscomp$44_s$jscomp$94$$){if($nodes$jscomp$23$$[$i$jscomp$256_j$jscomp$71$$]!=null)return new $APP.$cljs$core$NodeSeq$$(null,$nodes$jscomp$23$$,$i$jscomp$256_j$jscomp$71$$,null,null);var $temp__5823__auto__$jscomp$9_temp__5823__auto____$1$$=
$nodes$jscomp$23$$[$i$jscomp$256_j$jscomp$71$$+1];if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$9_temp__5823__auto____$1$$)&&($temp__5823__auto__$jscomp$9_temp__5823__auto____$1$$=$temp__5823__auto__$jscomp$9_temp__5823__auto____$1$$.$inode_seq$(),$APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$9_temp__5823__auto____$1$$)))return new $APP.$cljs$core$NodeSeq$$(null,$nodes$jscomp$23$$,$i$jscomp$256_j$jscomp$71$$+2,$temp__5823__auto__$jscomp$9_temp__5823__auto____$1$$,null);$i$jscomp$256_j$jscomp$71$$+=
2}else return null;else return new $APP.$cljs$core$NodeSeq$$(null,$nodes$jscomp$23$$,$i$jscomp$256_j$jscomp$71$$,$len$jscomp$44_s$jscomp$94$$,null)};
$APP.$cljs$core$ArrayNodeSeq$$=function($meta$jscomp$47$$,$nodes$jscomp$24$$,$i$jscomp$257$$,$s$jscomp$95$$,$__hash$jscomp$29$$){this.$meta$=$meta$jscomp$47$$;this.$nodes$=$nodes$jscomp$24$$;this.i=$i$jscomp$257$$;this.s=$s$jscomp$95$$;this.$__hash$=$__hash$jscomp$29$$;this.$cljs$lang$protocol_mask$partition0$$=32374988;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$core$create_array_node_seq$$=function($var_args$jscomp$240$$){switch(arguments.length){case 1:return $cljs$core$create_array_node_seq$cljs$0core$0IFn$0_invoke$0arity$01$$(arguments[0]);case 3:return $cljs$core$create_array_node_seq$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$cljs$core$create_array_node_seq$cljs$0core$0IFn$0_invoke$0arity$01$$=function($nodes$jscomp$26$$){return $cljs$core$create_array_node_seq$cljs$0core$0IFn$0_invoke$0arity$03$$($nodes$jscomp$26$$,0,null)};
$cljs$core$create_array_node_seq$cljs$0core$0IFn$0_invoke$0arity$03$$=function($nodes$jscomp$27$$,$i$jscomp$259_j$jscomp$72$$,$len$jscomp$45_s$jscomp$97$$){if($len$jscomp$45_s$jscomp$97$$==null)for($len$jscomp$45_s$jscomp$97$$=$nodes$jscomp$27$$.length;;)if($i$jscomp$259_j$jscomp$72$$<$len$jscomp$45_s$jscomp$97$$){var $temp__5823__auto__$jscomp$10_temp__5823__auto____$1$jscomp$1$$=$nodes$jscomp$27$$[$i$jscomp$259_j$jscomp$72$$];if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$10_temp__5823__auto____$1$jscomp$1$$)&&
($temp__5823__auto__$jscomp$10_temp__5823__auto____$1$jscomp$1$$=$temp__5823__auto__$jscomp$10_temp__5823__auto____$1$jscomp$1$$.$inode_seq$(),$APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$10_temp__5823__auto____$1$jscomp$1$$)))return new $APP.$cljs$core$ArrayNodeSeq$$(null,$nodes$jscomp$27$$,$i$jscomp$259_j$jscomp$72$$+1,$temp__5823__auto__$jscomp$10_temp__5823__auto____$1$jscomp$1$$,null);$i$jscomp$259_j$jscomp$72$$+=1}else return null;else return new $APP.$cljs$core$ArrayNodeSeq$$(null,$nodes$jscomp$27$$,
$i$jscomp$259_j$jscomp$72$$,$len$jscomp$45_s$jscomp$97$$,null)};$cljs$core$HashMapIter$$=function($nil_val$$,$root_iter$$){this.$nil_val$=$nil_val$$;this.$root_iter$=$root_iter$$;this.$seen$=!1};
$APP.$cljs$core$PersistentHashMap$$=function($meta$jscomp$49$$,$cnt$jscomp$22$$,$root$jscomp$10$$,$has_nil_QMARK_$$,$nil_val$jscomp$2$$,$__hash$jscomp$31$$){this.$meta$=$meta$jscomp$49$$;this.$cnt$=$cnt$jscomp$22$$;this.root=$root$jscomp$10$$;this.$has_nil_QMARK_$=$has_nil_QMARK_$$;this.$nil_val$=$nil_val$jscomp$2$$;this.$__hash$=$__hash$jscomp$31$$;this.$cljs$lang$protocol_mask$partition0$$=16123663;this.$cljs$lang$protocol_mask$partition1$$=139268};
$APP.$cljs$core$PersistentHashMap$fromArray$$=function($arr$jscomp$127$$){for(var $len$jscomp$46$$=$arr$jscomp$127$$.length,$i$jscomp$260$$=0,$G__28292_ret$jscomp$37$$=$APP.$cljs$core$_as_transient$$($cljs$core$PersistentHashMap$EMPTY$$);;)if($i$jscomp$260$$<$len$jscomp$46$$){var $G__28291$$=$i$jscomp$260$$+2;$G__28292_ret$jscomp$37$$=$cljs$core$_assoc_BANG_$$($G__28292_ret$jscomp$37$$,$arr$jscomp$127$$[$i$jscomp$260$$],$arr$jscomp$127$$[$i$jscomp$260$$+1]);$i$jscomp$260$$=$G__28291$$}else return $APP.$cljs$core$_persistent_BANG_$$($G__28292_ret$jscomp$37$$)};
$APP.$cljs$core$PersistentHashMap$fromArrays$$=function($ks$jscomp$14$$,$vs$$){for(var $len$jscomp$47$$=$ks$jscomp$14$$.length,$i$jscomp$261$$=0,$G__28302_out$jscomp$8$$=$APP.$cljs$core$_as_transient$$($cljs$core$PersistentHashMap$EMPTY$$);;)if($i$jscomp$261$$<$len$jscomp$47$$){if($vs$$.length<=$i$jscomp$261$$)throw Error(["No value supplied for key: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ks$jscomp$14$$[$i$jscomp$261$$])].join(""));var $G__28301$$=$i$jscomp$261$$+1;$G__28302_out$jscomp$8$$=
$cljs$core$_assoc_BANG_$$($G__28302_out$jscomp$8$$,$ks$jscomp$14$$[$i$jscomp$261$$],$vs$$[$i$jscomp$261$$]);$i$jscomp$261$$=$G__28301$$}else return $APP.$cljs$core$_persistent_BANG_$$($G__28302_out$jscomp$8$$)};
$cljs$core$TransientHashMap$$=function($root$jscomp$12$$,$count$jscomp$49$$,$has_nil_QMARK_$jscomp$2$$,$nil_val$jscomp$4$$){this.$edit$={};this.root=$root$jscomp$12$$;this.count=$count$jscomp$49$$;this.$has_nil_QMARK_$=$has_nil_QMARK_$jscomp$2$$;this.$nil_val$=$nil_val$jscomp$4$$;this.$cljs$lang$protocol_mask$partition0$$=259;this.$cljs$lang$protocol_mask$partition1$$=56};
$JSCompiler_StaticMethods_assoc_BANG_$$=function($JSCompiler_StaticMethods_assoc_BANG_$self$$,$k$jscomp$153_node$jscomp$58$$,$v$jscomp$49$$){if($JSCompiler_StaticMethods_assoc_BANG_$self$$.$edit$){if($k$jscomp$153_node$jscomp$58$$==null)$JSCompiler_StaticMethods_assoc_BANG_$self$$.$nil_val$!==$v$jscomp$49$$&&($JSCompiler_StaticMethods_assoc_BANG_$self$$.$nil_val$=$v$jscomp$49$$),$JSCompiler_StaticMethods_assoc_BANG_$self$$.$has_nil_QMARK_$||($JSCompiler_StaticMethods_assoc_BANG_$self$$.count+=1,$JSCompiler_StaticMethods_assoc_BANG_$self$$.$has_nil_QMARK_$=
!0);else{var $added_leaf_QMARK_$jscomp$9$$=new $cljs$core$Box$$;$k$jscomp$153_node$jscomp$58$$=($JSCompiler_StaticMethods_assoc_BANG_$self$$.root==null?$cljs$core$BitmapIndexedNode$EMPTY$$:$JSCompiler_StaticMethods_assoc_BANG_$self$$.root).$inode_assoc_BANG_$($JSCompiler_StaticMethods_assoc_BANG_$self$$.$edit$,0,$APP.$cljs$core$hash$$($k$jscomp$153_node$jscomp$58$$),$k$jscomp$153_node$jscomp$58$$,$v$jscomp$49$$,$added_leaf_QMARK_$jscomp$9$$);$k$jscomp$153_node$jscomp$58$$!==$JSCompiler_StaticMethods_assoc_BANG_$self$$.root&&
($JSCompiler_StaticMethods_assoc_BANG_$self$$.root=$k$jscomp$153_node$jscomp$58$$);$added_leaf_QMARK_$jscomp$9$$.$val$&&($JSCompiler_StaticMethods_assoc_BANG_$self$$.count+=1)}return $JSCompiler_StaticMethods_assoc_BANG_$self$$}throw Error("assoc! after persistent!");};
$cljs$core$tree_map_seq_push$$=function($node$jscomp$60_t$jscomp$10$$,$G__28357_stack$jscomp$1$$,$ascending_QMARK_$jscomp$4$$){for(var $G__28358_stack__$1$$=$G__28357_stack$jscomp$1$$;;)if($node$jscomp$60_t$jscomp$10$$!=null)$G__28357_stack$jscomp$1$$=$ascending_QMARK_$jscomp$4$$?$node$jscomp$60_t$jscomp$10$$.left:$node$jscomp$60_t$jscomp$10$$.right,$G__28358_stack__$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__28358_stack__$1$$,$node$jscomp$60_t$jscomp$10$$),$node$jscomp$60_t$jscomp$10$$=
$G__28357_stack$jscomp$1$$;else return $G__28358_stack__$1$$};$cljs$core$PersistentTreeMapSeq$$=function($meta$jscomp$51$$,$stack$jscomp$2$$,$ascending_QMARK_$jscomp$5$$,$cnt$jscomp$24$$,$__hash$jscomp$33$$){this.$meta$=$meta$jscomp$51$$;this.stack=$stack$jscomp$2$$;this.$ascending_QMARK_$=$ascending_QMARK_$jscomp$5$$;this.$cnt$=$cnt$jscomp$24$$;this.$__hash$=$__hash$jscomp$33$$;this.$cljs$lang$protocol_mask$partition0$$=32374990;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$core$create_tree_map_seq$$=function($tree$$,$ascending_QMARK_$jscomp$7$$,$cnt$jscomp$26$$){return new $cljs$core$PersistentTreeMapSeq$$(null,$cljs$core$tree_map_seq_push$$($tree$$,null,$ascending_QMARK_$jscomp$7$$),$ascending_QMARK_$jscomp$7$$,$cnt$jscomp$26$$,null)};
$cljs$core$balance_left$$=function($key$jscomp$159$$,$val$jscomp$95$$,$ins$$,$right$jscomp$4$$){return $ins$$ instanceof $APP.$cljs$core$RedNode$$?$ins$$.left instanceof $APP.$cljs$core$RedNode$$?new $APP.$cljs$core$RedNode$$($ins$$.key,$ins$$.$val$,$ins$$.left.$blacken$(),new $APP.$cljs$core$BlackNode$$($key$jscomp$159$$,$val$jscomp$95$$,$ins$$.right,$right$jscomp$4$$,null),null):$ins$$.right instanceof $APP.$cljs$core$RedNode$$?new $APP.$cljs$core$RedNode$$($ins$$.right.key,$ins$$.right.$val$,new $APP.$cljs$core$BlackNode$$($ins$$.key,
$ins$$.$val$,$ins$$.left,$ins$$.right.left,null),new $APP.$cljs$core$BlackNode$$($key$jscomp$159$$,$val$jscomp$95$$,$ins$$.right.right,$right$jscomp$4$$,null),null):new $APP.$cljs$core$BlackNode$$($key$jscomp$159$$,$val$jscomp$95$$,$ins$$,$right$jscomp$4$$,null):new $APP.$cljs$core$BlackNode$$($key$jscomp$159$$,$val$jscomp$95$$,$ins$$,$right$jscomp$4$$,null)};
$cljs$core$balance_right$$=function($key$jscomp$160$$,$val$jscomp$96$$,$left$jscomp$4$$,$ins$jscomp$1$$){return $ins$jscomp$1$$ instanceof $APP.$cljs$core$RedNode$$?$ins$jscomp$1$$.right instanceof $APP.$cljs$core$RedNode$$?new $APP.$cljs$core$RedNode$$($ins$jscomp$1$$.key,$ins$jscomp$1$$.$val$,new $APP.$cljs$core$BlackNode$$($key$jscomp$160$$,$val$jscomp$96$$,$left$jscomp$4$$,$ins$jscomp$1$$.left,null),$ins$jscomp$1$$.right.$blacken$(),null):$ins$jscomp$1$$.left instanceof $APP.$cljs$core$RedNode$$?
new $APP.$cljs$core$RedNode$$($ins$jscomp$1$$.left.key,$ins$jscomp$1$$.left.$val$,new $APP.$cljs$core$BlackNode$$($key$jscomp$160$$,$val$jscomp$96$$,$left$jscomp$4$$,$ins$jscomp$1$$.left.left,null),new $APP.$cljs$core$BlackNode$$($ins$jscomp$1$$.key,$ins$jscomp$1$$.$val$,$ins$jscomp$1$$.left.right,$ins$jscomp$1$$.right,null),null):new $APP.$cljs$core$BlackNode$$($key$jscomp$160$$,$val$jscomp$96$$,$left$jscomp$4$$,$ins$jscomp$1$$,null):new $APP.$cljs$core$BlackNode$$($key$jscomp$160$$,$val$jscomp$96$$,
$left$jscomp$4$$,$ins$jscomp$1$$,null)};
$cljs$core$balance_left_del$$=function($key$jscomp$161$$,$val$jscomp$97$$,$del$$,$right$jscomp$5$$){if($del$$ instanceof $APP.$cljs$core$RedNode$$)return new $APP.$cljs$core$RedNode$$($key$jscomp$161$$,$val$jscomp$97$$,$del$$.$blacken$(),$right$jscomp$5$$,null);if($right$jscomp$5$$ instanceof $APP.$cljs$core$BlackNode$$)return $cljs$core$balance_right$$($key$jscomp$161$$,$val$jscomp$97$$,$del$$,$right$jscomp$5$$.$redden$());if($right$jscomp$5$$ instanceof $APP.$cljs$core$RedNode$$&&$right$jscomp$5$$.left instanceof
$APP.$cljs$core$BlackNode$$)return new $APP.$cljs$core$RedNode$$($right$jscomp$5$$.left.key,$right$jscomp$5$$.left.$val$,new $APP.$cljs$core$BlackNode$$($key$jscomp$161$$,$val$jscomp$97$$,$del$$,$right$jscomp$5$$.left.left,null),$cljs$core$balance_right$$($right$jscomp$5$$.key,$right$jscomp$5$$.$val$,$right$jscomp$5$$.left.right,$right$jscomp$5$$.right.$redden$()),null);throw Error("red-black tree invariant violation");};
$cljs$core$balance_right_del$$=function($key$jscomp$162$$,$val$jscomp$98$$,$left$jscomp$5$$,$del$jscomp$1$$){if($del$jscomp$1$$ instanceof $APP.$cljs$core$RedNode$$)return new $APP.$cljs$core$RedNode$$($key$jscomp$162$$,$val$jscomp$98$$,$left$jscomp$5$$,$del$jscomp$1$$.$blacken$(),null);if($left$jscomp$5$$ instanceof $APP.$cljs$core$BlackNode$$)return $cljs$core$balance_left$$($key$jscomp$162$$,$val$jscomp$98$$,$left$jscomp$5$$.$redden$(),$del$jscomp$1$$);if($left$jscomp$5$$ instanceof $APP.$cljs$core$RedNode$$&&
$left$jscomp$5$$.right instanceof $APP.$cljs$core$BlackNode$$)return new $APP.$cljs$core$RedNode$$($left$jscomp$5$$.right.key,$left$jscomp$5$$.right.$val$,$cljs$core$balance_left$$($left$jscomp$5$$.key,$left$jscomp$5$$.$val$,$left$jscomp$5$$.left.$redden$(),$left$jscomp$5$$.right.left),new $APP.$cljs$core$BlackNode$$($key$jscomp$162$$,$val$jscomp$98$$,$left$jscomp$5$$.right.right,$del$jscomp$1$$,null),null);throw Error("red-black tree invariant violation");};
$APP.$cljs$core$BlackNode$$=function($key$jscomp$163$$,$val$jscomp$99$$,$left$jscomp$6$$,$right$jscomp$6$$,$__hash$jscomp$35$$){this.key=$key$jscomp$163$$;this.$val$=$val$jscomp$99$$;this.left=$left$jscomp$6$$;this.right=$right$jscomp$6$$;this.$__hash$=$__hash$jscomp$35$$;this.$cljs$lang$protocol_mask$partition0$$=166619935;this.$cljs$lang$protocol_mask$partition1$$=0};
$APP.$cljs$core$RedNode$$=function($key$jscomp$165$$,$val$jscomp$101$$,$left$jscomp$8$$,$right$jscomp$8$$,$__hash$jscomp$37$$){this.key=$key$jscomp$165$$;this.$val$=$val$jscomp$101$$;this.left=$left$jscomp$8$$;this.right=$right$jscomp$8$$;this.$__hash$=$__hash$jscomp$37$$;this.$cljs$lang$protocol_mask$partition0$$=166619935;this.$cljs$lang$protocol_mask$partition1$$=0};
$APP.$cljs$core$PersistentTreeMap$$=function($comp$jscomp$5$$,$tree$jscomp$4$$,$cnt$jscomp$27$$,$meta$jscomp$55$$,$__hash$jscomp$39$$){this.$comp$=$comp$jscomp$5$$;this.$tree$=$tree$jscomp$4$$;this.$cnt$=$cnt$jscomp$27$$;this.$meta$=$meta$jscomp$55$$;this.$__hash$=$__hash$jscomp$39$$;this.$cljs$lang$protocol_mask$partition0$$=418776847;this.$cljs$lang$protocol_mask$partition1$$=8192};
$JSCompiler_StaticMethods_entry_at$$=function($JSCompiler_StaticMethods_entry_at$self$$,$k$jscomp$177$$){for(var $t$jscomp$13$$=$JSCompiler_StaticMethods_entry_at$self$$.$tree$;;)if($t$jscomp$13$$!=null){var $G__23820$jscomp$inline_2873_c$jscomp$114$$=$t$jscomp$13$$.key;$G__23820$jscomp$inline_2873_c$jscomp$114$$=$JSCompiler_StaticMethods_entry_at$self$$.$comp$.$cljs$core$IFn$_invoke$arity$2$?$JSCompiler_StaticMethods_entry_at$self$$.$comp$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$177$$,$G__23820$jscomp$inline_2873_c$jscomp$114$$):
$JSCompiler_StaticMethods_entry_at$self$$.$comp$($k$jscomp$177$$,$G__23820$jscomp$inline_2873_c$jscomp$114$$);if($G__23820$jscomp$inline_2873_c$jscomp$114$$===0)return $t$jscomp$13$$;$t$jscomp$13$$=$G__23820$jscomp$inline_2873_c$jscomp$114$$<0?$t$jscomp$13$$.left:$t$jscomp$13$$.right}else return null};
$APP.$cljs$core$sorted_map_by$$=function($var_args$jscomp$245$$){for(var $JSCompiler_inline_result$jscomp$229_args__5755__auto__$jscomp$7_in$$jscomp$inline_2877$$=[],$G__28807$jscomp$inline_2879_comparator$jscomp$inline_2875_len__5749__auto___28802$$=arguments.length,$G__28808$jscomp$inline_2880_i__5750__auto___28803_out$jscomp$inline_2878$$=0;;)if($G__28808$jscomp$inline_2880_i__5750__auto___28803_out$jscomp$inline_2878$$<$G__28807$jscomp$inline_2879_comparator$jscomp$inline_2875_len__5749__auto___28802$$)$JSCompiler_inline_result$jscomp$229_args__5755__auto__$jscomp$7_in$$jscomp$inline_2877$$.push(arguments[$G__28808$jscomp$inline_2880_i__5750__auto___28803_out$jscomp$inline_2878$$]),
$G__28808$jscomp$inline_2880_i__5750__auto___28803_out$jscomp$inline_2878$$+=1;else break;a:{$G__28807$jscomp$inline_2879_comparator$jscomp$inline_2875_len__5749__auto___28802$$=arguments[0];$JSCompiler_inline_result$jscomp$229_args__5755__auto__$jscomp$7_in$$jscomp$inline_2877$$=$APP.$cljs$core$seq$$(1<$JSCompiler_inline_result$jscomp$229_args__5755__auto__$jscomp$7_in$$jscomp$inline_2877$$.length?new $APP.$cljs$core$IndexedSeq$$($JSCompiler_inline_result$jscomp$229_args__5755__auto__$jscomp$7_in$$jscomp$inline_2877$$.slice(1),
0,null):null);for($G__28808$jscomp$inline_2880_i__5750__auto___28803_out$jscomp$inline_2878$$=new $APP.$cljs$core$PersistentTreeMap$$($cljs$core$fn__GT_comparator$$($G__28807$jscomp$inline_2879_comparator$jscomp$inline_2875_len__5749__auto___28802$$),null,0,null,0);;)if($JSCompiler_inline_result$jscomp$229_args__5755__auto__$jscomp$7_in$$jscomp$inline_2877$$)$G__28807$jscomp$inline_2879_comparator$jscomp$inline_2875_len__5749__auto___28802$$=$APP.$cljs$core$next$$($APP.$cljs$core$next$$($JSCompiler_inline_result$jscomp$229_args__5755__auto__$jscomp$7_in$$jscomp$inline_2877$$)),
$G__28808$jscomp$inline_2880_i__5750__auto___28803_out$jscomp$inline_2878$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__28808$jscomp$inline_2880_i__5750__auto___28803_out$jscomp$inline_2878$$,$APP.$cljs$core$first$$($JSCompiler_inline_result$jscomp$229_args__5755__auto__$jscomp$7_in$$jscomp$inline_2877$$),$APP.$cljs$core$second$$($JSCompiler_inline_result$jscomp$229_args__5755__auto__$jscomp$7_in$$jscomp$inline_2877$$)),$JSCompiler_inline_result$jscomp$229_args__5755__auto__$jscomp$7_in$$jscomp$inline_2877$$=
$G__28807$jscomp$inline_2879_comparator$jscomp$inline_2875_len__5749__auto___28802$$;else{$JSCompiler_inline_result$jscomp$229_args__5755__auto__$jscomp$7_in$$jscomp$inline_2877$$=$G__28808$jscomp$inline_2880_i__5750__auto___28803_out$jscomp$inline_2878$$;break a}$JSCompiler_inline_result$jscomp$229_args__5755__auto__$jscomp$7_in$$jscomp$inline_2877$$=void 0}return $JSCompiler_inline_result$jscomp$229_args__5755__auto__$jscomp$7_in$$jscomp$inline_2877$$};
$cljs$core$KeySeq$$=function($mseq$$,$_meta$jscomp$7$$){this.$mseq$=$mseq$$;this.$_meta$=$_meta$jscomp$7$$;this.$cljs$lang$protocol_mask$partition0$$=32374988;this.$cljs$lang$protocol_mask$partition1$$=0};$APP.$cljs$core$keys$$=function($map$jscomp$10_temp__5825__auto__$jscomp$13$$){return($map$jscomp$10_temp__5825__auto__$jscomp$13$$=$APP.$cljs$core$seq$$($map$jscomp$10_temp__5825__auto__$jscomp$13$$))?new $cljs$core$KeySeq$$($map$jscomp$10_temp__5825__auto__$jscomp$13$$,null):null};
$APP.$cljs$core$key$$=function($map_entry$$){return $APP.$cljs$core$_key$$($map_entry$$)};$cljs$core$ValSeq$$=function($mseq$jscomp$3$$,$_meta$jscomp$9$$){this.$mseq$=$mseq$jscomp$3$$;this.$_meta$=$_meta$jscomp$9$$;this.$cljs$lang$protocol_mask$partition0$$=32374988;this.$cljs$lang$protocol_mask$partition1$$=0};
$APP.$cljs$core$vals$$=function($map$jscomp$11_temp__5825__auto__$jscomp$14$$){return($map$jscomp$11_temp__5825__auto__$jscomp$14$$=$APP.$cljs$core$seq$$($map$jscomp$11_temp__5825__auto__$jscomp$14$$))?new $cljs$core$ValSeq$$($map$jscomp$11_temp__5825__auto__$jscomp$14$$,null):null};$APP.$cljs$core$val$$=function($map_entry$jscomp$1$$){return $APP.$cljs$core$_val$$($map_entry$jscomp$1$$)};
$APP.$cljs$core$select_keys$$=function($map$jscomp$12$$,$G__28945_keys$jscomp$14_keyseq$$){var $G__28944_ret$jscomp$40$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;for($G__28945_keys$jscomp$14_keyseq$$=$APP.$cljs$core$seq$$($G__28945_keys$jscomp$14_keyseq$$);;)if($G__28945_keys$jscomp$14_keyseq$$){var $key$jscomp$167$$=$APP.$cljs$core$first$$($G__28945_keys$jscomp$14_keyseq$$),$entry$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map$jscomp$12$$,$key$jscomp$167$$,$cljs$cst$98$cljs_DOT_core_SLASH_not_found$$);
$G__28944_ret$jscomp$40$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($entry$jscomp$7$$,$cljs$cst$98$cljs_DOT_core_SLASH_not_found$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__28944_ret$jscomp$40$$,$key$jscomp$167$$,$entry$jscomp$7$$):$G__28944_ret$jscomp$40$$;$G__28945_keys$jscomp$14_keyseq$$=$APP.$cljs$core$next$$($G__28945_keys$jscomp$14_keyseq$$)}else return $APP.$cljs$core$_with_meta$$($G__28944_ret$jscomp$40$$,$APP.$cljs$core$meta$$($map$jscomp$12$$))};
$cljs$core$HashSetIter$$=function($iter$jscomp$9$$){this.$iter$=$iter$jscomp$9$$};$APP.$cljs$core$PersistentHashSet$$=function($meta$jscomp$57$$,$hash_map$$,$__hash$jscomp$41$$){this.$meta$=$meta$jscomp$57$$;this.$hash_map$=$hash_map$$;this.$__hash$=$__hash$jscomp$41$$;this.$cljs$lang$protocol_mask$partition0$$=15077647;this.$cljs$lang$protocol_mask$partition1$$=139268};
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$=function($items$jscomp$5$$){for(var $len$jscomp$51$$=$items$jscomp$5$$.length,$t$jscomp$18$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$i_29039$$=0;;)if($i_29039$$<$len$jscomp$51$$)$cljs$core$_conj_BANG_$$($t$jscomp$18$$,$items$jscomp$5$$[$i_29039$$]),$i_29039$$+=1;else break;return $APP.$cljs$core$_persistent_BANG_$$($t$jscomp$18$$)};
$cljs$core$TransientHashSet$$=function($transient_map$$){this.$transient_map$=$transient_map$$;this.$cljs$lang$protocol_mask$partition1$$=136;this.$cljs$lang$protocol_mask$partition0$$=259};$cljs$core$PersistentTreeSet$$=function($meta$jscomp$59$$,$tree_map$$,$__hash$jscomp$43$$){this.$meta$=$meta$jscomp$59$$;this.$tree_map$=$tree_map$$;this.$__hash$=$__hash$jscomp$43$$;this.$cljs$lang$protocol_mask$partition0$$=417730831;this.$cljs$lang$protocol_mask$partition1$$=8192};
$APP.$cljs$core$set$$=function($coll$jscomp$735_in$$jscomp$5_in$__$1$$){if($APP.$cljs$core$set_QMARK_$$($coll$jscomp$735_in$$jscomp$5_in$__$1$$))return $APP.$cljs$core$with_meta$$($coll$jscomp$735_in$$jscomp$5_in$__$1$$,null);$coll$jscomp$735_in$$jscomp$5_in$__$1$$=$APP.$cljs$core$seq$$($coll$jscomp$735_in$$jscomp$5_in$__$1$$);if($coll$jscomp$735_in$$jscomp$5_in$__$1$$==null)return $APP.$cljs$core$PersistentHashSet$EMPTY$$;if($coll$jscomp$735_in$$jscomp$5_in$__$1$$ instanceof $APP.$cljs$core$IndexedSeq$$&&
$coll$jscomp$735_in$$jscomp$5_in$__$1$$.i===0)return $APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$($coll$jscomp$735_in$$jscomp$5_in$__$1$$.$arr$);for(var $G__29119_out$jscomp$13$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentHashSet$EMPTY$$);;)if($coll$jscomp$735_in$$jscomp$5_in$__$1$$!=null){var $G__29118$$=$APP.$cljs$core$next$$($coll$jscomp$735_in$$jscomp$5_in$__$1$$);$G__29119_out$jscomp$13$$=$cljs$core$_conj_BANG_$$($G__29119_out$jscomp$13$$,$cljs$core$_first$$($coll$jscomp$735_in$$jscomp$5_in$__$1$$));
$coll$jscomp$735_in$$jscomp$5_in$__$1$$=$G__29118$$}else return $APP.$cljs$core$_persistent_BANG_$$($G__29119_out$jscomp$13$$)};
$cljs$core$sorted_set$$=function($var_args$jscomp$249$$){for(var $args__5755__auto__$jscomp$10$$=[],$len__5749__auto___29129$$=arguments.length,$i__5750__auto___29130$$=0;;)if($i__5750__auto___29130$$<$len__5749__auto___29129$$)$args__5755__auto__$jscomp$10$$.push(arguments[$i__5750__auto___29130$$]),$i__5750__auto___29130$$+=1;else break;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,$cljs$core$PersistentTreeSet$EMPTY$$,0<$args__5755__auto__$jscomp$10$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$10$$.slice(0),0,null):null)};
$cljs$core$sorted_set_by$$=function($var_args$jscomp$250$$){for(var $args__5755__auto__$jscomp$11_keys$jscomp$inline_2885$$=[],$len__5749__auto___29133$$=arguments.length,$i__5750__auto___29134$$=0;;)if($i__5750__auto___29134$$<$len__5749__auto___29133$$)$args__5755__auto__$jscomp$11_keys$jscomp$inline_2885$$.push(arguments[$i__5750__auto___29134$$]),$i__5750__auto___29134$$+=1;else break;$args__5755__auto__$jscomp$11_keys$jscomp$inline_2885$$=1<$args__5755__auto__$jscomp$11_keys$jscomp$inline_2885$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$11_keys$jscomp$inline_2885$$.slice(1),0,null):null;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,new $cljs$core$PersistentTreeSet$$(null,$APP.$cljs$core$sorted_map_by$$(arguments[0]),0),$args__5755__auto__$jscomp$11_keys$jscomp$inline_2885$$)};
$APP.$cljs$core$replace$cljs$0core$0IFn$0_invoke$0arity$02$$=function($smap$jscomp$1$$,$coll$jscomp$736$$){if($APP.$cljs$core$vector_QMARK_$$($coll$jscomp$736$$)){var $n$jscomp$140$$=$APP.$cljs$core$count$$($coll$jscomp$736$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($v$jscomp$70$$,$i$jscomp$264$$){var $temp__5823__auto__$jscomp$14$$=$cljs$core$find$$($smap$jscomp$1$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$70$$,$i$jscomp$264$$));return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$14$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($v$jscomp$70$$,$i$jscomp$264$$,$APP.$cljs$core$second$$($temp__5823__auto__$jscomp$14$$)):$v$jscomp$70$$},$coll$jscomp$736$$,$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($n$jscomp$140$$,$cljs$core$iterate$$($APP.$cljs$core$inc$$,0)))}return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__23896_SHARP_$$){var $temp__5823__auto__$jscomp$15$$=$cljs$core$find$$($smap$jscomp$1$$,$p1__23896_SHARP_$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$15$$)?
$APP.$cljs$core$second$$($temp__5823__auto__$jscomp$15$$):$p1__23896_SHARP_$$},$coll$jscomp$736$$)};
$APP.$cljs$core$butlast$$=function($G__29153_s$jscomp$101_s__$1$jscomp$6$$){for(var $G__29152_ret$jscomp$42$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;)if($APP.$cljs$core$next$$($G__29153_s$jscomp$101_s__$1$jscomp$6$$))$G__29152_ret$jscomp$42$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__29152_ret$jscomp$42$$,$APP.$cljs$core$first$$($G__29153_s$jscomp$101_s__$1$jscomp$6$$)),$G__29153_s$jscomp$101_s__$1$jscomp$6$$=$APP.$cljs$core$next$$($G__29153_s$jscomp$101_s__$1$jscomp$6$$);else return $APP.$cljs$core$seq$$($G__29152_ret$jscomp$42$$)};
$APP.$cljs$core$name$$=function($x$jscomp$568$$){if($x$jscomp$568$$!=null&&($x$jscomp$568$$.$cljs$lang$protocol_mask$partition1$$&4096||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$568$$.$cljs$core$INamed$$))return $x$jscomp$568$$.$cljs$core$INamed$_name$arity$1$(null);if(typeof $x$jscomp$568$$==="string")return $x$jscomp$568$$;throw Error(["Doesn't support name: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$568$$)].join(""));};
$APP.$cljs$core$zipmap$$=function($G__29156_keys$jscomp$18_ks$jscomp$16$$,$G__29157_vals$jscomp$7_vs$jscomp$1$$){var $G__29155_map$jscomp$13$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$G__29156_keys$jscomp$18_ks$jscomp$16$$=$APP.$cljs$core$seq$$($G__29156_keys$jscomp$18_ks$jscomp$16$$);for($G__29157_vals$jscomp$7_vs$jscomp$1$$=$APP.$cljs$core$seq$$($G__29157_vals$jscomp$7_vs$jscomp$1$$);;)if($G__29156_keys$jscomp$18_ks$jscomp$16$$&&$G__29157_vals$jscomp$7_vs$jscomp$1$$)$G__29155_map$jscomp$13$$=
$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($G__29155_map$jscomp$13$$,$APP.$cljs$core$first$$($G__29156_keys$jscomp$18_ks$jscomp$16$$),$APP.$cljs$core$first$$($G__29157_vals$jscomp$7_vs$jscomp$1$$)),$G__29156_keys$jscomp$18_ks$jscomp$16$$=$APP.$cljs$core$next$$($G__29156_keys$jscomp$18_ks$jscomp$16$$),$G__29157_vals$jscomp$7_vs$jscomp$1$$=$APP.$cljs$core$next$$($G__29157_vals$jscomp$7_vs$jscomp$1$$);else return $APP.$cljs$core$_persistent_BANG_$$($G__29155_map$jscomp$13$$)};
$cljs$core$ArrayList$$=function(){this.$arr$=[]};
$APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$=function($pred$jscomp$12$$,$coll$jscomp$746$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $JSCompiler_temp$jscomp$236_temp__5825__auto__$jscomp$22$$=$APP.$cljs$core$seq$$($coll$jscomp$746$$);if($JSCompiler_temp$jscomp$236_temp__5825__auto__$jscomp$22$$){var $G__23930$jscomp$inline_2896_JSCompiler_inline_result$jscomp$237$$=$APP.$cljs$core$first$$($JSCompiler_temp$jscomp$236_temp__5825__auto__$jscomp$22$$);$G__23930$jscomp$inline_2896_JSCompiler_inline_result$jscomp$237$$=
$pred$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($G__23930$jscomp$inline_2896_JSCompiler_inline_result$jscomp$237$$):$pred$jscomp$12$$($G__23930$jscomp$inline_2896_JSCompiler_inline_result$jscomp$237$$);$JSCompiler_temp$jscomp$236_temp__5825__auto__$jscomp$22$$=$APP.$cljs$core$truth_$$($G__23930$jscomp$inline_2896_JSCompiler_inline_result$jscomp$237$$)?$APP.$cljs$core$cons$$($APP.$cljs$core$first$$($JSCompiler_temp$jscomp$236_temp__5825__auto__$jscomp$22$$),
$APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$($pred$jscomp$12$$,$APP.$cljs$core$rest$$($JSCompiler_temp$jscomp$236_temp__5825__auto__$jscomp$22$$))):null}else $JSCompiler_temp$jscomp$236_temp__5825__auto__$jscomp$22$$=null;return $JSCompiler_temp$jscomp$236_temp__5825__auto__$jscomp$22$$},null,null)};
$cljs$core$IntegerRangeChunk$$=function($start$jscomp$138$$,$step$jscomp$11$$,$count$jscomp$51$$){this.start=$start$jscomp$138$$;this.step=$step$jscomp$11$$;this.count=$count$jscomp$51$$;this.$cljs$lang$protocol_mask$partition0$$=82;this.$cljs$lang$protocol_mask$partition1$$=0};$cljs$core$RangeIterator$$=function($i$jscomp$267$$,$end$jscomp$29$$,$step$jscomp$13$$){this.i=$i$jscomp$267$$;this.end=$end$jscomp$29$$;this.step=$step$jscomp$13$$};
$cljs$core$IntegerRange$$=function($meta$jscomp$61$$,$start$jscomp$141$$,$end$jscomp$32$$,$step$jscomp$16$$,$cnt$jscomp$29$$,$__hash$jscomp$45$$){this.$meta$=$meta$jscomp$61$$;this.start=$start$jscomp$141$$;this.end=$end$jscomp$32$$;this.step=$step$jscomp$16$$;this.$cnt$=$cnt$jscomp$29$$;this.$__hash$=$__hash$jscomp$45$$;this.$cljs$lang$protocol_mask$partition0$$=32375006;this.$cljs$lang$protocol_mask$partition1$$=402944};
$cljs$core$Range$$=function($meta$jscomp$63$$,$start$jscomp$143$$,$end$jscomp$34$$,$step$jscomp$18$$,$chunk$jscomp$12$$,$chunk_next$$,$__hash$jscomp$47$$){this.$meta$=$meta$jscomp$63$$;this.start=$start$jscomp$143$$;this.end=$end$jscomp$34$$;this.step=$step$jscomp$18$$;this.$chunk$=$chunk$jscomp$12$$;this.$chunk_next$=$chunk_next$$;this.$__hash$=$__hash$jscomp$47$$;this.$cljs$lang$protocol_mask$partition1$$=140800;this.$cljs$lang$protocol_mask$partition0$$=32374988};
$JSCompiler_StaticMethods_forceChunk$$=function($JSCompiler_StaticMethods_forceChunk$self$$){if($JSCompiler_StaticMethods_forceChunk$self$$.$chunk$==null){var $arr$jscomp$134$$=[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];a:{var $n$jscomp$inline_2900_n__$1$jscomp$inline_2902_val$jscomp$103$$=0;for(var $G__29256$jscomp$inline_2904_val$jscomp$inline_2901_val__$1$jscomp$inline_2903$$=
$JSCompiler_StaticMethods_forceChunk$self$$.start;;){if($n$jscomp$inline_2900_n__$1$jscomp$inline_2902_val$jscomp$103$$<32)if($arr$jscomp$134$$[$n$jscomp$inline_2900_n__$1$jscomp$inline_2902_val$jscomp$103$$]=$G__29256$jscomp$inline_2904_val$jscomp$inline_2901_val__$1$jscomp$inline_2903$$,$n$jscomp$inline_2900_n__$1$jscomp$inline_2902_val$jscomp$103$$+=1,$G__29256$jscomp$inline_2904_val$jscomp$inline_2901_val__$1$jscomp$inline_2903$$+=$JSCompiler_StaticMethods_forceChunk$self$$.step,$JSCompiler_StaticMethods_forceChunk$self$$.step>
0?$G__29256$jscomp$inline_2904_val$jscomp$inline_2901_val__$1$jscomp$inline_2903$$<$JSCompiler_StaticMethods_forceChunk$self$$.end:$G__29256$jscomp$inline_2904_val$jscomp$inline_2901_val__$1$jscomp$inline_2903$$>$JSCompiler_StaticMethods_forceChunk$self$$.end)continue;else{$n$jscomp$inline_2900_n__$1$jscomp$inline_2902_val$jscomp$103$$=$JSCompiler_StaticMethods_forceChunk$self$$.$chunk$=new $cljs$core$ArrayChunk$$($arr$jscomp$134$$,0,$n$jscomp$inline_2900_n__$1$jscomp$inline_2902_val$jscomp$103$$);
break a}else{$n$jscomp$inline_2900_n__$1$jscomp$inline_2902_val$jscomp$103$$=$G__29256$jscomp$inline_2904_val$jscomp$inline_2901_val__$1$jscomp$inline_2903$$;break a}break}$n$jscomp$inline_2900_n__$1$jscomp$inline_2902_val$jscomp$103$$=void 0}$JSCompiler_StaticMethods_forceChunk$self$$.$chunk$==null&&($JSCompiler_StaticMethods_forceChunk$self$$.$chunk$=new $cljs$core$ArrayChunk$$($arr$jscomp$134$$,0,32),($JSCompiler_StaticMethods_forceChunk$self$$.step>0?$n$jscomp$inline_2900_n__$1$jscomp$inline_2902_val$jscomp$103$$<
$JSCompiler_StaticMethods_forceChunk$self$$.end:$n$jscomp$inline_2900_n__$1$jscomp$inline_2902_val$jscomp$103$$>$JSCompiler_StaticMethods_forceChunk$self$$.end)&&($JSCompiler_StaticMethods_forceChunk$self$$.$chunk_next$=new $cljs$core$Range$$(null,$n$jscomp$inline_2900_n__$1$jscomp$inline_2902_val$jscomp$103$$,$JSCompiler_StaticMethods_forceChunk$self$$.end,$JSCompiler_StaticMethods_forceChunk$self$$.step,null,null,null)))}};
$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$=function($end$jscomp$36$$){return $APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$03$$(0,$end$jscomp$36$$,1)};$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$=function($start$jscomp$145$$,$end$jscomp$37$$){return $APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$03$$($start$jscomp$145$$,$end$jscomp$37$$,1)};
$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$03$$=function($start$jscomp$146$$,$end$jscomp$38$$,$step$jscomp$20$$){return $step$jscomp$20$$>0?$end$jscomp$38$$<=$start$jscomp$146$$?$APP.$cljs$core$List$EMPTY$$:$APP.$cljs$core$integer_QMARK_$$($start$jscomp$146$$)&&$APP.$cljs$core$integer_QMARK_$$($end$jscomp$38$$)&&$APP.$cljs$core$integer_QMARK_$$($step$jscomp$20$$)?new $cljs$core$IntegerRange$$(null,$start$jscomp$146$$,$end$jscomp$38$$,$step$jscomp$20$$,Math.ceil(($end$jscomp$38$$-$start$jscomp$146$$)/
$step$jscomp$20$$),null):new $cljs$core$Range$$(null,$start$jscomp$146$$,$end$jscomp$38$$,$step$jscomp$20$$,null,null,null):$step$jscomp$20$$<0?$end$jscomp$38$$>=$start$jscomp$146$$?$APP.$cljs$core$List$EMPTY$$:$APP.$cljs$core$integer_QMARK_$$($start$jscomp$146$$)&&$APP.$cljs$core$integer_QMARK_$$($end$jscomp$38$$)&&$APP.$cljs$core$integer_QMARK_$$($step$jscomp$20$$)?new $cljs$core$IntegerRange$$(null,$start$jscomp$146$$,$end$jscomp$38$$,$step$jscomp$20$$,Math.ceil(($end$jscomp$38$$-$start$jscomp$146$$)/
$step$jscomp$20$$),null):new $cljs$core$Range$$(null,$start$jscomp$146$$,$end$jscomp$38$$,$step$jscomp$20$$,null,null,null):$end$jscomp$38$$===$start$jscomp$146$$?$APP.$cljs$core$List$EMPTY$$:$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$($start$jscomp$146$$)};
$APP.$cljs$core$take_nth$cljs$0core$0IFn$0_invoke$0arity$02$$=function($n$jscomp$156$$,$coll$jscomp$763$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $temp__5825__auto__$jscomp$27$$=$APP.$cljs$core$seq$$($coll$jscomp$763$$);return $temp__5825__auto__$jscomp$27$$?$APP.$cljs$core$cons$$($APP.$cljs$core$first$$($temp__5825__auto__$jscomp$27$$),$APP.$cljs$core$take_nth$cljs$0core$0IFn$0_invoke$0arity$02$$($n$jscomp$156$$,$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($n$jscomp$156$$,
$temp__5825__auto__$jscomp$27$$))):null},null,null)};$APP.$cljs$core$split_with$$=function($pred$jscomp$13$$,$coll$jscomp$764$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$($pred$jscomp$13$$,$coll$jscomp$764$$),$APP.$cljs$core$drop_while$cljs$0core$0IFn$0_invoke$0arity$02$$($pred$jscomp$13$$,$coll$jscomp$764$$)],null)};
$APP.$cljs$core$frequencies$$=function($coll$jscomp$766$$){return $APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($counts$$,$x$jscomp$588$$){return $APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($counts$$,$x$jscomp$588$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($counts$$,$x$jscomp$588$$,0)+1)},$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$coll$jscomp$766$$))};
$cljs$core$reductions$cljs$0core$0IFn$0_invoke$0arity$03$$=function($f$jscomp$296$$,$init$jscomp$45$$,$coll$jscomp$768$$){return $cljs$core$reduced_QMARK_$$($init$jscomp$45$$)?new $APP.$cljs$core$List$$(null,$APP.$cljs$core$_deref$$($init$jscomp$45$$),null,1,null):$APP.$cljs$core$cons$$($init$jscomp$45$$,new $APP.$cljs$core$LazySeq$$(null,function(){var $JSCompiler_temp$jscomp$239_temp__5825__auto__$jscomp$29$$=$APP.$cljs$core$seq$$($coll$jscomp$768$$);if($JSCompiler_temp$jscomp$239_temp__5825__auto__$jscomp$29$$){var $JSCompiler_temp_const$jscomp$240$$=
$cljs$core$reductions$cljs$0core$0IFn$0_invoke$0arity$03$$;var $G__23963$jscomp$inline_2906_JSCompiler_inline_result$jscomp$241$$=$APP.$cljs$core$first$$($JSCompiler_temp$jscomp$239_temp__5825__auto__$jscomp$29$$);$G__23963$jscomp$inline_2906_JSCompiler_inline_result$jscomp$241$$=$f$jscomp$296$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$296$$.$cljs$core$IFn$_invoke$arity$2$($init$jscomp$45$$,$G__23963$jscomp$inline_2906_JSCompiler_inline_result$jscomp$241$$):$f$jscomp$296$$($init$jscomp$45$$,$G__23963$jscomp$inline_2906_JSCompiler_inline_result$jscomp$241$$);
$JSCompiler_temp$jscomp$239_temp__5825__auto__$jscomp$29$$=$JSCompiler_temp_const$jscomp$240$$($f$jscomp$296$$,$G__23963$jscomp$inline_2906_JSCompiler_inline_result$jscomp$241$$,$APP.$cljs$core$rest$$($JSCompiler_temp$jscomp$239_temp__5825__auto__$jscomp$29$$))}else $JSCompiler_temp$jscomp$239_temp__5825__auto__$jscomp$29$$=null;return $JSCompiler_temp$jscomp$239_temp__5825__auto__$jscomp$29$$},null,null))};
$APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$298$$,$g$jscomp$63$$){return function(){function $G__29324__3$$($x$jscomp$598$$,$y$jscomp$249$$,$z$jscomp$91$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$f$jscomp$298$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$298$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$598$$,$y$jscomp$249$$,$z$jscomp$91$$):$f$jscomp$298$$($x$jscomp$598$$,$y$jscomp$249$$,$z$jscomp$91$$),$g$jscomp$63$$.$cljs$core$IFn$_invoke$arity$3$?
$g$jscomp$63$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$598$$,$y$jscomp$249$$,$z$jscomp$91$$):$g$jscomp$63$$($x$jscomp$598$$,$y$jscomp$249$$,$z$jscomp$91$$)],null)}function $G__29324__2$$($x$jscomp$597$$,$y$jscomp$248$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$f$jscomp$298$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$298$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$597$$,$y$jscomp$248$$):$f$jscomp$298$$($x$jscomp$597$$,$y$jscomp$248$$),
$g$jscomp$63$$.$cljs$core$IFn$_invoke$arity$2$?$g$jscomp$63$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$597$$,$y$jscomp$248$$):$g$jscomp$63$$($x$jscomp$597$$,$y$jscomp$248$$)],null)}function $G__29324__1$$($x$jscomp$596$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$f$jscomp$298$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$298$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$596$$):$f$jscomp$298$$($x$jscomp$596$$),$g$jscomp$63$$.$cljs$core$IFn$_invoke$arity$1$?
$g$jscomp$63$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$596$$):$g$jscomp$63$$($x$jscomp$596$$)],null)}function $G__29324__0$$(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$f$jscomp$298$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$298$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$298$$(),$g$jscomp$63$$.$cljs$core$IFn$_invoke$arity$0$?$g$jscomp$63$$.$cljs$core$IFn$_invoke$arity$0$():$g$jscomp$63$$()],null)}var $G__29324$$=null,$G__29324__4$$=
function(){function $G__29328$$($x$jscomp$600$$,$y$jscomp$251$$,$z$jscomp$93$$,$var_args$jscomp$268$$){var $G__29330__i_args$jscomp$96$$=null;if(arguments.length>3){$G__29330__i_args$jscomp$96$$=0;for(var $G__29330__a$$=Array(arguments.length-3);$G__29330__i_args$jscomp$96$$<$G__29330__a$$.length;)$G__29330__a$$[$G__29330__i_args$jscomp$96$$]=arguments[$G__29330__i_args$jscomp$96$$+3],++$G__29330__i_args$jscomp$96$$;$G__29330__i_args$jscomp$96$$=new $APP.$cljs$core$IndexedSeq$$($G__29330__a$$,0,null)}return $G__29328__delegate$$.call(this,
$x$jscomp$600$$,$y$jscomp$251$$,$z$jscomp$93$$,$G__29330__i_args$jscomp$96$$)}function $G__29328__delegate$$($x$jscomp$599$$,$y$jscomp$250$$,$z$jscomp$92$$,$args$jscomp$95$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($f$jscomp$298$$,$x$jscomp$599$$,$y$jscomp$250$$,$z$jscomp$92$$,$args$jscomp$95$$),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($g$jscomp$63$$,$x$jscomp$599$$,
$y$jscomp$250$$,$z$jscomp$92$$,$args$jscomp$95$$)],null)}$G__29328$$.$cljs$lang$maxFixedArity$=3;$G__29328$$.$cljs$lang$applyTo$=function($arglist__29331_args$jscomp$97$$){var $x$jscomp$601$$=$APP.$cljs$core$first$$($arglist__29331_args$jscomp$97$$);$arglist__29331_args$jscomp$97$$=$APP.$cljs$core$next$$($arglist__29331_args$jscomp$97$$);var $y$jscomp$252$$=$APP.$cljs$core$first$$($arglist__29331_args$jscomp$97$$);$arglist__29331_args$jscomp$97$$=$APP.$cljs$core$next$$($arglist__29331_args$jscomp$97$$);
var $z$jscomp$94$$=$APP.$cljs$core$first$$($arglist__29331_args$jscomp$97$$);$arglist__29331_args$jscomp$97$$=$APP.$cljs$core$rest$$($arglist__29331_args$jscomp$97$$);return $G__29328__delegate$$($x$jscomp$601$$,$y$jscomp$252$$,$z$jscomp$94$$,$arglist__29331_args$jscomp$97$$)};$G__29328$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__29328__delegate$$;return $G__29328$$}();$G__29324$$=function($x$jscomp$602$$,$y$jscomp$253$$,$z$jscomp$95$$,$var_args$jscomp$269$$){switch(arguments.length){case 0:return $G__29324__0$$.call(this);
case 1:return $G__29324__1$$.call(this,$x$jscomp$602$$);case 2:return $G__29324__2$$.call(this,$x$jscomp$602$$,$y$jscomp$253$$);case 3:return $G__29324__3$$.call(this,$x$jscomp$602$$,$y$jscomp$253$$,$z$jscomp$95$$);default:var $G__29332_G__29333__i$$=null;if(arguments.length>3){$G__29332_G__29333__i$$=0;for(var $G__29333__a$$=Array(arguments.length-3);$G__29332_G__29333__i$$<$G__29333__a$$.length;)$G__29333__a$$[$G__29332_G__29333__i$$]=arguments[$G__29332_G__29333__i$$+3],++$G__29332_G__29333__i$$;
$G__29332_G__29333__i$$=new $APP.$cljs$core$IndexedSeq$$($G__29333__a$$,0,null)}return $G__29324__4$$.$cljs$core$IFn$_invoke$arity$variadic$($x$jscomp$602$$,$y$jscomp$253$$,$z$jscomp$95$$,$G__29332_G__29333__i$$)}throw Error("Invalid arity: "+arguments.length);};$G__29324$$.$cljs$lang$maxFixedArity$=3;$G__29324$$.$cljs$lang$applyTo$=$G__29324__4$$.$cljs$lang$applyTo$;$G__29324$$.$cljs$core$IFn$_invoke$arity$0$=$G__29324__0$$;$G__29324$$.$cljs$core$IFn$_invoke$arity$1$=$G__29324__1$$;$G__29324$$.$cljs$core$IFn$_invoke$arity$2$=
$G__29324__2$$;$G__29324$$.$cljs$core$IFn$_invoke$arity$3$=$G__29324__3$$;$G__29324$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__29324__4$$.$cljs$core$IFn$_invoke$arity$variadic$;return $G__29324$$}()};
$cljs$core$dorun$cljs$0core$0IFn$0_invoke$0arity$01$$=function($coll$jscomp$769_temp__5825__auto__$jscomp$30$$){for(;;)if($coll$jscomp$769_temp__5825__auto__$jscomp$30$$=$APP.$cljs$core$seq$$($coll$jscomp$769_temp__5825__auto__$jscomp$30$$))$coll$jscomp$769_temp__5825__auto__$jscomp$30$$=$APP.$cljs$core$next$$($coll$jscomp$769_temp__5825__auto__$jscomp$30$$);else return null};
$APP.$cljs$core$doall$cljs$0core$0IFn$0_invoke$0arity$01$$=function($coll$jscomp$771$$){$cljs$core$dorun$cljs$0core$0IFn$0_invoke$0arity$01$$($coll$jscomp$771$$);return $coll$jscomp$771$$};$APP.$cljs$core$regexp_QMARK_$$=function($x$jscomp$617$$){return $x$jscomp$617$$ instanceof RegExp};
$APP.$cljs$core$re_matches$$=function($matches$jscomp$1_re$jscomp$2$$,$s$jscomp$118$$){if(typeof $s$jscomp$118$$==="string")return $matches$jscomp$1_re$jscomp$2$$=$matches$jscomp$1_re$jscomp$2$$.exec($s$jscomp$118$$),$matches$jscomp$1_re$jscomp$2$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($matches$jscomp$1_re$jscomp$2$$[0],$s$jscomp$118$$)?$matches$jscomp$1_re$jscomp$2$$.length===1?$matches$jscomp$1_re$jscomp$2$$[0]:$APP.$cljs$core$vec$$($matches$jscomp$1_re$jscomp$2$$):null;
throw new TypeError("re-matches must match against a string.");};
$APP.$cljs$core$re_find$$=function($matches$jscomp$2_re$jscomp$3$$,$s$jscomp$119$$){if(typeof $s$jscomp$119$$==="string")return $matches$jscomp$2_re$jscomp$3$$=$matches$jscomp$2_re$jscomp$3$$.exec($s$jscomp$119$$),$matches$jscomp$2_re$jscomp$3$$==null?null:$matches$jscomp$2_re$jscomp$3$$.length===1?$matches$jscomp$2_re$jscomp$3$$[0]:$APP.$cljs$core$vec$$($matches$jscomp$2_re$jscomp$3$$);throw new TypeError("re-find must match against a string.");};
$APP.$cljs$core$re_seq$$=function($re$jscomp$5$$,$s$jscomp$121$$){if(typeof $s$jscomp$121$$==="string")return $cljs$core$re_seq_STAR_$$($re$jscomp$5$$,$s$jscomp$121$$);throw new TypeError("re-seq must match against a string.");};
$APP.$cljs$core$re_pattern$$=function($pattern$jscomp$5_s$jscomp$122$$){if($pattern$jscomp$5_s$jscomp$122$$ instanceof RegExp)return $pattern$jscomp$5_s$jscomp$122$$;var $flags$jscomp$6_vec__23986$$=$APP.$cljs$core$re_find$$(/^\(\?([idmsux]*)\)/,$pattern$jscomp$5_s$jscomp$122$$),$prefix$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flags$jscomp$6_vec__23986$$,0,null);$flags$jscomp$6_vec__23986$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flags$jscomp$6_vec__23986$$,
1,null);$pattern$jscomp$5_s$jscomp$122$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($pattern$jscomp$5_s$jscomp$122$$,$prefix$jscomp$5$$==null?0:$prefix$jscomp$5$$.length);return new RegExp($pattern$jscomp$5_s$jscomp$122$$,$APP.$cljs$core$truth_$$($flags$jscomp$6_vec__23986$$)?$flags$jscomp$6_vec__23986$$:"")};
$APP.$cljs$core$pr_sequential_writer$$=function($writer$jscomp$9$$,$print_one$$,$G__23995_29392_G__29396_begin$jscomp$6$$,$sep$jscomp$2$$,$end$jscomp$39$$,$opts$jscomp$2$$,$G__23996_29393_coll$jscomp$773$$){var $_STAR_print_level_STAR__orig_val__23989$$=$cljs$core$_STAR_print_level_STAR_$$;$cljs$core$_STAR_print_level_STAR_$$=$cljs$core$_STAR_print_level_STAR_$$==null?null:$cljs$core$_STAR_print_level_STAR_$$-1;try{if($cljs$core$_STAR_print_level_STAR_$$!=null&&$cljs$core$_STAR_print_level_STAR_$$<
0)return $APP.$cljs$core$_write$$($writer$jscomp$9$$,"#");$APP.$cljs$core$_write$$($writer$jscomp$9$$,$G__23995_29392_G__29396_begin$jscomp$6$$);if($cljs$cst$4$print_length$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$2$$)===0)$APP.$cljs$core$seq$$($G__23996_29393_coll$jscomp$773$$)&&$APP.$cljs$core$_write$$($writer$jscomp$9$$,function(){var $or__5025__auto__$jscomp$42$$=$cljs$cst$105$more_marker$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$2$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$42$$)?
$or__5025__auto__$jscomp$42$$:"..."}());else{if($APP.$cljs$core$seq$$($G__23996_29393_coll$jscomp$773$$)){var $G__23991_29381$$=$APP.$cljs$core$first$$($G__23996_29393_coll$jscomp$773$$);$print_one$$.$cljs$core$IFn$_invoke$arity$3$?$print_one$$.$cljs$core$IFn$_invoke$arity$3$($G__23991_29381$$,$writer$jscomp$9$$,$opts$jscomp$2$$):$print_one$$($G__23991_29381$$,$writer$jscomp$9$$,$opts$jscomp$2$$)}for(var $coll_29389__$1$$=$APP.$cljs$core$next$$($G__23996_29393_coll$jscomp$773$$),$n_29390$$=$cljs$cst$4$print_length$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$2$$)-
1;;)if(!$coll_29389__$1$$||$n_29390$$!=null&&$n_29390$$===0){$APP.$cljs$core$seq$$($coll_29389__$1$$)&&$n_29390$$===0&&($APP.$cljs$core$_write$$($writer$jscomp$9$$,$sep$jscomp$2$$),$APP.$cljs$core$_write$$($writer$jscomp$9$$,function(){var $or__5025__auto__$jscomp$43$$=$cljs$cst$105$more_marker$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$2$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$43$$)?$or__5025__auto__$jscomp$43$$:"..."}()));break}else{$APP.$cljs$core$_write$$($writer$jscomp$9$$,
$sep$jscomp$2$$);var $G__23994_29391$$=$APP.$cljs$core$first$$($coll_29389__$1$$);$G__23995_29392_G__29396_begin$jscomp$6$$=$writer$jscomp$9$$;$G__23996_29393_coll$jscomp$773$$=$opts$jscomp$2$$;$print_one$$.$cljs$core$IFn$_invoke$arity$3$?$print_one$$.$cljs$core$IFn$_invoke$arity$3$($G__23994_29391$$,$G__23995_29392_G__29396_begin$jscomp$6$$,$G__23996_29393_coll$jscomp$773$$):$print_one$$($G__23994_29391$$,$G__23995_29392_G__29396_begin$jscomp$6$$,$G__23996_29393_coll$jscomp$773$$);var $G__29395$$=
$APP.$cljs$core$next$$($coll_29389__$1$$);$G__23995_29392_G__29396_begin$jscomp$6$$=$n_29390$$-1;$coll_29389__$1$$=$G__29395$$;$n_29390$$=$G__23995_29392_G__29396_begin$jscomp$6$$}}return $APP.$cljs$core$_write$$($writer$jscomp$9$$,$end$jscomp$39$$)}finally{$cljs$core$_STAR_print_level_STAR_$$=$_STAR_print_level_STAR__orig_val__23989$$}};
$cljs$core$write_all$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($writer$jscomp$10$$,$c__5548__auto__$jscomp$6_seq__23999_ss$jscomp$5_temp__5825__auto__$jscomp$31$$){$c__5548__auto__$jscomp$6_seq__23999_ss$jscomp$5_temp__5825__auto__$jscomp$31$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$6_seq__23999_ss$jscomp$5_temp__5825__auto__$jscomp$31$$);for(var $G__29411_chunk__24000_seq__23999__$1$$=null,$G__29410_count__24001$$=0,$i__24002$$=0;;)if($i__24002$$<$G__29410_count__24001$$){var $G__29412_s$jscomp$123$$=
$G__29411_chunk__24000_seq__23999__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__24002$$);$APP.$cljs$core$_write$$($writer$jscomp$10$$,$G__29412_s$jscomp$123$$);$i__24002$$+=1}else if($c__5548__auto__$jscomp$6_seq__23999_ss$jscomp$5_temp__5825__auto__$jscomp$31$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$6_seq__23999_ss$jscomp$5_temp__5825__auto__$jscomp$31$$))$G__29411_chunk__24000_seq__23999__$1$$=$c__5548__auto__$jscomp$6_seq__23999_ss$jscomp$5_temp__5825__auto__$jscomp$31$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__29411_chunk__24000_seq__23999__$1$$)?
($c__5548__auto__$jscomp$6_seq__23999_ss$jscomp$5_temp__5825__auto__$jscomp$31$$=$APP.$cljs$core$_chunked_first$$($G__29411_chunk__24000_seq__23999__$1$$),$G__29410_count__24001$$=$APP.$cljs$core$_chunked_rest$$($G__29411_chunk__24000_seq__23999__$1$$),$G__29411_chunk__24000_seq__23999__$1$$=$c__5548__auto__$jscomp$6_seq__23999_ss$jscomp$5_temp__5825__auto__$jscomp$31$$,$G__29412_s$jscomp$123$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$6_seq__23999_ss$jscomp$5_temp__5825__auto__$jscomp$31$$),
$c__5548__auto__$jscomp$6_seq__23999_ss$jscomp$5_temp__5825__auto__$jscomp$31$$=$G__29410_count__24001$$,$G__29410_count__24001$$=$G__29412_s$jscomp$123$$):($G__29412_s$jscomp$123$$=$APP.$cljs$core$first$$($G__29411_chunk__24000_seq__23999__$1$$),$APP.$cljs$core$_write$$($writer$jscomp$10$$,$G__29412_s$jscomp$123$$),$c__5548__auto__$jscomp$6_seq__23999_ss$jscomp$5_temp__5825__auto__$jscomp$31$$=$APP.$cljs$core$next$$($G__29411_chunk__24000_seq__23999__$1$$),$G__29411_chunk__24000_seq__23999__$1$$=
null,$G__29410_count__24001$$=0),$i__24002$$=0;else return null};$cljs$core$string_print$$=function($x$jscomp$618$$){if($APP.$cljs$core$_STAR_print_fn_STAR_$$==null)throw Error("No *print-fn* fn set for evaluation environment");$APP.$cljs$core$_STAR_print_fn_STAR_$$.call(null,$x$jscomp$618$$);return null};
$cljs$core$quote_string$$=function($s$jscomp$124$$){return['"',$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$124$$.replace(RegExp('[\\\\"\b\f\n\r\t]',"g"),function($match$jscomp$7$$){return $cljs$core$char_escapes$$[$match$jscomp$7$$]})),'"'].join("")};
$cljs$core$print_meta_QMARK_$$=function($and__5023__auto__$jscomp$28_and__5023__auto____$1$jscomp$14_opts$jscomp$3$$,$obj$jscomp$96$$){return($and__5023__auto__$jscomp$28_and__5023__auto____$1$jscomp$14_opts$jscomp$3$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$28_and__5023__auto____$1$jscomp$14_opts$jscomp$3$$,$cljs$cst$2$meta$$)))?($and__5023__auto__$jscomp$28_and__5023__auto____$1$jscomp$14_opts$jscomp$3$$=$obj$jscomp$96$$!=null?
$obj$jscomp$96$$.$cljs$lang$protocol_mask$partition0$$&131072||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$obj$jscomp$96$$.$cljs$core$IMeta$$?!0:!1:!1)?$APP.$cljs$core$meta$$($obj$jscomp$96$$)!=null:$and__5023__auto__$jscomp$28_and__5023__auto____$1$jscomp$14_opts$jscomp$3$$:$and__5023__auto__$jscomp$28_and__5023__auto____$1$jscomp$14_opts$jscomp$3$$};
$cljs$core$pr_writer_impl$$=function($obj$jscomp$97$$,$writer$jscomp$11$$,$name__$1$jscomp$1_normalize_opts$jscomp$4$$){if($obj$jscomp$97$$==null)return $APP.$cljs$core$_write$$($writer$jscomp$11$$,"nil");if($cljs$core$print_meta_QMARK_$$($name__$1$jscomp$1_normalize_opts$jscomp$4$$,$obj$jscomp$97$$)){$APP.$cljs$core$_write$$($writer$jscomp$11$$,"^");var $G__24006_29424_G__24010$$=$APP.$cljs$core$meta$$($obj$jscomp$97$$);$APP.$cljs$core$pr_writer$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$core$pr_writer$$.$cljs$core$IFn$_invoke$arity$3$($G__24006_29424_G__24010$$,
$writer$jscomp$11$$,$name__$1$jscomp$1_normalize_opts$jscomp$4$$):$APP.$cljs$core$pr_writer$$($G__24006_29424_G__24010$$,$writer$jscomp$11$$,$name__$1$jscomp$1_normalize_opts$jscomp$4$$);$APP.$cljs$core$_write$$($writer$jscomp$11$$," ")}if($obj$jscomp$97$$.$cljs$lang$type$)return $obj$jscomp$97$$.$cljs$lang$ctorPrWriter$($obj$jscomp$97$$,$writer$jscomp$11$$,$name__$1$jscomp$1_normalize_opts$jscomp$4$$);if($obj$jscomp$97$$!=null?$obj$jscomp$97$$.$cljs$lang$protocol_mask$partition0$$&2147483648||$APP.$cljs$core$PROTOCOL_SENTINEL$$===
$obj$jscomp$97$$.$cljs$core$IPrintWithWriter$$||($obj$jscomp$97$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IPrintWithWriter$$,$obj$jscomp$97$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IPrintWithWriter$$,$obj$jscomp$97$$))return $APP.$cljs$core$_pr_writer$$($obj$jscomp$97$$,$writer$jscomp$11$$,$name__$1$jscomp$1_normalize_opts$jscomp$4$$);if($obj$jscomp$97$$===!0||$obj$jscomp$97$$===!1)return $APP.$cljs$core$_write$$($writer$jscomp$11$$,
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$97$$));if(typeof $obj$jscomp$97$$==="number")return $APP.$cljs$core$_write$$($writer$jscomp$11$$,isNaN($obj$jscomp$97$$)?"##NaN":$obj$jscomp$97$$===Number.POSITIVE_INFINITY?"##Inf":$obj$jscomp$97$$===Number.NEGATIVE_INFINITY?"##-Inf":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$97$$));if($APP.$cljs$core$object_QMARK_$$($obj$jscomp$97$$))return $APP.$cljs$core$_write$$($writer$jscomp$11$$,"#js "),$G__24006_29424_G__24010$$=
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($k$jscomp$205$$){return new $APP.$cljs$core$MapEntry$$($APP.$cljs$core$re_matches$$(/[A-Za-z_\*\+\?!\-'][\w\*\+\?!\-']*/,$k$jscomp$205$$)!=null?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$205$$):$k$jscomp$205$$,$obj$jscomp$97$$[$k$jscomp$205$$],null)},$module$contents$goog$object_getKeys$$($obj$jscomp$97$$)),$cljs$core$print_map$$.$cljs$core$IFn$_invoke$arity$4$?$cljs$core$print_map$$.$cljs$core$IFn$_invoke$arity$4$($G__24006_29424_G__24010$$,
$APP.$cljs$core$pr_writer$$,$writer$jscomp$11$$,$name__$1$jscomp$1_normalize_opts$jscomp$4$$):$cljs$core$print_map$$($G__24006_29424_G__24010$$,$APP.$cljs$core$pr_writer$$,$writer$jscomp$11$$,$name__$1$jscomp$1_normalize_opts$jscomp$4$$);if($APP.$cljs$core$array_QMARK_$$($obj$jscomp$97$$))return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$11$$,$APP.$cljs$core$pr_writer$$,"#js ["," ","]",$name__$1$jscomp$1_normalize_opts$jscomp$4$$,$obj$jscomp$97$$);if(typeof $obj$jscomp$97$$==="string")return $APP.$cljs$core$truth_$$($cljs$cst$1$readably$$.$cljs$core$IFn$_invoke$arity$1$($name__$1$jscomp$1_normalize_opts$jscomp$4$$))?
$APP.$cljs$core$_write$$($writer$jscomp$11$$,$cljs$core$quote_string$$($obj$jscomp$97$$)):$APP.$cljs$core$_write$$($writer$jscomp$11$$,$obj$jscomp$97$$);if(typeof $obj$jscomp$97$$==="function"){var $name$jscomp$109$$=$obj$jscomp$97$$.name;$name__$1$jscomp$1_normalize_opts$jscomp$4$$=$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$44$$=$name$jscomp$109$$==null;return $or__5025__auto__$jscomp$44$$?$or__5025__auto__$jscomp$44$$:$goog$string$internal$isEmptyOrWhitespace$$($name$jscomp$109$$)}())?
"Function":$name$jscomp$109$$;return $cljs$core$write_all$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($writer$jscomp$11$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["#object[",$name__$1$jscomp$1_normalize_opts$jscomp$4$$,$APP.$cljs$core$truth_$$(!1)?[' "',$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$97$$),'"'].join(""):"","]"]))}if($obj$jscomp$97$$ instanceof Date)return $name__$1$jscomp$1_normalize_opts$jscomp$4$$=function($n$jscomp$159_ns$jscomp$8$$,$len$jscomp$52$$){for($n$jscomp$159_ns$jscomp$8$$=
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$159_ns$jscomp$8$$);;)if($n$jscomp$159_ns$jscomp$8$$.length<$len$jscomp$52$$)$n$jscomp$159_ns$jscomp$8$$=["0",$n$jscomp$159_ns$jscomp$8$$].join("");else return $n$jscomp$159_ns$jscomp$8$$},$cljs$core$write_all$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($writer$jscomp$11$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(['#inst "',$name__$1$jscomp$1_normalize_opts$jscomp$4$$($obj$jscomp$97$$.getUTCFullYear(),4),"-",$name__$1$jscomp$1_normalize_opts$jscomp$4$$($obj$jscomp$97$$.getUTCMonth()+
1,2),"-",$name__$1$jscomp$1_normalize_opts$jscomp$4$$($obj$jscomp$97$$.getUTCDate(),2),"T",$name__$1$jscomp$1_normalize_opts$jscomp$4$$($obj$jscomp$97$$.getUTCHours(),2),":",$name__$1$jscomp$1_normalize_opts$jscomp$4$$($obj$jscomp$97$$.getUTCMinutes(),2),":",$name__$1$jscomp$1_normalize_opts$jscomp$4$$($obj$jscomp$97$$.getUTCSeconds(),2),".",$name__$1$jscomp$1_normalize_opts$jscomp$4$$($obj$jscomp$97$$.getUTCMilliseconds(),3),"-",'00:00"']));if($APP.$cljs$core$regexp_QMARK_$$($obj$jscomp$97$$))return $cljs$core$write_all$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($writer$jscomp$11$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(['#"',$obj$jscomp$97$$.source,'"']));if($cljs$core$js_symbol_QMARK_$$($obj$jscomp$97$$))return $cljs$core$write_all$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($writer$jscomp$11$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["#object[",$obj$jscomp$97$$.toString(),"]"]));if($APP.$cljs$core$truth_$$(function(){var $G__24015__$1$$=$obj$jscomp$97$$==null?null:$obj$jscomp$97$$.constructor;return $G__24015__$1$$==null?null:
$G__24015__$1$$.$cljs$lang$ctorStr$}()))return $cljs$core$write_all$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($writer$jscomp$11$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["#object[",$obj$jscomp$97$$.constructor.$cljs$lang$ctorStr$.replace(RegExp("/","g"),"."),"]"]));$name$jscomp$109$$=function(){var $G__24016__$1$$=$obj$jscomp$97$$==null?null:$obj$jscomp$97$$.constructor;return $G__24016__$1$$==null?null:$G__24016__$1$$.name}();$name__$1$jscomp$1_normalize_opts$jscomp$4$$=
$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$45$$=$name$jscomp$109$$==null;return $or__5025__auto__$jscomp$45$$?$or__5025__auto__$jscomp$45$$:$goog$string$internal$isEmptyOrWhitespace$$($name$jscomp$109$$)}())?"Object":$name$jscomp$109$$;return $obj$jscomp$97$$.constructor==null?$cljs$core$write_all$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($writer$jscomp$11$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["#object[",$name__$1$jscomp$1_normalize_opts$jscomp$4$$,
"]"])):$cljs$core$write_all$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($writer$jscomp$11$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["#object[",$name__$1$jscomp$1_normalize_opts$jscomp$4$$," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$97$$),"]"]))};
$APP.$cljs$core$pr_writer$$=function($obj$jscomp$98$$,$writer$jscomp$12$$,$G__24019_opts$jscomp$5$$){var $temp__5823__auto__$jscomp$17$$=$cljs$cst$106$alt_impl$$.$cljs$core$IFn$_invoke$arity$1$($G__24019_opts$jscomp$5$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$17$$)?($G__24019_opts$jscomp$5$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__24019_opts$jscomp$5$$,$cljs$cst$107$fallback_impl$$,$cljs$core$pr_writer_impl$$),$temp__5823__auto__$jscomp$17$$.$cljs$core$IFn$_invoke$arity$3$?
$temp__5823__auto__$jscomp$17$$.$cljs$core$IFn$_invoke$arity$3$($obj$jscomp$98$$,$writer$jscomp$12$$,$G__24019_opts$jscomp$5$$):$temp__5823__auto__$jscomp$17$$($obj$jscomp$98$$,$writer$jscomp$12$$,$G__24019_opts$jscomp$5$$)):$cljs$core$pr_writer_impl$$($obj$jscomp$98$$,$writer$jscomp$12$$,$G__24019_opts$jscomp$5$$)};
$cljs$core$pr_sb_with_opts$$=function($c__5548__auto__$jscomp$inline_2920_objs$jscomp$1_seq__24020$jscomp$inline_2913_temp__5825__auto__$jscomp$inline_2918$$,$opts$jscomp$7$$){var $sb$jscomp$7$$=new $APP.$goog$string$StringBuffer$$,$writer$jscomp$14$$=new $cljs$core$StringBufferWriter$$($sb$jscomp$7$$);a:{$APP.$cljs$core$pr_writer$$($APP.$cljs$core$first$$($c__5548__auto__$jscomp$inline_2920_objs$jscomp$1_seq__24020$jscomp$inline_2913_temp__5825__auto__$jscomp$inline_2918$$),$writer$jscomp$14$$,$opts$jscomp$7$$);
$c__5548__auto__$jscomp$inline_2920_objs$jscomp$1_seq__24020$jscomp$inline_2913_temp__5825__auto__$jscomp$inline_2918$$=$APP.$cljs$core$seq$$($APP.$cljs$core$next$$($c__5548__auto__$jscomp$inline_2920_objs$jscomp$1_seq__24020$jscomp$inline_2913_temp__5825__auto__$jscomp$inline_2918$$));for(var $G__29452$jscomp$inline_2922_chunk__24021$jscomp$inline_2914_seq__24020__$1$jscomp$inline_2919$$=null,$G__29451$jscomp$inline_2921_count__24022$jscomp$inline_2915$$=0,$i__24023$jscomp$inline_2916$$=0;;)if($i__24023$jscomp$inline_2916$$<
$G__29451$jscomp$inline_2921_count__24022$jscomp$inline_2915$$){var $G__29453$jscomp$inline_2923_obj$jscomp$inline_2917$$=$G__29452$jscomp$inline_2922_chunk__24021$jscomp$inline_2914_seq__24020__$1$jscomp$inline_2919$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__24023$jscomp$inline_2916$$);$APP.$cljs$core$_write$$($writer$jscomp$14$$," ");$APP.$cljs$core$pr_writer$$($G__29453$jscomp$inline_2923_obj$jscomp$inline_2917$$,$writer$jscomp$14$$,$opts$jscomp$7$$);$i__24023$jscomp$inline_2916$$+=1}else if($c__5548__auto__$jscomp$inline_2920_objs$jscomp$1_seq__24020$jscomp$inline_2913_temp__5825__auto__$jscomp$inline_2918$$=
$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$inline_2920_objs$jscomp$1_seq__24020$jscomp$inline_2913_temp__5825__auto__$jscomp$inline_2918$$))$G__29452$jscomp$inline_2922_chunk__24021$jscomp$inline_2914_seq__24020__$1$jscomp$inline_2919$$=$c__5548__auto__$jscomp$inline_2920_objs$jscomp$1_seq__24020$jscomp$inline_2913_temp__5825__auto__$jscomp$inline_2918$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__29452$jscomp$inline_2922_chunk__24021$jscomp$inline_2914_seq__24020__$1$jscomp$inline_2919$$)?($c__5548__auto__$jscomp$inline_2920_objs$jscomp$1_seq__24020$jscomp$inline_2913_temp__5825__auto__$jscomp$inline_2918$$=
$APP.$cljs$core$_chunked_first$$($G__29452$jscomp$inline_2922_chunk__24021$jscomp$inline_2914_seq__24020__$1$jscomp$inline_2919$$),$G__29451$jscomp$inline_2921_count__24022$jscomp$inline_2915$$=$APP.$cljs$core$_chunked_rest$$($G__29452$jscomp$inline_2922_chunk__24021$jscomp$inline_2914_seq__24020__$1$jscomp$inline_2919$$),$G__29452$jscomp$inline_2922_chunk__24021$jscomp$inline_2914_seq__24020__$1$jscomp$inline_2919$$=$c__5548__auto__$jscomp$inline_2920_objs$jscomp$1_seq__24020$jscomp$inline_2913_temp__5825__auto__$jscomp$inline_2918$$,
$G__29453$jscomp$inline_2923_obj$jscomp$inline_2917$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$inline_2920_objs$jscomp$1_seq__24020$jscomp$inline_2913_temp__5825__auto__$jscomp$inline_2918$$),$c__5548__auto__$jscomp$inline_2920_objs$jscomp$1_seq__24020$jscomp$inline_2913_temp__5825__auto__$jscomp$inline_2918$$=$G__29451$jscomp$inline_2921_count__24022$jscomp$inline_2915$$,$G__29451$jscomp$inline_2921_count__24022$jscomp$inline_2915$$=$G__29453$jscomp$inline_2923_obj$jscomp$inline_2917$$):($G__29453$jscomp$inline_2923_obj$jscomp$inline_2917$$=
$APP.$cljs$core$first$$($G__29452$jscomp$inline_2922_chunk__24021$jscomp$inline_2914_seq__24020__$1$jscomp$inline_2919$$),$APP.$cljs$core$_write$$($writer$jscomp$14$$," "),$APP.$cljs$core$pr_writer$$($G__29453$jscomp$inline_2923_obj$jscomp$inline_2917$$,$writer$jscomp$14$$,$opts$jscomp$7$$),$c__5548__auto__$jscomp$inline_2920_objs$jscomp$1_seq__24020$jscomp$inline_2913_temp__5825__auto__$jscomp$inline_2918$$=$APP.$cljs$core$next$$($G__29452$jscomp$inline_2922_chunk__24021$jscomp$inline_2914_seq__24020__$1$jscomp$inline_2919$$),
$G__29452$jscomp$inline_2922_chunk__24021$jscomp$inline_2914_seq__24020__$1$jscomp$inline_2919$$=null,$G__29451$jscomp$inline_2921_count__24022$jscomp$inline_2915$$=0),$i__24023$jscomp$inline_2916$$=0;else break a}$writer$jscomp$14$$.$cljs$core$IWriter$_flush$arity$1$(null);return $sb$jscomp$7$$};
$cljs$core$pr_str_with_opts$$=function($objs$jscomp$2$$,$opts$jscomp$8$$){return $APP.$cljs$core$empty_QMARK_$$($objs$jscomp$2$$)?"":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$core$pr_sb_with_opts$$($objs$jscomp$2$$,$opts$jscomp$8$$))};$APP.$cljs$core$newline$cljs$0core$0IFn$0_invoke$0arity$01$$=function($opts$jscomp$11$$){$cljs$core$string_print$$("\n");return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($opts$jscomp$11$$,$cljs$cst$0$flush_on_newline$$),null};
$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($objs$jscomp$7$$){return $cljs$core$string_print$$($cljs$core$pr_str_with_opts$$($objs$jscomp$7$$,$cljs$core$pr_opts$$()))};
$APP.$cljs$core$println$$=function($var_args$jscomp$283$$){for(var $args__5755__auto__$jscomp$17$$=[],$len__5749__auto___29485$$=arguments.length,$i__5750__auto___29486$$=0;;)if($i__5750__auto___29486$$<$len__5749__auto___29485$$)$args__5755__auto__$jscomp$17$$.push(arguments[$i__5750__auto___29486$$]),$i__5750__auto___29486$$+=1;else break;return $APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$17$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$17$$.slice(0),
0,null):null)};
$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($objs$jscomp$12$$){var $opts$jscomp$inline_2929$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cljs$core$pr_opts$$(),$cljs$cst$1$readably$$,!1);$cljs$core$string_print$$($cljs$core$pr_str_with_opts$$($objs$jscomp$12$$,$opts$jscomp$inline_2929$$));return $APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_print_newline_STAR_$$)?$APP.$cljs$core$newline$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$core$pr_opts$$()):null};
$cljs$core$strip_ns$$=function($named$$){return $named$$ instanceof $APP.$cljs$core$Symbol$$?$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$(null,$APP.$cljs$core$name$$($named$$)):$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$(null,$APP.$cljs$core$name$$($named$$))};
$cljs$core$lift_ns$$=function($first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$){if($APP.$cljs$core$truth_$$(!1)){var $G__24039_G__24039__$1_seq__24053_v__$1$jscomp$6$$=$APP.$cljs$core$seq$$($first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$),$G__29512_G__29518_lm_lm__$1_lm__$2_seq__24041$$=$APP.$cljs$core$seq$$($G__24039_G__24039__$1_seq__24053_v__$1$jscomp$6$$),$G__29510_G__29516_first__24042_ns__$2_temp__5825__auto__$jscomp$33$$=$APP.$cljs$core$first$$($G__29512_G__29518_lm_lm__$1_lm__$2_seq__24041$$);
$APP.$cljs$core$next$$($G__29512_G__29518_lm_lm__$1_lm__$2_seq__24041$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__29510_G__29516_first__24042_ns__$2_temp__5825__auto__$jscomp$33$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__29510_G__29516_first__24042_ns__$2_temp__5825__auto__$jscomp$33$$,1,null);$G__29512_G__29518_lm_lm__$1_lm__$2_seq__24041$$=$APP.$cljs$core$empty$$($first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$);for($first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$=
null;;){$G__29510_G__29516_first__24042_ns__$2_temp__5825__auto__$jscomp$33$$=$first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$;$G__24039_G__24039__$1_seq__24053_v__$1$jscomp$6$$=$APP.$cljs$core$seq$$($G__24039_G__24039__$1_seq__24053_v__$1$jscomp$6$$);$first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$=$APP.$cljs$core$first$$($G__24039_G__24039__$1_seq__24053_v__$1$jscomp$6$$);var $G__29511_G__29517_entries__$1_seq__24053__$1$$=$APP.$cljs$core$next$$($G__24039_G__24039__$1_seq__24053_v__$1$jscomp$6$$),
$vec__24055$$=$first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$;$first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__24055$$,0,null);$G__24039_G__24039__$1_seq__24053_v__$1$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__24055$$,1,null);if($APP.$cljs$core$truth_$$($vec__24055$$))if($first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$||$first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$ instanceof
$APP.$cljs$core$Symbol$$)if($APP.$cljs$core$truth_$$($G__29510_G__29516_first__24042_ns__$2_temp__5825__auto__$jscomp$33$$))if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__29510_G__29516_first__24042_ns__$2_temp__5825__auto__$jscomp$33$$,$APP.$cljs$core$namespace$$($first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$))){$G__29512_G__29518_lm_lm__$1_lm__$2_seq__24041$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__29512_G__29518_lm_lm__$1_lm__$2_seq__24041$$,$cljs$core$strip_ns$$($first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$),
$G__24039_G__24039__$1_seq__24053_v__$1$jscomp$6$$);$first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$=$G__29510_G__29516_first__24042_ns__$2_temp__5825__auto__$jscomp$33$$;$G__24039_G__24039__$1_seq__24053_v__$1$jscomp$6$$=$G__29511_G__29517_entries__$1_seq__24053__$1$$;continue}else return null;else if($G__29510_G__29516_first__24042_ns__$2_temp__5825__auto__$jscomp$33$$=$APP.$cljs$core$namespace$$($first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$),$APP.$cljs$core$truth_$$($G__29510_G__29516_first__24042_ns__$2_temp__5825__auto__$jscomp$33$$)){$G__29512_G__29518_lm_lm__$1_lm__$2_seq__24041$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__29512_G__29518_lm_lm__$1_lm__$2_seq__24041$$,$cljs$core$strip_ns$$($first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$),$G__24039_G__24039__$1_seq__24053_v__$1$jscomp$6$$);$first__24054_k__$1$jscomp$1_m$jscomp$56_ns__$1$jscomp$1$$=$G__29510_G__29516_first__24042_ns__$2_temp__5825__auto__$jscomp$33$$;$G__24039_G__24039__$1_seq__24053_v__$1$jscomp$6$$=$G__29511_G__29517_entries__$1_seq__24053__$1$$;continue}else return null;else return null;
else return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__29510_G__29516_first__24042_ns__$2_temp__5825__auto__$jscomp$33$$,$G__29512_G__29518_lm_lm__$1_lm__$2_seq__24041$$],null);break}}else return null};
$cljs$core$print_prefix_map$$=function($prefix$jscomp$6$$,$m$jscomp$57$$,$print_one$jscomp$1$$,$writer$jscomp$15$$,$opts$jscomp$12$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$15$$,function($G__24061_e$jscomp$106$$,$w$jscomp$14$$,$opts__$1$$){var $G__24058_29521$$=$APP.$cljs$core$_key$$($G__24061_e$jscomp$106$$);$print_one$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$?$print_one$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$($G__24058_29521$$,$w$jscomp$14$$,$opts__$1$$):$print_one$jscomp$1$$($G__24058_29521$$,
$w$jscomp$14$$,$opts__$1$$);$APP.$cljs$core$_write$$($w$jscomp$14$$," ");$G__24061_e$jscomp$106$$=$APP.$cljs$core$_val$$($G__24061_e$jscomp$106$$);return $print_one$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$?$print_one$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$($G__24061_e$jscomp$106$$,$w$jscomp$14$$,$opts__$1$$):$print_one$jscomp$1$$($G__24061_e$jscomp$106$$,$w$jscomp$14$$,$opts__$1$$)},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($prefix$jscomp$6$$),"{"].join(""),", ","}",$opts$jscomp$12$$,
$APP.$cljs$core$seq$$($m$jscomp$57$$))};
$cljs$core$print_map$$=function($m$jscomp$58$$,$print_one$jscomp$2$$,$writer$jscomp$16$$,$opts$jscomp$13$$){var $lift_map_vec__24064$$=$APP.$cljs$core$map_QMARK_$$($m$jscomp$58$$)?$cljs$core$lift_ns$$($m$jscomp$58$$):null,$ns$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lift_map_vec__24064$$,0,null);$lift_map_vec__24064$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lift_map_vec__24064$$,1,null);return $APP.$cljs$core$truth_$$($ns$jscomp$10$$)?$cljs$core$print_prefix_map$$(["#:",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ns$jscomp$10$$)].join(""),$lift_map_vec__24064$$,$print_one$jscomp$2$$,$writer$jscomp$16$$,$opts$jscomp$13$$):$cljs$core$print_prefix_map$$(null,$m$jscomp$58$$,$print_one$jscomp$2$$,$writer$jscomp$16$$,$opts$jscomp$13$$)};$APP.$cljs$core$add_watch$$=function($iref$jscomp$4$$,$key$jscomp$171$$,$f$jscomp$302$$){$cljs$core$_add_watch$$($iref$jscomp$4$$,$key$jscomp$171$$,$f$jscomp$302$$)};
$APP.$cljs$core$remove_watch$$=function($iref$jscomp$5$$,$key$jscomp$172$$){$cljs$core$_remove_watch$$($iref$jscomp$5$$,$key$jscomp$172$$);return $iref$jscomp$5$$};$APP.$cljs$core$Delay$$=function($f$jscomp$303$$){this.f=$f$jscomp$303$$;this.value=null;this.$cljs$lang$protocol_mask$partition0$$=2147516416;this.$cljs$lang$protocol_mask$partition1$$=1};$APP.$cljs$core$delay_QMARK_$$=function($x$jscomp$628$$){return $x$jscomp$628$$ instanceof $APP.$cljs$core$Delay$$};
$APP.$cljs$core$force$$=function($x$jscomp$629$$){return $APP.$cljs$core$delay_QMARK_$$($x$jscomp$629$$)?$APP.$cljs$core$_deref$$($x$jscomp$629$$):$x$jscomp$629$$};
$cljs$core$preserving_reduced$$=function($rf$jscomp$17$$){return function($p1__24072_SHARP__ret$jscomp$47$$,$p2__24073_SHARP_$$){$p1__24072_SHARP__ret$jscomp$47$$=$rf$jscomp$17$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$17$$.$cljs$core$IFn$_invoke$arity$2$($p1__24072_SHARP__ret$jscomp$47$$,$p2__24073_SHARP_$$):$rf$jscomp$17$$($p1__24072_SHARP__ret$jscomp$47$$,$p2__24073_SHARP_$$);return $cljs$core$reduced_QMARK_$$($p1__24072_SHARP__ret$jscomp$47$$)?$APP.$cljs$core$reduced$$($p1__24072_SHARP__ret$jscomp$47$$):
$p1__24072_SHARP__ret$jscomp$47$$}};
$cljs$core$cat$$=function($rf$jscomp$18$$){var $rf1$$=$cljs$core$preserving_reduced$$($rf$jscomp$18$$);return function(){function $G__29624__2$$($result$jscomp$68$$,$input$jscomp$42$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($rf1$$,$result$jscomp$68$$,$input$jscomp$42$$)}function $G__29624__1$$($result$jscomp$67$$){return $rf$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$67$$):$rf$jscomp$18$$($result$jscomp$67$$)}
function $G__29624__0$$(){return $rf$jscomp$18$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$18$$.$cljs$core$IFn$_invoke$arity$0$():$rf$jscomp$18$$()}var $G__29624$$=null;$G__29624$$=function($result$jscomp$69$$,$input$jscomp$43$$){switch(arguments.length){case 0:return $G__29624__0$$.call(this);case 1:return $G__29624__1$$.call(this,$result$jscomp$69$$);case 2:return $G__29624__2$$.call(this,$result$jscomp$69$$,$input$jscomp$43$$)}throw Error("Invalid arity: "+arguments.length);};$G__29624$$.$cljs$core$IFn$_invoke$arity$0$=
$G__29624__0$$;$G__29624$$.$cljs$core$IFn$_invoke$arity$1$=$G__29624__1$$;$G__29624$$.$cljs$core$IFn$_invoke$arity$2$=$G__29624__2$$;return $G__29624$$}()};
$cljs$core$halt_when$cljs$0core$0IFn$0_invoke$0arity$02$$=function($pred$jscomp$15$$,$retf$$){return function($rf$jscomp$19$$){return function(){function $G__29634__2$$($G__24076$jscomp$inline_2931_result$jscomp$71$$,$JSCompiler_temp$jscomp$246_input$jscomp$44$$){if($APP.$cljs$core$truth_$$($pred$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$246_input$jscomp$44$$):$pred$jscomp$15$$($JSCompiler_temp$jscomp$246_input$jscomp$44$$))){var $JSCompiler_temp$jscomp$244_JSCompiler_temp_const$jscomp$245$$=
$cljs$cst$112$cljs_DOT_core_SLASH_halt$$;$APP.$cljs$core$truth_$$($retf$$)&&($G__24076$jscomp$inline_2931_result$jscomp$71$$=$rf$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$($G__24076$jscomp$inline_2931_result$jscomp$71$$):$rf$jscomp$19$$($G__24076$jscomp$inline_2931_result$jscomp$71$$),$JSCompiler_temp$jscomp$246_input$jscomp$44$$=$retf$$.$cljs$core$IFn$_invoke$arity$2$?$retf$$.$cljs$core$IFn$_invoke$arity$2$($G__24076$jscomp$inline_2931_result$jscomp$71$$,
$JSCompiler_temp$jscomp$246_input$jscomp$44$$):$retf$$($G__24076$jscomp$inline_2931_result$jscomp$71$$,$JSCompiler_temp$jscomp$246_input$jscomp$44$$));$JSCompiler_temp$jscomp$244_JSCompiler_temp_const$jscomp$245$$=$APP.$cljs$core$reduced$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$JSCompiler_temp$jscomp$244_JSCompiler_temp_const$jscomp$245$$,$JSCompiler_temp$jscomp$246_input$jscomp$44$$],null))}else $JSCompiler_temp$jscomp$244_JSCompiler_temp_const$jscomp$245$$=$rf$jscomp$19$$.$cljs$core$IFn$_invoke$arity$2$?
$rf$jscomp$19$$.$cljs$core$IFn$_invoke$arity$2$($G__24076$jscomp$inline_2931_result$jscomp$71$$,$JSCompiler_temp$jscomp$246_input$jscomp$44$$):$rf$jscomp$19$$($G__24076$jscomp$inline_2931_result$jscomp$71$$,$JSCompiler_temp$jscomp$246_input$jscomp$44$$);return $JSCompiler_temp$jscomp$244_JSCompiler_temp_const$jscomp$245$$}function $G__29634__1$$($result$jscomp$70$$){return $APP.$cljs$core$map_QMARK_$$($result$jscomp$70$$)&&$APP.$cljs$core$contains_QMARK_$$($result$jscomp$70$$,$cljs$cst$112$cljs_DOT_core_SLASH_halt$$)?
$cljs$cst$112$cljs_DOT_core_SLASH_halt$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$70$$):$rf$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$70$$):$rf$jscomp$19$$($result$jscomp$70$$)}function $G__29634__0$$(){return $rf$jscomp$19$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$19$$.$cljs$core$IFn$_invoke$arity$0$():$rf$jscomp$19$$()}var $G__29634$$=null;$G__29634$$=function($result$jscomp$72$$,$input$jscomp$45$$){switch(arguments.length){case 0:return $G__29634__0$$.call(this);
case 1:return $G__29634__1$$.call(this,$result$jscomp$72$$);case 2:return $G__29634__2$$.call(this,$result$jscomp$72$$,$input$jscomp$45$$)}throw Error("Invalid arity: "+arguments.length);};$G__29634$$.$cljs$core$IFn$_invoke$arity$0$=$G__29634__0$$;$G__29634$$.$cljs$core$IFn$_invoke$arity$1$=$G__29634__1$$;$G__29634$$.$cljs$core$IFn$_invoke$arity$2$=$G__29634__2$$;return $G__29634$$}()}};
$cljs$core$Eduction$$=function($xform$jscomp$8$$,$coll$jscomp$810$$){this.$xform$=$xform$jscomp$8$$;this.$coll$=$coll$jscomp$810$$;this.$cljs$lang$protocol_mask$partition0$$=2173173760;this.$cljs$lang$protocol_mask$partition1$$=131072};
$APP.$cljs$core$run_BANG_$$=function($proc$$,$coll$jscomp$812$$){$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__24084_SHARP_$$,$p2__24083_SHARP_$$){return $proc$$.$cljs$core$IFn$_invoke$arity$1$?$proc$$.$cljs$core$IFn$_invoke$arity$1$($p2__24083_SHARP_$$):$proc$$($p2__24083_SHARP_$$)},null,$coll$jscomp$812$$);return null};$cljs$core$IEncodeJS$$=function(){};
$cljs$core$_clj__GT_js$$=function($JSCompiler_temp$jscomp$247_x$jscomp$638$$){if($JSCompiler_temp$jscomp$247_x$jscomp$638$$!=null&&$JSCompiler_temp$jscomp$247_x$jscomp$638$$.$cljs$core$IEncodeJS$_clj__GT_js$arity$1$!=null)$JSCompiler_temp$jscomp$247_x$jscomp$638$$=$JSCompiler_temp$jscomp$247_x$jscomp$638$$.$cljs$core$IEncodeJS$_clj__GT_js$arity$1$($JSCompiler_temp$jscomp$247_x$jscomp$638$$);else{var $m__5372__auto__$jscomp$inline_2938_m__5374__auto__$jscomp$inline_2937$$=$cljs$core$_clj__GT_js$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$247_x$jscomp$638$$==
null?null:$JSCompiler_temp$jscomp$247_x$jscomp$638$$)];if($m__5372__auto__$jscomp$inline_2938_m__5374__auto__$jscomp$inline_2937$$!=null)$JSCompiler_temp$jscomp$247_x$jscomp$638$$=$m__5372__auto__$jscomp$inline_2938_m__5374__auto__$jscomp$inline_2937$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2938_m__5374__auto__$jscomp$inline_2937$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$247_x$jscomp$638$$):$m__5372__auto__$jscomp$inline_2938_m__5374__auto__$jscomp$inline_2937$$($JSCompiler_temp$jscomp$247_x$jscomp$638$$);
else if($m__5372__auto__$jscomp$inline_2938_m__5374__auto__$jscomp$inline_2937$$=$cljs$core$_clj__GT_js$$._,$m__5372__auto__$jscomp$inline_2938_m__5374__auto__$jscomp$inline_2937$$!=null)$JSCompiler_temp$jscomp$247_x$jscomp$638$$=$m__5372__auto__$jscomp$inline_2938_m__5374__auto__$jscomp$inline_2937$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_2938_m__5374__auto__$jscomp$inline_2937$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$247_x$jscomp$638$$):$m__5372__auto__$jscomp$inline_2938_m__5374__auto__$jscomp$inline_2937$$($JSCompiler_temp$jscomp$247_x$jscomp$638$$);
else throw $APP.$cljs$core$missing_protocol$$("IEncodeJS.-clj-\x3ejs",$JSCompiler_temp$jscomp$247_x$jscomp$638$$);}return $JSCompiler_temp$jscomp$247_x$jscomp$638$$};
$cljs$core$key__GT_js$cljs$0core$0IFn$0_invoke$0arity$02$$=function($k$jscomp$210$$,$primitive_fn$$){return($k$jscomp$210$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$k$jscomp$210$$.$cljs$core$IEncodeJS$$||($k$jscomp$210$$.$cljs$lang$protocol_mask$partition$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IEncodeJS$$,$k$jscomp$210$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IEncodeJS$$,$k$jscomp$210$$))?$cljs$core$_clj__GT_js$$($k$jscomp$210$$):typeof $k$jscomp$210$$==="string"||
typeof $k$jscomp$210$$==="number"||$k$jscomp$210$$ instanceof $APP.$cljs$core$Keyword$$||$k$jscomp$210$$ instanceof $APP.$cljs$core$Symbol$$?$primitive_fn$$.$cljs$core$IFn$_invoke$arity$1$?$primitive_fn$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$210$$):$primitive_fn$$($k$jscomp$210$$):$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$k$jscomp$210$$]))};$cljs$core$IEncodeClojure$$=function(){};
$cljs$core$_js__GT_clj$$=function($JSCompiler_temp$jscomp$248_x$jscomp$643$$,$options$jscomp$78$$){if($JSCompiler_temp$jscomp$248_x$jscomp$643$$!=null&&$JSCompiler_temp$jscomp$248_x$jscomp$643$$.$cljs$core$IEncodeClojure$_js__GT_clj$arity$2$!=null)$JSCompiler_temp$jscomp$248_x$jscomp$643$$=$JSCompiler_temp$jscomp$248_x$jscomp$643$$.$cljs$core$IEncodeClojure$_js__GT_clj$arity$2$($JSCompiler_temp$jscomp$248_x$jscomp$643$$,$options$jscomp$78$$);else{var $m__5372__auto__$jscomp$inline_2951_m__5374__auto__$jscomp$inline_2950$$=
$cljs$core$_js__GT_clj$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$248_x$jscomp$643$$==null?null:$JSCompiler_temp$jscomp$248_x$jscomp$643$$)];if($m__5372__auto__$jscomp$inline_2951_m__5374__auto__$jscomp$inline_2950$$!=null)$JSCompiler_temp$jscomp$248_x$jscomp$643$$=$m__5372__auto__$jscomp$inline_2951_m__5374__auto__$jscomp$inline_2950$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2951_m__5374__auto__$jscomp$inline_2950$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$248_x$jscomp$643$$,
$options$jscomp$78$$):$m__5372__auto__$jscomp$inline_2951_m__5374__auto__$jscomp$inline_2950$$($JSCompiler_temp$jscomp$248_x$jscomp$643$$,$options$jscomp$78$$);else if($m__5372__auto__$jscomp$inline_2951_m__5374__auto__$jscomp$inline_2950$$=$cljs$core$_js__GT_clj$$._,$m__5372__auto__$jscomp$inline_2951_m__5374__auto__$jscomp$inline_2950$$!=null)$JSCompiler_temp$jscomp$248_x$jscomp$643$$=$m__5372__auto__$jscomp$inline_2951_m__5374__auto__$jscomp$inline_2950$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_2951_m__5374__auto__$jscomp$inline_2950$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$248_x$jscomp$643$$,
$options$jscomp$78$$):$m__5372__auto__$jscomp$inline_2951_m__5374__auto__$jscomp$inline_2950$$($JSCompiler_temp$jscomp$248_x$jscomp$643$$,$options$jscomp$78$$);else throw $APP.$cljs$core$missing_protocol$$("IEncodeClojure.-js-\x3eclj",$JSCompiler_temp$jscomp$248_x$jscomp$643$$);}return $JSCompiler_temp$jscomp$248_x$jscomp$643$$};
$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($x$jscomp$645$$,$opts$jscomp$53$$){var $keywordize_keys_map__24153__$1$$=$APP.$cljs$core$__destructure_map$$($opts$jscomp$53$$);$keywordize_keys_map__24153__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($keywordize_keys_map__24153__$1$$,$APP.$cljs$cst$127$keywordize_keys$$);var $keyfn$jscomp$3$$=$APP.$cljs$core$truth_$$($keywordize_keys_map__24153__$1$$)?$APP.$cljs$core$keyword$$:$APP.$cljs$core$str$$;return function $cljs$core$thisfn$jscomp$1$$($x__$1$jscomp$12$$){return($x__$1$jscomp$12$$!=
null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x__$1$jscomp$12$$.$cljs$core$IEncodeClojure$$||($x__$1$jscomp$12$$.$cljs$lang$protocol_mask$partition$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IEncodeClojure$$,$x__$1$jscomp$12$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IEncodeClojure$$,$x__$1$jscomp$12$$))?$cljs$core$_js__GT_clj$$($x__$1$jscomp$12$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$array_map$$,$opts$jscomp$53$$)):$APP.$cljs$core$seq_QMARK_$$($x__$1$jscomp$12$$)?
$APP.$cljs$core$doall$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$thisfn$jscomp$1$$,$x__$1$jscomp$12$$)):$APP.$cljs$core$map_entry_QMARK_$$($x__$1$jscomp$12$$)?new $APP.$cljs$core$MapEntry$$($cljs$core$thisfn$jscomp$1$$($APP.$cljs$core$_key$$($x__$1$jscomp$12$$)),$cljs$core$thisfn$jscomp$1$$($APP.$cljs$core$_val$$($x__$1$jscomp$12$$)),null):$APP.$cljs$core$coll_QMARK_$$($x__$1$jscomp$12$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$empty$$($x__$1$jscomp$12$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($cljs$core$thisfn$jscomp$1$$),$x__$1$jscomp$12$$):$APP.$cljs$core$array_QMARK_$$($x__$1$jscomp$12$$)?$APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__24147_SHARP_$$,$p2__24148_SHARP_$$){return $APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($p1__24147_SHARP_$$,$cljs$core$thisfn$jscomp$1$$($p2__24148_SHARP_$$))},$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),
$x__$1$jscomp$12$$)):$APP.$cljs$core$type$$($x__$1$jscomp$12$$)===Object?$APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($r$jscomp$24$$,$k$jscomp$212$$){return $APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($r$jscomp$24$$,$keyfn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$keyfn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$212$$):$keyfn$jscomp$3$$($k$jscomp$212$$),$cljs$core$thisfn$jscomp$1$$($APP.$module$contents$goog$object_get$$($x__$1$jscomp$12$$,
$k$jscomp$212$$)))},$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$module$contents$goog$object_getKeys$$($x__$1$jscomp$12$$))):$x__$1$jscomp$12$$}($x$jscomp$645$$)};
$APP.$cljs$core$memoize$$=function($f$jscomp$308$$){var $mem$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);return function(){function $G__29807$$($var_args$jscomp$296$$){var $G__29810__i_args$jscomp$109$$=null;if(arguments.length>0){$G__29810__i_args$jscomp$109$$=0;for(var $G__29810__a$$=Array(arguments.length-0);$G__29810__i_args$jscomp$109$$<$G__29810__a$$.length;)$G__29810__a$$[$G__29810__i_args$jscomp$109$$]=arguments[$G__29810__i_args$jscomp$109$$+
0],++$G__29810__i_args$jscomp$109$$;$G__29810__i_args$jscomp$109$$=new $APP.$cljs$core$IndexedSeq$$($G__29810__a$$,0,null)}return $G__29807__delegate$$.call(this,$G__29810__i_args$jscomp$109$$)}function $G__29807__delegate$$($args$jscomp$108$$){var $ret$jscomp$50_v$jscomp$76$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($mem$$),$args$jscomp$108$$,$cljs$core$lookup_sentinel$$);return $ret$jscomp$50_v$jscomp$76$$===$cljs$core$lookup_sentinel$$?($ret$jscomp$50_v$jscomp$76$$=
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$308$$,$args$jscomp$108$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($mem$$,$APP.$cljs$core$assoc$$,$args$jscomp$108$$,$ret$jscomp$50_v$jscomp$76$$),$ret$jscomp$50_v$jscomp$76$$):$ret$jscomp$50_v$jscomp$76$$}$G__29807$$.$cljs$lang$maxFixedArity$=0;$G__29807$$.$cljs$lang$applyTo$=function($arglist__29811_args$jscomp$110$$){$arglist__29811_args$jscomp$110$$=$APP.$cljs$core$seq$$($arglist__29811_args$jscomp$110$$);return $G__29807__delegate$$($arglist__29811_args$jscomp$110$$)};
$G__29807$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__29807__delegate$$;return $G__29807$$}()};$cljs$core$rand_int$$=function($n$jscomp$161$$){return Math.floor(Math.random()*$n$jscomp$161$$)};
$APP.$cljs$core$group_by$$=function($f$jscomp$311$$,$coll$jscomp$814$$){return $APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret$jscomp$52$$,$x$jscomp$646$$){var $k$jscomp$213$$=$f$jscomp$311$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$311$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$646$$):$f$jscomp$311$$($x$jscomp$646$$);return $APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($ret$jscomp$52$$,$k$jscomp$213$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($ret$jscomp$52$$,
$k$jscomp$213$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$x$jscomp$646$$))},$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$coll$jscomp$814$$))};
$APP.$cljs$core$get_global_hierarchy$$=function(){$cljs$core$_global_hierarchy$$==null&&($cljs$core$_global_hierarchy$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$128$parents$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$129$descendants$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$130$ancestors$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null)));return $cljs$core$_global_hierarchy$$};
$cljs$core$isa_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($h$jscomp$73$$,$child$jscomp$3$$,$parent$jscomp$12$$){var $G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($child$jscomp$3$$,$parent$jscomp$12$$);if($G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$)return $G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$;
$G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$=$cljs$cst$130$ancestors$$.$cljs$core$IFn$_invoke$arity$1$($h$jscomp$73$$);$G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$=
$G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$.$cljs$core$IFn$_invoke$arity$1$?$G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$3$$):
$G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$($child$jscomp$3$$);if(!($G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$=
$APP.$cljs$core$contains_QMARK_$$($G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$,$parent$jscomp$12$$))&&($G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$=
$APP.$cljs$core$vector_QMARK_$$($parent$jscomp$12$$)))if($G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$=$APP.$cljs$core$vector_QMARK_$$($child$jscomp$3$$))if($G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$=
$APP.$cljs$core$count$$($parent$jscomp$12$$)===$APP.$cljs$core$count$$($child$jscomp$3$$)){$G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$=!0;for(var $G__29836_i$jscomp$272$$=0;;)if($G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$&&
$G__29836_i$jscomp$272$$!==$APP.$cljs$core$count$$($parent$jscomp$12$$))$G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$=$cljs$core$isa_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($h$jscomp$73$$,$child$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$child$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($G__29836_i$jscomp$272$$):
$child$jscomp$3$$($G__29836_i$jscomp$272$$),$parent$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$parent$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($G__29836_i$jscomp$272$$):$parent$jscomp$12$$($G__29836_i$jscomp$272$$)),$G__29836_i$jscomp$272$$+=1;else return $G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$}else return $G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$;
else return $G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$;else return $G__29835_JSCompiler_inline_result$jscomp$249_and__5023__auto__$jscomp$29_and__5023__auto____$1$jscomp$15_and__5023__auto____$2$jscomp$5_fexpr__24165$jscomp$inline_2953_or__5025__auto__$jscomp$46_or__5025__auto____$1$jscomp$11_ret$jscomp$53$$};
$cljs$core$parents$cljs$0core$0IFn$0_invoke$0arity$01$$=function($tag$jscomp$3$$){var $h$jscomp$inline_2955$$=$APP.$cljs$core$deref$$($APP.$cljs$core$get_global_hierarchy$$());return $APP.$cljs$core$not_empty$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$128$parents$$.$cljs$core$IFn$_invoke$arity$1$($h$jscomp$inline_2955$$),$tag$jscomp$3$$))};
$cljs$core$reset_cache$$=function($method_cache$$,$method_table$$,$cached_hierarchy$$,$hierarchy$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($method_cache$$,function(){return $APP.$cljs$core$_deref$$($method_table$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cached_hierarchy$$,function(){return $APP.$cljs$core$_deref$$($hierarchy$$)})};
$cljs$core$dominates$$=function($x$jscomp$648$$,$y$jscomp$274$$,$or__5025__auto__$jscomp$49_prefer_table$jscomp$1$$,$hierarchy$jscomp$1$$){$or__5025__auto__$jscomp$49_prefer_table$jscomp$1$$=$cljs$core$prefers_STAR_$$($x$jscomp$648$$,$y$jscomp$274$$,$or__5025__auto__$jscomp$49_prefer_table$jscomp$1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$49_prefer_table$jscomp$1$$)?$or__5025__auto__$jscomp$49_prefer_table$jscomp$1$$:$cljs$core$isa_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($hierarchy$jscomp$1$$,
$x$jscomp$648$$,$y$jscomp$274$$)};
$cljs$core$_add_method$$=function($mf$jscomp$3$$,$dispatch_val$jscomp$2$$,$method$jscomp$2$$){if($mf$jscomp$3$$!=null&&$mf$jscomp$3$$.$cljs$core$IMultiFn$_add_method$arity$3$!=null)$mf$jscomp$3$$.$cljs$core$IMultiFn$_add_method$arity$3$($mf$jscomp$3$$,$dispatch_val$jscomp$2$$,$method$jscomp$2$$);else{var $m__5372__auto__$jscomp$inline_2973_m__5374__auto__$jscomp$inline_2972$$=$cljs$core$_add_method$$[$APP.$goog$typeOf$$($mf$jscomp$3$$==null?null:$mf$jscomp$3$$)];if($m__5372__auto__$jscomp$inline_2973_m__5374__auto__$jscomp$inline_2972$$!=
null)$m__5372__auto__$jscomp$inline_2973_m__5374__auto__$jscomp$inline_2972$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_2973_m__5374__auto__$jscomp$inline_2972$$.$cljs$core$IFn$_invoke$arity$3$($mf$jscomp$3$$,$dispatch_val$jscomp$2$$,$method$jscomp$2$$):$m__5372__auto__$jscomp$inline_2973_m__5374__auto__$jscomp$inline_2972$$($mf$jscomp$3$$,$dispatch_val$jscomp$2$$,$method$jscomp$2$$);else if($m__5372__auto__$jscomp$inline_2973_m__5374__auto__$jscomp$inline_2972$$=$cljs$core$_add_method$$._,
$m__5372__auto__$jscomp$inline_2973_m__5374__auto__$jscomp$inline_2972$$!=null)$m__5372__auto__$jscomp$inline_2973_m__5374__auto__$jscomp$inline_2972$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_2973_m__5374__auto__$jscomp$inline_2972$$.$cljs$core$IFn$_invoke$arity$3$($mf$jscomp$3$$,$dispatch_val$jscomp$2$$,$method$jscomp$2$$):$m__5372__auto__$jscomp$inline_2973_m__5374__auto__$jscomp$inline_2972$$($mf$jscomp$3$$,$dispatch_val$jscomp$2$$,$method$jscomp$2$$);else throw $APP.$cljs$core$missing_protocol$$("IMultiFn.-add-method",
$mf$jscomp$3$$);}};$cljs$core$throw_no_method_error$$=function($name$jscomp$111$$,$dispatch_val$jscomp$9$$){throw Error(["No method in multimethod '",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$111$$),"' for dispatch value: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($dispatch_val$jscomp$9$$)].join(""));};
$APP.$cljs$core$MultiFn$$=function($name$jscomp$112$$,$dispatch_fn$$,$default_dispatch_val$jscomp$1$$,$hierarchy$jscomp$3$$,$method_table$jscomp$2$$,$prefer_table$jscomp$3$$,$method_cache$jscomp$2$$,$cached_hierarchy$jscomp$2$$){this.name=$name$jscomp$112$$;this.$dispatch_fn$=$dispatch_fn$$;this.$default_dispatch_val$=$default_dispatch_val$jscomp$1$$;this.$hierarchy$=$hierarchy$jscomp$3$$;this.$method_table$=$method_table$jscomp$2$$;this.$prefer_table$=$prefer_table$jscomp$3$$;this.$method_cache$=
$method_cache$jscomp$2$$;this.$cached_hierarchy$=$cached_hierarchy$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=4194305;this.$cljs$lang$protocol_mask$partition1$$=4352};
$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$=function($JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$,$dispatch_val$jscomp$34$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$.$cached_hierarchy$),$APP.$cljs$core$_deref$$($JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$.$hierarchy$))||$cljs$core$reset_cache$$($JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$.$method_cache$,
$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$.$method_table$,$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$.$cached_hierarchy$,$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$.$hierarchy$);var $fexpr__24193$jscomp$inline_2975_temp__5823__auto__$jscomp$19$$=$APP.$cljs$core$_deref$$($JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$.$method_cache$);$fexpr__24193$jscomp$inline_2975_temp__5823__auto__$jscomp$19$$=
$fexpr__24193$jscomp$inline_2975_temp__5823__auto__$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__24193$jscomp$inline_2975_temp__5823__auto__$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$($dispatch_val$jscomp$34$$):$fexpr__24193$jscomp$inline_2975_temp__5823__auto__$jscomp$19$$($dispatch_val$jscomp$34$$);return $APP.$cljs$core$truth_$$($fexpr__24193$jscomp$inline_2975_temp__5823__auto__$jscomp$19$$)?$fexpr__24193$jscomp$inline_2975_temp__5823__auto__$jscomp$19$$:$cljs$core$find_and_cache_best_method$$($JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$.name,
$dispatch_val$jscomp$34$$,$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$.$hierarchy$,$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$.$method_table$,$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$.$prefer_table$,$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$.$method_cache$,$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$.$cached_hierarchy$,$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$self$$.$default_dispatch_val$)};
$cljs$core$UUID$$=function($uuid$$,$__hash$jscomp$49$$){this.uuid=$uuid$$;this.$__hash$=$__hash$jscomp$49$$;this.$cljs$lang$protocol_mask$partition0$$=2153775104;this.$cljs$lang$protocol_mask$partition1$$=2048};$APP.$cljs$core$uuid$$=function($s$jscomp$128$$){return new $cljs$core$UUID$$($s$jscomp$128$$.toLowerCase(),null)};
$cljs$core$random_uuid$$=function(){function $quad_hex$$(){var $unpadded_hex$$=$cljs$core$rand_int$$(65536).toString(16);switch($unpadded_hex$$.length){case 1:return["000",$unpadded_hex$$].join("");case 2:return["00",$unpadded_hex$$].join("");case 3:return["0",$unpadded_hex$$].join("");default:return $unpadded_hex$$}}var $ver_tripple_hex$$=(16384|4095&$cljs$core$rand_int$$(65536)).toString(16),$res_tripple_hex$$=(32768|16383&$cljs$core$rand_int$$(65536)).toString(16);return $APP.$cljs$core$uuid$$([$quad_hex$$(),
$quad_hex$$(),"-",$quad_hex$$(),"-",$ver_tripple_hex$$,"-",$res_tripple_hex$$,"-",$quad_hex$$(),$quad_hex$$(),$quad_hex$$()].join(""))};$APP.$cljs$core$uuid_QMARK_$$=function($x$jscomp$649$$){return $x$jscomp$649$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$649$$.$cljs$core$IUUID$$?!0:!1:!1};
$APP.$cljs$core$ExceptionInfo$$=function($message$jscomp$42$$,$data$jscomp$88$$,$cause$jscomp$1$$){var $e$jscomp$125$$=Error($message$jscomp$42$$);this.message=$message$jscomp$42$$;this.data=$data$jscomp$88$$;this.cause=$cause$jscomp$1$$;this.name=$e$jscomp$125$$.name;this.description=$e$jscomp$125$$.description;this.number=$e$jscomp$125$$.number;this.fileName=$e$jscomp$125$$.fileName;this.lineNumber=$e$jscomp$125$$.lineNumber;this.columnNumber=$e$jscomp$125$$.columnNumber;this.stack=$e$jscomp$125$$.stack;
return this};$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$=function($msg$jscomp$2$$,$data$jscomp$89$$){return $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($msg$jscomp$2$$,$data$jscomp$89$$,null)};$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$=function($msg$jscomp$3$$,$data$jscomp$90$$,$cause$jscomp$2$$){return new $APP.$cljs$core$ExceptionInfo$$($msg$jscomp$3$$,$data$jscomp$90$$,$cause$jscomp$2$$)};
$APP.$cljs$core$ex_data$$=function($ex$jscomp$4$$){return $ex$jscomp$4$$ instanceof $APP.$cljs$core$ExceptionInfo$$?$ex$jscomp$4$$.data:null};$APP.$cljs$core$ex_message$$=function($ex$jscomp$5$$){return $ex$jscomp$5$$ instanceof Error?$ex$jscomp$5$$.message:null};$cljs$core$ex_cause$$=function($ex$jscomp$6$$){return $ex$jscomp$6$$ instanceof $APP.$cljs$core$ExceptionInfo$$?$ex$jscomp$6$$.cause:null};
$cljs$core$Throwable__GT_map$$=function($o$jscomp$131$$){var $via$$=function(){for(var $G__30062_via$jscomp$1$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$G__30063_t$jscomp$22$$=$o$jscomp$131$$;;)if($APP.$cljs$core$truth_$$($G__30063_t$jscomp$22$$))$G__30062_via$jscomp$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__30062_via$jscomp$1$$,$G__30063_t$jscomp$22$$),$G__30063_t$jscomp$22$$=$cljs$core$ex_cause$$($G__30063_t$jscomp$22$$);else return $G__30062_via$jscomp$1$$}(),$root$jscomp$14$$=
$APP.$cljs$core$peek$$($via$$);return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$143$via$$,$APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($t$jscomp$21$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$t$jscomp$21$$ instanceof $APP.$cljs$core$ExceptionInfo$$?$cljs$cst$140$cljs_DOT_core_SLASH_ExceptionInfo$$:$t$jscomp$21$$ instanceof Error?$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("js",$t$jscomp$21$$.name):null],null),function(){var $temp__5825__auto__$jscomp$34$$=$APP.$cljs$core$ex_message$$($t$jscomp$21$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$34$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$temp__5825__auto__$jscomp$34$$],
null):null}(),function(){var $temp__5825__auto__$jscomp$35$$=$APP.$cljs$core$ex_data$$($t$jscomp$21$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$35$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$142$data$$,$temp__5825__auto__$jscomp$35$$],null):null}()]))},$via$$)),$APP.$cljs$cst$144$trace$$,null],null),function(){var $temp__5825__auto__$jscomp$36$$=$APP.$cljs$core$ex_message$$($root$jscomp$14$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$36$$)?
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$145$cause$$,$temp__5825__auto__$jscomp$36$$],null):null}(),function(){var $temp__5825__auto__$jscomp$37$$=$APP.$cljs$core$ex_data$$($root$jscomp$14$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$37$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$142$data$$,$temp__5825__auto__$jscomp$37$$],null):null}(),function(){var $temp__5825__auto__$jscomp$38$$=$cljs$cst$146$clojure_DOT_error_SLASH_phase$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($o$jscomp$131$$));
return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$38$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$147$phase$$,$temp__5825__auto__$jscomp$38$$],null):null}()]))};
$APP.$cljs$core$special_symbol_QMARK_$$=function($x$jscomp$651$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,24,[$APP.$cljs$cst$148$_AMPERSAND_$$,"null",$cljs$cst$149$case_STAR_$$,"null",$cljs$cst$150$defrecord_STAR_$$,"null",$cljs$cst$151$try$$,"null",$cljs$cst$152$ns_STAR_$$,"null",$cljs$cst$153$finally$$,"null",$cljs$cst$154$loop_STAR_$$,"null",$cljs$cst$155$do$$,"null",$cljs$cst$156$letfn_STAR_$$,"null",$cljs$cst$157$if$$,
"null",$cljs$cst$158$new$$,"null",$cljs$cst$6$ns$$,"null",$cljs$cst$159$deftype_STAR_$$,"null",$cljs$cst$160$let_STAR_$$,"null",$cljs$cst$161$js_STAR_$$,"null",$APP.$cljs$cst$162$fn_STAR_$$,"null",$cljs$cst$163$recur$$,"null",$cljs$cst$164$set_BANG_$$,"null",$cljs$cst$165$_DOT_$$,"null",$APP.$cljs$cst$166$var$$,"null",$APP.$cljs$cst$167$quote$$,"null",$cljs$cst$168$catch$$,"null",$cljs$cst$169$throw$$,"null",$cljs$cst$170$def$$,"null"],null),null),$x$jscomp$651$$)};
$cljs$core$demunge_pattern$$=function(){$APP.$cljs$core$truth_$$($cljs$core$DEMUNGE_PATTERN$$)||($cljs$core$DEMUNGE_PATTERN$$=function(){for(var $ks__$1$jscomp$2$$=$APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$02$$(function($a$jscomp$191$$,$b$jscomp$159$$){return $b$jscomp$159$$.length-$a$jscomp$191$$.length},$module$contents$goog$object_getKeys$$($cljs$core$DEMUNGE_MAP$$)),$ret$jscomp$55$$="";;)if($APP.$cljs$core$seq$$($ks__$1$jscomp$2$$)){var $G__30099$$=$APP.$cljs$core$next$$($ks__$1$jscomp$2$$),
$G__30100$$=[function(){var $G__24207$$=$ret$jscomp$55$$;return $ret$jscomp$55$$!==""?[$G__24207$$,"|"].join(""):$G__24207$$}(),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($ks__$1$jscomp$2$$))].join("");$ks__$1$jscomp$2$$=$G__30099$$;$ret$jscomp$55$$=$G__30100$$}else return[$ret$jscomp$55$$,"|\\$"].join("")}());return $cljs$core$DEMUNGE_PATTERN$$};
$cljs$core$demunge$$=function($fexpr__24214_name$jscomp$116$$){var $munged_name__$1$jscomp$inline_11316_name_SINGLEQUOTE_$jscomp$inline_2981$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($fexpr__24214_name$jscomp$116$$);if($munged_name__$1$jscomp$inline_11316_name_SINGLEQUOTE_$jscomp$inline_2981$$==="_DOT__DOT_")var $G__24215_JSCompiler_temp$jscomp$10655_r$jscomp$inline_11315$$="..";else a:{$G__24215_JSCompiler_temp$jscomp$10655_r$jscomp$inline_11315$$=new RegExp($cljs$core$demunge_pattern$$(),
"g");$munged_name__$1$jscomp$inline_11316_name_SINGLEQUOTE_$jscomp$inline_2981$$=$APP.$cljs$core$truth_$$($APP.$goog$string$internal$endsWith$$($munged_name__$1$jscomp$inline_11316_name_SINGLEQUOTE_$jscomp$inline_2981$$,"$"))?$munged_name__$1$jscomp$inline_11316_name_SINGLEQUOTE_$jscomp$inline_2981$$.substring(0,$munged_name__$1$jscomp$inline_11316_name_SINGLEQUOTE_$jscomp$inline_2981$$.length-1):$munged_name__$1$jscomp$inline_11316_name_SINGLEQUOTE_$jscomp$inline_2981$$;for(var $G__30109$jscomp$inline_11321_ret$jscomp$inline_11317$$=
"",$G__30110$jscomp$inline_11322_last_match_end$jscomp$inline_11318$$=0;;){var $temp__5823__auto__$jscomp$inline_11319_x$jscomp$inline_11320$$=$G__24215_JSCompiler_temp$jscomp$10655_r$jscomp$inline_11315$$.exec($munged_name__$1$jscomp$inline_11316_name_SINGLEQUOTE_$jscomp$inline_2981$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_11319_x$jscomp$inline_11320$$))$temp__5823__auto__$jscomp$inline_11319_x$jscomp$inline_11320$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($temp__5823__auto__$jscomp$inline_11319_x$jscomp$inline_11320$$,
0,null),$G__30109$jscomp$inline_11321_ret$jscomp$inline_11317$$=[$G__30109$jscomp$inline_11321_ret$jscomp$inline_11317$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($munged_name__$1$jscomp$inline_11316_name_SINGLEQUOTE_$jscomp$inline_2981$$.substring($G__30110$jscomp$inline_11322_last_match_end$jscomp$inline_11318$$,$G__24215_JSCompiler_temp$jscomp$10655_r$jscomp$inline_11315$$.lastIndex-$temp__5823__auto__$jscomp$inline_11319_x$jscomp$inline_11320$$.length)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($temp__5823__auto__$jscomp$inline_11319_x$jscomp$inline_11320$$===
"$"?"/":$APP.$module$contents$goog$object_get$$($cljs$core$DEMUNGE_MAP$$,$temp__5823__auto__$jscomp$inline_11319_x$jscomp$inline_11320$$))].join(""),$G__30110$jscomp$inline_11322_last_match_end$jscomp$inline_11318$$=$G__24215_JSCompiler_temp$jscomp$10655_r$jscomp$inline_11315$$.lastIndex;else{$G__24215_JSCompiler_temp$jscomp$10655_r$jscomp$inline_11315$$=[$G__30109$jscomp$inline_11321_ret$jscomp$inline_11317$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($munged_name__$1$jscomp$inline_11316_name_SINGLEQUOTE_$jscomp$inline_2981$$.substring($G__30110$jscomp$inline_11322_last_match_end$jscomp$inline_11318$$,
$munged_name__$1$jscomp$inline_11316_name_SINGLEQUOTE_$jscomp$inline_2981$$.length))].join("");break a}}$G__24215_JSCompiler_temp$jscomp$10655_r$jscomp$inline_11315$$=void 0}$fexpr__24214_name$jscomp$116$$=$fexpr__24214_name$jscomp$116$$ instanceof $APP.$cljs$core$Symbol$$?$APP.$cljs$core$symbol$$:$APP.$cljs$core$str$$;return $fexpr__24214_name$jscomp$116$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__24214_name$jscomp$116$$.$cljs$core$IFn$_invoke$arity$1$($G__24215_JSCompiler_temp$jscomp$10655_r$jscomp$inline_11315$$):
$fexpr__24214_name$jscomp$116$$($G__24215_JSCompiler_temp$jscomp$10655_r$jscomp$inline_11315$$)};
$APP.$cljs$core$update_vals$$=function($m$jscomp$71$$,$f$jscomp$332$$){return $APP.$cljs$core$with_meta$$($APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce_kv$$(function($acc$jscomp$8$$,$k$jscomp$227$$,$v$jscomp$80$$){return $APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$8$$,$k$jscomp$227$$,$f$jscomp$332$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$332$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$80$$):$f$jscomp$332$$($v$jscomp$80$$))},$m$jscomp$71$$!=null&&($m$jscomp$71$$.$cljs$lang$protocol_mask$partition1$$&
4||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$m$jscomp$71$$.$cljs$core$IEditableCollection$$)?$APP.$cljs$core$_as_transient$$($m$jscomp$71$$):$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$m$jscomp$71$$)),$APP.$cljs$core$meta$$($m$jscomp$71$$))};$cljs$core$uri_QMARK_$$=function($x$jscomp$655$$){return $x$jscomp$655$$ instanceof $goog$Uri$$};
$cljs$core$parsing_err$$=function($val$jscomp$107$$){return["Expected string, got: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$107$$==null?"nil":$APP.$goog$typeOf$$($val$jscomp$107$$))].join("")};
$APP.$cljs$core$parse_long$$=function($i$jscomp$286_s$jscomp$129$$){if(typeof $i$jscomp$286_s$jscomp$129$$==="string"){var $and__5023__auto__$jscomp$34$$=$APP.$cljs$core$re_matches$$(/[+-]?\d+/,$i$jscomp$286_s$jscomp$129$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$34$$)?($i$jscomp$286_s$jscomp$129$$=parseInt($i$jscomp$286_s$jscomp$129$$),$i$jscomp$286_s$jscomp$129$$<=Number.MAX_SAFE_INTEGER&&$i$jscomp$286_s$jscomp$129$$>=Number.MIN_SAFE_INTEGER?$i$jscomp$286_s$jscomp$129$$:null):
$and__5023__auto__$jscomp$34$$}throw Error($cljs$core$parsing_err$$($i$jscomp$286_s$jscomp$129$$));};
$APP.$cljs$core$parse_double$$=function($s$jscomp$130$$){if(typeof $s$jscomp$130$$==="string")return $APP.$cljs$core$re_matches$$(/[\x00-\x20]*[+-]?NaN[\x00-\x20]*/,$s$jscomp$130$$)?NaN:$APP.$cljs$core$re_matches$$(/[\x00-\x20]*[+-]?(Infinity|((\d+\.?\d*|\.\d+)([eE][+-]?\d+)?)[dDfF]?)[\x00-\x20]*/,$s$jscomp$130$$)?parseFloat($s$jscomp$130$$):null;throw Error($cljs$core$parsing_err$$($s$jscomp$130$$));};
$cljs$core$parse_uuid$$=function($s$jscomp$131$$){if(typeof $s$jscomp$131$$==="string")return $APP.$cljs$core$re_matches$$($cljs$core$uuid_regex$$,$s$jscomp$131$$)?$APP.$cljs$core$uuid$$($s$jscomp$131$$):null;throw Error($cljs$core$parsing_err$$($s$jscomp$131$$));};
$APP.$cljs$core$parse_boolean$$=function($s$jscomp$132$$){if(typeof $s$jscomp$132$$==="string")switch($s$jscomp$132$$){case "true":return!0;case "false":return!1;default:return null}else throw Error($cljs$core$parsing_err$$($s$jscomp$132$$));};
$clojure$string$replace_all$$=function($s$jscomp$136$$,$re$jscomp$6$$,$replacement$jscomp$5$$){var $G__24236__$1$jscomp$inline_2983_G__24236__$2$jscomp$inline_2984$$=$APP.$cljs$core$truth_$$($re$jscomp$6$$.ignoreCase)?"gi":"g";$G__24236__$1$jscomp$inline_2983_G__24236__$2$jscomp$inline_2984$$=$APP.$cljs$core$truth_$$($re$jscomp$6$$.multiline)?[$G__24236__$1$jscomp$inline_2983_G__24236__$2$jscomp$inline_2984$$,"m"].join(""):$G__24236__$1$jscomp$inline_2983_G__24236__$2$jscomp$inline_2984$$;return $s$jscomp$136$$.replace(new RegExp($re$jscomp$6$$.source,
$APP.$cljs$core$truth_$$($re$jscomp$6$$.unicode)?[$G__24236__$1$jscomp$inline_2983_G__24236__$2$jscomp$inline_2984$$,"u"].join(""):$G__24236__$1$jscomp$inline_2983_G__24236__$2$jscomp$inline_2984$$),$replacement$jscomp$5$$)};
$clojure$string$replace_with$$=function($f$jscomp$334$$){return function(){function $G__24299$$($var_args$jscomp$308$$){var $G__24300__i_args$jscomp$114$$=null;if(arguments.length>0){$G__24300__i_args$jscomp$114$$=0;for(var $G__24300__a$$=Array(arguments.length-0);$G__24300__i_args$jscomp$114$$<$G__24300__a$$.length;)$G__24300__a$$[$G__24300__i_args$jscomp$114$$]=arguments[$G__24300__i_args$jscomp$114$$+0],++$G__24300__i_args$jscomp$114$$;$G__24300__i_args$jscomp$114$$=new $APP.$cljs$core$IndexedSeq$$($G__24300__a$$,
0,null)}return $G__24299__delegate$$.call(this,$G__24300__i_args$jscomp$114$$)}function $G__24299__delegate$$($G__24237_G__24239_args$jscomp$113_matches$jscomp$4$$){$G__24237_G__24239_args$jscomp$113_matches$jscomp$4$$=$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$02$$(2,$G__24237_G__24239_args$jscomp$113_matches$jscomp$4$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($G__24237_G__24239_args$jscomp$113_matches$jscomp$4$$),1))return $G__24237_G__24239_args$jscomp$113_matches$jscomp$4$$=
$APP.$cljs$core$first$$($G__24237_G__24239_args$jscomp$113_matches$jscomp$4$$),$f$jscomp$334$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$334$$.$cljs$core$IFn$_invoke$arity$1$($G__24237_G__24239_args$jscomp$113_matches$jscomp$4$$):$f$jscomp$334$$($G__24237_G__24239_args$jscomp$113_matches$jscomp$4$$);$G__24237_G__24239_args$jscomp$113_matches$jscomp$4$$=$APP.$cljs$core$vec$$($G__24237_G__24239_args$jscomp$113_matches$jscomp$4$$);return $f$jscomp$334$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$334$$.$cljs$core$IFn$_invoke$arity$1$($G__24237_G__24239_args$jscomp$113_matches$jscomp$4$$):
$f$jscomp$334$$($G__24237_G__24239_args$jscomp$113_matches$jscomp$4$$)}$G__24299$$.$cljs$lang$maxFixedArity$=0;$G__24299$$.$cljs$lang$applyTo$=function($arglist__24301_args$jscomp$115$$){$arglist__24301_args$jscomp$115$$=$APP.$cljs$core$seq$$($arglist__24301_args$jscomp$115$$);return $G__24299__delegate$$($arglist__24301_args$jscomp$115$$)};$G__24299$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__24299__delegate$$;return $G__24299$$}()};
$APP.$clojure$string$replace$$=function($s$jscomp$137$$,$match$jscomp$9$$,$replacement$jscomp$6$$){if(typeof $match$jscomp$9$$==="string")return $s$jscomp$137$$.replace(new RegExp($goog$string$regExpEscape$$($match$jscomp$9$$),"g"),$replacement$jscomp$6$$);if($match$jscomp$9$$ instanceof RegExp)return typeof $replacement$jscomp$6$$==="string"?$clojure$string$replace_all$$($s$jscomp$137$$,$match$jscomp$9$$,$replacement$jscomp$6$$):$clojure$string$replace_all$$($s$jscomp$137$$,$match$jscomp$9$$,$clojure$string$replace_with$$($replacement$jscomp$6$$));
throw["Invalid match arg: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($match$jscomp$9$$)].join("");};$APP.$clojure$string$upper_case$$=function($s$jscomp$139$$){return $s$jscomp$139$$.toUpperCase()};$clojure$string$lower_case$$=function($s$jscomp$140$$){return $s$jscomp$140$$.toLowerCase()};
$clojure$string$split_with_empty_regex$$=function($s$jscomp$142$$,$c$jscomp$135_limit$jscomp$2$$){if($c$jscomp$135_limit$jscomp$2$$<=0||$c$jscomp$135_limit$jscomp$2$$>=2+$APP.$cljs$core$count$$($s$jscomp$142$$))return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$vec$$($APP.$cljs$core$cons$$("",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$seq$$($s$jscomp$142$$)))),"");if($APP.$cljs$core$truth_$$($cljs$core$_EQ__EQ_$cljs$0core$0IFn$0_invoke$0arity$02$$?
$cljs$core$_equiv$$(1,$c$jscomp$135_limit$jscomp$2$$):$cljs$core$_EQ__EQ_$$(1,$c$jscomp$135_limit$jscomp$2$$)))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$s$jscomp$142$$],null);if($APP.$cljs$core$truth_$$($cljs$core$_EQ__EQ_$cljs$0core$0IFn$0_invoke$0arity$02$$?$cljs$core$_equiv$$(2,$c$jscomp$135_limit$jscomp$2$$):$cljs$core$_EQ__EQ_$$(2,$c$jscomp$135_limit$jscomp$2$$)))return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["",$s$jscomp$142$$],null);$c$jscomp$135_limit$jscomp$2$$-=2;return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$vec$$($APP.$cljs$core$cons$$("",$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$seq$$($s$jscomp$142$$))),0,$c$jscomp$135_limit$jscomp$2$$))),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$142$$,$c$jscomp$135_limit$jscomp$2$$))};
$clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$02$$=function($s$jscomp$143$$,$re$jscomp$7$$){return $clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$143$$,$re$jscomp$7$$,0)};
$clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$03$$=function($s$jscomp$144_s__$1$jscomp$inline_2989$$,$JSCompiler_temp$jscomp$257_JSCompiler_temp$jscomp$258_re$jscomp$8_v$jscomp$inline_11325$$,$JSCompiler_temp$jscomp$inline_11326_limit$jscomp$3_v__$1$jscomp$inline_11327$$){if("/(?:)/"===$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$257_JSCompiler_temp$jscomp$258_re$jscomp$8_v$jscomp$inline_11325$$))$JSCompiler_temp$jscomp$257_JSCompiler_temp$jscomp$258_re$jscomp$8_v$jscomp$inline_11325$$=$clojure$string$split_with_empty_regex$$($s$jscomp$144_s__$1$jscomp$inline_2989$$,
$JSCompiler_temp$jscomp$inline_11326_limit$jscomp$3_v__$1$jscomp$inline_11327$$);else if($JSCompiler_temp$jscomp$inline_11326_limit$jscomp$3_v__$1$jscomp$inline_11327$$<1)$JSCompiler_temp$jscomp$257_JSCompiler_temp$jscomp$258_re$jscomp$8_v$jscomp$inline_11325$$=$APP.$cljs$core$vec$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$144_s__$1$jscomp$inline_2989$$).split($JSCompiler_temp$jscomp$257_JSCompiler_temp$jscomp$258_re$jscomp$8_v$jscomp$inline_11325$$));else a:{for(var $G__24333$jscomp$inline_2995_limit__$1$jscomp$inline_2990$$=
$JSCompiler_temp$jscomp$inline_11326_limit$jscomp$3_v__$1$jscomp$inline_11327$$,$G__24334$jscomp$inline_2996_parts$jscomp$inline_2991$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){if(1===$G__24333$jscomp$inline_2995_limit__$1$jscomp$inline_2990$$){$JSCompiler_temp$jscomp$257_JSCompiler_temp$jscomp$258_re$jscomp$8_v$jscomp$inline_11325$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__24334$jscomp$inline_2996_parts$jscomp$inline_2991$$,$s$jscomp$144_s__$1$jscomp$inline_2989$$);break a}var $G__24332$jscomp$inline_2994_m$jscomp$inline_2992$$=
$APP.$cljs$core$re_find$$($JSCompiler_temp$jscomp$257_JSCompiler_temp$jscomp$258_re$jscomp$8_v$jscomp$inline_11325$$,$s$jscomp$144_s__$1$jscomp$inline_2989$$);if($G__24332$jscomp$inline_2994_m$jscomp$inline_2992$$!=null){var $index$jscomp$inline_2993$$=$s$jscomp$144_s__$1$jscomp$inline_2989$$.indexOf($G__24332$jscomp$inline_2994_m$jscomp$inline_2992$$);$G__24332$jscomp$inline_2994_m$jscomp$inline_2992$$=$s$jscomp$144_s__$1$jscomp$inline_2989$$.substring($index$jscomp$inline_2993$$+$APP.$cljs$core$count$$($G__24332$jscomp$inline_2994_m$jscomp$inline_2992$$));
--$G__24333$jscomp$inline_2995_limit__$1$jscomp$inline_2990$$;$G__24334$jscomp$inline_2996_parts$jscomp$inline_2991$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__24334$jscomp$inline_2996_parts$jscomp$inline_2991$$,$s$jscomp$144_s__$1$jscomp$inline_2989$$.substring(0,$index$jscomp$inline_2993$$));$s$jscomp$144_s__$1$jscomp$inline_2989$$=$G__24332$jscomp$inline_2994_m$jscomp$inline_2992$$}else{$JSCompiler_temp$jscomp$257_JSCompiler_temp$jscomp$258_re$jscomp$8_v$jscomp$inline_11325$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__24334$jscomp$inline_2996_parts$jscomp$inline_2991$$,$s$jscomp$144_s__$1$jscomp$inline_2989$$);break a}}$JSCompiler_temp$jscomp$257_JSCompiler_temp$jscomp$258_re$jscomp$8_v$jscomp$inline_11325$$=void 0}if(0===$JSCompiler_temp$jscomp$inline_11326_limit$jscomp$3_v__$1$jscomp$inline_11327$$&&1<$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$257_JSCompiler_temp$jscomp$258_re$jscomp$8_v$jscomp$inline_11325$$))a:{for($JSCompiler_temp$jscomp$inline_11326_limit$jscomp$3_v__$1$jscomp$inline_11327$$=
$JSCompiler_temp$jscomp$257_JSCompiler_temp$jscomp$258_re$jscomp$8_v$jscomp$inline_11325$$;;)if(""===$APP.$cljs$core$peek$$($JSCompiler_temp$jscomp$inline_11326_limit$jscomp$3_v__$1$jscomp$inline_11327$$))$JSCompiler_temp$jscomp$inline_11326_limit$jscomp$3_v__$1$jscomp$inline_11327$$=$APP.$cljs$core$pop$$($JSCompiler_temp$jscomp$inline_11326_limit$jscomp$3_v__$1$jscomp$inline_11327$$);else break a;$JSCompiler_temp$jscomp$inline_11326_limit$jscomp$3_v__$1$jscomp$inline_11327$$=void 0}else $JSCompiler_temp$jscomp$inline_11326_limit$jscomp$3_v__$1$jscomp$inline_11327$$=
$JSCompiler_temp$jscomp$257_JSCompiler_temp$jscomp$258_re$jscomp$8_v$jscomp$inline_11325$$;return $JSCompiler_temp$jscomp$inline_11326_limit$jscomp$3_v__$1$jscomp$inline_11327$$};$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$=function($result$jscomp$76_s$jscomp$152$$,$value$jscomp$212$$){$result$jscomp$76_s$jscomp$152$$=$result$jscomp$76_s$jscomp$152$$.indexOf($value$jscomp$212$$);return $result$jscomp$76_s$jscomp$152$$<0?null:$result$jscomp$76_s$jscomp$152$$};
$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$=function($result$jscomp$77_s$jscomp$153$$,$value$jscomp$213$$,$from_index$$){$result$jscomp$77_s$jscomp$153$$=$result$jscomp$77_s$jscomp$153$$.indexOf($value$jscomp$213$$,$from_index$$);return $result$jscomp$77_s$jscomp$153$$<0?null:$result$jscomp$77_s$jscomp$153$$};$APP.$cljs$tools$reader$impl$utils$char$0$$=function($x$jscomp$656$$){return $x$jscomp$656$$==null?null:$APP.$cljs$core$char$0$$($x$jscomp$656$$)};
$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$=function($ch$jscomp$7$$){return $ch$jscomp$7$$==null?null:$ch$jscomp$7$$===","?!0:$cljs$tools$reader$impl$utils$ws_rx$$.test($ch$jscomp$7$$)};$APP.$cljs$tools$reader$impl$utils$numeric_QMARK_$$=function($ch$jscomp$8$$){return $ch$jscomp$8$$==null?null:!/[^0-9]/.test($ch$jscomp$8$$)};
$APP.$cljs$tools$reader$impl$utils$desugar_meta$$=function($f$jscomp$335$$){return $f$jscomp$335$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$f$jscomp$335$$,!0]):$f$jscomp$335$$ instanceof $APP.$cljs$core$Symbol$$?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$78$tag$$,$f$jscomp$335$$],null):typeof $f$jscomp$335$$==="string"?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$78$tag$$,$f$jscomp$335$$],null):$APP.$cljs$core$vector_QMARK_$$($f$jscomp$335$$)?
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$181$param_tags$$,$f$jscomp$335$$],null):$f$jscomp$335$$};
$APP.$cljs$tools$reader$impl$utils$namespace_keys$$=function($ns$jscomp$16$$,$keys$jscomp$19$$){return function $cljs$tools$reader$impl$utils$namespace_keys_$_iter__24355$$($s__24356$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__24356__$2_temp__5825__auto__$jscomp$40$$=$APP.$cljs$core$seq$$($s__24356$$);if($s__24356__$2_temp__5825__auto__$jscomp$40$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__24356__$2_temp__5825__auto__$jscomp$40$$)){var $c__5501__auto__$$=$APP.$cljs$core$_chunked_first$$($s__24356__$2_temp__5825__auto__$jscomp$40$$),
$size__5502__auto__$$=$APP.$cljs$core$count$$($c__5501__auto__$$),$b__24359$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$$);return function(){for(var $i__24358$$=0;;)if($i__24358$$<$size__5502__auto__$$){var $JSCompiler_temp$jscomp$261_key$jscomp$174$$=$APP.$cljs$core$_nth$$($c__5501__auto__$$,$i__24358$$),$JSCompiler_temp_const$jscomp$260$$=$b__24359$$;if($JSCompiler_temp$jscomp$261_key$jscomp$174$$ instanceof $APP.$cljs$core$Symbol$$||$JSCompiler_temp$jscomp$261_key$jscomp$174$$ instanceof
$APP.$cljs$core$Keyword$$){var $key_name$jscomp$inline_3000_vec__24367$jscomp$inline_2998$$=$APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$namespace$$,$APP.$cljs$core$name$$)($JSCompiler_temp$jscomp$261_key$jscomp$174$$),$key_ns$jscomp$inline_2999$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($key_name$jscomp$inline_3000_vec__24367$jscomp$inline_2998$$,0,null);$key_name$jscomp$inline_3000_vec__24367$jscomp$inline_2998$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($key_name$jscomp$inline_3000_vec__24367$jscomp$inline_2998$$,
1,null);var $__GT_key$jscomp$inline_3001$$=$JSCompiler_temp$jscomp$261_key$jscomp$174$$ instanceof $APP.$cljs$core$Symbol$$?$APP.$cljs$core$symbol$$:$APP.$cljs$core$keyword$$;$JSCompiler_temp$jscomp$261_key$jscomp$174$$=$key_ns$jscomp$inline_2999$$==null?$__GT_key$jscomp$inline_3001$$.$cljs$core$IFn$_invoke$arity$2$?$__GT_key$jscomp$inline_3001$$.$cljs$core$IFn$_invoke$arity$2$($ns$jscomp$16$$,$key_name$jscomp$inline_3000_vec__24367$jscomp$inline_2998$$):$__GT_key$jscomp$inline_3001$$($ns$jscomp$16$$,
$key_name$jscomp$inline_3000_vec__24367$jscomp$inline_2998$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("_",$key_ns$jscomp$inline_2999$$)?$__GT_key$jscomp$inline_3001$$.$cljs$core$IFn$_invoke$arity$1$?$__GT_key$jscomp$inline_3001$$.$cljs$core$IFn$_invoke$arity$1$($key_name$jscomp$inline_3000_vec__24367$jscomp$inline_2998$$):$__GT_key$jscomp$inline_3001$$($key_name$jscomp$inline_3000_vec__24367$jscomp$inline_2998$$):$JSCompiler_temp$jscomp$261_key$jscomp$174$$}$JSCompiler_temp_const$jscomp$260$$.add($JSCompiler_temp$jscomp$261_key$jscomp$174$$);
$i__24358$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__24359$$),$cljs$tools$reader$impl$utils$namespace_keys_$_iter__24355$$($APP.$cljs$core$_chunked_rest$$($s__24356__$2_temp__5825__auto__$jscomp$40$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__24359$$),null)}var $key$jscomp$173$$=$APP.$cljs$core$first$$($s__24356__$2_temp__5825__auto__$jscomp$40$$);return $APP.$cljs$core$cons$$($key$jscomp$173$$ instanceof $APP.$cljs$core$Symbol$$||$key$jscomp$173$$ instanceof
$APP.$cljs$core$Keyword$$?function(){var $key_name$jscomp$1_vec__24376$$=$APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$namespace$$,$APP.$cljs$core$name$$)($key$jscomp$173$$),$key_ns$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($key_name$jscomp$1_vec__24376$$,0,null);$key_name$jscomp$1_vec__24376$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($key_name$jscomp$1_vec__24376$$,1,null);var $__GT_key$jscomp$1$$=$key$jscomp$173$$ instanceof $APP.$cljs$core$Symbol$$?
$APP.$cljs$core$symbol$$:$APP.$cljs$core$keyword$$;return $key_ns$jscomp$1$$==null?$__GT_key$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$__GT_key$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($ns$jscomp$16$$,$key_name$jscomp$1_vec__24376$$):$__GT_key$jscomp$1$$($ns$jscomp$16$$,$key_name$jscomp$1_vec__24376$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("_",$key_ns$jscomp$1$$)?$__GT_key$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$__GT_key$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($key_name$jscomp$1_vec__24376$$):
$__GT_key$jscomp$1$$($key_name$jscomp$1_vec__24376$$):$key$jscomp$173$$}():$key$jscomp$173$$,$cljs$tools$reader$impl$utils$namespace_keys_$_iter__24355$$($APP.$cljs$core$rest$$($s__24356__$2_temp__5825__auto__$jscomp$40$$)))}return null}},null,null)}($keys$jscomp$19$$)};
$APP.$cljs$tools$reader$impl$utils$second_SINGLEQUOTE_$$=function($b$jscomp$160_p__24384$$){var $a$jscomp$192$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$160_p__24384$$,0,null);$b$jscomp$160_p__24384$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$160_p__24384$$,1,null);return $APP.$cljs$core$truth_$$($a$jscomp$192$$)?null:$b$jscomp$160_p__24384$$};
$APP.$cljs$tools$reader$impl$utils$char_code$$=function($ch$jscomp$9_code$jscomp$2$$,$base$jscomp$8$$){$ch$jscomp$9_code$jscomp$2$$=parseInt($ch$jscomp$9_code$jscomp$2$$,$base$jscomp$8$$);return $APP.$cljs$core$truth_$$(isNaN($ch$jscomp$9_code$jscomp$2$$))?-1:$ch$jscomp$9_code$jscomp$2$$};
$APP.$cljs$tools$reader$reader_types$read_char$$=function($JSCompiler_temp$jscomp$262_reader$jscomp$1$$){if($JSCompiler_temp$jscomp$262_reader$jscomp$1$$!=null&&$JSCompiler_temp$jscomp$262_reader$jscomp$1$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$!=null)$JSCompiler_temp$jscomp$262_reader$jscomp$1$$=$JSCompiler_temp$jscomp$262_reader$jscomp$1$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$($JSCompiler_temp$jscomp$262_reader$jscomp$1$$);else{var $m__5372__auto__$jscomp$inline_3005_m__5374__auto__$jscomp$inline_3004$$=
$APP.$cljs$tools$reader$reader_types$read_char$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$262_reader$jscomp$1$$==null?null:$JSCompiler_temp$jscomp$262_reader$jscomp$1$$)];if($m__5372__auto__$jscomp$inline_3005_m__5374__auto__$jscomp$inline_3004$$!=null)$JSCompiler_temp$jscomp$262_reader$jscomp$1$$=$m__5372__auto__$jscomp$inline_3005_m__5374__auto__$jscomp$inline_3004$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3005_m__5374__auto__$jscomp$inline_3004$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$262_reader$jscomp$1$$):
$m__5372__auto__$jscomp$inline_3005_m__5374__auto__$jscomp$inline_3004$$($JSCompiler_temp$jscomp$262_reader$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_3005_m__5374__auto__$jscomp$inline_3004$$=$APP.$cljs$tools$reader$reader_types$read_char$$._,$m__5372__auto__$jscomp$inline_3005_m__5374__auto__$jscomp$inline_3004$$!=null)$JSCompiler_temp$jscomp$262_reader$jscomp$1$$=$m__5372__auto__$jscomp$inline_3005_m__5374__auto__$jscomp$inline_3004$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3005_m__5374__auto__$jscomp$inline_3004$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$262_reader$jscomp$1$$):
$m__5372__auto__$jscomp$inline_3005_m__5374__auto__$jscomp$inline_3004$$($JSCompiler_temp$jscomp$262_reader$jscomp$1$$);else throw $APP.$cljs$core$missing_protocol$$("Reader.read-char",$JSCompiler_temp$jscomp$262_reader$jscomp$1$$);}return $JSCompiler_temp$jscomp$262_reader$jscomp$1$$};
$cljs$tools$reader$reader_types$peek_char$$=function($JSCompiler_temp$jscomp$263_reader$jscomp$3$$){if($JSCompiler_temp$jscomp$263_reader$jscomp$3$$!=null&&$JSCompiler_temp$jscomp$263_reader$jscomp$3$$.$cljs$tools$reader$reader_types$Reader$peek_char$arity$1$!=null)$JSCompiler_temp$jscomp$263_reader$jscomp$3$$=$JSCompiler_temp$jscomp$263_reader$jscomp$3$$.$cljs$tools$reader$reader_types$Reader$peek_char$arity$1$($JSCompiler_temp$jscomp$263_reader$jscomp$3$$);else{var $m__5372__auto__$jscomp$inline_3009_m__5374__auto__$jscomp$inline_3008$$=
$cljs$tools$reader$reader_types$peek_char$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$263_reader$jscomp$3$$==null?null:$JSCompiler_temp$jscomp$263_reader$jscomp$3$$)];if($m__5372__auto__$jscomp$inline_3009_m__5374__auto__$jscomp$inline_3008$$!=null)$JSCompiler_temp$jscomp$263_reader$jscomp$3$$=$m__5372__auto__$jscomp$inline_3009_m__5374__auto__$jscomp$inline_3008$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3009_m__5374__auto__$jscomp$inline_3008$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$263_reader$jscomp$3$$):
$m__5372__auto__$jscomp$inline_3009_m__5374__auto__$jscomp$inline_3008$$($JSCompiler_temp$jscomp$263_reader$jscomp$3$$);else if($m__5372__auto__$jscomp$inline_3009_m__5374__auto__$jscomp$inline_3008$$=$cljs$tools$reader$reader_types$peek_char$$._,$m__5372__auto__$jscomp$inline_3009_m__5374__auto__$jscomp$inline_3008$$!=null)$JSCompiler_temp$jscomp$263_reader$jscomp$3$$=$m__5372__auto__$jscomp$inline_3009_m__5374__auto__$jscomp$inline_3008$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3009_m__5374__auto__$jscomp$inline_3008$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$263_reader$jscomp$3$$):
$m__5372__auto__$jscomp$inline_3009_m__5374__auto__$jscomp$inline_3008$$($JSCompiler_temp$jscomp$263_reader$jscomp$3$$);else throw $APP.$cljs$core$missing_protocol$$("Reader.peek-char",$JSCompiler_temp$jscomp$263_reader$jscomp$3$$);}return $JSCompiler_temp$jscomp$263_reader$jscomp$3$$};
$APP.$cljs$tools$reader$reader_types$unread$$=function($reader$jscomp$5$$,$ch$jscomp$11$$){if($reader$jscomp$5$$!=null&&$reader$jscomp$5$$.$cljs$tools$reader$reader_types$IPushbackReader$unread$arity$2$!=null)$reader$jscomp$5$$.$cljs$tools$reader$reader_types$IPushbackReader$unread$arity$2$($reader$jscomp$5$$,$ch$jscomp$11$$);else{var $m__5372__auto__$jscomp$inline_3014_m__5374__auto__$jscomp$inline_3013$$=$APP.$cljs$tools$reader$reader_types$unread$$[$APP.$goog$typeOf$$($reader$jscomp$5$$==null?
null:$reader$jscomp$5$$)];if($m__5372__auto__$jscomp$inline_3014_m__5374__auto__$jscomp$inline_3013$$!=null)$m__5372__auto__$jscomp$inline_3014_m__5374__auto__$jscomp$inline_3013$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3014_m__5374__auto__$jscomp$inline_3013$$.$cljs$core$IFn$_invoke$arity$2$($reader$jscomp$5$$,$ch$jscomp$11$$):$m__5372__auto__$jscomp$inline_3014_m__5374__auto__$jscomp$inline_3013$$($reader$jscomp$5$$,$ch$jscomp$11$$);else if($m__5372__auto__$jscomp$inline_3014_m__5374__auto__$jscomp$inline_3013$$=
$APP.$cljs$tools$reader$reader_types$unread$$._,$m__5372__auto__$jscomp$inline_3014_m__5374__auto__$jscomp$inline_3013$$!=null)$m__5372__auto__$jscomp$inline_3014_m__5374__auto__$jscomp$inline_3013$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3014_m__5374__auto__$jscomp$inline_3013$$.$cljs$core$IFn$_invoke$arity$2$($reader$jscomp$5$$,$ch$jscomp$11$$):$m__5372__auto__$jscomp$inline_3014_m__5374__auto__$jscomp$inline_3013$$($reader$jscomp$5$$,$ch$jscomp$11$$);else throw $APP.$cljs$core$missing_protocol$$("IPushbackReader.unread",
$reader$jscomp$5$$);}};
$APP.$cljs$tools$reader$reader_types$get_line_number$$=function($JSCompiler_temp$jscomp$265_reader$jscomp$7$$){if($JSCompiler_temp$jscomp$265_reader$jscomp$7$$!=null&&$JSCompiler_temp$jscomp$265_reader$jscomp$7$$.$cljs$tools$reader$reader_types$IndexingReader$get_line_number$arity$1$!=null)$JSCompiler_temp$jscomp$265_reader$jscomp$7$$=$JSCompiler_temp$jscomp$265_reader$jscomp$7$$.$cljs$tools$reader$reader_types$IndexingReader$get_line_number$arity$1$($JSCompiler_temp$jscomp$265_reader$jscomp$7$$);else{var $m__5372__auto__$jscomp$inline_3018_m__5374__auto__$jscomp$inline_3017$$=
$APP.$cljs$tools$reader$reader_types$get_line_number$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$265_reader$jscomp$7$$==null?null:$JSCompiler_temp$jscomp$265_reader$jscomp$7$$)];if($m__5372__auto__$jscomp$inline_3018_m__5374__auto__$jscomp$inline_3017$$!=null)$JSCompiler_temp$jscomp$265_reader$jscomp$7$$=$m__5372__auto__$jscomp$inline_3018_m__5374__auto__$jscomp$inline_3017$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3018_m__5374__auto__$jscomp$inline_3017$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$265_reader$jscomp$7$$):
$m__5372__auto__$jscomp$inline_3018_m__5374__auto__$jscomp$inline_3017$$($JSCompiler_temp$jscomp$265_reader$jscomp$7$$);else if($m__5372__auto__$jscomp$inline_3018_m__5374__auto__$jscomp$inline_3017$$=$APP.$cljs$tools$reader$reader_types$get_line_number$$._,$m__5372__auto__$jscomp$inline_3018_m__5374__auto__$jscomp$inline_3017$$!=null)$JSCompiler_temp$jscomp$265_reader$jscomp$7$$=$m__5372__auto__$jscomp$inline_3018_m__5374__auto__$jscomp$inline_3017$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3018_m__5374__auto__$jscomp$inline_3017$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$265_reader$jscomp$7$$):
$m__5372__auto__$jscomp$inline_3018_m__5374__auto__$jscomp$inline_3017$$($JSCompiler_temp$jscomp$265_reader$jscomp$7$$);else throw $APP.$cljs$core$missing_protocol$$("IndexingReader.get-line-number",$JSCompiler_temp$jscomp$265_reader$jscomp$7$$);}return $JSCompiler_temp$jscomp$265_reader$jscomp$7$$};
$cljs$tools$reader$reader_types$get_column_number$$=function($JSCompiler_temp$jscomp$266_reader$jscomp$9$$){if($JSCompiler_temp$jscomp$266_reader$jscomp$9$$!=null&&$JSCompiler_temp$jscomp$266_reader$jscomp$9$$.$cljs$tools$reader$reader_types$IndexingReader$get_column_number$arity$1$!=null)$JSCompiler_temp$jscomp$266_reader$jscomp$9$$=$JSCompiler_temp$jscomp$266_reader$jscomp$9$$.$cljs$tools$reader$reader_types$IndexingReader$get_column_number$arity$1$($JSCompiler_temp$jscomp$266_reader$jscomp$9$$);
else{var $m__5372__auto__$jscomp$inline_3022_m__5374__auto__$jscomp$inline_3021$$=$cljs$tools$reader$reader_types$get_column_number$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$266_reader$jscomp$9$$==null?null:$JSCompiler_temp$jscomp$266_reader$jscomp$9$$)];if($m__5372__auto__$jscomp$inline_3022_m__5374__auto__$jscomp$inline_3021$$!=null)$JSCompiler_temp$jscomp$266_reader$jscomp$9$$=$m__5372__auto__$jscomp$inline_3022_m__5374__auto__$jscomp$inline_3021$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3022_m__5374__auto__$jscomp$inline_3021$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$266_reader$jscomp$9$$):
$m__5372__auto__$jscomp$inline_3022_m__5374__auto__$jscomp$inline_3021$$($JSCompiler_temp$jscomp$266_reader$jscomp$9$$);else if($m__5372__auto__$jscomp$inline_3022_m__5374__auto__$jscomp$inline_3021$$=$cljs$tools$reader$reader_types$get_column_number$$._,$m__5372__auto__$jscomp$inline_3022_m__5374__auto__$jscomp$inline_3021$$!=null)$JSCompiler_temp$jscomp$266_reader$jscomp$9$$=$m__5372__auto__$jscomp$inline_3022_m__5374__auto__$jscomp$inline_3021$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3022_m__5374__auto__$jscomp$inline_3021$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$266_reader$jscomp$9$$):
$m__5372__auto__$jscomp$inline_3022_m__5374__auto__$jscomp$inline_3021$$($JSCompiler_temp$jscomp$266_reader$jscomp$9$$);else throw $APP.$cljs$core$missing_protocol$$("IndexingReader.get-column-number",$JSCompiler_temp$jscomp$266_reader$jscomp$9$$);}return $JSCompiler_temp$jscomp$266_reader$jscomp$9$$};
$APP.$cljs$tools$reader$reader_types$get_file_name$$=function($JSCompiler_temp$jscomp$267_reader$jscomp$11$$){if($JSCompiler_temp$jscomp$267_reader$jscomp$11$$!=null&&$JSCompiler_temp$jscomp$267_reader$jscomp$11$$.$cljs$tools$reader$reader_types$IndexingReader$get_file_name$arity$1$!=null)$JSCompiler_temp$jscomp$267_reader$jscomp$11$$=$JSCompiler_temp$jscomp$267_reader$jscomp$11$$.$cljs$tools$reader$reader_types$IndexingReader$get_file_name$arity$1$($JSCompiler_temp$jscomp$267_reader$jscomp$11$$);
else{var $m__5372__auto__$jscomp$inline_3026_m__5374__auto__$jscomp$inline_3025$$=$APP.$cljs$tools$reader$reader_types$get_file_name$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$267_reader$jscomp$11$$==null?null:$JSCompiler_temp$jscomp$267_reader$jscomp$11$$)];if($m__5372__auto__$jscomp$inline_3026_m__5374__auto__$jscomp$inline_3025$$!=null)$JSCompiler_temp$jscomp$267_reader$jscomp$11$$=$m__5372__auto__$jscomp$inline_3026_m__5374__auto__$jscomp$inline_3025$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3026_m__5374__auto__$jscomp$inline_3025$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$267_reader$jscomp$11$$):
$m__5372__auto__$jscomp$inline_3026_m__5374__auto__$jscomp$inline_3025$$($JSCompiler_temp$jscomp$267_reader$jscomp$11$$);else if($m__5372__auto__$jscomp$inline_3026_m__5374__auto__$jscomp$inline_3025$$=$APP.$cljs$tools$reader$reader_types$get_file_name$$._,$m__5372__auto__$jscomp$inline_3026_m__5374__auto__$jscomp$inline_3025$$!=null)$JSCompiler_temp$jscomp$267_reader$jscomp$11$$=$m__5372__auto__$jscomp$inline_3026_m__5374__auto__$jscomp$inline_3025$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3026_m__5374__auto__$jscomp$inline_3025$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$267_reader$jscomp$11$$):
$m__5372__auto__$jscomp$inline_3026_m__5374__auto__$jscomp$inline_3025$$($JSCompiler_temp$jscomp$267_reader$jscomp$11$$);else throw $APP.$cljs$core$missing_protocol$$("IndexingReader.get-file-name",$JSCompiler_temp$jscomp$267_reader$jscomp$11$$);}return $JSCompiler_temp$jscomp$267_reader$jscomp$11$$};$APP.$cljs$tools$reader$reader_types$StringReader$$=function($s$jscomp$159$$,$s_len$$){this.s=$s$jscomp$159$$;this.$s_len$=$s_len$$;this.$s_pos$=0};
$APP.$cljs$tools$reader$reader_types$PushbackReader$$=function($rdr$$){var $buf$jscomp$5$$=$cljs$core$object_array$cljs$0core$0IFn$0_invoke$0arity$01$$(1);this.$rdr$=$rdr$$;this.$buf$=$buf$jscomp$5$$;this.$buf_pos$=this.$buf_len$=1};$APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$=function($rdr$jscomp$7$$){return $rdr$jscomp$7$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$rdr$jscomp$7$$.$cljs$tools$reader$reader_types$IndexingReader$$?!0:!1:!1};
$cljs$tools$reader$impl$inspect$inspect_STAR__col$$=function($l$jscomp$73_truncate$$,$col$jscomp$13_content$jscomp$9_elements$$,$start$jscomp$151$$,$end$jscomp$40$$){var $n$jscomp$170_suffix$jscomp$2$$=$APP.$cljs$core$count$$($col$jscomp$13_content$jscomp$9_elements$$);$l$jscomp$73_truncate$$=$APP.$cljs$core$truth_$$($l$jscomp$73_truncate$$)?0:10<$n$jscomp$170_suffix$jscomp$2$$?10:$n$jscomp$170_suffix$jscomp$2$$;$col$jscomp$13_content$jscomp$9_elements$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$tools$reader$impl$inspect$inspect_STAR_$$,
!0),$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($l$jscomp$73_truncate$$,$col$jscomp$13_content$jscomp$9_elements$$));$col$jscomp$13_content$jscomp$9_elements$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$interpose$cljs$0core$0IFn$0_invoke$0arity$02$$(" ",$col$jscomp$13_content$jscomp$9_elements$$));$n$jscomp$170_suffix$jscomp$2$$=$l$jscomp$73_truncate$$<$n$jscomp$170_suffix$jscomp$2$$?"...":null;return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($start$jscomp$151$$),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($col$jscomp$13_content$jscomp$9_elements$$),$n$jscomp$170_suffix$jscomp$2$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$40$$)].join("")};$cljs$tools$reader$impl$inspect$inspect$cljs$0core$0IFn$0_invoke$0arity$01$$=function($x$jscomp$666$$){return $cljs$tools$reader$impl$inspect$inspect_STAR_$$.$cljs$core$IFn$_invoke$arity$2$(!1,$x$jscomp$666$$)};
$cljs$tools$reader$impl$errors$throw_ex$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($details$jscomp$2_rdr$jscomp$12$$,$details$jscomp$inline_11341_ex_type$jscomp$1_line$jscomp$11_msg2$$,$full_msg_msg$jscomp$5$$){$details$jscomp$inline_11341_ex_type$jscomp$1_line$jscomp$11_msg2$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$206$reader_exception$$,$cljs$cst$207$ex_kind$$,$details$jscomp$inline_11341_ex_type$jscomp$1_line$jscomp$11_msg2$$],null);
$details$jscomp$2_rdr$jscomp$12$$=$APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$($details$jscomp$2_rdr$jscomp$12$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($details$jscomp$inline_11341_ex_type$jscomp$1_line$jscomp$11_msg2$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$tools$reader$reader_types$get_file_name$$($details$jscomp$2_rdr$jscomp$12$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$209$line$$,$APP.$cljs$tools$reader$reader_types$get_line_number$$($details$jscomp$2_rdr$jscomp$12$$),
$cljs$cst$210$col$$,$cljs$tools$reader$reader_types$get_column_number$$($details$jscomp$2_rdr$jscomp$12$$)])):$details$jscomp$inline_11341_ex_type$jscomp$1_line$jscomp$11_msg2$$;var $file$jscomp$1_msg1$$=$APP.$cljs$cst$208$file$$.$cljs$core$IFn$_invoke$arity$1$($details$jscomp$2_rdr$jscomp$12$$);$details$jscomp$inline_11341_ex_type$jscomp$1_line$jscomp$11_msg2$$=$APP.$cljs$cst$209$line$$.$cljs$core$IFn$_invoke$arity$1$($details$jscomp$2_rdr$jscomp$12$$);var $col$jscomp$17$$=$cljs$cst$210$col$$.$cljs$core$IFn$_invoke$arity$1$($details$jscomp$2_rdr$jscomp$12$$);
$file$jscomp$1_msg1$$=$APP.$cljs$core$truth_$$($file$jscomp$1_msg1$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$1_msg1$$)," "].join(""):null;$details$jscomp$inline_11341_ex_type$jscomp$1_line$jscomp$11_msg2$$=$APP.$cljs$core$truth_$$($details$jscomp$inline_11341_ex_type$jscomp$1_line$jscomp$11_msg2$$)?["[line ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($details$jscomp$inline_11341_ex_type$jscomp$1_line$jscomp$11_msg2$$),", col ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($col$jscomp$17$$),
"]"].join(""):null;$full_msg_msg$jscomp$5$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$str$$,$file$jscomp$1_msg1$$,$details$jscomp$inline_11341_ex_type$jscomp$1_line$jscomp$11_msg2$$,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($file$jscomp$1_msg1$$)?$file$jscomp$1_msg1$$:$details$jscomp$inline_11341_ex_type$jscomp$1_line$jscomp$11_msg2$$)?" ":null,$full_msg_msg$jscomp$5$$);throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$($full_msg_msg$jscomp$5$$,
$details$jscomp$2_rdr$jscomp$12$$);};$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($rdr$jscomp$13$$,$msgs$$){return $cljs$tools$reader$impl$errors$throw_ex$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$13$$,$cljs$cst$211$reader_error$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$msgs$$)]))};
$cljs$tools$reader$impl$errors$illegal_arg_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($rdr$jscomp$14$$,$msgs$jscomp$1$$){return $cljs$tools$reader$impl$errors$throw_ex$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$14$$,$cljs$cst$212$illegal_argument$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$msgs$jscomp$1$$)]))};
$cljs$tools$reader$impl$errors$eof_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($rdr$jscomp$15$$,$msgs$jscomp$2$$){return $cljs$tools$reader$impl$errors$throw_ex$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$15$$,$cljs$cst$213$eof$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$msgs$jscomp$2$$)]))};
$APP.$cljs$tools$reader$impl$errors$throw_eof_delimited$cljs$0core$0IFn$0_invoke$0arity$05$$=function($rdr$jscomp$17$$,$kind$jscomp$5$$,$line$jscomp$13$$,$column$jscomp$5$$,$n$jscomp$172$$){return $cljs$tools$reader$impl$errors$eof_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$17$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Unexpected EOF while reading ",$APP.$cljs$core$truth_$$($n$jscomp$172$$)?["item ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$172$$),
" of "].join(""):null,$APP.$cljs$core$name$$($kind$jscomp$5$$),$APP.$cljs$core$truth_$$($line$jscomp$13$$)?[", starting at line ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($line$jscomp$13$$)," and column ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($column$jscomp$5$$)].join(""):null,"."]))};
$APP.$cljs$tools$reader$impl$errors$throw_odd_map$$=function($rdr$jscomp$18$$,$line$jscomp$14$$,$col$jscomp$18$$,$elements$jscomp$1$$){$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$18$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["The map literal starting with ",$cljs$tools$reader$impl$inspect$inspect$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$first$$($elements$jscomp$1$$)),$APP.$cljs$core$truth_$$($line$jscomp$14$$)?
[" on line ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($line$jscomp$14$$)," column ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($col$jscomp$18$$)].join(""):null," contains ",$APP.$cljs$core$count$$($elements$jscomp$1$$)," form(s). Map literals must contain an even number of forms."]))};
$APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_literal$$=function($token$jscomp$11$$){throw $cljs$tools$reader$impl$errors$illegal_arg_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid unicode literal: \\",$token$jscomp$11$$,"."]));};
$APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_escape$$=function($rdr$jscomp$21$$,$ch$jscomp$18$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$21$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid unicode escape: \\u",$ch$jscomp$18$$,"."]))};
$APP.$cljs$tools$reader$impl$errors$throw_invalid$$=function($rdr$jscomp$22$$,$kind$jscomp$6$$,$token$jscomp$12$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$22$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid ",$APP.$cljs$core$name$$($kind$jscomp$6$$),": ",$token$jscomp$12$$,"."]))};
$APP.$cljs$tools$reader$impl$errors$throw_eof_at_start$$=function($rdr$jscomp$23$$,$kind$jscomp$7$$){return $cljs$tools$reader$impl$errors$eof_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$23$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Unexpected EOF while reading start of ",$APP.$cljs$core$name$$($kind$jscomp$7$$),"."]))};
$cljs$tools$reader$impl$errors$throw_bad_char$$=function($rdr$jscomp$24$$,$kind$jscomp$8$$,$ch$jscomp$19$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$24$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid character: ",$ch$jscomp$19$$," found while reading ",$APP.$cljs$core$name$$($kind$jscomp$8$$),"."]))};
$APP.$cljs$tools$reader$impl$errors$throw_eof_at_dispatch$$=function($rdr$jscomp$25$$){return $cljs$tools$reader$impl$errors$eof_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$25$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Unexpected EOF while reading dispatch character."]))};
$APP.$cljs$tools$reader$impl$errors$throw_eof_reading$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($rdr$jscomp$27$$,$kind$jscomp$9$$,$start$jscomp$152$$){a:{var $G__24457__$1$jscomp$inline_3030_init$jscomp$48$$=$kind$jscomp$9$$ instanceof $APP.$cljs$core$Keyword$$?$kind$jscomp$9$$.$fqn$:null;switch($G__24457__$1$jscomp$inline_3030_init$jscomp$48$$){case "regex":$G__24457__$1$jscomp$inline_3030_init$jscomp$48$$='#"';break a;case "string":$G__24457__$1$jscomp$inline_3030_init$jscomp$48$$='"';
break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__24457__$1$jscomp$inline_3030_init$jscomp$48$$)].join(""));}}return $cljs$tools$reader$impl$errors$eof_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$27$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Unexpected EOF reading ",$APP.$cljs$core$name$$($kind$jscomp$9$$)," starting ",$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$str$$,$G__24457__$1$jscomp$inline_3030_init$jscomp$48$$,
$start$jscomp$152$$),"."]))};$APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_digit_in_token$$=function($ch$jscomp$21$$,$token$jscomp$14$$){return $cljs$tools$reader$impl$errors$illegal_arg_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid digit ",$ch$jscomp$21$$," in unicode character \\",$token$jscomp$14$$,"."]))};
$APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_digit$$=function($rdr$jscomp$30$$,$ch$jscomp$22$$){return $cljs$tools$reader$impl$errors$illegal_arg_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$30$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid digit ",$ch$jscomp$22$$," in unicode character."]))};
$APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_len$$=function($rdr$jscomp$31$$,$actual$$,$expected$$){return $cljs$tools$reader$impl$errors$illegal_arg_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$31$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid unicode literal. Unicode literals should be ",$expected$$,"characters long. ","Value supplied is ",$actual$$," characters long."]))};
$APP.$cljs$tools$reader$impl$errors$throw_invalid_character_literal$$=function($rdr$jscomp$32$$,$token$jscomp$15$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$32$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid character literal \\u",$token$jscomp$15$$,"."]))};
$APP.$cljs$tools$reader$impl$errors$throw_invalid_octal_len$$=function($rdr$jscomp$33$$,$token$jscomp$16$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$33$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid octal escape sequence in a character literal: ",$token$jscomp$16$$,". Octal escape sequences must be 3 or fewer digits."]))};
$APP.$cljs$tools$reader$impl$errors$throw_bad_octal_number$$=function($rdr$jscomp$34$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$34$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Octal escape sequence must be in range [0, 377]."]))};
$APP.$cljs$tools$reader$impl$errors$throw_eof_in_character$$=function($rdr$jscomp$36$$){return $cljs$tools$reader$impl$errors$eof_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$36$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Unexpected EOF while reading character."]))};
$APP.$cljs$tools$reader$impl$errors$throw_bad_escape_char$$=function($rdr$jscomp$37$$,$ch$jscomp$23$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$37$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Unsupported escape character: \\",$ch$jscomp$23$$,"."]))};
$APP.$cljs$tools$reader$impl$errors$throw_single_colon$$=function($rdr$jscomp$38$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$38$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["A single colon is not a valid keyword."]))};
$APP.$cljs$tools$reader$impl$errors$throw_bad_metadata$$=function($rdr$jscomp$39$$,$x$jscomp$668$$){$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$39$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Metadata cannot be ",$cljs$tools$reader$impl$inspect$inspect$cljs$0core$0IFn$0_invoke$0arity$01$$($x$jscomp$668$$),". Metadata must be a Symbol, Keyword, String, Map or Vector."]))};
$APP.$cljs$tools$reader$impl$errors$throw_bad_metadata_target$$=function($rdr$jscomp$40$$,$target$jscomp$104$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$40$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Metadata can not be applied to ",$cljs$tools$reader$impl$inspect$inspect$cljs$0core$0IFn$0_invoke$0arity$01$$($target$jscomp$104$$),". ","Metadata can only be applied to IMetas."]))};
$APP.$cljs$tools$reader$impl$errors$throw_ns_map_no_map$$=function($rdr$jscomp$42$$,$ns_name$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$42$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Namespaced map with namespace ",$ns_name$$," does not specify a map."]))};
$APP.$cljs$tools$reader$impl$errors$throw_bad_ns$$=function($rdr$jscomp$43$$,$ns_name$jscomp$1$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$43$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid value used as namespace in namespaced map: ",$ns_name$jscomp$1$$,"."]))};
$APP.$cljs$tools$reader$impl$errors$throw_bad_reader_tag$$=function($rdr$jscomp$44$$,$tag$jscomp$16$$){$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$44$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid reader tag: ",$cljs$tools$reader$impl$inspect$inspect$cljs$0core$0IFn$0_invoke$0arity$01$$($tag$jscomp$16$$),". Reader tags must be symbols."]))};
$APP.$cljs$tools$reader$impl$errors$throw_unknown_reader_tag$$=function($rdr$jscomp$45$$,$tag$jscomp$17$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$45$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["No reader function for tag ",$cljs$tools$reader$impl$inspect$inspect$cljs$0core$0IFn$0_invoke$0arity$01$$($tag$jscomp$17$$),"."]))};
$cljs$tools$reader$impl$errors$duplicate_keys_error$$=function($msg$jscomp$6$$,$coll$jscomp$820_dups$$){$coll$jscomp$820_dups$$=function($seq$$){return function $cljs$tools$reader$impl$errors$duplicate_keys_error_$_duplicates_$_iter__24483$$($s__24484$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__24484__$1_s__24484__$2_temp__5825__auto__$jscomp$45$$=$s__24484$$;;)if($s__24484__$1_s__24484__$2_temp__5825__auto__$jscomp$45$$=$APP.$cljs$core$seq$$($s__24484__$1_s__24484__$2_temp__5825__auto__$jscomp$45$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__24484__$1_s__24484__$2_temp__5825__auto__$jscomp$45$$)){var $JSCompiler_inline_result$jscomp$269_c__5501__auto__$jscomp$1_id$jscomp$7$$=
$APP.$cljs$core$_chunked_first$$($s__24484__$1_s__24484__$2_temp__5825__auto__$jscomp$45$$),$size__5502__auto__$jscomp$1$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$269_c__5501__auto__$jscomp$1_id$jscomp$7$$),$b__24486_vec__24492$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$1$$);a:{for(var $i__24485$jscomp$inline_3032$$=0;;)if($i__24485$jscomp$inline_3032$$<$size__5502__auto__$jscomp$1$$){var $vec__24488$jscomp$inline_3033$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$269_c__5501__auto__$jscomp$1_id$jscomp$7$$,
$i__24485$jscomp$inline_3032$$),$id$jscomp$inline_3034$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__24488$jscomp$inline_3033$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__24488$jscomp$inline_3033$$,1,null)>1&&$b__24486_vec__24492$$.add($id$jscomp$inline_3034$$);$i__24485$jscomp$inline_3032$$+=1}else{$JSCompiler_inline_result$jscomp$269_c__5501__auto__$jscomp$1_id$jscomp$7$$=!0;break a}$JSCompiler_inline_result$jscomp$269_c__5501__auto__$jscomp$1_id$jscomp$7$$=
void 0}return $JSCompiler_inline_result$jscomp$269_c__5501__auto__$jscomp$1_id$jscomp$7$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__24486_vec__24492$$),$cljs$tools$reader$impl$errors$duplicate_keys_error_$_duplicates_$_iter__24483$$($APP.$cljs$core$_chunked_rest$$($s__24484__$1_s__24484__$2_temp__5825__auto__$jscomp$45$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__24486_vec__24492$$),null)}$b__24486_vec__24492$$=$APP.$cljs$core$first$$($s__24484__$1_s__24484__$2_temp__5825__auto__$jscomp$45$$);
$JSCompiler_inline_result$jscomp$269_c__5501__auto__$jscomp$1_id$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b__24486_vec__24492$$,0,null);if($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b__24486_vec__24492$$,1,null)>1)return $APP.$cljs$core$cons$$($JSCompiler_inline_result$jscomp$269_c__5501__auto__$jscomp$1_id$jscomp$7$$,$cljs$tools$reader$impl$errors$duplicate_keys_error_$_duplicates_$_iter__24483$$($APP.$cljs$core$rest$$($s__24484__$1_s__24484__$2_temp__5825__auto__$jscomp$45$$)));
$s__24484__$1_s__24484__$2_temp__5825__auto__$jscomp$45$$=$APP.$cljs$core$rest$$($s__24484__$1_s__24484__$2_temp__5825__auto__$jscomp$45$$)}else return null},null,null)}($APP.$cljs$core$frequencies$$($seq$$))}($coll$jscomp$820_dups$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$str$$,$msg$jscomp$6$$,$APP.$cljs$core$count$$($coll$jscomp$820_dups$$)>1?"s":null,": ",$APP.$cljs$core$interpose$cljs$0core$0IFn$0_invoke$0arity$02$$(", ",$coll$jscomp$820_dups$$))};
$APP.$cljs$tools$reader$impl$errors$throw_dup_keys$$=function($rdr$jscomp$46$$,$kind$jscomp$10_s$jscomp$inline_3036$$,$ks$jscomp$18$$){$kind$jscomp$10_s$jscomp$inline_3036$$=$APP.$cljs$core$name$$($kind$jscomp$10_s$jscomp$inline_3036$$);return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$46$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$tools$reader$impl$errors$duplicate_keys_error$$([String($kind$jscomp$10_s$jscomp$inline_3036$$.charAt(0)).toUpperCase()+
String($kind$jscomp$10_s$jscomp$inline_3036$$.slice(1)).toLowerCase()," literal contains duplicate key"].join(""),$ks$jscomp$18$$)]))};
$APP.$cljs$tools$reader$impl$errors$throw_eof_error$$=function($rdr$jscomp$47$$,$line$jscomp$15$$){return $APP.$cljs$core$truth_$$($line$jscomp$15$$)?$cljs$tools$reader$impl$errors$eof_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$47$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["EOF while reading, starting at line ",$line$jscomp$15$$,"."])):$cljs$tools$reader$impl$errors$eof_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$47$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["EOF while reading."]))};
$APP.$cljs$tools$reader$impl$commons$read_past$$=function($rdr$jscomp$48$$){for(var $ch$jscomp$24$$=$rdr$jscomp$48$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);;)if($APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$24$$):$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$24$$))$ch$jscomp$24$$=$rdr$jscomp$48$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);
else return $ch$jscomp$24$$};$cljs$tools$reader$impl$commons$matches_QMARK_$$=function($pattern$jscomp$6_vec__24524$$,$s$jscomp$168$$){$pattern$jscomp$6_vec__24524$$=$APP.$cljs$core$re_find$$($pattern$jscomp$6_vec__24524$$,$s$jscomp$168$$);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($pattern$jscomp$6_vec__24524$$,0,null)===$s$jscomp$168$$};
$APP.$cljs$tools$reader$impl$commons$match_number$$=function($JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$){if($cljs$tools$reader$impl$commons$matches_QMARK_$$($cljs$tools$reader$impl$commons$int_pattern$$,$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$)){var $a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$=
$APP.$cljs$core$vec$$($APP.$cljs$core$re_find$$($cljs$tools$reader$impl$commons$int_pattern$$,$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$));if(($a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(2):
$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(2))!=null)$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$=0;else{$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$=
"-"===($a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(1):$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(1));$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$=
($a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(3):$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(3))!=null?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(3):$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(3),
10],null):($a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(4):$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(4))!=
null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(4):$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(4),
16],null):($a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(5):$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(5))!=
null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(5):$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(5),
8],null):($a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(7):$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(7))!=
null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(7):$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(7),
parseInt($a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(6):$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(6))],
null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,null],null);var $n$jscomp$inline_3042$$=$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(0):$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(0);
$n$jscomp$inline_3042$$==null?$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$=null:($a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$=parseInt($n$jscomp$inline_3042$$,$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?
$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(1):$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(1)),$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$=
$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$?-1*$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$:$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$,
$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$=$APP.$cljs$core$truth_$$(isNaN($JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$))?null:$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$)}}else $cljs$tools$reader$impl$commons$matches_QMARK_$$($cljs$tools$reader$impl$commons$float_pattern$$,
$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$)?($a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$=$APP.$cljs$core$vec$$($APP.$cljs$core$re_find$$($cljs$tools$reader$impl$commons$float_pattern$$,$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$)),
$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$=($a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(4):
$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(4))!=null?parseFloat($a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(1):
$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(1)):parseFloat($JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$)):$cljs$tools$reader$impl$commons$matches_QMARK_$$($cljs$tools$reader$impl$commons$ratio_pattern$$,$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$)?
($a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$=$APP.$cljs$core$vec$$($APP.$cljs$core$re_find$$($cljs$tools$reader$impl$commons$ratio_pattern$$,$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$)),$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$=
$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(1):$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(1),$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$=
$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$?$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$.$cljs$core$IFn$_invoke$arity$1$(2):$a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$(2),$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$=
$APP.$cljs$core$truth_$$($APP.$cljs$core$re_find$$(/^\+/,$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$))?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$,
1):$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$,$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$=parseInt($JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$)/
parseInt($a$jscomp$inline_3041_bn$jscomp$inline_3043_denominator$jscomp$inline_3052_m$jscomp$inline_3039_m$jscomp$inline_3047_m$jscomp$inline_3050$$)):$JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$=null;return $JSCompiler_temp$jscomp$271_JSCompiler_temp$jscomp$272_JSCompiler_temp$jscomp$273_bn__$1$jscomp$inline_3044_negate_QMARK_$jscomp$inline_3040_numerator$jscomp$inline_3051_numerator__$1$jscomp$inline_3053_s$jscomp$169$$};
$APP.$cljs$tools$reader$impl$commons$parse_symbol$$=function($sym$jscomp$12_token$jscomp$18$$){if(""===$sym$jscomp$12_token$jscomp$18$$||/:$/.test($sym$jscomp$12_token$jscomp$18$$)===!0||/^::/.test($sym$jscomp$12_token$jscomp$18$$)===!0)return null;var $ns_idx_ns_idx__$1$$=$sym$jscomp$12_token$jscomp$18$$.indexOf("/"),$ns$jscomp$17$$=$ns_idx_ns_idx__$1$$>0?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($sym$jscomp$12_token$jscomp$18$$,0,$ns_idx_ns_idx__$1$$):null;if($ns$jscomp$17$$!=null){$ns_idx_ns_idx__$1$$+=
1;if($ns_idx_ns_idx__$1$$===$APP.$cljs$core$count$$($sym$jscomp$12_token$jscomp$18$$))return null;$sym$jscomp$12_token$jscomp$18$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($sym$jscomp$12_token$jscomp$18$$,$ns_idx_ns_idx__$1$$);return $APP.$cljs$tools$reader$impl$utils$numeric_QMARK_$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($sym$jscomp$12_token$jscomp$18$$,0))||""===$sym$jscomp$12_token$jscomp$18$$||/:$/.test($ns$jscomp$17$$)!==!1||$sym$jscomp$12_token$jscomp$18$$!==
"/"&&-1!==$sym$jscomp$12_token$jscomp$18$$.indexOf("/")?null:new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$ns$jscomp$17$$,$sym$jscomp$12_token$jscomp$18$$],null)}return $sym$jscomp$12_token$jscomp$18$$==="/"||-1===$sym$jscomp$12_token$jscomp$18$$.indexOf("/")?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$sym$jscomp$12_token$jscomp$18$$],null):null};
$APP.$cljs$tools$reader$impl$commons$throwing_reader$$=function($msg$jscomp$7$$){return function(){function $G__24581$$($rdr$jscomp$51$$,$var_args$jscomp$324$$){var $G__24582__i__$jscomp$167$$=null;if(arguments.length>1){$G__24582__i__$jscomp$167$$=0;for(var $G__24582__a$$=Array(arguments.length-1);$G__24582__i__$jscomp$167$$<$G__24582__a$$.length;)$G__24582__a$$[$G__24582__i__$jscomp$167$$]=arguments[$G__24582__i__$jscomp$167$$+1],++$G__24582__i__$jscomp$167$$;$G__24582__i__$jscomp$167$$=new $APP.$cljs$core$IndexedSeq$$($G__24582__a$$,
0,null)}return $G__24581__delegate$$.call(this,$rdr$jscomp$51$$,$G__24582__i__$jscomp$167$$)}function $G__24581__delegate$$($rdr$jscomp$50$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$50$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$msg$jscomp$7$$]))}$G__24581$$.$cljs$lang$maxFixedArity$=1;$G__24581$$.$cljs$lang$applyTo$=function($_$jscomp$168_arglist__24583$$){var $rdr$jscomp$52$$=$APP.$cljs$core$first$$($_$jscomp$168_arglist__24583$$);
$_$jscomp$168_arglist__24583$$=$APP.$cljs$core$rest$$($_$jscomp$168_arglist__24583$$);return $G__24581__delegate$$($rdr$jscomp$52$$,$_$jscomp$168_arglist__24583$$)};$G__24581$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__24581__delegate$$;return $G__24581$$}()};
$cljs$tools$reader$edn$macro_terminating_QMARK_$$=function($ch$jscomp$44$$){var $and__5023__auto__$jscomp$42_and__5023__auto____$1$jscomp$16_and__5023__auto____$2$jscomp$6$$="#"!==$ch$jscomp$44$$;return $and__5023__auto__$jscomp$42_and__5023__auto____$1$jscomp$16_and__5023__auto____$2$jscomp$6$$?($and__5023__auto__$jscomp$42_and__5023__auto____$1$jscomp$16_and__5023__auto____$2$jscomp$6$$="'"!==$ch$jscomp$44$$)?($and__5023__auto__$jscomp$42_and__5023__auto____$1$jscomp$16_and__5023__auto____$2$jscomp$6$$=
":"!==$ch$jscomp$44$$)?$cljs$tools$reader$edn$macros$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$tools$reader$edn$macros$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$44$$):$cljs$tools$reader$edn$macros$$($ch$jscomp$44$$):$and__5023__auto__$jscomp$42_and__5023__auto____$1$jscomp$16_and__5023__auto____$2$jscomp$6$$:$and__5023__auto__$jscomp$42_and__5023__auto____$1$jscomp$16_and__5023__auto____$2$jscomp$6$$:$and__5023__auto__$jscomp$42_and__5023__auto____$1$jscomp$16_and__5023__auto____$2$jscomp$6$$};
$cljs$tools$reader$edn$not_constituent_QMARK_$$=function($ch$jscomp$45$$){return"@"===$ch$jscomp$45$$||"`"===$ch$jscomp$45$$||"~"===$ch$jscomp$45$$};
$cljs$tools$reader$edn$read_token$cljs$0core$0IFn$0_invoke$0arity$04$$=function($rdr$jscomp$90$$,$kind$jscomp$15$$,$G__25386_ch$jscomp$46_initch$jscomp$8$$,$G__25057$jscomp$inline_11348_G__25385_sb$jscomp$16_validate_leading_QMARK_$$){if($APP.$cljs$core$not$$($G__25386_ch$jscomp$46_initch$jscomp$8$$))return $APP.$cljs$tools$reader$impl$errors$throw_eof_at_start$$($rdr$jscomp$90$$,$kind$jscomp$15$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__25057$jscomp$inline_11348_G__25385_sb$jscomp$16_validate_leading_QMARK_$$)?
$cljs$tools$reader$edn$not_constituent_QMARK_$$($G__25386_ch$jscomp$46_initch$jscomp$8$$):$G__25057$jscomp$inline_11348_G__25385_sb$jscomp$16_validate_leading_QMARK_$$))return $cljs$tools$reader$impl$errors$throw_bad_char$$($rdr$jscomp$90$$,$kind$jscomp$15$$,$G__25386_ch$jscomp$46_initch$jscomp$8$$);for($G__25057$jscomp$inline_11348_G__25385_sb$jscomp$16_validate_leading_QMARK_$$=new $APP.$goog$string$StringBuffer$$;;){if($APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($G__25386_ch$jscomp$46_initch$jscomp$8$$)||
$cljs$tools$reader$edn$macro_terminating_QMARK_$$($G__25386_ch$jscomp$46_initch$jscomp$8$$)||$G__25386_ch$jscomp$46_initch$jscomp$8$$==null)return $G__25386_ch$jscomp$46_initch$jscomp$8$$!=null&&$APP.$cljs$tools$reader$reader_types$unread$$($rdr$jscomp$90$$,$G__25386_ch$jscomp$46_initch$jscomp$8$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__25057$jscomp$inline_11348_G__25385_sb$jscomp$16_validate_leading_QMARK_$$);if($cljs$tools$reader$edn$not_constituent_QMARK_$$($G__25386_ch$jscomp$46_initch$jscomp$8$$))return $cljs$tools$reader$impl$errors$throw_bad_char$$($rdr$jscomp$90$$,
$kind$jscomp$15$$,$G__25386_ch$jscomp$46_initch$jscomp$8$$);$G__25057$jscomp$inline_11348_G__25385_sb$jscomp$16_validate_leading_QMARK_$$.append($G__25386_ch$jscomp$46_initch$jscomp$8$$);$G__25386_ch$jscomp$46_initch$jscomp$8$$=$APP.$cljs$tools$reader$reader_types$read_char$$($rdr$jscomp$90$$)}};
$cljs$tools$reader$edn$read_dispatch$$=function($rdr$jscomp$91$$,$_$jscomp$184_temp__5823__auto__$jscomp$28$$,$opts$jscomp$91$$){$_$jscomp$184_temp__5823__auto__$jscomp$28$$=$APP.$cljs$tools$reader$reader_types$read_char$$($rdr$jscomp$91$$);if($APP.$cljs$core$truth_$$($_$jscomp$184_temp__5823__auto__$jscomp$28$$)){var $temp__5823__auto____$1$jscomp$5$$=$cljs$tools$reader$edn$dispatch_macros$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$tools$reader$edn$dispatch_macros$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$184_temp__5823__auto__$jscomp$28$$):
$cljs$tools$reader$edn$dispatch_macros$$($_$jscomp$184_temp__5823__auto__$jscomp$28$$);if($APP.$cljs$core$truth_$$($temp__5823__auto____$1$jscomp$5$$))return $temp__5823__auto____$1$jscomp$5$$.$cljs$core$IFn$_invoke$arity$3$?$temp__5823__auto____$1$jscomp$5$$.$cljs$core$IFn$_invoke$arity$3$($rdr$jscomp$91$$,$_$jscomp$184_temp__5823__auto__$jscomp$28$$,$opts$jscomp$91$$):$temp__5823__auto____$1$jscomp$5$$($rdr$jscomp$91$$,$_$jscomp$184_temp__5823__auto__$jscomp$28$$,$opts$jscomp$91$$);$APP.$cljs$tools$reader$reader_types$unread$$($rdr$jscomp$91$$,
$_$jscomp$184_temp__5823__auto__$jscomp$28$$);return $cljs$tools$reader$edn$read_tagged$$.$cljs$core$IFn$_invoke$arity$3$?$cljs$tools$reader$edn$read_tagged$$.$cljs$core$IFn$_invoke$arity$3$($rdr$jscomp$91$$,$_$jscomp$184_temp__5823__auto__$jscomp$28$$,$opts$jscomp$91$$):$cljs$tools$reader$edn$read_tagged$$($rdr$jscomp$91$$,$_$jscomp$184_temp__5823__auto__$jscomp$28$$,$opts$jscomp$91$$)}return $APP.$cljs$tools$reader$impl$errors$throw_eof_at_dispatch$$($rdr$jscomp$91$$)};
$cljs$tools$reader$edn$read_unmatched_delimiter$$=function($rdr$jscomp$92$$,$ch$jscomp$48$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$92$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Unmatched delimiter ",$ch$jscomp$48$$,"."]))};
$cljs$tools$reader$edn$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$04$$=function($token$jscomp$25$$,$l$jscomp$75_length$jscomp$28$$,$base$jscomp$13$$){$l$jscomp$75_length$jscomp$28$$=1+$l$jscomp$75_length$jscomp$28$$;$APP.$cljs$core$count$$($token$jscomp$25$$)!==$l$jscomp$75_length$jscomp$28$$&&$APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_literal$$($token$jscomp$25$$);for(var $i$jscomp$290$$=1,$G__25414_uc$jscomp$3$$=0;;){if($i$jscomp$290$$===$l$jscomp$75_length$jscomp$28$$)return String.fromCharCode($G__25414_uc$jscomp$3$$);
var $d$jscomp$104$$=$APP.$cljs$tools$reader$impl$utils$char_code$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($token$jscomp$25$$,$i$jscomp$290$$),$base$jscomp$13$$);if($d$jscomp$104$$===-1)return $APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_digit_in_token$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($token$jscomp$25$$,$i$jscomp$290$$),$token$jscomp$25$$);$G__25414_uc$jscomp$3$$=$d$jscomp$104$$+$G__25414_uc$jscomp$3$$*$base$jscomp$13$$;$i$jscomp$290$$+=1}};
$cljs$tools$reader$edn$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$05$$=function($rdr$jscomp$93$$,$initch$jscomp$9$$,$base$jscomp$14$$,$length$jscomp$29$$,$exact_QMARK_$jscomp$1$$){for(var $i$jscomp$291$$=1,$G__25423_uc$jscomp$4$$=$APP.$cljs$tools$reader$impl$utils$char_code$$($initch$jscomp$9$$,$base$jscomp$14$$);;){if($G__25423_uc$jscomp$4$$===-1)return $APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_digit$$($rdr$jscomp$93$$,$initch$jscomp$9$$);if($i$jscomp$291$$!==$length$jscomp$29$$){var $ch$jscomp$49$$=
$cljs$tools$reader$reader_types$peek_char$$($rdr$jscomp$93$$);var $JSCompiler_inline_result$jscomp$274_d$jscomp$105_or__5025__auto__$jscomp$inline_3058_or__5025__auto____$1$jscomp$inline_3059$$=$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$49$$);$JSCompiler_inline_result$jscomp$274_d$jscomp$105_or__5025__auto__$jscomp$inline_3058_or__5025__auto____$1$jscomp$inline_3059$$||($JSCompiler_inline_result$jscomp$274_d$jscomp$105_or__5025__auto__$jscomp$inline_3058_or__5025__auto____$1$jscomp$inline_3059$$=
$cljs$tools$reader$edn$macros$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$tools$reader$edn$macros$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$49$$):$cljs$tools$reader$edn$macros$$($ch$jscomp$49$$),$JSCompiler_inline_result$jscomp$274_d$jscomp$105_or__5025__auto__$jscomp$inline_3058_or__5025__auto____$1$jscomp$inline_3059$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$274_d$jscomp$105_or__5025__auto__$jscomp$inline_3058_or__5025__auto____$1$jscomp$inline_3059$$)?$JSCompiler_inline_result$jscomp$274_d$jscomp$105_or__5025__auto__$jscomp$inline_3058_or__5025__auto____$1$jscomp$inline_3059$$:
$ch$jscomp$49$$==null);if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$274_d$jscomp$105_or__5025__auto__$jscomp$inline_3058_or__5025__auto____$1$jscomp$inline_3059$$))return $APP.$cljs$core$truth_$$($exact_QMARK_$jscomp$1$$)?$APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_len$$($rdr$jscomp$93$$,$i$jscomp$291$$,$length$jscomp$29$$):String.fromCharCode($G__25423_uc$jscomp$4$$);$JSCompiler_inline_result$jscomp$274_d$jscomp$105_or__5025__auto__$jscomp$inline_3058_or__5025__auto____$1$jscomp$inline_3059$$=
$APP.$cljs$tools$reader$impl$utils$char_code$$($ch$jscomp$49$$,$base$jscomp$14$$);$APP.$cljs$tools$reader$reader_types$read_char$$($rdr$jscomp$93$$);if($JSCompiler_inline_result$jscomp$274_d$jscomp$105_or__5025__auto__$jscomp$inline_3058_or__5025__auto____$1$jscomp$inline_3059$$===-1)return $APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_digit$$($rdr$jscomp$93$$,$ch$jscomp$49$$);$G__25423_uc$jscomp$4$$=$JSCompiler_inline_result$jscomp$274_d$jscomp$105_or__5025__auto__$jscomp$inline_3058_or__5025__auto____$1$jscomp$inline_3059$$+
$G__25423_uc$jscomp$4$$*$base$jscomp$14$$;$i$jscomp$291$$+=1}else return String.fromCharCode($G__25423_uc$jscomp$4$$)}};
$cljs$tools$reader$edn$read_char_STAR_$$=function($rdr$jscomp$94$$){var $c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$=$APP.$cljs$tools$reader$reader_types$read_char$$($rdr$jscomp$94$$);if($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$!=null){$c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$=$cljs$tools$reader$edn$macro_terminating_QMARK_$$($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$)||$cljs$tools$reader$edn$not_constituent_QMARK_$$($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$)||
$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$)?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$):$cljs$tools$reader$edn$read_token$cljs$0core$0IFn$0_invoke$0arity$04$$($rdr$jscomp$94$$,$APP.$cljs$cst$215$character$$,$c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$,!1);var $ic$jscomp$1_len$jscomp$55_token_len$jscomp$1$$=$c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$.length;
if(1===$ic$jscomp$1_len$jscomp$55_token_len$jscomp$1$$)return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$,0);if($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$==="newline")return"\n";if($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$==="space")return" ";if($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$==="tab")return"\t";if($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$==="backspace")return"\b";
if($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$==="formfeed")return"\f";if($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$==="return")return"\r";if($APP.$cljs$core$truth_$$($APP.$goog$string$internal$startsWith$$($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$,"u")))return $c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$=$cljs$tools$reader$edn$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$04$$($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$,4,16),
$ic$jscomp$1_len$jscomp$55_token_len$jscomp$1$$=$c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$.charCodeAt(),$ic$jscomp$1_len$jscomp$55_token_len$jscomp$1$$>55295&&$ic$jscomp$1_len$jscomp$55_token_len$jscomp$1$$<57344?$APP.$cljs$tools$reader$impl$errors$throw_invalid_character_literal$$($rdr$jscomp$94$$,$ic$jscomp$1_len$jscomp$55_token_len$jscomp$1$$.toString(16)):$c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$;if($APP.$cljs$core$truth_$$($APP.$goog$string$internal$startsWith$$($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$,
"o"))){--$ic$jscomp$1_len$jscomp$55_token_len$jscomp$1$$;if($ic$jscomp$1_len$jscomp$55_token_len$jscomp$1$$>3)return $APP.$cljs$tools$reader$impl$errors$throw_invalid_octal_len$$($rdr$jscomp$94$$,$c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$);$c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$=$cljs$tools$reader$edn$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$04$$($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$,$ic$jscomp$1_len$jscomp$55_token_len$jscomp$1$$,8);return($c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$|
0)>255?$APP.$cljs$tools$reader$impl$errors$throw_bad_octal_number$$($rdr$jscomp$94$$):$c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$}return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$94$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Unsupported character: ",$c$jscomp$143_ch$jscomp$50_token$jscomp$26_uc$jscomp$5$$,"."]))}return $APP.$cljs$tools$reader$impl$errors$throw_eof_in_character$$($rdr$jscomp$94$$)};
$cljs$tools$reader$edn$starting_line_col_info$$=function($rdr$jscomp$95$$){return $APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$($rdr$jscomp$95$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$tools$reader$reader_types$get_line_number$$($rdr$jscomp$95$$),($cljs$tools$reader$reader_types$get_column_number$$($rdr$jscomp$95$$)|0)-1|0],null):null};
$cljs$tools$reader$edn$read_delimited$$=function($kind$jscomp$16$$,$delim$jscomp$2_delim__$1$jscomp$1$$,$rdr$jscomp$96$$,$opts$jscomp$94$$){var $start_column$jscomp$6_vec__25151$$=$cljs$tools$reader$edn$starting_line_col_info$$($rdr$jscomp$96$$),$start_line$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$6_vec__25151$$,0,null);$start_column$jscomp$6_vec__25151$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$6_vec__25151$$,1,
null);$delim$jscomp$2_delim__$1$jscomp$1$$=$APP.$cljs$tools$reader$impl$utils$char$0$$($delim$jscomp$2_delim__$1$jscomp$1$$);for(var $a$jscomp$195$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;){var $ch$jscomp$51_mret_o$jscomp$137$$=$APP.$cljs$tools$reader$impl$commons$read_past$$($rdr$jscomp$96$$);$APP.$cljs$core$truth_$$($ch$jscomp$51_mret_o$jscomp$137$$)||$APP.$cljs$tools$reader$impl$errors$throw_eof_delimited$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$96$$,
$kind$jscomp$16$$,$start_line$jscomp$6$$,$start_column$jscomp$6_vec__25151$$,$APP.$cljs$core$count$$($a$jscomp$195$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($delim$jscomp$2_delim__$1$jscomp$1$$,$APP.$cljs$tools$reader$impl$utils$char$0$$($ch$jscomp$51_mret_o$jscomp$137$$)))return $APP.$cljs$core$_persistent_BANG_$$($a$jscomp$195$$);var $macrofn_temp__5823__auto__$jscomp$29$$=$cljs$tools$reader$edn$macros$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$tools$reader$edn$macros$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$51_mret_o$jscomp$137$$):
$cljs$tools$reader$edn$macros$$($ch$jscomp$51_mret_o$jscomp$137$$);$APP.$cljs$core$truth_$$($macrofn_temp__5823__auto__$jscomp$29$$)?($ch$jscomp$51_mret_o$jscomp$137$$=$macrofn_temp__5823__auto__$jscomp$29$$.$cljs$core$IFn$_invoke$arity$3$?$macrofn_temp__5823__auto__$jscomp$29$$.$cljs$core$IFn$_invoke$arity$3$($rdr$jscomp$96$$,$ch$jscomp$51_mret_o$jscomp$137$$,$opts$jscomp$94$$):$macrofn_temp__5823__auto__$jscomp$29$$($rdr$jscomp$96$$,$ch$jscomp$51_mret_o$jscomp$137$$,$opts$jscomp$94$$),$a$jscomp$195$$=
$ch$jscomp$51_mret_o$jscomp$137$$!==$rdr$jscomp$96$$?$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$195$$,$ch$jscomp$51_mret_o$jscomp$137$$):$a$jscomp$195$$):($APP.$cljs$tools$reader$reader_types$unread$$($rdr$jscomp$96$$,$ch$jscomp$51_mret_o$jscomp$137$$),$ch$jscomp$51_mret_o$jscomp$137$$=$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$?$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$($rdr$jscomp$96$$,!0,null,$opts$jscomp$94$$):$cljs$tools$reader$edn$read$$($rdr$jscomp$96$$,
!0,null,$opts$jscomp$94$$),$a$jscomp$195$$=$ch$jscomp$51_mret_o$jscomp$137$$!==$rdr$jscomp$96$$?$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$195$$,$ch$jscomp$51_mret_o$jscomp$137$$):$a$jscomp$195$$)}};
$cljs$tools$reader$edn$read_list$$=function($rdr$jscomp$97_the_list$jscomp$1$$,$_$jscomp$185$$,$opts$jscomp$95$$){$rdr$jscomp$97_the_list$jscomp$1$$=$cljs$tools$reader$edn$read_delimited$$($APP.$cljs$cst$201$list$$,")",$rdr$jscomp$97_the_list$jscomp$1$$,$opts$jscomp$95$$);return $APP.$cljs$core$empty_QMARK_$$($rdr$jscomp$97_the_list$jscomp$1$$)?$APP.$cljs$core$List$EMPTY$$:$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$list$$,$rdr$jscomp$97_the_list$jscomp$1$$)};
$cljs$tools$reader$edn$read_vector$$=function($rdr$jscomp$98$$,$_$jscomp$186$$,$opts$jscomp$96$$){return $cljs$tools$reader$edn$read_delimited$$($APP.$cljs$cst$200$vector$$,"]",$rdr$jscomp$98$$,$opts$jscomp$96$$)};
$cljs$tools$reader$edn$read_map$$=function($rdr$jscomp$99$$,$_$jscomp$187_start_line$jscomp$7$$,$opts$jscomp$97_the_map$jscomp$1$$){var $start_column$jscomp$7_vec__25170$$=$cljs$tools$reader$edn$starting_line_col_info$$($rdr$jscomp$99$$);$_$jscomp$187_start_line$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$7_vec__25170$$,0,null);$start_column$jscomp$7_vec__25170$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$7_vec__25170$$,
1,null);$opts$jscomp$97_the_map$jscomp$1$$=$cljs$tools$reader$edn$read_delimited$$($APP.$cljs$cst$202$map$$,"}",$rdr$jscomp$99$$,$opts$jscomp$97_the_map$jscomp$1$$);var $map_count$jscomp$1$$=$APP.$cljs$core$count$$($opts$jscomp$97_the_map$jscomp$1$$),$ks$jscomp$20$$=$APP.$cljs$core$take_nth$cljs$0core$0IFn$0_invoke$0arity$02$$(2,$opts$jscomp$97_the_map$jscomp$1$$),$key_set$jscomp$1$$=$APP.$cljs$core$set$$($ks$jscomp$20$$);!$APP.$cljs$core$even_QMARK_$$($map_count$jscomp$1$$)&&$APP.$cljs$tools$reader$impl$errors$throw_odd_map$$($rdr$jscomp$99$$,
$_$jscomp$187_start_line$jscomp$7$$,$start_column$jscomp$7_vec__25170$$,$opts$jscomp$97_the_map$jscomp$1$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($key_set$jscomp$1$$),$APP.$cljs$core$count$$($ks$jscomp$20$$))||$APP.$cljs$tools$reader$impl$errors$throw_dup_keys$$($rdr$jscomp$99$$,$APP.$cljs$cst$202$map$$,$ks$jscomp$20$$);return $map_count$jscomp$1$$<=2*$APP.$cljs$core$PersistentArrayMap$HASHMAP_THRESHOLD$$?$APP.$cljs$core$PersistentArrayMap$fromArray$$($APP.$cljs$core$to_array$$($opts$jscomp$97_the_map$jscomp$1$$),
!0,!0):$APP.$cljs$core$PersistentHashMap$fromArray$$($APP.$cljs$core$to_array$$($opts$jscomp$97_the_map$jscomp$1$$))};
$cljs$tools$reader$edn$read_number$$=function($rdr$jscomp$100$$,$initch$jscomp$10$$){for(var $sb$jscomp$17$$=function(){var $G__25177$$=new $APP.$goog$string$StringBuffer$$;$G__25177$$.append($initch$jscomp$10$$);return $G__25177$$}(),$ch$jscomp$52$$=$APP.$cljs$tools$reader$reader_types$read_char$$($rdr$jscomp$100$$);;){if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$62_or__5025__auto____$1$jscomp$16$$=$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$52$$);if($or__5025__auto__$jscomp$62_or__5025__auto____$1$jscomp$16$$)return $or__5025__auto__$jscomp$62_or__5025__auto____$1$jscomp$16$$;
$or__5025__auto__$jscomp$62_or__5025__auto____$1$jscomp$16$$=$cljs$tools$reader$edn$macros$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$tools$reader$edn$macros$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$52$$):$cljs$tools$reader$edn$macros$$($ch$jscomp$52$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$62_or__5025__auto____$1$jscomp$16$$)?$or__5025__auto__$jscomp$62_or__5025__auto____$1$jscomp$16$$:$ch$jscomp$52$$==null}())){var $G__25464_s$jscomp$179$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$17$$);
$ch$jscomp$52$$!=null&&$APP.$cljs$tools$reader$reader_types$unread$$($rdr$jscomp$100$$,$ch$jscomp$52$$);var $G__25465_or__5025__auto__$jscomp$61$$=$APP.$cljs$tools$reader$impl$commons$match_number$$($G__25464_s$jscomp$179$$);return $APP.$cljs$core$truth_$$($G__25465_or__5025__auto__$jscomp$61$$)?$G__25465_or__5025__auto__$jscomp$61$$:$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$100$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid number: ",
$G__25464_s$jscomp$179$$,"."]))}$G__25464_s$jscomp$179$$=function(){var $G__25184$$=$sb$jscomp$17$$;$G__25184$$.append($ch$jscomp$52$$);return $G__25184$$}();$G__25465_or__5025__auto__$jscomp$61$$=$APP.$cljs$tools$reader$reader_types$read_char$$($rdr$jscomp$100$$);$sb$jscomp$17$$=$G__25464_s$jscomp$179$$;$ch$jscomp$52$$=$G__25465_or__5025__auto__$jscomp$61$$}};
$cljs$tools$reader$edn$escape_char$$=function($rdr$jscomp$101$$){var $ch$jscomp$53_ch__$1$jscomp$5$$=$APP.$cljs$tools$reader$reader_types$read_char$$($rdr$jscomp$101$$);switch($ch$jscomp$53_ch__$1$jscomp$5$$){case "t":return"\t";case "r":return"\r";case "n":return"\n";case "\\":return"\\";case '"':return'"';case "b":return"\b";case "f":return"\f";case "u":return $ch$jscomp$53_ch__$1$jscomp$5$$=$APP.$cljs$tools$reader$reader_types$read_char$$($rdr$jscomp$101$$),-1===parseInt($ch$jscomp$53_ch__$1$jscomp$5$$|
0,16)?$APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_escape$$($rdr$jscomp$101$$,$ch$jscomp$53_ch__$1$jscomp$5$$):$cljs$tools$reader$edn$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$101$$,$ch$jscomp$53_ch__$1$jscomp$5$$,16,4,!0);default:return $APP.$cljs$tools$reader$impl$utils$numeric_QMARK_$$($ch$jscomp$53_ch__$1$jscomp$5$$)?($ch$jscomp$53_ch__$1$jscomp$5$$=$cljs$tools$reader$edn$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$101$$,$ch$jscomp$53_ch__$1$jscomp$5$$,
8,3,!1),($ch$jscomp$53_ch__$1$jscomp$5$$|0)>255?$APP.$cljs$tools$reader$impl$errors$throw_bad_octal_number$$($rdr$jscomp$101$$):$ch$jscomp$53_ch__$1$jscomp$5$$):$APP.$cljs$tools$reader$impl$errors$throw_bad_escape_char$$($rdr$jscomp$101$$,$ch$jscomp$53_ch__$1$jscomp$5$$)}};
$cljs$tools$reader$edn$read_string_STAR_$$=function($rdr$jscomp$102$$){for(var $sb$jscomp$19$$=new $APP.$goog$string$StringBuffer$$,$ch$jscomp$54$$=$APP.$cljs$tools$reader$reader_types$read_char$$($rdr$jscomp$102$$);;){var $G__25198_G__25479_G__25481$$=$ch$jscomp$54$$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$G__25198_G__25479_G__25481$$))return $APP.$cljs$tools$reader$impl$errors$throw_eof_reading$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$102$$,$APP.$cljs$cst$198$string$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(['"',$sb$jscomp$19$$]));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("\\",$G__25198_G__25479_G__25481$$)){$G__25198_G__25479_G__25481$$=function(){var $G__25199$$=$sb$jscomp$19$$;$G__25199$$.append($cljs$tools$reader$edn$escape_char$$($rdr$jscomp$102$$));return $G__25199$$}();var $G__25480_G__25482$$=$APP.$cljs$tools$reader$reader_types$read_char$$($rdr$jscomp$102$$);$sb$jscomp$19$$=$G__25198_G__25479_G__25481$$;$ch$jscomp$54$$=
$G__25480_G__25482$$}else{if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$('"',$G__25198_G__25479_G__25481$$))return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$19$$);$G__25198_G__25479_G__25481$$=function(){var $G__25203$$=$sb$jscomp$19$$;$G__25203$$.append($ch$jscomp$54$$);return $G__25203$$}();$G__25480_G__25482$$=$APP.$cljs$tools$reader$reader_types$read_char$$($rdr$jscomp$102$$);$sb$jscomp$19$$=$G__25198_G__25479_G__25481$$;$ch$jscomp$54$$=$G__25480_G__25482$$}}};
$cljs$tools$reader$edn$read_symbol$$=function($rdr$jscomp$103$$,$initch$jscomp$11_temp__5825__auto__$jscomp$52$$){$initch$jscomp$11_temp__5825__auto__$jscomp$52$$=$cljs$tools$reader$edn$read_token$cljs$0core$0IFn$0_invoke$0arity$04$$($rdr$jscomp$103$$,$APP.$cljs$cst$219$symbol$$,$initch$jscomp$11_temp__5825__auto__$jscomp$52$$,!0);if($APP.$cljs$core$truth_$$($initch$jscomp$11_temp__5825__auto__$jscomp$52$$))switch($initch$jscomp$11_temp__5825__auto__$jscomp$52$$){case "nil":return null;case "true":return!0;
case "false":return!1;case "/":return $APP.$cljs$cst$220$_SLASH_$$;default:var $or__5025__auto__$jscomp$63_temp__5825__auto____$1$jscomp$inline_3062$$=$APP.$cljs$tools$reader$impl$commons$parse_symbol$$($initch$jscomp$11_temp__5825__auto__$jscomp$52$$);$or__5025__auto__$jscomp$63_temp__5825__auto____$1$jscomp$inline_3062$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$63_temp__5825__auto____$1$jscomp$inline_3062$$)?$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$($or__5025__auto__$jscomp$63_temp__5825__auto____$1$jscomp$inline_3062$$.$cljs$core$IFn$_invoke$arity$1$?
$or__5025__auto__$jscomp$63_temp__5825__auto____$1$jscomp$inline_3062$$.$cljs$core$IFn$_invoke$arity$1$(0):$or__5025__auto__$jscomp$63_temp__5825__auto____$1$jscomp$inline_3062$$(0),$or__5025__auto__$jscomp$63_temp__5825__auto____$1$jscomp$inline_3062$$.$cljs$core$IFn$_invoke$arity$1$?$or__5025__auto__$jscomp$63_temp__5825__auto____$1$jscomp$inline_3062$$.$cljs$core$IFn$_invoke$arity$1$(1):$or__5025__auto__$jscomp$63_temp__5825__auto____$1$jscomp$inline_3062$$(1)):null;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$63_temp__5825__auto____$1$jscomp$inline_3062$$)?
$or__5025__auto__$jscomp$63_temp__5825__auto____$1$jscomp$inline_3062$$:$APP.$cljs$tools$reader$impl$errors$throw_invalid$$($rdr$jscomp$103$$,$APP.$cljs$cst$219$symbol$$,$initch$jscomp$11_temp__5825__auto__$jscomp$52$$)}else return null};
$cljs$tools$reader$edn$read_keyword$$=function($reader$jscomp$42$$){var $ch$jscomp$55_token$jscomp$28$$=$APP.$cljs$tools$reader$reader_types$read_char$$($reader$jscomp$42$$);if($APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$55_token$jscomp$28$$))return $APP.$cljs$tools$reader$impl$errors$throw_single_colon$$($reader$jscomp$42$$);$ch$jscomp$55_token$jscomp$28$$=$cljs$tools$reader$edn$read_token$cljs$0core$0IFn$0_invoke$0arity$04$$($reader$jscomp$42$$,$APP.$cljs$cst$221$keyword$$,
$ch$jscomp$55_token$jscomp$28$$,!0);var $name$jscomp$122_s$jscomp$180$$=$APP.$cljs$tools$reader$impl$commons$parse_symbol$$($ch$jscomp$55_token$jscomp$28$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($name$jscomp$122_s$jscomp$180$$)?-1===$ch$jscomp$55_token$jscomp$28$$.indexOf("::"):$name$jscomp$122_s$jscomp$180$$)){var $ns$jscomp$21$$=$name$jscomp$122_s$jscomp$180$$.$cljs$core$IFn$_invoke$arity$1$?$name$jscomp$122_s$jscomp$180$$.$cljs$core$IFn$_invoke$arity$1$(0):$name$jscomp$122_s$jscomp$180$$(0);
$name$jscomp$122_s$jscomp$180$$=$name$jscomp$122_s$jscomp$180$$.$cljs$core$IFn$_invoke$arity$1$?$name$jscomp$122_s$jscomp$180$$.$cljs$core$IFn$_invoke$arity$1$(1):$name$jscomp$122_s$jscomp$180$$(1);return":"===$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($ch$jscomp$55_token$jscomp$28$$,0)?$APP.$cljs$tools$reader$impl$errors$throw_invalid$$($reader$jscomp$42$$,$APP.$cljs$cst$221$keyword$$,[":",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$55_token$jscomp$28$$)].join("")):
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$($ns$jscomp$21$$,$name$jscomp$122_s$jscomp$180$$)}return $APP.$cljs$tools$reader$impl$errors$throw_invalid$$($reader$jscomp$42$$,$APP.$cljs$cst$221$keyword$$,[":",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$55_token$jscomp$28$$)].join(""))};
$cljs$tools$reader$edn$read_meta$$=function($rdr$jscomp$105$$,$_$jscomp$190_m$jscomp$81$$,$o$jscomp$138_opts$jscomp$102$$){$_$jscomp$190_m$jscomp$81$$=$APP.$cljs$tools$reader$impl$utils$desugar_meta$$($cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$?$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$($rdr$jscomp$105$$,!0,null,$o$jscomp$138_opts$jscomp$102$$):$cljs$tools$reader$edn$read$$($rdr$jscomp$105$$,!0,null,$o$jscomp$138_opts$jscomp$102$$));$APP.$cljs$core$map_QMARK_$$($_$jscomp$190_m$jscomp$81$$)||
$APP.$cljs$tools$reader$impl$errors$throw_bad_metadata$$($rdr$jscomp$105$$,$_$jscomp$190_m$jscomp$81$$);$o$jscomp$138_opts$jscomp$102$$=$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$?$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$($rdr$jscomp$105$$,!0,null,$o$jscomp$138_opts$jscomp$102$$):$cljs$tools$reader$edn$read$$($rdr$jscomp$105$$,!0,null,$o$jscomp$138_opts$jscomp$102$$);return $o$jscomp$138_opts$jscomp$102$$!=null&&($o$jscomp$138_opts$jscomp$102$$.$cljs$lang$protocol_mask$partition0$$&
131072||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$o$jscomp$138_opts$jscomp$102$$.$cljs$core$IMeta$$)?$APP.$cljs$core$with_meta$$($o$jscomp$138_opts$jscomp$102$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$meta$$($o$jscomp$138_opts$jscomp$102$$),$_$jscomp$190_m$jscomp$81$$]))):$APP.$cljs$tools$reader$impl$errors$throw_bad_metadata_target$$($rdr$jscomp$105$$,$o$jscomp$138_opts$jscomp$102$$)};
$cljs$tools$reader$edn$read_set$$=function($rdr$jscomp$106$$,$_$jscomp$191_coll$jscomp$824$$,$opts$jscomp$103_the_set$jscomp$1$$){$_$jscomp$191_coll$jscomp$824$$=$cljs$tools$reader$edn$read_delimited$$($APP.$cljs$cst$203$set$$,"}",$rdr$jscomp$106$$,$opts$jscomp$103_the_set$jscomp$1$$);$opts$jscomp$103_the_set$jscomp$1$$=$APP.$cljs$core$set$$($_$jscomp$191_coll$jscomp$824$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($_$jscomp$191_coll$jscomp$824$$),$APP.$cljs$core$count$$($opts$jscomp$103_the_set$jscomp$1$$))||
$APP.$cljs$tools$reader$impl$errors$throw_dup_keys$$($rdr$jscomp$106$$,$APP.$cljs$cst$203$set$$,$_$jscomp$191_coll$jscomp$824$$);return $opts$jscomp$103_the_set$jscomp$1$$};$cljs$tools$reader$edn$read_discard$$=function($rdr$jscomp$107$$){$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$?$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$($rdr$jscomp$107$$,!0,null,!0):$cljs$tools$reader$edn$read$$($rdr$jscomp$107$$,!0,null,!0);return $rdr$jscomp$107$$};
$cljs$tools$reader$edn$read_namespaced_map$$=function($rdr$jscomp$108$$,$_$jscomp$193_initch$jscomp$inline_11353_keys$jscomp$21_token$jscomp$29$$,$items$jscomp$7_opts$jscomp$105_vals$jscomp$9$$){$_$jscomp$193_initch$jscomp$inline_11353_keys$jscomp$21_token$jscomp$29$$=$APP.$cljs$tools$reader$reader_types$read_char$$($rdr$jscomp$108$$);$_$jscomp$193_initch$jscomp$inline_11353_keys$jscomp$21_token$jscomp$29$$=$cljs$tools$reader$edn$read_token$cljs$0core$0IFn$0_invoke$0arity$04$$($rdr$jscomp$108$$,$APP.$cljs$cst$247$namespaced_map$$,
$_$jscomp$193_initch$jscomp$inline_11353_keys$jscomp$21_token$jscomp$29$$,!0);var $G__25247__$1$jscomp$inline_3064_temp__5823__auto__$jscomp$30$$=$_$jscomp$193_initch$jscomp$inline_11353_keys$jscomp$21_token$jscomp$29$$==null?null:$APP.$cljs$tools$reader$impl$commons$parse_symbol$$($_$jscomp$193_initch$jscomp$inline_11353_keys$jscomp$21_token$jscomp$29$$);$G__25247__$1$jscomp$inline_3064_temp__5823__auto__$jscomp$30$$=$G__25247__$1$jscomp$inline_3064_temp__5823__auto__$jscomp$30$$==null?null:$APP.$cljs$tools$reader$impl$utils$second_SINGLEQUOTE_$$($G__25247__$1$jscomp$inline_3064_temp__5823__auto__$jscomp$30$$);
return $APP.$cljs$core$truth_$$($G__25247__$1$jscomp$inline_3064_temp__5823__auto__$jscomp$30$$)?$APP.$cljs$tools$reader$impl$commons$read_past$$($rdr$jscomp$108$$)==="{"?($items$jscomp$7_opts$jscomp$105_vals$jscomp$9$$=$cljs$tools$reader$edn$read_delimited$$($APP.$cljs$cst$247$namespaced_map$$,"}",$rdr$jscomp$108$$,$items$jscomp$7_opts$jscomp$105_vals$jscomp$9$$),$APP.$cljs$core$odd_QMARK_$$($APP.$cljs$core$count$$($items$jscomp$7_opts$jscomp$105_vals$jscomp$9$$))&&$APP.$cljs$tools$reader$impl$errors$throw_odd_map$$($rdr$jscomp$108$$,
null,null,$items$jscomp$7_opts$jscomp$105_vals$jscomp$9$$),$_$jscomp$193_initch$jscomp$inline_11353_keys$jscomp$21_token$jscomp$29$$=$APP.$cljs$tools$reader$impl$utils$namespace_keys$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__25247__$1$jscomp$inline_3064_temp__5823__auto__$jscomp$30$$),$APP.$cljs$core$take_nth$cljs$0core$0IFn$0_invoke$0arity$02$$(2,$items$jscomp$7_opts$jscomp$105_vals$jscomp$9$$)),$items$jscomp$7_opts$jscomp$105_vals$jscomp$9$$=$APP.$cljs$core$take_nth$cljs$0core$0IFn$0_invoke$0arity$02$$(2,
$APP.$cljs$core$rest$$($items$jscomp$7_opts$jscomp$105_vals$jscomp$9$$)),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($APP.$cljs$core$set$$($_$jscomp$193_initch$jscomp$inline_11353_keys$jscomp$21_token$jscomp$29$$)),$APP.$cljs$core$count$$($_$jscomp$193_initch$jscomp$inline_11353_keys$jscomp$21_token$jscomp$29$$))||$APP.$cljs$tools$reader$impl$errors$throw_dup_keys$$($rdr$jscomp$108$$,$APP.$cljs$cst$247$namespaced_map$$,$_$jscomp$193_initch$jscomp$inline_11353_keys$jscomp$21_token$jscomp$29$$),
$APP.$cljs$core$zipmap$$($_$jscomp$193_initch$jscomp$inline_11353_keys$jscomp$21_token$jscomp$29$$,$items$jscomp$7_opts$jscomp$105_vals$jscomp$9$$)):$APP.$cljs$tools$reader$impl$errors$throw_ns_map_no_map$$($rdr$jscomp$108$$,$_$jscomp$193_initch$jscomp$inline_11353_keys$jscomp$21_token$jscomp$29$$):$APP.$cljs$tools$reader$impl$errors$throw_bad_ns$$($rdr$jscomp$108$$,$_$jscomp$193_initch$jscomp$inline_11353_keys$jscomp$21_token$jscomp$29$$)};
$cljs$tools$reader$edn$read_symbolic_value$$=function($rdr$jscomp$109$$,$_$jscomp$194_sym$jscomp$21$$,$opts$jscomp$106$$){$_$jscomp$194_sym$jscomp$21$$=$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$?$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$($rdr$jscomp$109$$,!0,null,$opts$jscomp$106$$):$cljs$tools$reader$edn$read$$($rdr$jscomp$109$$,!0,null,$opts$jscomp$106$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$222$NaN$$,$_$jscomp$194_sym$jscomp$21$$)?
Number.NaN:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$223$_Inf$$,$_$jscomp$194_sym$jscomp$21$$)?Number.NEGATIVE_INFINITY:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$224$Inf$$,$_$jscomp$194_sym$jscomp$21$$)?Number.POSITIVE_INFINITY:$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$109$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([["Invalid token: ##",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$194_sym$jscomp$21$$)].join("")]))};
$cljs$tools$reader$edn$macros$$=function($ch$jscomp$57$$){switch($ch$jscomp$57$$){case '"':return $cljs$tools$reader$edn$read_string_STAR_$$;case ":":return $cljs$tools$reader$edn$read_keyword$$;case ";":return $APP.$cljs$tools$reader$impl$commons$read_comment$$;case "^":return $cljs$tools$reader$edn$read_meta$$;case "(":return $cljs$tools$reader$edn$read_list$$;case ")":return $cljs$tools$reader$edn$read_unmatched_delimiter$$;case "[":return $cljs$tools$reader$edn$read_vector$$;case "]":return $cljs$tools$reader$edn$read_unmatched_delimiter$$;
case "{":return $cljs$tools$reader$edn$read_map$$;case "}":return $cljs$tools$reader$edn$read_unmatched_delimiter$$;case "\\":return $cljs$tools$reader$edn$read_char_STAR_$$;case "#":return $cljs$tools$reader$edn$read_dispatch$$;default:return null}};
$cljs$tools$reader$edn$dispatch_macros$$=function($ch$jscomp$58$$){switch($ch$jscomp$58$$){case "^":return $cljs$tools$reader$edn$read_meta$$;case "{":return $cljs$tools$reader$edn$read_set$$;case "\x3c":return $APP.$cljs$tools$reader$impl$commons$throwing_reader$$("Unreadable form");case "!":return $APP.$cljs$tools$reader$impl$commons$read_comment$$;case "_":return $cljs$tools$reader$edn$read_discard$$;case ":":return $cljs$tools$reader$edn$read_namespaced_map$$;case "#":return $cljs$tools$reader$edn$read_symbolic_value$$;
default:return null}};
$cljs$tools$reader$edn$read_tagged$$=function($rdr$jscomp$110$$,$initch$jscomp$13_tag$jscomp$19$$,$opts$jscomp$107_temp__5823__auto____$1$jscomp$6$$){$initch$jscomp$13_tag$jscomp$19$$=$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$?$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$($rdr$jscomp$110$$,!0,null,$opts$jscomp$107_temp__5823__auto____$1$jscomp$6$$):$cljs$tools$reader$edn$read$$($rdr$jscomp$110$$,!0,null,$opts$jscomp$107_temp__5823__auto____$1$jscomp$6$$);var $object$jscomp$8$$=
$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$?$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$($rdr$jscomp$110$$,!0,null,$opts$jscomp$107_temp__5823__auto____$1$jscomp$6$$):$cljs$tools$reader$edn$read$$($rdr$jscomp$110$$,!0,null,$opts$jscomp$107_temp__5823__auto____$1$jscomp$6$$);$initch$jscomp$13_tag$jscomp$19$$ instanceof $APP.$cljs$core$Symbol$$||$APP.$cljs$tools$reader$impl$errors$throw_bad_reader_tag$$($rdr$jscomp$110$$,"Reader tag must be a symbol");var $or__5025__auto__$jscomp$inline_3066_temp__5823__auto__$jscomp$31$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$250$readers$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$107_temp__5823__auto____$1$jscomp$6$$),$initch$jscomp$13_tag$jscomp$19$$);$or__5025__auto__$jscomp$inline_3066_temp__5823__auto__$jscomp$31$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_3066_temp__5823__auto__$jscomp$31$$)?$or__5025__auto__$jscomp$inline_3066_temp__5823__auto__$jscomp$31$$:$APP.$cljs$tools$reader$default_data_readers$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$cljs$tools$reader$default_data_readers$$.$cljs$core$IFn$_invoke$arity$1$($initch$jscomp$13_tag$jscomp$19$$):(0,$APP.$cljs$tools$reader$default_data_readers$$)($initch$jscomp$13_tag$jscomp$19$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_3066_temp__5823__auto__$jscomp$31$$))return $or__5025__auto__$jscomp$inline_3066_temp__5823__auto__$jscomp$31$$.$cljs$core$IFn$_invoke$arity$1$?$or__5025__auto__$jscomp$inline_3066_temp__5823__auto__$jscomp$31$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$8$$):
$or__5025__auto__$jscomp$inline_3066_temp__5823__auto__$jscomp$31$$($object$jscomp$8$$);$opts$jscomp$107_temp__5823__auto____$1$jscomp$6$$=$APP.$cljs$cst$205$default$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$107_temp__5823__auto____$1$jscomp$6$$);return $APP.$cljs$core$truth_$$($opts$jscomp$107_temp__5823__auto____$1$jscomp$6$$)?$opts$jscomp$107_temp__5823__auto____$1$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$?$opts$jscomp$107_temp__5823__auto____$1$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$($initch$jscomp$13_tag$jscomp$19$$,
$object$jscomp$8$$):$opts$jscomp$107_temp__5823__auto____$1$jscomp$6$$($initch$jscomp$13_tag$jscomp$19$$,$object$jscomp$8$$):$APP.$cljs$tools$reader$impl$errors$throw_unknown_reader_tag$$($rdr$jscomp$110$$,$initch$jscomp$13_tag$jscomp$19$$)};
$cljs$tools$reader$edn$read$$=function($var_args$jscomp$332$$){switch(arguments.length){case 1:return $cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,arguments[0]);case 2:return $cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);case 4:return $cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$(arguments[0],arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$02$$=function($map__25323__$1_p__25321$$,$reader$jscomp$44$$){$map__25323__$1_p__25321$$=$APP.$cljs$core$__destructure_map$$($map__25323__$1_p__25321$$);var $eof$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__25323__$1_p__25321$$,$cljs$cst$213$eof$$),$eof_error_QMARK_$jscomp$5$$=!$APP.$cljs$core$contains_QMARK_$$($map__25323__$1_p__25321$$,$cljs$cst$213$eof$$);return $cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$($reader$jscomp$44$$,
$eof_error_QMARK_$jscomp$5$$,$eof$jscomp$1$$,$map__25323__$1_p__25321$$)};
$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$04$$=function($reader$jscomp$45$$,$e$jscomp$129_eof_error_QMARK_$jscomp$6$$,$d$jscomp$107_eof$jscomp$2$$,$opts$jscomp$109$$){try{for(;;){var $ch$jscomp$59$$=$APP.$cljs$tools$reader$reader_types$read_char$$($reader$jscomp$45$$);if(!$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$59$$)){if($ch$jscomp$59$$==null)return $APP.$cljs$core$truth_$$($e$jscomp$129_eof_error_QMARK_$jscomp$6$$)?$APP.$cljs$tools$reader$impl$errors$throw_eof_error$$($reader$jscomp$45$$,
null):$d$jscomp$107_eof$jscomp$2$$;if($APP.$cljs$tools$reader$impl$utils$numeric_QMARK_$$($ch$jscomp$59$$)||("+"===$ch$jscomp$59$$||"-"===$ch$jscomp$59$$)&&$APP.$cljs$tools$reader$impl$utils$numeric_QMARK_$$($reader$jscomp$45$$.$cljs$tools$reader$reader_types$Reader$peek_char$arity$1$(null)))return $cljs$tools$reader$edn$read_number$$($reader$jscomp$45$$,$ch$jscomp$59$$);var $f$jscomp$341$$=$cljs$tools$reader$edn$macros$$($ch$jscomp$59$$);if($APP.$cljs$core$truth_$$($f$jscomp$341$$)){var $res$jscomp$15$$=
$f$jscomp$341$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$341$$.$cljs$core$IFn$_invoke$arity$3$($reader$jscomp$45$$,$ch$jscomp$59$$,$opts$jscomp$109$$):$f$jscomp$341$$($reader$jscomp$45$$,$ch$jscomp$59$$,$opts$jscomp$109$$);if($res$jscomp$15$$===$reader$jscomp$45$$)continue;else return $res$jscomp$15$$}else return $cljs$tools$reader$edn$read_symbol$$($reader$jscomp$45$$,$ch$jscomp$59$$);break}}}catch($e25327$$){if($e25327$$ instanceof Error){$e$jscomp$129_eof_error_QMARK_$jscomp$6$$=$e25327$$;if($e$jscomp$129_eof_error_QMARK_$jscomp$6$$ instanceof
$APP.$cljs$core$ExceptionInfo$$){$d$jscomp$107_eof$jscomp$2$$=$APP.$cljs$core$ex_data$$($e$jscomp$129_eof_error_QMARK_$jscomp$6$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$206$reader_exception$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($d$jscomp$107_eof$jscomp$2$$)))throw $e$jscomp$129_eof_error_QMARK_$jscomp$6$$;throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$129_eof_error_QMARK_$jscomp$6$$.message,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$206$reader_exception$$],null),$d$jscomp$107_eof$jscomp$2$$,$APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$($reader$jscomp$45$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$209$line$$,$APP.$cljs$tools$reader$reader_types$get_line_number$$($reader$jscomp$45$$),$APP.$cljs$cst$216$column$$,$cljs$tools$reader$reader_types$get_column_number$$($reader$jscomp$45$$),$APP.$cljs$cst$208$file$$,$APP.$cljs$tools$reader$reader_types$get_file_name$$($reader$jscomp$45$$)],
null):null])),$e$jscomp$129_eof_error_QMARK_$jscomp$6$$);}throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$129_eof_error_QMARK_$jscomp$6$$.message,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$206$reader_exception$$],null),$APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$($reader$jscomp$45$$)?
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$209$line$$,$APP.$cljs$tools$reader$reader_types$get_line_number$$($reader$jscomp$45$$),$APP.$cljs$cst$216$column$$,$cljs$tools$reader$reader_types$get_column_number$$($reader$jscomp$45$$),$APP.$cljs$cst$208$file$$,$APP.$cljs$tools$reader$reader_types$get_file_name$$($reader$jscomp$45$$)],null):null])),$e$jscomp$129_eof_error_QMARK_$jscomp$6$$);}throw $e25327$$;}};
$cljs$reader$parse_int$$=function($n$jscomp$177_s$jscomp$184$$){$n$jscomp$177_s$jscomp$184$$=parseInt($n$jscomp$177_s$jscomp$184$$,10);return $APP.$cljs$core$not$$(isNaN($n$jscomp$177_s$jscomp$184$$))?$n$jscomp$177_s$jscomp$184$$:null};
$cljs$reader$check$$=function($low$jscomp$6$$,$n$jscomp$178$$,$high$jscomp$7$$,$msg$jscomp$8$$){if(!($low$jscomp$6$$<=$n$jscomp$178$$&&$n$jscomp$178$$<=$high$jscomp$7$$))throw Error([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($msg$jscomp$8$$)," Failed:  ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($low$jscomp$6$$),"\x3c\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$178$$),"\x3c\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($high$jscomp$7$$)].join(""));
return $n$jscomp$178$$};
$cljs$reader$parse_and_validate_timestamp$$=function($s$jscomp$185_years__$1$$){var $months__$1_vec__25498$$=$APP.$cljs$core$re_matches$$($cljs$reader$timestamp_regex$$,$s$jscomp$185_years__$1$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($months__$1_vec__25498$$,0,null);var $days__$1_years$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($months__$1_vec__25498$$,1,null),$months$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($months__$1_vec__25498$$,2,null),$days$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($months__$1_vec__25498$$,3,null),$hours$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($months__$1_vec__25498$$,4,null),$minutes$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($months__$1_vec__25498$$,5,null),$seconds$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($months__$1_vec__25498$$,6,null),$fraction$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($months__$1_vec__25498$$,7,null),$offset$jscomp$30_offset_sign$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($months__$1_vec__25498$$,8,null),$offset_hours$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($months__$1_vec__25498$$,9,null),$offset_minutes$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($months__$1_vec__25498$$,10,null);if($APP.$cljs$core$not$$($months__$1_vec__25498$$))throw Error(["Unrecognized date/time syntax: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$185_years__$1$$)].join(""));$s$jscomp$185_years__$1$$=
$cljs$reader$parse_int$$($days__$1_years$$);$months__$1_vec__25498$$=function(){var $or__5025__auto__$jscomp$65$$=$cljs$reader$parse_int$$($months$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$65$$)?$or__5025__auto__$jscomp$65$$:1}();$days__$1_years$$=function(){var $or__5025__auto__$jscomp$66$$=$cljs$reader$parse_int$$($days$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$66$$)?$or__5025__auto__$jscomp$66$$:1}();var $hours__$1$$=function(){var $or__5025__auto__$jscomp$67$$=
$cljs$reader$parse_int$$($hours$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$67$$)?$or__5025__auto__$jscomp$67$$:0}(),$minutes__$1$$=function(){var $or__5025__auto__$jscomp$68$$=$cljs$reader$parse_int$$($minutes$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$68$$)?$or__5025__auto__$jscomp$68$$:0}(),$seconds__$1$$=function(){var $or__5025__auto__$jscomp$69$$=$cljs$reader$parse_int$$($seconds$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$69$$)?$or__5025__auto__$jscomp$69$$:
0}(),$fraction__$1$$=function(){a:if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$APP.$cljs$core$count$$($fraction$$)))var $JSCompiler_inline_result$jscomp$275_b$jscomp$inline_3070_or__5025__auto__$jscomp$70$$=$fraction$$;else if(3<$APP.$cljs$core$count$$($fraction$$))$JSCompiler_inline_result$jscomp$275_b$jscomp$inline_3070_or__5025__auto__$jscomp$70$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($fraction$$,0,3);else{for($JSCompiler_inline_result$jscomp$275_b$jscomp$inline_3070_or__5025__auto__$jscomp$70$$=
new $APP.$goog$string$StringBuffer$$($fraction$$);;)if($JSCompiler_inline_result$jscomp$275_b$jscomp$inline_3070_or__5025__auto__$jscomp$70$$.getLength()<3)$JSCompiler_inline_result$jscomp$275_b$jscomp$inline_3070_or__5025__auto__$jscomp$70$$=$JSCompiler_inline_result$jscomp$275_b$jscomp$inline_3070_or__5025__auto__$jscomp$70$$.append("0");else{$JSCompiler_inline_result$jscomp$275_b$jscomp$inline_3070_or__5025__auto__$jscomp$70$$=$JSCompiler_inline_result$jscomp$275_b$jscomp$inline_3070_or__5025__auto__$jscomp$70$$.toString();
break a}$JSCompiler_inline_result$jscomp$275_b$jscomp$inline_3070_or__5025__auto__$jscomp$70$$=void 0}$JSCompiler_inline_result$jscomp$275_b$jscomp$inline_3070_or__5025__auto__$jscomp$70$$=$cljs$reader$parse_int$$($JSCompiler_inline_result$jscomp$275_b$jscomp$inline_3070_or__5025__auto__$jscomp$70$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$275_b$jscomp$inline_3070_or__5025__auto__$jscomp$70$$)?$JSCompiler_inline_result$jscomp$275_b$jscomp$inline_3070_or__5025__auto__$jscomp$70$$:
0}();$offset$jscomp$30_offset_sign$$=($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$30_offset_sign$$,"-")?-1:1)*(function(){var $or__5025__auto__$jscomp$71$$=$cljs$reader$parse_int$$($offset_hours$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$71$$)?$or__5025__auto__$jscomp$71$$:0}()*60+function(){var $or__5025__auto__$jscomp$72$$=$cljs$reader$parse_int$$($offset_minutes$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$72$$)?$or__5025__auto__$jscomp$72$$:
0}());return new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$s$jscomp$185_years__$1$$,$cljs$reader$check$$(1,$months__$1_vec__25498$$,12,"timestamp month field must be in range 1..12"),$cljs$reader$check$$(1,$days__$1_years$$,$cljs$reader$days_in_month$$($months__$1_vec__25498$$,$APP.$cljs$core$mod$$($s$jscomp$185_years__$1$$,4)===0&&($APP.$cljs$core$mod$$($s$jscomp$185_years__$1$$,100)!==0||$APP.$cljs$core$mod$$($s$jscomp$185_years__$1$$,400)===0)),
"timestamp day field must be in range 1..last day in month"),$cljs$reader$check$$(0,$hours__$1$$,23,"timestamp hour field must be in range 0..23"),$cljs$reader$check$$(0,$minutes__$1$$,59,"timestamp minute field must be in range 0..59"),$cljs$reader$check$$(0,$seconds__$1$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($minutes__$1$$,59)?60:59,"timestamp second field must be in range 0..60"),$cljs$reader$check$$(0,$fraction__$1$$,999,"timestamp millisecond field must be in range 0..999"),
$offset$jscomp$30_offset_sign$$],null)};
$cljs$reader$read_string$cljs$0core$0IFn$0_invoke$0arity$01$$=function($s$jscomp$187$$){var $opts$jscomp$inline_11355$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$250$readers$$,$APP.$cljs$core$_deref$$($cljs$reader$_STAR_tag_table_STAR_$$),$APP.$cljs$cst$205$default$$,$APP.$cljs$core$_deref$$($cljs$reader$_STAR_default_data_reader_fn_STAR_$$),$cljs$cst$213$eof$$,null],null);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($s$jscomp$187$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$187$$,
""):$s$jscomp$187$$)?$cljs$tools$reader$edn$read$cljs$0core$0IFn$0_invoke$0arity$02$$($opts$jscomp$inline_11355$$,new $APP.$cljs$tools$reader$reader_types$PushbackReader$$(new $APP.$cljs$tools$reader$reader_types$StringReader$$($s$jscomp$187$$,$APP.$cljs$core$count$$($s$jscomp$187$$)))):null};$APP.$goog$math$toRadians$$=function($angleDegrees$$){return $angleDegrees$$*Math.PI/180};$app$common$math$nan_QMARK_$$=function($v$jscomp$85$$){return isNaN($v$jscomp$85$$)};
$APP.$app$common$math$finite_QMARK_$$=function($v$jscomp$86$$){var $and__5023__auto__$jscomp$46$$=$v$jscomp$86$$!=null;return $and__5023__auto__$jscomp$46$$?isFinite($v$jscomp$86$$):$and__5023__auto__$jscomp$46$$};$APP.$app$common$math$finite$$=function($v$jscomp$87$$,$default$$$){return $APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($v$jscomp$87$$))?$v$jscomp$87$$:$default$$$};$APP.$app$common$math$abs$$=function($v$jscomp$88$$){return Math.abs($v$jscomp$88$$)};
$app$common$math$cubicroot$$=function($v$jscomp$96$$){return $v$jscomp$96$$>0?Math.pow($v$jscomp$96$$,1/3):-Math.pow(-$v$jscomp$96$$,1/3)};$APP.$app$common$math$floor$$=function($v$jscomp$97$$){return Math.floor($v$jscomp$97$$)};$APP.$app$common$math$ceil$$=function($v$jscomp$100$$){return Math.ceil($v$jscomp$100$$)};
$APP.$app$common$math$precision$$=function($v$jscomp$101$$,$d$jscomp$109_n$jscomp$179$$){return typeof $v$jscomp$101$$==="number"&&$APP.$cljs$core$integer_QMARK_$$($d$jscomp$109_n$jscomp$179$$)?($d$jscomp$109_n$jscomp$179$$=Math.pow(10,$d$jscomp$109_n$jscomp$179$$),$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$101$$*$d$jscomp$109_n$jscomp$179$$)/$d$jscomp$109_n$jscomp$179$$):null};
$APP.$app$common$math$hypot$$=function($a$jscomp$202$$,$b$jscomp$168$$){return Math.hypot($a$jscomp$202$$,$b$jscomp$168$$)};
$APP.$app$common$math$clamp$$=function($num$jscomp$16$$,$from$jscomp$4$$,$to$jscomp$5$$){var $or__5025__auto__$jscomp$inline_3091$$=isNaN($num$jscomp$16$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_3091$$)?$or__5025__auto__$jscomp$inline_3091$$:$num$jscomp$16$$<$from$jscomp$4$$)?$from$jscomp$4$$:$num$jscomp$16$$>$to$jscomp$5$$?$to$jscomp$5$$:$num$jscomp$16$$};
$APP.$app$common$math$almost_zero_QMARK_$$=function($num$jscomp$17$$){return $APP.$app$common$math$abs$$($num$jscomp$17$$)<1E-4};$app$common$math$round_to_zero$$=function($num$jscomp$18$$){return $APP.$app$common$math$abs$$($num$jscomp$18$$)<1E-4?0:$num$jscomp$18$$};$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($num1$jscomp$1$$,$num2$jscomp$1$$){return $app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($num1$jscomp$1$$,$num2$jscomp$1$$,.001)};
$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($num1$jscomp$2$$,$num2$jscomp$2$$,$precision$$){return $APP.$app$common$math$abs$$($num1$jscomp$2$$-$num2$jscomp$2$$)<=$precision$$};$app$common$math$max_abs$$=function($a$jscomp$203$$,$b$jscomp$169$$){return Math.max($APP.$app$common$math$abs$$($a$jscomp$203$$),$APP.$app$common$math$abs$$($b$jscomp$169$$))};
$clojure$set$bubble_max_key$$=function($k$jscomp$232$$,$coll$jscomp$825$$){var $max$jscomp$1$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$max_key$$,$k$jscomp$232$$,$coll$jscomp$825$$);return $APP.$cljs$core$cons$$($max$jscomp$1$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__24230_SHARP_$$){return $max$jscomp$1$$===$p1__24230_SHARP_$$},$coll$jscomp$825$$))};
$APP.$clojure$set$rename_keys$$=function($map$jscomp$14$$,$kmap$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($m$jscomp$85$$,$new$_p__24263$$){var $old$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new$_p__24263$$,0,null);$new$_p__24263$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new$_p__24263$$,1,null);return $APP.$cljs$core$contains_QMARK_$$($map$jscomp$14$$,$old$jscomp$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$85$$,
$new$_p__24263$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map$jscomp$14$$,$old$jscomp$1$$)):$m$jscomp$85$$},$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$,$map$jscomp$14$$,$APP.$cljs$core$keys$$($kmap$$)),$kmap$$)};
$APP.$clojure$set$map_invert$$=function($m$jscomp$87$$){return $APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce_kv$$(function($m__$1$jscomp$4$$,$k$jscomp$234$$,$v$jscomp$103$$){return $APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($m__$1$jscomp$4$$,$v$jscomp$103$$,$k$jscomp$234$$)},$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$m$jscomp$87$$))};
$APP.$clojure$set$subset_QMARK_$$=function($set1$$,$set2$$){return $APP.$cljs$core$count$$($set1$$)<=$APP.$cljs$core$count$$($set2$$)&&$APP.$cljs$core$every_QMARK_$$(function($p1__24297_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($set2$$,$p1__24297_SHARP_$$)},$set1$$)};
$clojure$walk$walk$$=function($inner$jscomp$1$$,$outer$$,$form$jscomp$24$$){if($APP.$cljs$core$list_QMARK_$$($form$jscomp$24$$)){var $G__24370_G__24371_G__24374_G__24375_G__24379$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$list$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($inner$jscomp$1$$,$form$jscomp$24$$));return $outer$$.$cljs$core$IFn$_invoke$arity$1$?$outer$$.$cljs$core$IFn$_invoke$arity$1$($G__24370_G__24371_G__24374_G__24375_G__24379$$):$outer$$($G__24370_G__24371_G__24374_G__24375_G__24379$$)}return $APP.$cljs$core$map_entry_QMARK_$$($form$jscomp$24$$)?
($G__24370_G__24371_G__24374_G__24375_G__24379$$=new $APP.$cljs$core$MapEntry$$(function(){var $G__24372$$=$APP.$cljs$core$_key$$($form$jscomp$24$$);return $inner$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$inner$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__24372$$):$inner$jscomp$1$$($G__24372$$)}(),function(){var $G__24373$$=$APP.$cljs$core$_val$$($form$jscomp$24$$);return $inner$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$inner$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__24373$$):$inner$jscomp$1$$($G__24373$$)}(),
null),$outer$$.$cljs$core$IFn$_invoke$arity$1$?$outer$$.$cljs$core$IFn$_invoke$arity$1$($G__24370_G__24371_G__24374_G__24375_G__24379$$):$outer$$($G__24370_G__24371_G__24374_G__24375_G__24379$$)):$APP.$cljs$core$seq_QMARK_$$($form$jscomp$24$$)?($G__24370_G__24371_G__24374_G__24375_G__24379$$=$APP.$cljs$core$doall$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($inner$jscomp$1$$,$form$jscomp$24$$)),$outer$$.$cljs$core$IFn$_invoke$arity$1$?$outer$$.$cljs$core$IFn$_invoke$arity$1$($G__24370_G__24371_G__24374_G__24375_G__24379$$):
$outer$$($G__24370_G__24371_G__24374_G__24375_G__24379$$)):$APP.$cljs$core$record_QMARK_$$($form$jscomp$24$$)?($G__24370_G__24371_G__24374_G__24375_G__24379$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($r$jscomp$36$$,$x$jscomp$678$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($r$jscomp$36$$,$inner$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$inner$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$678$$):$inner$jscomp$1$$($x$jscomp$678$$))},$form$jscomp$24$$,
$form$jscomp$24$$),$outer$$.$cljs$core$IFn$_invoke$arity$1$?$outer$$.$cljs$core$IFn$_invoke$arity$1$($G__24370_G__24371_G__24374_G__24375_G__24379$$):$outer$$($G__24370_G__24371_G__24374_G__24375_G__24379$$)):$APP.$cljs$core$coll_QMARK_$$($form$jscomp$24$$)?($G__24370_G__24371_G__24374_G__24375_G__24379$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$empty$$($form$jscomp$24$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($inner$jscomp$1$$,$form$jscomp$24$$)),$outer$$.$cljs$core$IFn$_invoke$arity$1$?
$outer$$.$cljs$core$IFn$_invoke$arity$1$($G__24370_G__24371_G__24374_G__24375_G__24379$$):$outer$$($G__24370_G__24371_G__24374_G__24375_G__24379$$)):$outer$$.$cljs$core$IFn$_invoke$arity$1$?$outer$$.$cljs$core$IFn$_invoke$arity$1$($form$jscomp$24$$):$outer$$($form$jscomp$24$$)};$APP.$cuerdas$core$empty_QMARK_$$=function($s$jscomp$193$$){return $s$jscomp$193$$==null||typeof $s$jscomp$193$$==="string"&&$APP.$cljs$core$count$$($s$jscomp$193$$)===0};
$APP.$cuerdas$core$includes_QMARK_$$=function($s$jscomp$195$$,$subs$jscomp$1$$){var $and__5023__auto__$jscomp$47_and__5023__auto____$1$jscomp$17$$=typeof $s$jscomp$195$$==="string";return $and__5023__auto__$jscomp$47_and__5023__auto____$1$jscomp$17$$?($and__5023__auto__$jscomp$47_and__5023__auto____$1$jscomp$17$$=typeof $subs$jscomp$1$$==="string")?$s$jscomp$195$$.indexOf($subs$jscomp$1$$)!=-1:$and__5023__auto__$jscomp$47_and__5023__auto____$1$jscomp$17$$:$and__5023__auto__$jscomp$47_and__5023__auto____$1$jscomp$17$$};
$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$=function($s$jscomp$196$$,$begin$jscomp$7$$){return typeof $s$jscomp$196$$==="string"?$s$jscomp$196$$.slice($begin$jscomp$7$$):null};$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$=function($s$jscomp$197$$,$begin$jscomp$8$$,$end$jscomp$41$$){return typeof $s$jscomp$197$$==="string"?$s$jscomp$197$$.slice($begin$jscomp$8$$,$end$jscomp$41$$):null};
$APP.$cuerdas$core$starts_with_QMARK_$$=function($s$jscomp$199$$,$prefix$jscomp$8$$){return typeof $s$jscomp$199$$==="string"&&typeof $prefix$jscomp$8$$==="string"&&$s$jscomp$199$$.lastIndexOf($prefix$jscomp$8$$,0)===0};
$APP.$cuerdas$core$ends_with_QMARK_$$=function($s$jscomp$201$$,$suffix$jscomp$6$$){var $JSCompiler_temp$jscomp$281_JSCompiler_temp$jscomp$282_l$jscomp$inline_3096_or__5025__auto__$jscomp$inline_3095$$;if($JSCompiler_temp$jscomp$281_JSCompiler_temp$jscomp$282_l$jscomp$inline_3096_or__5025__auto__$jscomp$inline_3095$$=typeof $s$jscomp$201$$==="string")if($JSCompiler_temp$jscomp$281_JSCompiler_temp$jscomp$282_l$jscomp$inline_3096_or__5025__auto__$jscomp$inline_3095$$=typeof $suffix$jscomp$6$$==="string")$JSCompiler_temp$jscomp$281_JSCompiler_temp$jscomp$282_l$jscomp$inline_3096_or__5025__auto__$jscomp$inline_3095$$=
$APP.$cljs$core$count$$($suffix$jscomp$6$$)===0,$JSCompiler_temp$jscomp$281_JSCompiler_temp$jscomp$282_l$jscomp$inline_3096_or__5025__auto__$jscomp$inline_3095$$||($JSCompiler_temp$jscomp$281_JSCompiler_temp$jscomp$282_l$jscomp$inline_3096_or__5025__auto__$jscomp$inline_3095$$=$APP.$cljs$core$count$$($s$jscomp$201$$)-$APP.$cljs$core$count$$($suffix$jscomp$6$$),$JSCompiler_temp$jscomp$281_JSCompiler_temp$jscomp$282_l$jscomp$inline_3096_or__5025__auto__$jscomp$inline_3095$$=$JSCompiler_temp$jscomp$281_JSCompiler_temp$jscomp$282_l$jscomp$inline_3096_or__5025__auto__$jscomp$inline_3095$$>=
0&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$201$$.indexOf($suffix$jscomp$6$$,$JSCompiler_temp$jscomp$281_JSCompiler_temp$jscomp$282_l$jscomp$inline_3096_or__5025__auto__$jscomp$inline_3095$$),$JSCompiler_temp$jscomp$281_JSCompiler_temp$jscomp$282_l$jscomp$inline_3096_or__5025__auto__$jscomp$inline_3095$$));return $JSCompiler_temp$jscomp$281_JSCompiler_temp$jscomp$282_l$jscomp$inline_3096_or__5025__auto__$jscomp$inline_3095$$};
$APP.$cuerdas$core$lower$$=function($s$jscomp$202$$){return typeof $s$jscomp$202$$==="string"?$s$jscomp$202$$.toLowerCase():null};$APP.$cuerdas$core$upper$$=function($s$jscomp$203$$){return typeof $s$jscomp$203$$==="string"?$s$jscomp$203$$.toUpperCase():null};
$APP.$cuerdas$core$blank_QMARK_$$=function($s$jscomp$204$$){return $s$jscomp$204$$==null||typeof $s$jscomp$204$$==="string"&&($APP.$cljs$core$count$$($s$jscomp$204$$)===0||$APP.$cljs$core$re_matches$$($cuerdas$core$str_blank_re$$,$s$jscomp$204$$)!=null)};$cuerdas$core$word_QMARK_$$=function($s$jscomp$208$$){return typeof $s$jscomp$208$$==="string"&&$APP.$cljs$core$re_matches$$($cuerdas$core$world_pred_re$$,$s$jscomp$208$$)!=null};
$cuerdas$core$numeric_QMARK_$$=function($s$jscomp$210$$){return typeof $s$jscomp$210$$==="string"&&$APP.$cljs$core$re_matches$$($cuerdas$core$numeric_pred_re$$,$s$jscomp$210$$)!=null};$APP.$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$=function($s$jscomp$211$$,$val$jscomp$109$$){return typeof $s$jscomp$211$$==="string"&&typeof $val$jscomp$109$$==="string"?$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$211$$,$val$jscomp$109$$):null};
$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$=function($JSCompiler_temp$jscomp$259_result$jscomp$inline_3100_s$jscomp$213$$,$val$jscomp$111$$){typeof $JSCompiler_temp$jscomp$259_result$jscomp$inline_3100_s$jscomp$213$$==="string"&&typeof $val$jscomp$111$$==="string"?($JSCompiler_temp$jscomp$259_result$jscomp$inline_3100_s$jscomp$213$$=$JSCompiler_temp$jscomp$259_result$jscomp$inline_3100_s$jscomp$213$$.lastIndexOf($val$jscomp$111$$),$JSCompiler_temp$jscomp$259_result$jscomp$inline_3100_s$jscomp$213$$=
$JSCompiler_temp$jscomp$259_result$jscomp$inline_3100_s$jscomp$213$$<0?null:$JSCompiler_temp$jscomp$259_result$jscomp$inline_3100_s$jscomp$213$$):$JSCompiler_temp$jscomp$259_result$jscomp$inline_3100_s$jscomp$213$$=null;return $JSCompiler_temp$jscomp$259_result$jscomp$inline_3100_s$jscomp$213$$};$cuerdas$core$str__GT_trim_re$$=function($chs_rxstr$$){$chs_rxstr$$="["+$goog$string$regExpEscape$$($chs_rxstr$$)+"]";return $APP.$cljs$core$re_pattern$$("^"+$chs_rxstr$$+"+|"+$chs_rxstr$$+"+$")};
$cuerdas$core$str__GT_rtrim_re$$=function($chs$jscomp$1_rxstr__$1$jscomp$1$$){$chs$jscomp$1_rxstr__$1$jscomp$1$$="["+$goog$string$regExpEscape$$($chs$jscomp$1_rxstr__$1$jscomp$1$$)+"]+$";return $APP.$cljs$core$re_pattern$$($chs$jscomp$1_rxstr__$1$jscomp$1$$)};
$cuerdas$core$rtrim$cljs$0core$0IFn$0_invoke$0arity$02$$=function($s$jscomp$218$$){if(typeof $s$jscomp$218$$==="string"){var $rx$jscomp$1$$=$cuerdas$core$str__GT_rtrim_re$$("%");return $APP.$cuerdas$core$replace$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cuerdas$core$replace$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$218$$,$rx$jscomp$1$$,""):$APP.$cuerdas$core$replace$$($s$jscomp$218$$,$rx$jscomp$1$$,"")}return null};
$cuerdas$core$strip_prefix$$=function($s$jscomp$222$$,$prefix$jscomp$9$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($s$jscomp$222$$,$prefix$jscomp$9$$)?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$222$$,$APP.$cljs$core$count$$($prefix$jscomp$9$$),$APP.$cljs$core$count$$($s$jscomp$222$$)):$s$jscomp$222$$};
$APP.$cuerdas$core$strip_suffix$$=function($s$jscomp$223$$,$suffix$jscomp$7$$){return $APP.$cuerdas$core$ends_with_QMARK_$$($s$jscomp$223$$,$suffix$jscomp$7$$)?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$223$$,0,$APP.$cljs$core$count$$($s$jscomp$223$$)-$APP.$cljs$core$count$$($suffix$jscomp$7$$)):$s$jscomp$223$$};
$cuerdas$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$=function($s$jscomp$225$$,$n$jscomp$182$$){return typeof $s$jscomp$225$$==="string"?$goog$string$repeat$$($s$jscomp$225$$,$n$jscomp$182$$):null};
$cuerdas$core$replace_all$$=function($s$jscomp$226$$,$re$jscomp$9$$,$replacement$jscomp$9$$){var $flags$jscomp$7_flags__$1$$=$re$jscomp$9$$.flags;$flags$jscomp$7_flags__$1$$=$APP.$cuerdas$core$includes_QMARK_$$($flags$jscomp$7_flags__$1$$,"g")?$flags$jscomp$7_flags__$1$$:""+$flags$jscomp$7_flags__$1$$+"g";return $s$jscomp$226$$.replace(new RegExp($re$jscomp$9$$.source,$flags$jscomp$7_flags__$1$$),$replacement$jscomp$9$$)};
$cuerdas$core$replace_with$$=function($f$jscomp$348$$){return function(){function $G__27246$$($var_args$jscomp$353$$){var $G__27251__i_args$jscomp$120$$=null;if(arguments.length>0){$G__27251__i_args$jscomp$120$$=0;for(var $G__27251__a$$=Array(arguments.length-0);$G__27251__i_args$jscomp$120$$<$G__27251__a$$.length;)$G__27251__a$$[$G__27251__i_args$jscomp$120$$]=arguments[$G__27251__i_args$jscomp$120$$+0],++$G__27251__i_args$jscomp$120$$;$G__27251__i_args$jscomp$120$$=new $APP.$cljs$core$IndexedSeq$$($G__27251__a$$,
0,null)}return $G__27246__delegate$$.call(this,$G__27251__i_args$jscomp$120$$)}function $G__27246__delegate$$($G__25965_G__25967_args$jscomp$119_matches$jscomp$5$$){$G__25965_G__25967_args$jscomp$119_matches$jscomp$5$$=$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$02$$(2,$G__25965_G__25967_args$jscomp$119_matches$jscomp$5$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($G__25965_G__25967_args$jscomp$119_matches$jscomp$5$$),1))return $G__25965_G__25967_args$jscomp$119_matches$jscomp$5$$=
$APP.$cljs$core$first$$($G__25965_G__25967_args$jscomp$119_matches$jscomp$5$$),$f$jscomp$348$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$348$$.$cljs$core$IFn$_invoke$arity$1$($G__25965_G__25967_args$jscomp$119_matches$jscomp$5$$):$f$jscomp$348$$($G__25965_G__25967_args$jscomp$119_matches$jscomp$5$$);$G__25965_G__25967_args$jscomp$119_matches$jscomp$5$$=$APP.$cljs$core$vec$$($G__25965_G__25967_args$jscomp$119_matches$jscomp$5$$);return $f$jscomp$348$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$348$$.$cljs$core$IFn$_invoke$arity$1$($G__25965_G__25967_args$jscomp$119_matches$jscomp$5$$):
$f$jscomp$348$$($G__25965_G__25967_args$jscomp$119_matches$jscomp$5$$)}$G__27246$$.$cljs$lang$maxFixedArity$=0;$G__27246$$.$cljs$lang$applyTo$=function($arglist__27252_args$jscomp$121$$){$arglist__27252_args$jscomp$121$$=$APP.$cljs$core$seq$$($arglist__27252_args$jscomp$121$$);return $G__27246__delegate$$($arglist__27252_args$jscomp$121$$)};$G__27246$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__27246__delegate$$;return $G__27246$$}()};
$APP.$cuerdas$core$replace$$=function($s$jscomp$228$$,$match$jscomp$14$$,$replacement$jscomp$11$$){return typeof $s$jscomp$228$$==="string"?typeof $match$jscomp$14$$==="string"?$APP.$clojure$string$replace$$($s$jscomp$228$$,$match$jscomp$14$$,$replacement$jscomp$11$$):$APP.$cljs$core$regexp_QMARK_$$($match$jscomp$14$$)?typeof $replacement$jscomp$11$$==="string"?$cuerdas$core$replace_all$$($s$jscomp$228$$,$match$jscomp$14$$,$replacement$jscomp$11$$):$cuerdas$core$replace_all$$($s$jscomp$228$$,$match$jscomp$14$$,
$cuerdas$core$replace_with$$($replacement$jscomp$11$$)):null:null};
$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$=function($s$jscomp$236$$,$sep$jscomp$3$$){if($s$jscomp$236$$==null)return $s$jscomp$236$$;if($APP.$cljs$core$regexp_QMARK_$$($sep$jscomp$3$$))return $clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$236$$,$sep$jscomp$3$$);if(typeof $sep$jscomp$3$$==="string")return $clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$236$$,$APP.$cljs$core$re_pattern$$($goog$string$regExpEscape$$($sep$jscomp$3$$)));if($cljs$core$char_QMARK_$$($sep$jscomp$3$$))return $clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$236$$,
$APP.$cljs$core$re_pattern$$($goog$string$regExpEscape$$($sep$jscomp$3$$.toString())));throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Invalid arguments",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$254$sep$$,$sep$jscomp$3$$],null));};
$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$03$$=function($s$jscomp$237$$,$sep$jscomp$4$$,$num$jscomp$23$$){if($s$jscomp$237$$==null)return $s$jscomp$237$$;if($APP.$cljs$core$regexp_QMARK_$$($sep$jscomp$4$$))return $clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$237$$,$sep$jscomp$4$$,$num$jscomp$23$$);if(typeof $sep$jscomp$4$$==="string")return $clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$237$$,$APP.$cljs$core$re_pattern$$($goog$string$regExpEscape$$($sep$jscomp$4$$)),
$num$jscomp$23$$);if($cljs$core$char_QMARK_$$($sep$jscomp$4$$))return $clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$237$$,$APP.$cljs$core$re_pattern$$($goog$string$regExpEscape$$($sep$jscomp$4$$.toString())),$num$jscomp$23$$);throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Invalid arguments",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$254$sep$$,$sep$jscomp$4$$],null));};
$cuerdas$core$words$cljs$0core$0IFn$0_invoke$0arity$02$$=function($s$jscomp$243$$){return typeof $s$jscomp$243$$==="string"?$APP.$cljs$core$vec$$($APP.$cljs$core$re_seq$$($cuerdas$core$words_default_re$$,$s$jscomp$243$$)):null};
$cuerdas$core$interpolate_format$$=function($s$jscomp$244$$,$params$jscomp$5$$){return $APP.$cuerdas$core$replace$$($s$jscomp$244$$,/(?:%\([\d\w:_\-]+\)s|\$[\w\d:_\-]+)/,function($match$jscomp$16_val$jscomp$113_val__$1$jscomp$7$$){$match$jscomp$16_val$jscomp$113_val__$1$jscomp$7$$=$cljs$reader$read_string$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($match$jscomp$16_val$jscomp$113_val__$1$jscomp$7$$,
0,1),"$")?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($match$jscomp$16_val$jscomp$113_val__$1$jscomp$7$$,1):$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($match$jscomp$16_val$jscomp$113_val__$1$jscomp$7$$,2,-2));$match$jscomp$16_val$jscomp$113_val__$1$jscomp$7$$=$match$jscomp$16_val$jscomp$113_val__$1$jscomp$7$$ instanceof $APP.$cljs$core$Symbol$$?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($match$jscomp$16_val$jscomp$113_val__$1$jscomp$7$$):
$APP.$cljs$core$keyword$$($match$jscomp$16_val$jscomp$113_val__$1$jscomp$7$$):$match$jscomp$16_val$jscomp$113_val__$1$jscomp$7$$;return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($params$jscomp$5$$,$match$jscomp$16_val$jscomp$113_val__$1$jscomp$7$$,""))})};
$cuerdas$core$indexed_format$$=function($s$jscomp$245$$,$params$jscomp$6$$){var $params__$1$$=$APP.$cljs$core$clj__GT_js$$($APP.$cljs$core$truth_$$($params$jscomp$6$$)?$params$jscomp$6$$:$APP.$cljs$core$PersistentVector$EMPTY$$);return $APP.$cuerdas$core$replace$$($s$jscomp$245$$,RegExp("%s","g"),function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$count$$($params__$1$$)===0?"%s":$params__$1$$.shift())})};
$cuerdas$core$unsurround$$=function($s$jscomp$248$$){var $surrounding__$1$$='"'.toString(),$length$jscomp$30$$=$APP.$cljs$core$count$$($surrounding__$1$$),$fstr$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$248$$,0,$length$jscomp$30$$),$lstr_slength$$=$APP.$cljs$core$count$$($s$jscomp$248$$),$rightend$$=$lstr_slength$$-$length$jscomp$30$$;$lstr_slength$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$248$$,$rightend$$,$lstr_slength$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($fstr$$,
$surrounding__$1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($lstr_slength$$,$surrounding__$1$$)?$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$248$$,$length$jscomp$30$$,$rightend$$):$s$jscomp$248$$};
$cuerdas$core$quote$cljs$0core$0IFn$0_invoke$0arity$01$$=function($s$jscomp$249$$){return typeof $s$jscomp$249$$==="string"?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("",new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,['"',$s$jscomp$249$$,'"'],null)):null};
$cuerdas$core$stylize_split$$=function($s$jscomp$253$$){return typeof $s$jscomp$253$$==="string"||$s$jscomp$253$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$seq$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cuerdas$core$replace$$($APP.$cljs$core$name$$($s$jscomp$253$$),$cuerdas$core$stylize_re1$$,"-$1"),$cuerdas$core$stylize_re2$$)):null};
$APP.$cuerdas$core$stylize$cljs$0core$0IFn$0_invoke$0arity$04$$=function($G__26501_G__26501__$1_first__26469$jscomp$inline_11363_s$jscomp$255$$,$JSCompiler_temp$jscomp$10659_first_fn$jscomp$1$$,$rest_fn$jscomp$1$$,$join_with$jscomp$3$$){$G__26501_G__26501__$1_first__26469$jscomp$inline_11363_s$jscomp$255$$=$cuerdas$core$stylize_split$$($G__26501_G__26501__$1_first__26469$jscomp$inline_11363_s$jscomp$255$$);$G__26501_G__26501__$1_first__26469$jscomp$inline_11363_s$jscomp$255$$=$G__26501_G__26501__$1_first__26469$jscomp$inline_11363_s$jscomp$255$$==
null?null:$APP.$cljs$core$seq$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$empty_QMARK_$$,$G__26501_G__26501__$1_first__26469$jscomp$inline_11363_s$jscomp$255$$));if($G__26501_G__26501__$1_first__26469$jscomp$inline_11363_s$jscomp$255$$==null)$JSCompiler_temp$jscomp$10659_first_fn$jscomp$1$$=null;else{var $seq__26468$jscomp$inline_11362_seq__26468__$1$jscomp$inline_11364$$=$APP.$cljs$core$seq$$($G__26501_G__26501__$1_first__26469$jscomp$inline_11363_s$jscomp$255$$);
$G__26501_G__26501__$1_first__26469$jscomp$inline_11363_s$jscomp$255$$=$APP.$cljs$core$first$$($seq__26468$jscomp$inline_11362_seq__26468__$1$jscomp$inline_11364$$);$seq__26468$jscomp$inline_11362_seq__26468__$1$jscomp$inline_11364$$=$APP.$cljs$core$next$$($seq__26468$jscomp$inline_11362_seq__26468__$1$jscomp$inline_11364$$);$JSCompiler_temp$jscomp$10659_first_fn$jscomp$1$$=typeof $G__26501_G__26501__$1_first__26469$jscomp$inline_11363_s$jscomp$255$$==="string"?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$($join_with$jscomp$3$$,
$APP.$cljs$core$cons$$($JSCompiler_temp$jscomp$10659_first_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_temp$jscomp$10659_first_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__26501_G__26501__$1_first__26469$jscomp$inline_11363_s$jscomp$255$$):$JSCompiler_temp$jscomp$10659_first_fn$jscomp$1$$($G__26501_G__26501__$1_first__26469$jscomp$inline_11363_s$jscomp$255$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($rest_fn$jscomp$1$$,$seq__26468$jscomp$inline_11362_seq__26468__$1$jscomp$inline_11364$$))):
null}return $JSCompiler_temp$jscomp$10659_first_fn$jscomp$1$$};$APP.$cuerdas$core$capital$$=function($s$jscomp$256$$){if(typeof $s$jscomp$256$$==="string"){var $len$jscomp$56$$=$s$jscomp$256$$.length;return $len$jscomp$56$$===0?$s$jscomp$256$$:""+$APP.$cuerdas$core$upper$$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$256$$,0,1))+$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$256$$,1,$len$jscomp$56$$)}return $s$jscomp$256$$};
$cuerdas$core$camel$$=function($s$jscomp$257$$){return $APP.$cuerdas$core$stylize$cljs$0core$0IFn$0_invoke$0arity$04$$($s$jscomp$257$$,$APP.$cuerdas$core$lower$$,$APP.$cuerdas$core$capital$$,"")};$APP.$cuerdas$core$kebab$$=function($s$jscomp$263$$){return $APP.$cuerdas$core$stylize$cljs$0core$0IFn$0_invoke$0arity$04$$($s$jscomp$263$$,$APP.$cuerdas$core$lower$$,$APP.$cuerdas$core$lower$$,"-")};
$APP.$cuerdas$core$css_selector$$=function($G__26612_s$jscomp$265$$){$G__26612_s$jscomp$265$$=$cuerdas$core$stylize_split$$($G__26612_s$jscomp$265$$);return $G__26612_s$jscomp$265$$==null?null:$APP.$cljs$core$seq$$($G__26612_s$jscomp$265$$)?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("-",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$lower$$,$G__26612_s$jscomp$265$$)):null};
$cuerdas$core$pad$cljs$0core$0IFn$0_invoke$0arity$02$$=function($s$jscomp$271$$){var $first$jscomp$9_map__26794__$1_type$jscomp$178$$=$APP.$cljs$core$__destructure_map$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$255$length$$,20,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$258$right$$],null)),$length$jscomp$31_padlen_padlen__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($first$jscomp$9_map__26794__$1_type$jscomp$178$$,$APP.$cljs$cst$255$length$$,0),$padding_padding__$1_second$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($first$jscomp$9_map__26794__$1_type$jscomp$178$$,$APP.$cljs$cst$256$padding$$," ");$first$jscomp$9_map__26794__$1_type$jscomp$178$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($first$jscomp$9_map__26794__$1_type$jscomp$178$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$257$left$$);if(typeof $s$jscomp$271$$==="string"){$padding_padding__$1_second$jscomp$1$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($padding_padding__$1_second$jscomp$1$$,
0,1);$length$jscomp$31_padlen_padlen__$1$$-=$s$jscomp$271$$.length;$length$jscomp$31_padlen_padlen__$1$$=$length$jscomp$31_padlen_padlen__$1$$<0?0:$length$jscomp$31_padlen_padlen__$1$$;if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$258$right$$,$first$jscomp$9_map__26794__$1_type$jscomp$178$$):$APP.$cljs$core$_EQ_$$($APP.$cljs$cst$258$right$$,$first$jscomp$9_map__26794__$1_type$jscomp$178$$)))return[$s$jscomp$271$$,
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cuerdas$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($padding_padding__$1_second$jscomp$1$$,$length$jscomp$31_padlen_padlen__$1$$))].join("");if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$259$both$$,$first$jscomp$9_map__26794__$1_type$jscomp$178$$):$APP.$cljs$core$_EQ_$$($cljs$cst$259$both$$,$first$jscomp$9_map__26794__$1_type$jscomp$178$$)))return $first$jscomp$9_map__26794__$1_type$jscomp$178$$=
$cuerdas$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($padding_padding__$1_second$jscomp$1$$,Math.ceil($length$jscomp$31_padlen_padlen__$1$$/2)),$padding_padding__$1_second$jscomp$1$$=$cuerdas$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($padding_padding__$1_second$jscomp$1$$,Math.floor($length$jscomp$31_padlen_padlen__$1$$/2)),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($first$jscomp$9_map__26794__$1_type$jscomp$178$$),$s$jscomp$271$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($padding_padding__$1_second$jscomp$1$$)].join("");
if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$257$left$$,$first$jscomp$9_map__26794__$1_type$jscomp$178$$):$APP.$cljs$core$_EQ_$$($APP.$cljs$cst$257$left$$,$first$jscomp$9_map__26794__$1_type$jscomp$178$$)))return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cuerdas$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($padding_padding__$1_second$jscomp$1$$,$length$jscomp$31_padlen_padlen__$1$$)),
$s$jscomp$271$$].join("");throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($first$jscomp$9_map__26794__$1_type$jscomp$178$$)].join(""));}return null};
$linked$map$Node$$=function($value$jscomp$219$$,$left$jscomp$11$$,$right$jscomp$11$$,$__meta$jscomp$1$$,$__extmap$jscomp$1$$,$__hash$jscomp$52$$){this.value=$value$jscomp$219$$;this.left=$left$jscomp$11$$;this.right=$right$jscomp$11$$;this.$__meta$=$__meta$jscomp$1$$;this.$__extmap$=$__extmap$jscomp$1$$;this.$__hash$=$__hash$jscomp$52$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$linked$map$LinkedMap$$=function($head$$,$delegate_map$$){this.head=$head$$;this.$delegate_map$=$delegate_map$$;this.$cljs$lang$protocol_mask$partition0$$=2314602255;this.$cljs$lang$protocol_mask$partition1$$=8192};
$linked$map$assoc_STAR_$$=function($delegate_map$jscomp$2_this$$jscomp$137$$,$k$jscomp$249$$,$v$jscomp$109$$){var $head$jscomp$2$$=$delegate_map$jscomp$2_this$$jscomp$137$$.head;$delegate_map$jscomp$2_this$$jscomp$137$$=$delegate_map$jscomp$2_this$$jscomp$137$$.$delegate_map$;var $tail$jscomp$4_temp__5823__auto__$jscomp$34$$=$cljs$core$find$$($delegate_map$jscomp$2_this$$jscomp$137$$,$k$jscomp$249$$);if($APP.$cljs$core$truth_$$($tail$jscomp$4_temp__5823__auto__$jscomp$34$$))return new $linked$map$LinkedMap$$($head$jscomp$2$$,
$APP.$cljs$core$assoc_in$$($delegate_map$jscomp$2_this$$jscomp$137$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$249$$,$APP.$cljs$cst$260$value$$],null),$v$jscomp$109$$));if($APP.$cljs$core$empty_QMARK_$$($delegate_map$jscomp$2_this$$jscomp$137$$))return new $linked$map$LinkedMap$$($k$jscomp$249$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($delegate_map$jscomp$2_this$$jscomp$137$$,$k$jscomp$249$$,new $linked$map$Node$$($v$jscomp$109$$,
$k$jscomp$249$$,$k$jscomp$249$$,null,null,null)));$tail$jscomp$4_temp__5823__auto__$jscomp$34$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($delegate_map$jscomp$2_this$$jscomp$137$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$head$jscomp$2$$,$APP.$cljs$cst$257$left$$],null));return new $linked$map$LinkedMap$$($head$jscomp$2$$,$APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($delegate_map$jscomp$2_this$$jscomp$137$$,
$k$jscomp$249$$,new $linked$map$Node$$($v$jscomp$109$$,$tail$jscomp$4_temp__5823__auto__$jscomp$34$$,$head$jscomp$2$$,null,null,null)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$head$jscomp$2$$,$APP.$cljs$cst$257$left$$],null),$k$jscomp$249$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$tail$jscomp$4_temp__5823__auto__$jscomp$34$$,$APP.$cljs$cst$258$right$$],null),$k$jscomp$249$$))};
$linked$map$dissoc_STAR_$$=function($rk_this$$jscomp$138$$,$k$jscomp$250$$){var $head$jscomp$3_head__$1$$=$rk_this$$jscomp$138$$.head,$delegate_map$jscomp$3$$=$rk_this$$jscomp$138$$.$delegate_map$,$lk_temp__5823__auto__$jscomp$35$$=$cljs$core$find$$($delegate_map$jscomp$3$$,$k$jscomp$250$$);if($APP.$cljs$core$truth_$$($lk_temp__5823__auto__$jscomp$35$$)){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($delegate_map$jscomp$3$$)))return $APP.$cljs$core$empty$$($rk_this$$jscomp$138$$);
$rk_this$$jscomp$138$$=$APP.$cljs$cst$258$right$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_val$$($lk_temp__5823__auto__$jscomp$35$$));$lk_temp__5823__auto__$jscomp$35$$=$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_val$$($lk_temp__5823__auto__$jscomp$35$$));$head$jscomp$3_head__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$250$$,$head$jscomp$3_head__$1$$)?$rk_this$$jscomp$138$$:$head$jscomp$3_head__$1$$;return new $linked$map$LinkedMap$$($head$jscomp$3_head__$1$$,
$APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($delegate_map$jscomp$3$$,$k$jscomp$250$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$rk_this$$jscomp$138$$,$APP.$cljs$cst$257$left$$],null),$lk_temp__5823__auto__$jscomp$35$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$lk_temp__5823__auto__$jscomp$35$$,$APP.$cljs$cst$258$right$$],null),
$rk_this$$jscomp$138$$))}return $rk_this$$jscomp$138$$};$linked$map$map_entry$$=function($k$jscomp$251$$,$v$jscomp$110$$){return new $APP.$cljs$core$MapEntry$$($k$jscomp$251$$,$v$jscomp$110$$,null)};
$linked$map$seq_STAR_$$=function($head$jscomp$4_this$$jscomp$139$$){var $delegate_map$jscomp$5$$=$head$jscomp$4_this$$jscomp$139$$.$delegate_map$;$head$jscomp$4_this$$jscomp$139$$=$head$jscomp$4_this$$jscomp$139$$.head;var $tail$jscomp$5$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($delegate_map$jscomp$5$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$head$jscomp$4_this$$jscomp$139$$,$APP.$cljs$cst$257$left$$],null));return $APP.$cljs$core$seq$$($delegate_map$jscomp$5$$)?
$linked$map$visit_node$$($delegate_map$jscomp$5$$,$head$jscomp$4_this$$jscomp$139$$,$tail$jscomp$5$$,$APP.$cljs$cst$258$right$$):null};
$linked$map$rseq_STAR_$$=function($head$jscomp$5_this$$jscomp$140$$){var $delegate_map$jscomp$6$$=$head$jscomp$5_this$$jscomp$140$$.$delegate_map$;$head$jscomp$5_this$$jscomp$140$$=$head$jscomp$5_this$$jscomp$140$$.head;var $tail$jscomp$6$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($delegate_map$jscomp$6$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$head$jscomp$5_this$$jscomp$140$$,$APP.$cljs$cst$257$left$$],null));return $APP.$cljs$core$seq$$($delegate_map$jscomp$6$$)?
$linked$map$visit_node$$($delegate_map$jscomp$6$$,$tail$jscomp$6$$,$head$jscomp$5_this$$jscomp$140$$,$APP.$cljs$cst$257$left$$):null};$linked$set$LinkedSet$$=function($linked_map$$){this.$linked_map$=$linked_map$$;this.$cljs$lang$protocol_mask$partition0$$=2313556239;this.$cljs$lang$protocol_mask$partition1$$=8192};$app$common$data$ordered_set_QMARK_$$=function($o$jscomp$141$$){return $o$jscomp$141$$ instanceof $linked$set$LinkedSet$$};
$APP.$app$common$data$ordered_map_QMARK_$$=function($o$jscomp$142$$){return $o$jscomp$142$$ instanceof $linked$map$LinkedMap$$};
$app$common$data$oupdate_in$$=function($var_args$jscomp$372$$){for(var $args__5755__auto__$jscomp$33$$=[],$len__5749__auto___31929$$=arguments.length,$i__5750__auto___31931$$=0;;)if($i__5750__auto___31931$$<$len__5749__auto___31929$$)$args__5755__auto__$jscomp$33$$.push(arguments[$i__5750__auto___31931$$]),$i__5750__auto___31931$$+=1;else break;return $app$common$data$oupdate_in$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],arguments[2],3<$args__5755__auto__$jscomp$33$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$33$$.slice(3),0,null):null)};
$app$common$data$oupdate_in$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($m$jscomp$90$$,$ks$jscomp$25$$,$f$jscomp$350$$,$args$jscomp$122$$){return function $app$common$data$up$$($m__$1$jscomp$5$$,$first__31184_ks__$1$jscomp$3$$,$f__$1$jscomp$1$$,$args__$1$jscomp$2$$){var $seq__31183_seq__31183__$1$$=$APP.$cljs$core$seq$$($first__31184_ks__$1$jscomp$3$$);$first__31184_ks__$1$jscomp$3$$=$APP.$cljs$core$first$$($seq__31183_seq__31183__$1$$);return($seq__31183_seq__31183__$1$$=$APP.$cljs$core$next$$($seq__31183_seq__31183__$1$$))?
$app$common$data$oassoc$$.$cljs$core$IFn$_invoke$arity$variadic$($m__$1$jscomp$5$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$first__31184_ks__$1$jscomp$3$$,$app$common$data$up$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m__$1$jscomp$5$$,$first__31184_ks__$1$jscomp$3$$),$seq__31183_seq__31183__$1$$,$f__$1$jscomp$1$$,$args__$1$jscomp$2$$)])):$app$common$data$oassoc$$.$cljs$core$IFn$_invoke$arity$variadic$($m__$1$jscomp$5$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$first__31184_ks__$1$jscomp$3$$,
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($f__$1$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m__$1$jscomp$5$$,$first__31184_ks__$1$jscomp$3$$),$args__$1$jscomp$2$$)]))}($m$jscomp$90$$,$ks$jscomp$25$$,$f$jscomp$350$$,$args$jscomp$122$$)};
$app$common$data$oreorder_before$$=function($o$jscomp$145$$,$ks$jscomp$26$$,$k$jscomp$259$$,$v$jscomp$115$$,$before_k$$){function $f$jscomp$351$$($o_SINGLEQUOTE__result$jscomp$85$$){var $found$jscomp$8$$=$APP.$cljs$core$volatile_BANG_$$(!1);$o_SINGLEQUOTE__result$jscomp$85$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$10$$,$p__31185_v_SINGLEQUOTE_$$){var $k_SINGLEQUOTE_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31185_v_SINGLEQUOTE_$$,0,null);
$p__31185_v_SINGLEQUOTE_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31185_v_SINGLEQUOTE_$$,1,null);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($before_k$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k_SINGLEQUOTE_$$,$before_k$$):$before_k$$)?($APP.$cljs$core$_vreset_BANG_$$($found$jscomp$8$$,!0),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($acc$jscomp$10$$,$k$jscomp$259$$,$v$jscomp$115$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$k_SINGLEQUOTE_$$,
$p__31185_v_SINGLEQUOTE_$$]))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$259$$,$k_SINGLEQUOTE_$$)?$acc$jscomp$10$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$10$$,$k_SINGLEQUOTE_$$,$p__31185_v_SINGLEQUOTE_$$)},$APP.$linked$map$empty_linked_map$$,$o_SINGLEQUOTE__result$jscomp$85$$);return $APP.$cljs$core$not$$($before_k$$)||$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($found$jscomp$8$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($o_SINGLEQUOTE__result$jscomp$85$$,
$k$jscomp$259$$,$v$jscomp$115$$):$o_SINGLEQUOTE__result$jscomp$85$$}return $APP.$cljs$core$seq$$($ks$jscomp$26$$)?$app$common$data$oupdate_in$$($o$jscomp$145$$,$ks$jscomp$26$$,$f$jscomp$351$$):$f$jscomp$351$$($o$jscomp$145$$)};$app$common$data$vec2$$=function($o1$$,$o2$$){return new $APP.$cljs$core$MapEntry$$($o1$$,$o2$$,null)};
$APP.$app$common$data$not_empty_QMARK_$$=function($coll$jscomp$864$$){return $APP.$cljs$core$coll_QMARK_$$($coll$jscomp$864$$)?$APP.$cljs$core$boolean$0$$($APP.$cljs$core$seq$$($coll$jscomp$864$$)):$coll$jscomp$864$$!=null};
$app$common$data$transient_concat$$=function($G__31974_c1$jscomp$10_result$jscomp$86$$,$G__31975_colls$jscomp$8_colls__$1$jscomp$1$$){for($G__31974_c1$jscomp$10_result$jscomp$86$$=$APP.$cljs$core$_as_transient$$($G__31974_c1$jscomp$10_result$jscomp$86$$);;)if($APP.$cljs$core$truth_$$($G__31975_colls$jscomp$8_colls__$1$jscomp$1$$))$G__31974_c1$jscomp$10_result$jscomp$86$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj_BANG_$$,$G__31974_c1$jscomp$10_result$jscomp$86$$,
$APP.$cljs$core$first$$($G__31975_colls$jscomp$8_colls__$1$jscomp$1$$)),$G__31975_colls$jscomp$8_colls__$1$jscomp$1$$=$APP.$cljs$core$next$$($G__31975_colls$jscomp$8_colls__$1$jscomp$1$$);else return $APP.$cljs$core$_persistent_BANG_$$($G__31974_c1$jscomp$10_result$jscomp$86$$)};
$APP.$app$common$data$concat_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($c1$jscomp$12$$,$more$jscomp$37$$){return $APP.$cljs$core$set_QMARK_$$($c1$jscomp$12$$)?$app$common$data$transient_concat$$($c1$jscomp$12$$,$more$jscomp$37$$):$app$common$data$transient_concat$$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$cons$$($c1$jscomp$12$$,$more$jscomp$37$$))};$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$=function($items$jscomp$9$$){return $APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($items$jscomp$9$$)};
$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$=function($items$jscomp$10_items__$1$$){var $idx$jscomp$49$$=0;$items$jscomp$10_items__$1$$=$APP.$cljs$core$seq$$($items$jscomp$10_items__$1$$);for(var $G__31999_res$jscomp$16$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;)if($items$jscomp$10_items__$1$$){var $G__31997$$=$idx$jscomp$49$$+1,$G__31998$$=$APP.$cljs$core$next$$($items$jscomp$10_items__$1$$);$G__31999_res$jscomp$16$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__31999_res$jscomp$16$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$idx$jscomp$49$$,$APP.$cljs$core$first$$($items$jscomp$10_items__$1$$)],null));$idx$jscomp$49$$=$G__31997$$;$items$jscomp$10_items__$1$$=$G__31998$$}else return $APP.$cljs$core$_persistent_BANG_$$($G__31999_res$jscomp$16$$)};
$APP.$app$common$data$group_by$cljs$0core$0IFn$0_invoke$0arity$03$$=function($kf$jscomp$4$$,$vf$jscomp$3$$,$coll$jscomp$866$$){return $app$common$data$group_by$cljs$0core$0IFn$0_invoke$0arity$04$$($kf$jscomp$4$$,$vf$jscomp$3$$,$coll$jscomp$866$$)};
$app$common$data$group_by$cljs$0core$0IFn$0_invoke$0arity$04$$=function($kf$jscomp$5$$,$vf$jscomp$4$$,$coll$jscomp$867$$){var $conj$$=$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$87$$,$item$jscomp$25$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($result$jscomp$87$$,$kf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?
$kf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$25$$):$kf$jscomp$5$$($item$jscomp$25$$),$conj$$,$vf$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$vf$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$25$$):$vf$jscomp$4$$($item$jscomp$25$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$coll$jscomp$867$$)};
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$=function($pred$jscomp$19$$,$coll$jscomp$868$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($pred$jscomp$19$$,$coll$jscomp$868$$)};
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$=function($pred$jscomp$20$$,$coll$jscomp$869$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($_$jscomp$201$$,$x$jscomp$684$$){return $APP.$cljs$core$truth_$$($pred$jscomp$20$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$20$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$684$$):$pred$jscomp$20$$($x$jscomp$684$$))?$APP.$cljs$core$reduced$$($x$jscomp$684$$):null},null,$coll$jscomp$869$$)};
$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$=function($kf$jscomp$6$$,$coll$jscomp$870$$){return $APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$03$$($kf$jscomp$6$$,$APP.$cljs$core$identity$$,$coll$jscomp$870$$)};
$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$03$$=function($kf$jscomp$7$$,$vf$jscomp$5$$,$coll$jscomp$871$$){return $APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__31273_SHARP_$$,$p2__31275_SHARP_$$){return $APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($p1__31273_SHARP_$$,$kf$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$kf$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($p2__31275_SHARP_$$):$kf$jscomp$7$$($p2__31275_SHARP_$$),
$vf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$vf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($p2__31275_SHARP_$$):$vf$jscomp$5$$($p2__31275_SHARP_$$))},$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$coll$jscomp$871$$))};
$APP.$app$common$data$index_of_pred$$=function($G__32029_coll$jscomp$872_s$jscomp$286$$,$pred$jscomp$21$$){$G__32029_coll$jscomp$872_s$jscomp$286$$=$APP.$cljs$core$seq$$($G__32029_coll$jscomp$872_s$jscomp$286$$);for(var $G__32030_index$jscomp$122$$=0;;)if($G__32029_coll$jscomp$872_s$jscomp$286$$){var $G__31286$jscomp$inline_3125_JSCompiler_inline_result$jscomp$297$$=$APP.$cljs$core$first$$($G__32029_coll$jscomp$872_s$jscomp$286$$);$G__31286$jscomp$inline_3125_JSCompiler_inline_result$jscomp$297$$=
$pred$jscomp$21$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$21$$.$cljs$core$IFn$_invoke$arity$1$($G__31286$jscomp$inline_3125_JSCompiler_inline_result$jscomp$297$$):$pred$jscomp$21$$($G__31286$jscomp$inline_3125_JSCompiler_inline_result$jscomp$297$$);if($APP.$cljs$core$truth_$$($G__31286$jscomp$inline_3125_JSCompiler_inline_result$jscomp$297$$))return $G__32030_index$jscomp$122$$;$G__32029_coll$jscomp$872_s$jscomp$286$$=$APP.$cljs$core$next$$($G__32029_coll$jscomp$872_s$jscomp$286$$);$G__32030_index$jscomp$122$$+=
1}else return null};$APP.$app$common$data$index_of$$=function($coll$jscomp$873$$,$v$jscomp$118$$){return $APP.$app$common$data$index_of_pred$$($coll$jscomp$873$$,function($p1__31288_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__31288_SHARP_$$,$v$jscomp$118$$)})};
$APP.$app$common$data$vec_without_nils$$=function($coll$jscomp$875$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nil_QMARK_$$),$coll$jscomp$875$$)};
$APP.$app$common$data$without_qualified$cljs$0core$0IFn$0_invoke$0arity$01$$=function($data$jscomp$93$$){return $APP.$cljs$core$reduce_kv$$(function($data__$1$jscomp$1$$,$k$jscomp$264$$){return $cljs$core$qualified_keyword_QMARK_$$($k$jscomp$264$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($data__$1$jscomp$1$$,$k$jscomp$264$$):$data__$1$jscomp$1$$},$data$jscomp$93$$,$data$jscomp$93$$)};
$APP.$app$common$data$without_keys$$=function($data$jscomp$94$$,$keys$jscomp$22$$){return $data$jscomp$94$$!=null&&($data$jscomp$94$$.$cljs$lang$protocol_mask$partition1$$&4||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$data$jscomp$94$$.$cljs$core$IEditableCollection$$)?$APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($cljs$core$dissoc_BANG_$$,$APP.$cljs$core$_as_transient$$($data$jscomp$94$$),$keys$jscomp$22$$)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$dissoc$$,
$data$jscomp$94$$,$keys$jscomp$22$$)};
$APP.$app$common$data$remove_at_index$$=function($v$jscomp$120$$,$index$jscomp$123$$){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$120$$,0,$index$jscomp$123$$),$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$120$$,$index$jscomp$123$$+1)]))};
$app$common$data$without_obj$$=function($coll$jscomp$876$$,$o$jscomp$150$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__31333_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__31333_SHARP_$$,$o$jscomp$150$$)}),$coll$jscomp$876$$)};
$APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$=function($mfn$jscomp$1$$,$coll$jscomp$877$$){return $APP.$cljs$core$reduce_kv$$(function($coll__$1$jscomp$485$$,$k$jscomp$265$$,$v$jscomp$121$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($coll__$1$jscomp$485$$,$k$jscomp$265$$,$mfn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$mfn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$265$$,$v$jscomp$121$$):$mfn$jscomp$1$$($k$jscomp$265$$,$v$jscomp$121$$))},$coll$jscomp$877$$,
$coll$jscomp$877$$)};$APP.$app$common$data$removev$$=function($pred$jscomp$22$$,$coll$jscomp$878$$){return $APP.$cljs$core$filterv$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$not$$,$pred$jscomp$22$$),$coll$jscomp$878$$)};
$APP.$app$common$data$removem$$=function($pred$jscomp$24$$,$coll$jscomp$880$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($pred$jscomp$24$$),$coll$jscomp$880$$)};
$APP.$app$common$data$map_perm$cljs$0core$0IFn$0_invoke$0arity$03$$=function($mfn$jscomp$3$$,$pred_QMARK_$$,$coll$jscomp$882$$){return $app$common$data$map_perm$cljs$0core$0IFn$0_invoke$0arity$04$$($mfn$jscomp$3$$,$pred_QMARK_$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$coll$jscomp$882$$)};
$app$common$data$map_perm$cljs$0core$0IFn$0_invoke$0arity$04$$=function($mfn$jscomp$4$$,$pred_QMARK_$jscomp$1$$,$G__32071_current$jscomp$5_target$jscomp$105$$,$G__32072_coll$jscomp$883_coll__$1$jscomp$486$$){var $G__32067$jscomp$inline_11375_G__32070_coll__$2$jscomp$inline_11371_result$jscomp$88$$=$APP.$cljs$core$_as_transient$$($G__32071_current$jscomp$5_target$jscomp$105$$);$G__32071_current$jscomp$5_target$jscomp$105$$=$APP.$cljs$core$first$$($G__32072_coll$jscomp$883_coll__$1$jscomp$486$$);for($G__32072_coll$jscomp$883_coll__$1$jscomp$486$$=
$APP.$cljs$core$rest$$($G__32072_coll$jscomp$883_coll__$1$jscomp$486$$);;){if($APP.$cljs$core$not$$($G__32071_current$jscomp$5_target$jscomp$105$$))return $APP.$cljs$core$_persistent_BANG_$$($G__32067$jscomp$inline_11375_G__32070_coll__$2$jscomp$inline_11371_result$jscomp$88$$);a:{var $G__31383$jscomp$inline_11373_G__32065$jscomp$inline_11372_result__$1$jscomp$inline_11369$$=$G__32067$jscomp$inline_11375_G__32070_coll__$2$jscomp$inline_11371_result$jscomp$88$$,$G__32066$jscomp$inline_11374_other$jscomp$inline_11370$$=
$APP.$cljs$core$first$$($G__32072_coll$jscomp$883_coll__$1$jscomp$486$$);for($G__32067$jscomp$inline_11375_G__32070_coll__$2$jscomp$inline_11371_result$jscomp$88$$=$APP.$cljs$core$rest$$($G__32072_coll$jscomp$883_coll__$1$jscomp$486$$);;){if($APP.$cljs$core$not$$($G__32066$jscomp$inline_11374_other$jscomp$inline_11370$$)){$G__32067$jscomp$inline_11375_G__32070_coll__$2$jscomp$inline_11371_result$jscomp$88$$=$G__31383$jscomp$inline_11373_G__32065$jscomp$inline_11372_result__$1$jscomp$inline_11369$$;
break a}$G__31383$jscomp$inline_11373_G__32065$jscomp$inline_11372_result__$1$jscomp$inline_11369$$=$APP.$cljs$core$truth_$$($pred_QMARK_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$pred_QMARK_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($G__32071_current$jscomp$5_target$jscomp$105$$,$G__32066$jscomp$inline_11374_other$jscomp$inline_11370$$):$pred_QMARK_$jscomp$1$$($G__32071_current$jscomp$5_target$jscomp$105$$,$G__32066$jscomp$inline_11374_other$jscomp$inline_11370$$))?$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__31383$jscomp$inline_11373_G__32065$jscomp$inline_11372_result__$1$jscomp$inline_11369$$,
$mfn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$mfn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($G__32071_current$jscomp$5_target$jscomp$105$$,$G__32066$jscomp$inline_11374_other$jscomp$inline_11370$$):$mfn$jscomp$4$$($G__32071_current$jscomp$5_target$jscomp$105$$,$G__32066$jscomp$inline_11374_other$jscomp$inline_11370$$)):$G__31383$jscomp$inline_11373_G__32065$jscomp$inline_11372_result__$1$jscomp$inline_11369$$;$G__32066$jscomp$inline_11374_other$jscomp$inline_11370$$=$APP.$cljs$core$first$$($G__32067$jscomp$inline_11375_G__32070_coll__$2$jscomp$inline_11371_result$jscomp$88$$);
$G__32067$jscomp$inline_11375_G__32070_coll__$2$jscomp$inline_11371_result$jscomp$88$$=$APP.$cljs$core$rest$$($G__32067$jscomp$inline_11375_G__32070_coll__$2$jscomp$inline_11371_result$jscomp$88$$)}$G__32067$jscomp$inline_11375_G__32070_coll__$2$jscomp$inline_11371_result$jscomp$88$$=void 0}$G__32071_current$jscomp$5_target$jscomp$105$$=$APP.$cljs$core$first$$($G__32072_coll$jscomp$883_coll__$1$jscomp$486$$);$G__32072_coll$jscomp$883_coll__$1$jscomp$486$$=$APP.$cljs$core$rest$$($G__32072_coll$jscomp$883_coll__$1$jscomp$486$$)}};
$APP.$app$common$data$getf$$=function($coll$jscomp$884$$){return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$get$$,$coll$jscomp$884$$)};
$APP.$app$common$data$update_vals$$=function($m$jscomp$93$$,$f$jscomp$354$$){return $APP.$cljs$core$reduce_kv$$(function($acc$jscomp$12$$,$k$jscomp$266$$,$v$jscomp$122$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$12$$,$k$jscomp$266$$,$f$jscomp$354$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$354$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$122$$):$f$jscomp$354$$($v$jscomp$122$$))},$m$jscomp$93$$,$m$jscomp$93$$)};
$APP.$app$common$data$update_in_when$$=function($var_args$jscomp$389$$){for(var $args__5755__auto__$jscomp$34$$=[],$len__5749__auto___32086$$=arguments.length,$i__5750__auto___32087$$=0;;)if($i__5750__auto___32087$$<$len__5749__auto___32086$$)$args__5755__auto__$jscomp$34$$.push(arguments[$i__5750__auto___32087$$]),$i__5750__auto___32087$$+=1;else break;return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],arguments[2],3<$args__5755__auto__$jscomp$34$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$34$$.slice(3),0,null):null)};
$APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($m$jscomp$94$$,$key_seq$$,$f$jscomp$355$$,$args$jscomp$123$$){var $found$jscomp$9$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$94$$,$key_seq$$,$app$common$data$sentinel$$);return $app$common$data$sentinel$$!==$found$jscomp$9$$?$APP.$cljs$core$assoc_in$$($m$jscomp$94$$,$key_seq$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($f$jscomp$355$$,$found$jscomp$9$$,$args$jscomp$123$$)):
$m$jscomp$94$$};
$APP.$app$common$data$update_when$$=function($var_args$jscomp$390$$){for(var $args__5755__auto__$jscomp$35$$=[],$len__5749__auto___32091$$=arguments.length,$i__5750__auto___32092$$=0;;)if($i__5750__auto___32092$$<$len__5749__auto___32091$$)$args__5755__auto__$jscomp$35$$.push(arguments[$i__5750__auto___32092$$]),$i__5750__auto___32092$$+=1;else break;return $APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],arguments[2],3<$args__5755__auto__$jscomp$35$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$35$$.slice(3),
0,null):null)};
$APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($m$jscomp$95$$,$key$jscomp$177$$,$f$jscomp$356$$,$args$jscomp$124$$){var $found$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$95$$,$key$jscomp$177$$,$app$common$data$sentinel$$);return $app$common$data$sentinel$$!==$found$jscomp$10$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$95$$,$key$jscomp$177$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($f$jscomp$356$$,$found$jscomp$10$$,
$args$jscomp$124$$)):$m$jscomp$95$$};$app$common$data$assoc_in_when$$=function($m$jscomp$96$$,$key_seq$jscomp$1$$,$v$jscomp$123$$){var $found$jscomp$11$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$96$$,$key_seq$jscomp$1$$,$app$common$data$sentinel$$);return $app$common$data$sentinel$$!==$found$jscomp$11$$?$APP.$cljs$core$assoc_in$$($m$jscomp$96$$,$key_seq$jscomp$1$$,$v$jscomp$123$$):$m$jscomp$96$$};
$app$common$data$assoc_when$$=function($m$jscomp$97$$,$key$jscomp$178$$){var $found$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$97$$,$key$jscomp$178$$,$app$common$data$sentinel$$);return $app$common$data$sentinel$$!==$found$jscomp$12$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$97$$,$key$jscomp$178$$,$APP.$cljs$cst$1902$scale$$):$m$jscomp$97$$};
$APP.$app$common$data$txt_merge$$=function($obj$jscomp$106$$,$attrs$$){return $APP.$cljs$core$reduce_kv$$(function($obj__$1$jscomp$1$$,$k$jscomp$267$$,$v$jscomp$125$$){return $v$jscomp$125$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($obj__$1$jscomp$1$$,$k$jscomp$267$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($obj__$1$jscomp$1$$,$k$jscomp$267$$,$v$jscomp$125$$)},$obj$jscomp$106$$,$attrs$$)};
$APP.$app$common$data$with_prev$$=function($coll$jscomp$887$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vector$$,$coll$jscomp$887$$,$APP.$cljs$core$cons$$(null,$coll$jscomp$887$$))};
$app$common$data$with_prev_next$$=function($coll$jscomp$888$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$vector$$,$coll$jscomp$888$$,$APP.$cljs$core$cons$$(null,$coll$jscomp$888$$),$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$rest$$($coll$jscomp$888$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null],null)))};
$app$common$data$add_at_index$$=function($before$jscomp$2_coll$jscomp$889$$,$after$jscomp$1_index$jscomp$124_vec__31452$$,$element$jscomp$13$$){$after$jscomp$1_index$jscomp$124_vec__31452$$=$cljs$core$split_at$$($after$jscomp$1_index$jscomp$124_vec__31452$$,$before$jscomp$2_coll$jscomp$889$$);$before$jscomp$2_coll$jscomp$889$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($after$jscomp$1_index$jscomp$124_vec__31452$$,0,null);$after$jscomp$1_index$jscomp$124_vec__31452$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($after$jscomp$1_index$jscomp$124_vec__31452$$,
1,null);return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$before$jscomp$2_coll$jscomp$889$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$element$jscomp$13$$],null),$after$jscomp$1_index$jscomp$124_vec__31452$$]))};
$APP.$app$common$data$insert_at_index$$=function($before$jscomp$3_elems$jscomp$1$$,$after$jscomp$2_index$jscomp$125_vec__31455$$,$new_elems$$){$after$jscomp$2_index$jscomp$125_vec__31455$$=$cljs$core$split_at$$($after$jscomp$2_index$jscomp$125_vec__31455$$,$before$jscomp$3_elems$jscomp$1$$);$before$jscomp$3_elems$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($after$jscomp$2_index$jscomp$125_vec__31455$$,0,null);$after$jscomp$2_index$jscomp$125_vec__31455$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($after$jscomp$2_index$jscomp$125_vec__31455$$,
1,null);var $p_QMARK_$$=$APP.$cljs$core$set$$($new_elems$$);return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($p_QMARK_$$,$before$jscomp$3_elems$jscomp$1$$),$new_elems$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($p_QMARK_$$,$after$jscomp$2_index$jscomp$125_vec__31455$$)]))};
$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$=function($v$jscomp$130$$){return $APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$130$$,null)};
$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$02$$=function($v$jscomp$131_v__$1$jscomp$8$$,$default$$jscomp$1$$){$v$jscomp$131_v__$1$jscomp$8$$=parseInt($v$jscomp$131_v__$1$jscomp$8$$,10);var $or__5025__auto__$jscomp$inline_3131$$=$v$jscomp$131_v__$1$jscomp$8$$==null;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_3131$$?$or__5025__auto__$jscomp$inline_3131$$:isNaN($v$jscomp$131_v__$1$jscomp$8$$))?$default$$jscomp$1$$:$v$jscomp$131_v__$1$jscomp$8$$};
$app$common$data$parse_percent$cljs$0core$0IFn$0_invoke$0arity$02$$=function($v$jscomp$136_v$jscomp$inline_11377_v__$1$jscomp$10$$){if($APP.$cuerdas$core$ends_with_QMARK_$$($v$jscomp$136_v$jscomp$inline_11377_v__$1$jscomp$10$$,"%")){$v$jscomp$136_v$jscomp$inline_11377_v__$1$jscomp$10$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$136_v$jscomp$inline_11377_v__$1$jscomp$10$$,"%");$v$jscomp$136_v$jscomp$inline_11377_v__$1$jscomp$10$$=parseFloat($v$jscomp$136_v$jscomp$inline_11377_v__$1$jscomp$10$$);
var $or__5025__auto__$jscomp$inline_3135$$=$v$jscomp$136_v$jscomp$inline_11377_v__$1$jscomp$10$$==null;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_3135$$?$or__5025__auto__$jscomp$inline_3135$$:isNaN($v$jscomp$136_v$jscomp$inline_11377_v__$1$jscomp$10$$))?null:$v$jscomp$136_v$jscomp$inline_11377_v__$1$jscomp$10$$/100}return $APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$136_v$jscomp$inline_11377_v__$1$jscomp$10$$,null)};
$APP.$app$common$data$read_string$$=function($v$jscomp$139$$){return $cljs$reader$read_string$cljs$0core$0IFn$0_invoke$0arity$01$$($v$jscomp$139$$)};$APP.$app$common$data$coalesce$$=function($val$jscomp$116$$){return $APP.$cljs$core$truth_$$($val$jscomp$116$$)?$val$jscomp$116$$:1};
$app$common$data$nilf$$=function($f$jscomp$360$$){return function(){function $G__32147$$($var_args$jscomp$398$$){var $G__32149__i_args$jscomp$127$$=null;if(arguments.length>0){$G__32149__i_args$jscomp$127$$=0;for(var $G__32149__a$$=Array(arguments.length-0);$G__32149__i_args$jscomp$127$$<$G__32149__a$$.length;)$G__32149__a$$[$G__32149__i_args$jscomp$127$$]=arguments[$G__32149__i_args$jscomp$127$$+0],++$G__32149__i_args$jscomp$127$$;$G__32149__i_args$jscomp$127$$=new $APP.$cljs$core$IndexedSeq$$($G__32149__a$$,
0,null)}return $G__32147__delegate$$.call(this,$G__32149__i_args$jscomp$127$$)}function $G__32147__delegate$$($args$jscomp$126$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($APP.$cljs$core$nil_QMARK_$$,$args$jscomp$126$$))?null:$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$360$$,$args$jscomp$126$$)}$G__32147$$.$cljs$lang$maxFixedArity$=0;$G__32147$$.$cljs$lang$applyTo$=function($arglist__32151_args$jscomp$128$$){$arglist__32151_args$jscomp$128$$=$APP.$cljs$core$seq$$($arglist__32151_args$jscomp$128$$);
return $G__32147__delegate$$($arglist__32151_args$jscomp$128$$)};$G__32147$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__32147__delegate$$;return $G__32147$$}()};$APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($a$jscomp$212$$){return $APP.$app$common$math$finite_QMARK_$$($a$jscomp$212$$)};$APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($a$jscomp$213$$,$b$jscomp$172$$){return $APP.$app$common$math$finite_QMARK_$$($a$jscomp$213$$)&&$APP.$app$common$math$finite_QMARK_$$($b$jscomp$172$$)};
$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$04$$=function($a$jscomp$215$$,$b$jscomp$174$$,$c$jscomp$147$$,$d$jscomp$110$$){return $APP.$app$common$math$finite_QMARK_$$($a$jscomp$215$$)&&$APP.$app$common$math$finite_QMARK_$$($b$jscomp$174$$)&&$APP.$app$common$math$finite_QMARK_$$($c$jscomp$147$$)&&$APP.$app$common$math$finite_QMARK_$$($d$jscomp$110$$)};
$app$common$data$safe_PLUS_$$=function($a$jscomp$217$$,$b$jscomp$176$$){return $APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($a$jscomp$217$$))?$a$jscomp$217$$+$b$jscomp$176$$:$a$jscomp$217$$};
$app$common$data$any_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($element$jscomp$16$$){return $APP.$cljs$core$some$$(function($p1__31676_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($element$jscomp$16$$,$p1__31676_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3676$strokeColor$$,$cljs$cst$3674$strokeOpacity$$,$cljs$cst$3675$strokeWidth$$,$cljs$cst$3088$strokeLinecap$$,$cljs$cst$3677$strokeCapStart$$,$cljs$cst$3678$strokeCapEnd$$]))};
$APP.$app$common$data$name$$=function($maybe_keyword$$){return $maybe_keyword$$==null?null:$maybe_keyword$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$($maybe_keyword$$):typeof $maybe_keyword$$==="string"?$maybe_keyword$$:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($maybe_keyword$$)};
$APP.$app$common$data$prefix_keyword$$=function($prefix$jscomp$11_prefix__$1$$,$kw$jscomp$2_kw__$1$$){$prefix$jscomp$11_prefix__$1$$=$prefix$jscomp$11_prefix__$1$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$app$common$data$name$$($prefix$jscomp$11_prefix__$1$$):$prefix$jscomp$11_prefix__$1$$;$kw$jscomp$2_kw__$1$$=$kw$jscomp$2_kw__$1$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$app$common$data$name$$($kw$jscomp$2_kw__$1$$):$kw$jscomp$2_kw__$1$$;return $APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($prefix$jscomp$11_prefix__$1$$),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($kw$jscomp$2_kw__$1$$)].join(""))};
$APP.$app$common$data$lazy_map$$=function($keys$jscomp$24$$,$generator_fn$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($key$jscomp$181$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$key$jscomp$181$$,new $APP.$cljs$core$Delay$$(function(){return $generator_fn$$.$cljs$core$IFn$_invoke$arity$1$?$generator_fn$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$181$$):
$generator_fn$$($key$jscomp$181$$)})],null)}),$keys$jscomp$24$$)};$app$common$data$unstable_sort$cljs$0core$0IFn$0_invoke$0arity$02$$=function($comp_fn$$,$items$jscomp$12_items__$1$jscomp$1$$){$items$jscomp$12_items__$1$jscomp$1$$=$APP.$cljs$core$to_array$$($items$jscomp$12_items__$1$jscomp$1$$);$APP.$module$contents$goog$array_sort$$($items$jscomp$12_items__$1$jscomp$1$$,$comp_fn$$);return $APP.$cljs$core$seq$$($items$jscomp$12_items__$1$jscomp$1$$)};
$app$common$data$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$=function($value$jscomp$228_value__$1$$){var $map__31787__$1_precision$jscomp$2$$=$APP.$cljs$core$__destructure_map$$(2);$map__31787__$1_precision$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__31787__$1_precision$jscomp$2$$,$APP.$cljs$cst$267$precision$$,2);$value$jscomp$228_value__$1$$=typeof $value$jscomp$228_value__$1$$==="string"?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$228_value__$1$$):
$value$jscomp$228_value__$1$$;if($APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($value$jscomp$228_value__$1$$)))if(typeof $value$jscomp$228_value__$1$$==="number")try{var $num_str__$1$jscomp$inline_3139$$=$APP.$cuerdas$core$replace$$($value$jscomp$228_value__$1$$.toFixed($map__31787__$1_precision$jscomp$2$$),/\.0+$/,""),$temp__5823__auto__$jscomp$inline_3140$$=$APP.$cljs$core$re_find$$(/(\.\d*[^0])0+$/,$num_str__$1$jscomp$inline_3139$$);var $JSCompiler_temp$jscomp$306$$=$APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_3140$$)?
$APP.$cuerdas$core$replace$$($num_str__$1$jscomp$inline_3139$$,$APP.$cljs$core$first$$($temp__5823__auto__$jscomp$inline_3140$$),$APP.$cljs$core$second$$($temp__5823__auto__$jscomp$inline_3140$$)):$num_str__$1$jscomp$inline_3139$$}catch($e31778$jscomp$inline_3141$$){$JSCompiler_temp$jscomp$306$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$228_value__$1$$)}else $JSCompiler_temp$jscomp$306$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$228_value__$1$$);
else $JSCompiler_temp$jscomp$306$$=null;return $JSCompiler_temp$jscomp$306$$};
$app$common$data$get_initials$$=function($name$jscomp$123$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$upper$$,$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(2,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__31815_SHARP_$$){return $APP.$cljs$core$first$$($APP.$cljs$core$re_seq$$(/[a-zA-Z]/,$p1__31815_SHARP_$$))},$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($name$jscomp$123$$)?
$name$jscomp$123$$:""),/\s+/)))))};
$app$common$data$close_BANG_$$=function($JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$){var $m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$meta$$($JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$),$APP.$cljs$core$with_meta$$($cljs$cst$268$app_DOT_common_DOT_data_SLASH_close_BANG_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$269$cljs_DOT_analyzer_SLASH_no_resolve$$,
!0],null)));if($m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$)$JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$=$m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$):
$m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$($JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$);else if($JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$!=null&&$JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$.$app$common$data$ICloseable$close_BANG_$arity$1$!=null)$JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$=$JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$.$app$common$data$ICloseable$close_BANG_$arity$1$($JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$);
else if($m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$=$app$common$data$close_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$==null?null:$JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$)],$m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$!=null)$JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$=$m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$.$cljs$core$IFn$_invoke$arity$1$?
$m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$):$m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$($JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$);else if($m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$=$app$common$data$close_BANG_$$._,
$m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$!=null)$JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$=$m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$):
$m__5372__auto__$jscomp$inline_3145_m__5374__auto__$jscomp$inline_3144_temp__5823__auto__$jscomp$42$$($JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$);else throw $APP.$cljs$core$missing_protocol$$("ICloseable.close!",$JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$);return $JSCompiler_temp$jscomp$307_JSCompiler_temp$jscomp$308__$jscomp$207$$};
$app$common$data$take_until$cljs$0core$0IFn$0_invoke$0arity$01$$=function($pred$jscomp$25$$){return $cljs$core$halt_when$cljs$0core$0IFn$0_invoke$0arity$02$$($pred$jscomp$25$$,function($r$jscomp$38$$,$h$jscomp$93$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($r$jscomp$38$$,$h$jscomp$93$$)})};
$app$common$data$take_until$cljs$0core$0IFn$0_invoke$0arity$02$$=function($pred$jscomp$26$$,$coll$jscomp$897$$){return $cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$04$$($app$common$data$take_until$cljs$0core$0IFn$0_invoke$0arity$01$$($pred$jscomp$26$$),$APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$coll$jscomp$897$$)};
$app$common$data$safe_subvec$cljs$0core$0IFn$0_invoke$0arity$03$$=function($v$jscomp$149$$,$start$jscomp$155$$,$end$jscomp$42$$){if($v$jscomp$149$$!=null){var $size$jscomp$36$$=$APP.$cljs$core$count$$($v$jscomp$149$$);return $start$jscomp$155$$>=0&&$start$jscomp$155$$<$size$jscomp$36$$&&$end$jscomp$42$$>=0&&$start$jscomp$155$$<=$end$jscomp$42$$&&$end$jscomp$42$$<=$size$jscomp$36$$?$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$149$$,$start$jscomp$155$$,$end$jscomp$42$$):null}return null};
$APP.$app$common$data$append_class$$=function($class$$$,$current_class$$){return $APP.$cljs$core$seq$$($class$$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($class$$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($current_class$$)].join(""):$current_class$$};
$me$flowthing$pp$extract_map_ns$$=function($G__24709_m$jscomp$102_temp__5827__auto__$jscomp$1_v$jscomp$150_vec__24559$$){if($APP.$cljs$core$seq$$($G__24709_m$jscomp$102_temp__5827__auto__$jscomp$1_v$jscomp$150_vec__24559$$))for(var $G__24707_m__$1$jscomp$6$$=$G__24709_m$jscomp$102_temp__5827__auto__$jscomp$1_v$jscomp$150_vec__24559$$,$G__24708_ns$jscomp$23$$=null,$JSCompiler_temp_const$jscomp$309_nm$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;;){$G__24709_m$jscomp$102_temp__5827__auto__$jscomp$1_v$jscomp$150_vec__24559$$=
$APP.$cljs$core$first$$($G__24707_m__$1$jscomp$6$$);if($G__24709_m$jscomp$102_temp__5827__auto__$jscomp$1_v$jscomp$150_vec__24559$$==null)return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__24708_ns$jscomp$23$$,$JSCompiler_temp_const$jscomp$309_nm$$],null);var $JSCompiler_inline_result$jscomp$312_k$jscomp$271_x$jscomp$inline_3147$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__24709_m$jscomp$102_temp__5827__auto__$jscomp$1_v$jscomp$150_vec__24559$$,
0,null);$G__24709_m$jscomp$102_temp__5827__auto__$jscomp$1_v$jscomp$150_vec__24559$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__24709_m$jscomp$102_temp__5827__auto__$jscomp$1_v$jscomp$150_vec__24559$$,1,null);if($cljs$core$qualified_ident_QMARK_$$($JSCompiler_inline_result$jscomp$312_k$jscomp$271_x$jscomp$inline_3147$$)){var $JSCompiler_temp_const$jscomp$311_k_ns$$=$APP.$cljs$core$namespace$$($JSCompiler_inline_result$jscomp$312_k$jscomp$271_x$jscomp$inline_3147$$);if($G__24708_ns$jscomp$23$$==
null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__24708_ns$jscomp$23$$,$JSCompiler_temp_const$jscomp$311_k_ns$$)){$G__24707_m__$1$jscomp$6$$=$APP.$cljs$core$rest$$($G__24707_m__$1$jscomp$6$$);$G__24708_ns$jscomp$23$$=$JSCompiler_temp_const$jscomp$311_k_ns$$;$JSCompiler_temp_const$jscomp$311_k_ns$$=$APP.$cljs$core$assoc$$;var $JSCompiler_temp_const$jscomp$310$$=$JSCompiler_temp_const$jscomp$311_k_ns$$.$cljs$core$IFn$_invoke$arity$3$;$JSCompiler_inline_result$jscomp$312_k$jscomp$271_x$jscomp$inline_3147$$=
$JSCompiler_inline_result$jscomp$312_k$jscomp$271_x$jscomp$inline_3147$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$(null,$APP.$cljs$core$name$$($JSCompiler_inline_result$jscomp$312_k$jscomp$271_x$jscomp$inline_3147$$)):$JSCompiler_inline_result$jscomp$312_k$jscomp$271_x$jscomp$inline_3147$$ instanceof $APP.$cljs$core$Symbol$$?$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$(null,$APP.$cljs$core$name$$($JSCompiler_inline_result$jscomp$312_k$jscomp$271_x$jscomp$inline_3147$$)):
null;$JSCompiler_temp_const$jscomp$309_nm$$=$G__24709_m$jscomp$102_temp__5827__auto__$jscomp$1_v$jscomp$150_vec__24559$$=$JSCompiler_temp_const$jscomp$310$$.call($JSCompiler_temp_const$jscomp$311_k_ns$$,$JSCompiler_temp_const$jscomp$309_nm$$,$JSCompiler_inline_result$jscomp$312_k$jscomp$271_x$jscomp$inline_3147$$,$G__24709_m$jscomp$102_temp__5827__auto__$jscomp$1_v$jscomp$150_vec__24559$$);continue}else return null}else return null;break}else return null};
$me$flowthing$pp$close_delim$$=function($coll$jscomp$899$$){return $APP.$cljs$core$map_QMARK_$$($coll$jscomp$899$$)?"}":$APP.$cljs$core$vector_QMARK_$$($coll$jscomp$899$$)?"]":$APP.$cljs$core$set_QMARK_$$($coll$jscomp$899$$)?"}":$APP.$cljs$core$array_QMARK_$$($coll$jscomp$899$$)?"]":")"};
$me$flowthing$pp$write$$=function($JSCompiler_temp$jscomp$313_this$$jscomp$144$$,$s$jscomp$293$$){if($JSCompiler_temp$jscomp$313_this$$jscomp$144$$!=null&&$JSCompiler_temp$jscomp$313_this$$jscomp$144$$.$me$flowthing$pp$CountKeepingWriter$write$arity$2$!=null)$JSCompiler_temp$jscomp$313_this$$jscomp$144$$=$JSCompiler_temp$jscomp$313_this$$jscomp$144$$.$me$flowthing$pp$CountKeepingWriter$write$arity$2$($JSCompiler_temp$jscomp$313_this$$jscomp$144$$,$s$jscomp$293$$);else{var $m__5372__auto__$jscomp$inline_3152_m__5374__auto__$jscomp$inline_3151$$=
$me$flowthing$pp$write$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$313_this$$jscomp$144$$==null?null:$JSCompiler_temp$jscomp$313_this$$jscomp$144$$)];if($m__5372__auto__$jscomp$inline_3152_m__5374__auto__$jscomp$inline_3151$$!=null)$JSCompiler_temp$jscomp$313_this$$jscomp$144$$=$m__5372__auto__$jscomp$inline_3152_m__5374__auto__$jscomp$inline_3151$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3152_m__5374__auto__$jscomp$inline_3151$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$313_this$$jscomp$144$$,
$s$jscomp$293$$):$m__5372__auto__$jscomp$inline_3152_m__5374__auto__$jscomp$inline_3151$$($JSCompiler_temp$jscomp$313_this$$jscomp$144$$,$s$jscomp$293$$);else if($m__5372__auto__$jscomp$inline_3152_m__5374__auto__$jscomp$inline_3151$$=$me$flowthing$pp$write$$._,$m__5372__auto__$jscomp$inline_3152_m__5374__auto__$jscomp$inline_3151$$!=null)$JSCompiler_temp$jscomp$313_this$$jscomp$144$$=$m__5372__auto__$jscomp$inline_3152_m__5374__auto__$jscomp$inline_3151$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3152_m__5374__auto__$jscomp$inline_3151$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$313_this$$jscomp$144$$,
$s$jscomp$293$$):$m__5372__auto__$jscomp$inline_3152_m__5374__auto__$jscomp$inline_3151$$($JSCompiler_temp$jscomp$313_this$$jscomp$144$$,$s$jscomp$293$$);else throw $APP.$cljs$core$missing_protocol$$("CountKeepingWriter.write",$JSCompiler_temp$jscomp$313_this$$jscomp$144$$);}return $JSCompiler_temp$jscomp$313_this$$jscomp$144$$};
$me$flowthing$pp$remaining$$=function($JSCompiler_temp$jscomp$314_this$$jscomp$146$$){if($JSCompiler_temp$jscomp$314_this$$jscomp$146$$!=null&&$JSCompiler_temp$jscomp$314_this$$jscomp$146$$.$me$flowthing$pp$CountKeepingWriter$remaining$arity$1$!=null)$JSCompiler_temp$jscomp$314_this$$jscomp$146$$=$JSCompiler_temp$jscomp$314_this$$jscomp$146$$.$me$flowthing$pp$CountKeepingWriter$remaining$arity$1$($JSCompiler_temp$jscomp$314_this$$jscomp$146$$);else{var $m__5372__auto__$jscomp$inline_3156_m__5374__auto__$jscomp$inline_3155$$=
$me$flowthing$pp$remaining$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$314_this$$jscomp$146$$==null?null:$JSCompiler_temp$jscomp$314_this$$jscomp$146$$)];if($m__5372__auto__$jscomp$inline_3156_m__5374__auto__$jscomp$inline_3155$$!=null)$JSCompiler_temp$jscomp$314_this$$jscomp$146$$=$m__5372__auto__$jscomp$inline_3156_m__5374__auto__$jscomp$inline_3155$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3156_m__5374__auto__$jscomp$inline_3155$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$314_this$$jscomp$146$$):
$m__5372__auto__$jscomp$inline_3156_m__5374__auto__$jscomp$inline_3155$$($JSCompiler_temp$jscomp$314_this$$jscomp$146$$);else if($m__5372__auto__$jscomp$inline_3156_m__5374__auto__$jscomp$inline_3155$$=$me$flowthing$pp$remaining$$._,$m__5372__auto__$jscomp$inline_3156_m__5374__auto__$jscomp$inline_3155$$!=null)$JSCompiler_temp$jscomp$314_this$$jscomp$146$$=$m__5372__auto__$jscomp$inline_3156_m__5374__auto__$jscomp$inline_3155$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3156_m__5374__auto__$jscomp$inline_3155$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$314_this$$jscomp$146$$):
$m__5372__auto__$jscomp$inline_3156_m__5374__auto__$jscomp$inline_3155$$($JSCompiler_temp$jscomp$314_this$$jscomp$146$$);else throw $APP.$cljs$core$missing_protocol$$("CountKeepingWriter.remaining",$JSCompiler_temp$jscomp$314_this$$jscomp$146$$);}return $JSCompiler_temp$jscomp$314_this$$jscomp$146$$};
$me$flowthing$pp$nl$$=function($this$$jscomp$148$$){if($this$$jscomp$148$$!=null&&$this$$jscomp$148$$.$me$flowthing$pp$CountKeepingWriter$nl$arity$1$!=null)$this$$jscomp$148$$.$me$flowthing$pp$CountKeepingWriter$nl$arity$1$($this$$jscomp$148$$);else{var $m__5372__auto__$jscomp$inline_3160_m__5374__auto__$jscomp$inline_3159$$=$me$flowthing$pp$nl$$[$APP.$goog$typeOf$$($this$$jscomp$148$$==null?null:$this$$jscomp$148$$)];if($m__5372__auto__$jscomp$inline_3160_m__5374__auto__$jscomp$inline_3159$$!=null)$m__5372__auto__$jscomp$inline_3160_m__5374__auto__$jscomp$inline_3159$$.$cljs$core$IFn$_invoke$arity$1$?
$m__5372__auto__$jscomp$inline_3160_m__5374__auto__$jscomp$inline_3159$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$148$$):$m__5372__auto__$jscomp$inline_3160_m__5374__auto__$jscomp$inline_3159$$($this$$jscomp$148$$);else if($m__5372__auto__$jscomp$inline_3160_m__5374__auto__$jscomp$inline_3159$$=$me$flowthing$pp$nl$$._,$m__5372__auto__$jscomp$inline_3160_m__5374__auto__$jscomp$inline_3159$$!=null)$m__5372__auto__$jscomp$inline_3160_m__5374__auto__$jscomp$inline_3159$$.$cljs$core$IFn$_invoke$arity$1$?
$m__5372__auto__$jscomp$inline_3160_m__5374__auto__$jscomp$inline_3159$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$148$$):$m__5372__auto__$jscomp$inline_3160_m__5374__auto__$jscomp$inline_3159$$($this$$jscomp$148$$);else throw $APP.$cljs$core$missing_protocol$$("CountKeepingWriter.nl",$this$$jscomp$148$$);}};$me$flowthing$pp$write_into$$=function($writer$jscomp$63$$,$s$jscomp$294$$){return $APP.$cljs$core$_write$$($writer$jscomp$63$$,$s$jscomp$294$$)};
$me$flowthing$pp$t_me$0flowthing$0pp24586$$=function($writer$jscomp$64$$,$opts$jscomp$116$$,$max_width$$,$c$jscomp$159$$,$meta24587$$){this.$writer$=$writer$jscomp$64$$;this.$opts$=$opts$jscomp$116$$;this.$max_width$=$max_width$$;this.c=$c$jscomp$159$$;this.$meta24587$=$meta24587$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$me$flowthing$pp$open_delim_PLUS_form$$=function($coll$jscomp$900_coll__$1$jscomp$487$$){if($APP.$cljs$core$record_QMARK_$$($coll$jscomp$900_coll__$1$jscomp$487$$))return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[["#",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$type$$($coll$jscomp$900_coll__$1$jscomp$487$$)])),"{"].join(""),$coll$jscomp$900_coll__$1$jscomp$487$$],
null);var $ns_map_vec__24601$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$(!1)?$APP.$cljs$core$map_QMARK_$$($coll$jscomp$900_coll__$1$jscomp$487$$):!1)?$me$flowthing$pp$extract_map_ns$$($coll$jscomp$900_coll__$1$jscomp$487$$):null,$JSCompiler_temp$jscomp$10668_ns$jscomp$24$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ns_map_vec__24601$$,0,null);$ns_map_vec__24601$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ns_map_vec__24601$$,1,null);$coll$jscomp$900_coll__$1$jscomp$487$$=
$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10668_ns$jscomp$24$$)?$ns_map_vec__24601$$:$coll$jscomp$900_coll__$1$jscomp$487$$;$JSCompiler_temp$jscomp$10668_ns$jscomp$24$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10668_ns$jscomp$24$$)?["#:",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10668_ns$jscomp$24$$),"{"].join(""):$APP.$cljs$core$map_QMARK_$$($coll$jscomp$900_coll__$1$jscomp$487$$)?"{":$APP.$cljs$core$vector_QMARK_$$($coll$jscomp$900_coll__$1$jscomp$487$$)?
"[":$APP.$cljs$core$set_QMARK_$$($coll$jscomp$900_coll__$1$jscomp$487$$)?"#{":$APP.$cljs$core$array_QMARK_$$($coll$jscomp$900_coll__$1$jscomp$487$$)?"[":"(";return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$10668_ns$jscomp$24$$,$coll$jscomp$900_coll__$1$jscomp$487$$],null)};
$me$flowthing$pp$meets_print_level_QMARK_$$=function($level$jscomp$29$$){return $APP.$cljs$core$int_QMARK_$$($cljs$core$_STAR_print_level_STAR_$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$29$$,$cljs$core$_STAR_print_level_STAR_$$)};
$me$flowthing$pp$_print_coll$$=function($coll$jscomp$902_form$jscomp$30_vec__24619$$,$writer$jscomp$69$$,$opts$jscomp$121$$){if($me$flowthing$pp$meets_print_level_QMARK_$$($APP.$cljs$cst$284$level$$.$cljs$core$IFn$_invoke$arity$2$($opts$jscomp$121$$,0)))return $APP.$cljs$core$_write$$($writer$jscomp$69$$,"#");$coll$jscomp$902_form$jscomp$30_vec__24619$$=$me$flowthing$pp$open_delim_PLUS_form$$($coll$jscomp$902_form$jscomp$30_vec__24619$$);var $G__24759_index_24750_o$jscomp$153$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($coll$jscomp$902_form$jscomp$30_vec__24619$$,
0,null);$coll$jscomp$902_form$jscomp$30_vec__24619$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($coll$jscomp$902_form$jscomp$30_vec__24619$$,1,null);$APP.$cljs$core$_write$$($writer$jscomp$69$$,$G__24759_index_24750_o$jscomp$153$$);if($APP.$cljs$core$seq$$($coll$jscomp$902_form$jscomp$30_vec__24619$$)){var $form_24749__$1_n_24752$$=$coll$jscomp$902_form$jscomp$30_vec__24619$$;for($G__24759_index_24750_o$jscomp$153$$=0;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__24759_index_24750_o$jscomp$153$$,
$cljs$core$_STAR_print_length_STAR_$$))$APP.$cljs$core$_write$$($writer$jscomp$69$$,"...");else{var $G__24626_24753_f_24751$$=$APP.$cljs$core$first$$($form_24749__$1_n_24752$$);$form_24749__$1_n_24752$$=$APP.$cljs$core$next$$($form_24749__$1_n_24752$$);var $G__24627_24754$$=$writer$jscomp$69$$,$G__24628_24755$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($opts$jscomp$121$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$core$inc$$);$me$flowthing$pp$_print$$.$cljs$core$IFn$_invoke$arity$3$?$me$flowthing$pp$_print$$.$cljs$core$IFn$_invoke$arity$3$($G__24626_24753_f_24751$$,
$G__24627_24754$$,$G__24628_24755$$):$me$flowthing$pp$_print$$($G__24626_24753_f_24751$$,$G__24627_24754$$,$G__24628_24755$$);if(!$APP.$cljs$core$empty_QMARK_$$($form_24749__$1_n_24752$$)){$APP.$cljs$core$_write$$($writer$jscomp$69$$," ");$G__24759_index_24750_o$jscomp$153$$+=1;continue}}break}}return $me$flowthing$pp$write_into$$($writer$jscomp$69$$,$me$flowthing$pp$close_delim$$($coll$jscomp$902_form$jscomp$30_vec__24619$$))};
$me$flowthing$pp$_print$$=function($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$,$JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$,$opts$jscomp$123$$){if($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$==null)$JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$=$APP.$cljs$core$_write$$($JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$,
"nil");else if($APP.$cljs$core$seq_QMARK_$$($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$)){var $G__24629$jscomp$inline_11385_G__24744$jscomp$inline_3176_index_24737$jscomp$inline_3173_o$jscomp$inline_3170_temp__5827__auto__$jscomp$inline_11384$$=$APP.$cljs$core$first$$($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$);$G__24629$jscomp$inline_11385_G__24744$jscomp$inline_3176_index_24737$jscomp$inline_3173_o$jscomp$inline_3170_temp__5827__auto__$jscomp$inline_11384$$=
$me$flowthing$pp$reader_macros$$.$cljs$core$IFn$_invoke$arity$1$?$me$flowthing$pp$reader_macros$$.$cljs$core$IFn$_invoke$arity$1$($G__24629$jscomp$inline_11385_G__24744$jscomp$inline_3176_index_24737$jscomp$inline_3173_o$jscomp$inline_3170_temp__5827__auto__$jscomp$inline_11384$$):$me$flowthing$pp$reader_macros$$($G__24629$jscomp$inline_11385_G__24744$jscomp$inline_3176_index_24737$jscomp$inline_3173_o$jscomp$inline_3170_temp__5827__auto__$jscomp$inline_11384$$);$G__24629$jscomp$inline_11385_G__24744$jscomp$inline_3176_index_24737$jscomp$inline_3173_o$jscomp$inline_3170_temp__5827__auto__$jscomp$inline_11384$$==
null?$JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$=$me$flowthing$pp$_print_coll$$($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$,$JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$,$opts$jscomp$123$$):($APP.$cljs$core$_write$$($JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$,$G__24629$jscomp$inline_11385_G__24744$jscomp$inline_3176_index_24737$jscomp$inline_3173_o$jscomp$inline_3170_temp__5827__auto__$jscomp$inline_11384$$),
$JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$=$me$flowthing$pp$write_into$$($JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$,$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$second$$($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$)]))))}else if($APP.$cljs$core$map_QMARK_$$($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$))if($me$flowthing$pp$meets_print_level_QMARK_$$($APP.$cljs$cst$284$level$$.$cljs$core$IFn$_invoke$arity$2$($opts$jscomp$123$$,
0)))$JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$=$APP.$cljs$core$_write$$($JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$,"#");else{$form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$=$me$flowthing$pp$open_delim_PLUS_form$$($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$);$G__24629$jscomp$inline_11385_G__24744$jscomp$inline_3176_index_24737$jscomp$inline_3173_o$jscomp$inline_3170_temp__5827__auto__$jscomp$inline_11384$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$,0,null);$form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$,1,null);$APP.$cljs$core$_write$$($JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$,$G__24629$jscomp$inline_11385_G__24744$jscomp$inline_3176_index_24737$jscomp$inline_3173_o$jscomp$inline_3170_temp__5827__auto__$jscomp$inline_11384$$);
if($APP.$cljs$core$seq$$($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$)){var $form_24736__$1$jscomp$inline_3172_n_24740$jscomp$inline_3175$$=$form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$;for($G__24629$jscomp$inline_11385_G__24744$jscomp$inline_3176_index_24737$jscomp$inline_3173_o$jscomp$inline_3170_temp__5827__auto__$jscomp$inline_11384$$=0;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__24629$jscomp$inline_11385_G__24744$jscomp$inline_3176_index_24737$jscomp$inline_3173_o$jscomp$inline_3170_temp__5827__auto__$jscomp$inline_11384$$,
$cljs$core$_STAR_print_length_STAR_$$))$APP.$cljs$core$_write$$($JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$,"...");else{var $f_24739$jscomp$inline_3174_writer$jscomp$inline_11388$$=$APP.$cljs$core$first$$($form_24736__$1$jscomp$inline_3172_n_24740$jscomp$inline_3175$$);$form_24736__$1$jscomp$inline_3172_n_24740$jscomp$inline_3175$$=$APP.$cljs$core$next$$($form_24736__$1$jscomp$inline_3172_n_24740$jscomp$inline_3175$$);var $G__24610$jscomp$inline_11392_this$$jscomp$inline_11387$$=
$f_24739$jscomp$inline_3174_writer$jscomp$inline_11388$$;$f_24739$jscomp$inline_3174_writer$jscomp$inline_11388$$=$JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$;var $opts$jscomp$inline_11389_opts__$1$jscomp$inline_11390$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($opts$jscomp$123$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$core$inc$$);if($me$flowthing$pp$meets_print_level_QMARK_$$($APP.$cljs$cst$284$level$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$inline_11389_opts__$1$jscomp$inline_11390$$)))$APP.$cljs$core$_write$$($f_24739$jscomp$inline_3174_writer$jscomp$inline_11388$$,
"#");else{$opts$jscomp$inline_11389_opts__$1$jscomp$inline_11390$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($opts$jscomp$inline_11389_opts__$1$jscomp$inline_11390$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$core$inc$$);var $G__24607_24733$jscomp$inline_11391$$=$APP.$cljs$core$_key$$($G__24610$jscomp$inline_11392_this$$jscomp$inline_11387$$);$me$flowthing$pp$_print$$.$cljs$core$IFn$_invoke$arity$3$?$me$flowthing$pp$_print$$.$cljs$core$IFn$_invoke$arity$3$($G__24607_24733$jscomp$inline_11391$$,
$f_24739$jscomp$inline_3174_writer$jscomp$inline_11388$$,$opts$jscomp$inline_11389_opts__$1$jscomp$inline_11390$$):$me$flowthing$pp$_print$$($G__24607_24733$jscomp$inline_11391$$,$f_24739$jscomp$inline_3174_writer$jscomp$inline_11388$$,$opts$jscomp$inline_11389_opts__$1$jscomp$inline_11390$$);$APP.$cljs$core$_write$$($f_24739$jscomp$inline_3174_writer$jscomp$inline_11388$$," ");$G__24610$jscomp$inline_11392_this$$jscomp$inline_11387$$=$APP.$cljs$core$_val$$($G__24610$jscomp$inline_11392_this$$jscomp$inline_11387$$);
$me$flowthing$pp$_print$$.$cljs$core$IFn$_invoke$arity$3$?$me$flowthing$pp$_print$$.$cljs$core$IFn$_invoke$arity$3$($G__24610$jscomp$inline_11392_this$$jscomp$inline_11387$$,$f_24739$jscomp$inline_3174_writer$jscomp$inline_11388$$,$opts$jscomp$inline_11389_opts__$1$jscomp$inline_11390$$):$me$flowthing$pp$_print$$($G__24610$jscomp$inline_11392_this$$jscomp$inline_11387$$,$f_24739$jscomp$inline_3174_writer$jscomp$inline_11388$$,$opts$jscomp$inline_11389_opts__$1$jscomp$inline_11390$$)}if(!$APP.$cljs$core$empty_QMARK_$$($form_24736__$1$jscomp$inline_3172_n_24740$jscomp$inline_3175$$)){$me$flowthing$pp$write_into$$($JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$,
$cljs$cst$285$map_entry_separator$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$123$$));$APP.$cljs$core$_write$$($JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$," ");$G__24629$jscomp$inline_11385_G__24744$jscomp$inline_3176_index_24737$jscomp$inline_3173_o$jscomp$inline_3170_temp__5827__auto__$jscomp$inline_11384$$+=1;continue}}break}}$JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$=$me$flowthing$pp$write_into$$($JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$,
$me$flowthing$pp$close_delim$$($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$))}else $JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$=$APP.$cljs$core$vector_QMARK_$$($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$)?$me$flowthing$pp$_print_coll$$($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$,$JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$,
$opts$jscomp$123$$):$APP.$cljs$core$set_QMARK_$$($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$)?$me$flowthing$pp$_print_coll$$($form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$,$JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$,$opts$jscomp$123$$):$me$flowthing$pp$write_into$$($JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$,$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$form$jscomp$inline_3171_this$$jscomp$151_vec__24614$jscomp$inline_3169$$])));
return $JSCompiler_temp$jscomp$318_JSCompiler_temp$jscomp$319_JSCompiler_temp$jscomp$320_writer$jscomp$71$$};$me$flowthing$pp$with_str_writer$$=function($f$jscomp$368$$){var $sb$jscomp$20$$=new $APP.$goog$string$StringBuffer$$,$writer$jscomp$72$$=new $cljs$core$StringBufferWriter$$($sb$jscomp$20$$);$f$jscomp$368$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$368$$.$cljs$core$IFn$_invoke$arity$1$($writer$jscomp$72$$):$f$jscomp$368$$($writer$jscomp$72$$);return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$20$$)};
$me$flowthing$pp$print_linear$cljs$0core$0IFn$0_invoke$0arity$02$$=function($form$jscomp$32$$,$opts$jscomp$124$$){return $me$flowthing$pp$with_str_writer$$(function($writer$jscomp$73$$){return $me$flowthing$pp$_print$$($form$jscomp$32$$,$writer$jscomp$73$$,$opts$jscomp$124$$)})};
$me$flowthing$pp$print_mode$$=function($writer$jscomp$75$$,$form$jscomp$34$$,$opts$jscomp$126$$){var $reserve_chars$$=$cljs$cst$286$reserve_chars$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$126$$);return $me$flowthing$pp$print_linear$cljs$0core$0IFn$0_invoke$0arity$02$$($form$jscomp$34$$,$opts$jscomp$126$$).length<=$me$flowthing$pp$remaining$$($writer$jscomp$75$$)-$reserve_chars$$?$APP.$cljs$cst$287$linear$$:$cljs$cst$288$miser$$};
$me$flowthing$pp$write_sep$$=function($writer$jscomp$76$$,$mode$jscomp$15$$){switch($mode$jscomp$15$$ instanceof $APP.$cljs$core$Keyword$$?$mode$jscomp$15$$.$fqn$:null){case "miser":$me$flowthing$pp$nl$$($writer$jscomp$76$$);break;default:$me$flowthing$pp$write$$($writer$jscomp$76$$," ")}};
$me$flowthing$pp$pprint_meta$$=function($form$jscomp$35_m_24782__$1_temp__5829__auto__$jscomp$3$$,$writer$jscomp$77$$,$opts$jscomp$127$$,$mode$jscomp$16$$){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$(!1)?$cljs$core$_STAR_print_readably_STAR_$$:!1)&&($form$jscomp$35_m_24782__$1_temp__5829__auto__$jscomp$3$$=$APP.$cljs$core$meta$$($form$jscomp$35_m_24782__$1_temp__5829__auto__$jscomp$3$$),$form$jscomp$35_m_24782__$1_temp__5829__auto__$jscomp$3$$!=null&&$APP.$cljs$core$seq$$($form$jscomp$35_m_24782__$1_temp__5829__auto__$jscomp$3$$))){$me$flowthing$pp$write$$($writer$jscomp$77$$,
"^");var $JSCompiler_inline_result$jscomp$10669_and__5023__auto__$jscomp$inline_11394$$=($JSCompiler_inline_result$jscomp$10669_and__5023__auto__$jscomp$inline_11394$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($form$jscomp$35_m_24782__$1_temp__5829__auto__$jscomp$3$$),1))?$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($form$jscomp$35_m_24782__$1_temp__5829__auto__$jscomp$3$$):$JSCompiler_inline_result$jscomp$10669_and__5023__auto__$jscomp$inline_11394$$;
$form$jscomp$35_m_24782__$1_temp__5829__auto__$jscomp$3$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10669_and__5023__auto__$jscomp$inline_11394$$)?$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($form$jscomp$35_m_24782__$1_temp__5829__auto__$jscomp$3$$):$form$jscomp$35_m_24782__$1_temp__5829__auto__$jscomp$3$$;$me$flowthing$pp$_pprint$$.$cljs$core$IFn$_invoke$arity$3$?$me$flowthing$pp$_pprint$$.$cljs$core$IFn$_invoke$arity$3$($form$jscomp$35_m_24782__$1_temp__5829__auto__$jscomp$3$$,
$writer$jscomp$77$$,$opts$jscomp$127$$):$me$flowthing$pp$_pprint$$($form$jscomp$35_m_24782__$1_temp__5829__auto__$jscomp$3$$,$writer$jscomp$77$$,$opts$jscomp$127$$);$me$flowthing$pp$write_sep$$($writer$jscomp$77$$,$mode$jscomp$16$$)}};
$me$flowthing$pp$pprint_opts$$=function($indentation_open_delim$$,$opts$jscomp$128$$){$indentation_open_delim$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$289$indentation$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$128$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(" ".repeat($indentation_open_delim$$.length))].join("");return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($opts$jscomp$128$$,$cljs$cst$289$indentation$$,
$indentation_open_delim$$),$APP.$cljs$cst$284$level$$,$APP.$cljs$core$inc$$)};
$me$flowthing$pp$_pprint_coll$$=function($G__24666_24789_mode$jscomp$17_this$$jscomp$152$$,$writer$jscomp$78$$,$G__24668_24791_opts$jscomp$129_opts__$1$jscomp$2$$){if($me$flowthing$pp$meets_print_level_QMARK_$$($APP.$cljs$cst$284$level$$.$cljs$core$IFn$_invoke$arity$1$($G__24668_24791_opts$jscomp$129_opts__$1$jscomp$2$$)))return $me$flowthing$pp$write$$($writer$jscomp$78$$,"#");var $form$jscomp$36_vec__24650$$=$me$flowthing$pp$open_delim_PLUS_form$$($G__24666_24789_mode$jscomp$17_this$$jscomp$152$$),$G__24667_24790_G__24799_index_24785_o$jscomp$154$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($form$jscomp$36_vec__24650$$,0,null);$form$jscomp$36_vec__24650$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($form$jscomp$36_vec__24650$$,1,null);$G__24666_24789_mode$jscomp$17_this$$jscomp$152$$=$me$flowthing$pp$print_mode$$($writer$jscomp$78$$,$G__24666_24789_mode$jscomp$17_this$$jscomp$152$$,$G__24668_24791_opts$jscomp$129_opts__$1$jscomp$2$$);$G__24668_24791_opts$jscomp$129_opts__$1$jscomp$2$$=$me$flowthing$pp$pprint_opts$$($G__24667_24790_G__24799_index_24785_o$jscomp$154$$,
$G__24668_24791_opts$jscomp$129_opts__$1$jscomp$2$$);$me$flowthing$pp$pprint_meta$$($form$jscomp$36_vec__24650$$,$writer$jscomp$78$$,$G__24668_24791_opts$jscomp$129_opts__$1$jscomp$2$$,$G__24666_24789_mode$jscomp$17_this$$jscomp$152$$);$me$flowthing$pp$write$$($writer$jscomp$78$$,$G__24667_24790_G__24799_index_24785_o$jscomp$154$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$_STAR_print_length_STAR_$$,0))$me$flowthing$pp$write$$($writer$jscomp$78$$,"...");else if($APP.$cljs$core$seq$$($form$jscomp$36_vec__24650$$)){var $form_24784__$1_n_24788$$=
$form$jscomp$36_vec__24650$$;for($G__24667_24790_G__24799_index_24785_o$jscomp$154$$=0;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__24667_24790_G__24799_index_24785_o$jscomp$154$$,$cljs$core$_STAR_print_length_STAR_$$))$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__24666_24789_mode$jscomp$17_this$$jscomp$152$$,$cljs$cst$288$miser$$)&&$me$flowthing$pp$write$$($writer$jscomp$78$$,$cljs$cst$289$indentation$$.$cljs$core$IFn$_invoke$arity$1$($G__24668_24791_opts$jscomp$129_opts__$1$jscomp$2$$)),
$me$flowthing$pp$write$$($writer$jscomp$78$$,"...");else{$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__24666_24789_mode$jscomp$17_this$$jscomp$152$$,$cljs$cst$288$miser$$)&&$G__24667_24790_G__24799_index_24785_o$jscomp$154$$>0&&$me$flowthing$pp$write$$($writer$jscomp$78$$,$cljs$cst$289$indentation$$.$cljs$core$IFn$_invoke$arity$1$($G__24668_24791_opts$jscomp$129_opts__$1$jscomp$2$$));var $G__24669_24792_f_24787$$=$APP.$cljs$core$first$$($form_24784__$1_n_24788$$);$form_24784__$1_n_24788$$=
$APP.$cljs$core$next$$($form_24784__$1_n_24788$$);if($APP.$cljs$core$empty_QMARK_$$($form_24784__$1_n_24788$$))$G__24666_24789_mode$jscomp$17_this$$jscomp$152$$=$G__24669_24792_f_24787$$,$G__24667_24790_G__24799_index_24785_o$jscomp$154$$=$writer$jscomp$78$$,$G__24668_24791_opts$jscomp$129_opts__$1$jscomp$2$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__24668_24791_opts$jscomp$129_opts__$1$jscomp$2$$,$cljs$cst$286$reserve_chars$$,$APP.$cljs$core$inc$$),$me$flowthing$pp$_pprint$$.$cljs$core$IFn$_invoke$arity$3$?
$me$flowthing$pp$_pprint$$.$cljs$core$IFn$_invoke$arity$3$($G__24666_24789_mode$jscomp$17_this$$jscomp$152$$,$G__24667_24790_G__24799_index_24785_o$jscomp$154$$,$G__24668_24791_opts$jscomp$129_opts__$1$jscomp$2$$):$me$flowthing$pp$_pprint$$($G__24666_24789_mode$jscomp$17_this$$jscomp$152$$,$G__24667_24790_G__24799_index_24785_o$jscomp$154$$,$G__24668_24791_opts$jscomp$129_opts__$1$jscomp$2$$);else{var $G__24670_24793$$=$writer$jscomp$78$$,$G__24671_24794$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__24668_24791_opts$jscomp$129_opts__$1$jscomp$2$$,
$cljs$cst$286$reserve_chars$$,0);$me$flowthing$pp$_pprint$$.$cljs$core$IFn$_invoke$arity$3$?$me$flowthing$pp$_pprint$$.$cljs$core$IFn$_invoke$arity$3$($G__24669_24792_f_24787$$,$G__24670_24793$$,$G__24671_24794$$):$me$flowthing$pp$_pprint$$($G__24669_24792_f_24787$$,$G__24670_24793$$,$G__24671_24794$$);$me$flowthing$pp$write_sep$$($writer$jscomp$78$$,$G__24666_24789_mode$jscomp$17_this$$jscomp$152$$);$G__24667_24790_G__24799_index_24785_o$jscomp$154$$+=1;continue}}break}}return $me$flowthing$pp$write$$($writer$jscomp$78$$,
$me$flowthing$pp$close_delim$$($form$jscomp$36_vec__24650$$))};
$me$flowthing$pp$_pprint_map_entry$$=function($this$$jscomp$153_v$jscomp$151$$,$writer$jscomp$79$$,$opts$jscomp$130_opts__$1$jscomp$3$$){if($me$flowthing$pp$meets_print_level_QMARK_$$($APP.$cljs$cst$284$level$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$130_opts__$1$jscomp$3$$)))$me$flowthing$pp$write$$($writer$jscomp$79$$,"#");else{var $k$jscomp$272_mode$jscomp$18$$=$APP.$cljs$core$_key$$($this$$jscomp$153_v$jscomp$151$$);$opts$jscomp$130_opts__$1$jscomp$3$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($opts$jscomp$130_opts__$1$jscomp$3$$,
$APP.$cljs$cst$284$level$$,$APP.$cljs$core$inc$$);$me$flowthing$pp$_pprint$$.$cljs$core$IFn$_invoke$arity$3$?$me$flowthing$pp$_pprint$$.$cljs$core$IFn$_invoke$arity$3$($k$jscomp$272_mode$jscomp$18$$,$writer$jscomp$79$$,$opts$jscomp$130_opts__$1$jscomp$3$$):$me$flowthing$pp$_pprint$$($k$jscomp$272_mode$jscomp$18$$,$writer$jscomp$79$$,$opts$jscomp$130_opts__$1$jscomp$3$$);$this$$jscomp$153_v$jscomp$151$$=$APP.$cljs$core$_val$$($this$$jscomp$153_v$jscomp$151$$);$k$jscomp$272_mode$jscomp$18$$=$me$flowthing$pp$print_mode$$($writer$jscomp$79$$,
$this$$jscomp$153_v$jscomp$151$$,$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($opts$jscomp$130_opts__$1$jscomp$3$$,$cljs$cst$286$reserve_chars$$,$APP.$cljs$core$inc$$));$me$flowthing$pp$write_sep$$($writer$jscomp$79$$,$k$jscomp$272_mode$jscomp$18$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$288$miser$$,$k$jscomp$272_mode$jscomp$18$$)&&$me$flowthing$pp$write$$($writer$jscomp$79$$,$cljs$cst$289$indentation$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$130_opts__$1$jscomp$3$$));
$me$flowthing$pp$_pprint$$.$cljs$core$IFn$_invoke$arity$3$?$me$flowthing$pp$_pprint$$.$cljs$core$IFn$_invoke$arity$3$($this$$jscomp$153_v$jscomp$151$$,$writer$jscomp$79$$,$opts$jscomp$130_opts__$1$jscomp$3$$):$me$flowthing$pp$_pprint$$($this$$jscomp$153_v$jscomp$151$$,$writer$jscomp$79$$,$opts$jscomp$130_opts__$1$jscomp$3$$)}};
$me$flowthing$pp$_pprint_seq$$=function($this$$jscomp$155$$,$writer$jscomp$81$$,$G__24688_opts$jscomp$132$$){var $G__24686_temp__5827__auto__$jscomp$3$$=function(){var $G__24684$$=$APP.$cljs$core$first$$($this$$jscomp$155$$);return $me$flowthing$pp$reader_macros$$.$cljs$core$IFn$_invoke$arity$1$?$me$flowthing$pp$reader_macros$$.$cljs$core$IFn$_invoke$arity$1$($G__24684$$):$me$flowthing$pp$reader_macros$$($G__24684$$)}();if($G__24686_temp__5827__auto__$jscomp$3$$==null)return $me$flowthing$pp$_pprint_coll$$($this$$jscomp$155$$,
$writer$jscomp$81$$,$G__24688_opts$jscomp$132$$);if($me$flowthing$pp$meets_print_level_QMARK_$$($APP.$cljs$cst$284$level$$.$cljs$core$IFn$_invoke$arity$1$($G__24688_opts$jscomp$132$$)))return $me$flowthing$pp$write$$($writer$jscomp$81$$,"#");$me$flowthing$pp$write$$($writer$jscomp$81$$,$G__24686_temp__5827__auto__$jscomp$3$$);$G__24686_temp__5827__auto__$jscomp$3$$=$APP.$cljs$core$second$$($this$$jscomp$155$$);$G__24688_opts$jscomp$132$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__24688_opts$jscomp$132$$,
$cljs$cst$289$indentation$$,function($indentation$jscomp$1$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($indentation$jscomp$1$$)," "].join("")});return $me$flowthing$pp$_pprint$$.$cljs$core$IFn$_invoke$arity$3$?$me$flowthing$pp$_pprint$$.$cljs$core$IFn$_invoke$arity$3$($G__24686_temp__5827__auto__$jscomp$3$$,$writer$jscomp$81$$,$G__24688_opts$jscomp$132$$):$me$flowthing$pp$_pprint$$($G__24686_temp__5827__auto__$jscomp$3$$,$writer$jscomp$81$$,$G__24688_opts$jscomp$132$$)};
$me$flowthing$pp$_pprint_queue$$=function($this$$jscomp$156$$,$writer$jscomp$82$$,$opts$jscomp$133$$){$me$flowthing$pp$write$$($writer$jscomp$82$$,"\x3c-");$me$flowthing$pp$_pprint_coll$$(function(){var $or__5025__auto__$jscomp$84$$=$APP.$cljs$core$seq$$($this$$jscomp$156$$);return $or__5025__auto__$jscomp$84$$?$or__5025__auto__$jscomp$84$$:$APP.$cljs$core$List$EMPTY$$}(),$writer$jscomp$82$$,$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($opts$jscomp$133$$,$cljs$cst$289$indentation$$,function($p1__24689_SHARP_$$){return["  ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__24689_SHARP_$$)].join("")}));return $me$flowthing$pp$write$$($writer$jscomp$82$$,"-\x3c")};
$me$flowthing$pp$_pprint$$=function($mode$jscomp$inline_3184_this$$jscomp$157$$,$JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,$opts$jscomp$134_opts__$1$jscomp$inline_3185$$){if($mode$jscomp$inline_3184_this$$jscomp$157$$==null)$JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$=$me$flowthing$pp$write$$($JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,
"nil");else if($mode$jscomp$inline_3184_this$$jscomp$157$$ instanceof $cljs$core$PersistentQueue$$)$JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$=$me$flowthing$pp$_pprint_queue$$($mode$jscomp$inline_3184_this$$jscomp$157$$,$JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,$opts$jscomp$134_opts__$1$jscomp$inline_3185$$);else if($APP.$cljs$core$seq_QMARK_$$($mode$jscomp$inline_3184_this$$jscomp$157$$))$JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$=
$me$flowthing$pp$_pprint_seq$$($mode$jscomp$inline_3184_this$$jscomp$157$$,$JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,$opts$jscomp$134_opts__$1$jscomp$inline_3185$$);else if($APP.$cljs$core$map_QMARK_$$($mode$jscomp$inline_3184_this$$jscomp$157$$))if($me$flowthing$pp$meets_print_level_QMARK_$$($APP.$cljs$cst$284$level$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$134_opts__$1$jscomp$inline_3185$$)))$JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$=
$me$flowthing$pp$write$$($JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,"#");else{var $form$jscomp$inline_3183_vec__24680$jscomp$inline_3181$$=$me$flowthing$pp$open_delim_PLUS_form$$($mode$jscomp$inline_3184_this$$jscomp$157$$),$G__24810$jscomp$inline_3191_index_24804$jscomp$inline_3187_o$jscomp$inline_3182$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($form$jscomp$inline_3183_vec__24680$jscomp$inline_3181$$,
0,null);$form$jscomp$inline_3183_vec__24680$jscomp$inline_3181$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($form$jscomp$inline_3183_vec__24680$jscomp$inline_3181$$,1,null);$mode$jscomp$inline_3184_this$$jscomp$157$$=$me$flowthing$pp$print_mode$$($JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,$mode$jscomp$inline_3184_this$$jscomp$157$$,$opts$jscomp$134_opts__$1$jscomp$inline_3185$$);$opts$jscomp$134_opts__$1$jscomp$inline_3185$$=
$me$flowthing$pp$pprint_opts$$($G__24810$jscomp$inline_3191_index_24804$jscomp$inline_3187_o$jscomp$inline_3182$$,$opts$jscomp$134_opts__$1$jscomp$inline_3185$$);$me$flowthing$pp$pprint_meta$$($form$jscomp$inline_3183_vec__24680$jscomp$inline_3181$$,$JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,$opts$jscomp$134_opts__$1$jscomp$inline_3185$$,$mode$jscomp$inline_3184_this$$jscomp$157$$);$me$flowthing$pp$write$$($JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,
$G__24810$jscomp$inline_3191_index_24804$jscomp$inline_3187_o$jscomp$inline_3182$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$_STAR_print_length_STAR_$$,0))$me$flowthing$pp$write$$($JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,"...");else if($APP.$cljs$core$seq$$($form$jscomp$inline_3183_vec__24680$jscomp$inline_3181$$)){var $form_24803__$1$jscomp$inline_3186_n_24806$jscomp$inline_3189$$=$form$jscomp$inline_3183_vec__24680$jscomp$inline_3181$$;
for($G__24810$jscomp$inline_3191_index_24804$jscomp$inline_3187_o$jscomp$inline_3182$$=0;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__24810$jscomp$inline_3191_index_24804$jscomp$inline_3187_o$jscomp$inline_3182$$,$cljs$core$_STAR_print_length_STAR_$$))$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$inline_3184_this$$jscomp$157$$,$cljs$cst$288$miser$$)&&$me$flowthing$pp$write$$($JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,
$cljs$cst$289$indentation$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$134_opts__$1$jscomp$inline_3185$$)),$me$flowthing$pp$write$$($JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,"...");else{$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$inline_3184_this$$jscomp$157$$,$cljs$cst$288$miser$$)&&$G__24810$jscomp$inline_3191_index_24804$jscomp$inline_3187_o$jscomp$inline_3182$$>0&&$me$flowthing$pp$write$$($JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,
$cljs$cst$289$indentation$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$134_opts__$1$jscomp$inline_3185$$));var $f_24805$jscomp$inline_3188$$=$APP.$cljs$core$first$$($form_24803__$1$jscomp$inline_3186_n_24806$jscomp$inline_3189$$);$form_24803__$1$jscomp$inline_3186_n_24806$jscomp$inline_3189$$=$APP.$cljs$core$next$$($form_24803__$1$jscomp$inline_3186_n_24806$jscomp$inline_3189$$);if($APP.$cljs$core$empty_QMARK_$$($form_24803__$1$jscomp$inline_3186_n_24806$jscomp$inline_3189$$))$me$flowthing$pp$_pprint_map_entry$$($f_24805$jscomp$inline_3188$$,
$JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($opts$jscomp$134_opts__$1$jscomp$inline_3185$$,$cljs$cst$286$reserve_chars$$,$APP.$cljs$core$inc$$));else{var $map_entry_separator_24808$jscomp$inline_3190$$=$cljs$cst$285$map_entry_separator$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$134_opts__$1$jscomp$inline_3185$$);$me$flowthing$pp$_pprint_map_entry$$($f_24805$jscomp$inline_3188$$,
$JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($opts$jscomp$134_opts__$1$jscomp$inline_3185$$,$cljs$cst$286$reserve_chars$$,$map_entry_separator_24808$jscomp$inline_3190$$.length));$me$flowthing$pp$write$$($JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,$map_entry_separator_24808$jscomp$inline_3190$$);
$me$flowthing$pp$write_sep$$($JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,$mode$jscomp$inline_3184_this$$jscomp$157$$);$G__24810$jscomp$inline_3191_index_24804$jscomp$inline_3187_o$jscomp$inline_3182$$+=1;continue}}break}}$JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$=$me$flowthing$pp$write$$($JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,
$me$flowthing$pp$close_delim$$($form$jscomp$inline_3183_vec__24680$jscomp$inline_3181$$))}else $JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$=$APP.$cljs$core$vector_QMARK_$$($mode$jscomp$inline_3184_this$$jscomp$157$$)?$me$flowthing$pp$_pprint_coll$$($mode$jscomp$inline_3184_this$$jscomp$157$$,$JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,
$opts$jscomp$134_opts__$1$jscomp$inline_3185$$):$APP.$cljs$core$set_QMARK_$$($mode$jscomp$inline_3184_this$$jscomp$157$$)?$me$flowthing$pp$_pprint_coll$$($mode$jscomp$inline_3184_this$$jscomp$157$$,$JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,$opts$jscomp$134_opts__$1$jscomp$inline_3185$$):$me$flowthing$pp$write$$($JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$,
$me$flowthing$pp$print_linear$cljs$0core$0IFn$0_invoke$0arity$02$$($mode$jscomp$inline_3184_this$$jscomp$157$$,$opts$jscomp$134_opts__$1$jscomp$inline_3185$$));return $JSCompiler_temp$jscomp$321_JSCompiler_temp$jscomp$322_JSCompiler_temp$jscomp$323_JSCompiler_temp$jscomp$324_writer$jscomp$83$$};
$me$flowthing$pp$pprint$cljs$0core$0IFn$0_invoke$0arity$03$$=function($x$jscomp$691$$,$p__24699_sb$jscomp$21$$){function $pp$$($writer__$1$jscomp$1_writer__$2$$){a:switch($max_width$jscomp$3$$){case Infinity:var $JSCompiler_inline_result$jscomp$326_opts$jscomp$inline_11397$$=Number.MAX_SAFE_INTEGER;break a;default:$JSCompiler_inline_result$jscomp$326_opts$jscomp$inline_11397$$=$max_width$jscomp$3$$}$JSCompiler_inline_result$jscomp$326_opts$jscomp$inline_11397$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$281$max_width$$,$JSCompiler_inline_result$jscomp$326_opts$jscomp$inline_11397$$],null);var $max_width$jscomp$inline_11398$$=$APP.$cljs$cst$281$max_width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$326_opts$jscomp$inline_11397$$);$writer__$1$jscomp$1_writer__$2$$=new $me$flowthing$pp$t_me$0flowthing$0pp24586$$($writer__$1$jscomp$1_writer__$2$$,$JSCompiler_inline_result$jscomp$326_opts$jscomp$inline_11397$$,$max_width$jscomp$inline_11398$$,$APP.$cljs$core$volatile_BANG_$$(0),
$APP.$cljs$core$PersistentArrayMap$EMPTY$$);$me$flowthing$pp$_pprint$$($x$jscomp$691$$,$writer__$1$jscomp$1_writer__$2$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__24700__$1$$,$cljs$cst$285$map_entry_separator$$,$map_entry_separator$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$284$level$$,0,$cljs$cst$289$indentation$$,"",$cljs$cst$286$reserve_chars$$,0])));return $writer__$1$jscomp$1_writer__$2$$.$me$flowthing$pp$CountKeepingWriter$nl$arity$1$(null)}
var $writer$jscomp$84_writer__$1$$=$cljs$core$_STAR_out_STAR_$$,$map__24700__$1$$=$APP.$cljs$core$__destructure_map$$($p__24699_sb$jscomp$21$$),$max_width$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__24700__$1$$,$APP.$cljs$cst$281$max_width$$,72),$map_entry_separator$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__24700__$1$$,$cljs$cst$285$map_entry_separator$$,",");if($APP.$cljs$core$truth_$$($writer$jscomp$84_writer__$1$$))return $pp$$($writer$jscomp$84_writer__$1$$);
$p__24699_sb$jscomp$21$$=new $APP.$goog$string$StringBuffer$$;$writer$jscomp$84_writer__$1$$=new $cljs$core$StringBufferWriter$$($p__24699_sb$jscomp$21$$);$pp$$($writer$jscomp$84_writer__$1$$);$cljs$core$string_print$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__24699_sb$jscomp$21$$));return $APP.$cljs$core$truth_$$(!0)?$writer$jscomp$84_writer__$1$$.$cljs$core$IWriter$_flush$arity$1$(null):null};
$app$common$pprint$pprint$$=function($var_args$jscomp$414$$){for(var $args__5755__auto__$jscomp$39$$=[],$len__5749__auto___24741$$=arguments.length,$i__5750__auto___24742$$=0;;)if($i__5750__auto___24742$$<$len__5749__auto___24741$$)$args__5755__auto__$jscomp$39$$.push(arguments[$i__5750__auto___24742$$]),$i__5750__auto___24742$$+=1;else break;$app$common$pprint$pprint$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$39$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$39$$.slice(1),
0,null):null)};
$app$common$pprint$pprint$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($expr$jscomp$3$$,$p__24715_width$jscomp$29$$){var $length$jscomp$32_map__24716__$1$$=$APP.$cljs$core$__destructure_map$$($p__24715_width$jscomp$29$$);$p__24715_width$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($length$jscomp$32_map__24716__$1$$,$APP.$cljs$cst$290$width$$,120);var $level$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($length$jscomp$32_map__24716__$1$$,$APP.$cljs$cst$284$level$$,
8);$length$jscomp$32_map__24716__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($length$jscomp$32_map__24716__$1$$,$APP.$cljs$cst$255$length$$,25);var $_STAR_print_level_STAR__orig_val__24717$$=$cljs$core$_STAR_print_level_STAR_$$,$_STAR_print_length_STAR__orig_val__24718$$=$cljs$core$_STAR_print_length_STAR_$$;$cljs$core$_STAR_print_level_STAR_$$=$level$jscomp$30$$;$cljs$core$_STAR_print_length_STAR_$$=$length$jscomp$32_map__24716__$1$$;try{return $me$flowthing$pp$pprint$cljs$0core$0IFn$0_invoke$0arity$03$$($expr$jscomp$3$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$281$max_width$$,$p__24715_width$jscomp$29$$],null))}finally{$cljs$core$_STAR_print_length_STAR_$$=$_STAR_print_length_STAR__orig_val__24718$$,$cljs$core$_STAR_print_level_STAR_$$=$_STAR_print_level_STAR__orig_val__24717$$}};
$app$common$pprint$pprint_str$$=function($var_args$jscomp$415$$){for(var $args__5755__auto__$jscomp$40$$=[],$len__5749__auto___24764$$=arguments.length,$i__5750__auto___24765$$=0;;)if($i__5750__auto___24765$$<$len__5749__auto___24764$$)$args__5755__auto__$jscomp$40$$.push(arguments[$i__5750__auto___24765$$]),$i__5750__auto___24765$$+=1;else break;return $app$common$pprint$pprint_str$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$40$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$40$$.slice(1),
0,null):null)};
$app$common$pprint$pprint_str$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($expr$jscomp$4$$,$opts$jscomp$137_p__24723$$){$opts$jscomp$137_p__24723$$=$APP.$cljs$core$__destructure_map$$($opts$jscomp$137_p__24723$$);var $sb__5670__auto__$$=new $APP.$goog$string$StringBuffer$$,$_STAR_print_newline_STAR__orig_val__24725_24771$$=$APP.$cljs$core$_STAR_print_newline_STAR_$$,$_STAR_print_fn_STAR__orig_val__24726_24772$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;
$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$$){return $sb__5670__auto__$$.append($x__5671__auto__$$)};try{$app$common$pprint$pprint$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($expr$jscomp$4$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$opts$jscomp$137_p__24723$$]))}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=$_STAR_print_fn_STAR__orig_val__24726_24772$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__24725_24771$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$$)};
$app$common$json$read_kebab_key$$=function($k$jscomp$273$$){return typeof $k$jscomp$273$$==="string"&&$APP.$cljs$core$not$$($APP.$cuerdas$core$includes_QMARK_$$($k$jscomp$273$$,"/"))?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$kebab$$($k$jscomp$273$$)):$k$jscomp$273$$};
$APP.$app$common$json$write_camel_key$$=function($k$jscomp$274$$){return $k$jscomp$274$$ instanceof $APP.$cljs$core$Keyword$$||$k$jscomp$274$$ instanceof $APP.$cljs$core$Symbol$$?$cuerdas$core$camel$$($k$jscomp$274$$):$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$274$$)};
$APP.$app$common$json$__GT_clj$$=function($var_args$jscomp$417$$){for(var $args__5755__auto__$jscomp$42$$=[],$len__5749__auto___31126$$=arguments.length,$i__5750__auto___31127$$=0;;)if($i__5750__auto___31127$$<$len__5749__auto___31126$$)$args__5755__auto__$jscomp$42$$.push(arguments[$i__5750__auto___31127$$]),$i__5750__auto___31127$$+=1;else break;return $app$common$json$__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$42$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$42$$.slice(1),
0,null):null)};
$app$common$json$__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($o$jscomp$156$$,$map__31105__$1_p__31102$$){$map__31105__$1_p__31102$$=$APP.$cljs$core$__destructure_map$$($map__31105__$1_p__31102$$);var $key_fn$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__31105__$1_p__31102$$,$APP.$cljs$cst$291$key_fn$$,$app$common$json$read_kebab_key$$),$val_fn$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__31105__$1_p__31102$$,$cljs$cst$292$val_fn$$,$APP.$cljs$core$identity$$),
$recursive$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__31105__$1_p__31102$$,$cljs$cst$293$recursive$$,!0);return function $app$common$json$this_fn$jscomp$1$$($x$jscomp$693$$){var $x__$1$jscomp$14$$=$val_fn$$.$cljs$core$IFn$_invoke$arity$1$?$val_fn$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$693$$):$val_fn$$($x$jscomp$693$$);return $APP.$cljs$core$array_QMARK_$$($x__$1$jscomp$14$$)?$APP.$cljs$core$persistent_BANG_$$($x__$1$jscomp$14$$.reduce(function($p1__31096_SHARP_$$,$p2__31097_SHARP_$$){return $APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($p1__31096_SHARP_$$,
$APP.$cljs$core$truth_$$($recursive$$)?$app$common$json$this_fn$jscomp$1$$($p2__31097_SHARP_$$):$p2__31097_SHARP_$$)},$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$))):$APP.$cljs$core$type$$($x__$1$jscomp$14$$)===Object?$APP.$cljs$core$persistent_BANG_$$($module$contents$goog$object_getKeys$$($x__$1$jscomp$14$$).reduce(function($p1__31098_SHARP_$$,$p2__31099_SHARP_$$){return $APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($p1__31098_SHARP_$$,$key_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$key_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($p2__31099_SHARP_$$):$key_fn$jscomp$1$$($p2__31099_SHARP_$$),$APP.$cljs$core$truth_$$($recursive$$)?$app$common$json$this_fn$jscomp$1$$($x__$1$jscomp$14$$[$p2__31099_SHARP_$$]):$x__$1$jscomp$14$$[$p2__31099_SHARP_$$])},$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$))):$x__$1$jscomp$14$$}($o$jscomp$156$$)};
$APP.$app$common$json$decode$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($data$jscomp$97$$,$opts$jscomp$140_p__31121$$){$opts$jscomp$140_p__31121$$=$APP.$cljs$core$__destructure_map$$($opts$jscomp$140_p__31121$$);return $app$common$json$__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(JSON.parse($data$jscomp$97$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$opts$jscomp$140_p__31121$$]))};
$malli$impl$util$_map_valid$$=function($f$jscomp$371$$,$v$jscomp$155$$){return $APP.$cljs$core$keyword_identical_QMARK_$$($v$jscomp$155$$,$cljs$cst$295$malli_DOT_core_SLASH_invalid$$)?$v$jscomp$155$$:$f$jscomp$371$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$371$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$155$$):$f$jscomp$371$$($v$jscomp$155$$)};
$malli$impl$util$_map_invalid$$=function($v$jscomp$156$$){return $APP.$cljs$core$keyword_identical_QMARK_$$($v$jscomp$156$$,$cljs$cst$295$malli_DOT_core_SLASH_invalid$$)?$APP.$cljs$core$reduced$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$reduced$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$156$$):$APP.$cljs$core$reduced$$($v$jscomp$156$$):$v$jscomp$156$$};
$malli$impl$util$_reduce_kv_valid$$=function($f$jscomp$373$$,$coll$jscomp$903$$){var $init$jscomp$50$$=$APP.$cljs$core$PersistentVector$EMPTY$$;return $APP.$cljs$core$reduce_kv$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__24865_SHARP_$$){return $malli$impl$util$_map_invalid$$($p1__24865_SHARP_$$)},$f$jscomp$373$$),$init$jscomp$50$$,$coll$jscomp$903$$)};
$malli$impl$util$_merge$$=function($m1$jscomp$2$$,$m2$jscomp$2$$){return $APP.$cljs$core$truth_$$($m1$jscomp$2$$)?$APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce_kv$$($APP.$cljs$core$assoc_BANG_$$,$APP.$cljs$core$_as_transient$$($m1$jscomp$2$$),$m2$jscomp$2$$)):$m2$jscomp$2$$};
$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$04$$=function($path$jscomp$25$$,$in$$jscomp$6$$,$schema$$,$value$jscomp$229$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$296$path$$,$path$jscomp$25$$,$APP.$cljs$cst$297$in$$,$in$$jscomp$6$$,$APP.$cljs$cst$298$schema$$,$schema$$,$APP.$cljs$cst$260$value$$,$value$jscomp$229$$],null)};
$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$=function($path$jscomp$26$$,$in$$jscomp$7$$,$schema$jscomp$1$$,$value$jscomp$230$$,$type$jscomp$179$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$296$path$$,$path$jscomp$26$$,$APP.$cljs$cst$297$in$$,$in$$jscomp$7$$,$APP.$cljs$cst$298$schema$$,$schema$jscomp$1$$,$APP.$cljs$cst$260$value$$,$value$jscomp$230$$,$APP.$cljs$cst$139$type$$,$type$jscomp$179$$],null)};
$malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$374$$,$os$jscomp$1$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($f$jscomp$374$$),$os$jscomp$1$$)};
$malli$impl$util$_every_pred$$=function($preds$$){return function($m$jscomp$105$$){return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($or__5025__auto__$jscomp$85_p1__24879_SHARP_$$,$p2__24878_SHARP_$$){$or__5025__auto__$jscomp$85_p1__24879_SHARP_$$=$p2__24878_SHARP_$$.$cljs$core$IFn$_invoke$arity$1$?$p2__24878_SHARP_$$.$cljs$core$IFn$_invoke$arity$1$($m$jscomp$105$$):$p2__24878_SHARP_$$($m$jscomp$105$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$85_p1__24879_SHARP_$$)?
$or__5025__auto__$jscomp$85_p1__24879_SHARP_$$:$APP.$cljs$core$reduced$$(!1)},!0,$preds$$))}};$malli$impl$util$_some_pred$$=function($preds$jscomp$1$$){return function($x$jscomp$697$$){return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$some$$(function($p1__24880_SHARP_$$){return $p1__24880_SHARP_$$.$cljs$core$IFn$_invoke$arity$1$?$p1__24880_SHARP_$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$697$$):$p1__24880_SHARP_$$($x$jscomp$697$$)},$preds$jscomp$1$$))}};
$malli$impl$regex$noncaching_park_validator_BANG_$$=function($JSCompiler_temp$jscomp$328_driver$jscomp$1$$,$validator$jscomp$4$$,$regs$jscomp$1$$,$pos$jscomp$2$$,$coll$jscomp$906$$,$k$jscomp$278$$){if($JSCompiler_temp$jscomp$328_driver$jscomp$1$$!=null&&$JSCompiler_temp$jscomp$328_driver$jscomp$1$$.$malli$impl$regex$IValidationDriver$noncaching_park_validator_BANG_$arity$6$!=null)$JSCompiler_temp$jscomp$328_driver$jscomp$1$$=$JSCompiler_temp$jscomp$328_driver$jscomp$1$$.$malli$impl$regex$IValidationDriver$noncaching_park_validator_BANG_$arity$6$($JSCompiler_temp$jscomp$328_driver$jscomp$1$$,
$validator$jscomp$4$$,$regs$jscomp$1$$,$pos$jscomp$2$$,$coll$jscomp$906$$,$k$jscomp$278$$);else{var $m__5372__auto__$jscomp$inline_3204_m__5374__auto__$jscomp$inline_3203$$=$malli$impl$regex$noncaching_park_validator_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$328_driver$jscomp$1$$==null?null:$JSCompiler_temp$jscomp$328_driver$jscomp$1$$)];if($m__5372__auto__$jscomp$inline_3204_m__5374__auto__$jscomp$inline_3203$$!=null)$JSCompiler_temp$jscomp$328_driver$jscomp$1$$=$m__5372__auto__$jscomp$inline_3204_m__5374__auto__$jscomp$inline_3203$$.$cljs$core$IFn$_invoke$arity$6$?
$m__5372__auto__$jscomp$inline_3204_m__5374__auto__$jscomp$inline_3203$$.$cljs$core$IFn$_invoke$arity$6$($JSCompiler_temp$jscomp$328_driver$jscomp$1$$,$validator$jscomp$4$$,$regs$jscomp$1$$,$pos$jscomp$2$$,$coll$jscomp$906$$,$k$jscomp$278$$):$m__5372__auto__$jscomp$inline_3204_m__5374__auto__$jscomp$inline_3203$$($JSCompiler_temp$jscomp$328_driver$jscomp$1$$,$validator$jscomp$4$$,$regs$jscomp$1$$,$pos$jscomp$2$$,$coll$jscomp$906$$,$k$jscomp$278$$);else if($m__5372__auto__$jscomp$inline_3204_m__5374__auto__$jscomp$inline_3203$$=
$malli$impl$regex$noncaching_park_validator_BANG_$$._,$m__5372__auto__$jscomp$inline_3204_m__5374__auto__$jscomp$inline_3203$$!=null)$JSCompiler_temp$jscomp$328_driver$jscomp$1$$=$m__5372__auto__$jscomp$inline_3204_m__5374__auto__$jscomp$inline_3203$$.$cljs$core$IFn$_invoke$arity$6$?$m__5372__auto__$jscomp$inline_3204_m__5374__auto__$jscomp$inline_3203$$.$cljs$core$IFn$_invoke$arity$6$($JSCompiler_temp$jscomp$328_driver$jscomp$1$$,$validator$jscomp$4$$,$regs$jscomp$1$$,$pos$jscomp$2$$,$coll$jscomp$906$$,
$k$jscomp$278$$):$m__5372__auto__$jscomp$inline_3204_m__5374__auto__$jscomp$inline_3203$$($JSCompiler_temp$jscomp$328_driver$jscomp$1$$,$validator$jscomp$4$$,$regs$jscomp$1$$,$pos$jscomp$2$$,$coll$jscomp$906$$,$k$jscomp$278$$);else throw $APP.$cljs$core$missing_protocol$$("IValidationDriver.noncaching-park-validator!",$JSCompiler_temp$jscomp$328_driver$jscomp$1$$);}return $JSCompiler_temp$jscomp$328_driver$jscomp$1$$};
$malli$impl$regex$park_validator_BANG_$$=function($JSCompiler_temp$jscomp$329_driver$jscomp$3$$,$validator$jscomp$6$$,$regs$jscomp$3$$,$pos$jscomp$4$$,$coll$jscomp$908$$,$k$jscomp$280$$){if($JSCompiler_temp$jscomp$329_driver$jscomp$3$$!=null&&$JSCompiler_temp$jscomp$329_driver$jscomp$3$$.$malli$impl$regex$IValidationDriver$park_validator_BANG_$arity$6$!=null)$JSCompiler_temp$jscomp$329_driver$jscomp$3$$=$JSCompiler_temp$jscomp$329_driver$jscomp$3$$.$malli$impl$regex$IValidationDriver$park_validator_BANG_$arity$6$($JSCompiler_temp$jscomp$329_driver$jscomp$3$$,
$validator$jscomp$6$$,$regs$jscomp$3$$,$pos$jscomp$4$$,$coll$jscomp$908$$,$k$jscomp$280$$);else{var $m__5372__auto__$jscomp$inline_3213_m__5374__auto__$jscomp$inline_3212$$=$malli$impl$regex$park_validator_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$329_driver$jscomp$3$$==null?null:$JSCompiler_temp$jscomp$329_driver$jscomp$3$$)];if($m__5372__auto__$jscomp$inline_3213_m__5374__auto__$jscomp$inline_3212$$!=null)$JSCompiler_temp$jscomp$329_driver$jscomp$3$$=$m__5372__auto__$jscomp$inline_3213_m__5374__auto__$jscomp$inline_3212$$.$cljs$core$IFn$_invoke$arity$6$?
$m__5372__auto__$jscomp$inline_3213_m__5374__auto__$jscomp$inline_3212$$.$cljs$core$IFn$_invoke$arity$6$($JSCompiler_temp$jscomp$329_driver$jscomp$3$$,$validator$jscomp$6$$,$regs$jscomp$3$$,$pos$jscomp$4$$,$coll$jscomp$908$$,$k$jscomp$280$$):$m__5372__auto__$jscomp$inline_3213_m__5374__auto__$jscomp$inline_3212$$($JSCompiler_temp$jscomp$329_driver$jscomp$3$$,$validator$jscomp$6$$,$regs$jscomp$3$$,$pos$jscomp$4$$,$coll$jscomp$908$$,$k$jscomp$280$$);else if($m__5372__auto__$jscomp$inline_3213_m__5374__auto__$jscomp$inline_3212$$=
$malli$impl$regex$park_validator_BANG_$$._,$m__5372__auto__$jscomp$inline_3213_m__5374__auto__$jscomp$inline_3212$$!=null)$JSCompiler_temp$jscomp$329_driver$jscomp$3$$=$m__5372__auto__$jscomp$inline_3213_m__5374__auto__$jscomp$inline_3212$$.$cljs$core$IFn$_invoke$arity$6$?$m__5372__auto__$jscomp$inline_3213_m__5374__auto__$jscomp$inline_3212$$.$cljs$core$IFn$_invoke$arity$6$($JSCompiler_temp$jscomp$329_driver$jscomp$3$$,$validator$jscomp$6$$,$regs$jscomp$3$$,$pos$jscomp$4$$,$coll$jscomp$908$$,$k$jscomp$280$$):
$m__5372__auto__$jscomp$inline_3213_m__5374__auto__$jscomp$inline_3212$$($JSCompiler_temp$jscomp$329_driver$jscomp$3$$,$validator$jscomp$6$$,$regs$jscomp$3$$,$pos$jscomp$4$$,$coll$jscomp$908$$,$k$jscomp$280$$);else throw $APP.$cljs$core$missing_protocol$$("IValidationDriver.park-validator!",$JSCompiler_temp$jscomp$329_driver$jscomp$3$$);}return $JSCompiler_temp$jscomp$329_driver$jscomp$3$$};
$malli$impl$regex$noncaching_park_explainer_BANG_$$=function($JSCompiler_temp$jscomp$330_driver$jscomp$5$$,$explainer$jscomp$1$$,$regs$jscomp$5$$,$pos$jscomp$6$$,$coll$jscomp$910$$,$k$jscomp$282$$){if($JSCompiler_temp$jscomp$330_driver$jscomp$5$$!=null&&$JSCompiler_temp$jscomp$330_driver$jscomp$5$$.$malli$impl$regex$IExplanationDriver$noncaching_park_explainer_BANG_$arity$6$!=null)$JSCompiler_temp$jscomp$330_driver$jscomp$5$$=$JSCompiler_temp$jscomp$330_driver$jscomp$5$$.$malli$impl$regex$IExplanationDriver$noncaching_park_explainer_BANG_$arity$6$($JSCompiler_temp$jscomp$330_driver$jscomp$5$$,
$explainer$jscomp$1$$,$regs$jscomp$5$$,$pos$jscomp$6$$,$coll$jscomp$910$$,$k$jscomp$282$$);else{var $m__5372__auto__$jscomp$inline_3222_m__5374__auto__$jscomp$inline_3221$$=$malli$impl$regex$noncaching_park_explainer_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$330_driver$jscomp$5$$==null?null:$JSCompiler_temp$jscomp$330_driver$jscomp$5$$)];if($m__5372__auto__$jscomp$inline_3222_m__5374__auto__$jscomp$inline_3221$$!=null)$JSCompiler_temp$jscomp$330_driver$jscomp$5$$=$m__5372__auto__$jscomp$inline_3222_m__5374__auto__$jscomp$inline_3221$$.$cljs$core$IFn$_invoke$arity$6$?
$m__5372__auto__$jscomp$inline_3222_m__5374__auto__$jscomp$inline_3221$$.$cljs$core$IFn$_invoke$arity$6$($JSCompiler_temp$jscomp$330_driver$jscomp$5$$,$explainer$jscomp$1$$,$regs$jscomp$5$$,$pos$jscomp$6$$,$coll$jscomp$910$$,$k$jscomp$282$$):$m__5372__auto__$jscomp$inline_3222_m__5374__auto__$jscomp$inline_3221$$($JSCompiler_temp$jscomp$330_driver$jscomp$5$$,$explainer$jscomp$1$$,$regs$jscomp$5$$,$pos$jscomp$6$$,$coll$jscomp$910$$,$k$jscomp$282$$);else if($m__5372__auto__$jscomp$inline_3222_m__5374__auto__$jscomp$inline_3221$$=
$malli$impl$regex$noncaching_park_explainer_BANG_$$._,$m__5372__auto__$jscomp$inline_3222_m__5374__auto__$jscomp$inline_3221$$!=null)$JSCompiler_temp$jscomp$330_driver$jscomp$5$$=$m__5372__auto__$jscomp$inline_3222_m__5374__auto__$jscomp$inline_3221$$.$cljs$core$IFn$_invoke$arity$6$?$m__5372__auto__$jscomp$inline_3222_m__5374__auto__$jscomp$inline_3221$$.$cljs$core$IFn$_invoke$arity$6$($JSCompiler_temp$jscomp$330_driver$jscomp$5$$,$explainer$jscomp$1$$,$regs$jscomp$5$$,$pos$jscomp$6$$,$coll$jscomp$910$$,
$k$jscomp$282$$):$m__5372__auto__$jscomp$inline_3222_m__5374__auto__$jscomp$inline_3221$$($JSCompiler_temp$jscomp$330_driver$jscomp$5$$,$explainer$jscomp$1$$,$regs$jscomp$5$$,$pos$jscomp$6$$,$coll$jscomp$910$$,$k$jscomp$282$$);else throw $APP.$cljs$core$missing_protocol$$("IExplanationDriver.noncaching-park-explainer!",$JSCompiler_temp$jscomp$330_driver$jscomp$5$$);}return $JSCompiler_temp$jscomp$330_driver$jscomp$5$$};
$malli$impl$regex$park_explainer_BANG_$$=function($JSCompiler_temp$jscomp$331_driver$jscomp$7$$,$explainer$jscomp$3$$,$regs$jscomp$7$$,$pos$jscomp$8$$,$coll$jscomp$912$$,$k$jscomp$284$$){if($JSCompiler_temp$jscomp$331_driver$jscomp$7$$!=null&&$JSCompiler_temp$jscomp$331_driver$jscomp$7$$.$malli$impl$regex$IExplanationDriver$park_explainer_BANG_$arity$6$!=null)$JSCompiler_temp$jscomp$331_driver$jscomp$7$$=$JSCompiler_temp$jscomp$331_driver$jscomp$7$$.$malli$impl$regex$IExplanationDriver$park_explainer_BANG_$arity$6$($JSCompiler_temp$jscomp$331_driver$jscomp$7$$,
$explainer$jscomp$3$$,$regs$jscomp$7$$,$pos$jscomp$8$$,$coll$jscomp$912$$,$k$jscomp$284$$);else{var $m__5372__auto__$jscomp$inline_3231_m__5374__auto__$jscomp$inline_3230$$=$malli$impl$regex$park_explainer_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$331_driver$jscomp$7$$==null?null:$JSCompiler_temp$jscomp$331_driver$jscomp$7$$)];if($m__5372__auto__$jscomp$inline_3231_m__5374__auto__$jscomp$inline_3230$$!=null)$JSCompiler_temp$jscomp$331_driver$jscomp$7$$=$m__5372__auto__$jscomp$inline_3231_m__5374__auto__$jscomp$inline_3230$$.$cljs$core$IFn$_invoke$arity$6$?
$m__5372__auto__$jscomp$inline_3231_m__5374__auto__$jscomp$inline_3230$$.$cljs$core$IFn$_invoke$arity$6$($JSCompiler_temp$jscomp$331_driver$jscomp$7$$,$explainer$jscomp$3$$,$regs$jscomp$7$$,$pos$jscomp$8$$,$coll$jscomp$912$$,$k$jscomp$284$$):$m__5372__auto__$jscomp$inline_3231_m__5374__auto__$jscomp$inline_3230$$($JSCompiler_temp$jscomp$331_driver$jscomp$7$$,$explainer$jscomp$3$$,$regs$jscomp$7$$,$pos$jscomp$8$$,$coll$jscomp$912$$,$k$jscomp$284$$);else if($m__5372__auto__$jscomp$inline_3231_m__5374__auto__$jscomp$inline_3230$$=
$malli$impl$regex$park_explainer_BANG_$$._,$m__5372__auto__$jscomp$inline_3231_m__5374__auto__$jscomp$inline_3230$$!=null)$JSCompiler_temp$jscomp$331_driver$jscomp$7$$=$m__5372__auto__$jscomp$inline_3231_m__5374__auto__$jscomp$inline_3230$$.$cljs$core$IFn$_invoke$arity$6$?$m__5372__auto__$jscomp$inline_3231_m__5374__auto__$jscomp$inline_3230$$.$cljs$core$IFn$_invoke$arity$6$($JSCompiler_temp$jscomp$331_driver$jscomp$7$$,$explainer$jscomp$3$$,$regs$jscomp$7$$,$pos$jscomp$8$$,$coll$jscomp$912$$,$k$jscomp$284$$):
$m__5372__auto__$jscomp$inline_3231_m__5374__auto__$jscomp$inline_3230$$($JSCompiler_temp$jscomp$331_driver$jscomp$7$$,$explainer$jscomp$3$$,$regs$jscomp$7$$,$pos$jscomp$8$$,$coll$jscomp$912$$,$k$jscomp$284$$);else throw $APP.$cljs$core$missing_protocol$$("IExplanationDriver.park-explainer!",$JSCompiler_temp$jscomp$331_driver$jscomp$7$$);}return $JSCompiler_temp$jscomp$331_driver$jscomp$7$$};
$malli$impl$regex$value_path$$=function($JSCompiler_temp$jscomp$332_self$jscomp$16$$,$pos$jscomp$10$$){if($JSCompiler_temp$jscomp$332_self$jscomp$16$$!=null&&$JSCompiler_temp$jscomp$332_self$jscomp$16$$.$malli$impl$regex$IExplanationDriver$value_path$arity$2$!=null)$JSCompiler_temp$jscomp$332_self$jscomp$16$$=$JSCompiler_temp$jscomp$332_self$jscomp$16$$.$malli$impl$regex$IExplanationDriver$value_path$arity$2$($JSCompiler_temp$jscomp$332_self$jscomp$16$$,$pos$jscomp$10$$);else{var $m__5372__auto__$jscomp$inline_3236_m__5374__auto__$jscomp$inline_3235$$=
$malli$impl$regex$value_path$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$332_self$jscomp$16$$==null?null:$JSCompiler_temp$jscomp$332_self$jscomp$16$$)];if($m__5372__auto__$jscomp$inline_3236_m__5374__auto__$jscomp$inline_3235$$!=null)$JSCompiler_temp$jscomp$332_self$jscomp$16$$=$m__5372__auto__$jscomp$inline_3236_m__5374__auto__$jscomp$inline_3235$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3236_m__5374__auto__$jscomp$inline_3235$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$332_self$jscomp$16$$,
$pos$jscomp$10$$):$m__5372__auto__$jscomp$inline_3236_m__5374__auto__$jscomp$inline_3235$$($JSCompiler_temp$jscomp$332_self$jscomp$16$$,$pos$jscomp$10$$);else if($m__5372__auto__$jscomp$inline_3236_m__5374__auto__$jscomp$inline_3235$$=$malli$impl$regex$value_path$$._,$m__5372__auto__$jscomp$inline_3236_m__5374__auto__$jscomp$inline_3235$$!=null)$JSCompiler_temp$jscomp$332_self$jscomp$16$$=$m__5372__auto__$jscomp$inline_3236_m__5374__auto__$jscomp$inline_3235$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3236_m__5374__auto__$jscomp$inline_3235$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$332_self$jscomp$16$$,
$pos$jscomp$10$$):$m__5372__auto__$jscomp$inline_3236_m__5374__auto__$jscomp$inline_3235$$($JSCompiler_temp$jscomp$332_self$jscomp$16$$,$pos$jscomp$10$$);else throw $APP.$cljs$core$missing_protocol$$("IExplanationDriver.value-path",$JSCompiler_temp$jscomp$332_self$jscomp$16$$);}return $JSCompiler_temp$jscomp$332_self$jscomp$16$$};
$malli$impl$regex$fail_BANG_$$=function($JSCompiler_temp$jscomp$333_self$jscomp$18$$,$pos$jscomp$12$$,$errors_STAR_$jscomp$1$$){if($JSCompiler_temp$jscomp$333_self$jscomp$18$$!=null&&$JSCompiler_temp$jscomp$333_self$jscomp$18$$.$malli$impl$regex$IExplanationDriver$fail_BANG_$arity$3$!=null)$JSCompiler_temp$jscomp$333_self$jscomp$18$$=$JSCompiler_temp$jscomp$333_self$jscomp$18$$.$malli$impl$regex$IExplanationDriver$fail_BANG_$arity$3$($JSCompiler_temp$jscomp$333_self$jscomp$18$$,$pos$jscomp$12$$,$errors_STAR_$jscomp$1$$);
else{var $m__5372__auto__$jscomp$inline_3242_m__5374__auto__$jscomp$inline_3241$$=$malli$impl$regex$fail_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$333_self$jscomp$18$$==null?null:$JSCompiler_temp$jscomp$333_self$jscomp$18$$)];if($m__5372__auto__$jscomp$inline_3242_m__5374__auto__$jscomp$inline_3241$$!=null)$JSCompiler_temp$jscomp$333_self$jscomp$18$$=$m__5372__auto__$jscomp$inline_3242_m__5374__auto__$jscomp$inline_3241$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_3242_m__5374__auto__$jscomp$inline_3241$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$333_self$jscomp$18$$,
$pos$jscomp$12$$,$errors_STAR_$jscomp$1$$):$m__5372__auto__$jscomp$inline_3242_m__5374__auto__$jscomp$inline_3241$$($JSCompiler_temp$jscomp$333_self$jscomp$18$$,$pos$jscomp$12$$,$errors_STAR_$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_3242_m__5374__auto__$jscomp$inline_3241$$=$malli$impl$regex$fail_BANG_$$._,$m__5372__auto__$jscomp$inline_3242_m__5374__auto__$jscomp$inline_3241$$!=null)$JSCompiler_temp$jscomp$333_self$jscomp$18$$=$m__5372__auto__$jscomp$inline_3242_m__5374__auto__$jscomp$inline_3241$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_3242_m__5374__auto__$jscomp$inline_3241$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$333_self$jscomp$18$$,$pos$jscomp$12$$,$errors_STAR_$jscomp$1$$):$m__5372__auto__$jscomp$inline_3242_m__5374__auto__$jscomp$inline_3241$$($JSCompiler_temp$jscomp$333_self$jscomp$18$$,$pos$jscomp$12$$,$errors_STAR_$jscomp$1$$);else throw $APP.$cljs$core$missing_protocol$$("IExplanationDriver.fail!",$JSCompiler_temp$jscomp$333_self$jscomp$18$$);}return $JSCompiler_temp$jscomp$333_self$jscomp$18$$};
$malli$impl$regex$noncaching_park_transformer_BANG_$$=function($JSCompiler_temp$jscomp$334_driver$jscomp$9$$,$transformer$jscomp$2$$,$regs$jscomp$9$$,$coll_STAR_$jscomp$1$$,$pos$jscomp$14$$,$coll$jscomp$914$$,$k$jscomp$286$$){if($JSCompiler_temp$jscomp$334_driver$jscomp$9$$!=null&&$JSCompiler_temp$jscomp$334_driver$jscomp$9$$.$malli$impl$regex$IParseDriver$noncaching_park_transformer_BANG_$arity$7$!=null)$JSCompiler_temp$jscomp$334_driver$jscomp$9$$=$JSCompiler_temp$jscomp$334_driver$jscomp$9$$.$malli$impl$regex$IParseDriver$noncaching_park_transformer_BANG_$arity$7$($JSCompiler_temp$jscomp$334_driver$jscomp$9$$,
$transformer$jscomp$2$$,$regs$jscomp$9$$,$coll_STAR_$jscomp$1$$,$pos$jscomp$14$$,$coll$jscomp$914$$,$k$jscomp$286$$);else{var $m__5372__auto__$jscomp$inline_3252_m__5374__auto__$jscomp$inline_3251$$=$malli$impl$regex$noncaching_park_transformer_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$334_driver$jscomp$9$$==null?null:$JSCompiler_temp$jscomp$334_driver$jscomp$9$$)];if($m__5372__auto__$jscomp$inline_3252_m__5374__auto__$jscomp$inline_3251$$!=null)$JSCompiler_temp$jscomp$334_driver$jscomp$9$$=
$m__5372__auto__$jscomp$inline_3252_m__5374__auto__$jscomp$inline_3251$$.$cljs$core$IFn$_invoke$arity$7$?$m__5372__auto__$jscomp$inline_3252_m__5374__auto__$jscomp$inline_3251$$.$cljs$core$IFn$_invoke$arity$7$($JSCompiler_temp$jscomp$334_driver$jscomp$9$$,$transformer$jscomp$2$$,$regs$jscomp$9$$,$coll_STAR_$jscomp$1$$,$pos$jscomp$14$$,$coll$jscomp$914$$,$k$jscomp$286$$):$m__5372__auto__$jscomp$inline_3252_m__5374__auto__$jscomp$inline_3251$$($JSCompiler_temp$jscomp$334_driver$jscomp$9$$,$transformer$jscomp$2$$,
$regs$jscomp$9$$,$coll_STAR_$jscomp$1$$,$pos$jscomp$14$$,$coll$jscomp$914$$,$k$jscomp$286$$);else if($m__5372__auto__$jscomp$inline_3252_m__5374__auto__$jscomp$inline_3251$$=$malli$impl$regex$noncaching_park_transformer_BANG_$$._,$m__5372__auto__$jscomp$inline_3252_m__5374__auto__$jscomp$inline_3251$$!=null)$JSCompiler_temp$jscomp$334_driver$jscomp$9$$=$m__5372__auto__$jscomp$inline_3252_m__5374__auto__$jscomp$inline_3251$$.$cljs$core$IFn$_invoke$arity$7$?$m__5372__auto__$jscomp$inline_3252_m__5374__auto__$jscomp$inline_3251$$.$cljs$core$IFn$_invoke$arity$7$($JSCompiler_temp$jscomp$334_driver$jscomp$9$$,
$transformer$jscomp$2$$,$regs$jscomp$9$$,$coll_STAR_$jscomp$1$$,$pos$jscomp$14$$,$coll$jscomp$914$$,$k$jscomp$286$$):$m__5372__auto__$jscomp$inline_3252_m__5374__auto__$jscomp$inline_3251$$($JSCompiler_temp$jscomp$334_driver$jscomp$9$$,$transformer$jscomp$2$$,$regs$jscomp$9$$,$coll_STAR_$jscomp$1$$,$pos$jscomp$14$$,$coll$jscomp$914$$,$k$jscomp$286$$);else throw $APP.$cljs$core$missing_protocol$$("IParseDriver.noncaching-park-transformer!",$JSCompiler_temp$jscomp$334_driver$jscomp$9$$);}return $JSCompiler_temp$jscomp$334_driver$jscomp$9$$};
$malli$impl$regex$park_transformer_BANG_$$=function($JSCompiler_temp$jscomp$335_driver$jscomp$11$$,$transformer$jscomp$4$$,$regs$jscomp$11$$,$coll_STAR_$jscomp$3$$,$pos$jscomp$16$$,$coll$jscomp$916$$,$k$jscomp$288$$){if($JSCompiler_temp$jscomp$335_driver$jscomp$11$$!=null&&$JSCompiler_temp$jscomp$335_driver$jscomp$11$$.$malli$impl$regex$IParseDriver$park_transformer_BANG_$arity$7$!=null)$JSCompiler_temp$jscomp$335_driver$jscomp$11$$=$JSCompiler_temp$jscomp$335_driver$jscomp$11$$.$malli$impl$regex$IParseDriver$park_transformer_BANG_$arity$7$($JSCompiler_temp$jscomp$335_driver$jscomp$11$$,
$transformer$jscomp$4$$,$regs$jscomp$11$$,$coll_STAR_$jscomp$3$$,$pos$jscomp$16$$,$coll$jscomp$916$$,$k$jscomp$288$$);else{var $m__5372__auto__$jscomp$inline_3262_m__5374__auto__$jscomp$inline_3261$$=$malli$impl$regex$park_transformer_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$335_driver$jscomp$11$$==null?null:$JSCompiler_temp$jscomp$335_driver$jscomp$11$$)];if($m__5372__auto__$jscomp$inline_3262_m__5374__auto__$jscomp$inline_3261$$!=null)$JSCompiler_temp$jscomp$335_driver$jscomp$11$$=$m__5372__auto__$jscomp$inline_3262_m__5374__auto__$jscomp$inline_3261$$.$cljs$core$IFn$_invoke$arity$7$?
$m__5372__auto__$jscomp$inline_3262_m__5374__auto__$jscomp$inline_3261$$.$cljs$core$IFn$_invoke$arity$7$($JSCompiler_temp$jscomp$335_driver$jscomp$11$$,$transformer$jscomp$4$$,$regs$jscomp$11$$,$coll_STAR_$jscomp$3$$,$pos$jscomp$16$$,$coll$jscomp$916$$,$k$jscomp$288$$):$m__5372__auto__$jscomp$inline_3262_m__5374__auto__$jscomp$inline_3261$$($JSCompiler_temp$jscomp$335_driver$jscomp$11$$,$transformer$jscomp$4$$,$regs$jscomp$11$$,$coll_STAR_$jscomp$3$$,$pos$jscomp$16$$,$coll$jscomp$916$$,$k$jscomp$288$$);
else if($m__5372__auto__$jscomp$inline_3262_m__5374__auto__$jscomp$inline_3261$$=$malli$impl$regex$park_transformer_BANG_$$._,$m__5372__auto__$jscomp$inline_3262_m__5374__auto__$jscomp$inline_3261$$!=null)$JSCompiler_temp$jscomp$335_driver$jscomp$11$$=$m__5372__auto__$jscomp$inline_3262_m__5374__auto__$jscomp$inline_3261$$.$cljs$core$IFn$_invoke$arity$7$?$m__5372__auto__$jscomp$inline_3262_m__5374__auto__$jscomp$inline_3261$$.$cljs$core$IFn$_invoke$arity$7$($JSCompiler_temp$jscomp$335_driver$jscomp$11$$,
$transformer$jscomp$4$$,$regs$jscomp$11$$,$coll_STAR_$jscomp$3$$,$pos$jscomp$16$$,$coll$jscomp$916$$,$k$jscomp$288$$):$m__5372__auto__$jscomp$inline_3262_m__5374__auto__$jscomp$inline_3261$$($JSCompiler_temp$jscomp$335_driver$jscomp$11$$,$transformer$jscomp$4$$,$regs$jscomp$11$$,$coll_STAR_$jscomp$3$$,$pos$jscomp$16$$,$coll$jscomp$916$$,$k$jscomp$288$$);else throw $APP.$cljs$core$missing_protocol$$("IParseDriver.park-transformer!",$JSCompiler_temp$jscomp$335_driver$jscomp$11$$);}return $JSCompiler_temp$jscomp$335_driver$jscomp$11$$};
$malli$impl$regex$item_validator$$=function($valid_QMARK_$$){return function($G__24941$jscomp$inline_3265_JSCompiler_inline_result$jscomp$336__$jscomp$211_and__5023__auto__$jscomp$inline_3264$$,$___$1$jscomp$61$$,$G__24942_pos$jscomp$17$$,$G__24943_coll$jscomp$917$$,$k$jscomp$289$$){if($G__24941$jscomp$inline_3265_JSCompiler_inline_result$jscomp$336__$jscomp$211_and__5023__auto__$jscomp$inline_3264$$=$APP.$cljs$core$seq$$($G__24943_coll$jscomp$917$$))$G__24941$jscomp$inline_3265_JSCompiler_inline_result$jscomp$336__$jscomp$211_and__5023__auto__$jscomp$inline_3264$$=
$APP.$cljs$core$first$$($G__24943_coll$jscomp$917$$),$G__24941$jscomp$inline_3265_JSCompiler_inline_result$jscomp$336__$jscomp$211_and__5023__auto__$jscomp$inline_3264$$=$valid_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$valid_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__24941$jscomp$inline_3265_JSCompiler_inline_result$jscomp$336__$jscomp$211_and__5023__auto__$jscomp$inline_3264$$):$valid_QMARK_$$($G__24941$jscomp$inline_3265_JSCompiler_inline_result$jscomp$336__$jscomp$211_and__5023__auto__$jscomp$inline_3264$$);
return $APP.$cljs$core$truth_$$($G__24941$jscomp$inline_3265_JSCompiler_inline_result$jscomp$336__$jscomp$211_and__5023__auto__$jscomp$inline_3264$$)?($G__24942_pos$jscomp$17$$+=1,$G__24943_coll$jscomp$917$$=$APP.$cljs$core$rest$$($G__24943_coll$jscomp$917$$),$k$jscomp$289$$.$cljs$core$IFn$_invoke$arity$2$?$k$jscomp$289$$.$cljs$core$IFn$_invoke$arity$2$($G__24942_pos$jscomp$17$$,$G__24943_coll$jscomp$917$$):$k$jscomp$289$$($G__24942_pos$jscomp$17$$,$G__24943_coll$jscomp$917$$)):null}};
$malli$impl$regex$item_explainer$$=function($path$jscomp$27$$,$schema$jscomp$2$$,$schema_explainer$$){return function($G__24948_driver$jscomp$12$$,$_$jscomp$212_errors$jscomp$1_in$$jscomp$8$$,$pos$jscomp$18$$,$G__24949_coll$jscomp$918$$,$k$jscomp$290$$){$_$jscomp$212_errors$jscomp$1_in$$jscomp$8$$=$malli$impl$regex$value_path$$($G__24948_driver$jscomp$12$$,$pos$jscomp$18$$);if($APP.$cljs$core$seq$$($G__24949_coll$jscomp$918$$)){var $G__24945$jscomp$inline_3267$$=$APP.$cljs$core$first$$($G__24949_coll$jscomp$918$$),
$G__24947$jscomp$inline_3268$$=$APP.$cljs$core$PersistentVector$EMPTY$$;$_$jscomp$212_errors$jscomp$1_in$$jscomp$8$$=$schema_explainer$$.$cljs$core$IFn$_invoke$arity$3$?$schema_explainer$$.$cljs$core$IFn$_invoke$arity$3$($G__24945$jscomp$inline_3267$$,$_$jscomp$212_errors$jscomp$1_in$$jscomp$8$$,$G__24947$jscomp$inline_3268$$):$schema_explainer$$($G__24945$jscomp$inline_3267$$,$_$jscomp$212_errors$jscomp$1_in$$jscomp$8$$,$G__24947$jscomp$inline_3268$$);if($APP.$cljs$core$seq$$($_$jscomp$212_errors$jscomp$1_in$$jscomp$8$$))return $malli$impl$regex$fail_BANG_$$($G__24948_driver$jscomp$12$$,
$pos$jscomp$18$$,$_$jscomp$212_errors$jscomp$1_in$$jscomp$8$$);$G__24948_driver$jscomp$12$$=$pos$jscomp$18$$+1;$G__24949_coll$jscomp$918$$=$APP.$cljs$core$rest$$($G__24949_coll$jscomp$918$$);return $k$jscomp$290$$.$cljs$core$IFn$_invoke$arity$2$?$k$jscomp$290$$.$cljs$core$IFn$_invoke$arity$2$($G__24948_driver$jscomp$12$$,$G__24949_coll$jscomp$918$$):$k$jscomp$290$$($G__24948_driver$jscomp$12$$,$G__24949_coll$jscomp$918$$)}return $malli$impl$regex$fail_BANG_$$($G__24948_driver$jscomp$12$$,$pos$jscomp$18$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($path$jscomp$27$$,$_$jscomp$212_errors$jscomp$1_in$$jscomp$8$$,$schema$jscomp$2$$,null,$cljs$cst$299$malli_DOT_core_SLASH_end_of_input$$)],null))}};
$malli$impl$regex$item_encoder$$=function($valid_QMARK_$jscomp$1$$,$encode$$){return function($_$jscomp$214_v$jscomp$161$$,$___$1$jscomp$63$$,$G__24959_coll_STAR_$jscomp$4$$,$G__24960_pos$jscomp$20$$,$G__24961_coll$jscomp$920$$,$k$jscomp$292$$){return $APP.$cljs$core$seq$$($G__24961_coll$jscomp$920$$)&&($_$jscomp$214_v$jscomp$161$$=$APP.$cljs$core$first$$($G__24961_coll$jscomp$920$$),$APP.$cljs$core$truth_$$($valid_QMARK_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$valid_QMARK_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$214_v$jscomp$161$$):
$valid_QMARK_$jscomp$1$$($_$jscomp$214_v$jscomp$161$$)))?($G__24959_coll_STAR_$jscomp$4$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__24959_coll_STAR_$jscomp$4$$,$encode$$.$cljs$core$IFn$_invoke$arity$1$?$encode$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$214_v$jscomp$161$$):$encode$$($_$jscomp$214_v$jscomp$161$$)),$G__24960_pos$jscomp$20$$+=1,$G__24961_coll$jscomp$920$$=$APP.$cljs$core$rest$$($G__24961_coll$jscomp$920$$),$k$jscomp$292$$.$cljs$core$IFn$_invoke$arity$3$?$k$jscomp$292$$.$cljs$core$IFn$_invoke$arity$3$($G__24959_coll_STAR_$jscomp$4$$,
$G__24960_pos$jscomp$20$$,$G__24961_coll$jscomp$920$$):$k$jscomp$292$$($G__24959_coll_STAR_$jscomp$4$$,$G__24960_pos$jscomp$20$$,$G__24961_coll$jscomp$920$$)):null}};
$malli$impl$regex$item_decoder$$=function($decode$jscomp$1$$,$valid_QMARK_$jscomp$2$$){return function($G__24967$jscomp$inline_3270__$jscomp$215_v$jscomp$162$$,$___$1$jscomp$64$$,$G__24968_coll_STAR_$jscomp$5$$,$G__24969_pos$jscomp$21$$,$G__24970_coll$jscomp$921$$,$k$jscomp$293$$){return $APP.$cljs$core$seq$$($G__24970_coll$jscomp$921$$)&&($G__24967$jscomp$inline_3270__$jscomp$215_v$jscomp$162$$=$APP.$cljs$core$first$$($G__24970_coll$jscomp$921$$),$G__24967$jscomp$inline_3270__$jscomp$215_v$jscomp$162$$=
$decode$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$decode$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__24967$jscomp$inline_3270__$jscomp$215_v$jscomp$162$$):$decode$jscomp$1$$($G__24967$jscomp$inline_3270__$jscomp$215_v$jscomp$162$$),$APP.$cljs$core$truth_$$($valid_QMARK_$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$valid_QMARK_$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__24967$jscomp$inline_3270__$jscomp$215_v$jscomp$162$$):$valid_QMARK_$jscomp$2$$($G__24967$jscomp$inline_3270__$jscomp$215_v$jscomp$162$$)))?
($G__24968_coll_STAR_$jscomp$5$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__24968_coll_STAR_$jscomp$5$$,$G__24967$jscomp$inline_3270__$jscomp$215_v$jscomp$162$$),$G__24969_pos$jscomp$21$$+=1,$G__24970_coll$jscomp$921$$=$APP.$cljs$core$rest$$($G__24970_coll$jscomp$921$$),$k$jscomp$293$$.$cljs$core$IFn$_invoke$arity$3$?$k$jscomp$293$$.$cljs$core$IFn$_invoke$arity$3$($G__24968_coll_STAR_$jscomp$5$$,$G__24969_pos$jscomp$21$$,$G__24970_coll$jscomp$921$$):$k$jscomp$293$$($G__24968_coll_STAR_$jscomp$5$$,
$G__24969_pos$jscomp$21$$,$G__24970_coll$jscomp$921$$)):null}};
$malli$impl$regex$item_transformer$$=function($G__24971__$1_method$jscomp$4$$,$validator$jscomp$7$$,$t$jscomp$24$$){$G__24971__$1_method$jscomp$4$$=$G__24971__$1_method$jscomp$4$$ instanceof $APP.$cljs$core$Keyword$$?$G__24971__$1_method$jscomp$4$$.$fqn$:null;switch($G__24971__$1_method$jscomp$4$$){case "encode":return $malli$impl$regex$item_encoder$$($validator$jscomp$7$$,$t$jscomp$24$$);case "decode":return $malli$impl$regex$item_decoder$$($t$jscomp$24$$,$validator$jscomp$7$$);default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__24971__$1_method$jscomp$4$$)].join(""));}};$malli$impl$regex$end_validator$$=function(){return function($_$jscomp$216$$,$___$1$jscomp$65$$,$pos$jscomp$22$$,$coll$jscomp$922$$,$k$jscomp$294$$){return $APP.$cljs$core$empty_QMARK_$$($coll$jscomp$922$$)?$k$jscomp$294$$.$cljs$core$IFn$_invoke$arity$2$?$k$jscomp$294$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$22$$,$coll$jscomp$922$$):$k$jscomp$294$$($pos$jscomp$22$$,$coll$jscomp$922$$):null}};
$malli$impl$regex$end_explainer$$=function($schema$jscomp$3$$,$path$jscomp$28$$){return function($driver$jscomp$13$$,$_$jscomp$217$$,$pos$jscomp$23$$,$coll$jscomp$923$$,$k$jscomp$295$$){return $APP.$cljs$core$empty_QMARK_$$($coll$jscomp$923$$)?$k$jscomp$295$$.$cljs$core$IFn$_invoke$arity$2$?$k$jscomp$295$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$23$$,$coll$jscomp$923$$):$k$jscomp$295$$($pos$jscomp$23$$,$coll$jscomp$923$$):$malli$impl$regex$fail_BANG_$$($driver$jscomp$13$$,$pos$jscomp$23$$,new $APP.$cljs$core$List$$(null,
$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($path$jscomp$28$$,$malli$impl$regex$value_path$$($driver$jscomp$13$$,$pos$jscomp$23$$),$schema$jscomp$3$$,$APP.$cljs$core$first$$($coll$jscomp$923$$),$cljs$cst$300$malli_DOT_core_SLASH_input_remaining$$),null,1,null))}};
$malli$impl$regex$end_transformer$$=function(){return function($_$jscomp$219$$,$___$1$jscomp$67$$,$coll_STAR_$jscomp$6$$,$pos$jscomp$25$$,$coll$jscomp$925$$,$k$jscomp$297$$){return $APP.$cljs$core$empty_QMARK_$$($coll$jscomp$925$$)?$k$jscomp$297$$.$cljs$core$IFn$_invoke$arity$3$?$k$jscomp$297$$.$cljs$core$IFn$_invoke$arity$3$($coll_STAR_$jscomp$6$$,$pos$jscomp$25$$,$coll$jscomp$925$$):$k$jscomp$297$$($coll_STAR_$jscomp$6$$,$pos$jscomp$25$$,$coll$jscomp$925$$):null}};
$malli$impl$regex$pure_parser$$=function(){return function($_$jscomp$220$$,$___$1$jscomp$68$$,$pos$jscomp$26$$,$coll$jscomp$926$$,$k$jscomp$298$$){return $k$jscomp$298$$.$cljs$core$IFn$_invoke$arity$3$?$k$jscomp$298$$.$cljs$core$IFn$_invoke$arity$3$(null,$pos$jscomp$26$$,$coll$jscomp$926$$):$k$jscomp$298$$(null,$pos$jscomp$26$$,$coll$jscomp$926$$)}};$malli$impl$regex$pure_unparser$$=function(){return $APP.$cljs$core$PersistentVector$EMPTY$$};
$malli$impl$regex$fmap_parser$$=function($f$jscomp$375$$,$p$jscomp$41$$){return function($driver$jscomp$14$$,$regs$jscomp$12$$,$pos$jscomp$27$$,$coll$jscomp$927$$,$k$jscomp$299$$){function $G__24979$$($G__24980_v$jscomp$164$$,$pos__$1$$,$coll__$1$jscomp$488$$){$G__24980_v$jscomp$164$$=$f$jscomp$375$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$375$$.$cljs$core$IFn$_invoke$arity$1$($G__24980_v$jscomp$164$$):$f$jscomp$375$$($G__24980_v$jscomp$164$$);return $k$jscomp$299$$.$cljs$core$IFn$_invoke$arity$3$?
$k$jscomp$299$$.$cljs$core$IFn$_invoke$arity$3$($G__24980_v$jscomp$164$$,$pos__$1$$,$coll__$1$jscomp$488$$):$k$jscomp$299$$($G__24980_v$jscomp$164$$,$pos__$1$$,$coll__$1$jscomp$488$$)}return $p$jscomp$41$$.$cljs$core$IFn$_invoke$arity$5$?$p$jscomp$41$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$14$$,$regs$jscomp$12$$,$pos$jscomp$27$$,$coll$jscomp$927$$,$G__24979$$):$p$jscomp$41$$($driver$jscomp$14$$,$regs$jscomp$12$$,$pos$jscomp$27$$,$coll$jscomp$927$$,$G__24979$$)}};
$malli$impl$regex$entry__GT_regex$$=function($_QMARK_kr$$){return $APP.$cljs$core$vector_QMARK_$$($_QMARK_kr$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_kr$$,1):$_QMARK_kr$$};
$malli$impl$regex$_STAR__validator$$=function($p$jscomp$47$$){var $_STAR_p_epsilon$$=$malli$impl$regex$cat_validator$$.$cljs$core$IFn$_invoke$arity$0$();return function $malli$impl$regex$_STAR__validator_$__STAR_p$$($driver$jscomp$27$$,$regs$jscomp$25$$,$pos$jscomp$47$$,$coll$jscomp$949$$,$k$jscomp$319$$){function $G__25239$$($pos__$1$jscomp$6$$,$coll__$1$jscomp$494$$){return $malli$impl$regex$park_validator_BANG_$$($driver$jscomp$27$$,$malli$impl$regex$_STAR__validator_$__STAR_p$$,$regs$jscomp$25$$,
$pos__$1$jscomp$6$$,$coll__$1$jscomp$494$$,$k$jscomp$319$$)}$malli$impl$regex$park_validator_BANG_$$($driver$jscomp$27$$,$_STAR_p_epsilon$$,$regs$jscomp$25$$,$pos$jscomp$47$$,$coll$jscomp$949$$,$k$jscomp$319$$);return $p$jscomp$47$$.$cljs$core$IFn$_invoke$arity$5$?$p$jscomp$47$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$27$$,$regs$jscomp$25$$,$pos$jscomp$47$$,$coll$jscomp$949$$,$G__25239$$):$p$jscomp$47$$($driver$jscomp$27$$,$regs$jscomp$25$$,$pos$jscomp$47$$,$coll$jscomp$949$$,$G__25239$$)}};
$malli$impl$regex$_STAR__explainer$$=function($p$jscomp$48$$){var $_STAR_p_epsilon$jscomp$1$$=$malli$impl$regex$cat_explainer$$.$cljs$core$IFn$_invoke$arity$0$();return function $malli$impl$regex$_STAR__explainer_$__STAR_p$$($driver$jscomp$28$$,$regs$jscomp$26$$,$pos$jscomp$48$$,$coll$jscomp$950$$,$k$jscomp$320$$){function $G__25245$$($pos__$1$jscomp$7$$,$coll__$1$jscomp$495$$){return $malli$impl$regex$park_explainer_BANG_$$($driver$jscomp$28$$,$malli$impl$regex$_STAR__explainer_$__STAR_p$$,$regs$jscomp$26$$,
$pos__$1$jscomp$7$$,$coll__$1$jscomp$495$$,$k$jscomp$320$$)}$malli$impl$regex$park_explainer_BANG_$$($driver$jscomp$28$$,$_STAR_p_epsilon$jscomp$1$$,$regs$jscomp$26$$,$pos$jscomp$48$$,$coll$jscomp$950$$,$k$jscomp$320$$);return $p$jscomp$48$$.$cljs$core$IFn$_invoke$arity$5$?$p$jscomp$48$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$28$$,$regs$jscomp$26$$,$pos$jscomp$48$$,$coll$jscomp$950$$,$G__25245$$):$p$jscomp$48$$($driver$jscomp$28$$,$regs$jscomp$26$$,$pos$jscomp$48$$,$coll$jscomp$950$$,$G__25245$$)}};
$malli$impl$regex$_STAR__parser$$=function($p$jscomp$49$$){function $_STAR_p_epsilon$jscomp$2$$($_$jscomp$230$$,$___$1$jscomp$76$$,$coll_STAR_$jscomp$12$$,$pos$jscomp$49$$,$coll$jscomp$951$$,$k$jscomp$321$$){return $k$jscomp$321$$.$cljs$core$IFn$_invoke$arity$3$?$k$jscomp$321$$.$cljs$core$IFn$_invoke$arity$3$($coll_STAR_$jscomp$12$$,$pos$jscomp$49$$,$coll$jscomp$951$$):$k$jscomp$321$$($coll_STAR_$jscomp$12$$,$pos$jscomp$49$$,$coll$jscomp$951$$)}return function(){function $malli$impl$regex$_STAR__parser_$__STAR_p__6$$($driver$jscomp$30$$,
$regs$jscomp$28$$,$coll_STAR_$jscomp$13$$,$pos$jscomp$51$$,$coll$jscomp$953$$,$k$jscomp$323$$){function $G__25255$$($v$jscomp$169$$,$pos__$1$jscomp$8$$,$coll__$1$jscomp$496$$){return $malli$impl$regex$park_transformer_BANG_$$($driver$jscomp$30$$,$malli$impl$regex$_STAR__parser_$__STAR_p$$,$regs$jscomp$28$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($coll_STAR_$jscomp$13$$,$v$jscomp$169$$),$pos__$1$jscomp$8$$,$coll__$1$jscomp$496$$,$k$jscomp$323$$)}$malli$impl$regex$park_transformer_BANG_$$($driver$jscomp$30$$,
$_STAR_p_epsilon$jscomp$2$$,$regs$jscomp$28$$,$coll_STAR_$jscomp$13$$,$pos$jscomp$51$$,$coll$jscomp$953$$,$k$jscomp$323$$);return $p$jscomp$49$$.$cljs$core$IFn$_invoke$arity$5$?$p$jscomp$49$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$30$$,$regs$jscomp$28$$,$pos$jscomp$51$$,$coll$jscomp$953$$,$G__25255$$):$p$jscomp$49$$($driver$jscomp$30$$,$regs$jscomp$28$$,$pos$jscomp$51$$,$coll$jscomp$953$$,$G__25255$$)}function $malli$impl$regex$_STAR__parser_$__STAR_p__5$$($driver$jscomp$29$$,$regs$jscomp$27$$,
$pos$jscomp$50$$,$coll$jscomp$952$$,$k$jscomp$322$$){return $malli$impl$regex$_STAR__parser_$__STAR_p$$.$cljs$core$IFn$_invoke$arity$6$($driver$jscomp$29$$,$regs$jscomp$27$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$pos$jscomp$50$$,$coll$jscomp$952$$,$k$jscomp$322$$)}var $malli$impl$regex$_STAR__parser_$__STAR_p$$=null;$malli$impl$regex$_STAR__parser_$__STAR_p$$=function($driver$jscomp$31$$,$regs$jscomp$29$$,$coll_STAR_$jscomp$14$$,$pos$jscomp$52$$,$coll$jscomp$954$$,$k$jscomp$324$$){switch(arguments.length){case 5:return $malli$impl$regex$_STAR__parser_$__STAR_p__5$$.call(this,
$driver$jscomp$31$$,$regs$jscomp$29$$,$coll_STAR_$jscomp$14$$,$pos$jscomp$52$$,$coll$jscomp$954$$);case 6:return $malli$impl$regex$_STAR__parser_$__STAR_p__6$$.call(this,$driver$jscomp$31$$,$regs$jscomp$29$$,$coll_STAR_$jscomp$14$$,$pos$jscomp$52$$,$coll$jscomp$954$$,$k$jscomp$324$$)}throw Error("Invalid arity: "+arguments.length);};$malli$impl$regex$_STAR__parser_$__STAR_p$$.$cljs$core$IFn$_invoke$arity$5$=$malli$impl$regex$_STAR__parser_$__STAR_p__5$$;$malli$impl$regex$_STAR__parser_$__STAR_p$$.$cljs$core$IFn$_invoke$arity$6$=
$malli$impl$regex$_STAR__parser_$__STAR_p__6$$;return $malli$impl$regex$_STAR__parser_$__STAR_p$$}()};
$malli$impl$regex$_STAR__unparser$$=function($up$jscomp$1$$){return function($v$jscomp$170$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$18$$,$result$jscomp$93_v__$1$jscomp$11$$){$result$jscomp$93_v__$1$jscomp$11$$=$up$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$up$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$93_v__$1$jscomp$11$$):$up$jscomp$1$$($result$jscomp$93_v__$1$jscomp$11$$);return $APP.$cljs$core$keyword_identical_QMARK_$$($result$jscomp$93_v__$1$jscomp$11$$,
$cljs$cst$295$malli_DOT_core_SLASH_invalid$$)?$APP.$cljs$core$reduced$$($result$jscomp$93_v__$1$jscomp$11$$):$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$18$$,$result$jscomp$93_v__$1$jscomp$11$$)},$APP.$cljs$core$PersistentVector$EMPTY$$,$v$jscomp$170$$)}};
$malli$impl$regex$_STAR__transformer$$=function($p$jscomp$50$$){var $_STAR_p_epsilon$jscomp$3$$=$malli$impl$regex$cat_transformer$$.$cljs$core$IFn$_invoke$arity$0$();return function $malli$impl$regex$_STAR__transformer_$__STAR_p$$($driver$jscomp$32$$,$regs$jscomp$30$$,$coll_STAR_$jscomp$15$$,$pos$jscomp$53$$,$coll$jscomp$955$$,$k$jscomp$325$$){function $G__25266$$($coll_STAR___$1$jscomp$1$$,$pos__$1$jscomp$9$$,$coll__$1$jscomp$497$$){return $malli$impl$regex$park_transformer_BANG_$$($driver$jscomp$32$$,
$malli$impl$regex$_STAR__transformer_$__STAR_p$$,$regs$jscomp$30$$,$coll_STAR___$1$jscomp$1$$,$pos__$1$jscomp$9$$,$coll__$1$jscomp$497$$,$k$jscomp$325$$)}$malli$impl$regex$park_transformer_BANG_$$($driver$jscomp$32$$,$_STAR_p_epsilon$jscomp$3$$,$regs$jscomp$30$$,$coll_STAR_$jscomp$15$$,$pos$jscomp$53$$,$coll$jscomp$955$$,$k$jscomp$325$$);return $p$jscomp$50$$.$cljs$core$IFn$_invoke$arity$6$?$p$jscomp$50$$.$cljs$core$IFn$_invoke$arity$6$($driver$jscomp$32$$,$regs$jscomp$30$$,$coll_STAR_$jscomp$15$$,
$pos$jscomp$53$$,$coll$jscomp$955$$,$G__25266$$):$p$jscomp$50$$($driver$jscomp$32$$,$regs$jscomp$30$$,$coll_STAR_$jscomp$15$$,$pos$jscomp$53$$,$coll$jscomp$955$$,$G__25266$$)}};
$malli$impl$regex$_PLUS__parser$$=function($p$jscomp$53$$){return $malli$impl$regex$fmap_parser$$(function($p__25272_vs$jscomp$2$$){var $v$jscomp$171$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__25272_vs$jscomp$2$$,0,null);$p__25272_vs$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__25272_vs$jscomp$2$$,1,null);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$v$jscomp$171$$],null),$p__25272_vs$jscomp$2$$)},$malli$impl$regex$cat_parser$$.$cljs$core$IFn$_invoke$arity$variadic$($p$jscomp$53$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$impl$regex$_STAR__parser$$($p$jscomp$53$$)])))};
$malli$impl$regex$_PLUS__unparser$$=function($up$jscomp$2$$){var $up_STAR_$$=$malli$impl$regex$_STAR__unparser$$($up$jscomp$2$$);return function($x$jscomp$700$$){return $APP.$cljs$core$vector_QMARK_$$($x$jscomp$700$$)&&1<=$APP.$cljs$core$count$$($x$jscomp$700$$)?$up_STAR_$$($x$jscomp$700$$):$cljs$cst$295$malli_DOT_core_SLASH_invalid$$}};
$malli$impl$regex$repeat_validator$$=function($min$jscomp$1$$,$max$jscomp$2$$,$p$jscomp$55$$){var $rep_epsilon$$=$malli$impl$regex$cat_validator$$.$cljs$core$IFn$_invoke$arity$0$(),$compulsories$$=function $malli$impl$regex$repeat_validator_$_compulsories$$($driver$jscomp$33$$,$regs$jscomp$31$$,$pos$jscomp$54$$,$coll$jscomp$956$$,$k$jscomp$326$$){if($APP.$cljs$core$peek$$($regs$jscomp$31$$)<$min$jscomp$1$$){var $G__25311$$=function($pos__$1$jscomp$10$$,$coll__$1$jscomp$498$$){return $malli$impl$regex$noncaching_park_validator_BANG_$$($driver$jscomp$33$$,
function($driver__$1$$,$stack$jscomp$5$$,$pos__$2$$,$coll__$2$jscomp$3$$,$k__$1$jscomp$3$$){return $malli$impl$regex$repeat_validator_$_compulsories$$($driver__$1$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pop$$($stack$jscomp$5$$),$APP.$cljs$core$peek$$($stack$jscomp$5$$)+1),$pos__$2$$,$coll__$2$jscomp$3$$,$k__$1$jscomp$3$$)},$regs$jscomp$31$$,$pos__$1$jscomp$10$$,$coll__$1$jscomp$498$$,$k$jscomp$326$$)};return $p$jscomp$55$$.$cljs$core$IFn$_invoke$arity$5$?$p$jscomp$55$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$33$$,
$regs$jscomp$31$$,$pos$jscomp$54$$,$coll$jscomp$956$$,$G__25311$$):$p$jscomp$55$$($driver$jscomp$33$$,$regs$jscomp$31$$,$pos$jscomp$54$$,$coll$jscomp$956$$,$G__25311$$)}return $optionals$$($driver$jscomp$33$$,$regs$jscomp$31$$,$pos$jscomp$54$$,$coll$jscomp$956$$,$k$jscomp$326$$)},$optionals$$=function $malli$impl$regex$repeat_validator_$_optionals$$($driver$jscomp$34$$,$regs$jscomp$32$$,$pos$jscomp$55$$,$coll$jscomp$957$$,$k$jscomp$327$$){if($APP.$cljs$core$peek$$($regs$jscomp$32$$)<$max$jscomp$2$$&&
$APP.$cljs$core$peek$$($regs$jscomp$32$$)<=$pos$jscomp$55$$&&$APP.$cljs$core$seq$$($coll$jscomp$957$$)){$malli$impl$regex$park_validator_BANG_$$($driver$jscomp$34$$,$rep_epsilon$$,$regs$jscomp$32$$,$pos$jscomp$55$$,$coll$jscomp$957$$,$k$jscomp$327$$);var $G__25320$$=function($pos__$1$jscomp$11$$,$coll__$1$jscomp$499$$){return $malli$impl$regex$park_validator_BANG_$$($driver$jscomp$34$$,function($driver__$1$jscomp$1$$,$regs__$1$$,$pos__$2$jscomp$1$$,$coll__$2$jscomp$4$$,$k__$1$jscomp$4$$){return $malli$impl$regex$repeat_validator_$_optionals$$($driver__$1$jscomp$1$$,
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pop$$($regs__$1$$),$APP.$cljs$core$peek$$($regs__$1$$)+1),$pos__$2$jscomp$1$$,$coll__$2$jscomp$4$$,$k__$1$jscomp$4$$)},$regs$jscomp$32$$,$pos__$1$jscomp$11$$,$coll__$1$jscomp$499$$,$k$jscomp$327$$)};return $p$jscomp$55$$.$cljs$core$IFn$_invoke$arity$5$?$p$jscomp$55$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$34$$,$regs$jscomp$32$$,$pos$jscomp$55$$,$coll$jscomp$957$$,$G__25320$$):$p$jscomp$55$$($driver$jscomp$34$$,$regs$jscomp$32$$,
$pos$jscomp$55$$,$coll$jscomp$957$$,$G__25320$$)}return $k$jscomp$327$$.$cljs$core$IFn$_invoke$arity$2$?$k$jscomp$327$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$55$$,$coll$jscomp$957$$):$k$jscomp$327$$($pos$jscomp$55$$,$coll$jscomp$957$$)};return function($driver$jscomp$35$$,$regs$jscomp$33$$,$pos$jscomp$56$$,$coll$jscomp$958$$,$k$jscomp$328$$){return $compulsories$$($driver$jscomp$35$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($regs$jscomp$33$$,0),$pos$jscomp$56$$,$coll$jscomp$958$$,
$k$jscomp$328$$)}};
$malli$impl$regex$repeat_explainer$$=function($min$jscomp$2$$,$max$jscomp$3$$,$p$jscomp$56$$){var $rep_epsilon$jscomp$1$$=$malli$impl$regex$cat_explainer$$.$cljs$core$IFn$_invoke$arity$0$(),$compulsories$jscomp$1$$=function $malli$impl$regex$repeat_explainer_$_compulsories$$($driver$jscomp$36$$,$regs$jscomp$34$$,$pos$jscomp$57$$,$coll$jscomp$959$$,$k$jscomp$329$$){if($APP.$cljs$core$peek$$($regs$jscomp$34$$)<$min$jscomp$2$$){var $G__25347$$=function($pos__$1$jscomp$12$$,$coll__$1$jscomp$500$$){return $malli$impl$regex$noncaching_park_explainer_BANG_$$($driver$jscomp$36$$,function($driver__$1$jscomp$2$$,
$regs__$1$jscomp$1$$,$pos__$2$jscomp$2$$,$coll__$2$jscomp$5$$,$k__$1$jscomp$5$$){return $malli$impl$regex$repeat_explainer_$_compulsories$$($driver__$1$jscomp$2$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pop$$($regs__$1$jscomp$1$$),$APP.$cljs$core$peek$$($regs__$1$jscomp$1$$)+1),$pos__$2$jscomp$2$$,$coll__$2$jscomp$5$$,$k__$1$jscomp$5$$)},$regs$jscomp$34$$,$pos__$1$jscomp$12$$,$coll__$1$jscomp$500$$,$k$jscomp$329$$)};return $p$jscomp$56$$.$cljs$core$IFn$_invoke$arity$5$?
$p$jscomp$56$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$36$$,$regs$jscomp$34$$,$pos$jscomp$57$$,$coll$jscomp$959$$,$G__25347$$):$p$jscomp$56$$($driver$jscomp$36$$,$regs$jscomp$34$$,$pos$jscomp$57$$,$coll$jscomp$959$$,$G__25347$$)}return $optionals$jscomp$1$$($driver$jscomp$36$$,$regs$jscomp$34$$,$pos$jscomp$57$$,$coll$jscomp$959$$,$k$jscomp$329$$)},$optionals$jscomp$1$$=function $malli$impl$regex$repeat_explainer_$_optionals$$($driver$jscomp$37$$,$regs$jscomp$35$$,$pos$jscomp$58$$,$coll$jscomp$960$$,
$k$jscomp$330$$){if($APP.$cljs$core$peek$$($regs$jscomp$35$$)<$max$jscomp$3$$&&$APP.$cljs$core$peek$$($regs$jscomp$35$$)<=$pos$jscomp$58$$&&$APP.$cljs$core$seq$$($coll$jscomp$960$$)){$malli$impl$regex$park_explainer_BANG_$$($driver$jscomp$37$$,$rep_epsilon$jscomp$1$$,$regs$jscomp$35$$,$pos$jscomp$58$$,$coll$jscomp$960$$,$k$jscomp$330$$);var $G__25354$$=function($pos__$1$jscomp$13$$,$coll__$1$jscomp$501$$){return $malli$impl$regex$park_explainer_BANG_$$($driver$jscomp$37$$,function($driver__$1$jscomp$3$$,
$regs__$1$jscomp$2$$,$pos__$2$jscomp$3$$,$coll__$2$jscomp$6$$,$k__$1$jscomp$6$$){return $malli$impl$regex$repeat_explainer_$_optionals$$($driver__$1$jscomp$3$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pop$$($regs__$1$jscomp$2$$),$APP.$cljs$core$peek$$($regs__$1$jscomp$2$$)+1),$pos__$2$jscomp$3$$,$coll__$2$jscomp$6$$,$k__$1$jscomp$6$$)},$regs$jscomp$35$$,$pos__$1$jscomp$13$$,$coll__$1$jscomp$501$$,$k$jscomp$330$$)};return $p$jscomp$56$$.$cljs$core$IFn$_invoke$arity$5$?
$p$jscomp$56$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$37$$,$regs$jscomp$35$$,$pos$jscomp$58$$,$coll$jscomp$960$$,$G__25354$$):$p$jscomp$56$$($driver$jscomp$37$$,$regs$jscomp$35$$,$pos$jscomp$58$$,$coll$jscomp$960$$,$G__25354$$)}return $k$jscomp$330$$.$cljs$core$IFn$_invoke$arity$2$?$k$jscomp$330$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$58$$,$coll$jscomp$960$$):$k$jscomp$330$$($pos$jscomp$58$$,$coll$jscomp$960$$)};return function($driver$jscomp$38$$,$regs$jscomp$36$$,$pos$jscomp$59$$,
$coll$jscomp$961$$,$k$jscomp$331$$){return $compulsories$jscomp$1$$($driver$jscomp$38$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($regs$jscomp$36$$,0),$pos$jscomp$59$$,$coll$jscomp$961$$,$k$jscomp$331$$)}};
$malli$impl$regex$repeat_parser$$=function($min$jscomp$3$$,$max$jscomp$4$$,$p$jscomp$57$$){function $rep_epsilon$jscomp$2$$($_$jscomp$231$$,$___$1$jscomp$77$$,$coll_STAR_$jscomp$16$$,$pos$jscomp$60$$,$coll$jscomp$962$$,$k$jscomp$332$$){return $k$jscomp$332$$.$cljs$core$IFn$_invoke$arity$3$?$k$jscomp$332$$.$cljs$core$IFn$_invoke$arity$3$($coll_STAR_$jscomp$16$$,$pos$jscomp$60$$,$coll$jscomp$962$$):$k$jscomp$332$$($coll_STAR_$jscomp$16$$,$pos$jscomp$60$$,$coll$jscomp$962$$)}var $compulsories$jscomp$2$$=
function $malli$impl$regex$repeat_parser_$_compulsories$$($driver$jscomp$39$$,$regs$jscomp$37$$,$coll_STAR_$jscomp$17$$,$pos$jscomp$61$$,$coll$jscomp$963$$,$k$jscomp$333$$){if($APP.$cljs$core$peek$$($regs$jscomp$37$$)<$min$jscomp$3$$){var $G__25380$$=function($v$jscomp$172$$,$pos__$1$jscomp$14$$,$coll__$1$jscomp$502$$){return $malli$impl$regex$noncaching_park_transformer_BANG_$$($driver$jscomp$39$$,function($driver__$1$jscomp$4$$,$regs__$1$jscomp$3$$,$coll_STAR___$1$jscomp$2$$,$pos__$2$jscomp$4$$,
$coll__$2$jscomp$7$$,$k__$1$jscomp$7$$){return $malli$impl$regex$repeat_parser_$_compulsories$$($driver__$1$jscomp$4$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pop$$($regs__$1$jscomp$3$$),$APP.$cljs$core$peek$$($regs__$1$jscomp$3$$)+1),$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($coll_STAR___$1$jscomp$2$$,$v$jscomp$172$$),$pos__$2$jscomp$4$$,$coll__$2$jscomp$7$$,$k__$1$jscomp$7$$)},$regs$jscomp$37$$,$coll_STAR_$jscomp$17$$,$pos__$1$jscomp$14$$,$coll__$1$jscomp$502$$,
$k$jscomp$333$$)};return $p$jscomp$57$$.$cljs$core$IFn$_invoke$arity$5$?$p$jscomp$57$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$39$$,$regs$jscomp$37$$,$pos$jscomp$61$$,$coll$jscomp$963$$,$G__25380$$):$p$jscomp$57$$($driver$jscomp$39$$,$regs$jscomp$37$$,$pos$jscomp$61$$,$coll$jscomp$963$$,$G__25380$$)}return $optionals$jscomp$2$$($driver$jscomp$39$$,$regs$jscomp$37$$,$coll_STAR_$jscomp$17$$,$pos$jscomp$61$$,$coll$jscomp$963$$,$k$jscomp$333$$)},$optionals$jscomp$2$$=function $malli$impl$regex$repeat_parser_$_optionals$$($driver$jscomp$40$$,
$regs$jscomp$38$$,$coll_STAR_$jscomp$18$$,$pos$jscomp$62$$,$coll$jscomp$964$$,$k$jscomp$334$$){if($APP.$cljs$core$peek$$($regs$jscomp$38$$)<$max$jscomp$4$$&&$APP.$cljs$core$peek$$($regs$jscomp$38$$)<=$pos$jscomp$62$$&&$APP.$cljs$core$seq$$($coll$jscomp$964$$)){$malli$impl$regex$park_transformer_BANG_$$($driver$jscomp$40$$,$rep_epsilon$jscomp$2$$,$regs$jscomp$38$$,$coll_STAR_$jscomp$18$$,$pos$jscomp$62$$,$coll$jscomp$964$$,$k$jscomp$334$$);var $G__25392$$=function($v$jscomp$173$$,$pos__$1$jscomp$15$$,
$coll__$1$jscomp$503$$){return $malli$impl$regex$park_transformer_BANG_$$($driver$jscomp$40$$,function($driver__$1$jscomp$5$$,$regs__$1$jscomp$4$$,$coll_STAR___$1$jscomp$3$$,$pos__$2$jscomp$5$$,$coll__$2$jscomp$8$$,$k__$1$jscomp$8$$){return $malli$impl$regex$repeat_parser_$_optionals$$($driver__$1$jscomp$5$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pop$$($regs__$1$jscomp$4$$),$APP.$cljs$core$peek$$($regs__$1$jscomp$4$$)+1),$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($coll_STAR___$1$jscomp$3$$,
$v$jscomp$173$$),$pos__$2$jscomp$5$$,$coll__$2$jscomp$8$$,$k__$1$jscomp$8$$)},$regs$jscomp$38$$,$coll_STAR_$jscomp$18$$,$pos__$1$jscomp$15$$,$coll__$1$jscomp$503$$,$k$jscomp$334$$)};return $p$jscomp$57$$.$cljs$core$IFn$_invoke$arity$5$?$p$jscomp$57$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$40$$,$regs$jscomp$38$$,$pos$jscomp$62$$,$coll$jscomp$964$$,$G__25392$$):$p$jscomp$57$$($driver$jscomp$40$$,$regs$jscomp$38$$,$pos$jscomp$62$$,$coll$jscomp$964$$,$G__25392$$)}return $k$jscomp$334$$.$cljs$core$IFn$_invoke$arity$3$?
$k$jscomp$334$$.$cljs$core$IFn$_invoke$arity$3$($coll_STAR_$jscomp$18$$,$pos$jscomp$62$$,$coll$jscomp$964$$):$k$jscomp$334$$($coll_STAR_$jscomp$18$$,$pos$jscomp$62$$,$coll$jscomp$964$$)};return function($driver$jscomp$41$$,$regs$jscomp$39$$,$pos$jscomp$63$$,$coll$jscomp$965$$,$k$jscomp$335$$){return $compulsories$jscomp$2$$($driver$jscomp$41$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($regs$jscomp$39$$,0),$APP.$cljs$core$PersistentVector$EMPTY$$,$pos$jscomp$63$$,$coll$jscomp$965$$,$k$jscomp$335$$)}};
$malli$impl$regex$repeat_unparser$$=function($min$jscomp$4$$,$max$jscomp$5$$,$up$jscomp$3$$){var $up_STAR_$jscomp$1$$=$malli$impl$regex$_STAR__unparser$$($up$jscomp$3$$);return function($v$jscomp$174$$){return $APP.$cljs$core$vector_QMARK_$$($v$jscomp$174$$)&&$min$jscomp$4$$<=$APP.$cljs$core$count$$($v$jscomp$174$$)&&$APP.$cljs$core$count$$($v$jscomp$174$$)<=$max$jscomp$5$$?$up_STAR_$jscomp$1$$($v$jscomp$174$$):$cljs$cst$295$malli_DOT_core_SLASH_invalid$$}};
$malli$impl$regex$repeat_transformer$$=function($min$jscomp$5$$,$max$jscomp$6$$,$p$jscomp$58$$){var $rep_epsilon$jscomp$3$$=$malli$impl$regex$cat_transformer$$.$cljs$core$IFn$_invoke$arity$0$(),$compulsories$jscomp$3$$=function $malli$impl$regex$repeat_transformer_$_compulsories$$($driver$jscomp$42$$,$regs$jscomp$40$$,$coll_STAR_$jscomp$19$$,$pos$jscomp$64$$,$coll$jscomp$966$$,$k$jscomp$336$$){if($APP.$cljs$core$peek$$($regs$jscomp$40$$)<$min$jscomp$5$$){var $G__25433$$=function($coll_STAR___$1$jscomp$4$$,
$pos__$1$jscomp$16$$,$coll__$1$jscomp$504$$){return $malli$impl$regex$noncaching_park_transformer_BANG_$$($driver$jscomp$42$$,function($driver__$1$jscomp$6$$,$regs__$1$jscomp$5$$,$coll_STAR___$2$$,$pos__$2$jscomp$6$$,$coll__$2$jscomp$9$$,$k__$1$jscomp$9$$){return $malli$impl$regex$repeat_transformer_$_compulsories$$($driver__$1$jscomp$6$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pop$$($regs__$1$jscomp$5$$),$APP.$cljs$core$peek$$($regs__$1$jscomp$5$$)+1),$coll_STAR___$2$$,
$pos__$2$jscomp$6$$,$coll__$2$jscomp$9$$,$k__$1$jscomp$9$$)},$regs$jscomp$40$$,$coll_STAR___$1$jscomp$4$$,$pos__$1$jscomp$16$$,$coll__$1$jscomp$504$$,$k$jscomp$336$$)};return $p$jscomp$58$$.$cljs$core$IFn$_invoke$arity$6$?$p$jscomp$58$$.$cljs$core$IFn$_invoke$arity$6$($driver$jscomp$42$$,$regs$jscomp$40$$,$coll_STAR_$jscomp$19$$,$pos$jscomp$64$$,$coll$jscomp$966$$,$G__25433$$):$p$jscomp$58$$($driver$jscomp$42$$,$regs$jscomp$40$$,$coll_STAR_$jscomp$19$$,$pos$jscomp$64$$,$coll$jscomp$966$$,$G__25433$$)}return $optionals$jscomp$3$$($driver$jscomp$42$$,
$regs$jscomp$40$$,$coll_STAR_$jscomp$19$$,$pos$jscomp$64$$,$coll$jscomp$966$$,$k$jscomp$336$$)},$optionals$jscomp$3$$=function $malli$impl$regex$repeat_transformer_$_optionals$$($driver$jscomp$43$$,$regs$jscomp$41$$,$coll_STAR_$jscomp$20$$,$pos$jscomp$65$$,$coll$jscomp$967$$,$k$jscomp$337$$){if($APP.$cljs$core$peek$$($regs$jscomp$41$$)<$max$jscomp$6$$&&$APP.$cljs$core$peek$$($regs$jscomp$41$$)<=$pos$jscomp$65$$&&$APP.$cljs$core$seq$$($coll$jscomp$967$$)){$malli$impl$regex$park_transformer_BANG_$$($driver$jscomp$43$$,
$rep_epsilon$jscomp$3$$,$regs$jscomp$41$$,$coll_STAR_$jscomp$20$$,$pos$jscomp$65$$,$coll$jscomp$967$$,$k$jscomp$337$$);var $G__25446$$=function($coll_STAR___$1$jscomp$5$$,$pos__$1$jscomp$17$$,$coll__$1$jscomp$505$$){return $malli$impl$regex$park_transformer_BANG_$$($driver$jscomp$43$$,function($driver__$1$jscomp$7$$,$regs__$1$jscomp$6$$,$coll_STAR___$2$jscomp$1$$,$pos__$2$jscomp$7$$,$coll__$2$jscomp$10$$,$k__$1$jscomp$10$$){return $malli$impl$regex$repeat_transformer_$_optionals$$($driver__$1$jscomp$7$$,
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pop$$($regs__$1$jscomp$6$$),$APP.$cljs$core$peek$$($regs__$1$jscomp$6$$)+1),$coll_STAR___$2$jscomp$1$$,$pos__$2$jscomp$7$$,$coll__$2$jscomp$10$$,$k__$1$jscomp$10$$)},$regs$jscomp$41$$,$coll_STAR___$1$jscomp$5$$,$pos__$1$jscomp$17$$,$coll__$1$jscomp$505$$,$k$jscomp$337$$)};return $p$jscomp$58$$.$cljs$core$IFn$_invoke$arity$6$?$p$jscomp$58$$.$cljs$core$IFn$_invoke$arity$6$($driver$jscomp$43$$,$regs$jscomp$41$$,$coll_STAR_$jscomp$20$$,
$pos$jscomp$65$$,$coll$jscomp$967$$,$G__25446$$):$p$jscomp$58$$($driver$jscomp$43$$,$regs$jscomp$41$$,$coll_STAR_$jscomp$20$$,$pos$jscomp$65$$,$coll$jscomp$967$$,$G__25446$$)}return $k$jscomp$337$$.$cljs$core$IFn$_invoke$arity$3$?$k$jscomp$337$$.$cljs$core$IFn$_invoke$arity$3$($coll_STAR_$jscomp$20$$,$pos$jscomp$65$$,$coll$jscomp$967$$):$k$jscomp$337$$($coll_STAR_$jscomp$20$$,$pos$jscomp$65$$,$coll$jscomp$967$$)};return function($driver$jscomp$44$$,$regs$jscomp$42$$,$coll_STAR_$jscomp$21$$,$pos$jscomp$66$$,
$coll$jscomp$968$$,$k$jscomp$338$$){return $compulsories$jscomp$3$$($driver$jscomp$44$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($regs$jscomp$42$$,0),$coll_STAR_$jscomp$21$$,$pos$jscomp$66$$,$coll$jscomp$968$$,$k$jscomp$338$$)}};
$malli$impl$regex$ensure_cached_BANG_$$=function($JSCompiler_temp$jscomp$337_cache$jscomp$1$$,$f$jscomp$377$$,$pos$jscomp$68$$,$regs$jscomp$44$$){if($JSCompiler_temp$jscomp$337_cache$jscomp$1$$!=null&&$JSCompiler_temp$jscomp$337_cache$jscomp$1$$.$malli$impl$regex$ICache$ensure_cached_BANG_$arity$4$!=null)$JSCompiler_temp$jscomp$337_cache$jscomp$1$$=$JSCompiler_temp$jscomp$337_cache$jscomp$1$$.$malli$impl$regex$ICache$ensure_cached_BANG_$arity$4$($JSCompiler_temp$jscomp$337_cache$jscomp$1$$,$f$jscomp$377$$,
$pos$jscomp$68$$,$regs$jscomp$44$$);else{var $m__5372__auto__$jscomp$inline_3279_m__5374__auto__$jscomp$inline_3278$$=$malli$impl$regex$ensure_cached_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$337_cache$jscomp$1$$==null?null:$JSCompiler_temp$jscomp$337_cache$jscomp$1$$)];if($m__5372__auto__$jscomp$inline_3279_m__5374__auto__$jscomp$inline_3278$$!=null)$JSCompiler_temp$jscomp$337_cache$jscomp$1$$=$m__5372__auto__$jscomp$inline_3279_m__5374__auto__$jscomp$inline_3278$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_3279_m__5374__auto__$jscomp$inline_3278$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$337_cache$jscomp$1$$,$f$jscomp$377$$,$pos$jscomp$68$$,$regs$jscomp$44$$):$m__5372__auto__$jscomp$inline_3279_m__5374__auto__$jscomp$inline_3278$$($JSCompiler_temp$jscomp$337_cache$jscomp$1$$,$f$jscomp$377$$,$pos$jscomp$68$$,$regs$jscomp$44$$);else if($m__5372__auto__$jscomp$inline_3279_m__5374__auto__$jscomp$inline_3278$$=$malli$impl$regex$ensure_cached_BANG_$$._,$m__5372__auto__$jscomp$inline_3279_m__5374__auto__$jscomp$inline_3278$$!=
null)$JSCompiler_temp$jscomp$337_cache$jscomp$1$$=$m__5372__auto__$jscomp$inline_3279_m__5374__auto__$jscomp$inline_3278$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_3279_m__5374__auto__$jscomp$inline_3278$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$337_cache$jscomp$1$$,$f$jscomp$377$$,$pos$jscomp$68$$,$regs$jscomp$44$$):$m__5372__auto__$jscomp$inline_3279_m__5374__auto__$jscomp$inline_3278$$($JSCompiler_temp$jscomp$337_cache$jscomp$1$$,$f$jscomp$377$$,$pos$jscomp$68$$,
$regs$jscomp$44$$);else throw $APP.$cljs$core$missing_protocol$$("ICache.ensure-cached!",$JSCompiler_temp$jscomp$337_cache$jscomp$1$$);}return $JSCompiler_temp$jscomp$337_cache$jscomp$1$$};$malli$impl$regex$CacheEntry$$=function($hash$jscomp$23$$,$f$jscomp$378$$,$pos$jscomp$69$$,$regs$jscomp$45$$){this.hash=$hash$jscomp$23$$;this.f=$f$jscomp$378$$;this.pos=$pos$jscomp$69$$;this.$regs$=$regs$jscomp$45$$};
$malli$impl$regex$Cache$$=function(){this.values=$cljs$core$object_array$cljs$0core$0IFn$0_invoke$0arity$01$$(2);this.size=0};$malli$impl$regex$CheckDriver$$=function(){var $cache$jscomp$2$$=new $malli$impl$regex$Cache$$;this.$success$=!1;this.stack=[];this.cache=$cache$jscomp$2$$};
$JSCompiler_StaticMethods_malli$impl$regex$Driver$pop_thunk_BANG_$arity$1$$=function($JSCompiler_StaticMethods_malli$impl$regex$Driver$pop_thunk_BANG_$arity$1$self$$){return $JSCompiler_StaticMethods_malli$impl$regex$Driver$pop_thunk_BANG_$arity$1$self$$.stack.length===0?null:$JSCompiler_StaticMethods_malli$impl$regex$Driver$pop_thunk_BANG_$arity$1$self$$.stack.pop()};
$malli$impl$regex$ParseDriver$$=function(){var $cache$jscomp$4$$=new $malli$impl$regex$Cache$$;this.$success$=!1;this.stack=[];this.cache=$cache$jscomp$4$$;this.result=null};
$malli$impl$regex$validator$$=function($p$jscomp$59$$){var $p__$1$$=$malli$impl$regex$cat_validator$$.$cljs$core$IFn$_invoke$arity$variadic$($p$jscomp$59$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$impl$regex$end_validator$$()]));return function($coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$){var $G__25529_25959_and__5023__auto__$jscomp$57$$=$APP.$cljs$core$sequential_QMARK_$$($coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$);
if($G__25529_25959_and__5023__auto__$jscomp$57$$){var $driver$jscomp$47$$=new $malli$impl$regex$CheckDriver$$;$G__25529_25959_and__5023__auto__$jscomp$57$$=function(){return $driver$jscomp$47$$.$success$=$APP.$cljs$core$boolean$0$$(!0)};$p__$1$$.$cljs$core$IFn$_invoke$arity$5$?$p__$1$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$47$$,$APP.$cljs$core$List$EMPTY$$,0,$coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$,$G__25529_25959_and__5023__auto__$jscomp$57$$):
$p__$1$$($driver$jscomp$47$$,$APP.$cljs$core$List$EMPTY$$,0,$coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$,$G__25529_25959_and__5023__auto__$jscomp$57$$);$coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$=$driver$jscomp$47$$.$success$;if($APP.$cljs$core$truth_$$($coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$))return $coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$;
for(;;){$coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$=$JSCompiler_StaticMethods_malli$impl$regex$Driver$pop_thunk_BANG_$arity$1$$($driver$jscomp$47$$);if($coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$==null)return!1;$coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$.$cljs$core$IFn$_invoke$arity$0$?$coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$.$cljs$core$IFn$_invoke$arity$0$():
$coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$();$coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$=$driver$jscomp$47$$.$success$;if($APP.$cljs$core$truth_$$($coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$))return $coll$jscomp$975_or__5025__auto__$jscomp$87_or__5025__auto____$1$jscomp$17_temp__5827__auto__$jscomp$7_thunk$$}}else return $G__25529_25959_and__5023__auto__$jscomp$57$$}};
$malli$impl$regex$ExplanationDriver$$=function($cache$jscomp$6$$,$in$$jscomp$9$$){var $errors$jscomp$2$$=$APP.$cljs$core$PersistentVector$EMPTY$$;this.$success$=!1;this.stack=[];this.cache=$cache$jscomp$6$$;this.$in$$=$in$$jscomp$9$$;this.$errors_max_pos$=0;this.errors=$errors$jscomp$2$$};
$malli$impl$regex$explainer$$=function($schema$jscomp$4$$,$path$jscomp$29$$,$p$jscomp$60$$){var $p__$1$jscomp$1$$=$malli$impl$regex$cat_explainer$$.$cljs$core$IFn$_invoke$arity$variadic$($p$jscomp$60$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$impl$regex$end_explainer$$($schema$jscomp$4$$,$path$jscomp$29$$)]));return function($coll$jscomp$978_temp__5827__auto__$jscomp$8_thunk$jscomp$1$$,$G__25603_25972_in$$jscomp$11$$,$errors$jscomp$4$$){if($APP.$cljs$core$sequential_QMARK_$$($coll$jscomp$978_temp__5827__auto__$jscomp$8_thunk$jscomp$1$$)){var $driver$jscomp$48$$=
new $malli$impl$regex$ExplanationDriver$$(new $malli$impl$regex$Cache$$,$G__25603_25972_in$$jscomp$11$$);$G__25603_25972_in$$jscomp$11$$=function(){return $driver$jscomp$48$$.$success$=$APP.$cljs$core$boolean$0$$(!0)};$p__$1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$5$?$p__$1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$48$$,$APP.$cljs$core$List$EMPTY$$,0,$coll$jscomp$978_temp__5827__auto__$jscomp$8_thunk$jscomp$1$$,$G__25603_25972_in$$jscomp$11$$):$p__$1$jscomp$1$$($driver$jscomp$48$$,
$APP.$cljs$core$List$EMPTY$$,0,$coll$jscomp$978_temp__5827__auto__$jscomp$8_thunk$jscomp$1$$,$G__25603_25972_in$$jscomp$11$$);if($APP.$cljs$core$truth_$$($driver$jscomp$48$$.$success$))return $errors$jscomp$4$$;for(;;){$coll$jscomp$978_temp__5827__auto__$jscomp$8_thunk$jscomp$1$$=$JSCompiler_StaticMethods_malli$impl$regex$Driver$pop_thunk_BANG_$arity$1$$($driver$jscomp$48$$);if($coll$jscomp$978_temp__5827__auto__$jscomp$8_thunk$jscomp$1$$==null)return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$4$$,
$driver$jscomp$48$$.errors);$coll$jscomp$978_temp__5827__auto__$jscomp$8_thunk$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$coll$jscomp$978_temp__5827__auto__$jscomp$8_thunk$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$coll$jscomp$978_temp__5827__auto__$jscomp$8_thunk$jscomp$1$$();if($APP.$cljs$core$truth_$$($driver$jscomp$48$$.$success$))return $errors$jscomp$4$$}}else return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$4$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($path$jscomp$29$$,
$G__25603_25972_in$$jscomp$11$$,$schema$jscomp$4$$,$coll$jscomp$978_temp__5827__auto__$jscomp$8_thunk$jscomp$1$$,$cljs$cst$315$malli_DOT_core_SLASH_invalid_type$$))}};
$malli$impl$regex$transformer$$=function($p$jscomp$62$$){var $p__$1$jscomp$3$$=$malli$impl$regex$cat_transformer$$.$cljs$core$IFn$_invoke$arity$variadic$($p$jscomp$62$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$impl$regex$end_transformer$$()]));return function($coll$jscomp$980$$){if($APP.$cljs$core$sequential_QMARK_$$($coll$jscomp$980$$)){var $driver$jscomp$50$$=new $malli$impl$regex$ParseDriver$$,$G__25637_25976_temp__5827__auto__$jscomp$10_thunk$jscomp$3$$=$APP.$cljs$core$PersistentVector$EMPTY$$,
$G__25640_25979$$=function($coll_STAR_$jscomp$24$$){$driver$jscomp$50$$.$success$=$APP.$cljs$core$boolean$0$$(!0);return $driver$jscomp$50$$.result=$coll_STAR_$jscomp$24$$};$p__$1$jscomp$3$$.$cljs$core$IFn$_invoke$arity$6$?$p__$1$jscomp$3$$.$cljs$core$IFn$_invoke$arity$6$($driver$jscomp$50$$,$APP.$cljs$core$List$EMPTY$$,$G__25637_25976_temp__5827__auto__$jscomp$10_thunk$jscomp$3$$,0,$coll$jscomp$980$$,$G__25640_25979$$):$p__$1$jscomp$3$$($driver$jscomp$50$$,$APP.$cljs$core$List$EMPTY$$,$G__25637_25976_temp__5827__auto__$jscomp$10_thunk$jscomp$3$$,
0,$coll$jscomp$980$$,$G__25640_25979$$);if($APP.$cljs$core$truth_$$($driver$jscomp$50$$.$success$))return $driver$jscomp$50$$.result;for(;;){$G__25637_25976_temp__5827__auto__$jscomp$10_thunk$jscomp$3$$=$JSCompiler_StaticMethods_malli$impl$regex$Driver$pop_thunk_BANG_$arity$1$$($driver$jscomp$50$$);if($G__25637_25976_temp__5827__auto__$jscomp$10_thunk$jscomp$3$$==null)return $coll$jscomp$980$$;$G__25637_25976_temp__5827__auto__$jscomp$10_thunk$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$G__25637_25976_temp__5827__auto__$jscomp$10_thunk$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():
$G__25637_25976_temp__5827__auto__$jscomp$10_thunk$jscomp$3$$();if($APP.$cljs$core$truth_$$($driver$jscomp$50$$.$success$))return $driver$jscomp$50$$.result}}else return $coll$jscomp$980$$}};$malli$registry$Registry$$=function(){};
$malli$registry$_schema$$=function($JSCompiler_temp$jscomp$342_this$$jscomp$159$$,$type$jscomp$181$$){if($JSCompiler_temp$jscomp$342_this$$jscomp$159$$!=null&&$JSCompiler_temp$jscomp$342_this$$jscomp$159$$.$malli$registry$Registry$_schema$arity$2$!=null)$JSCompiler_temp$jscomp$342_this$$jscomp$159$$=$JSCompiler_temp$jscomp$342_this$$jscomp$159$$.$malli$registry$Registry$_schema$arity$2$($JSCompiler_temp$jscomp$342_this$$jscomp$159$$,$type$jscomp$181$$);else{var $m__5372__auto__$jscomp$inline_3294_m__5374__auto__$jscomp$inline_3293$$=
$malli$registry$_schema$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$342_this$$jscomp$159$$==null?null:$JSCompiler_temp$jscomp$342_this$$jscomp$159$$)];if($m__5372__auto__$jscomp$inline_3294_m__5374__auto__$jscomp$inline_3293$$!=null)$JSCompiler_temp$jscomp$342_this$$jscomp$159$$=$m__5372__auto__$jscomp$inline_3294_m__5374__auto__$jscomp$inline_3293$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3294_m__5374__auto__$jscomp$inline_3293$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$342_this$$jscomp$159$$,
$type$jscomp$181$$):$m__5372__auto__$jscomp$inline_3294_m__5374__auto__$jscomp$inline_3293$$($JSCompiler_temp$jscomp$342_this$$jscomp$159$$,$type$jscomp$181$$);else if($m__5372__auto__$jscomp$inline_3294_m__5374__auto__$jscomp$inline_3293$$=$malli$registry$_schema$$._,$m__5372__auto__$jscomp$inline_3294_m__5374__auto__$jscomp$inline_3293$$!=null)$JSCompiler_temp$jscomp$342_this$$jscomp$159$$=$m__5372__auto__$jscomp$inline_3294_m__5374__auto__$jscomp$inline_3293$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3294_m__5374__auto__$jscomp$inline_3293$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$342_this$$jscomp$159$$,
$type$jscomp$181$$):$m__5372__auto__$jscomp$inline_3294_m__5374__auto__$jscomp$inline_3293$$($JSCompiler_temp$jscomp$342_this$$jscomp$159$$,$type$jscomp$181$$);else throw $APP.$cljs$core$missing_protocol$$("Registry.-schema",$JSCompiler_temp$jscomp$342_this$$jscomp$159$$);}return $JSCompiler_temp$jscomp$342_this$$jscomp$159$$};
$malli$registry$_schemas$$=function($JSCompiler_temp$jscomp$343_this$$jscomp$161$$){if($JSCompiler_temp$jscomp$343_this$$jscomp$161$$!=null&&$JSCompiler_temp$jscomp$343_this$$jscomp$161$$.$malli$registry$Registry$_schemas$arity$1$!=null)$JSCompiler_temp$jscomp$343_this$$jscomp$161$$=$JSCompiler_temp$jscomp$343_this$$jscomp$161$$.$malli$registry$Registry$_schemas$arity$1$($JSCompiler_temp$jscomp$343_this$$jscomp$161$$);else{var $m__5372__auto__$jscomp$inline_3298_m__5374__auto__$jscomp$inline_3297$$=
$malli$registry$_schemas$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$343_this$$jscomp$161$$==null?null:$JSCompiler_temp$jscomp$343_this$$jscomp$161$$)];if($m__5372__auto__$jscomp$inline_3298_m__5374__auto__$jscomp$inline_3297$$!=null)$JSCompiler_temp$jscomp$343_this$$jscomp$161$$=$m__5372__auto__$jscomp$inline_3298_m__5374__auto__$jscomp$inline_3297$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3298_m__5374__auto__$jscomp$inline_3297$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$343_this$$jscomp$161$$):
$m__5372__auto__$jscomp$inline_3298_m__5374__auto__$jscomp$inline_3297$$($JSCompiler_temp$jscomp$343_this$$jscomp$161$$);else if($m__5372__auto__$jscomp$inline_3298_m__5374__auto__$jscomp$inline_3297$$=$malli$registry$_schemas$$._,$m__5372__auto__$jscomp$inline_3298_m__5374__auto__$jscomp$inline_3297$$!=null)$JSCompiler_temp$jscomp$343_this$$jscomp$161$$=$m__5372__auto__$jscomp$inline_3298_m__5374__auto__$jscomp$inline_3297$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3298_m__5374__auto__$jscomp$inline_3297$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$343_this$$jscomp$161$$):
$m__5372__auto__$jscomp$inline_3298_m__5374__auto__$jscomp$inline_3297$$($JSCompiler_temp$jscomp$343_this$$jscomp$161$$);else throw $APP.$cljs$core$missing_protocol$$("Registry.-schemas",$JSCompiler_temp$jscomp$343_this$$jscomp$161$$);}return $JSCompiler_temp$jscomp$343_this$$jscomp$161$$};
$malli$registry$t_malli$0registry24964$$=function($m$jscomp$109$$,$fm$$,$meta24965$$){this.m=$m$jscomp$109$$;this.fm=$fm$$;this.$meta24965$=$meta24965$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};$malli$registry$t_malli$0registry24972$$=function($m$jscomp$112$$,$meta24973$$){this.m=$m$jscomp$112$$;this.$meta24973$=$meta24973$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$registry$registry$$=function($_QMARK_registry$$){return $_QMARK_registry$$==null?null:$_QMARK_registry$$!=null&&$APP.$cljs$core$PROTOCOL_SENTINEL$$===$_QMARK_registry$$.$malli$registry$Registry$$?$_QMARK_registry$$:$APP.$cljs$core$map_QMARK_$$($_QMARK_registry$$)?new $malli$registry$t_malli$0registry24972$$($_QMARK_registry$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$):($_QMARK_registry$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$_QMARK_registry$$.$malli$registry$Registry$$||($_QMARK_registry$$.$cljs$lang$protocol_mask$partition$$?
0:$APP.$cljs$core$native_satisfies_QMARK_$$($malli$registry$Registry$$,$_QMARK_registry$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($malli$registry$Registry$$,$_QMARK_registry$$))?$_QMARK_registry$$:null};$malli$registry$t_malli$0registry25009$$=function($meta25010$$){this.$meta25010$=$meta25010$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$registry$t_malli$0registry25037$$=function($_QMARK_registries$$,$registries$$,$meta25038$$){this.$_QMARK_registries$=$_QMARK_registries$$;this.$registries$=$registries$$;this.$meta25038$=$meta25038$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$registry$composite_registry$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($_QMARK_registries$jscomp$2$$){var $registries$jscomp$2$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($malli$registry$registry$$,$_QMARK_registries$jscomp$2$$);return new $malli$registry$t_malli$0registry25037$$($_QMARK_registries$jscomp$2$$,$registries$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$malli$registry$t_malli$0registry25073$$=function($db$jscomp$1$$,$meta25074$$){this.db=$db$jscomp$1$$;this.$meta25074$=$meta25074$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};$malli$registry$t_malli$0registry25109$$=function($meta25110$$){this.$meta25110$=$meta25110$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$borkdude$dynaload$LazyVar$$=function($f$jscomp$381$$){this.f=$f$jscomp$381$$;this.$cached$=null;this.$cljs$lang$protocol_mask$partition0$$=32769;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$_type$$=function($JSCompiler_temp$jscomp$344_this$$jscomp$185$$){if($JSCompiler_temp$jscomp$344_this$$jscomp$185$$!=null&&$JSCompiler_temp$jscomp$344_this$$jscomp$185$$.$malli$core$IntoSchema$_type$arity$1$!=null)$JSCompiler_temp$jscomp$344_this$$jscomp$185$$=$JSCompiler_temp$jscomp$344_this$$jscomp$185$$.$malli$core$IntoSchema$_type$arity$1$($JSCompiler_temp$jscomp$344_this$$jscomp$185$$);else{var $m__5372__auto__$jscomp$inline_3302_m__5374__auto__$jscomp$inline_3301$$=$malli$core$_type$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$344_this$$jscomp$185$$==
null?null:$JSCompiler_temp$jscomp$344_this$$jscomp$185$$)];if($m__5372__auto__$jscomp$inline_3302_m__5374__auto__$jscomp$inline_3301$$!=null)$JSCompiler_temp$jscomp$344_this$$jscomp$185$$=$m__5372__auto__$jscomp$inline_3302_m__5374__auto__$jscomp$inline_3301$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3302_m__5374__auto__$jscomp$inline_3301$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$344_this$$jscomp$185$$):$m__5372__auto__$jscomp$inline_3302_m__5374__auto__$jscomp$inline_3301$$($JSCompiler_temp$jscomp$344_this$$jscomp$185$$);
else if($m__5372__auto__$jscomp$inline_3302_m__5374__auto__$jscomp$inline_3301$$=$malli$core$_type$$._,$m__5372__auto__$jscomp$inline_3302_m__5374__auto__$jscomp$inline_3301$$!=null)$JSCompiler_temp$jscomp$344_this$$jscomp$185$$=$m__5372__auto__$jscomp$inline_3302_m__5374__auto__$jscomp$inline_3301$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3302_m__5374__auto__$jscomp$inline_3301$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$344_this$$jscomp$185$$):$m__5372__auto__$jscomp$inline_3302_m__5374__auto__$jscomp$inline_3301$$($JSCompiler_temp$jscomp$344_this$$jscomp$185$$);
else throw $APP.$cljs$core$missing_protocol$$("IntoSchema.-type",$JSCompiler_temp$jscomp$344_this$$jscomp$185$$);}return $JSCompiler_temp$jscomp$344_this$$jscomp$185$$};
$malli$core$_type_properties$$=function($JSCompiler_temp$jscomp$345_this$$jscomp$187$$){if($JSCompiler_temp$jscomp$345_this$$jscomp$187$$!=null&&$JSCompiler_temp$jscomp$345_this$$jscomp$187$$.$malli$core$IntoSchema$_type_properties$arity$1$!=null)$JSCompiler_temp$jscomp$345_this$$jscomp$187$$=$JSCompiler_temp$jscomp$345_this$$jscomp$187$$.$malli$core$IntoSchema$_type_properties$arity$1$($JSCompiler_temp$jscomp$345_this$$jscomp$187$$);else{var $m__5372__auto__$jscomp$inline_3306_m__5374__auto__$jscomp$inline_3305$$=
$malli$core$_type_properties$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$345_this$$jscomp$187$$==null?null:$JSCompiler_temp$jscomp$345_this$$jscomp$187$$)];if($m__5372__auto__$jscomp$inline_3306_m__5374__auto__$jscomp$inline_3305$$!=null)$JSCompiler_temp$jscomp$345_this$$jscomp$187$$=$m__5372__auto__$jscomp$inline_3306_m__5374__auto__$jscomp$inline_3305$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3306_m__5374__auto__$jscomp$inline_3305$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$345_this$$jscomp$187$$):
$m__5372__auto__$jscomp$inline_3306_m__5374__auto__$jscomp$inline_3305$$($JSCompiler_temp$jscomp$345_this$$jscomp$187$$);else if($m__5372__auto__$jscomp$inline_3306_m__5374__auto__$jscomp$inline_3305$$=$malli$core$_type_properties$$._,$m__5372__auto__$jscomp$inline_3306_m__5374__auto__$jscomp$inline_3305$$!=null)$JSCompiler_temp$jscomp$345_this$$jscomp$187$$=$m__5372__auto__$jscomp$inline_3306_m__5374__auto__$jscomp$inline_3305$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3306_m__5374__auto__$jscomp$inline_3305$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$345_this$$jscomp$187$$):
$m__5372__auto__$jscomp$inline_3306_m__5374__auto__$jscomp$inline_3305$$($JSCompiler_temp$jscomp$345_this$$jscomp$187$$);else throw $APP.$cljs$core$missing_protocol$$("IntoSchema.-type-properties",$JSCompiler_temp$jscomp$345_this$$jscomp$187$$);}return $JSCompiler_temp$jscomp$345_this$$jscomp$187$$};
$malli$core$_into_schema$$=function($JSCompiler_temp$jscomp$346_this$$jscomp$193$$,$properties$jscomp$5$$,$children$jscomp$4$$,$options$jscomp$85$$){if($JSCompiler_temp$jscomp$346_this$$jscomp$193$$!=null&&$JSCompiler_temp$jscomp$346_this$$jscomp$193$$.$malli$core$IntoSchema$_into_schema$arity$4$!=null)$JSCompiler_temp$jscomp$346_this$$jscomp$193$$=$JSCompiler_temp$jscomp$346_this$$jscomp$193$$.$malli$core$IntoSchema$_into_schema$arity$4$($JSCompiler_temp$jscomp$346_this$$jscomp$193$$,$properties$jscomp$5$$,
$children$jscomp$4$$,$options$jscomp$85$$);else{var $m__5372__auto__$jscomp$inline_3313_m__5374__auto__$jscomp$inline_3312$$=$malli$core$_into_schema$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$346_this$$jscomp$193$$==null?null:$JSCompiler_temp$jscomp$346_this$$jscomp$193$$)];if($m__5372__auto__$jscomp$inline_3313_m__5374__auto__$jscomp$inline_3312$$!=null)$JSCompiler_temp$jscomp$346_this$$jscomp$193$$=$m__5372__auto__$jscomp$inline_3313_m__5374__auto__$jscomp$inline_3312$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_3313_m__5374__auto__$jscomp$inline_3312$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$346_this$$jscomp$193$$,$properties$jscomp$5$$,$children$jscomp$4$$,$options$jscomp$85$$):$m__5372__auto__$jscomp$inline_3313_m__5374__auto__$jscomp$inline_3312$$($JSCompiler_temp$jscomp$346_this$$jscomp$193$$,$properties$jscomp$5$$,$children$jscomp$4$$,$options$jscomp$85$$);else if($m__5372__auto__$jscomp$inline_3313_m__5374__auto__$jscomp$inline_3312$$=$malli$core$_into_schema$$._,
$m__5372__auto__$jscomp$inline_3313_m__5374__auto__$jscomp$inline_3312$$!=null)$JSCompiler_temp$jscomp$346_this$$jscomp$193$$=$m__5372__auto__$jscomp$inline_3313_m__5374__auto__$jscomp$inline_3312$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_3313_m__5374__auto__$jscomp$inline_3312$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$346_this$$jscomp$193$$,$properties$jscomp$5$$,$children$jscomp$4$$,$options$jscomp$85$$):$m__5372__auto__$jscomp$inline_3313_m__5374__auto__$jscomp$inline_3312$$($JSCompiler_temp$jscomp$346_this$$jscomp$193$$,
$properties$jscomp$5$$,$children$jscomp$4$$,$options$jscomp$85$$);else throw $APP.$cljs$core$missing_protocol$$("IntoSchema.-into-schema",$JSCompiler_temp$jscomp$346_this$$jscomp$193$$);}return $JSCompiler_temp$jscomp$346_this$$jscomp$193$$};
$malli$core$_validator$$=function($JSCompiler_temp$jscomp$347_this$$jscomp$195$$){if($JSCompiler_temp$jscomp$347_this$$jscomp$195$$!=null&&$JSCompiler_temp$jscomp$347_this$$jscomp$195$$.$malli$core$Schema$_validator$arity$1$!=null)$JSCompiler_temp$jscomp$347_this$$jscomp$195$$=$JSCompiler_temp$jscomp$347_this$$jscomp$195$$.$malli$core$Schema$_validator$arity$1$($JSCompiler_temp$jscomp$347_this$$jscomp$195$$);else{var $m__5372__auto__$jscomp$inline_3317_m__5374__auto__$jscomp$inline_3316$$=$malli$core$_validator$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$347_this$$jscomp$195$$==
null?null:$JSCompiler_temp$jscomp$347_this$$jscomp$195$$)];if($m__5372__auto__$jscomp$inline_3317_m__5374__auto__$jscomp$inline_3316$$!=null)$JSCompiler_temp$jscomp$347_this$$jscomp$195$$=$m__5372__auto__$jscomp$inline_3317_m__5374__auto__$jscomp$inline_3316$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3317_m__5374__auto__$jscomp$inline_3316$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$347_this$$jscomp$195$$):$m__5372__auto__$jscomp$inline_3317_m__5374__auto__$jscomp$inline_3316$$($JSCompiler_temp$jscomp$347_this$$jscomp$195$$);
else if($m__5372__auto__$jscomp$inline_3317_m__5374__auto__$jscomp$inline_3316$$=$malli$core$_validator$$._,$m__5372__auto__$jscomp$inline_3317_m__5374__auto__$jscomp$inline_3316$$!=null)$JSCompiler_temp$jscomp$347_this$$jscomp$195$$=$m__5372__auto__$jscomp$inline_3317_m__5374__auto__$jscomp$inline_3316$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3317_m__5374__auto__$jscomp$inline_3316$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$347_this$$jscomp$195$$):$m__5372__auto__$jscomp$inline_3317_m__5374__auto__$jscomp$inline_3316$$($JSCompiler_temp$jscomp$347_this$$jscomp$195$$);
else throw $APP.$cljs$core$missing_protocol$$("Schema.-validator",$JSCompiler_temp$jscomp$347_this$$jscomp$195$$);}return $JSCompiler_temp$jscomp$347_this$$jscomp$195$$};
$malli$core$_explainer$$=function($JSCompiler_temp$jscomp$348_this$$jscomp$197$$,$path$jscomp$31$$){if($JSCompiler_temp$jscomp$348_this$$jscomp$197$$!=null&&$JSCompiler_temp$jscomp$348_this$$jscomp$197$$.$malli$core$Schema$_explainer$arity$2$!=null)$JSCompiler_temp$jscomp$348_this$$jscomp$197$$=$JSCompiler_temp$jscomp$348_this$$jscomp$197$$.$malli$core$Schema$_explainer$arity$2$($JSCompiler_temp$jscomp$348_this$$jscomp$197$$,$path$jscomp$31$$);else{var $m__5372__auto__$jscomp$inline_3322_m__5374__auto__$jscomp$inline_3321$$=
$malli$core$_explainer$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$348_this$$jscomp$197$$==null?null:$JSCompiler_temp$jscomp$348_this$$jscomp$197$$)];if($m__5372__auto__$jscomp$inline_3322_m__5374__auto__$jscomp$inline_3321$$!=null)$JSCompiler_temp$jscomp$348_this$$jscomp$197$$=$m__5372__auto__$jscomp$inline_3322_m__5374__auto__$jscomp$inline_3321$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3322_m__5374__auto__$jscomp$inline_3321$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$348_this$$jscomp$197$$,
$path$jscomp$31$$):$m__5372__auto__$jscomp$inline_3322_m__5374__auto__$jscomp$inline_3321$$($JSCompiler_temp$jscomp$348_this$$jscomp$197$$,$path$jscomp$31$$);else if($m__5372__auto__$jscomp$inline_3322_m__5374__auto__$jscomp$inline_3321$$=$malli$core$_explainer$$._,$m__5372__auto__$jscomp$inline_3322_m__5374__auto__$jscomp$inline_3321$$!=null)$JSCompiler_temp$jscomp$348_this$$jscomp$197$$=$m__5372__auto__$jscomp$inline_3322_m__5374__auto__$jscomp$inline_3321$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3322_m__5374__auto__$jscomp$inline_3321$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$348_this$$jscomp$197$$,
$path$jscomp$31$$):$m__5372__auto__$jscomp$inline_3322_m__5374__auto__$jscomp$inline_3321$$($JSCompiler_temp$jscomp$348_this$$jscomp$197$$,$path$jscomp$31$$);else throw $APP.$cljs$core$missing_protocol$$("Schema.-explainer",$JSCompiler_temp$jscomp$348_this$$jscomp$197$$);}return $JSCompiler_temp$jscomp$348_this$$jscomp$197$$};
$malli$core$_transformer$$=function($JSCompiler_temp$jscomp$349_this$$jscomp$203$$,$transformer$jscomp$8$$,$method$jscomp$6$$,$options$jscomp$87$$){if($JSCompiler_temp$jscomp$349_this$$jscomp$203$$!=null&&$JSCompiler_temp$jscomp$349_this$$jscomp$203$$.$malli$core$Schema$_transformer$arity$4$!=null)$JSCompiler_temp$jscomp$349_this$$jscomp$203$$=$JSCompiler_temp$jscomp$349_this$$jscomp$203$$.$malli$core$Schema$_transformer$arity$4$($JSCompiler_temp$jscomp$349_this$$jscomp$203$$,$transformer$jscomp$8$$,
$method$jscomp$6$$,$options$jscomp$87$$);else{var $m__5372__auto__$jscomp$inline_3329_m__5374__auto__$jscomp$inline_3328$$=$malli$core$_transformer$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$349_this$$jscomp$203$$==null?null:$JSCompiler_temp$jscomp$349_this$$jscomp$203$$)];if($m__5372__auto__$jscomp$inline_3329_m__5374__auto__$jscomp$inline_3328$$!=null)$JSCompiler_temp$jscomp$349_this$$jscomp$203$$=$m__5372__auto__$jscomp$inline_3329_m__5374__auto__$jscomp$inline_3328$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_3329_m__5374__auto__$jscomp$inline_3328$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$349_this$$jscomp$203$$,$transformer$jscomp$8$$,$method$jscomp$6$$,$options$jscomp$87$$):$m__5372__auto__$jscomp$inline_3329_m__5374__auto__$jscomp$inline_3328$$($JSCompiler_temp$jscomp$349_this$$jscomp$203$$,$transformer$jscomp$8$$,$method$jscomp$6$$,$options$jscomp$87$$);else if($m__5372__auto__$jscomp$inline_3329_m__5374__auto__$jscomp$inline_3328$$=$malli$core$_transformer$$._,
$m__5372__auto__$jscomp$inline_3329_m__5374__auto__$jscomp$inline_3328$$!=null)$JSCompiler_temp$jscomp$349_this$$jscomp$203$$=$m__5372__auto__$jscomp$inline_3329_m__5374__auto__$jscomp$inline_3328$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_3329_m__5374__auto__$jscomp$inline_3328$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$349_this$$jscomp$203$$,$transformer$jscomp$8$$,$method$jscomp$6$$,$options$jscomp$87$$):$m__5372__auto__$jscomp$inline_3329_m__5374__auto__$jscomp$inline_3328$$($JSCompiler_temp$jscomp$349_this$$jscomp$203$$,
$transformer$jscomp$8$$,$method$jscomp$6$$,$options$jscomp$87$$);else throw $APP.$cljs$core$missing_protocol$$("Schema.-transformer",$JSCompiler_temp$jscomp$349_this$$jscomp$203$$);}return $JSCompiler_temp$jscomp$349_this$$jscomp$203$$};
$malli$core$_walk$$=function($JSCompiler_temp$jscomp$350_this$$jscomp$205$$,$walker$jscomp$1$$,$path$jscomp$33$$,$options$jscomp$89$$){if($JSCompiler_temp$jscomp$350_this$$jscomp$205$$!=null&&$JSCompiler_temp$jscomp$350_this$$jscomp$205$$.$malli$core$Schema$_walk$arity$4$!=null)$JSCompiler_temp$jscomp$350_this$$jscomp$205$$=$JSCompiler_temp$jscomp$350_this$$jscomp$205$$.$malli$core$Schema$_walk$arity$4$($JSCompiler_temp$jscomp$350_this$$jscomp$205$$,$walker$jscomp$1$$,$path$jscomp$33$$,$options$jscomp$89$$);
else{var $m__5372__auto__$jscomp$inline_3336_m__5374__auto__$jscomp$inline_3335$$=$malli$core$_walk$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$350_this$$jscomp$205$$==null?null:$JSCompiler_temp$jscomp$350_this$$jscomp$205$$)];if($m__5372__auto__$jscomp$inline_3336_m__5374__auto__$jscomp$inline_3335$$!=null)$JSCompiler_temp$jscomp$350_this$$jscomp$205$$=$m__5372__auto__$jscomp$inline_3336_m__5374__auto__$jscomp$inline_3335$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_3336_m__5374__auto__$jscomp$inline_3335$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$350_this$$jscomp$205$$,
$walker$jscomp$1$$,$path$jscomp$33$$,$options$jscomp$89$$):$m__5372__auto__$jscomp$inline_3336_m__5374__auto__$jscomp$inline_3335$$($JSCompiler_temp$jscomp$350_this$$jscomp$205$$,$walker$jscomp$1$$,$path$jscomp$33$$,$options$jscomp$89$$);else if($m__5372__auto__$jscomp$inline_3336_m__5374__auto__$jscomp$inline_3335$$=$malli$core$_walk$$._,$m__5372__auto__$jscomp$inline_3336_m__5374__auto__$jscomp$inline_3335$$!=null)$JSCompiler_temp$jscomp$350_this$$jscomp$205$$=$m__5372__auto__$jscomp$inline_3336_m__5374__auto__$jscomp$inline_3335$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_3336_m__5374__auto__$jscomp$inline_3335$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$350_this$$jscomp$205$$,$walker$jscomp$1$$,$path$jscomp$33$$,$options$jscomp$89$$):$m__5372__auto__$jscomp$inline_3336_m__5374__auto__$jscomp$inline_3335$$($JSCompiler_temp$jscomp$350_this$$jscomp$205$$,$walker$jscomp$1$$,$path$jscomp$33$$,$options$jscomp$89$$);else throw $APP.$cljs$core$missing_protocol$$("Schema.-walk",$JSCompiler_temp$jscomp$350_this$$jscomp$205$$);}return $JSCompiler_temp$jscomp$350_this$$jscomp$205$$};
$malli$core$_properties$$=function($JSCompiler_temp$jscomp$351_this$$jscomp$207$$){if($JSCompiler_temp$jscomp$351_this$$jscomp$207$$!=null&&$JSCompiler_temp$jscomp$351_this$$jscomp$207$$.$malli$core$Schema$_properties$arity$1$!=null)$JSCompiler_temp$jscomp$351_this$$jscomp$207$$=$JSCompiler_temp$jscomp$351_this$$jscomp$207$$.$properties$;else{var $m__5372__auto__$jscomp$inline_3340_m__5374__auto__$jscomp$inline_3339$$=$malli$core$_properties$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$351_this$$jscomp$207$$==
null?null:$JSCompiler_temp$jscomp$351_this$$jscomp$207$$)];if($m__5372__auto__$jscomp$inline_3340_m__5374__auto__$jscomp$inline_3339$$!=null)$JSCompiler_temp$jscomp$351_this$$jscomp$207$$=$m__5372__auto__$jscomp$inline_3340_m__5374__auto__$jscomp$inline_3339$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3340_m__5374__auto__$jscomp$inline_3339$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$351_this$$jscomp$207$$):$m__5372__auto__$jscomp$inline_3340_m__5374__auto__$jscomp$inline_3339$$($JSCompiler_temp$jscomp$351_this$$jscomp$207$$);
else if($m__5372__auto__$jscomp$inline_3340_m__5374__auto__$jscomp$inline_3339$$=$malli$core$_properties$$._,$m__5372__auto__$jscomp$inline_3340_m__5374__auto__$jscomp$inline_3339$$!=null)$JSCompiler_temp$jscomp$351_this$$jscomp$207$$=$m__5372__auto__$jscomp$inline_3340_m__5374__auto__$jscomp$inline_3339$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3340_m__5374__auto__$jscomp$inline_3339$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$351_this$$jscomp$207$$):$m__5372__auto__$jscomp$inline_3340_m__5374__auto__$jscomp$inline_3339$$($JSCompiler_temp$jscomp$351_this$$jscomp$207$$);
else throw $APP.$cljs$core$missing_protocol$$("Schema.-properties",$JSCompiler_temp$jscomp$351_this$$jscomp$207$$);}return $JSCompiler_temp$jscomp$351_this$$jscomp$207$$};
$malli$core$_options$$=function($JSCompiler_temp$jscomp$352_this$$jscomp$209$$){if($JSCompiler_temp$jscomp$352_this$$jscomp$209$$!=null&&$JSCompiler_temp$jscomp$352_this$$jscomp$209$$.$malli$core$Schema$_options$arity$1$!=null)$JSCompiler_temp$jscomp$352_this$$jscomp$209$$=$JSCompiler_temp$jscomp$352_this$$jscomp$209$$.$malli$core$Schema$_options$arity$1$($JSCompiler_temp$jscomp$352_this$$jscomp$209$$);else{var $m__5372__auto__$jscomp$inline_3344_m__5374__auto__$jscomp$inline_3343$$=$malli$core$_options$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$352_this$$jscomp$209$$==
null?null:$JSCompiler_temp$jscomp$352_this$$jscomp$209$$)];if($m__5372__auto__$jscomp$inline_3344_m__5374__auto__$jscomp$inline_3343$$!=null)$JSCompiler_temp$jscomp$352_this$$jscomp$209$$=$m__5372__auto__$jscomp$inline_3344_m__5374__auto__$jscomp$inline_3343$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3344_m__5374__auto__$jscomp$inline_3343$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$352_this$$jscomp$209$$):$m__5372__auto__$jscomp$inline_3344_m__5374__auto__$jscomp$inline_3343$$($JSCompiler_temp$jscomp$352_this$$jscomp$209$$);
else if($m__5372__auto__$jscomp$inline_3344_m__5374__auto__$jscomp$inline_3343$$=$malli$core$_options$$._,$m__5372__auto__$jscomp$inline_3344_m__5374__auto__$jscomp$inline_3343$$!=null)$JSCompiler_temp$jscomp$352_this$$jscomp$209$$=$m__5372__auto__$jscomp$inline_3344_m__5374__auto__$jscomp$inline_3343$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3344_m__5374__auto__$jscomp$inline_3343$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$352_this$$jscomp$209$$):$m__5372__auto__$jscomp$inline_3344_m__5374__auto__$jscomp$inline_3343$$($JSCompiler_temp$jscomp$352_this$$jscomp$209$$);
else throw $APP.$cljs$core$missing_protocol$$("Schema.-options",$JSCompiler_temp$jscomp$352_this$$jscomp$209$$);}return $JSCompiler_temp$jscomp$352_this$$jscomp$209$$};
$malli$core$_children$$=function($JSCompiler_temp$jscomp$353_this$$jscomp$211$$){if($JSCompiler_temp$jscomp$353_this$$jscomp$211$$!=null&&$JSCompiler_temp$jscomp$353_this$$jscomp$211$$.$malli$core$Schema$_children$arity$1$!=null)$JSCompiler_temp$jscomp$353_this$$jscomp$211$$=$JSCompiler_temp$jscomp$353_this$$jscomp$211$$.$malli$core$Schema$_children$arity$1$($JSCompiler_temp$jscomp$353_this$$jscomp$211$$);else{var $m__5372__auto__$jscomp$inline_3348_m__5374__auto__$jscomp$inline_3347$$=$malli$core$_children$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$353_this$$jscomp$211$$==
null?null:$JSCompiler_temp$jscomp$353_this$$jscomp$211$$)];if($m__5372__auto__$jscomp$inline_3348_m__5374__auto__$jscomp$inline_3347$$!=null)$JSCompiler_temp$jscomp$353_this$$jscomp$211$$=$m__5372__auto__$jscomp$inline_3348_m__5374__auto__$jscomp$inline_3347$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3348_m__5374__auto__$jscomp$inline_3347$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$353_this$$jscomp$211$$):$m__5372__auto__$jscomp$inline_3348_m__5374__auto__$jscomp$inline_3347$$($JSCompiler_temp$jscomp$353_this$$jscomp$211$$);
else if($m__5372__auto__$jscomp$inline_3348_m__5374__auto__$jscomp$inline_3347$$=$malli$core$_children$$._,$m__5372__auto__$jscomp$inline_3348_m__5374__auto__$jscomp$inline_3347$$!=null)$JSCompiler_temp$jscomp$353_this$$jscomp$211$$=$m__5372__auto__$jscomp$inline_3348_m__5374__auto__$jscomp$inline_3347$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3348_m__5374__auto__$jscomp$inline_3347$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$353_this$$jscomp$211$$):$m__5372__auto__$jscomp$inline_3348_m__5374__auto__$jscomp$inline_3347$$($JSCompiler_temp$jscomp$353_this$$jscomp$211$$);
else throw $APP.$cljs$core$missing_protocol$$("Schema.-children",$JSCompiler_temp$jscomp$353_this$$jscomp$211$$);}return $JSCompiler_temp$jscomp$353_this$$jscomp$211$$};
$malli$core$_parent$$=function($JSCompiler_temp$jscomp$354_this$$jscomp$213$$){if($JSCompiler_temp$jscomp$354_this$$jscomp$213$$!=null&&$JSCompiler_temp$jscomp$354_this$$jscomp$213$$.$malli$core$Schema$_parent$arity$1$!=null)$JSCompiler_temp$jscomp$354_this$$jscomp$213$$=$JSCompiler_temp$jscomp$354_this$$jscomp$213$$.parent;else{var $m__5372__auto__$jscomp$inline_3352_m__5374__auto__$jscomp$inline_3351$$=$malli$core$_parent$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$354_this$$jscomp$213$$==null?
null:$JSCompiler_temp$jscomp$354_this$$jscomp$213$$)];if($m__5372__auto__$jscomp$inline_3352_m__5374__auto__$jscomp$inline_3351$$!=null)$JSCompiler_temp$jscomp$354_this$$jscomp$213$$=$m__5372__auto__$jscomp$inline_3352_m__5374__auto__$jscomp$inline_3351$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3352_m__5374__auto__$jscomp$inline_3351$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$354_this$$jscomp$213$$):$m__5372__auto__$jscomp$inline_3352_m__5374__auto__$jscomp$inline_3351$$($JSCompiler_temp$jscomp$354_this$$jscomp$213$$);
else if($m__5372__auto__$jscomp$inline_3352_m__5374__auto__$jscomp$inline_3351$$=$malli$core$_parent$$._,$m__5372__auto__$jscomp$inline_3352_m__5374__auto__$jscomp$inline_3351$$!=null)$JSCompiler_temp$jscomp$354_this$$jscomp$213$$=$m__5372__auto__$jscomp$inline_3352_m__5374__auto__$jscomp$inline_3351$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3352_m__5374__auto__$jscomp$inline_3351$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$354_this$$jscomp$213$$):$m__5372__auto__$jscomp$inline_3352_m__5374__auto__$jscomp$inline_3351$$($JSCompiler_temp$jscomp$354_this$$jscomp$213$$);
else throw $APP.$cljs$core$missing_protocol$$("Schema.-parent",$JSCompiler_temp$jscomp$354_this$$jscomp$213$$);}return $JSCompiler_temp$jscomp$354_this$$jscomp$213$$};
$malli$core$_form$$=function($JSCompiler_temp$jscomp$355_this$$jscomp$215$$){if($JSCompiler_temp$jscomp$355_this$$jscomp$215$$!=null&&$JSCompiler_temp$jscomp$355_this$$jscomp$215$$.$malli$core$Schema$_form$arity$1$!=null)$JSCompiler_temp$jscomp$355_this$$jscomp$215$$=$JSCompiler_temp$jscomp$355_this$$jscomp$215$$.$malli$core$Schema$_form$arity$1$($JSCompiler_temp$jscomp$355_this$$jscomp$215$$);else{var $m__5372__auto__$jscomp$inline_3356_m__5374__auto__$jscomp$inline_3355$$=$malli$core$_form$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$355_this$$jscomp$215$$==
null?null:$JSCompiler_temp$jscomp$355_this$$jscomp$215$$)];if($m__5372__auto__$jscomp$inline_3356_m__5374__auto__$jscomp$inline_3355$$!=null)$JSCompiler_temp$jscomp$355_this$$jscomp$215$$=$m__5372__auto__$jscomp$inline_3356_m__5374__auto__$jscomp$inline_3355$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3356_m__5374__auto__$jscomp$inline_3355$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$355_this$$jscomp$215$$):$m__5372__auto__$jscomp$inline_3356_m__5374__auto__$jscomp$inline_3355$$($JSCompiler_temp$jscomp$355_this$$jscomp$215$$);
else if($m__5372__auto__$jscomp$inline_3356_m__5374__auto__$jscomp$inline_3355$$=$malli$core$_form$$._,$m__5372__auto__$jscomp$inline_3356_m__5374__auto__$jscomp$inline_3355$$!=null)$JSCompiler_temp$jscomp$355_this$$jscomp$215$$=$m__5372__auto__$jscomp$inline_3356_m__5374__auto__$jscomp$inline_3355$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3356_m__5374__auto__$jscomp$inline_3355$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$355_this$$jscomp$215$$):$m__5372__auto__$jscomp$inline_3356_m__5374__auto__$jscomp$inline_3355$$($JSCompiler_temp$jscomp$355_this$$jscomp$215$$);
else throw $APP.$cljs$core$missing_protocol$$("Schema.-form",$JSCompiler_temp$jscomp$355_this$$jscomp$215$$);}return $JSCompiler_temp$jscomp$355_this$$jscomp$215$$};
$malli$core$_to_ast$$=function($JSCompiler_temp$jscomp$356_this$$jscomp$217$$,$options$jscomp$91$$){if($JSCompiler_temp$jscomp$356_this$$jscomp$217$$!=null&&$JSCompiler_temp$jscomp$356_this$$jscomp$217$$.$malli$core$AST$_to_ast$arity$2$!=null)$JSCompiler_temp$jscomp$356_this$$jscomp$217$$=$JSCompiler_temp$jscomp$356_this$$jscomp$217$$.$malli$core$AST$_to_ast$arity$2$($JSCompiler_temp$jscomp$356_this$$jscomp$217$$,$options$jscomp$91$$);else{var $m__5372__auto__$jscomp$inline_3361_m__5374__auto__$jscomp$inline_3360$$=
$malli$core$_to_ast$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$356_this$$jscomp$217$$==null?null:$JSCompiler_temp$jscomp$356_this$$jscomp$217$$)];if($m__5372__auto__$jscomp$inline_3361_m__5374__auto__$jscomp$inline_3360$$!=null)$JSCompiler_temp$jscomp$356_this$$jscomp$217$$=$m__5372__auto__$jscomp$inline_3361_m__5374__auto__$jscomp$inline_3360$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3361_m__5374__auto__$jscomp$inline_3360$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$356_this$$jscomp$217$$,
$options$jscomp$91$$):$m__5372__auto__$jscomp$inline_3361_m__5374__auto__$jscomp$inline_3360$$($JSCompiler_temp$jscomp$356_this$$jscomp$217$$,$options$jscomp$91$$);else if($m__5372__auto__$jscomp$inline_3361_m__5374__auto__$jscomp$inline_3360$$=$malli$core$_to_ast$$._,$m__5372__auto__$jscomp$inline_3361_m__5374__auto__$jscomp$inline_3360$$!=null)$JSCompiler_temp$jscomp$356_this$$jscomp$217$$=$m__5372__auto__$jscomp$inline_3361_m__5374__auto__$jscomp$inline_3360$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3361_m__5374__auto__$jscomp$inline_3360$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$356_this$$jscomp$217$$,
$options$jscomp$91$$):$m__5372__auto__$jscomp$inline_3361_m__5374__auto__$jscomp$inline_3360$$($JSCompiler_temp$jscomp$356_this$$jscomp$217$$,$options$jscomp$91$$);else throw $APP.$cljs$core$missing_protocol$$("AST.-to-ast",$JSCompiler_temp$jscomp$356_this$$jscomp$217$$);}return $JSCompiler_temp$jscomp$356_this$$jscomp$217$$};
$malli$core$_entry_keyset$$=function($JSCompiler_temp$jscomp$357_this$$jscomp$221$$){if($JSCompiler_temp$jscomp$357_this$$jscomp$221$$!=null&&$JSCompiler_temp$jscomp$357_this$$jscomp$221$$.$malli$core$EntryParser$_entry_keyset$arity$1$!=null)$JSCompiler_temp$jscomp$357_this$$jscomp$221$$=$JSCompiler_temp$jscomp$357_this$$jscomp$221$$.$malli$core$EntryParser$_entry_keyset$arity$1$($JSCompiler_temp$jscomp$357_this$$jscomp$221$$);else{var $m__5372__auto__$jscomp$inline_3365_m__5374__auto__$jscomp$inline_3364$$=
$malli$core$_entry_keyset$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$357_this$$jscomp$221$$==null?null:$JSCompiler_temp$jscomp$357_this$$jscomp$221$$)];if($m__5372__auto__$jscomp$inline_3365_m__5374__auto__$jscomp$inline_3364$$!=null)$JSCompiler_temp$jscomp$357_this$$jscomp$221$$=$m__5372__auto__$jscomp$inline_3365_m__5374__auto__$jscomp$inline_3364$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3365_m__5374__auto__$jscomp$inline_3364$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$357_this$$jscomp$221$$):
$m__5372__auto__$jscomp$inline_3365_m__5374__auto__$jscomp$inline_3364$$($JSCompiler_temp$jscomp$357_this$$jscomp$221$$);else if($m__5372__auto__$jscomp$inline_3365_m__5374__auto__$jscomp$inline_3364$$=$malli$core$_entry_keyset$$._,$m__5372__auto__$jscomp$inline_3365_m__5374__auto__$jscomp$inline_3364$$!=null)$JSCompiler_temp$jscomp$357_this$$jscomp$221$$=$m__5372__auto__$jscomp$inline_3365_m__5374__auto__$jscomp$inline_3364$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3365_m__5374__auto__$jscomp$inline_3364$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$357_this$$jscomp$221$$):
$m__5372__auto__$jscomp$inline_3365_m__5374__auto__$jscomp$inline_3364$$($JSCompiler_temp$jscomp$357_this$$jscomp$221$$);else throw $APP.$cljs$core$missing_protocol$$("EntryParser.-entry-keyset",$JSCompiler_temp$jscomp$357_this$$jscomp$221$$);}return $JSCompiler_temp$jscomp$357_this$$jscomp$221$$};
$malli$core$_entry_children$$=function($JSCompiler_temp$jscomp$358_this$$jscomp$223$$){if($JSCompiler_temp$jscomp$358_this$$jscomp$223$$!=null&&$JSCompiler_temp$jscomp$358_this$$jscomp$223$$.$malli$core$EntryParser$_entry_children$arity$1$!=null)$JSCompiler_temp$jscomp$358_this$$jscomp$223$$=$JSCompiler_temp$jscomp$358_this$$jscomp$223$$.$malli$core$EntryParser$_entry_children$arity$1$($JSCompiler_temp$jscomp$358_this$$jscomp$223$$);else{var $m__5372__auto__$jscomp$inline_3369_m__5374__auto__$jscomp$inline_3368$$=
$malli$core$_entry_children$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$358_this$$jscomp$223$$==null?null:$JSCompiler_temp$jscomp$358_this$$jscomp$223$$)];if($m__5372__auto__$jscomp$inline_3369_m__5374__auto__$jscomp$inline_3368$$!=null)$JSCompiler_temp$jscomp$358_this$$jscomp$223$$=$m__5372__auto__$jscomp$inline_3369_m__5374__auto__$jscomp$inline_3368$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3369_m__5374__auto__$jscomp$inline_3368$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$358_this$$jscomp$223$$):
$m__5372__auto__$jscomp$inline_3369_m__5374__auto__$jscomp$inline_3368$$($JSCompiler_temp$jscomp$358_this$$jscomp$223$$);else if($m__5372__auto__$jscomp$inline_3369_m__5374__auto__$jscomp$inline_3368$$=$malli$core$_entry_children$$._,$m__5372__auto__$jscomp$inline_3369_m__5374__auto__$jscomp$inline_3368$$!=null)$JSCompiler_temp$jscomp$358_this$$jscomp$223$$=$m__5372__auto__$jscomp$inline_3369_m__5374__auto__$jscomp$inline_3368$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3369_m__5374__auto__$jscomp$inline_3368$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$358_this$$jscomp$223$$):
$m__5372__auto__$jscomp$inline_3369_m__5374__auto__$jscomp$inline_3368$$($JSCompiler_temp$jscomp$358_this$$jscomp$223$$);else throw $APP.$cljs$core$missing_protocol$$("EntryParser.-entry-children",$JSCompiler_temp$jscomp$358_this$$jscomp$223$$);}return $JSCompiler_temp$jscomp$358_this$$jscomp$223$$};
$malli$core$_entry_entries$$=function($JSCompiler_temp$jscomp$359_this$$jscomp$225$$){if($JSCompiler_temp$jscomp$359_this$$jscomp$225$$!=null&&$JSCompiler_temp$jscomp$359_this$$jscomp$225$$.$malli$core$EntryParser$_entry_entries$arity$1$!=null)$JSCompiler_temp$jscomp$359_this$$jscomp$225$$=$JSCompiler_temp$jscomp$359_this$$jscomp$225$$.$malli$core$EntryParser$_entry_entries$arity$1$($JSCompiler_temp$jscomp$359_this$$jscomp$225$$);else{var $m__5372__auto__$jscomp$inline_3373_m__5374__auto__$jscomp$inline_3372$$=
$malli$core$_entry_entries$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$359_this$$jscomp$225$$==null?null:$JSCompiler_temp$jscomp$359_this$$jscomp$225$$)];if($m__5372__auto__$jscomp$inline_3373_m__5374__auto__$jscomp$inline_3372$$!=null)$JSCompiler_temp$jscomp$359_this$$jscomp$225$$=$m__5372__auto__$jscomp$inline_3373_m__5374__auto__$jscomp$inline_3372$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3373_m__5374__auto__$jscomp$inline_3372$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$359_this$$jscomp$225$$):
$m__5372__auto__$jscomp$inline_3373_m__5374__auto__$jscomp$inline_3372$$($JSCompiler_temp$jscomp$359_this$$jscomp$225$$);else if($m__5372__auto__$jscomp$inline_3373_m__5374__auto__$jscomp$inline_3372$$=$malli$core$_entry_entries$$._,$m__5372__auto__$jscomp$inline_3373_m__5374__auto__$jscomp$inline_3372$$!=null)$JSCompiler_temp$jscomp$359_this$$jscomp$225$$=$m__5372__auto__$jscomp$inline_3373_m__5374__auto__$jscomp$inline_3372$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3373_m__5374__auto__$jscomp$inline_3372$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$359_this$$jscomp$225$$):
$m__5372__auto__$jscomp$inline_3373_m__5374__auto__$jscomp$inline_3372$$($JSCompiler_temp$jscomp$359_this$$jscomp$225$$);else throw $APP.$cljs$core$missing_protocol$$("EntryParser.-entry-entries",$JSCompiler_temp$jscomp$359_this$$jscomp$225$$);}return $JSCompiler_temp$jscomp$359_this$$jscomp$225$$};
$malli$core$_entry_forms$$=function($JSCompiler_temp$jscomp$360_this$$jscomp$227$$){if($JSCompiler_temp$jscomp$360_this$$jscomp$227$$!=null&&$JSCompiler_temp$jscomp$360_this$$jscomp$227$$.$malli$core$EntryParser$_entry_forms$arity$1$!=null)$JSCompiler_temp$jscomp$360_this$$jscomp$227$$=$JSCompiler_temp$jscomp$360_this$$jscomp$227$$.$malli$core$EntryParser$_entry_forms$arity$1$($JSCompiler_temp$jscomp$360_this$$jscomp$227$$);else{var $m__5372__auto__$jscomp$inline_3377_m__5374__auto__$jscomp$inline_3376$$=
$malli$core$_entry_forms$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$360_this$$jscomp$227$$==null?null:$JSCompiler_temp$jscomp$360_this$$jscomp$227$$)];if($m__5372__auto__$jscomp$inline_3377_m__5374__auto__$jscomp$inline_3376$$!=null)$JSCompiler_temp$jscomp$360_this$$jscomp$227$$=$m__5372__auto__$jscomp$inline_3377_m__5374__auto__$jscomp$inline_3376$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3377_m__5374__auto__$jscomp$inline_3376$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$360_this$$jscomp$227$$):
$m__5372__auto__$jscomp$inline_3377_m__5374__auto__$jscomp$inline_3376$$($JSCompiler_temp$jscomp$360_this$$jscomp$227$$);else if($m__5372__auto__$jscomp$inline_3377_m__5374__auto__$jscomp$inline_3376$$=$malli$core$_entry_forms$$._,$m__5372__auto__$jscomp$inline_3377_m__5374__auto__$jscomp$inline_3376$$!=null)$JSCompiler_temp$jscomp$360_this$$jscomp$227$$=$m__5372__auto__$jscomp$inline_3377_m__5374__auto__$jscomp$inline_3376$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3377_m__5374__auto__$jscomp$inline_3376$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$360_this$$jscomp$227$$):
$m__5372__auto__$jscomp$inline_3377_m__5374__auto__$jscomp$inline_3376$$($JSCompiler_temp$jscomp$360_this$$jscomp$227$$);else throw $APP.$cljs$core$missing_protocol$$("EntryParser.-entry-forms",$JSCompiler_temp$jscomp$360_this$$jscomp$227$$);}return $JSCompiler_temp$jscomp$360_this$$jscomp$227$$};
$malli$core$_entries$$=function($JSCompiler_temp$jscomp$361_this$$jscomp$229$$){if($JSCompiler_temp$jscomp$361_this$$jscomp$229$$!=null&&$JSCompiler_temp$jscomp$361_this$$jscomp$229$$.$malli$core$EntrySchema$_entries$arity$1$!=null)$JSCompiler_temp$jscomp$361_this$$jscomp$229$$=$JSCompiler_temp$jscomp$361_this$$jscomp$229$$.$malli$core$EntrySchema$_entries$arity$1$($JSCompiler_temp$jscomp$361_this$$jscomp$229$$);else{var $m__5372__auto__$jscomp$inline_3381_m__5374__auto__$jscomp$inline_3380$$=$malli$core$_entries$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$361_this$$jscomp$229$$==
null?null:$JSCompiler_temp$jscomp$361_this$$jscomp$229$$)];if($m__5372__auto__$jscomp$inline_3381_m__5374__auto__$jscomp$inline_3380$$!=null)$JSCompiler_temp$jscomp$361_this$$jscomp$229$$=$m__5372__auto__$jscomp$inline_3381_m__5374__auto__$jscomp$inline_3380$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3381_m__5374__auto__$jscomp$inline_3380$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$361_this$$jscomp$229$$):$m__5372__auto__$jscomp$inline_3381_m__5374__auto__$jscomp$inline_3380$$($JSCompiler_temp$jscomp$361_this$$jscomp$229$$);
else if($m__5372__auto__$jscomp$inline_3381_m__5374__auto__$jscomp$inline_3380$$=$malli$core$_entries$$._,$m__5372__auto__$jscomp$inline_3381_m__5374__auto__$jscomp$inline_3380$$!=null)$JSCompiler_temp$jscomp$361_this$$jscomp$229$$=$m__5372__auto__$jscomp$inline_3381_m__5374__auto__$jscomp$inline_3380$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3381_m__5374__auto__$jscomp$inline_3380$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$361_this$$jscomp$229$$):$m__5372__auto__$jscomp$inline_3381_m__5374__auto__$jscomp$inline_3380$$($JSCompiler_temp$jscomp$361_this$$jscomp$229$$);
else throw $APP.$cljs$core$missing_protocol$$("EntrySchema.-entries",$JSCompiler_temp$jscomp$361_this$$jscomp$229$$);}return $JSCompiler_temp$jscomp$361_this$$jscomp$229$$};
$malli$core$_entry_parser$$=function($JSCompiler_temp$jscomp$362_this$$jscomp$231$$){if($JSCompiler_temp$jscomp$362_this$$jscomp$231$$!=null&&$JSCompiler_temp$jscomp$362_this$$jscomp$231$$.$malli$core$EntrySchema$_entry_parser$arity$1$!=null)$JSCompiler_temp$jscomp$362_this$$jscomp$231$$=$JSCompiler_temp$jscomp$362_this$$jscomp$231$$.$entry_parser$;else{var $m__5372__auto__$jscomp$inline_3385_m__5374__auto__$jscomp$inline_3384$$=$malli$core$_entry_parser$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$362_this$$jscomp$231$$==
null?null:$JSCompiler_temp$jscomp$362_this$$jscomp$231$$)];if($m__5372__auto__$jscomp$inline_3385_m__5374__auto__$jscomp$inline_3384$$!=null)$JSCompiler_temp$jscomp$362_this$$jscomp$231$$=$m__5372__auto__$jscomp$inline_3385_m__5374__auto__$jscomp$inline_3384$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3385_m__5374__auto__$jscomp$inline_3384$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$362_this$$jscomp$231$$):$m__5372__auto__$jscomp$inline_3385_m__5374__auto__$jscomp$inline_3384$$($JSCompiler_temp$jscomp$362_this$$jscomp$231$$);
else if($m__5372__auto__$jscomp$inline_3385_m__5374__auto__$jscomp$inline_3384$$=$malli$core$_entry_parser$$._,$m__5372__auto__$jscomp$inline_3385_m__5374__auto__$jscomp$inline_3384$$!=null)$JSCompiler_temp$jscomp$362_this$$jscomp$231$$=$m__5372__auto__$jscomp$inline_3385_m__5374__auto__$jscomp$inline_3384$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3385_m__5374__auto__$jscomp$inline_3384$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$362_this$$jscomp$231$$):$m__5372__auto__$jscomp$inline_3385_m__5374__auto__$jscomp$inline_3384$$($JSCompiler_temp$jscomp$362_this$$jscomp$231$$);
else throw $APP.$cljs$core$missing_protocol$$("EntrySchema.-entry-parser",$JSCompiler_temp$jscomp$362_this$$jscomp$231$$);}return $JSCompiler_temp$jscomp$362_this$$jscomp$231$$};
$malli$core$_cache$$=function($JSCompiler_temp$jscomp$363_this$$jscomp$233$$){if($JSCompiler_temp$jscomp$363_this$$jscomp$233$$!=null&&$JSCompiler_temp$jscomp$363_this$$jscomp$233$$.$malli$core$Cached$_cache$arity$1$!=null)$JSCompiler_temp$jscomp$363_this$$jscomp$233$$=$JSCompiler_temp$jscomp$363_this$$jscomp$233$$.cache;else{var $m__5372__auto__$jscomp$inline_3389_m__5374__auto__$jscomp$inline_3388$$=$malli$core$_cache$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$363_this$$jscomp$233$$==null?null:
$JSCompiler_temp$jscomp$363_this$$jscomp$233$$)];if($m__5372__auto__$jscomp$inline_3389_m__5374__auto__$jscomp$inline_3388$$!=null)$JSCompiler_temp$jscomp$363_this$$jscomp$233$$=$m__5372__auto__$jscomp$inline_3389_m__5374__auto__$jscomp$inline_3388$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3389_m__5374__auto__$jscomp$inline_3388$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$363_this$$jscomp$233$$):$m__5372__auto__$jscomp$inline_3389_m__5374__auto__$jscomp$inline_3388$$($JSCompiler_temp$jscomp$363_this$$jscomp$233$$);
else if($m__5372__auto__$jscomp$inline_3389_m__5374__auto__$jscomp$inline_3388$$=$malli$core$_cache$$._,$m__5372__auto__$jscomp$inline_3389_m__5374__auto__$jscomp$inline_3388$$!=null)$JSCompiler_temp$jscomp$363_this$$jscomp$233$$=$m__5372__auto__$jscomp$inline_3389_m__5374__auto__$jscomp$inline_3388$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3389_m__5374__auto__$jscomp$inline_3388$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$363_this$$jscomp$233$$):$m__5372__auto__$jscomp$inline_3389_m__5374__auto__$jscomp$inline_3388$$($JSCompiler_temp$jscomp$363_this$$jscomp$233$$);
else throw $APP.$cljs$core$missing_protocol$$("Cached.-cache",$JSCompiler_temp$jscomp$363_this$$jscomp$233$$);}return $JSCompiler_temp$jscomp$363_this$$jscomp$233$$};
$malli$core$_get$$=function($JSCompiler_temp$jscomp$364_this$$jscomp$237$$,$key$jscomp$184$$,$default$$jscomp$10$$){if($JSCompiler_temp$jscomp$364_this$$jscomp$237$$!=null&&$JSCompiler_temp$jscomp$364_this$$jscomp$237$$.$malli$core$LensSchema$_get$arity$3$!=null)$JSCompiler_temp$jscomp$364_this$$jscomp$237$$=$JSCompiler_temp$jscomp$364_this$$jscomp$237$$.$malli$core$LensSchema$_get$arity$3$($JSCompiler_temp$jscomp$364_this$$jscomp$237$$,$key$jscomp$184$$,$default$$jscomp$10$$);else{var $m__5372__auto__$jscomp$inline_3395_m__5374__auto__$jscomp$inline_3394$$=
$malli$core$_get$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$364_this$$jscomp$237$$==null?null:$JSCompiler_temp$jscomp$364_this$$jscomp$237$$)];if($m__5372__auto__$jscomp$inline_3395_m__5374__auto__$jscomp$inline_3394$$!=null)$JSCompiler_temp$jscomp$364_this$$jscomp$237$$=$m__5372__auto__$jscomp$inline_3395_m__5374__auto__$jscomp$inline_3394$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_3395_m__5374__auto__$jscomp$inline_3394$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$364_this$$jscomp$237$$,
$key$jscomp$184$$,$default$$jscomp$10$$):$m__5372__auto__$jscomp$inline_3395_m__5374__auto__$jscomp$inline_3394$$($JSCompiler_temp$jscomp$364_this$$jscomp$237$$,$key$jscomp$184$$,$default$$jscomp$10$$);else if($m__5372__auto__$jscomp$inline_3395_m__5374__auto__$jscomp$inline_3394$$=$malli$core$_get$$._,$m__5372__auto__$jscomp$inline_3395_m__5374__auto__$jscomp$inline_3394$$!=null)$JSCompiler_temp$jscomp$364_this$$jscomp$237$$=$m__5372__auto__$jscomp$inline_3395_m__5374__auto__$jscomp$inline_3394$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_3395_m__5374__auto__$jscomp$inline_3394$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$364_this$$jscomp$237$$,$key$jscomp$184$$,$default$$jscomp$10$$):$m__5372__auto__$jscomp$inline_3395_m__5374__auto__$jscomp$inline_3394$$($JSCompiler_temp$jscomp$364_this$$jscomp$237$$,$key$jscomp$184$$,$default$$jscomp$10$$);else throw $APP.$cljs$core$missing_protocol$$("LensSchema.-get",$JSCompiler_temp$jscomp$364_this$$jscomp$237$$);}return $JSCompiler_temp$jscomp$364_this$$jscomp$237$$};
$malli$core$_set$$=function($JSCompiler_temp$jscomp$365_this$$jscomp$239$$,$key$jscomp$186$$,$value$jscomp$232$$){if($JSCompiler_temp$jscomp$365_this$$jscomp$239$$!=null&&$JSCompiler_temp$jscomp$365_this$$jscomp$239$$.$malli$core$LensSchema$_set$arity$3$!=null)$JSCompiler_temp$jscomp$365_this$$jscomp$239$$=$JSCompiler_temp$jscomp$365_this$$jscomp$239$$.$malli$core$LensSchema$_set$arity$3$($JSCompiler_temp$jscomp$365_this$$jscomp$239$$,$key$jscomp$186$$,$value$jscomp$232$$);else{var $m__5372__auto__$jscomp$inline_3401_m__5374__auto__$jscomp$inline_3400$$=
$malli$core$_set$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$365_this$$jscomp$239$$==null?null:$JSCompiler_temp$jscomp$365_this$$jscomp$239$$)];if($m__5372__auto__$jscomp$inline_3401_m__5374__auto__$jscomp$inline_3400$$!=null)$JSCompiler_temp$jscomp$365_this$$jscomp$239$$=$m__5372__auto__$jscomp$inline_3401_m__5374__auto__$jscomp$inline_3400$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_3401_m__5374__auto__$jscomp$inline_3400$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$365_this$$jscomp$239$$,
$key$jscomp$186$$,$value$jscomp$232$$):$m__5372__auto__$jscomp$inline_3401_m__5374__auto__$jscomp$inline_3400$$($JSCompiler_temp$jscomp$365_this$$jscomp$239$$,$key$jscomp$186$$,$value$jscomp$232$$);else if($m__5372__auto__$jscomp$inline_3401_m__5374__auto__$jscomp$inline_3400$$=$malli$core$_set$$._,$m__5372__auto__$jscomp$inline_3401_m__5374__auto__$jscomp$inline_3400$$!=null)$JSCompiler_temp$jscomp$365_this$$jscomp$239$$=$m__5372__auto__$jscomp$inline_3401_m__5374__auto__$jscomp$inline_3400$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_3401_m__5374__auto__$jscomp$inline_3400$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$365_this$$jscomp$239$$,$key$jscomp$186$$,$value$jscomp$232$$):$m__5372__auto__$jscomp$inline_3401_m__5374__auto__$jscomp$inline_3400$$($JSCompiler_temp$jscomp$365_this$$jscomp$239$$,$key$jscomp$186$$,$value$jscomp$232$$);else throw $APP.$cljs$core$missing_protocol$$("LensSchema.-set",$JSCompiler_temp$jscomp$365_this$$jscomp$239$$);}return $JSCompiler_temp$jscomp$365_this$$jscomp$239$$};
$malli$core$_ref$$=function($JSCompiler_temp$jscomp$366_this$$jscomp$241$$){if($JSCompiler_temp$jscomp$366_this$$jscomp$241$$!=null&&$JSCompiler_temp$jscomp$366_this$$jscomp$241$$.$malli$core$RefSchema$_ref$arity$1$!=null)$JSCompiler_temp$jscomp$366_this$$jscomp$241$$=$JSCompiler_temp$jscomp$366_this$$jscomp$241$$.$malli$core$RefSchema$_ref$arity$1$($JSCompiler_temp$jscomp$366_this$$jscomp$241$$);else{var $m__5372__auto__$jscomp$inline_3405_m__5374__auto__$jscomp$inline_3404$$=$malli$core$_ref$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$366_this$$jscomp$241$$==
null?null:$JSCompiler_temp$jscomp$366_this$$jscomp$241$$)];if($m__5372__auto__$jscomp$inline_3405_m__5374__auto__$jscomp$inline_3404$$!=null)$JSCompiler_temp$jscomp$366_this$$jscomp$241$$=$m__5372__auto__$jscomp$inline_3405_m__5374__auto__$jscomp$inline_3404$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3405_m__5374__auto__$jscomp$inline_3404$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$366_this$$jscomp$241$$):$m__5372__auto__$jscomp$inline_3405_m__5374__auto__$jscomp$inline_3404$$($JSCompiler_temp$jscomp$366_this$$jscomp$241$$);
else if($m__5372__auto__$jscomp$inline_3405_m__5374__auto__$jscomp$inline_3404$$=$malli$core$_ref$$._,$m__5372__auto__$jscomp$inline_3405_m__5374__auto__$jscomp$inline_3404$$!=null)$JSCompiler_temp$jscomp$366_this$$jscomp$241$$=$m__5372__auto__$jscomp$inline_3405_m__5374__auto__$jscomp$inline_3404$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3405_m__5374__auto__$jscomp$inline_3404$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$366_this$$jscomp$241$$):$m__5372__auto__$jscomp$inline_3405_m__5374__auto__$jscomp$inline_3404$$($JSCompiler_temp$jscomp$366_this$$jscomp$241$$);
else throw $APP.$cljs$core$missing_protocol$$("RefSchema.-ref",$JSCompiler_temp$jscomp$366_this$$jscomp$241$$);}return $JSCompiler_temp$jscomp$366_this$$jscomp$241$$};
$malli$core$_deref$$=function($JSCompiler_temp$jscomp$367_this$$jscomp$243$$){if($JSCompiler_temp$jscomp$367_this$$jscomp$243$$!=null&&$JSCompiler_temp$jscomp$367_this$$jscomp$243$$.$malli$core$RefSchema$_deref$arity$1$!=null)$JSCompiler_temp$jscomp$367_this$$jscomp$243$$=$JSCompiler_temp$jscomp$367_this$$jscomp$243$$.$malli$core$RefSchema$_deref$arity$1$($JSCompiler_temp$jscomp$367_this$$jscomp$243$$);else{var $m__5372__auto__$jscomp$inline_3409_m__5374__auto__$jscomp$inline_3408$$=$malli$core$_deref$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$367_this$$jscomp$243$$==
null?null:$JSCompiler_temp$jscomp$367_this$$jscomp$243$$)];if($m__5372__auto__$jscomp$inline_3409_m__5374__auto__$jscomp$inline_3408$$!=null)$JSCompiler_temp$jscomp$367_this$$jscomp$243$$=$m__5372__auto__$jscomp$inline_3409_m__5374__auto__$jscomp$inline_3408$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3409_m__5374__auto__$jscomp$inline_3408$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$367_this$$jscomp$243$$):$m__5372__auto__$jscomp$inline_3409_m__5374__auto__$jscomp$inline_3408$$($JSCompiler_temp$jscomp$367_this$$jscomp$243$$);
else if($m__5372__auto__$jscomp$inline_3409_m__5374__auto__$jscomp$inline_3408$$=$malli$core$_deref$$._,$m__5372__auto__$jscomp$inline_3409_m__5374__auto__$jscomp$inline_3408$$!=null)$JSCompiler_temp$jscomp$367_this$$jscomp$243$$=$m__5372__auto__$jscomp$inline_3409_m__5374__auto__$jscomp$inline_3408$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3409_m__5374__auto__$jscomp$inline_3408$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$367_this$$jscomp$243$$):$m__5372__auto__$jscomp$inline_3409_m__5374__auto__$jscomp$inline_3408$$($JSCompiler_temp$jscomp$367_this$$jscomp$243$$);
else throw $APP.$cljs$core$missing_protocol$$("RefSchema.-deref",$JSCompiler_temp$jscomp$367_this$$jscomp$243$$);}return $JSCompiler_temp$jscomp$367_this$$jscomp$243$$};
$malli$core$_accept$$=function($JSCompiler_temp$jscomp$368_this$$jscomp$245$$,$schema$jscomp$7$$,$path$jscomp$35$$,$options$jscomp$95$$){if($JSCompiler_temp$jscomp$368_this$$jscomp$245$$!=null&&$JSCompiler_temp$jscomp$368_this$$jscomp$245$$.$malli$core$Walker$_accept$arity$4$!=null)$JSCompiler_temp$jscomp$368_this$$jscomp$245$$=$JSCompiler_temp$jscomp$368_this$$jscomp$245$$.$malli$core$Walker$_accept$arity$4$($JSCompiler_temp$jscomp$368_this$$jscomp$245$$,$schema$jscomp$7$$,$path$jscomp$35$$,$options$jscomp$95$$);
else{var $m__5372__auto__$jscomp$inline_3416_m__5374__auto__$jscomp$inline_3415$$=$malli$core$_accept$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$368_this$$jscomp$245$$==null?null:$JSCompiler_temp$jscomp$368_this$$jscomp$245$$)];if($m__5372__auto__$jscomp$inline_3416_m__5374__auto__$jscomp$inline_3415$$!=null)$JSCompiler_temp$jscomp$368_this$$jscomp$245$$=$m__5372__auto__$jscomp$inline_3416_m__5374__auto__$jscomp$inline_3415$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_3416_m__5374__auto__$jscomp$inline_3415$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$368_this$$jscomp$245$$,
$schema$jscomp$7$$,$path$jscomp$35$$,$options$jscomp$95$$):$m__5372__auto__$jscomp$inline_3416_m__5374__auto__$jscomp$inline_3415$$($JSCompiler_temp$jscomp$368_this$$jscomp$245$$,$schema$jscomp$7$$,$path$jscomp$35$$,$options$jscomp$95$$);else if($m__5372__auto__$jscomp$inline_3416_m__5374__auto__$jscomp$inline_3415$$=$malli$core$_accept$$._,$m__5372__auto__$jscomp$inline_3416_m__5374__auto__$jscomp$inline_3415$$!=null)$JSCompiler_temp$jscomp$368_this$$jscomp$245$$=$m__5372__auto__$jscomp$inline_3416_m__5374__auto__$jscomp$inline_3415$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_3416_m__5374__auto__$jscomp$inline_3415$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$368_this$$jscomp$245$$,$schema$jscomp$7$$,$path$jscomp$35$$,$options$jscomp$95$$):$m__5372__auto__$jscomp$inline_3416_m__5374__auto__$jscomp$inline_3415$$($JSCompiler_temp$jscomp$368_this$$jscomp$245$$,$schema$jscomp$7$$,$path$jscomp$35$$,$options$jscomp$95$$);else throw $APP.$cljs$core$missing_protocol$$("Walker.-accept",$JSCompiler_temp$jscomp$368_this$$jscomp$245$$);
}return $JSCompiler_temp$jscomp$368_this$$jscomp$245$$};
$malli$core$_inner$$=function($JSCompiler_temp$jscomp$369_this$$jscomp$247$$,$schema$jscomp$9$$,$path$jscomp$37$$,$options$jscomp$97$$){if($JSCompiler_temp$jscomp$369_this$$jscomp$247$$!=null&&$JSCompiler_temp$jscomp$369_this$$jscomp$247$$.$malli$core$Walker$_inner$arity$4$!=null)$JSCompiler_temp$jscomp$369_this$$jscomp$247$$=$JSCompiler_temp$jscomp$369_this$$jscomp$247$$.$malli$core$Walker$_inner$arity$4$($JSCompiler_temp$jscomp$369_this$$jscomp$247$$,$schema$jscomp$9$$,$path$jscomp$37$$,$options$jscomp$97$$);
else{var $m__5372__auto__$jscomp$inline_3423_m__5374__auto__$jscomp$inline_3422$$=$malli$core$_inner$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$369_this$$jscomp$247$$==null?null:$JSCompiler_temp$jscomp$369_this$$jscomp$247$$)];if($m__5372__auto__$jscomp$inline_3423_m__5374__auto__$jscomp$inline_3422$$!=null)$JSCompiler_temp$jscomp$369_this$$jscomp$247$$=$m__5372__auto__$jscomp$inline_3423_m__5374__auto__$jscomp$inline_3422$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_3423_m__5374__auto__$jscomp$inline_3422$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$369_this$$jscomp$247$$,
$schema$jscomp$9$$,$path$jscomp$37$$,$options$jscomp$97$$):$m__5372__auto__$jscomp$inline_3423_m__5374__auto__$jscomp$inline_3422$$($JSCompiler_temp$jscomp$369_this$$jscomp$247$$,$schema$jscomp$9$$,$path$jscomp$37$$,$options$jscomp$97$$);else if($m__5372__auto__$jscomp$inline_3423_m__5374__auto__$jscomp$inline_3422$$=$malli$core$_inner$$._,$m__5372__auto__$jscomp$inline_3423_m__5374__auto__$jscomp$inline_3422$$!=null)$JSCompiler_temp$jscomp$369_this$$jscomp$247$$=$m__5372__auto__$jscomp$inline_3423_m__5374__auto__$jscomp$inline_3422$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_3423_m__5374__auto__$jscomp$inline_3422$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$369_this$$jscomp$247$$,$schema$jscomp$9$$,$path$jscomp$37$$,$options$jscomp$97$$):$m__5372__auto__$jscomp$inline_3423_m__5374__auto__$jscomp$inline_3422$$($JSCompiler_temp$jscomp$369_this$$jscomp$247$$,$schema$jscomp$9$$,$path$jscomp$37$$,$options$jscomp$97$$);else throw $APP.$cljs$core$missing_protocol$$("Walker.-inner",$JSCompiler_temp$jscomp$369_this$$jscomp$247$$);}return $JSCompiler_temp$jscomp$369_this$$jscomp$247$$};
$malli$core$_outer$$=function($JSCompiler_temp$jscomp$370_this$$jscomp$249$$,$schema$jscomp$11$$,$path$jscomp$39$$,$children$jscomp$6$$,$options$jscomp$99$$){if($JSCompiler_temp$jscomp$370_this$$jscomp$249$$!=null&&$JSCompiler_temp$jscomp$370_this$$jscomp$249$$.$malli$core$Walker$_outer$arity$5$!=null)$JSCompiler_temp$jscomp$370_this$$jscomp$249$$=$JSCompiler_temp$jscomp$370_this$$jscomp$249$$.$malli$core$Walker$_outer$arity$5$($JSCompiler_temp$jscomp$370_this$$jscomp$249$$,$schema$jscomp$11$$,$path$jscomp$39$$,
$children$jscomp$6$$,$options$jscomp$99$$);else{var $m__5372__auto__$jscomp$inline_3431_m__5374__auto__$jscomp$inline_3430$$=$malli$core$_outer$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$370_this$$jscomp$249$$==null?null:$JSCompiler_temp$jscomp$370_this$$jscomp$249$$)];if($m__5372__auto__$jscomp$inline_3431_m__5374__auto__$jscomp$inline_3430$$!=null)$JSCompiler_temp$jscomp$370_this$$jscomp$249$$=$m__5372__auto__$jscomp$inline_3431_m__5374__auto__$jscomp$inline_3430$$.$cljs$core$IFn$_invoke$arity$5$?
$m__5372__auto__$jscomp$inline_3431_m__5374__auto__$jscomp$inline_3430$$.$cljs$core$IFn$_invoke$arity$5$($JSCompiler_temp$jscomp$370_this$$jscomp$249$$,$schema$jscomp$11$$,$path$jscomp$39$$,$children$jscomp$6$$,$options$jscomp$99$$):$m__5372__auto__$jscomp$inline_3431_m__5374__auto__$jscomp$inline_3430$$($JSCompiler_temp$jscomp$370_this$$jscomp$249$$,$schema$jscomp$11$$,$path$jscomp$39$$,$children$jscomp$6$$,$options$jscomp$99$$);else if($m__5372__auto__$jscomp$inline_3431_m__5374__auto__$jscomp$inline_3430$$=
$malli$core$_outer$$._,$m__5372__auto__$jscomp$inline_3431_m__5374__auto__$jscomp$inline_3430$$!=null)$JSCompiler_temp$jscomp$370_this$$jscomp$249$$=$m__5372__auto__$jscomp$inline_3431_m__5374__auto__$jscomp$inline_3430$$.$cljs$core$IFn$_invoke$arity$5$?$m__5372__auto__$jscomp$inline_3431_m__5374__auto__$jscomp$inline_3430$$.$cljs$core$IFn$_invoke$arity$5$($JSCompiler_temp$jscomp$370_this$$jscomp$249$$,$schema$jscomp$11$$,$path$jscomp$39$$,$children$jscomp$6$$,$options$jscomp$99$$):$m__5372__auto__$jscomp$inline_3431_m__5374__auto__$jscomp$inline_3430$$($JSCompiler_temp$jscomp$370_this$$jscomp$249$$,
$schema$jscomp$11$$,$path$jscomp$39$$,$children$jscomp$6$$,$options$jscomp$99$$);else throw $APP.$cljs$core$missing_protocol$$("Walker.-outer",$JSCompiler_temp$jscomp$370_this$$jscomp$249$$);}return $JSCompiler_temp$jscomp$370_this$$jscomp$249$$};
$malli$core$_transformer_chain$$=function($JSCompiler_temp$jscomp$371_this$$jscomp$251$$){if($JSCompiler_temp$jscomp$371_this$$jscomp$251$$!=null&&$JSCompiler_temp$jscomp$371_this$$jscomp$251$$.$malli$core$Transformer$_transformer_chain$arity$1$!=null)$JSCompiler_temp$jscomp$371_this$$jscomp$251$$=$JSCompiler_temp$jscomp$371_this$$jscomp$251$$.$malli$core$Transformer$_transformer_chain$arity$1$($JSCompiler_temp$jscomp$371_this$$jscomp$251$$);else{var $m__5372__auto__$jscomp$inline_3435_m__5374__auto__$jscomp$inline_3434$$=
$malli$core$_transformer_chain$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$371_this$$jscomp$251$$==null?null:$JSCompiler_temp$jscomp$371_this$$jscomp$251$$)];if($m__5372__auto__$jscomp$inline_3435_m__5374__auto__$jscomp$inline_3434$$!=null)$JSCompiler_temp$jscomp$371_this$$jscomp$251$$=$m__5372__auto__$jscomp$inline_3435_m__5374__auto__$jscomp$inline_3434$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3435_m__5374__auto__$jscomp$inline_3434$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$371_this$$jscomp$251$$):
$m__5372__auto__$jscomp$inline_3435_m__5374__auto__$jscomp$inline_3434$$($JSCompiler_temp$jscomp$371_this$$jscomp$251$$);else if($m__5372__auto__$jscomp$inline_3435_m__5374__auto__$jscomp$inline_3434$$=$malli$core$_transformer_chain$$._,$m__5372__auto__$jscomp$inline_3435_m__5374__auto__$jscomp$inline_3434$$!=null)$JSCompiler_temp$jscomp$371_this$$jscomp$251$$=$m__5372__auto__$jscomp$inline_3435_m__5374__auto__$jscomp$inline_3434$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3435_m__5374__auto__$jscomp$inline_3434$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$371_this$$jscomp$251$$):
$m__5372__auto__$jscomp$inline_3435_m__5374__auto__$jscomp$inline_3434$$($JSCompiler_temp$jscomp$371_this$$jscomp$251$$);else throw $APP.$cljs$core$missing_protocol$$("Transformer.-transformer-chain",$JSCompiler_temp$jscomp$371_this$$jscomp$251$$);}return $JSCompiler_temp$jscomp$371_this$$jscomp$251$$};
$malli$core$_value_transformer$$=function($JSCompiler_temp$jscomp$372_this$$jscomp$253$$,$schema$jscomp$13$$,$method$jscomp$8$$,$options$jscomp$101$$){if($JSCompiler_temp$jscomp$372_this$$jscomp$253$$!=null&&$JSCompiler_temp$jscomp$372_this$$jscomp$253$$.$malli$core$Transformer$_value_transformer$arity$4$!=null)$JSCompiler_temp$jscomp$372_this$$jscomp$253$$=$JSCompiler_temp$jscomp$372_this$$jscomp$253$$.$malli$core$Transformer$_value_transformer$arity$4$($JSCompiler_temp$jscomp$372_this$$jscomp$253$$,
$schema$jscomp$13$$,$method$jscomp$8$$,$options$jscomp$101$$);else{var $m__5372__auto__$jscomp$inline_3442_m__5374__auto__$jscomp$inline_3441$$=$malli$core$_value_transformer$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$372_this$$jscomp$253$$==null?null:$JSCompiler_temp$jscomp$372_this$$jscomp$253$$)];if($m__5372__auto__$jscomp$inline_3442_m__5374__auto__$jscomp$inline_3441$$!=null)$JSCompiler_temp$jscomp$372_this$$jscomp$253$$=$m__5372__auto__$jscomp$inline_3442_m__5374__auto__$jscomp$inline_3441$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_3442_m__5374__auto__$jscomp$inline_3441$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$372_this$$jscomp$253$$,$schema$jscomp$13$$,$method$jscomp$8$$,$options$jscomp$101$$):$m__5372__auto__$jscomp$inline_3442_m__5374__auto__$jscomp$inline_3441$$($JSCompiler_temp$jscomp$372_this$$jscomp$253$$,$schema$jscomp$13$$,$method$jscomp$8$$,$options$jscomp$101$$);else if($m__5372__auto__$jscomp$inline_3442_m__5374__auto__$jscomp$inline_3441$$=$malli$core$_value_transformer$$._,
$m__5372__auto__$jscomp$inline_3442_m__5374__auto__$jscomp$inline_3441$$!=null)$JSCompiler_temp$jscomp$372_this$$jscomp$253$$=$m__5372__auto__$jscomp$inline_3442_m__5374__auto__$jscomp$inline_3441$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_3442_m__5374__auto__$jscomp$inline_3441$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$372_this$$jscomp$253$$,$schema$jscomp$13$$,$method$jscomp$8$$,$options$jscomp$101$$):$m__5372__auto__$jscomp$inline_3442_m__5374__auto__$jscomp$inline_3441$$($JSCompiler_temp$jscomp$372_this$$jscomp$253$$,
$schema$jscomp$13$$,$method$jscomp$8$$,$options$jscomp$101$$);else throw $APP.$cljs$core$missing_protocol$$("Transformer.-value-transformer",$JSCompiler_temp$jscomp$372_this$$jscomp$253$$);}return $JSCompiler_temp$jscomp$372_this$$jscomp$253$$};
$malli$core$_regex_op_QMARK_$$=function($JSCompiler_temp$jscomp$373_this$$jscomp$255$$){if($JSCompiler_temp$jscomp$373_this$$jscomp$255$$!=null&&$JSCompiler_temp$jscomp$373_this$$jscomp$255$$.$malli$core$RegexSchema$_regex_op_QMARK_$arity$1$!=null)$JSCompiler_temp$jscomp$373_this$$jscomp$255$$=$JSCompiler_temp$jscomp$373_this$$jscomp$255$$.$malli$core$RegexSchema$_regex_op_QMARK_$arity$1$($JSCompiler_temp$jscomp$373_this$$jscomp$255$$);else{var $m__5372__auto__$jscomp$inline_3446_m__5374__auto__$jscomp$inline_3445$$=
$malli$core$_regex_op_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$373_this$$jscomp$255$$==null?null:$JSCompiler_temp$jscomp$373_this$$jscomp$255$$)];if($m__5372__auto__$jscomp$inline_3446_m__5374__auto__$jscomp$inline_3445$$!=null)$JSCompiler_temp$jscomp$373_this$$jscomp$255$$=$m__5372__auto__$jscomp$inline_3446_m__5374__auto__$jscomp$inline_3445$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3446_m__5374__auto__$jscomp$inline_3445$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$373_this$$jscomp$255$$):
$m__5372__auto__$jscomp$inline_3446_m__5374__auto__$jscomp$inline_3445$$($JSCompiler_temp$jscomp$373_this$$jscomp$255$$);else if($m__5372__auto__$jscomp$inline_3446_m__5374__auto__$jscomp$inline_3445$$=$malli$core$_regex_op_QMARK_$$._,$m__5372__auto__$jscomp$inline_3446_m__5374__auto__$jscomp$inline_3445$$!=null)$JSCompiler_temp$jscomp$373_this$$jscomp$255$$=$m__5372__auto__$jscomp$inline_3446_m__5374__auto__$jscomp$inline_3445$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3446_m__5374__auto__$jscomp$inline_3445$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$373_this$$jscomp$255$$):
$m__5372__auto__$jscomp$inline_3446_m__5374__auto__$jscomp$inline_3445$$($JSCompiler_temp$jscomp$373_this$$jscomp$255$$);else throw $APP.$cljs$core$missing_protocol$$("RegexSchema.-regex-op?",$JSCompiler_temp$jscomp$373_this$$jscomp$255$$);}return $JSCompiler_temp$jscomp$373_this$$jscomp$255$$};
$malli$core$_regex_validator$$=function($JSCompiler_temp$jscomp$374_this$$jscomp$257$$){if($JSCompiler_temp$jscomp$374_this$$jscomp$257$$!=null&&$JSCompiler_temp$jscomp$374_this$$jscomp$257$$.$malli$core$RegexSchema$_regex_validator$arity$1$!=null)$JSCompiler_temp$jscomp$374_this$$jscomp$257$$=$JSCompiler_temp$jscomp$374_this$$jscomp$257$$.$malli$core$RegexSchema$_regex_validator$arity$1$($JSCompiler_temp$jscomp$374_this$$jscomp$257$$);else{var $m__5372__auto__$jscomp$inline_3450_m__5374__auto__$jscomp$inline_3449$$=
$malli$core$_regex_validator$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$374_this$$jscomp$257$$==null?null:$JSCompiler_temp$jscomp$374_this$$jscomp$257$$)];if($m__5372__auto__$jscomp$inline_3450_m__5374__auto__$jscomp$inline_3449$$!=null)$JSCompiler_temp$jscomp$374_this$$jscomp$257$$=$m__5372__auto__$jscomp$inline_3450_m__5374__auto__$jscomp$inline_3449$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3450_m__5374__auto__$jscomp$inline_3449$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$374_this$$jscomp$257$$):
$m__5372__auto__$jscomp$inline_3450_m__5374__auto__$jscomp$inline_3449$$($JSCompiler_temp$jscomp$374_this$$jscomp$257$$);else if($m__5372__auto__$jscomp$inline_3450_m__5374__auto__$jscomp$inline_3449$$=$malli$core$_regex_validator$$._,$m__5372__auto__$jscomp$inline_3450_m__5374__auto__$jscomp$inline_3449$$!=null)$JSCompiler_temp$jscomp$374_this$$jscomp$257$$=$m__5372__auto__$jscomp$inline_3450_m__5374__auto__$jscomp$inline_3449$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3450_m__5374__auto__$jscomp$inline_3449$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$374_this$$jscomp$257$$):
$m__5372__auto__$jscomp$inline_3450_m__5374__auto__$jscomp$inline_3449$$($JSCompiler_temp$jscomp$374_this$$jscomp$257$$);else throw $APP.$cljs$core$missing_protocol$$("RegexSchema.-regex-validator",$JSCompiler_temp$jscomp$374_this$$jscomp$257$$);}return $JSCompiler_temp$jscomp$374_this$$jscomp$257$$};
$malli$core$_regex_explainer$$=function($JSCompiler_temp$jscomp$375_this$$jscomp$259$$,$path$jscomp$41$$){if($JSCompiler_temp$jscomp$375_this$$jscomp$259$$!=null&&$JSCompiler_temp$jscomp$375_this$$jscomp$259$$.$malli$core$RegexSchema$_regex_explainer$arity$2$!=null)$JSCompiler_temp$jscomp$375_this$$jscomp$259$$=$JSCompiler_temp$jscomp$375_this$$jscomp$259$$.$malli$core$RegexSchema$_regex_explainer$arity$2$($JSCompiler_temp$jscomp$375_this$$jscomp$259$$,$path$jscomp$41$$);else{var $m__5372__auto__$jscomp$inline_3455_m__5374__auto__$jscomp$inline_3454$$=
$malli$core$_regex_explainer$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$375_this$$jscomp$259$$==null?null:$JSCompiler_temp$jscomp$375_this$$jscomp$259$$)];if($m__5372__auto__$jscomp$inline_3455_m__5374__auto__$jscomp$inline_3454$$!=null)$JSCompiler_temp$jscomp$375_this$$jscomp$259$$=$m__5372__auto__$jscomp$inline_3455_m__5374__auto__$jscomp$inline_3454$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3455_m__5374__auto__$jscomp$inline_3454$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$375_this$$jscomp$259$$,
$path$jscomp$41$$):$m__5372__auto__$jscomp$inline_3455_m__5374__auto__$jscomp$inline_3454$$($JSCompiler_temp$jscomp$375_this$$jscomp$259$$,$path$jscomp$41$$);else if($m__5372__auto__$jscomp$inline_3455_m__5374__auto__$jscomp$inline_3454$$=$malli$core$_regex_explainer$$._,$m__5372__auto__$jscomp$inline_3455_m__5374__auto__$jscomp$inline_3454$$!=null)$JSCompiler_temp$jscomp$375_this$$jscomp$259$$=$m__5372__auto__$jscomp$inline_3455_m__5374__auto__$jscomp$inline_3454$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_3455_m__5374__auto__$jscomp$inline_3454$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$375_this$$jscomp$259$$,$path$jscomp$41$$):$m__5372__auto__$jscomp$inline_3455_m__5374__auto__$jscomp$inline_3454$$($JSCompiler_temp$jscomp$375_this$$jscomp$259$$,$path$jscomp$41$$);else throw $APP.$cljs$core$missing_protocol$$("RegexSchema.-regex-explainer",$JSCompiler_temp$jscomp$375_this$$jscomp$259$$);}return $JSCompiler_temp$jscomp$375_this$$jscomp$259$$};
$malli$core$_regex_transformer$$=function($JSCompiler_temp$jscomp$376_this$$jscomp$265$$,$transformer$jscomp$10$$,$method$jscomp$10$$,$options$jscomp$103$$){if($JSCompiler_temp$jscomp$376_this$$jscomp$265$$!=null&&$JSCompiler_temp$jscomp$376_this$$jscomp$265$$.$malli$core$RegexSchema$_regex_transformer$arity$4$!=null)$JSCompiler_temp$jscomp$376_this$$jscomp$265$$=$JSCompiler_temp$jscomp$376_this$$jscomp$265$$.$malli$core$RegexSchema$_regex_transformer$arity$4$($JSCompiler_temp$jscomp$376_this$$jscomp$265$$,
$transformer$jscomp$10$$,$method$jscomp$10$$,$options$jscomp$103$$);else{var $m__5372__auto__$jscomp$inline_3462_m__5374__auto__$jscomp$inline_3461$$=$malli$core$_regex_transformer$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$376_this$$jscomp$265$$==null?null:$JSCompiler_temp$jscomp$376_this$$jscomp$265$$)];if($m__5372__auto__$jscomp$inline_3462_m__5374__auto__$jscomp$inline_3461$$!=null)$JSCompiler_temp$jscomp$376_this$$jscomp$265$$=$m__5372__auto__$jscomp$inline_3462_m__5374__auto__$jscomp$inline_3461$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_3462_m__5374__auto__$jscomp$inline_3461$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$376_this$$jscomp$265$$,$transformer$jscomp$10$$,$method$jscomp$10$$,$options$jscomp$103$$):$m__5372__auto__$jscomp$inline_3462_m__5374__auto__$jscomp$inline_3461$$($JSCompiler_temp$jscomp$376_this$$jscomp$265$$,$transformer$jscomp$10$$,$method$jscomp$10$$,$options$jscomp$103$$);else if($m__5372__auto__$jscomp$inline_3462_m__5374__auto__$jscomp$inline_3461$$=$malli$core$_regex_transformer$$._,
$m__5372__auto__$jscomp$inline_3462_m__5374__auto__$jscomp$inline_3461$$!=null)$JSCompiler_temp$jscomp$376_this$$jscomp$265$$=$m__5372__auto__$jscomp$inline_3462_m__5374__auto__$jscomp$inline_3461$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_3462_m__5374__auto__$jscomp$inline_3461$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$376_this$$jscomp$265$$,$transformer$jscomp$10$$,$method$jscomp$10$$,$options$jscomp$103$$):$m__5372__auto__$jscomp$inline_3462_m__5374__auto__$jscomp$inline_3461$$($JSCompiler_temp$jscomp$376_this$$jscomp$265$$,
$transformer$jscomp$10$$,$method$jscomp$10$$,$options$jscomp$103$$);else throw $APP.$cljs$core$missing_protocol$$("RegexSchema.-regex-transformer",$JSCompiler_temp$jscomp$376_this$$jscomp$265$$);}return $JSCompiler_temp$jscomp$376_this$$jscomp$265$$};
$malli$core$_regex_min_max$$=function($JSCompiler_temp$jscomp$377_this$$jscomp$267$$,$nested_QMARK_$jscomp$1$$){if($JSCompiler_temp$jscomp$377_this$$jscomp$267$$!=null&&$JSCompiler_temp$jscomp$377_this$$jscomp$267$$.$malli$core$RegexSchema$_regex_min_max$arity$2$!=null)$JSCompiler_temp$jscomp$377_this$$jscomp$267$$=$JSCompiler_temp$jscomp$377_this$$jscomp$267$$.$malli$core$RegexSchema$_regex_min_max$arity$2$($JSCompiler_temp$jscomp$377_this$$jscomp$267$$,$nested_QMARK_$jscomp$1$$);else{var $m__5372__auto__$jscomp$inline_3467_m__5374__auto__$jscomp$inline_3466$$=
$malli$core$_regex_min_max$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$377_this$$jscomp$267$$==null?null:$JSCompiler_temp$jscomp$377_this$$jscomp$267$$)];if($m__5372__auto__$jscomp$inline_3467_m__5374__auto__$jscomp$inline_3466$$!=null)$JSCompiler_temp$jscomp$377_this$$jscomp$267$$=$m__5372__auto__$jscomp$inline_3467_m__5374__auto__$jscomp$inline_3466$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3467_m__5374__auto__$jscomp$inline_3466$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$377_this$$jscomp$267$$,
$nested_QMARK_$jscomp$1$$):$m__5372__auto__$jscomp$inline_3467_m__5374__auto__$jscomp$inline_3466$$($JSCompiler_temp$jscomp$377_this$$jscomp$267$$,$nested_QMARK_$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_3467_m__5374__auto__$jscomp$inline_3466$$=$malli$core$_regex_min_max$$._,$m__5372__auto__$jscomp$inline_3467_m__5374__auto__$jscomp$inline_3466$$!=null)$JSCompiler_temp$jscomp$377_this$$jscomp$267$$=$m__5372__auto__$jscomp$inline_3467_m__5374__auto__$jscomp$inline_3466$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_3467_m__5374__auto__$jscomp$inline_3466$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$377_this$$jscomp$267$$,$nested_QMARK_$jscomp$1$$):$m__5372__auto__$jscomp$inline_3467_m__5374__auto__$jscomp$inline_3466$$($JSCompiler_temp$jscomp$377_this$$jscomp$267$$,$nested_QMARK_$jscomp$1$$);else throw $APP.$cljs$core$missing_protocol$$("RegexSchema.-regex-min-max",$JSCompiler_temp$jscomp$377_this$$jscomp$267$$);}return $JSCompiler_temp$jscomp$377_this$$jscomp$267$$};
$malli$core$_function_schema_QMARK_$$=function($JSCompiler_temp$jscomp$378_this$$jscomp$269$$){if($JSCompiler_temp$jscomp$378_this$$jscomp$269$$!=null&&$JSCompiler_temp$jscomp$378_this$$jscomp$269$$.$malli$core$FunctionSchema$_function_schema_QMARK_$arity$1$!=null)$JSCompiler_temp$jscomp$378_this$$jscomp$269$$=$JSCompiler_temp$jscomp$378_this$$jscomp$269$$.$malli$core$FunctionSchema$_function_schema_QMARK_$arity$1$($JSCompiler_temp$jscomp$378_this$$jscomp$269$$);else{var $m__5372__auto__$jscomp$inline_3471_m__5374__auto__$jscomp$inline_3470$$=
$malli$core$_function_schema_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$378_this$$jscomp$269$$==null?null:$JSCompiler_temp$jscomp$378_this$$jscomp$269$$)];if($m__5372__auto__$jscomp$inline_3471_m__5374__auto__$jscomp$inline_3470$$!=null)$JSCompiler_temp$jscomp$378_this$$jscomp$269$$=$m__5372__auto__$jscomp$inline_3471_m__5374__auto__$jscomp$inline_3470$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3471_m__5374__auto__$jscomp$inline_3470$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$378_this$$jscomp$269$$):
$m__5372__auto__$jscomp$inline_3471_m__5374__auto__$jscomp$inline_3470$$($JSCompiler_temp$jscomp$378_this$$jscomp$269$$);else if($m__5372__auto__$jscomp$inline_3471_m__5374__auto__$jscomp$inline_3470$$=$malli$core$_function_schema_QMARK_$$._,$m__5372__auto__$jscomp$inline_3471_m__5374__auto__$jscomp$inline_3470$$!=null)$JSCompiler_temp$jscomp$378_this$$jscomp$269$$=$m__5372__auto__$jscomp$inline_3471_m__5374__auto__$jscomp$inline_3470$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3471_m__5374__auto__$jscomp$inline_3470$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$378_this$$jscomp$269$$):
$m__5372__auto__$jscomp$inline_3471_m__5374__auto__$jscomp$inline_3470$$($JSCompiler_temp$jscomp$378_this$$jscomp$269$$);else throw $APP.$cljs$core$missing_protocol$$("FunctionSchema.-function-schema?",$JSCompiler_temp$jscomp$378_this$$jscomp$269$$);}return $JSCompiler_temp$jscomp$378_this$$jscomp$269$$};
$malli$core$_function_info$$=function($JSCompiler_temp$jscomp$379_this$$jscomp$273$$){if($JSCompiler_temp$jscomp$379_this$$jscomp$273$$!=null&&$JSCompiler_temp$jscomp$379_this$$jscomp$273$$.$malli$core$FunctionSchema$_function_info$arity$1$!=null)$JSCompiler_temp$jscomp$379_this$$jscomp$273$$=$JSCompiler_temp$jscomp$379_this$$jscomp$273$$.$malli$core$FunctionSchema$_function_info$arity$1$($JSCompiler_temp$jscomp$379_this$$jscomp$273$$);else{var $m__5372__auto__$jscomp$inline_3475_m__5374__auto__$jscomp$inline_3474$$=
$malli$core$_function_info$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$379_this$$jscomp$273$$==null?null:$JSCompiler_temp$jscomp$379_this$$jscomp$273$$)];if($m__5372__auto__$jscomp$inline_3475_m__5374__auto__$jscomp$inline_3474$$!=null)$JSCompiler_temp$jscomp$379_this$$jscomp$273$$=$m__5372__auto__$jscomp$inline_3475_m__5374__auto__$jscomp$inline_3474$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3475_m__5374__auto__$jscomp$inline_3474$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$379_this$$jscomp$273$$):
$m__5372__auto__$jscomp$inline_3475_m__5374__auto__$jscomp$inline_3474$$($JSCompiler_temp$jscomp$379_this$$jscomp$273$$);else if($m__5372__auto__$jscomp$inline_3475_m__5374__auto__$jscomp$inline_3474$$=$malli$core$_function_info$$._,$m__5372__auto__$jscomp$inline_3475_m__5374__auto__$jscomp$inline_3474$$!=null)$JSCompiler_temp$jscomp$379_this$$jscomp$273$$=$m__5372__auto__$jscomp$inline_3475_m__5374__auto__$jscomp$inline_3474$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3475_m__5374__auto__$jscomp$inline_3474$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$379_this$$jscomp$273$$):
$m__5372__auto__$jscomp$inline_3475_m__5374__auto__$jscomp$inline_3474$$($JSCompiler_temp$jscomp$379_this$$jscomp$273$$);else throw $APP.$cljs$core$missing_protocol$$("FunctionSchema.-function-info",$JSCompiler_temp$jscomp$379_this$$jscomp$273$$);}return $JSCompiler_temp$jscomp$379_this$$jscomp$273$$};
$malli$core$_instrument_f$$=function($JSCompiler_temp$jscomp$380_schema$jscomp$15$$,$props$jscomp$3$$,$f$jscomp$384$$,$options$jscomp$105$$){if($JSCompiler_temp$jscomp$380_schema$jscomp$15$$!=null&&$JSCompiler_temp$jscomp$380_schema$jscomp$15$$.$malli$core$FunctionSchema$_instrument_f$arity$4$!=null)$JSCompiler_temp$jscomp$380_schema$jscomp$15$$=$JSCompiler_temp$jscomp$380_schema$jscomp$15$$.$malli$core$FunctionSchema$_instrument_f$arity$4$($JSCompiler_temp$jscomp$380_schema$jscomp$15$$,$props$jscomp$3$$,
$f$jscomp$384$$,$options$jscomp$105$$);else{var $m__5372__auto__$jscomp$inline_3482_m__5374__auto__$jscomp$inline_3481$$=$malli$core$_instrument_f$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$380_schema$jscomp$15$$==null?null:$JSCompiler_temp$jscomp$380_schema$jscomp$15$$)];if($m__5372__auto__$jscomp$inline_3482_m__5374__auto__$jscomp$inline_3481$$!=null)$JSCompiler_temp$jscomp$380_schema$jscomp$15$$=$m__5372__auto__$jscomp$inline_3482_m__5374__auto__$jscomp$inline_3481$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_3482_m__5374__auto__$jscomp$inline_3481$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$380_schema$jscomp$15$$,$props$jscomp$3$$,$f$jscomp$384$$,$options$jscomp$105$$):$m__5372__auto__$jscomp$inline_3482_m__5374__auto__$jscomp$inline_3481$$($JSCompiler_temp$jscomp$380_schema$jscomp$15$$,$props$jscomp$3$$,$f$jscomp$384$$,$options$jscomp$105$$);else if($m__5372__auto__$jscomp$inline_3482_m__5374__auto__$jscomp$inline_3481$$=$malli$core$_instrument_f$$._,$m__5372__auto__$jscomp$inline_3482_m__5374__auto__$jscomp$inline_3481$$!=
null)$JSCompiler_temp$jscomp$380_schema$jscomp$15$$=$m__5372__auto__$jscomp$inline_3482_m__5374__auto__$jscomp$inline_3481$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_3482_m__5374__auto__$jscomp$inline_3481$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$380_schema$jscomp$15$$,$props$jscomp$3$$,$f$jscomp$384$$,$options$jscomp$105$$):$m__5372__auto__$jscomp$inline_3482_m__5374__auto__$jscomp$inline_3481$$($JSCompiler_temp$jscomp$380_schema$jscomp$15$$,$props$jscomp$3$$,
$f$jscomp$384$$,$options$jscomp$105$$);else throw $APP.$cljs$core$missing_protocol$$("FunctionSchema.-instrument-f",$JSCompiler_temp$jscomp$380_schema$jscomp$15$$);}return $JSCompiler_temp$jscomp$380_schema$jscomp$15$$};
$malli$core$_distributive_schema_QMARK_$$=function($JSCompiler_temp$jscomp$381_this$$jscomp$275$$){if($JSCompiler_temp$jscomp$381_this$$jscomp$275$$!=null&&$JSCompiler_temp$jscomp$381_this$$jscomp$275$$.$malli$core$DistributiveSchema$_distributive_schema_QMARK_$arity$1$!=null)$JSCompiler_temp$jscomp$381_this$$jscomp$275$$=$JSCompiler_temp$jscomp$381_this$$jscomp$275$$.$malli$core$DistributiveSchema$_distributive_schema_QMARK_$arity$1$($JSCompiler_temp$jscomp$381_this$$jscomp$275$$);else{var $m__5372__auto__$jscomp$inline_3486_m__5374__auto__$jscomp$inline_3485$$=
$malli$core$_distributive_schema_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$381_this$$jscomp$275$$==null?null:$JSCompiler_temp$jscomp$381_this$$jscomp$275$$)];if($m__5372__auto__$jscomp$inline_3486_m__5374__auto__$jscomp$inline_3485$$!=null)$JSCompiler_temp$jscomp$381_this$$jscomp$275$$=$m__5372__auto__$jscomp$inline_3486_m__5374__auto__$jscomp$inline_3485$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3486_m__5374__auto__$jscomp$inline_3485$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$381_this$$jscomp$275$$):
$m__5372__auto__$jscomp$inline_3486_m__5374__auto__$jscomp$inline_3485$$($JSCompiler_temp$jscomp$381_this$$jscomp$275$$);else if($m__5372__auto__$jscomp$inline_3486_m__5374__auto__$jscomp$inline_3485$$=$malli$core$_distributive_schema_QMARK_$$._,$m__5372__auto__$jscomp$inline_3486_m__5374__auto__$jscomp$inline_3485$$!=null)$JSCompiler_temp$jscomp$381_this$$jscomp$275$$=$m__5372__auto__$jscomp$inline_3486_m__5374__auto__$jscomp$inline_3485$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3486_m__5374__auto__$jscomp$inline_3485$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$381_this$$jscomp$275$$):
$m__5372__auto__$jscomp$inline_3486_m__5374__auto__$jscomp$inline_3485$$($JSCompiler_temp$jscomp$381_this$$jscomp$275$$);else throw $APP.$cljs$core$missing_protocol$$("DistributiveSchema.-distributive-schema?",$JSCompiler_temp$jscomp$381_this$$jscomp$275$$);}return $JSCompiler_temp$jscomp$381_this$$jscomp$275$$};
$malli$core$_distribute_to_children$$=function($JSCompiler_temp$jscomp$382_this$$jscomp$277$$,$f$jscomp$386$$,$options$jscomp$107$$){if($JSCompiler_temp$jscomp$382_this$$jscomp$277$$!=null&&$JSCompiler_temp$jscomp$382_this$$jscomp$277$$.$malli$core$DistributiveSchema$_distribute_to_children$arity$3$!=null)$JSCompiler_temp$jscomp$382_this$$jscomp$277$$=$JSCompiler_temp$jscomp$382_this$$jscomp$277$$.$malli$core$DistributiveSchema$_distribute_to_children$arity$3$($JSCompiler_temp$jscomp$382_this$$jscomp$277$$,
$f$jscomp$386$$,$options$jscomp$107$$);else{var $m__5372__auto__$jscomp$inline_3492_m__5374__auto__$jscomp$inline_3491$$=$malli$core$_distribute_to_children$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$382_this$$jscomp$277$$==null?null:$JSCompiler_temp$jscomp$382_this$$jscomp$277$$)];if($m__5372__auto__$jscomp$inline_3492_m__5374__auto__$jscomp$inline_3491$$!=null)$JSCompiler_temp$jscomp$382_this$$jscomp$277$$=$m__5372__auto__$jscomp$inline_3492_m__5374__auto__$jscomp$inline_3491$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_3492_m__5374__auto__$jscomp$inline_3491$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$382_this$$jscomp$277$$,$f$jscomp$386$$,$options$jscomp$107$$):$m__5372__auto__$jscomp$inline_3492_m__5374__auto__$jscomp$inline_3491$$($JSCompiler_temp$jscomp$382_this$$jscomp$277$$,$f$jscomp$386$$,$options$jscomp$107$$);else if($m__5372__auto__$jscomp$inline_3492_m__5374__auto__$jscomp$inline_3491$$=$malli$core$_distribute_to_children$$._,$m__5372__auto__$jscomp$inline_3492_m__5374__auto__$jscomp$inline_3491$$!=
null)$JSCompiler_temp$jscomp$382_this$$jscomp$277$$=$m__5372__auto__$jscomp$inline_3492_m__5374__auto__$jscomp$inline_3491$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_3492_m__5374__auto__$jscomp$inline_3491$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$382_this$$jscomp$277$$,$f$jscomp$386$$,$options$jscomp$107$$):$m__5372__auto__$jscomp$inline_3492_m__5374__auto__$jscomp$inline_3491$$($JSCompiler_temp$jscomp$382_this$$jscomp$277$$,$f$jscomp$386$$,$options$jscomp$107$$);
else throw $APP.$cljs$core$missing_protocol$$("DistributiveSchema.-distribute-to-children",$JSCompiler_temp$jscomp$382_this$$jscomp$277$$);}return $JSCompiler_temp$jscomp$382_this$$jscomp$277$$};$malli$core$_ref_schema_QMARK_$$=function($x$jscomp$703$$){return $x$jscomp$703$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$703$$.$malli$core$RefSchema$$?!0:!1:!1};
$malli$core$pr_writer_into_schema$$=function($obj$jscomp$107$$,$writer$jscomp$85$$,$opts$jscomp$141$$){$APP.$cljs$core$_write$$($writer$jscomp$85$$,"#IntoSchema ");return $APP.$cljs$core$_pr_writer$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$malli$core$_type$$($obj$jscomp$107$$)],null),$writer$jscomp$85$$,$opts$jscomp$141$$)};
$malli$core$pr_writer_schema$$=function($obj$jscomp$108$$,$writer$jscomp$86$$,$opts$jscomp$142$$){return $APP.$cljs$core$_pr_writer$$($malli$core$_form$$($obj$jscomp$108$$),$writer$jscomp$86$$,$opts$jscomp$142$$)};
$malli$core$Tag$$=function($key$jscomp$187$$,$value$jscomp$233$$,$__meta$jscomp$2$$,$__extmap$jscomp$2$$,$__hash$jscomp$53$$){this.key=$key$jscomp$187$$;this.value=$value$jscomp$233$$;this.$__meta$=$__meta$jscomp$2$$;this.$__extmap$=$__extmap$jscomp$2$$;this.$__hash$=$__hash$jscomp$53$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$malli$core$tag$$=function($key$jscomp$189$$,$value$jscomp$235$$){return new $malli$core$Tag$$($key$jscomp$189$$,$value$jscomp$235$$,null,null,null)};$malli$core$tag_QMARK_$$=function($x$jscomp$709$$){return $x$jscomp$709$$ instanceof $malli$core$Tag$$};
$malli$core$Tags$$=function($values$jscomp$27$$,$__meta$jscomp$3$$,$__extmap$jscomp$3$$,$__hash$jscomp$54$$){this.values=$values$jscomp$27$$;this.$__meta$=$__meta$jscomp$3$$;this.$__extmap$=$__extmap$jscomp$3$$;this.$__hash$=$__hash$jscomp$54$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};$malli$core$tags$$=function($values$jscomp$29$$){return new $malli$core$Tags$$($values$jscomp$29$$,null,null,null)};
$malli$core$tags_QMARK_$$=function($x$jscomp$710$$){return $x$jscomp$710$$ instanceof $malli$core$Tags$$};
$malli$core$_exception$$=function($type$jscomp$190$$,$data$jscomp$98$$){return $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$190$$),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$type$jscomp$190$$,$APP.$cljs$cst$141$message$$,$type$jscomp$190$$,$APP.$cljs$cst$142$data$$,$data$jscomp$98$$],null))};
$malli$core$_safe_pred$$=function($f$jscomp$387$$){return function($p1__31442_SHARP_$$){try{return $APP.$cljs$core$boolean$0$$($f$jscomp$387$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$387$$.$cljs$core$IFn$_invoke$arity$1$($p1__31442_SHARP_$$):$f$jscomp$387$$($p1__31442_SHARP_$$))}catch($e31444$$){if($e31444$$ instanceof Error)return!1;throw $e31444$$;}}};
$malli$core$_keyword__GT_string$$=function($x$jscomp$712$$){if($x$jscomp$712$$ instanceof $APP.$cljs$core$Keyword$$){var $temp__5823__auto__$jscomp$46$$=$APP.$cljs$core$namespace$$($x$jscomp$712$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$46$$)?[$temp__5823__auto__$jscomp$46$$,"/",$APP.$cljs$core$name$$($x$jscomp$712$$)].join(""):$APP.$cljs$core$name$$($x$jscomp$712$$)}return $x$jscomp$712$$};
$malli$core$_guard$$=function($pred$jscomp$28$$,$tf$jscomp$4$$){return $APP.$cljs$core$truth_$$($tf$jscomp$4$$)?function($x$jscomp$713$$){return $APP.$cljs$core$truth_$$($pred$jscomp$28$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$28$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$713$$):$pred$jscomp$28$$($x$jscomp$713$$))?$tf$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$tf$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$713$$):$tf$jscomp$4$$($x$jscomp$713$$):$x$jscomp$713$$}:null};
$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$=function($type$jscomp$194$$,$properties$jscomp$7$$,$children$jscomp$8$$,$min$jscomp$6$$,$max$jscomp$7$$){var $temp__5825__auto__$jscomp$57$$=function(){var $and__5023__auto__$jscomp$59$$=$APP.$cljs$core$sequential_QMARK_$$($children$jscomp$8$$)||$children$jscomp$8$$==null;return $and__5023__auto__$jscomp$59$$?$APP.$cljs$core$count$$($children$jscomp$8$$):$and__5023__auto__$jscomp$59$$}();$APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$57$$)&&
$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$90$$=$APP.$cljs$core$truth_$$($min$jscomp$6$$)?$temp__5825__auto__$jscomp$57$$<$min$jscomp$6$$:$min$jscomp$6$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$90$$)?$or__5025__auto__$jscomp$90$$:$APP.$cljs$core$truth_$$($max$jscomp$7$$)?$temp__5825__auto__$jscomp$57$$>$max$jscomp$7$$:$max$jscomp$7$$}())&&$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$340$malli_DOT_core_SLASH_child_error$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$type$jscomp$194$$,$cljs$cst$341$properties$$,$properties$jscomp$7$$,$APP.$cljs$cst$342$children$$,$children$jscomp$8$$,$APP.$cljs$cst$338$min$$,$min$jscomp$6$$,$APP.$cljs$cst$339$max$$,$max$jscomp$7$$],null))};
$malli$core$_pointer$$=function($G__31470$jscomp$inline_3496_JSCompiler_inline_result$jscomp$386_id$jscomp$9$$,$schema$jscomp$16$$,$options$jscomp$109$$){$G__31470$jscomp$inline_3496_JSCompiler_inline_result$jscomp$386_id$jscomp$9$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$G__31470$jscomp$inline_3496_JSCompiler_inline_result$jscomp$386_id$jscomp$9$$],null);$G__31470$jscomp$inline_3496_JSCompiler_inline_result$jscomp$386_id$jscomp$9$$=$malli$core$_schema_schema$$.$cljs$core$IFn$_invoke$arity$1$?
$malli$core$_schema_schema$$.$cljs$core$IFn$_invoke$arity$1$($G__31470$jscomp$inline_3496_JSCompiler_inline_result$jscomp$386_id$jscomp$9$$):$malli$core$_schema_schema$$($G__31470$jscomp$inline_3496_JSCompiler_inline_result$jscomp$386_id$jscomp$9$$);return $malli$core$_into_schema$$($G__31470$jscomp$inline_3496_JSCompiler_inline_result$jscomp$386_id$jscomp$9$$,null,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$schema$jscomp$16$$],null),$options$jscomp$109$$)};
$malli$core$_reference_QMARK_$$=function($_QMARK_schema$$){return typeof $_QMARK_schema$$==="string"||$cljs$core$qualified_ident_QMARK_$$($_QMARK_schema$$)||$_QMARK_schema$$ instanceof $APP.$cljs$core$Var$$};$malli$core$_boolean_fn$$=function($x$jscomp$714$$){return $APP.$cljs$core$boolean_QMARK_$$($x$jscomp$714$$)?$APP.$cljs$core$constantly$$($x$jscomp$714$$):$cljs$core$ifn_QMARK_$$($x$jscomp$714$$)?$x$jscomp$714$$:$APP.$cljs$core$constantly$$(!1)};
$malli$core$_infer$$=function($children$jscomp$9$$){var $G__31496_G__31496__$1_fs__$1$jscomp$2_seq__31512_seq__31512__$1$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,$APP.$cljs$core$string_QMARK_$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$221$keyword$$,
$cljs$core$keyword_QMARK_$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$219$symbol$$,$cljs$core$symbol_QMARK_$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$344$int$$,$APP.$cljs$core$int_QMARK_$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$345$double$$,$cljs$core$float_QMARK_$$],null)],null),
$first__31513_s__$1$jscomp$10_seq__31499$$=$APP.$cljs$core$seq$$($G__31496_G__31496__$1_fs__$1$jscomp$2_seq__31512_seq__31512__$1$$),$f__$1$jscomp$18_first__31500_vec__31514$$=$APP.$cljs$core$first$$($first__31513_s__$1$jscomp$10_seq__31499$$);$APP.$cljs$core$next$$($first__31513_s__$1$jscomp$10_seq__31499$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f__$1$jscomp$18_first__31500_vec__31514$$,0,null);for($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f__$1$jscomp$18_first__31500_vec__31514$$,
1,null);;){$G__31496_G__31496__$1_fs__$1$jscomp$2_seq__31512_seq__31512__$1$$=$APP.$cljs$core$seq$$($G__31496_G__31496__$1_fs__$1$jscomp$2_seq__31512_seq__31512__$1$$);$first__31513_s__$1$jscomp$10_seq__31499$$=$APP.$cljs$core$first$$($G__31496_G__31496__$1_fs__$1$jscomp$2_seq__31512_seq__31512__$1$$);$G__31496_G__31496__$1_fs__$1$jscomp$2_seq__31512_seq__31512__$1$$=$APP.$cljs$core$next$$($G__31496_G__31496__$1_fs__$1$jscomp$2_seq__31512_seq__31512__$1$$);$f__$1$jscomp$18_first__31500_vec__31514$$=
$first__31513_s__$1$jscomp$10_seq__31499$$;$first__31513_s__$1$jscomp$10_seq__31499$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f__$1$jscomp$18_first__31500_vec__31514$$,0,null);$f__$1$jscomp$18_first__31500_vec__31514$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f__$1$jscomp$18_first__31500_vec__31514$$,1,null);if($APP.$cljs$core$every_QMARK_$$($f__$1$jscomp$18_first__31500_vec__31514$$,$children$jscomp$9$$))return $first__31513_s__$1$jscomp$10_seq__31499$$;if(!$G__31496_G__31496__$1_fs__$1$jscomp$2_seq__31512_seq__31512__$1$$)return null}};
$malli$core$_update$$=function($x$jscomp$718$$,$k$jscomp$358$$,$JSCompiler_inline_result$jscomp$390_f$jscomp$392$$){var $JSCompiler_temp_const$jscomp$388$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$G__31588$jscomp$inline_3504$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$718$$,$k$jscomp$358$$);$JSCompiler_inline_result$jscomp$390_f$jscomp$392$$=$JSCompiler_inline_result$jscomp$390_f$jscomp$392$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$390_f$jscomp$392$$.$cljs$core$IFn$_invoke$arity$1$($G__31588$jscomp$inline_3504$$):
$JSCompiler_inline_result$jscomp$390_f$jscomp$392$$($G__31588$jscomp$inline_3504$$);return $JSCompiler_temp_const$jscomp$388$$.call($APP.$cljs$core$assoc$$,$x$jscomp$718$$,$k$jscomp$358$$,$JSCompiler_inline_result$jscomp$390_f$jscomp$392$$)};$malli$core$_equals$$=function($x$jscomp$719$$,$y$jscomp$277$$){return $x$jscomp$719$$===$y$jscomp$277$$||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$719$$,$y$jscomp$277$$)};
$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$393$$,$os$jscomp$3$$){return $malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$393$$,$os$jscomp$3$$)};
$malli$core$_memoize$$=function($f$jscomp$394$$){var $value$jscomp$236$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);return function(){var $or__5025__auto__$jscomp$91$$=$APP.$cljs$core$_deref$$($value$jscomp$236$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$91$$)?$or__5025__auto__$jscomp$91$$:$APP.$cljs$core$reset_BANG_$$($value$jscomp$236$$,$f$jscomp$394$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$394$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$394$$())}};
$malli$core$_group_by_arity_BANG_$$=function($infos$$){var $aritys$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$19$$,$map__31614__$1_p__31613$$){$map__31614__$1_p__31613$$=$APP.$cljs$core$__destructure_map$$($map__31614__$1_p__31613$$);var $min$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__31614__$1_p__31613$$,$APP.$cljs$cst$338$min$$),
$arity$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__31614__$1_p__31613$$,$cljs$cst$346$arity$$),$vararg$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$347$varargs$$,$arity$$),$min__$1$$=$APP.$cljs$core$truth_$$(function(){if($vararg$$){var $fexpr__31618$$=$APP.$cljs$core$_deref$$($aritys$$);return $fexpr__31618$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__31618$$.$cljs$core$IFn$_invoke$arity$1$($min$jscomp$7$$):$fexpr__31618$$($min$jscomp$7$$)}return $vararg$$}())?
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$max$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$int_QMARK_$$,$APP.$cljs$core$_deref$$($aritys$$)))+1:$min$jscomp$7$$;if($APP.$cljs$core$truth_$$(function(){if($vararg$$){var $fexpr__31620$$=$APP.$cljs$core$_deref$$($aritys$$);return $fexpr__31620$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__31620$$.$cljs$core$IFn$_invoke$arity$1$($arity$$):$fexpr__31620$$($arity$$)}return $vararg$$}()))return $malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$348$malli_DOT_core_SLASH_multiple_varargs$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$349$infos$$,$infos$$],null));if($APP.$cljs$core$truth_$$(function(){var $fexpr__31623$$=$APP.$cljs$core$_deref$$($aritys$$);return $fexpr__31623$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__31623$$.$cljs$core$IFn$_invoke$arity$1$($min__$1$$):$fexpr__31623$$($min__$1$$)}()))return $malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$350$malli_DOT_core_SLASH_duplicate_arities$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$349$infos$$,
$infos$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($aritys$$,$APP.$cljs$core$conj$$,$arity$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$19$$,$arity$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__31614__$1_p__31613$$,$APP.$cljs$cst$338$min$$,$min__$1$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$infos$$)};
$malli$core$_re_min_max$$=function($f$jscomp$395$$,$map__31637__$1_max_SINGLEQUOTE__p__31635$$,$child$jscomp$4_map__31640_map__31640__$1_max_SINGLEQUOTE__SINGLEQUOTE_$$){$map__31637__$1_max_SINGLEQUOTE__p__31635$$=$APP.$cljs$core$__destructure_map$$($map__31637__$1_max_SINGLEQUOTE__p__31635$$);var $G__31641_G__31642$jscomp$inline_11403_JSCompiler_inline_result$jscomp$10670_min_SINGLEQUOTE_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__31637__$1_max_SINGLEQUOTE__p__31635$$,$APP.$cljs$cst$338$min$$);
$map__31637__$1_max_SINGLEQUOTE__p__31635$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__31637__$1_max_SINGLEQUOTE__p__31635$$,$APP.$cljs$cst$339$max$$);$child$jscomp$4_map__31640_map__31640__$1_max_SINGLEQUOTE__SINGLEQUOTE_$$=$malli$core$_regex_min_max$$($child$jscomp$4_map__31640_map__31640__$1_max_SINGLEQUOTE__SINGLEQUOTE_$$,!0);$child$jscomp$4_map__31640_map__31640__$1_max_SINGLEQUOTE__SINGLEQUOTE_$$=$APP.$cljs$core$__destructure_map$$($child$jscomp$4_map__31640_map__31640__$1_max_SINGLEQUOTE__SINGLEQUOTE_$$);
var $min_SINGLEQUOTE__SINGLEQUOTE_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($child$jscomp$4_map__31640_map__31640__$1_max_SINGLEQUOTE__SINGLEQUOTE_$$,$APP.$cljs$cst$338$min$$);$child$jscomp$4_map__31640_map__31640__$1_max_SINGLEQUOTE__SINGLEQUOTE_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($child$jscomp$4_map__31640_map__31640__$1_max_SINGLEQUOTE__SINGLEQUOTE_$$,$APP.$cljs$cst$339$max$$);$G__31641_G__31642$jscomp$inline_11403_JSCompiler_inline_result$jscomp$10670_min_SINGLEQUOTE_$$=
$APP.$cljs$core$truth_$$($G__31641_G__31642$jscomp$inline_11403_JSCompiler_inline_result$jscomp$10670_min_SINGLEQUOTE_$$)?$G__31641_G__31642$jscomp$inline_11403_JSCompiler_inline_result$jscomp$10670_min_SINGLEQUOTE_$$:0;$G__31641_G__31642$jscomp$inline_11403_JSCompiler_inline_result$jscomp$10670_min_SINGLEQUOTE_$$=$f$jscomp$395$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$395$$.$cljs$core$IFn$_invoke$arity$2$($G__31641_G__31642$jscomp$inline_11403_JSCompiler_inline_result$jscomp$10670_min_SINGLEQUOTE_$$,
$min_SINGLEQUOTE__SINGLEQUOTE_$$):$f$jscomp$395$$($G__31641_G__31642$jscomp$inline_11403_JSCompiler_inline_result$jscomp$10670_min_SINGLEQUOTE_$$,$min_SINGLEQUOTE__SINGLEQUOTE_$$);$G__31641_G__31642$jscomp$inline_11403_JSCompiler_inline_result$jscomp$10670_min_SINGLEQUOTE_$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$338$min$$,$G__31641_G__31642$jscomp$inline_11403_JSCompiler_inline_result$jscomp$10670_min_SINGLEQUOTE_$$],null);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__31637__$1_max_SINGLEQUOTE__p__31635$$)?
$child$jscomp$4_map__31640_map__31640__$1_max_SINGLEQUOTE__SINGLEQUOTE_$$:$map__31637__$1_max_SINGLEQUOTE__p__31635$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__31641_G__31642$jscomp$inline_11403_JSCompiler_inline_result$jscomp$10670_min_SINGLEQUOTE_$$,$APP.$cljs$cst$339$max$$,$f$jscomp$395$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$395$$.$cljs$core$IFn$_invoke$arity$2$($map__31637__$1_max_SINGLEQUOTE__p__31635$$,$child$jscomp$4_map__31640_map__31640__$1_max_SINGLEQUOTE__SINGLEQUOTE_$$):
$f$jscomp$395$$($map__31637__$1_max_SINGLEQUOTE__p__31635$$,$child$jscomp$4_map__31640_map__31640__$1_max_SINGLEQUOTE__SINGLEQUOTE_$$)):$G__31641_G__31642$jscomp$inline_11403_JSCompiler_inline_result$jscomp$10670_min_SINGLEQUOTE_$$};
$malli$core$_re_alt_min_max$$=function($map__31647__$1_max_SINGLEQUOTE_$jscomp$1_p__31646$$,$child$jscomp$5_map__31649_min_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1$$){$map__31647__$1_max_SINGLEQUOTE_$jscomp$1_p__31646$$=$APP.$cljs$core$__destructure_map$$($map__31647__$1_max_SINGLEQUOTE_$jscomp$1_p__31646$$);var $G__31650_min_SINGLEQUOTE_$jscomp$1_x__5113__auto__$jscomp$inline_11405$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__31647__$1_max_SINGLEQUOTE_$jscomp$1_p__31646$$,$APP.$cljs$cst$338$min$$);
$map__31647__$1_max_SINGLEQUOTE_$jscomp$1_p__31646$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__31647__$1_max_SINGLEQUOTE_$jscomp$1_p__31646$$,$APP.$cljs$cst$339$max$$);$child$jscomp$5_map__31649_min_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1$$=$malli$core$_regex_min_max$$($child$jscomp$5_map__31649_min_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1$$,!0);var $map__31649__$1_max_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($child$jscomp$5_map__31649_min_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1$$);
$child$jscomp$5_map__31649_min_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__31649__$1_max_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1$$,$APP.$cljs$cst$338$min$$);$map__31649__$1_max_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__31649__$1_max_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1$$,$APP.$cljs$cst$339$max$$);$G__31650_min_SINGLEQUOTE_$jscomp$1_x__5113__auto__$jscomp$inline_11405$$=$APP.$cljs$core$truth_$$($G__31650_min_SINGLEQUOTE_$jscomp$1_x__5113__auto__$jscomp$inline_11405$$)?
$G__31650_min_SINGLEQUOTE_$jscomp$1_x__5113__auto__$jscomp$inline_11405$$:$malli$impl$util$_PLUS_max_size_PLUS_$$;$G__31650_min_SINGLEQUOTE_$jscomp$1_x__5113__auto__$jscomp$inline_11405$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$338$min$$,$G__31650_min_SINGLEQUOTE_$jscomp$1_x__5113__auto__$jscomp$inline_11405$$<$child$jscomp$5_map__31649_min_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1$$?$G__31650_min_SINGLEQUOTE_$jscomp$1_x__5113__auto__$jscomp$inline_11405$$:$child$jscomp$5_map__31649_min_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1$$],
null);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__31647__$1_max_SINGLEQUOTE_$jscomp$1_p__31646$$)?$map__31649__$1_max_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1$$:$map__31647__$1_max_SINGLEQUOTE_$jscomp$1_p__31646$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__31650_min_SINGLEQUOTE_$jscomp$1_x__5113__auto__$jscomp$inline_11405$$,$APP.$cljs$cst$339$max$$,$map__31647__$1_max_SINGLEQUOTE_$jscomp$1_p__31646$$>$map__31649__$1_max_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1$$?$map__31647__$1_max_SINGLEQUOTE_$jscomp$1_p__31646$$:
$map__31649__$1_max_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1$$):$G__31650_min_SINGLEQUOTE_$jscomp$1_x__5113__auto__$jscomp$inline_11405$$};$malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$=function($registry$jscomp$2$$,$vname$$,$vval$$){return $malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$04$$($registry$jscomp$2$$,$vname$$,$vval$$,$vval$$)};
$malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$04$$=function($registry$jscomp$3$$,$vname$jscomp$1$$,$vval$jscomp$1$$,$G__31666$jscomp$inline_3506_pred$jscomp$29_schema$jscomp$17$$){$G__31666$jscomp$inline_3506_pred$jscomp$29_schema$jscomp$17$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$vname$jscomp$1$$,$APP.$cljs$cst$351$pred$$,$G__31666$jscomp$inline_3506_pred$jscomp$29_schema$jscomp$17$$],null);$G__31666$jscomp$inline_3506_pred$jscomp$29_schema$jscomp$17$$=
$malli$core$_simple_schema$$.$cljs$core$IFn$_invoke$arity$1$?$malli$core$_simple_schema$$.$cljs$core$IFn$_invoke$arity$1$($G__31666$jscomp$inline_3506_pred$jscomp$29_schema$jscomp$17$$):$malli$core$_simple_schema$$($G__31666$jscomp$inline_3506_pred$jscomp$29_schema$jscomp$17$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($registry$jscomp$3$$,$vname$jscomp$1$$,$G__31666$jscomp$inline_3506_pred$jscomp$29_schema$jscomp$17$$),
$vval$jscomp$1$$,$G__31666$jscomp$inline_3506_pred$jscomp$29_schema$jscomp$17$$)};
$malli$core$_registry$cljs$0core$0IFn$0_invoke$0arity$01$$=function($opts$jscomp$143_or__5025__auto__$jscomp$94$$){$opts$jscomp$143_or__5025__auto__$jscomp$94$$=$APP.$cljs$core$truth_$$($opts$jscomp$143_or__5025__auto__$jscomp$94$$)?$malli$registry$registry$$($opts$jscomp$143_or__5025__auto__$jscomp$94$$.$cljs$core$IFn$_invoke$arity$1$?$opts$jscomp$143_or__5025__auto__$jscomp$94$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$352$registry$$):$opts$jscomp$143_or__5025__auto__$jscomp$94$$($cljs$cst$352$registry$$)):
null;return $APP.$cljs$core$truth_$$($opts$jscomp$143_or__5025__auto__$jscomp$94$$)?$opts$jscomp$143_or__5025__auto__$jscomp$94$$:$malli$core$default_registry$$};
$malli$core$_property_registry$$=function($m$jscomp$125$$,$options$jscomp$111$$,$f$jscomp$396$$){var $options__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$111$$,$cljs$cst$353$malli_DOT_core_SLASH_allow_invalid_refs$$,!0);return $APP.$cljs$core$reduce_kv$$(function($acc$jscomp$20$$,$k$jscomp$359$$,$G__31670$jscomp$inline_3508_JSCompiler_inline_result$jscomp$393_v$jscomp$177$$){var $JSCompiler_temp_const$jscomp$391$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;
$G__31670$jscomp$inline_3508_JSCompiler_inline_result$jscomp$393_v$jscomp$177$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($G__31670$jscomp$inline_3508_JSCompiler_inline_result$jscomp$393_v$jscomp$177$$,$options__$1$$):$APP.$malli$core$schema$$($G__31670$jscomp$inline_3508_JSCompiler_inline_result$jscomp$393_v$jscomp$177$$,$options__$1$$);$G__31670$jscomp$inline_3508_JSCompiler_inline_result$jscomp$393_v$jscomp$177$$=$f$jscomp$396$$.$cljs$core$IFn$_invoke$arity$1$?
$f$jscomp$396$$.$cljs$core$IFn$_invoke$arity$1$($G__31670$jscomp$inline_3508_JSCompiler_inline_result$jscomp$393_v$jscomp$177$$):$f$jscomp$396$$($G__31670$jscomp$inline_3508_JSCompiler_inline_result$jscomp$393_v$jscomp$177$$);return $JSCompiler_temp_const$jscomp$391$$.call($APP.$cljs$core$assoc$$,$acc$jscomp$20$$,$k$jscomp$359$$,$G__31670$jscomp$inline_3508_JSCompiler_inline_result$jscomp$393_v$jscomp$177$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$m$jscomp$125$$)};
$malli$core$_lookup$$=function($_QMARK_schema$jscomp$1$$,$options$jscomp$113$$){var $registry$jscomp$4_temp__5829__auto__$jscomp$4$$=$malli$core$_registry$cljs$0core$0IFn$0_invoke$0arity$01$$($options$jscomp$113$$),$or__5025__auto__$jscomp$95$$=$malli$registry$_schema$$($registry$jscomp$4_temp__5829__auto__$jscomp$4$$,$_QMARK_schema$jscomp$1$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$95$$))return $or__5025__auto__$jscomp$95$$;$registry$jscomp$4_temp__5829__auto__$jscomp$4$$=$registry$jscomp$4_temp__5829__auto__$jscomp$4$$==
null?null:$malli$registry$_schema$$($registry$jscomp$4_temp__5829__auto__$jscomp$4$$,$APP.$cljs$core$type$$($_QMARK_schema$jscomp$1$$));if($registry$jscomp$4_temp__5829__auto__$jscomp$4$$==null)return null;$APP.$cljs$core$truth_$$($malli$core$schema_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$malli$core$schema_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($_QMARK_schema$jscomp$1$$):$malli$core$schema_QMARK_$$($_QMARK_schema$jscomp$1$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($registry$jscomp$4_temp__5829__auto__$jscomp$4$$,
$malli$core$_parent$$($_QMARK_schema$jscomp$1$$))&&$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$357$malli_DOT_core_SLASH_infinitely_expanding_schema$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$298$schema$$,$_QMARK_schema$jscomp$1$$],null));return $malli$core$_into_schema$$($registry$jscomp$4_temp__5829__auto__$jscomp$4$$,null,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$_QMARK_schema$jscomp$1$$],null),
$options$jscomp$113$$)};
$malli$core$_lookup_BANG_$$=function($G__31681__QMARK_schema$jscomp$2$$,$G__34723__QMARK_form$$,$G__34724_f$jscomp$400$$,$G__34725_rec$$,$G__34726_options$jscomp$114$$){for(;;){var $and__5023__auto__$jscomp$inline_3510_and__5023__auto____$1$jscomp$inline_3511_or__5025__auto__$jscomp$96_temp__5823__auto__$jscomp$47$$=$G__34724_f$jscomp$400$$;$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_3510_and__5023__auto____$1$jscomp$inline_3511_or__5025__auto__$jscomp$96_temp__5823__auto__$jscomp$47$$)&&($and__5023__auto__$jscomp$inline_3510_and__5023__auto____$1$jscomp$inline_3511_or__5025__auto__$jscomp$96_temp__5823__auto__$jscomp$47$$=
$G__34724_f$jscomp$400$$.$cljs$core$IFn$_invoke$arity$1$?$G__34724_f$jscomp$400$$.$cljs$core$IFn$_invoke$arity$1$($G__31681__QMARK_schema$jscomp$2$$):$G__34724_f$jscomp$400$$($G__31681__QMARK_schema$jscomp$2$$),$and__5023__auto__$jscomp$inline_3510_and__5023__auto____$1$jscomp$inline_3511_or__5025__auto__$jscomp$96_temp__5823__auto__$jscomp$47$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_3510_and__5023__auto____$1$jscomp$inline_3511_or__5025__auto__$jscomp$96_temp__5823__auto__$jscomp$47$$)?
$G__31681__QMARK_schema$jscomp$2$$:$and__5023__auto__$jscomp$inline_3510_and__5023__auto____$1$jscomp$inline_3511_or__5025__auto__$jscomp$96_temp__5823__auto__$jscomp$47$$);if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_3510_and__5023__auto____$1$jscomp$inline_3511_or__5025__auto__$jscomp$96_temp__5823__auto__$jscomp$47$$))return $and__5023__auto__$jscomp$inline_3510_and__5023__auto____$1$jscomp$inline_3511_or__5025__auto__$jscomp$96_temp__5823__auto__$jscomp$47$$;$and__5023__auto__$jscomp$inline_3510_and__5023__auto____$1$jscomp$inline_3511_or__5025__auto__$jscomp$96_temp__5823__auto__$jscomp$47$$=
$malli$core$_lookup$$($G__31681__QMARK_schema$jscomp$2$$,$G__34726_options$jscomp$114$$);if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_3510_and__5023__auto____$1$jscomp$inline_3511_or__5025__auto__$jscomp$96_temp__5823__auto__$jscomp$47$$))if($G__31681__QMARK_schema$jscomp$2$$=$and__5023__auto__$jscomp$inline_3510_and__5023__auto____$1$jscomp$inline_3511_or__5025__auto__$jscomp$96_temp__5823__auto__$jscomp$47$$,$APP.$cljs$core$truth_$$($G__34725_rec$$))continue;else return $G__31681__QMARK_schema$jscomp$2$$;
else return $malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$358$malli_DOT_core_SLASH_invalid_schema$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$298$schema$$,$G__31681__QMARK_schema$jscomp$2$$,$APP.$cljs$cst$179$form$$,$G__34723__QMARK_form$$],null));break}};$malli$core$_create_cache$$=function(){return $APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$malli$core$_cached$$=function($fexpr__31686_s$jscomp$303$$,$k$jscomp$363$$,$f$jscomp$402$$){if($fexpr__31686_s$jscomp$303$$!=null&&$APP.$cljs$core$PROTOCOL_SENTINEL$$===$fexpr__31686_s$jscomp$303$$.$malli$core$Cached$$){var $c$jscomp$181$$=$malli$core$_cache$$($fexpr__31686_s$jscomp$303$$);var $fexpr__31685$jscomp$inline_3513_or__5025__auto__$jscomp$98$$=$APP.$cljs$core$_deref$$($c$jscomp$181$$);$fexpr__31685$jscomp$inline_3513_or__5025__auto__$jscomp$98$$=$fexpr__31685$jscomp$inline_3513_or__5025__auto__$jscomp$98$$.$cljs$core$IFn$_invoke$arity$1$?
$fexpr__31685$jscomp$inline_3513_or__5025__auto__$jscomp$98$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$363$$):$fexpr__31685$jscomp$inline_3513_or__5025__auto__$jscomp$98$$($k$jscomp$363$$);if($APP.$cljs$core$truth_$$($fexpr__31685$jscomp$inline_3513_or__5025__auto__$jscomp$98$$))return $fexpr__31685$jscomp$inline_3513_or__5025__auto__$jscomp$98$$;$fexpr__31686_s$jscomp$303$$=$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($c$jscomp$181$$,$APP.$cljs$core$assoc$$,$k$jscomp$363$$,$f$jscomp$402$$.$cljs$core$IFn$_invoke$arity$1$?
$f$jscomp$402$$.$cljs$core$IFn$_invoke$arity$1$($fexpr__31686_s$jscomp$303$$):$f$jscomp$402$$($fexpr__31686_s$jscomp$303$$));return $fexpr__31686_s$jscomp$303$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__31686_s$jscomp$303$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$363$$):$fexpr__31686_s$jscomp$303$$($k$jscomp$363$$)}return $f$jscomp$402$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$402$$.$cljs$core$IFn$_invoke$arity$1$($fexpr__31686_s$jscomp$303$$):$f$jscomp$402$$($fexpr__31686_s$jscomp$303$$)};
$malli$core$_create_form$$=function($G__31693$jscomp$inline_11414_JSCompiler_inline_result$jscomp$inline_11413_type$jscomp$196$$,$JSCompiler_temp$jscomp$395_fchild$jscomp$inline_11412_properties$jscomp$10_properties$jscomp$inline_11408$$,$JSCompiler_inline_result$jscomp$10672_children$jscomp$11$$,$has_children$jscomp$inline_11410_options$jscomp$116$$){if($APP.$cljs$core$seq$$($JSCompiler_temp$jscomp$395_fchild$jscomp$inline_11412_properties$jscomp$10_properties$jscomp$inline_11408$$)){var $has_properties$jscomp$inline_11411_registry$jscomp$inline_3517$$=
$cljs$cst$352$registry$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$395_fchild$jscomp$inline_11412_properties$jscomp$10_properties$jscomp$inline_11408$$);$JSCompiler_temp$jscomp$395_fchild$jscomp$inline_11412_properties$jscomp$10_properties$jscomp$inline_11408$$=$APP.$cljs$core$truth_$$($has_properties$jscomp$inline_11411_registry$jscomp$inline_3517$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$395_fchild$jscomp$inline_11412_properties$jscomp$10_properties$jscomp$inline_11408$$,
$cljs$cst$352$registry$$,$malli$core$_property_registry$$($has_properties$jscomp$inline_11411_registry$jscomp$inline_3517$$,$has_children$jscomp$inline_11410_options$jscomp$116$$,$malli$core$_form$$)):$JSCompiler_temp$jscomp$395_fchild$jscomp$inline_11412_properties$jscomp$10_properties$jscomp$inline_11408$$}else $JSCompiler_temp$jscomp$395_fchild$jscomp$inline_11412_properties$jscomp$10_properties$jscomp$inline_11408$$=null;$has_children$jscomp$inline_11410_options$jscomp$116$$=$APP.$cljs$core$seq$$($JSCompiler_inline_result$jscomp$10672_children$jscomp$11$$);
($has_properties$jscomp$inline_11411_registry$jscomp$inline_3517$$=$APP.$cljs$core$seq$$($JSCompiler_temp$jscomp$395_fchild$jscomp$inline_11412_properties$jscomp$10_properties$jscomp$inline_11408$$))&&$has_children$jscomp$inline_11410_options$jscomp$116$$?$JSCompiler_inline_result$jscomp$10672_children$jscomp$11$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__31693$jscomp$inline_11414_JSCompiler_inline_result$jscomp$inline_11413_type$jscomp$196$$,
$JSCompiler_temp$jscomp$395_fchild$jscomp$inline_11412_properties$jscomp$10_properties$jscomp$inline_11408$$],null),$JSCompiler_inline_result$jscomp$10672_children$jscomp$11$$):$has_properties$jscomp$inline_11411_registry$jscomp$inline_3517$$?$JSCompiler_inline_result$jscomp$10672_children$jscomp$11$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__31693$jscomp$inline_11414_JSCompiler_inline_result$jscomp$inline_11413_type$jscomp$196$$,$JSCompiler_temp$jscomp$395_fchild$jscomp$inline_11412_properties$jscomp$10_properties$jscomp$inline_11408$$],
null):$has_children$jscomp$inline_11410_options$jscomp$116$$?($JSCompiler_temp$jscomp$395_fchild$jscomp$inline_11412_properties$jscomp$10_properties$jscomp$inline_11408$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$10672_children$jscomp$11$$,0),$G__31693$jscomp$inline_11414_JSCompiler_inline_result$jscomp$inline_11413_type$jscomp$196$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__31693$jscomp$inline_11414_JSCompiler_inline_result$jscomp$inline_11413_type$jscomp$196$$],
null),$G__31693$jscomp$inline_11414_JSCompiler_inline_result$jscomp$inline_11413_type$jscomp$196$$=$APP.$cljs$core$map_QMARK_$$($JSCompiler_temp$jscomp$395_fchild$jscomp$inline_11412_properties$jscomp$10_properties$jscomp$inline_11408$$)||$JSCompiler_temp$jscomp$395_fchild$jscomp$inline_11412_properties$jscomp$10_properties$jscomp$inline_11408$$==null?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__31693$jscomp$inline_11414_JSCompiler_inline_result$jscomp$inline_11413_type$jscomp$196$$,
null):$G__31693$jscomp$inline_11414_JSCompiler_inline_result$jscomp$inline_11413_type$jscomp$196$$,$JSCompiler_inline_result$jscomp$10672_children$jscomp$11$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$G__31693$jscomp$inline_11414_JSCompiler_inline_result$jscomp$inline_11413_type$jscomp$196$$,$JSCompiler_inline_result$jscomp$10672_children$jscomp$11$$)):$JSCompiler_inline_result$jscomp$10672_children$jscomp$11$$=$G__31693$jscomp$inline_11414_JSCompiler_inline_result$jscomp$inline_11413_type$jscomp$196$$;
return $JSCompiler_inline_result$jscomp$10672_children$jscomp$11$$};$malli$core$_simple_form$$=function($parent$jscomp$17$$,$properties$jscomp$11$$,$children$jscomp$12$$,$f$jscomp$403$$,$options$jscomp$117$$){return $malli$core$_create_form$$($malli$core$_type$$($parent$jscomp$17$$),$properties$jscomp$11$$,$malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$403$$,$children$jscomp$12$$),$options$jscomp$117$$)};
$malli$core$_create_entry_form$$=function($parent$jscomp$18$$,$properties$jscomp$12$$,$entry_parser$$,$options$jscomp$118$$){return $malli$core$_create_form$$($malli$core$_type$$($parent$jscomp$18$$),$properties$jscomp$12$$,$malli$core$_entry_forms$$($entry_parser$$),$options$jscomp$118$$)};
$malli$core$_inner_indexed$$=function($walker$jscomp$2$$,$path$jscomp$43$$,$children$jscomp$13$$,$options$jscomp$119$$){return $malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($c$jscomp$182_p__31724$$){var $i$jscomp$309$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$182_p__31724$$,0,null);$c$jscomp$182_p__31724$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$182_p__31724$$,1,null);return $malli$core$_inner$$($walker$jscomp$2$$,$c$jscomp$182_p__31724$$,
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$43$$,$i$jscomp$309$$),$options$jscomp$119$$)},$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$children$jscomp$13$$))};
$malli$core$_inner_entries$$=function($walker$jscomp$3$$,$path$jscomp$44$$,$entries$jscomp$2$$,$options$jscomp$120$$){return $malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__31732_s$jscomp$304$$){var $k$jscomp$364$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31732_s$jscomp$304$$,0,null);$p__31732_s$jscomp$304$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31732_s$jscomp$304$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$k$jscomp$364$$,$malli$core$_properties$$($p__31732_s$jscomp$304$$),$malli$core$_inner$$($walker$jscomp$3$$,$p__31732_s$jscomp$304$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$44$$,$k$jscomp$364$$),$options$jscomp$120$$)],null)},$entries$jscomp$2$$)};
$malli$core$_walk_entries$$=function($schema$jscomp$18$$,$walker$jscomp$4$$,$path$jscomp$45$$,$options$jscomp$121$$){return $APP.$cljs$core$truth_$$($malli$core$_accept$$($walker$jscomp$4$$,$schema$jscomp$18$$,$path$jscomp$45$$,$options$jscomp$121$$))?$malli$core$_outer$$($walker$jscomp$4$$,$schema$jscomp$18$$,$path$jscomp$45$$,$malli$core$_inner_entries$$($walker$jscomp$4$$,$path$jscomp$45$$,$malli$core$_entries$$($schema$jscomp$18$$),$options$jscomp$121$$),$options$jscomp$121$$):null};
$malli$core$_walk_indexed$$=function($schema$jscomp$19$$,$walker$jscomp$5$$,$path$jscomp$46$$,$options$jscomp$122$$){return $APP.$cljs$core$truth_$$($malli$core$_accept$$($walker$jscomp$5$$,$schema$jscomp$19$$,$path$jscomp$46$$,$options$jscomp$122$$))?$malli$core$_outer$$($walker$jscomp$5$$,$schema$jscomp$19$$,$path$jscomp$46$$,$malli$core$_inner_indexed$$($walker$jscomp$5$$,$path$jscomp$46$$,$malli$core$_children$$($schema$jscomp$19$$),$options$jscomp$122$$),$options$jscomp$122$$):null};
$malli$core$_walk_leaf$$=function($schema$jscomp$20$$,$walker$jscomp$6$$,$path$jscomp$47$$,$options$jscomp$123$$){return $APP.$cljs$core$truth_$$($malli$core$_accept$$($walker$jscomp$6$$,$schema$jscomp$20$$,$path$jscomp$47$$,$options$jscomp$123$$))?$malli$core$_outer$$($walker$jscomp$6$$,$schema$jscomp$20$$,$path$jscomp$47$$,$malli$core$_children$$($schema$jscomp$20$$),$options$jscomp$123$$):null};
$malli$core$_set_children$$=function($schema$jscomp$21$$,$children$jscomp$14$$){return $malli$core$_equals$$($children$jscomp$14$$,$malli$core$_children$$($schema$jscomp$21$$))?$schema$jscomp$21$$:$malli$core$_into_schema$$($malli$core$_parent$$($schema$jscomp$21$$),$malli$core$_properties$$($schema$jscomp$21$$),$children$jscomp$14$$,$malli$core$_options$$($schema$jscomp$21$$))};
$malli$core$_set_assoc_children$$=function($schema$jscomp$25$$,$key$jscomp$190$$,$value$jscomp$237$$){return $malli$core$_set_children$$($schema$jscomp$25$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($malli$core$_children$$($schema$jscomp$25$$),$key$jscomp$190$$,$value$jscomp$237$$))};
$malli$core$_get_entries$$=function($or__5025__auto__$jscomp$100_schema$jscomp$26$$,$key$jscomp$191$$,$default$$jscomp$11$$){$or__5025__auto__$jscomp$100_schema$jscomp$26$$=$APP.$cljs$core$some$$($APP.$cljs$core$vector_QMARK_$$($key$jscomp$191$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$359$malli_DOT_core_SLASH_find$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($key$jscomp$191$$,0))?function($e$jscomp$155$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$155$$,
0),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($key$jscomp$191$$,1))?$e$jscomp$155$$:null}:function($e$jscomp$156$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$156$$,0),$key$jscomp$191$$)?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$156$$,2):null},$malli$core$_children$$($or__5025__auto__$jscomp$100_schema$jscomp$26$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$100_schema$jscomp$26$$)?
$or__5025__auto__$jscomp$100_schema$jscomp$26$$:$default$$jscomp$11$$};$malli$core$t_malli$0core31774$$=function($keyset$$,$children$jscomp$15$$,$forms$$,$entries$jscomp$3$$,$meta31775$$){this.$keyset$=$keyset$$;this.children=$children$jscomp$15$$;this.forms=$forms$$;this.entries=$entries$jscomp$3$$;this.$meta31775$=$meta31775$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$_simple_entry_parser$$=function($keyset$jscomp$2$$,$children$jscomp$17$$,$forms$jscomp$2$$){var $entries$jscomp$5$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__31766_s$jscomp$305$$){var $k$jscomp$365$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31766_s$jscomp$305$$,0,null),$p$jscomp$70_v$jscomp$inline_3522$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31766_s$jscomp$305$$,1,null);$p__31766_s$jscomp$305$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31766_s$jscomp$305$$,
2,null);$p$jscomp$70_v$jscomp$inline_3522$$=$malli$core$_val_schema$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$core$_val_schema$cljs$0core$0IFn$0_invoke$0arity$02$$($p__31766_s$jscomp$305$$,$p$jscomp$70_v$jscomp$inline_3522$$):$malli$core$_val_schema$$($p__31766_s$jscomp$305$$,$p$jscomp$70_v$jscomp$inline_3522$$);return new $APP.$cljs$core$MapEntry$$($k$jscomp$365$$,$p$jscomp$70_v$jscomp$inline_3522$$,null)},$children$jscomp$17$$);return new $malli$core$t_malli$0core31774$$($keyset$jscomp$2$$,$children$jscomp$17$$,
$forms$jscomp$2$$,$entries$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$malli$core$_update_parsed$$=function($entry_parser$jscomp$1_forms$jscomp$3$$,$_QMARK_key$$,$f$jscomp$406_s$jscomp$306_value$jscomp$238$$,$options$jscomp$124_p__$1$jscomp$4$$){var $keyset$jscomp$3_vec__31791$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$68$$=$APP.$cljs$core$vector_QMARK_$$($_QMARK_key$$);return $and__5023__auto__$jscomp$68$$?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($_QMARK_key$$,0):$and__5023__auto__$jscomp$68$$}())?$APP.$cljs$core$cons$$(!0,
$_QMARK_key$$):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[!1,$_QMARK_key$$],null),$c$jscomp$183_cut_override$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($keyset$jscomp$3_vec__31791$$,0,null),$k$jscomp$366$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($keyset$jscomp$3_vec__31791$$,1,null),$p$jscomp$71$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($keyset$jscomp$3_vec__31791$$,2,null);$keyset$jscomp$3_vec__31791$$=
$malli$core$_entry_keyset$$($entry_parser$jscomp$1_forms$jscomp$3$$);var $children$jscomp$18$$=$malli$core$_entry_children$$($entry_parser$jscomp$1_forms$jscomp$3$$);$entry_parser$jscomp$1_forms$jscomp$3$$=$malli$core$_entry_forms$$($entry_parser$jscomp$1_forms$jscomp$3$$);$f$jscomp$406_s$jscomp$306_value$jscomp$238$$=$APP.$cljs$core$truth_$$($f$jscomp$406_s$jscomp$306_value$jscomp$238$$)?$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$406_s$jscomp$306_value$jscomp$238$$,
$options$jscomp$124_p__$1$jscomp$4$$):$APP.$malli$core$schema$$($f$jscomp$406_s$jscomp$306_value$jscomp$238$$,$options$jscomp$124_p__$1$jscomp$4$$):null;var $i$jscomp$310$$=$cljs$cst$365$order$$.$cljs$core$IFn$_invoke$arity$1$($keyset$jscomp$3_vec__31791$$.$cljs$core$IFn$_invoke$arity$1$?$keyset$jscomp$3_vec__31791$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$366$$):$keyset$jscomp$3_vec__31791$$($k$jscomp$366$$));if($f$jscomp$406_s$jscomp$306_value$jscomp$238$$==null)return $c$jscomp$183_cut_override$$=
function($v$jscomp$181$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$181$$,0,$i$jscomp$310$$),$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$181$$,$i$jscomp$310$$+1))},$malli$core$_simple_entry_parser$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($keyset$jscomp$3_vec__31791$$,$k$jscomp$366$$),$c$jscomp$183_cut_override$$($children$jscomp$18$$),$c$jscomp$183_cut_override$$($entry_parser$jscomp$1_forms$jscomp$3$$));
$options$jscomp$124_p__$1$jscomp$4$$=$APP.$cljs$core$truth_$$($i$jscomp$310$$)?$APP.$cljs$core$truth_$$($c$jscomp$183_cut_override$$)?$p$jscomp$71$$:$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($children$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$?$children$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$($i$jscomp$310$$):$children$jscomp$18$$($i$jscomp$310$$),1):$p$jscomp$71$$;$c$jscomp$183_cut_override$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$k$jscomp$366$$,$options$jscomp$124_p__$1$jscomp$4$$,$f$jscomp$406_s$jscomp$306_value$jscomp$238$$],null);$f$jscomp$406_s$jscomp$306_value$jscomp$238$$=$APP.$cljs$core$seq$$($options$jscomp$124_p__$1$jscomp$4$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$366$$,$options$jscomp$124_p__$1$jscomp$4$$,$malli$core$_form$$($f$jscomp$406_s$jscomp$306_value$jscomp$238$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$k$jscomp$366$$,$malli$core$_form$$($f$jscomp$406_s$jscomp$306_value$jscomp$238$$)],null);return $APP.$cljs$core$truth_$$($i$jscomp$310$$)?$malli$core$_simple_entry_parser$$($keyset$jscomp$3_vec__31791$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($children$jscomp$18$$,$i$jscomp$310$$,$c$jscomp$183_cut_override$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($entry_parser$jscomp$1_forms$jscomp$3$$,$i$jscomp$310$$,$f$jscomp$406_s$jscomp$306_value$jscomp$238$$)):$malli$core$_simple_entry_parser$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($keyset$jscomp$3_vec__31791$$,
$k$jscomp$366$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$365$order$$,$APP.$cljs$core$count$$($keyset$jscomp$3_vec__31791$$)],null)),$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$18$$,$c$jscomp$183_cut_override$$),$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($entry_parser$jscomp$1_forms$jscomp$3$$,$f$jscomp$406_s$jscomp$306_value$jscomp$238$$))};
$malli$core$_set_entries$$=function($schema$jscomp$27$$,$_QMARK_key$jscomp$1_children$jscomp$19_vec__31801$$,$value$jscomp$239$$){var $temp__5823__auto__$jscomp$49$$=$malli$core$_entry_parser$$($schema$jscomp$27$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$49$$))return $malli$core$_set_children$$($schema$jscomp$27$$,$malli$core$_update_parsed$$($temp__5823__auto__$jscomp$49$$,$_QMARK_key$jscomp$1_children$jscomp$19_vec__31801$$,$value$jscomp$239$$,$malli$core$_options$$($schema$jscomp$27$$)));
var $found$jscomp$13$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$_QMARK_key$jscomp$1_children$jscomp$19_vec__31801$$=$APP.$cljs$core$vector_QMARK_$$($_QMARK_key$jscomp$1_children$jscomp$19_vec__31801$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($_QMARK_key$jscomp$1_children$jscomp$19_vec__31801$$,0),$APP.$cljs$core$second$$($_QMARK_key$jscomp$1_children$jscomp$19_vec__31801$$),
!0],null):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$_QMARK_key$jscomp$1_children$jscomp$19_vec__31801$$],null);var $key$jscomp$192$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_QMARK_key$jscomp$1_children$jscomp$19_vec__31801$$,0,null),$props$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_QMARK_key$jscomp$1_children$jscomp$19_vec__31801$$,1,null),$override$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_QMARK_key$jscomp$1_children$jscomp$19_vec__31801$$,
2,null);$_QMARK_key$jscomp$1_children$jscomp$19_vec__31801$$=function(){var $G__31805_G__31805__$1$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__31806$$){var $k$jscomp$367$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31806$$,0,null),$p$jscomp$72$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31806$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$192$$,$k$jscomp$367$$)?($APP.$cljs$core$reset_BANG_$$($found$jscomp$13$$,
!0),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$key$jscomp$192$$,$APP.$cljs$core$truth_$$($override$jscomp$1$$)?$props$jscomp$5$$:$p$jscomp$72$$,$value$jscomp$239$$],null)):$p__31806$$},$malli$core$_children$$($schema$jscomp$27$$));$G__31805_G__31805__$1$$=$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($found$jscomp$13$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__31805_G__31805__$1$$,$APP.$cljs$core$truth_$$($key$jscomp$192$$)?
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$key$jscomp$192$$,$props$jscomp$5$$,$value$jscomp$239$$],null):$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$366$malli_DOT_core_SLASH_key_missing$$)):$G__31805_G__31805__$1$$;return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($e$jscomp$157$$){return $APP.$cljs$core$last$$($e$jscomp$157$$)!=null},$G__31805_G__31805__$1$$)}();return $malli$core$_set_children$$($schema$jscomp$27$$,
$_QMARK_key$jscomp$1_children$jscomp$19_vec__31801$$)};
$malli$core$_parse_entry$$=function($e$jscomp$158$$,$naked_keys$$,$lazy_refs$$,$options$jscomp$125$$,$i$jscomp$311$$,$_children$$,$_forms$$,$_keyset$$){function $_parse_entry_else3$$($e0$jscomp$4$$,$e1$jscomp$3$$,$e2$jscomp$1_s$jscomp$311$$){$e2$jscomp$1_s$jscomp$311$$=$_schema$$($e2$jscomp$1_s$jscomp$311$$);var $f_SINGLEQUOTE_$$=$malli$core$_form$$($e2$jscomp$1_s$jscomp$311$$);return $_collect$$($e0$jscomp$4$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$e0$jscomp$4$$,$e1$jscomp$3$$,$e2$jscomp$1_s$jscomp$311$$],null),$APP.$cljs$core$truth_$$($e1$jscomp$3$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$e0$jscomp$4$$,$e1$jscomp$3$$,$f_SINGLEQUOTE_$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$e0$jscomp$4$$,$f_SINGLEQUOTE_$$],null),$i$jscomp$311$$)}function $_parse_entry_else2$$($e0$jscomp$3$$,$e1$jscomp$2_s$jscomp$310$$){$e1$jscomp$2_s$jscomp$310$$=
$_schema$$($e1$jscomp$2_s$jscomp$310$$);var $f$jscomp$408$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$e0$jscomp$3$$,$malli$core$_form$$($e1$jscomp$2_s$jscomp$310$$)],null);return $_collect$$($e0$jscomp$3$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$e0$jscomp$3$$,null,$e1$jscomp$2_s$jscomp$310$$],null),$f$jscomp$408$$,$i$jscomp$311$$)}function $_parse_ref_vector2$$($e__$1$jscomp$3$$,$e0$jscomp$2$$,
$e1$jscomp$1$$){var $s$jscomp$309$$=$_schema$$($e0$jscomp$2$$);return $_collect$$($e0$jscomp$2$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$e0$jscomp$2$$,$e1$jscomp$1$$,$s$jscomp$309$$],null),$e__$1$jscomp$3$$,$i$jscomp$311$$)}function $_parse_ref_vector1$$($e__$1$jscomp$2$$,$e0$jscomp$1$$){var $s$jscomp$308$$=$_schema$$($e0$jscomp$1$$);return $_collect$$($e0$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$e0$jscomp$1$$,null,$s$jscomp$308$$],null),$e__$1$jscomp$2$$,$i$jscomp$311$$)}function $_parse_ref_entry$$($e__$1$jscomp$1$$){var $s$jscomp$307$$=$_schema$$($e__$1$jscomp$1$$);return $_collect$$($e__$1$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$e__$1$jscomp$1$$,null,$s$jscomp$307$$],null),$e__$1$jscomp$1$$,$i$jscomp$311$$)}function $_schema$$($G__31843_JSCompiler_temp$jscomp$14039_e__$1$$){var $G__31477$jscomp$inline_14126_JSCompiler_inline_result$jscomp$inline_14125_and__5023__auto__$jscomp$inline_11420$$=
$malli$core$_reference_QMARK_$$($G__31843_JSCompiler_temp$jscomp$14039_e__$1$$);$APP.$cljs$core$truth_$$($G__31477$jscomp$inline_14126_JSCompiler_inline_result$jscomp$inline_14125_and__5023__auto__$jscomp$inline_11420$$?$lazy_refs$$:$G__31477$jscomp$inline_14126_JSCompiler_inline_result$jscomp$inline_14125_and__5023__auto__$jscomp$inline_11420$$)&&($G__31477$jscomp$inline_14126_JSCompiler_inline_result$jscomp$inline_14125_and__5023__auto__$jscomp$inline_11420$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$343$lazy$$,!0],null),$G__31477$jscomp$inline_14126_JSCompiler_inline_result$jscomp$inline_14125_and__5023__auto__$jscomp$inline_11420$$=$malli$core$_ref_schema$cljs$0core$0IFn$0_invoke$0arity$01$$?$malli$core$_ref_schema$cljs$0core$0IFn$0_invoke$0arity$01$$($G__31477$jscomp$inline_14126_JSCompiler_inline_result$jscomp$inline_14125_and__5023__auto__$jscomp$inline_11420$$):$malli$core$_ref_schema$$($G__31477$jscomp$inline_14126_JSCompiler_inline_result$jscomp$inline_14125_and__5023__auto__$jscomp$inline_11420$$),
$G__31843_JSCompiler_temp$jscomp$14039_e__$1$$=$malli$core$_into_schema$$($G__31477$jscomp$inline_14126_JSCompiler_inline_result$jscomp$inline_14125_and__5023__auto__$jscomp$inline_11420$$,null,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__31843_JSCompiler_temp$jscomp$14039_e__$1$$],null),$options$jscomp$125$$));return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($G__31843_JSCompiler_temp$jscomp$14039_e__$1$$,
$options$jscomp$125$$):$APP.$malli$core$schema$$($G__31843_JSCompiler_temp$jscomp$14039_e__$1$$,$options$jscomp$125$$)}function $_collect$$($k$jscomp$368$$,$c$jscomp$184$$,$f$jscomp$407$$,$i__$1$jscomp$5_i__$2$$){$i__$1$jscomp$5_i__$2$$|=0;$_keyset$$[2*$i__$1$jscomp$5_i__$2$$]=$k$jscomp$368$$;$_keyset$$[2*$i__$1$jscomp$5_i__$2$$+1]=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$365$order$$,$i__$1$jscomp$5_i__$2$$],null);$_children$$[$i__$1$jscomp$5_i__$2$$]=$c$jscomp$184$$;$_forms$$[$i__$1$jscomp$5_i__$2$$]=
$f$jscomp$407$$;return $i__$1$jscomp$5_i__$2$$+1}if($APP.$cljs$core$vector_QMARK_$$($e$jscomp$158$$)){var $ea$$=$cljs$core$object_array$cljs$0core$0IFn$0_invoke$0arity$01$$($e$jscomp$158$$),$n$jscomp$197$$=$ea$$.length,$e0$$=$ea$$[0];if($n$jscomp$197$$===1)return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$70$$=$malli$core$_reference_QMARK_$$($e0$$);return $and__5023__auto__$jscomp$70$$?$naked_keys$$:$and__5023__auto__$jscomp$70$$}())?$_parse_ref_vector1$$($e$jscomp$158$$,$e0$$):
$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$367$malli_DOT_core_SLASH_invalid_entry$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$368$entry$$,$e$jscomp$158$$],null));var $e1$$=$ea$$[1];return $n$jscomp$197$$===2?$malli$core$_reference_QMARK_$$($e0$$)&&$APP.$cljs$core$map_QMARK_$$($e1$$)?$APP.$cljs$core$truth_$$($naked_keys$$)?$_parse_ref_vector2$$($e$jscomp$158$$,$e0$$,$e1$$):$i$jscomp$311$$:$_parse_entry_else2$$($e0$$,$e1$$):$_parse_entry_else3$$($e0$$,$e1$$,
$ea$$[2])}return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($naked_keys$$)?$malli$core$_reference_QMARK_$$($e$jscomp$158$$):$naked_keys$$)?$_parse_ref_entry$$($e$jscomp$158$$):$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$367$malli_DOT_core_SLASH_invalid_entry$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$368$entry$$,$e$jscomp$158$$],null))};
$malli$core$_eager_entry_parser$$=function($_children$jscomp$1_children$jscomp$20$$,$f$jscomp$410_props$jscomp$6$$,$options$jscomp$126$$){function $_map$$($arr$jscomp$140$$){var $m$jscomp$129$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$array_map$$,$arr$jscomp$140$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2*$APP.$cljs$core$count$$($m$jscomp$129$$),$APP.$cljs$core$count$$($arr$jscomp$140$$))||$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$369$malli_DOT_core_SLASH_duplicate_keys$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$370$arr$$,$arr$jscomp$140$$],null));return $m$jscomp$129$$}function $_vec$$($arr$jscomp$139$$){return $APP.$cljs$core$vec$$($arr$jscomp$139$$)}var $map__31878__$1$$=$APP.$cljs$core$__destructure_map$$($f$jscomp$410_props$jscomp$6$$),$naked_keys$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__31878__$1$$,$cljs$cst$371$naked_keys$$),$lazy_refs$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__31878__$1$$,
$cljs$cst$372$lazy_refs$$),$ca$$=$cljs$core$object_array$cljs$0core$0IFn$0_invoke$0arity$01$$($_children$jscomp$1_children$jscomp$20$$),$n$jscomp$198$$=$ca$$.length;$_children$jscomp$1_children$jscomp$20$$=$cljs$core$object_array$cljs$0core$0IFn$0_invoke$0arity$01$$($n$jscomp$198$$);for(var $_forms$jscomp$1$$=$cljs$core$object_array$cljs$0core$0IFn$0_invoke$0arity$01$$($n$jscomp$198$$),$_keyset$jscomp$1$$=$cljs$core$object_array$cljs$0core$0IFn$0_invoke$0arity$01$$(2*$n$jscomp$198$$),$G__34803_i$jscomp$312$$=
0,$G__34804_ci$jscomp$2$$=0;;){if($G__34804_ci$jscomp$2$$===$n$jscomp$198$$)return $f$jscomp$410_props$jscomp$6$$=$G__34804_ci$jscomp$2$$===$G__34803_i$jscomp$312$$?$_vec$$:function($i$jscomp$313$$){return function($p1__31870_SHARP_$$){return $APP.$cljs$core$vec$$($p1__31870_SHARP_$$.slice(0,$i$jscomp$313$$))}}($G__34803_i$jscomp$312$$,$G__34804_ci$jscomp$2$$,$f$jscomp$410_props$jscomp$6$$,$map__31878__$1$$,$naked_keys$jscomp$1$$,$lazy_refs$jscomp$1$$,$ca$$,$n$jscomp$198$$,$_children$jscomp$1_children$jscomp$20$$,
$_forms$jscomp$1$$,$_keyset$jscomp$1$$),$malli$core$_simple_entry_parser$$($_map$$($_keyset$jscomp$1$$),$f$jscomp$410_props$jscomp$6$$($_children$jscomp$1_children$jscomp$20$$),$f$jscomp$410_props$jscomp$6$$($_forms$jscomp$1$$));$G__34803_i$jscomp$312$$=$malli$core$_parse_entry$$($ca$$[$G__34803_i$jscomp$312$$],$naked_keys$jscomp$1$$,$lazy_refs$jscomp$1$$,$options$jscomp$126$$,$G__34803_i$jscomp$312$$,$_children$jscomp$1_children$jscomp$20$$,$_forms$jscomp$1$$,$_keyset$jscomp$1$$)|0;$G__34804_ci$jscomp$2$$+=
1}};$malli$core$t_malli$0core31888$$=function($_QMARK_children$$,$props$jscomp$7$$,$options$jscomp$127$$,$parser$jscomp$2$$,$meta31889$$){this.$_QMARK_children$=$_QMARK_children$$;this.props=$props$jscomp$7$$;this.options=$options$jscomp$127$$;this.parser=$parser$jscomp$2$$;this.$meta31889$=$meta31889$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$_lazy_entry_parser$$=function($_QMARK_children$jscomp$2$$,$props$jscomp$9$$,$options$jscomp$129$$){return new $malli$core$t_malli$0core31888$$($_QMARK_children$jscomp$2$$,$props$jscomp$9$$,$options$jscomp$129$$,new $APP.$cljs$core$Delay$$(function(){return $malli$core$_eager_entry_parser$$($_QMARK_children$jscomp$2$$,$props$jscomp$9$$,$options$jscomp$129$$)}),$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$malli$core$_create_entry_parser$$=function($JSCompiler_temp$jscomp$397__QMARK_children$jscomp$3$$,$props$jscomp$10$$,$options$jscomp$130$$){if($JSCompiler_temp$jscomp$397__QMARK_children$jscomp$3$$==null||$APP.$cljs$core$PROTOCOL_SENTINEL$$!==$JSCompiler_temp$jscomp$397__QMARK_children$jscomp$3$$.$malli$core$EntryParser$$){var $JSCompiler_inline_result$jscomp$398_or__5025__auto__$jscomp$inline_3526$$=$cljs$cst$343$lazy$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$10$$);$JSCompiler_inline_result$jscomp$398_or__5025__auto__$jscomp$inline_3526$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$398_or__5025__auto__$jscomp$inline_3526$$)?$JSCompiler_inline_result$jscomp$398_or__5025__auto__$jscomp$inline_3526$$:$cljs$cst$378$malli_DOT_core_SLASH_lazy_entries$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$130$$);$JSCompiler_temp$jscomp$397__QMARK_children$jscomp$3$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$398_or__5025__auto__$jscomp$inline_3526$$)?$malli$core$_lazy_entry_parser$$($JSCompiler_temp$jscomp$397__QMARK_children$jscomp$3$$,
$props$jscomp$10$$,$options$jscomp$130$$):$malli$core$_eager_entry_parser$$($JSCompiler_temp$jscomp$397__QMARK_children$jscomp$3$$,$props$jscomp$10$$,$options$jscomp$130$$)}return $JSCompiler_temp$jscomp$397__QMARK_children$jscomp$3$$};$malli$core$_default_entry$$=function($e$jscomp$159$$){return $malli$core$_equals$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$159$$,0),$cljs$cst$379$malli_DOT_core_SLASH_default$$)};
$malli$core$_default_entry_schema$$=function($children$jscomp$21$$){return $APP.$cljs$core$some$$(function($e$jscomp$160$$){return $malli$core$_default_entry$$($e$jscomp$160$$)?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$160$$,2):null},$children$jscomp$21$$)};$malli$core$t_malli$0core31908$$=function($meta31909$$){this.$meta31909$=$meta31909$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$01$$=function($interceptor$$){return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$02$$($interceptor$$,null)};
$malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$02$$=function($enter_p__31938$$,$G__31943_G__31943__$1_G__31943__$2_f$jscomp$411$$){var $leave_map__31941__$1$$=$APP.$cljs$core$__destructure_map$$($enter_p__31938$$);$enter_p__31938$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($leave_map__31941__$1$$,$APP.$cljs$cst$381$enter$$);$leave_map__31941__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($leave_map__31941__$1$$,$cljs$cst$382$leave$$);$G__31943_G__31943__$1_G__31943__$2_f$jscomp$411$$=
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$leave_map__31941__$1$$,$G__31943_G__31943__$1_G__31943__$2_f$jscomp$411$$,$enter_p__31938$$],null);$G__31943_G__31943__$1_G__31943__$2_f$jscomp$411$$=$G__31943_G__31943__$1_G__31943__$2_f$jscomp$411$$==null?null:$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$identity$$,$G__31943_G__31943__$1_G__31943__$2_f$jscomp$411$$);$G__31943_G__31943__$1_G__31943__$2_f$jscomp$411$$=$G__31943_G__31943__$1_G__31943__$2_f$jscomp$411$$==
null?null:$APP.$cljs$core$seq$$($G__31943_G__31943__$1_G__31943__$2_f$jscomp$411$$);return $G__31943_G__31943__$1_G__31943__$2_f$jscomp$411$$==null?null:$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$core$_comp$$,$G__31943_G__31943__$1_G__31943__$2_f$jscomp$411$$)};
$malli$core$_parent_children_transformer$$=function($parent$jscomp$19_parent_transformer$$,$child_transformer_child_transformers_children$jscomp$22$$,$transformer$jscomp$12$$,$method$jscomp$12$$,$options$jscomp$131$$){$parent$jscomp$19_parent_transformer$$=$malli$core$_value_transformer$$($transformer$jscomp$12$$,$parent$jscomp$19_parent_transformer$$,$method$jscomp$12$$,$options$jscomp$131$$);$child_transformer_child_transformers_children$jscomp$22$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__31947_SHARP_$$){return $malli$core$_transformer$$($p1__31947_SHARP_$$,$transformer$jscomp$12$$,$method$jscomp$12$$,$options$jscomp$131$$)}),$child_transformer_child_transformers_children$jscomp$22$$);$child_transformer_child_transformers_children$jscomp$22$$=$APP.$cljs$core$seq$$($child_transformer_child_transformers_children$jscomp$22$$)?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$core$_comp$$,$APP.$cljs$core$_rseq$$($child_transformer_child_transformers_children$jscomp$22$$)):
null;return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$19_parent_transformer$$,$child_transformer_child_transformers_children$jscomp$22$$)};
$malli$core$_map_transformer$$=function($ts$jscomp$1$$){return function($x$jscomp$721$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($JSCompiler_temp$jscomp$399_m$jscomp$130$$,$JSCompiler_temp_const$jscomp$400_p__31955$$){var $k$jscomp$369$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$400_p__31955$$,0,null),$JSCompiler_inline_result$jscomp$402_t$jscomp$29$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$400_p__31955$$,
1,null),$G__31964$jscomp$inline_3528_temp__5823__auto__$jscomp$50$$=$cljs$core$find$$($JSCompiler_temp$jscomp$399_m$jscomp$130$$,$k$jscomp$369$$);$APP.$cljs$core$truth_$$($G__31964$jscomp$inline_3528_temp__5823__auto__$jscomp$50$$)&&($JSCompiler_temp_const$jscomp$400_p__31955$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$G__31964$jscomp$inline_3528_temp__5823__auto__$jscomp$50$$=$APP.$cljs$core$_val$$($G__31964$jscomp$inline_3528_temp__5823__auto__$jscomp$50$$),$JSCompiler_inline_result$jscomp$402_t$jscomp$29$$=
$JSCompiler_inline_result$jscomp$402_t$jscomp$29$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$402_t$jscomp$29$$.$cljs$core$IFn$_invoke$arity$1$($G__31964$jscomp$inline_3528_temp__5823__auto__$jscomp$50$$):$JSCompiler_inline_result$jscomp$402_t$jscomp$29$$($G__31964$jscomp$inline_3528_temp__5823__auto__$jscomp$50$$),$JSCompiler_temp$jscomp$399_m$jscomp$130$$=$JSCompiler_temp_const$jscomp$400_p__31955$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp$jscomp$399_m$jscomp$130$$,$k$jscomp$369$$,
$JSCompiler_inline_result$jscomp$402_t$jscomp$29$$));return $JSCompiler_temp$jscomp$399_m$jscomp$130$$},$x$jscomp$721$$,$ts$jscomp$1$$)}};$malli$core$_tuple_transformer$$=function($ts$jscomp$2$$){return function($x$jscomp$722$$){return $APP.$cljs$core$reduce_kv$$($malli$core$_update$$,$x$jscomp$722$$,$ts$jscomp$2$$)}};
$malli$core$_collection_transformer$$=function($t$jscomp$30$$,$empty$$){return function($x$jscomp$723$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$truth_$$($x$jscomp$723$$)?$empty$$:null,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($t$jscomp$30$$),$x$jscomp$723$$)}};
$malli$core$_or_transformer$$=function($this$$jscomp$284_this_transformer$$,$transformer$jscomp$13$$,$child_schemas$$,$method$jscomp$13$$,$options$jscomp$132$$){$this$$jscomp$284_this_transformer$$=$malli$core$_value_transformer$$($transformer$jscomp$13$$,$this$$jscomp$284_this_transformer$$,$method$jscomp$13$$,$options$jscomp$132$$);if($APP.$cljs$core$seq$$($child_schemas$$)){var $transformers$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($or__5025__auto__$jscomp$102_p1__31973_SHARP_$$){$or__5025__auto__$jscomp$102_p1__31973_SHARP_$$=
$malli$core$_transformer$$($or__5025__auto__$jscomp$102_p1__31973_SHARP_$$,$transformer$jscomp$13$$,$method$jscomp$13$$,$options$jscomp$132$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$102_p1__31973_SHARP_$$)?$or__5025__auto__$jscomp$102_p1__31973_SHARP_$$:$APP.$cljs$core$identity$$},$child_schemas$$),$validators$$=$malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$core$_validator$$,$child_schemas$$);return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$02$$($this$$jscomp$284_this_transformer$$,
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$384$decode$$,$method$jscomp$13$$)?function($x$jscomp$724$$){return $APP.$cljs$core$reduce_kv$$(function($acc$jscomp$24$$,$JSCompiler_inline_result$jscomp$403_fexpr__31990$jscomp$inline_3530_i$jscomp$314$$,$transformer__$1_x_STAR_$$){$transformer__$1_x_STAR_$$=$transformer__$1_x_STAR_$$.$cljs$core$IFn$_invoke$arity$1$?$transformer__$1_x_STAR_$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$724$$):$transformer__$1_x_STAR_$$($x$jscomp$724$$);
$JSCompiler_inline_result$jscomp$403_fexpr__31990$jscomp$inline_3530_i$jscomp$314$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($validators$$,$JSCompiler_inline_result$jscomp$403_fexpr__31990$jscomp$inline_3530_i$jscomp$314$$);$JSCompiler_inline_result$jscomp$403_fexpr__31990$jscomp$inline_3530_i$jscomp$314$$=$JSCompiler_inline_result$jscomp$403_fexpr__31990$jscomp$inline_3530_i$jscomp$314$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$403_fexpr__31990$jscomp$inline_3530_i$jscomp$314$$.$cljs$core$IFn$_invoke$arity$1$($transformer__$1_x_STAR_$$):
$JSCompiler_inline_result$jscomp$403_fexpr__31990$jscomp$inline_3530_i$jscomp$314$$($transformer__$1_x_STAR_$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$403_fexpr__31990$jscomp$inline_3530_i$jscomp$314$$)?$APP.$cljs$core$reduced$$($transformer__$1_x_STAR_$$):$malli$core$_equals$$($acc$jscomp$24$$,$cljs$cst$385$malli_DOT_core_SLASH_nil$$)?$transformer__$1_x_STAR_$$:$acc$jscomp$24$$},$cljs$cst$385$malli_DOT_core_SLASH_nil$$,$transformers$$)}:function($x$jscomp$725$$){return $APP.$cljs$core$reduce_kv$$(function($JSCompiler_inline_result$jscomp$405_JSCompiler_temp$jscomp$404_x__$1$jscomp$15$$,
$fexpr__31993$jscomp$inline_3532_i$jscomp$315$$,$validator$jscomp$14$$){$APP.$cljs$core$truth_$$($validator$jscomp$14$$.$cljs$core$IFn$_invoke$arity$1$?$validator$jscomp$14$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$405_JSCompiler_temp$jscomp$404_x__$1$jscomp$15$$):$validator$jscomp$14$$($JSCompiler_inline_result$jscomp$405_JSCompiler_temp$jscomp$404_x__$1$jscomp$15$$))&&($fexpr__31993$jscomp$inline_3532_i$jscomp$315$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($transformers$$,
$fexpr__31993$jscomp$inline_3532_i$jscomp$315$$),$JSCompiler_inline_result$jscomp$405_JSCompiler_temp$jscomp$404_x__$1$jscomp$15$$=$fexpr__31993$jscomp$inline_3532_i$jscomp$315$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__31993$jscomp$inline_3532_i$jscomp$315$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$405_JSCompiler_temp$jscomp$404_x__$1$jscomp$15$$):$fexpr__31993$jscomp$inline_3532_i$jscomp$315$$($JSCompiler_inline_result$jscomp$405_JSCompiler_temp$jscomp$404_x__$1$jscomp$15$$),
$JSCompiler_inline_result$jscomp$405_JSCompiler_temp$jscomp$404_x__$1$jscomp$15$$=$APP.$cljs$core$reduced$$($JSCompiler_inline_result$jscomp$405_JSCompiler_temp$jscomp$404_x__$1$jscomp$15$$));return $JSCompiler_inline_result$jscomp$405_JSCompiler_temp$jscomp$404_x__$1$jscomp$15$$},$x$jscomp$725$$,$validators$$)})}return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$01$$($this$$jscomp$284_this_transformer$$)};
$malli$core$_ast$$=function($G__32090__$1_acc$jscomp$25$$,$properties$jscomp$14$$,$options$jscomp$137$$){var $registry$jscomp$6$$=function(){var $temp__5825__auto__$jscomp$58$$=$cljs$cst$352$registry$$.$cljs$core$IFn$_invoke$arity$1$($properties$jscomp$14$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$58$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p__32081_v$jscomp$184$$){var $k$jscomp$373$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32081_v$jscomp$184$$,0,null);$p__32081_v$jscomp$184$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32081_v$jscomp$184$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$373$$,$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$02$$($p__32081_v$jscomp$184$$,$options$jscomp$137$$):$malli$core$ast$$($p__32081_v$jscomp$184$$,
$options$jscomp$137$$)],null)}),$temp__5825__auto__$jscomp$58$$):null}(),$properties__$1$jscomp$1$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$truth_$$($registry$jscomp$6$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($properties$jscomp$14$$,$cljs$cst$352$registry$$):$properties$jscomp$14$$);$G__32090__$1_acc$jscomp$25$$=$APP.$cljs$core$truth_$$($properties__$1$jscomp$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__32090__$1_acc$jscomp$25$$,$cljs$cst$341$properties$$,
$properties__$1$jscomp$1$$):$G__32090__$1_acc$jscomp$25$$;return $APP.$cljs$core$truth_$$($registry$jscomp$6$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__32090__$1_acc$jscomp$25$$,$cljs$cst$352$registry$$,$registry$jscomp$6$$):$G__32090__$1_acc$jscomp$25$$};
$malli$core$_entry_ast$$=function($schema$jscomp$28$$,$keyset$jscomp$7$$){return $malli$core$_ast$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$28$$):$APP.$malli$core$type$$($schema$jscomp$28$$),$cljs$cst$391$keys$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$26$$,$JSCompiler_temp_const$jscomp$406_p__32094$$){var $k$jscomp$374$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$406_p__32094$$,0,null),$JSCompiler_inline_result$jscomp$408_p$jscomp$75$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$406_p__32094$$,1,null),$G__32099$jscomp$inline_3534_s$jscomp$313$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$406_p__32094$$,2,null);$JSCompiler_temp_const$jscomp$406_p__32094$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;
$G__32099$jscomp$inline_3534_s$jscomp$313$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$365$order$$,$cljs$cst$365$order$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($keyset$jscomp$7$$,$k$jscomp$374$$)),$APP.$cljs$cst$260$value$$,$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$?$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$($G__32099$jscomp$inline_3534_s$jscomp$313$$):$malli$core$ast$$($G__32099$jscomp$inline_3534_s$jscomp$313$$)],
null);$JSCompiler_inline_result$jscomp$408_p$jscomp$75$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$408_p$jscomp$75$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__32099$jscomp$inline_3534_s$jscomp$313$$,$cljs$cst$341$properties$$,$JSCompiler_inline_result$jscomp$408_p$jscomp$75$$):$G__32099$jscomp$inline_3534_s$jscomp$313$$;return $JSCompiler_temp_const$jscomp$406_p__32094$$.call($APP.$cljs$core$assoc$$,$acc$jscomp$26$$,$k$jscomp$374$$,$JSCompiler_inline_result$jscomp$408_p$jscomp$75$$)},
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$malli$core$_children$$($schema$jscomp$28$$))],null),$malli$core$_properties$$($schema$jscomp$28$$),$malli$core$_options$$($schema$jscomp$28$$))};
$malli$core$_to_child_ast$$=function($schema$jscomp$29$$){var $JSCompiler_temp_const$jscomp$410$$=$APP.$cljs$cst$139$type$$,$JSCompiler_temp_const$jscomp$409$$=$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$29$$):$APP.$malli$core$type$$($schema$jscomp$29$$);var $G__32115$jscomp$inline_3536_JSCompiler_inline_result$jscomp$411$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$core$_children$$($schema$jscomp$29$$),
0);$G__32115$jscomp$inline_3536_JSCompiler_inline_result$jscomp$411$$=$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$?$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$($G__32115$jscomp$inline_3536_JSCompiler_inline_result$jscomp$411$$):$malli$core$ast$$($G__32115$jscomp$inline_3536_JSCompiler_inline_result$jscomp$411$$);return $malli$core$_ast$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$JSCompiler_temp_const$jscomp$410$$,$JSCompiler_temp_const$jscomp$409$$,$cljs$cst$392$child$$,$G__32115$jscomp$inline_3536_JSCompiler_inline_result$jscomp$411$$],
null),$malli$core$_properties$$($schema$jscomp$29$$),$malli$core$_options$$($schema$jscomp$29$$))};
$malli$core$_from_value_ast$$=function($parent$jscomp$22$$,$ast$jscomp$7_temp__5825__auto__$jscomp$inline_3538$$,$options$jscomp$139$$){var $JSCompiler_temp_const$jscomp$412$$=$cljs$cst$341$properties$$.$cljs$core$IFn$_invoke$arity$1$($ast$jscomp$7_temp__5825__auto__$jscomp$inline_3538$$);$ast$jscomp$7_temp__5825__auto__$jscomp$inline_3538$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($ast$jscomp$7_temp__5825__auto__$jscomp$inline_3538$$);return $malli$core$_into_schema$$($parent$jscomp$22$$,
$JSCompiler_temp_const$jscomp$412$$,$APP.$cljs$core$truth_$$($ast$jscomp$7_temp__5825__auto__$jscomp$inline_3538$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$ast$jscomp$7_temp__5825__auto__$jscomp$inline_3538$$],null):null,$options$jscomp$139$$)};
$malli$core$_to_value_ast$$=function($schema$jscomp$30$$){return $malli$core$_ast$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$30$$):$APP.$malli$core$type$$($schema$jscomp$30$$),$APP.$cljs$cst$260$value$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$core$_children$$($schema$jscomp$30$$),0)],null),$malli$core$_properties$$($schema$jscomp$30$$),
$malli$core$_options$$($schema$jscomp$30$$))};$malli$core$_to_type_ast$$=function($schema$jscomp$31$$){return $malli$core$_ast$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$31$$):$APP.$malli$core$type$$($schema$jscomp$31$$)],null),$malli$core$_properties$$($schema$jscomp$31$$),$malli$core$_options$$($schema$jscomp$31$$))};
$malli$core$_min_max_pred$$=function($f$jscomp$412$$){return function($map__32126__$1_p__32125$$){$map__32126__$1_p__32125$$=$APP.$cljs$core$__destructure_map$$($map__32126__$1_p__32125$$);var $min$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32126__$1_p__32125$$,$APP.$cljs$cst$338$min$$),$max$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32126__$1_p__32125$$,$APP.$cljs$cst$339$max$$);return $APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($min$jscomp$8$$)?
$min$jscomp$8$$:$max$jscomp$8$$)?null:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$72$$=$APP.$cljs$core$truth_$$($min$jscomp$8$$)?$max$jscomp$8$$:$min$jscomp$8$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$72$$)?$f$jscomp$412$$:$and__5023__auto__$jscomp$72$$}())?function($size$jscomp$40_x$jscomp$726$$){$size$jscomp$40_x$jscomp$726$$=$f$jscomp$412$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$412$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$40_x$jscomp$726$$):$f$jscomp$412$$($size$jscomp$40_x$jscomp$726$$);
return $min$jscomp$8$$<=$size$jscomp$40_x$jscomp$726$$&&$size$jscomp$40_x$jscomp$726$$<=$max$jscomp$8$$}:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($min$jscomp$8$$)?$max$jscomp$8$$:$min$jscomp$8$$)?function($x$jscomp$727$$){return $min$jscomp$8$$<=$x$jscomp$727$$&&$x$jscomp$727$$<=$max$jscomp$8$$}:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($min$jscomp$8$$)?$f$jscomp$412$$:$min$jscomp$8$$)?function($x$jscomp$728$$){return $min$jscomp$8$$<=($f$jscomp$412$$.$cljs$core$IFn$_invoke$arity$1$?
$f$jscomp$412$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$728$$):$f$jscomp$412$$($x$jscomp$728$$))}:$APP.$cljs$core$truth_$$($min$jscomp$8$$)?function($x$jscomp$729$$){return $min$jscomp$8$$<=$x$jscomp$729$$}:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($max$jscomp$8$$)?$f$jscomp$412$$:$max$jscomp$8$$)?function($x$jscomp$730$$){return($f$jscomp$412$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$412$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$730$$):$f$jscomp$412$$($x$jscomp$730$$))<=$max$jscomp$8$$}:
$APP.$cljs$core$truth_$$($max$jscomp$8$$)?function($x$jscomp$731$$){return $x$jscomp$731$$<=$max$jscomp$8$$}:null}};
$malli$core$_safe_count$$=function($x$jscomp$732$$){return $APP.$cljs$core$truth_$$($malli$core$_safely_countable_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$malli$core$_safely_countable_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$732$$):$malli$core$_safely_countable_QMARK_$$($x$jscomp$732$$))?$APP.$cljs$core$count$$($x$jscomp$732$$):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($cnt$jscomp$32$$){return $cnt$jscomp$32$$+1},0,$x$jscomp$732$$)};
$malli$core$_validate_limits$$=function($min$jscomp$9_or__5025__auto__$jscomp$104$$,$max$jscomp$9$$){$min$jscomp$9_or__5025__auto__$jscomp$104$$=$malli$core$_min_max_pred$$($malli$core$_safe_count$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,$min$jscomp$9_or__5025__auto__$jscomp$104$$,$APP.$cljs$cst$339$max$$,$max$jscomp$9$$],null));return $APP.$cljs$core$truth_$$($min$jscomp$9_or__5025__auto__$jscomp$104$$)?$min$jscomp$9_or__5025__auto__$jscomp$104$$:$APP.$cljs$core$constantly$$(!0)};
$malli$core$_needed_bounded_checks$$=function($min$jscomp$10_x__5110__auto__$jscomp$7_y__5111__auto__$jscomp$inline_14130$$,$max$jscomp$10_or__5025__auto__$jscomp$inline_14129_x__5110__auto__$jscomp$inline_14128$$,$options$jscomp$141_y__5111__auto__$jscomp$7$$){$max$jscomp$10_or__5025__auto__$jscomp$inline_14129_x__5110__auto__$jscomp$inline_14128$$=$max$jscomp$10_or__5025__auto__$jscomp$inline_14129_x__5110__auto__$jscomp$inline_14128$$==null?null:$max$jscomp$10_or__5025__auto__$jscomp$inline_14129_x__5110__auto__$jscomp$inline_14128$$+
1;$max$jscomp$10_or__5025__auto__$jscomp$inline_14129_x__5110__auto__$jscomp$inline_14128$$=$APP.$cljs$core$truth_$$($max$jscomp$10_or__5025__auto__$jscomp$inline_14129_x__5110__auto__$jscomp$inline_14128$$)?$max$jscomp$10_or__5025__auto__$jscomp$inline_14129_x__5110__auto__$jscomp$inline_14128$$:0;$min$jscomp$10_x__5110__auto__$jscomp$7_y__5111__auto__$jscomp$inline_14130$$=$APP.$cljs$core$truth_$$($min$jscomp$10_x__5110__auto__$jscomp$7_y__5111__auto__$jscomp$inline_14130$$)?$min$jscomp$10_x__5110__auto__$jscomp$7_y__5111__auto__$jscomp$inline_14130$$:
0;$min$jscomp$10_x__5110__auto__$jscomp$7_y__5111__auto__$jscomp$inline_14130$$=$max$jscomp$10_or__5025__auto__$jscomp$inline_14129_x__5110__auto__$jscomp$inline_14128$$>$min$jscomp$10_x__5110__auto__$jscomp$7_y__5111__auto__$jscomp$inline_14130$$?$max$jscomp$10_or__5025__auto__$jscomp$inline_14129_x__5110__auto__$jscomp$inline_14128$$:$min$jscomp$10_x__5110__auto__$jscomp$7_y__5111__auto__$jscomp$inline_14130$$;$options$jscomp$141_y__5111__auto__$jscomp$7$$=$cljs$cst$393$malli_DOT_core_SLASH_coll_check_limit$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$141_y__5111__auto__$jscomp$7$$,
101);return $min$jscomp$10_x__5110__auto__$jscomp$7_y__5111__auto__$jscomp$inline_14130$$>$options$jscomp$141_y__5111__auto__$jscomp$7$$?$min$jscomp$10_x__5110__auto__$jscomp$7_y__5111__auto__$jscomp$inline_14130$$:$options$jscomp$141_y__5111__auto__$jscomp$7$$};
$malli$core$_validate_bounded_limits$$=function($needed$$,$min$jscomp$11_or__5025__auto__$jscomp$107$$,$max$jscomp$11$$){$min$jscomp$11_or__5025__auto__$jscomp$107$$=$malli$core$_min_max_pred$$(function($p1__32161_SHARP_$$){return $cljs$core$bounded_count$$($needed$$,$p1__32161_SHARP_$$)})(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,$min$jscomp$11_or__5025__auto__$jscomp$107$$,$APP.$cljs$cst$339$max$$,$max$jscomp$11$$],null));return $APP.$cljs$core$truth_$$($min$jscomp$11_or__5025__auto__$jscomp$107$$)?
$min$jscomp$11_or__5025__auto__$jscomp$107$$:$APP.$cljs$core$constantly$$(!0)};
$malli$core$t_malli$0core32221$$=function($form$jscomp$38$$,$options$jscomp$142$$,$property_pred$$,$compile$$,$to_ast$$,$props$jscomp$11$$,$meta32193$$,$properties$jscomp$16$$,$map__32183$$,$children$jscomp$26$$,$min$jscomp$12$$,$type_properties$$,$parent$jscomp$24$$,$pred$jscomp$30$$,$type$jscomp$197$$,$from_ast$$,$cache$jscomp$8$$,$max$jscomp$12$$,$meta32222$$){this.form=$form$jscomp$38$$;this.options=$options$jscomp$142$$;this.$property_pred$=$property_pred$$;this.compile=$compile$$;this.$to_ast$=
$to_ast$$;this.props=$props$jscomp$11$$;this.$meta32193$=$meta32193$$;this.$properties$=$properties$jscomp$16$$;this.$map__32183$=$map__32183$$;this.children=$children$jscomp$26$$;this.min=$min$jscomp$12$$;this.$type_properties$=$type_properties$$;this.parent=$parent$jscomp$24$$;this.$pred$=$pred$jscomp$30$$;this.type=$type$jscomp$197$$;this.$from_ast$=$from_ast$$;this.cache=$cache$jscomp$8$$;this.max=$max$jscomp$12$$;this.$meta32222$=$meta32222$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;
this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core32192$$=function($property_pred$jscomp$2$$,$compile$jscomp$2$$,$to_ast$jscomp$2$$,$props$jscomp$13$$,$map__32183$jscomp$2$$,$min$jscomp$14$$,$type_properties$jscomp$2$$,$pred$jscomp$32$$,$type$jscomp$199$$,$from_ast$jscomp$2$$,$max$jscomp$14$$,$meta32193$jscomp$2$$){this.$property_pred$=$property_pred$jscomp$2$$;this.compile=$compile$jscomp$2$$;this.$to_ast$=$to_ast$jscomp$2$$;this.props=$props$jscomp$13$$;this.$map__32183$=$map__32183$jscomp$2$$;this.min=$min$jscomp$14$$;
this.$type_properties$=$type_properties$jscomp$2$$;this.$pred$=$pred$jscomp$32$$;this.type=$type$jscomp$199$$;this.$from_ast$=$from_ast$jscomp$2$$;this.max=$max$jscomp$14$$;this.$meta32193$=$meta32193$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core32354$$=function($meta32316$$,$parent$jscomp$28$$,$properties$jscomp$19$$,$children$jscomp$29$$,$options$jscomp$146$$,$form$jscomp$41$$,$cache$jscomp$11$$,$__GT_parser$$,$meta32355$$){this.$meta32316$=$meta32316$$;this.parent=$parent$jscomp$28$$;this.$properties$=$properties$jscomp$19$$;this.children=$children$jscomp$29$$;this.options=$options$jscomp$146$$;this.form=$form$jscomp$41$$;this.cache=$cache$jscomp$11$$;this.$__GT_parser$=$__GT_parser$$;this.$meta32355$=$meta32355$$;
this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};$malli$core$t_malli$0core32315$$=function($meta32316$jscomp$2$$){this.$meta32316$=$meta32316$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core32419$$=function($meta32403$$,$parent$jscomp$31$$,$properties$jscomp$22$$,$children$jscomp$32$$,$options$jscomp$149$$,$form$jscomp$44$$,$cache$jscomp$14$$,$__GT_parser$jscomp$3$$,$meta32420$$){this.$meta32403$=$meta32403$$;this.parent=$parent$jscomp$31$$;this.$properties$=$properties$jscomp$22$$;this.children=$children$jscomp$32$$;this.options=$options$jscomp$149$$;this.form=$form$jscomp$44$$;this.cache=$cache$jscomp$14$$;this.$__GT_parser$=$__GT_parser$jscomp$3$$;this.$meta32420$=
$meta32420$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};$malli$core$t_malli$0core32402$$=function($meta32403$jscomp$2$$){this.$meta32403$=$meta32403$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core32494$$=function($meta32487$$,$parent$jscomp$34$$,$properties$jscomp$25$$,$children$jscomp$35$$,$options$jscomp$152$$,$entry_parser$jscomp$3$$,$form$jscomp$47$$,$cache$jscomp$17$$,$meta32495$$){this.$meta32487$=$meta32487$$;this.parent=$parent$jscomp$34$$;this.$properties$=$properties$jscomp$25$$;this.children=$children$jscomp$35$$;this.options=$options$jscomp$152$$;this.$entry_parser$=$entry_parser$jscomp$3$$;this.form=$form$jscomp$47$$;this.cache=$cache$jscomp$17$$;this.$meta32495$=
$meta32495$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};$malli$core$t_malli$0core32486$$=function($meta32487$jscomp$2$$){this.$meta32487$=$meta32487$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core32608$$=function($form$jscomp$50$$,$options$jscomp$156$$,$properties$jscomp$28$$,$schema$jscomp$32$$,$children$jscomp$38$$,$parent$jscomp$38$$,$cache$jscomp$20$$,$meta32590$$,$vec__32603$$,$meta32609$$){this.form=$form$jscomp$50$$;this.options=$options$jscomp$156$$;this.$properties$=$properties$jscomp$28$$;this.$schema$=$schema$jscomp$32$$;this.children=$children$jscomp$38$$;this.parent=$parent$jscomp$38$$;this.cache=$cache$jscomp$20$$;this.$meta32590$=$meta32590$$;this.$vec__32603$=
$vec__32603$$;this.$meta32609$=$meta32609$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};$malli$core$t_malli$0core32589$$=function($meta32590$jscomp$2$$){this.$meta32590$=$meta32590$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core32664$$=function($meta32656$$,$parent$jscomp$42$$,$properties$jscomp$31$$,$children$jscomp$41$$,$options$jscomp$160$$,$form$jscomp$53$$,$schema$jscomp$35$$,$cache$jscomp$23$$,$meta32665$$){this.$meta32656$=$meta32656$$;this.parent=$parent$jscomp$42$$;this.$properties$=$properties$jscomp$31$$;this.children=$children$jscomp$41$$;this.options=$options$jscomp$160$$;this.form=$form$jscomp$53$$;this.$schema$=$schema$jscomp$35$$;this.cache=$cache$jscomp$23$$;this.$meta32665$=$meta32665$$;
this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};$malli$core$t_malli$0core32655$$=function($meta32656$jscomp$2$$){this.$meta32656$=$meta32656$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$_val_schema$$=function($var_args$jscomp$445$$){switch(arguments.length){case 2:return $malli$core$_val_schema$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);case 0:return new $malli$core$t_malli$0core32655$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null));default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$core$_val_schema$cljs$0core$0IFn$0_invoke$0arity$02$$=function($schema$jscomp$38$$,$properties$jscomp$34$$){return $malli$core$_into_schema$$(new $malli$core$t_malli$0core32655$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null)),$properties$jscomp$34$$,new $APP.$cljs$core$List$$(null,$schema$jscomp$38$$,null,1,null),$malli$core$_options$$($schema$jscomp$38$$))};
$malli$core$t_malli$0core32820$$=function($form$jscomp$56$$,$options$jscomp$164$$,$map__32776$$,$properties$jscomp$35$$,$closed$$,$children$jscomp$44$$,$entry_parser$jscomp$6$$,$parent$jscomp$46$$,$explicit_children$$,$default_schema$$,$meta32751$$,$pred_QMARK_$jscomp$2$$,$__GT_parser$jscomp$6$$,$cache$jscomp$26$$,$p__32775$$,$opts$jscomp$156$$,$meta32821$$){this.form=$form$jscomp$56$$;this.options=$options$jscomp$164$$;this.$map__32776$=$map__32776$$;this.$properties$=$properties$jscomp$35$$;this.closed=
$closed$$;this.children=$children$jscomp$44$$;this.$entry_parser$=$entry_parser$jscomp$6$$;this.parent=$parent$jscomp$46$$;this.$explicit_children$=$explicit_children$$;this.$default_schema$=$default_schema$$;this.$meta32751$=$meta32751$$;this.$pred_QMARK_$=$pred_QMARK_$jscomp$2$$;this.$__GT_parser$=$__GT_parser$jscomp$6$$;this.cache=$cache$jscomp$26$$;this.$p__32775$=$p__32775$$;this.$opts$=$opts$jscomp$156$$;this.$meta32821$=$meta32821$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=
0};$malli$core$t_malli$0core32750$$=function($opts$jscomp$158$$,$meta32751$jscomp$2$$){this.$opts$=$opts$jscomp$158$$;this.$meta32751$=$meta32751$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core32964$$=function($form$jscomp$59$$,$options$jscomp$168$$,$p__32957$$,$properties$jscomp$38$$,$children$jscomp$47$$,$min$jscomp$17$$,$map__32958$$,$value_schema$$,$parent$jscomp$50$$,$meta32940$$,$key_schema$$,$__GT_parser$jscomp$9$$,$cache$jscomp$29$$,$validate_limits$$,$max$jscomp$17$$,$opts$jscomp$161$$,$vec__32959$$,$meta32965$$){this.form=$form$jscomp$59$$;this.options=$options$jscomp$168$$;this.$p__32957$=$p__32957$$;this.$properties$=$properties$jscomp$38$$;this.children=
$children$jscomp$47$$;this.min=$min$jscomp$17$$;this.$map__32958$=$map__32958$$;this.$value_schema$=$value_schema$$;this.parent=$parent$jscomp$50$$;this.$meta32940$=$meta32940$$;this.$key_schema$=$key_schema$$;this.$__GT_parser$=$__GT_parser$jscomp$9$$;this.cache=$cache$jscomp$29$$;this.$validate_limits$=$validate_limits$$;this.max=$max$jscomp$17$$;this.$opts$=$opts$jscomp$161$$;this.$vec__32959$=$vec__32959$$;this.$meta32965$=$meta32965$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=
0};$malli$core$t_malli$0core32939$$=function($opts$jscomp$163$$,$meta32940$jscomp$2$$){this.$opts$=$opts$jscomp$163$$;this.$meta32940$=$meta32940$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};$malli$core$_safely_countable_QMARK_$$=function($x$jscomp$753$$){return $x$jscomp$753$$==null||$cljs$core$counted_QMARK_$$($x$jscomp$753$$)||$cljs$core$indexed_QMARK_$$($x$jscomp$753$$)||typeof $x$jscomp$753$$==="string"||Array===$APP.$cljs$core$type$$($x$jscomp$753$$)};
$malli$core$t_malli$0core33039$$=function($form$jscomp$62$$,$vec__33032$$,$options$jscomp$172$$,$map__33026$$,$temp__5823__auto__$jscomp$55$$,$fpred$$,$fin$$,$props$jscomp$16$$,$properties$jscomp$41$$,$unparse$jscomp$3$$,$schema$jscomp$41$$,$children$jscomp$50$$,$min$jscomp$20$$,$p__33025$$,$bounded$$,$parent$jscomp$54$$,$map__33029$$,$type$jscomp$202$$,$meta33018$$,$__GT_parser$jscomp$12$$,$fempty$$,$cache$jscomp$32$$,$validate_limits$jscomp$3$$,$max$jscomp$20$$,$parse$jscomp$1$$,$meta33040$$){this.form=
$form$jscomp$62$$;this.$vec__33032$=$vec__33032$$;this.options=$options$jscomp$172$$;this.$map__33026$=$map__33026$$;this.$temp__5823__auto__$=$temp__5823__auto__$jscomp$55$$;this.$fpred$=$fpred$$;this.$fin$=$fin$$;this.props=$props$jscomp$16$$;this.$properties$=$properties$jscomp$41$$;this.$unparse$=$unparse$jscomp$3$$;this.$schema$=$schema$jscomp$41$$;this.children=$children$jscomp$50$$;this.min=$min$jscomp$20$$;this.$p__33025$=$p__33025$$;this.$bounded$=$bounded$$;this.parent=$parent$jscomp$54$$;
this.$map__33029$=$map__33029$$;this.type=$type$jscomp$202$$;this.$meta33018$=$meta33018$$;this.$__GT_parser$=$__GT_parser$jscomp$12$$;this.$fempty$=$fempty$$;this.cache=$cache$jscomp$32$$;this.$validate_limits$=$validate_limits$jscomp$3$$;this.max=$max$jscomp$20$$;this.parse=$parse$jscomp$1$$;this.$meta33040$=$meta33040$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33017$$=function($props$jscomp$18$$,$meta33018$jscomp$2$$){this.props=$props$jscomp$18$$;this.$meta33018$=$meta33018$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33144$$=function($form$jscomp$65$$,$options$jscomp$176$$,$properties$jscomp$44$$,$children$jscomp$53$$,$parent$jscomp$58$$,$size$jscomp$42$$,$__GT_parser$jscomp$15$$,$meta33130$$,$cache$jscomp$35$$,$opts$jscomp$168$$,$meta33145$$){this.form=$form$jscomp$65$$;this.options=$options$jscomp$176$$;this.$properties$=$properties$jscomp$44$$;this.children=$children$jscomp$53$$;this.parent=$parent$jscomp$58$$;this.size=$size$jscomp$42$$;this.$__GT_parser$=$__GT_parser$jscomp$15$$;
this.$meta33130$=$meta33130$$;this.cache=$cache$jscomp$35$$;this.$opts$=$opts$jscomp$168$$;this.$meta33145$=$meta33145$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};$malli$core$t_malli$0core33129$$=function($opts$jscomp$170$$,$meta33130$jscomp$2$$){this.$opts$=$opts$jscomp$170$$;this.$meta33130$=$meta33130$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33218$$=function($meta33211$$,$parent$jscomp$61$$,$properties$jscomp$47$$,$children$jscomp$56$$,$options$jscomp$179$$,$schema$jscomp$44$$,$form$jscomp$68$$,$cache$jscomp$38$$,$meta33219$$){this.$meta33211$=$meta33211$$;this.parent=$parent$jscomp$61$$;this.$properties$=$properties$jscomp$47$$;this.children=$children$jscomp$56$$;this.options=$options$jscomp$179$$;this.$schema$=$schema$jscomp$44$$;this.form=$form$jscomp$68$$;this.cache=$cache$jscomp$38$$;this.$meta33219$=$meta33219$$;
this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};$malli$core$t_malli$0core33210$$=function($meta33211$jscomp$2$$){this.$meta33211$=$meta33211$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33258$$=function($form$jscomp$71$$,$options$jscomp$183$$,$child$jscomp$6$$,$properties$jscomp$50$$,$children$jscomp$59$$,$parent$jscomp$65$$,$vec__33254$$,$re$jscomp$14$$,$class_QMARK_$$,$meta33240$$,$p__33253$$,$matches_QMARK_$$,$cache$jscomp$41$$,$meta33259$$){this.form=$form$jscomp$71$$;this.options=$options$jscomp$183$$;this.$child$=$child$jscomp$6$$;this.$properties$=$properties$jscomp$50$$;this.children=$children$jscomp$59$$;this.parent=$parent$jscomp$65$$;this.$vec__33254$=
$vec__33254$$;this.re=$re$jscomp$14$$;this.$class_QMARK_$=$class_QMARK_$$;this.$meta33240$=$meta33240$$;this.$p__33253$=$p__33253$$;this.$matches_QMARK_$=$matches_QMARK_$$;this.cache=$cache$jscomp$41$$;this.$meta33259$=$meta33259$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33239$$=function($class_QMARK_$jscomp$2$$,$meta33240$jscomp$2$$){this.$class_QMARK_$=$class_QMARK_$jscomp$2$$;this.$meta33240$=$meta33240$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33384$$=function($meta33359$$,$parent$jscomp$69$$,$properties$jscomp$53$$,$children$jscomp$62$$,$options$jscomp$187$$,$f$jscomp$419$$,$form$jscomp$74$$,$cache$jscomp$44$$,$meta33385$$){this.$meta33359$=$meta33359$$;this.parent=$parent$jscomp$69$$;this.$properties$=$properties$jscomp$53$$;this.children=$children$jscomp$62$$;this.options=$options$jscomp$187$$;this.f=$f$jscomp$419$$;this.form=$form$jscomp$74$$;this.cache=$cache$jscomp$44$$;this.$meta33385$=$meta33385$$;this.$cljs$lang$protocol_mask$partition0$$=
2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};$malli$core$t_malli$0core33358$$=function($meta33359$jscomp$2$$){this.$meta33359$=$meta33359$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33557$$=function($form$jscomp$77$$,$options$jscomp$191$$,$properties$jscomp$56$$,$schema$jscomp$47$$,$children$jscomp$65$$,$parent$jscomp$73$$,$vec__33548$$,$__GT_parser$jscomp$18$$,$meta33507$$,$cache$jscomp$47$$,$meta33558$$){this.form=$form$jscomp$77$$;this.options=$options$jscomp$191$$;this.$properties$=$properties$jscomp$56$$;this.$schema$=$schema$jscomp$47$$;this.children=$children$jscomp$65$$;this.parent=$parent$jscomp$73$$;this.$vec__33548$=$vec__33548$$;this.$__GT_parser$=
$__GT_parser$jscomp$18$$;this.$meta33507$=$meta33507$$;this.cache=$cache$jscomp$47$$;this.$meta33558$=$meta33558$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};$malli$core$t_malli$0core33506$$=function($meta33507$jscomp$2$$){this.$meta33507$=$meta33507$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33688$$=function($form$jscomp$80$$,$options$jscomp$195$$,$properties$jscomp$59$$,$children$jscomp$68$$,$entry_parser$jscomp$9$$,$parent$jscomp$77$$,$meta33659$$,$opts_SINGLEQUOTE_$$,$dispatch$$,$cache$jscomp$50$$,$finder$$,$opts$jscomp$181$$,$dispatch_map$$,$meta33689$$){this.form=$form$jscomp$80$$;this.options=$options$jscomp$195$$;this.$properties$=$properties$jscomp$59$$;this.children=$children$jscomp$68$$;this.$entry_parser$=$entry_parser$jscomp$9$$;this.parent=$parent$jscomp$77$$;
this.$meta33659$=$meta33659$$;this.$opts_SINGLEQUOTE_$=$opts_SINGLEQUOTE_$$;this.$dispatch$=$dispatch$$;this.cache=$cache$jscomp$50$$;this.$finder$=$finder$$;this.$opts$=$opts$jscomp$181$$;this.$dispatch_map$=$dispatch_map$$;this.$meta33689$=$meta33689$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33658$$=function($opts$jscomp$183$$,$meta33659$jscomp$2$$){this.$opts$=$opts$jscomp$183$$;this.$meta33659$=$meta33659$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33738$$=function($form$jscomp$83$$,$options$jscomp$199$$,$properties$jscomp$62$$,$p__33728$$,$children$jscomp$71$$,$type_properties$jscomp$5$$,$rf$jscomp$23$$,$parent$jscomp$81$$,$p__33723$$,$ref$jscomp$3$$,$map__33733$$,$map__33724$$,$__GT_parser$jscomp$21$$,$p__33729$$,$vec__33730$$,$cache$jscomp$53$$,$meta33726$$,$lazy$$,$allow_invalid_refs$$,$meta33739$$){this.form=$form$jscomp$83$$;this.options=$options$jscomp$199$$;this.$properties$=$properties$jscomp$62$$;this.$p__33728$=
$p__33728$$;this.children=$children$jscomp$71$$;this.$type_properties$=$type_properties$jscomp$5$$;this.rf=$rf$jscomp$23$$;this.parent=$parent$jscomp$81$$;this.$p__33723$=$p__33723$$;this.ref=$ref$jscomp$3$$;this.$map__33733$=$map__33733$$;this.$map__33724$=$map__33724$$;this.$__GT_parser$=$__GT_parser$jscomp$21$$;this.$p__33729$=$p__33729$$;this.$vec__33730$=$vec__33730$$;this.cache=$cache$jscomp$53$$;this.$meta33726$=$meta33726$$;this.lazy=$lazy$$;this.$allow_invalid_refs$=$allow_invalid_refs$$;
this.$meta33739$=$meta33739$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33725$$=function($p__33723$jscomp$2$$,$map__33724$jscomp$2$$,$lazy$jscomp$2$$,$type_properties$jscomp$7$$,$meta33726$jscomp$2$$){this.$p__33723$=$p__33723$jscomp$2$$;this.$map__33724$=$map__33724$jscomp$2$$;this.lazy=$lazy$jscomp$2$$;this.$type_properties$=$type_properties$jscomp$7$$;this.$meta33726$=$meta33726$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$_ref_schema$$=function($var_args$jscomp$450$$){switch(arguments.length){case 0:return $malli$core$_ref_schema$cljs$0core$0IFn$0_invoke$0arity$01$$(null);case 1:return $malli$core$_ref_schema$cljs$0core$0IFn$0_invoke$0arity$01$$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$core$_ref_schema$cljs$0core$0IFn$0_invoke$0arity$01$$=function($p__33723$jscomp$4$$){var $map__33724__$1$$=$APP.$cljs$core$__destructure_map$$($p__33723$jscomp$4$$),$lazy$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33724__$1$$,$cljs$cst$343$lazy$$),$type_properties$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33724__$1$$,$cljs$cst$415$type_properties$$);return new $malli$core$t_malli$0core33725$$($p__33723$jscomp$4$$,$map__33724__$1$$,$lazy$jscomp$4$$,
$type_properties$jscomp$9$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null))};
$malli$core$t_malli$0core33751$$=function($form$jscomp$86$$,$options$jscomp$203$$,$child$jscomp$9$$,$properties$jscomp$65$$,$meta33748$$,$children$jscomp$74$$,$parent$jscomp$85$$,$raw$$,$map__33746$$,$type$jscomp$205$$,$internal$$,$cache$jscomp$56$$,$id$jscomp$10$$,$p__33745$$,$meta33752$$){this.form=$form$jscomp$86$$;this.options=$options$jscomp$203$$;this.$child$=$child$jscomp$9$$;this.$properties$=$properties$jscomp$65$$;this.$meta33748$=$meta33748$$;this.children=$children$jscomp$74$$;this.parent=
$parent$jscomp$85$$;this.raw=$raw$$;this.$map__33746$=$map__33746$$;this.type=$type$jscomp$205$$;this.$internal$=$internal$$;this.cache=$cache$jscomp$56$$;this.id=$id$jscomp$10$$;this.$p__33745$=$p__33745$$;this.$meta33752$=$meta33752$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33747$$=function($p__33745$jscomp$2$$,$map__33746$jscomp$2$$,$id$jscomp$12$$,$raw$jscomp$2$$,$internal$jscomp$2$$,$type$jscomp$207$$,$meta33748$jscomp$2$$){this.$p__33745$=$p__33745$jscomp$2$$;this.$map__33746$=$map__33746$jscomp$2$$;this.id=$id$jscomp$12$$;this.raw=$raw$jscomp$2$$;this.$internal$=$internal$jscomp$2$$;this.type=$type$jscomp$207$$;this.$meta33748$=$meta33748$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=
0};
$malli$core$_schema_schema$$=function($p__33745$jscomp$4$$){var $map__33746__$1$$=$APP.$cljs$core$__destructure_map$$($p__33745$jscomp$4$$),$id$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33746__$1$$,$APP.$cljs$cst$266$id$$),$raw$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33746__$1$$,$APP.$cljs$cst$561$raw$$),$internal$jscomp$4$$=$APP.$cljs$core$truth_$$($id$jscomp$14$$)?$id$jscomp$14$$:$raw$jscomp$4$$;return new $malli$core$t_malli$0core33747$$($p__33745$jscomp$4$$,$map__33746__$1$$,
$id$jscomp$14$$,$raw$jscomp$4$$,$internal$jscomp$4$$,$APP.$cljs$core$truth_$$($internal$jscomp$4$$)?$cljs$cst$412$malli_DOT_core_SLASH_schema$$:$APP.$cljs$cst$298$schema$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null))};
$malli$core$t_malli$0core33772$$=function($form$jscomp$89$$,$input$jscomp$50$$,$options$jscomp$207$$,$guard$$,$p__33765$$,$properties$jscomp$68$$,$children$jscomp$77$$,$map__33766$$,$parent$jscomp$89$$,$meta33760$$,$vec__33767$$,$__GT_checker$$,$output$jscomp$2$$,$function_checker$$,$cache$jscomp$59$$,$meta33773$$){this.form=$form$jscomp$89$$;this.input=$input$jscomp$50$$;this.options=$options$jscomp$207$$;this.$guard$=$guard$$;this.$p__33765$=$p__33765$$;this.$properties$=$properties$jscomp$68$$;
this.children=$children$jscomp$77$$;this.$map__33766$=$map__33766$$;this.parent=$parent$jscomp$89$$;this.$meta33760$=$meta33760$$;this.$vec__33767$=$vec__33767$$;this.$__GT_checker$=$__GT_checker$$;this.output=$output$jscomp$2$$;this.$function_checker$=$function_checker$$;this.cache=$cache$jscomp$59$$;this.$meta33773$=$meta33773$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33759$$=function($meta33760$jscomp$2$$){this.$meta33760$=$meta33760$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33807$$=function($form$jscomp$92$$,$options$jscomp$211$$,$meta33803$$,$p__33805$$,$properties$jscomp$72$$,$children$jscomp$80$$,$parent$jscomp$93$$,$_$jscomp$593$$,$map__33806$$,$__GT_checker$jscomp$3$$,$function_checker$jscomp$3$$,$cache$jscomp$62$$,$meta33808$$){this.form=$form$jscomp$92$$;this.options=$options$jscomp$211$$;this.$meta33803$=$meta33803$$;this.$p__33805$=$p__33805$$;this.$properties$=$properties$jscomp$72$$;this.children=$children$jscomp$80$$;this.parent=
$parent$jscomp$93$$;this.$_$=$_$jscomp$593$$;this.$map__33806$=$map__33806$$;this.$__GT_checker$=$__GT_checker$jscomp$3$$;this.$function_checker$=$function_checker$jscomp$3$$;this.cache=$cache$jscomp$62$$;this.$meta33808$=$meta33808$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33802$$=function($_$jscomp$595$$,$meta33803$jscomp$2$$){this.$_$=$_$jscomp$595$$;this.$meta33803$=$meta33803$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33838$$=function($form$jscomp$95$$,$options$jscomp$214$$,$map__33823$$,$forms$jscomp$4$$,$meta33828$$,$properties$jscomp$75$$,$childs$$,$schema$jscomp$51$$,$children$jscomp$83$$,$min$jscomp$25$$,$type_properties$jscomp$10$$,$fn$jscomp$10$$,$parent$jscomp$96$$,$type$jscomp$210$$,$cache$jscomp$65$$,$max$jscomp$25$$,$vec__33831$$,$p__33822$$,$meta33839$$){this.form=$form$jscomp$95$$;this.options=$options$jscomp$214$$;this.$map__33823$=$map__33823$$;this.forms=$forms$jscomp$4$$;
this.$meta33828$=$meta33828$$;this.$properties$=$properties$jscomp$75$$;this.$childs$=$childs$$;this.$schema$=$schema$jscomp$51$$;this.children=$children$jscomp$83$$;this.min=$min$jscomp$25$$;this.$type_properties$=$type_properties$jscomp$10$$;this.fn=$fn$jscomp$10$$;this.parent=$parent$jscomp$96$$;this.type=$type$jscomp$210$$;this.cache=$cache$jscomp$65$$;this.max=$max$jscomp$25$$;this.$vec__33831$=$vec__33831$$;this.$p__33822$=$p__33822$$;this.$meta33839$=$meta33839$$;this.$cljs$lang$protocol_mask$partition0$$=
2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33827$$=function($p__33822$jscomp$2$$,$map__33823$jscomp$2$$,$type$jscomp$212$$,$min$jscomp$27$$,$max$jscomp$27$$,$childs$jscomp$2$$,$type_properties$jscomp$12$$,$fn$jscomp$12$$,$meta33828$jscomp$2$$){this.$p__33822$=$p__33822$jscomp$2$$;this.$map__33823$=$map__33823$jscomp$2$$;this.type=$type$jscomp$212$$;this.min=$min$jscomp$27$$;this.max=$max$jscomp$27$$;this.$childs$=$childs$jscomp$2$$;this.$type_properties$=$type_properties$jscomp$12$$;this.fn=$fn$jscomp$12$$;this.$meta33828$=
$meta33828$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$_proxy_schema$$=function($p__33822$jscomp$4$$){var $map__33823__$1$$=$APP.$cljs$core$__destructure_map$$($p__33822$jscomp$4$$),$type$jscomp$214$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33823__$1$$,$APP.$cljs$cst$139$type$$),$min$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33823__$1$$,$APP.$cljs$cst$338$min$$),$max$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33823__$1$$,$APP.$cljs$cst$339$max$$),$childs$jscomp$4$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33823__$1$$,$cljs$cst$614$childs$$),$type_properties$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33823__$1$$,$cljs$cst$415$type_properties$$),$fn$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33823__$1$$,$APP.$cljs$cst$516$fn$$);return new $malli$core$t_malli$0core33827$$($p__33822$jscomp$4$$,$map__33823__$1$$,$type$jscomp$214$$,$min$jscomp$29$$,$max$jscomp$29$$,$childs$jscomp$4$$,$type_properties$jscomp$14$$,
$fn$jscomp$14$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null))};
$malli$core$regex_transformer$$=function($__GT_children$jscomp$3_schema$jscomp$57$$,$transformer$jscomp$34$$,$method$jscomp$34$$,$options$jscomp$217$$){var $this_transformer$jscomp$7$$=$malli$core$_value_transformer$$($transformer$jscomp$34$$,$__GT_children$jscomp$3_schema$jscomp$57$$,$method$jscomp$34$$,$options$jscomp$217$$);$__GT_children$jscomp$3_schema$jscomp$57$$=$malli$impl$regex$transformer$$($malli$core$_regex_transformer$$($__GT_children$jscomp$3_schema$jscomp$57$$,$transformer$jscomp$34$$,
$method$jscomp$34$$,$options$jscomp$217$$));return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$02$$($this_transformer$jscomp$7$$,$__GT_children$jscomp$3_schema$jscomp$57$$)};
$malli$core$t_malli$0core33873$$=function($form$jscomp$98$$,$options$jscomp$218$$,$re_min_max$$,$properties$jscomp$78$$,$re_explainer$$,$children$jscomp$86$$,$min$jscomp$30$$,$re_parser$$,$parent$jscomp$99$$,$re_unparser$$,$type$jscomp$215$$,$map__33857$$,$map__33858$$,$meta33862$$,$cache$jscomp$68$$,$re_transformer$$,$max$jscomp$30$$,$p__33856$$,$re_validator$$,$meta33874$$){this.form=$form$jscomp$98$$;this.options=$options$jscomp$218$$;this.$re_min_max$=$re_min_max$$;this.$properties$=$properties$jscomp$78$$;
this.$re_explainer$=$re_explainer$$;this.children=$children$jscomp$86$$;this.min=$min$jscomp$30$$;this.$re_parser$=$re_parser$$;this.parent=$parent$jscomp$99$$;this.$re_unparser$=$re_unparser$$;this.type=$type$jscomp$215$$;this.$map__33857$=$map__33857$$;this.$map__33858$=$map__33858$$;this.$meta33862$=$meta33862$$;this.cache=$cache$jscomp$68$$;this.$re_transformer$=$re_transformer$$;this.max=$max$jscomp$30$$;this.$p__33856$=$p__33856$$;this.$re_validator$=$re_validator$$;this.$meta33874$=$meta33874$$;
this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33861$$=function($re_min_max$jscomp$2$$,$re_explainer$jscomp$2$$,$min$jscomp$32$$,$re_parser$jscomp$2$$,$re_unparser$jscomp$2$$,$type$jscomp$217$$,$map__33857$jscomp$2$$,$map__33858$jscomp$2$$,$re_transformer$jscomp$2$$,$max$jscomp$32$$,$p__33856$jscomp$2$$,$re_validator$jscomp$2$$,$meta33862$jscomp$2$$){this.$re_min_max$=$re_min_max$jscomp$2$$;this.$re_explainer$=$re_explainer$jscomp$2$$;this.min=$min$jscomp$32$$;this.$re_parser$=$re_parser$jscomp$2$$;this.$re_unparser$=
$re_unparser$jscomp$2$$;this.type=$type$jscomp$217$$;this.$map__33857$=$map__33857$jscomp$2$$;this.$map__33858$=$map__33858$jscomp$2$$;this.$re_transformer$=$re_transformer$jscomp$2$$;this.max=$max$jscomp$32$$;this.$p__33856$=$p__33856$jscomp$2$$;this.$re_validator$=$re_validator$jscomp$2$$;this.$meta33862$=$meta33862$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$_sequence_schema$$=function($p__33856$jscomp$4$$){var $map__33857__$1$$=$APP.$cljs$core$__destructure_map$$($p__33856$jscomp$4$$),$map__33858$jscomp$4_map__33858__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33857__$1$$,$cljs$cst$628$child_bounds$$);$map__33858$jscomp$4_map__33858__$1$$=$APP.$cljs$core$__destructure_map$$($map__33858$jscomp$4_map__33858__$1$$);var $min$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33858$jscomp$4_map__33858__$1$$,
$APP.$cljs$cst$338$min$$),$max$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33858$jscomp$4_map__33858__$1$$,$APP.$cljs$cst$339$max$$),$type$jscomp$219$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33857__$1$$,$APP.$cljs$cst$139$type$$),$re_validator$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33857__$1$$,$cljs$cst$629$re_validator$$),$re_explainer$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33857__$1$$,
$cljs$cst$630$re_explainer$$),$re_parser$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33857__$1$$,$cljs$cst$631$re_parser$$),$re_unparser$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33857__$1$$,$cljs$cst$632$re_unparser$$),$re_transformer$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33857__$1$$,$cljs$cst$633$re_transformer$$),$re_min_max$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33857__$1$$,
$cljs$cst$634$re_min_max$$);return new $malli$core$t_malli$0core33861$$($re_min_max$jscomp$4$$,$re_explainer$jscomp$4$$,$min$jscomp$34$$,$re_parser$jscomp$4$$,$re_unparser$jscomp$4$$,$type$jscomp$219$$,$map__33857__$1$$,$map__33858$jscomp$4_map__33858__$1$$,$re_transformer$jscomp$4$$,$max$jscomp$34$$,$p__33856$jscomp$4$$,$re_validator$jscomp$4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null))};
$malli$core$t_malli$0core33934$$=function($form$jscomp$101$$,$p__33923$$,$options$jscomp$221$$,$re_min_max$jscomp$5$$,$keep$$,$properties$jscomp$81$$,$re_explainer$jscomp$5$$,$children$jscomp$89$$,$min$jscomp$35$$,$re_parser$jscomp$5$$,$entry_parser$jscomp$12$$,$parent$jscomp$102$$,$re_unparser$jscomp$5$$,$meta33927$$,$type$jscomp$220$$,$map__33924$$,$cache$jscomp$71$$,$map__33925$$,$re_transformer$jscomp$5$$,$max$jscomp$35$$,$opts$jscomp$198$$,$re_validator$jscomp$5$$,$meta33935$$){this.form=$form$jscomp$101$$;
this.$p__33923$=$p__33923$$;this.options=$options$jscomp$221$$;this.$re_min_max$=$re_min_max$jscomp$5$$;this.$keep$=$keep$$;this.$properties$=$properties$jscomp$81$$;this.$re_explainer$=$re_explainer$jscomp$5$$;this.children=$children$jscomp$89$$;this.min=$min$jscomp$35$$;this.$re_parser$=$re_parser$jscomp$5$$;this.$entry_parser$=$entry_parser$jscomp$12$$;this.parent=$parent$jscomp$102$$;this.$re_unparser$=$re_unparser$jscomp$5$$;this.$meta33927$=$meta33927$$;this.type=$type$jscomp$220$$;this.$map__33924$=
$map__33924$$;this.cache=$cache$jscomp$71$$;this.$map__33925$=$map__33925$$;this.$re_transformer$=$re_transformer$jscomp$5$$;this.max=$max$jscomp$35$$;this.$opts$=$opts$jscomp$198$$;this.$re_validator$=$re_validator$jscomp$5$$;this.$meta33935$=$meta33935$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$t_malli$0core33926$$=function($p__33923$jscomp$2$$,$re_min_max$jscomp$7$$,$keep$jscomp$2$$,$re_explainer$jscomp$7$$,$min$jscomp$37$$,$re_parser$jscomp$7$$,$re_unparser$jscomp$7$$,$type$jscomp$222$$,$map__33924$jscomp$2$$,$map__33925$jscomp$2$$,$re_transformer$jscomp$7$$,$max$jscomp$37$$,$opts$jscomp$200$$,$re_validator$jscomp$7$$,$meta33927$jscomp$2$$){this.$p__33923$=$p__33923$jscomp$2$$;this.$re_min_max$=$re_min_max$jscomp$7$$;this.$keep$=$keep$jscomp$2$$;this.$re_explainer$=$re_explainer$jscomp$7$$;
this.min=$min$jscomp$37$$;this.$re_parser$=$re_parser$jscomp$7$$;this.$re_unparser$=$re_unparser$jscomp$7$$;this.type=$type$jscomp$222$$;this.$map__33924$=$map__33924$jscomp$2$$;this.$map__33925$=$map__33925$jscomp$2$$;this.$re_transformer$=$re_transformer$jscomp$7$$;this.max=$max$jscomp$37$$;this.$opts$=$opts$jscomp$200$$;this.$re_validator$=$re_validator$jscomp$7$$;this.$meta33927$=$meta33927$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2147876864;this.$cljs$lang$protocol_mask$partition1$$=
0};
$malli$core$_sequence_entry_schema$$=function($p__33923$jscomp$4$$){var $map__33924__$1$$=$APP.$cljs$core$__destructure_map$$($p__33923$jscomp$4$$),$map__33925$jscomp$4_map__33925__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33924__$1$$,$cljs$cst$628$child_bounds$$);$map__33925$jscomp$4_map__33925__$1$$=$APP.$cljs$core$__destructure_map$$($map__33925$jscomp$4_map__33925__$1$$);var $min$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33925$jscomp$4_map__33925__$1$$,$APP.$cljs$cst$338$min$$),
$max$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33925$jscomp$4_map__33925__$1$$,$APP.$cljs$cst$339$max$$),$keep$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33925$jscomp$4_map__33925__$1$$,$cljs$cst$642$keep$$),$type$jscomp$224$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33924__$1$$,$APP.$cljs$cst$139$type$$),$re_validator$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33924__$1$$,$cljs$cst$629$re_validator$$),
$re_explainer$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33924__$1$$,$cljs$cst$630$re_explainer$$),$re_parser$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33924__$1$$,$cljs$cst$631$re_parser$$),$re_unparser$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33924__$1$$,$cljs$cst$632$re_unparser$$),$re_transformer$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33924__$1$$,$cljs$cst$633$re_transformer$$),
$re_min_max$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33924__$1$$,$cljs$cst$634$re_min_max$$);return new $malli$core$t_malli$0core33926$$($p__33923$jscomp$4$$,$re_min_max$jscomp$9$$,$keep$jscomp$4$$,$re_explainer$jscomp$9$$,$min$jscomp$39$$,$re_parser$jscomp$9$$,$re_unparser$jscomp$9$$,$type$jscomp$224$$,$map__33924__$1$$,$map__33925$jscomp$4_map__33925__$1$$,$re_transformer$jscomp$9$$,$max$jscomp$39$$,$map__33924__$1$$,$re_validator$jscomp$9$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null))};$malli$core$into_schema_QMARK_$$=function($x$jscomp$791$$){return $x$jscomp$791$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$791$$.$malli$core$IntoSchema$$?!0:!1:!1};
$malli$core$into_schema$$=function($var_args$jscomp$453$$){switch(arguments.length){case 3:return $malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],arguments[1],arguments[2]);case 4:return $malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$04$$(arguments[0],arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$03$$=function($type$jscomp$225$$,$properties$jscomp$84$$,$children$jscomp$92$$){return $malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$04$$($type$jscomp$225$$,$properties$jscomp$84$$,$children$jscomp$92$$,null)};
$malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$04$$=function($type$jscomp$226$$,$options__$1$jscomp$51_properties$jscomp$85$$,$children$jscomp$93$$,$options$jscomp$225$$){var $properties_SINGLEQUOTE__properties__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($options__$1$jscomp$51_properties$jscomp$85$$)?$APP.$cljs$core$count$$($options__$1$jscomp$51_properties$jscomp$85$$)>0?$options__$1$jscomp$51_properties$jscomp$85$$:null:null,$r$jscomp$53$$=$APP.$cljs$core$truth_$$($properties_SINGLEQUOTE__properties__$1$jscomp$2$$)?
$properties_SINGLEQUOTE__properties__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$properties_SINGLEQUOTE__properties__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$352$registry$$):$properties_SINGLEQUOTE__properties__$1$jscomp$2$$($cljs$cst$352$registry$$):null;$options__$1$jscomp$51_properties$jscomp$85$$=$APP.$cljs$core$truth_$$($r$jscomp$53$$)?$malli$core$_update$$($options$jscomp$225$$,$cljs$cst$352$registry$$,function($p1__34011_SHARP_$$){return $malli$registry$composite_registry$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$r$jscomp$53$$,
$APP.$cljs$core$truth_$$($p1__34011_SHARP_$$)?$p1__34011_SHARP_$$:$malli$core$_registry$cljs$0core$0IFn$0_invoke$0arity$01$$($options$jscomp$225$$)]))}):$options$jscomp$225$$;$properties_SINGLEQUOTE__properties__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($r$jscomp$53$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($properties_SINGLEQUOTE__properties__$1$jscomp$2$$,$cljs$cst$352$registry$$,$malli$core$_property_registry$$($r$jscomp$53$$,$options__$1$jscomp$51_properties$jscomp$85$$,$APP.$cljs$core$identity$$)):
$properties_SINGLEQUOTE__properties__$1$jscomp$2$$;return $malli$core$_into_schema$$($malli$core$_lookup_BANG_$$($type$jscomp$226$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$type$jscomp$226$$,$properties_SINGLEQUOTE__properties__$1$jscomp$2$$,$children$jscomp$93$$],null),$malli$core$into_schema_QMARK_$$,!1,$options__$1$jscomp$51_properties$jscomp$85$$),$properties_SINGLEQUOTE__properties__$1$jscomp$2$$,$children$jscomp$93$$,$options__$1$jscomp$51_properties$jscomp$85$$)};
$malli$core$schema_QMARK_$$=function($x$jscomp$792$$){return $x$jscomp$792$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$792$$.$malli$core$Schema$$?!0:!1:!1};$APP.$malli$core$options$cljs$0core$0IFn$0_invoke$0arity$02$$=function($_QMARK_schema$jscomp$18$$){return $malli$core$_options$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$18$$,null))};
$malli$core$t_malli$0core34055$$=function($_QMARK_schema$jscomp$23$$,$f$jscomp$430$$,$options$jscomp$236$$,$meta34056$$){this.$_QMARK_schema$=$_QMARK_schema$jscomp$23$$;this.f=$f$jscomp$430$$;this.options=$options$jscomp$236$$;this.$meta34056$=$meta34056$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$core$walk$cljs$0core$0IFn$0_invoke$0arity$03$$=function($_QMARK_schema$jscomp$26$$,$f$jscomp$433$$,$options$jscomp$238$$){return $malli$core$_walk$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$26$$,$options$jscomp$238$$),new $malli$core$t_malli$0core34055$$($_QMARK_schema$jscomp$26$$,$f$jscomp$433$$,$options$jscomp$238$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),$APP.$cljs$core$PersistentVector$EMPTY$$,$options$jscomp$238$$)};
$malli$core$validator$cljs$0core$0IFn$0_invoke$0arity$02$$=function($_QMARK_schema$jscomp$28$$,$options$jscomp$239$$){return $malli$core$_cached$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$28$$,$options$jscomp$239$$),$cljs$cst$47$validator$$,$malli$core$_validator$$)};
$APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$=function($_QMARK_schema$jscomp$30_fexpr__34075$$,$value$jscomp$267$$){$_QMARK_schema$jscomp$30_fexpr__34075$$=$malli$core$validator$cljs$0core$0IFn$0_invoke$0arity$02$$($_QMARK_schema$jscomp$30_fexpr__34075$$,$app$common$schema$default_options$$);return $_QMARK_schema$jscomp$30_fexpr__34075$$.$cljs$core$IFn$_invoke$arity$1$?$_QMARK_schema$jscomp$30_fexpr__34075$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$267$$):$_QMARK_schema$jscomp$30_fexpr__34075$$($value$jscomp$267$$)};
$APP.$malli$core$explainer$cljs$0core$0IFn$0_invoke$0arity$02$$=function($_QMARK_schema$jscomp$32$$,$options$jscomp$241$$){var $schema_SINGLEQUOTE_$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$32$$,$options$jscomp$241$$),$explainer_SINGLEQUOTE_$$=$malli$core$_cached$$($schema_SINGLEQUOTE_$$,$cljs$cst$645$explainer$$,function($p1__34076_SHARP_$$){return $malli$core$_explainer$$($p1__34076_SHARP_$$,$APP.$cljs$core$PersistentVector$EMPTY$$)});return function(){function $malli$core$explainer__3$$($value$jscomp$269$$,
$in$$jscomp$34_temp__5825__auto__$jscomp$63$$,$acc$jscomp$63$$){return($in$$jscomp$34_temp__5825__auto__$jscomp$63$$=$APP.$cljs$core$seq$$($explainer_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$3$?$explainer_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$3$($value$jscomp$269$$,$in$$jscomp$34_temp__5825__auto__$jscomp$63$$,$acc$jscomp$63$$):$explainer_SINGLEQUOTE_$$($value$jscomp$269$$,$in$$jscomp$34_temp__5825__auto__$jscomp$63$$,$acc$jscomp$63$$)))?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$298$schema$$,
$schema_SINGLEQUOTE_$$,$APP.$cljs$cst$260$value$$,$value$jscomp$269$$,$APP.$cljs$cst$570$errors$$,$in$$jscomp$34_temp__5825__auto__$jscomp$63$$],null):null}function $malli$core$explainer__1$$($value$jscomp$268$$){return $malli$core$explainer$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$($value$jscomp$268$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$)}var $malli$core$explainer$jscomp$1$$=null;$malli$core$explainer$jscomp$1$$=function($value$jscomp$270$$,$in$$jscomp$35$$,
$acc$jscomp$64$$){switch(arguments.length){case 1:return $malli$core$explainer__1$$.call(this,$value$jscomp$270$$);case 3:return $malli$core$explainer__3$$.call(this,$value$jscomp$270$$,$in$$jscomp$35$$,$acc$jscomp$64$$)}throw Error("Invalid arity: "+arguments.length);};$malli$core$explainer$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$=$malli$core$explainer__1$$;$malli$core$explainer$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$=$malli$core$explainer__3$$;return $malli$core$explainer$jscomp$1$$}()};
$malli$core$explain$cljs$0core$0IFn$0_invoke$0arity$03$$=function($_QMARK_schema$jscomp$34$$,$value$jscomp$272$$){return $APP.$malli$core$explainer$cljs$0core$0IFn$0_invoke$0arity$02$$($_QMARK_schema$jscomp$34$$,$app$common$schema$default_options$$)($value$jscomp$272$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$)};
$malli$core$decoder$cljs$0core$0IFn$0_invoke$0arity$03$$=function($_QMARK_schema$jscomp$44_or__5025__auto__$jscomp$124$$){var $options$jscomp$247$$=$app$common$schema$default_options$$,$t$jscomp$38$$=$app$common$schema$json_transformer$$;$_QMARK_schema$jscomp$44_or__5025__auto__$jscomp$124$$=$malli$core$_transformer$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$44_or__5025__auto__$jscomp$124$$,$options$jscomp$247$$),$malli$core$_into_transformer$$($t$jscomp$38$$),
$cljs$cst$384$decode$$,$options$jscomp$247$$);return $APP.$cljs$core$truth_$$($_QMARK_schema$jscomp$44_or__5025__auto__$jscomp$124$$)?$_QMARK_schema$jscomp$44_or__5025__auto__$jscomp$124$$:$APP.$cljs$core$identity$$};
$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$=function($_QMARK_schema$jscomp$68_schema$jscomp$62$$,$options$jscomp$258$$){$_QMARK_schema$jscomp$68_schema$jscomp$62$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$68_schema$jscomp$62$$,$options$jscomp$258$$);return $malli$core$_ref_schema_QMARK_$$($_QMARK_schema$jscomp$68_schema$jscomp$62$$)?$malli$core$_deref$$($_QMARK_schema$jscomp$68_schema$jscomp$62$$):$_QMARK_schema$jscomp$68_schema$jscomp$62$$};
$malli$core$deref_all$cljs$0core$0IFn$0_invoke$0arity$01$$=function($G__35918$jscomp$inline_3580_JSCompiler_inline_result$jscomp$433__QMARK_schema$jscomp$69_options$jscomp$inline_3577$$){a:{var $G__34192$jscomp$inline_3579__QMARK_schema$jscomp$inline_3576$$=$G__35918$jscomp$inline_3580_JSCompiler_inline_result$jscomp$433__QMARK_schema$jscomp$69_options$jscomp$inline_3577$$;for($G__35918$jscomp$inline_3580_JSCompiler_inline_result$jscomp$433__QMARK_schema$jscomp$69_options$jscomp$inline_3577$$=null;;){var $schema$jscomp$inline_3578$$=
$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$($G__34192$jscomp$inline_3579__QMARK_schema$jscomp$inline_3576$$,$G__35918$jscomp$inline_3580_JSCompiler_inline_result$jscomp$433__QMARK_schema$jscomp$69_options$jscomp$inline_3577$$);$G__34192$jscomp$inline_3579__QMARK_schema$jscomp$inline_3576$$=$schema$jscomp$inline_3578$$;if(!$malli$core$_ref_schema_QMARK_$$($schema$jscomp$inline_3578$$)){$G__35918$jscomp$inline_3580_JSCompiler_inline_result$jscomp$433__QMARK_schema$jscomp$69_options$jscomp$inline_3577$$=
$G__34192$jscomp$inline_3579__QMARK_schema$jscomp$inline_3576$$;break a}}$G__35918$jscomp$inline_3580_JSCompiler_inline_result$jscomp$433__QMARK_schema$jscomp$69_options$jscomp$inline_3577$$=void 0}return $G__35918$jscomp$inline_3580_JSCompiler_inline_result$jscomp$433__QMARK_schema$jscomp$69_options$jscomp$inline_3577$$};
$malli$core$ast$$=function($var_args$jscomp$486$$){switch(arguments.length){case 1:return $malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$(arguments[0]);case 2:return $malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$=function($_QMARK_schema$jscomp$73$$){return $malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$02$$($_QMARK_schema$jscomp$73$$,null)};
$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$02$$=function($_QMARK_schema$jscomp$74$$,$options$jscomp$262$$){var $s$jscomp$335$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$74$$,$options$jscomp$262$$);if($s$jscomp$335$$!=null&&$APP.$cljs$core$PROTOCOL_SENTINEL$$===$s$jscomp$335$$.$malli$core$AST$$)return $malli$core$_to_ast$$($s$jscomp$335$$,$options$jscomp$262$$);var $c$jscomp$203$$=$malli$core$_children$$($s$jscomp$335$$);return $malli$core$_ast$$(function(){var $G__34212$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$335$$)],null);return $APP.$cljs$core$truth_$$($c$jscomp$203$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__34212$$,$APP.$cljs$cst$342$children$$,$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__34209_SHARP_$$){return $malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__34209_SHARP_$$,$options$jscomp$262$$)},$c$jscomp$203$$)):
$G__34212$$}(),$malli$core$_properties$$($s$jscomp$335$$),$malli$core$_options$$($s$jscomp$335$$))};$_fail_BANG__35958$$=function($p1__34213_SHARP_$$){return $malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$660$malli_DOT_core_SLASH_sci_not_available$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$273$code$$,$p1__34213_SHARP_$$],null))};
$malli$core$eval$$=function($var_args$jscomp$487$$){switch(arguments.length){case 1:return $malli$core$eval$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],null);case 2:return $malli$core$eval$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$core$eval$cljs$0core$0IFn$0_invoke$0arity$02$$=function($_QMARK_code$jscomp$1$$,$fexpr__34219_fexpr__34220$jscomp$inline_11434_options$jscomp$263_or__5025__auto__$jscomp$inline_11433$$){if($APP.$cljs$core$vector_QMARK_$$($_QMARK_code$jscomp$1$$))return $_QMARK_code$jscomp$1$$;if($_QMARK_code$jscomp$1$$ instanceof $APP.$cljs$core$Symbol$$||typeof $_QMARK_code$jscomp$1$$==="string"||$APP.$cljs$core$sequential_QMARK_$$($_QMARK_code$jscomp$1$$)){if($APP.$cljs$core$truth_$$($cljs$cst$661$malli_DOT_core_SLASH_disable_sci$$.$cljs$core$IFn$_invoke$arity$1$($fexpr__34219_fexpr__34220$jscomp$inline_11434_options$jscomp$263_or__5025__auto__$jscomp$inline_11433$$)))return $_fail_BANG__35958$$($_QMARK_code$jscomp$1$$);
$fexpr__34219_fexpr__34220$jscomp$inline_11434_options$jscomp$263_or__5025__auto__$jscomp$inline_11433$$=$cljs$cst$662$malli_DOT_core_SLASH_sci_options$$.$cljs$core$IFn$_invoke$arity$1$($fexpr__34219_fexpr__34220$jscomp$inline_11434_options$jscomp$263_or__5025__auto__$jscomp$inline_11433$$);$fexpr__34219_fexpr__34220$jscomp$inline_11434_options$jscomp$263_or__5025__auto__$jscomp$inline_11433$$=$_evaluator_35960$$($APP.$cljs$core$truth_$$($fexpr__34219_fexpr__34220$jscomp$inline_11434_options$jscomp$263_or__5025__auto__$jscomp$inline_11433$$)?
$fexpr__34219_fexpr__34220$jscomp$inline_11434_options$jscomp$263_or__5025__auto__$jscomp$inline_11433$$:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$654$preset$$,$cljs$cst$655$termination_safe$$,$cljs$cst$656$aliases$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$8$str$$,$cljs$cst$657$clojure_DOT_string$$,$cljs$cst$316$m$$,$cljs$cst$658$malli_DOT_core$$],null),$cljs$cst$659$namespaces$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$658$malli_DOT_core$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$cljs$cst$400$properties$$,$APP.$malli$core$properties$$,$cljs$cst$407$type$$,$APP.$malli$core$type$$,$cljs$cst$361$children$$,$malli$core$children$$,$cljs$cst$363$entries$$,$malli$core$entries$$],null)],null)],null),$_fail_BANG__35958$$);$fexpr__34219_fexpr__34220$jscomp$inline_11434_options$jscomp$263_or__5025__auto__$jscomp$inline_11433$$=$fexpr__34219_fexpr__34220$jscomp$inline_11434_options$jscomp$263_or__5025__auto__$jscomp$inline_11433$$.$cljs$core$IFn$_invoke$arity$0$?$fexpr__34219_fexpr__34220$jscomp$inline_11434_options$jscomp$263_or__5025__auto__$jscomp$inline_11433$$.$cljs$core$IFn$_invoke$arity$0$():
$fexpr__34219_fexpr__34220$jscomp$inline_11434_options$jscomp$263_or__5025__auto__$jscomp$inline_11433$$();return $fexpr__34219_fexpr__34220$jscomp$inline_11434_options$jscomp$263_or__5025__auto__$jscomp$inline_11433$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__34219_fexpr__34220$jscomp$inline_11434_options$jscomp$263_or__5025__auto__$jscomp$inline_11433$$.$cljs$core$IFn$_invoke$arity$1$($_QMARK_code$jscomp$1$$):$fexpr__34219_fexpr__34220$jscomp$inline_11434_options$jscomp$263_or__5025__auto__$jscomp$inline_11433$$($_QMARK_code$jscomp$1$$)}return $_QMARK_code$jscomp$1$$};
$malli$core$_instrument$$=function($var_args$jscomp$491$$){switch(arguments.length){case 1:return $malli$core$_instrument$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],null,null);case 2:return $malli$core$_instrument$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);case 3:return $malli$core$_instrument$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$malli$core$_instrument$cljs$0core$0IFn$0_invoke$0arity$02$$=function($props$jscomp$26$$,$f$jscomp$436$$){return $malli$core$_instrument$cljs$0core$0IFn$0_invoke$0arity$03$$($props$jscomp$26$$,$f$jscomp$436$$,null)};
$malli$core$_instrument$cljs$0core$0IFn$0_invoke$0arity$03$$=function($props$jscomp$27_s$jscomp$337$$,$f$jscomp$437_or__5025__auto__$jscomp$130$$,$options$jscomp$265$$){var $props__$1$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($props$jscomp$27_s$jscomp$337$$,$APP.$cljs$cst$571$scope$$,function($p1__34411_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__34411_SHARP_$$)?$p1__34411_SHARP_$$:new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$564$output$$,null,$cljs$cst$563$input$$,null,$cljs$cst$565$guard$$,null],null),null)}),$APP.$cljs$cst$572$report$$,function($p1__34412_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__34412_SHARP_$$)?$p1__34412_SHARP_$$:$malli$core$_fail_BANG_$$});$props$jscomp$27_s$jscomp$337$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$298$schema$$.$cljs$core$IFn$_invoke$arity$1$($props__$1$$),$options$jscomp$265$$);$f$jscomp$437_or__5025__auto__$jscomp$130$$=
$malli$core$_instrument_f$$($props$jscomp$27_s$jscomp$337$$,$props__$1$$,$f$jscomp$437_or__5025__auto__$jscomp$130$$,$options$jscomp$265$$);return $APP.$cljs$core$truth_$$($f$jscomp$437_or__5025__auto__$jscomp$130$$)?$f$jscomp$437_or__5025__auto__$jscomp$130$$:$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$728$malli_DOT_core_SLASH_instrument_requires_function_schema$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$298$schema$$,$props$jscomp$27_s$jscomp$337$$],
null))};$malli$util$_required_map_entry_QMARK_$$=function($_QMARK_p$jscomp$2_p__34468$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_QMARK_p$jscomp$2_p__34468$$,0,null);$_QMARK_p$jscomp$2_p__34468$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_QMARK_p$jscomp$2_p__34468$$,1,null);return!($APP.$cljs$core$map_QMARK_$$($_QMARK_p$jscomp$2_p__34468$$)&&$APP.$cljs$cst$450$optional$$.$cljs$core$IFn$_invoke$arity$1$($_QMARK_p$jscomp$2_p__34468$$)===!0)};
$malli$util$t_malli$0util34488$$=function($_QMARK_schema$jscomp$79$$,$f$jscomp$438$$,$options$jscomp$269$$,$result$jscomp$96$$,$meta34489$$){this.$_QMARK_schema$=$_QMARK_schema$jscomp$79$$;this.f=$f$jscomp$438$$;this.options=$options$jscomp$269$$;this.result=$result$jscomp$96$$;this.$meta34489$=$meta34489$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$APP.$malli$util$find_first$cljs$0core$0IFn$0_invoke$0arity$02$$=function($_QMARK_schema$jscomp$81$$,$f$jscomp$440$$){var $result$jscomp$inline_3594$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$malli$core$_walk$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$81$$,null),new $malli$util$t_malli$0util34488$$($_QMARK_schema$jscomp$81$$,$f$jscomp$440$$,null,$result$jscomp$inline_3594$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),$APP.$cljs$core$PersistentVector$EMPTY$$,
null);return $APP.$cljs$core$_deref$$($result$jscomp$inline_3594$$)};
$malli$util$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($_QMARK_schema$jscomp$83_schema$jscomp$67$$,$args$jscomp$136$$){$_QMARK_schema$jscomp$83_schema$jscomp$67$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$1$($_QMARK_schema$jscomp$83_schema$jscomp$67$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$4$($malli$core$_update_properties$$,$_QMARK_schema$jscomp$83_schema$jscomp$67$$,$APP.$cljs$core$assoc$$,$args$jscomp$136$$)};
$malli$util$transform_entries$cljs$0core$0IFn$0_invoke$0arity$03$$=function($_QMARK_schema$jscomp$96$$,$f$jscomp$447$$,$options$jscomp$279$$){var $schema$jscomp$74$$=$malli$core$deref_all$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$96$$,$options$jscomp$279$$));return $malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$04$$($malli$core$_parent$$($schema$jscomp$74$$),$malli$core$_properties$$($schema$jscomp$74$$),function(){var $G__34735$$=
$malli$core$_children$$($schema$jscomp$74$$);return $f$jscomp$447$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$447$$.$cljs$core$IFn$_invoke$arity$1$($G__34735$$):$f$jscomp$447$$($G__34735$$)}(),function(){var $or__5025__auto__$jscomp$138$$=$APP.$malli$core$options$cljs$0core$0IFn$0_invoke$0arity$02$$($schema$jscomp$74$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$138$$)?$or__5025__auto__$jscomp$138$$:$options$jscomp$279$$}())};
$malli$util$optional_keys$cljs$0core$0IFn$0_invoke$0arity$03$$=function($_QMARK_schema$jscomp$99$$){function $mapper$$($p__34757$$){var $k$jscomp$404$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34757$$,0,null);return $APP.$cljs$core$truth_$$($accept$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$accept$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$404$$):$accept$jscomp$1$$($k$jscomp$404$$))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p__34757$$,1,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$450$optional$$,!0):$p__34757$$}var $options$jscomp$281$$=$app$common$schema$default_options$$,$accept$jscomp$1$$=$APP.$cljs$core$truth_$$(null)?$APP.$cljs$core$set$$(null):$APP.$cljs$core$constantly$$(!0);return $malli$util$transform_entries$cljs$0core$0IFn$0_invoke$0arity$03$$($_QMARK_schema$jscomp$99$$,function($p1__34737_SHARP_$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($mapper$$,$p1__34737_SHARP_$$)},$options$jscomp$281$$)};
$malli$util$required_keys$cljs$0core$0IFn$0_invoke$0arity$03$$=function($_QMARK_schema$jscomp$102$$){function $mapper$jscomp$1$$($p__34784$$){var $k$jscomp$405$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34784$$,0,null);return $APP.$cljs$core$truth_$$($accept$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$accept$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$405$$):$accept$jscomp$2$$($k$jscomp$405$$))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p__34784$$,1,$required$jscomp$1$$):
$p__34784$$}function $required$jscomp$1$$($p$jscomp$86_p_SINGLEQUOTE_$$){$p$jscomp$86_p_SINGLEQUOTE_$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$86_p_SINGLEQUOTE_$$,$APP.$cljs$cst$450$optional$$);return $APP.$cljs$core$seq$$($p$jscomp$86_p_SINGLEQUOTE_$$)?$p$jscomp$86_p_SINGLEQUOTE_$$:null}var $options$jscomp$283$$=$app$common$schema$default_options$$,$accept$jscomp$2$$=$APP.$cljs$core$truth_$$(null)?$APP.$cljs$core$set$$(null):$APP.$cljs$core$constantly$$(!0);return $malli$util$transform_entries$cljs$0core$0IFn$0_invoke$0arity$03$$($_QMARK_schema$jscomp$102$$,
function($p1__34767_SHARP_$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($mapper$jscomp$1$$,$p1__34767_SHARP_$$)},$options$jscomp$283$$)};
$malli$util$keys$$=function($_QMARK_schema$jscomp$111_temp__5825__auto__$jscomp$66$$){$_QMARK_schema$jscomp$111_temp__5825__auto__$jscomp$66$$=$malli$core$entries$$.$cljs$core$IFn$_invoke$arity$1$($_QMARK_schema$jscomp$111_temp__5825__auto__$jscomp$66$$);return $APP.$cljs$core$truth_$$($_QMARK_schema$jscomp$111_temp__5825__auto__$jscomp$66$$)?function $malli$util$keys_$_iter__34827$$($s__34828$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__34828__$2_temp__5825__auto____$1$jscomp$1$$=
$APP.$cljs$core$seq$$($s__34828$$);if($s__34828__$2_temp__5825__auto____$1$jscomp$1$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__34828__$2_temp__5825__auto____$1$jscomp$1$$)){var $JSCompiler_inline_result$jscomp$437_c__5501__auto__$jscomp$3_k$jscomp$412$$=$APP.$cljs$core$_chunked_first$$($s__34828__$2_temp__5825__auto____$1$jscomp$1$$),$size__5502__auto__$jscomp$3$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$437_c__5501__auto__$jscomp$3_k$jscomp$412$$),$b__34830_vec__34837$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$3$$);
a:{for(var $i__34829$jscomp$inline_3598$$=0;;)if($i__34829$jscomp$inline_3598$$<$size__5502__auto__$jscomp$3$$){var $vec__34834$jscomp$inline_3599$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$437_c__5501__auto__$jscomp$3_k$jscomp$412$$,$i__34829$jscomp$inline_3598$$),$k$jscomp$inline_3600$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__34834$jscomp$inline_3599$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__34834$jscomp$inline_3599$$,1,null);
$b__34830_vec__34837$$.add($k$jscomp$inline_3600$$);$i__34829$jscomp$inline_3598$$+=1}else{$JSCompiler_inline_result$jscomp$437_c__5501__auto__$jscomp$3_k$jscomp$412$$=!0;break a}$JSCompiler_inline_result$jscomp$437_c__5501__auto__$jscomp$3_k$jscomp$412$$=void 0}return $JSCompiler_inline_result$jscomp$437_c__5501__auto__$jscomp$3_k$jscomp$412$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__34830_vec__34837$$),$malli$util$keys_$_iter__34827$$($APP.$cljs$core$_chunked_rest$$($s__34828__$2_temp__5825__auto____$1$jscomp$1$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__34830_vec__34837$$),null)}$b__34830_vec__34837$$=$APP.$cljs$core$first$$($s__34828__$2_temp__5825__auto____$1$jscomp$1$$);$JSCompiler_inline_result$jscomp$437_c__5501__auto__$jscomp$3_k$jscomp$412$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b__34830_vec__34837$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b__34830_vec__34837$$,1,null);return $APP.$cljs$core$cons$$($JSCompiler_inline_result$jscomp$437_c__5501__auto__$jscomp$3_k$jscomp$412$$,
$malli$util$keys_$_iter__34827$$($APP.$cljs$core$rest$$($s__34828__$2_temp__5825__auto____$1$jscomp$1$$)))}return null}},null,null)}($_QMARK_schema$jscomp$111_temp__5825__auto__$jscomp$66$$):null};
$APP.$malli$util$get$cljs$0core$0IFn$0_invoke$0arity$04$$=function($_QMARK_schema$jscomp$114_schema$jscomp$76$$,$k$jscomp$416$$,$default$$jscomp$36$$){$_QMARK_schema$jscomp$114_schema$jscomp$76$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($_QMARK_schema$jscomp$114_schema$jscomp$76$$)?$_QMARK_schema$jscomp$114_schema$jscomp$76$$:$APP.$cljs$cst$202$map$$,null);return $APP.$cljs$core$truth_$$($_QMARK_schema$jscomp$114_schema$jscomp$76$$)?$malli$core$_get$$($_QMARK_schema$jscomp$114_schema$jscomp$76$$,
$k$jscomp$416$$,$default$$jscomp$36$$):null};$APP.$malli$util$assoc$cljs$0core$0IFn$0_invoke$0arity$04$$=function($_QMARK_schema$jscomp$116$$,$key$jscomp$246$$,$value$jscomp$293$$,$options$jscomp$289$$){return $malli$core$_set$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$116$$,$options$jscomp$289$$),$key$jscomp$246$$,$value$jscomp$293$$)};
$malli$util$update_in$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($schema$jscomp$80$$,$ks$jscomp$35$$){return function $malli$util$up$$($s$jscomp$346$$,$first__34883_p__34880$$,$JSCompiler_temp$jscomp$438_f__$1$jscomp$20$$,$args__$1$jscomp$4$$){var $seq__34882_seq__34882__$1$$=$APP.$cljs$core$seq$$($first__34883_p__34880$$);$first__34883_p__34880$$=$APP.$cljs$core$first$$($seq__34882_seq__34882__$1$$);if($seq__34882_seq__34882__$1$$=$APP.$cljs$core$next$$($seq__34882_seq__34882__$1$$)){var $JSCompiler_inline_result$jscomp$439_default$$jscomp$inline_3604$$=
$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$202$map$$,$APP.$malli$core$options$cljs$0core$0IFn$0_invoke$0arity$02$$($schema$jscomp$80$$));$JSCompiler_inline_result$jscomp$439_default$$jscomp$inline_3604$$=$APP.$malli$util$get$cljs$0core$0IFn$0_invoke$0arity$04$$($s$jscomp$346$$,$first__34883_p__34880$$,$JSCompiler_inline_result$jscomp$439_default$$jscomp$inline_3604$$);$JSCompiler_temp$jscomp$438_f__$1$jscomp$20$$=$malli$util$up$$($JSCompiler_inline_result$jscomp$439_default$$jscomp$inline_3604$$,
$seq__34882_seq__34882__$1$$,$JSCompiler_temp$jscomp$438_f__$1$jscomp$20$$,$args__$1$jscomp$4$$)}else $JSCompiler_temp$jscomp$438_f__$1$jscomp$20$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$438_f__$1$jscomp$20$$,$APP.$malli$util$get$cljs$0core$0IFn$0_invoke$0arity$04$$($s$jscomp$346$$,$first__34883_p__34880$$,null),$args__$1$jscomp$4$$);return $APP.$malli$util$assoc$cljs$0core$0IFn$0_invoke$0arity$04$$($s$jscomp$346$$,$first__34883_p__34880$$,$JSCompiler_temp$jscomp$438_f__$1$jscomp$20$$,
null)}($schema$jscomp$80$$,$ks$jscomp$35$$,$malli$util$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$]))};
$malli$util$_reducing$$=function($f$jscomp$450$$){return function($_$jscomp$729_vec__34890$$,$children$jscomp$121_seq__34891$$,$options$jscomp$292$$){$APP.$cljs$core$empty_QMARK_$$($children$jscomp$121_seq__34891$$)&&$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$734$malli_DOT_util_SLASH_reducing_children_must_be_non_empty$$);$_$jscomp$729_vec__34890$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__34887_SHARP_$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($p1__34887_SHARP_$$,
$options$jscomp$292$$)},$children$jscomp$121_seq__34891$$);$children$jscomp$121_seq__34891$$=$APP.$cljs$core$seq$$($_$jscomp$729_vec__34890$$);var $first__34892$$=$APP.$cljs$core$first$$($children$jscomp$121_seq__34891$$),$seq__34891__$1$$=$APP.$cljs$core$next$$($children$jscomp$121_seq__34891$$);return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$_$jscomp$729_vec__34890$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($malli$core$form$$,
$_$jscomp$729_vec__34890$$),new $APP.$cljs$core$Delay$$(function(){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__34888_SHARP_$$,$p2__34889_SHARP_$$){return $f$jscomp$450$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$450$$.$cljs$core$IFn$_invoke$arity$3$($p1__34888_SHARP_$$,$p2__34889_SHARP_$$,$options$jscomp$292$$):$f$jscomp$450$$($p1__34888_SHARP_$$,$p2__34889_SHARP_$$,$options$jscomp$292$$)},$first__34892$$,$seq__34891__$1$$)})],null)}};
$malli$util$_merge$$=function(){return $malli$core$_proxy_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$735$merge$$,$APP.$cljs$cst$516$fn$$,$malli$util$_reducing$$($malli$util$merge$$),$APP.$cljs$cst$338$min$$,1],null))};
$malli$util$_union$$=function(){return $malli$core$_proxy_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$736$union$$,$APP.$cljs$cst$516$fn$$,$malli$util$_reducing$$($malli$util$union$$),$APP.$cljs$cst$338$min$$,1],null))};$module$contents$goog$async$throwException_throwException$$=function($exception$jscomp$2$$){$APP.$goog$global$$.setTimeout(()=>{throw $exception$jscomp$2$$;},0)};
$goog$crypt$textToByteArray$$=function($str$jscomp$72$$){for(var $out$jscomp$14$$=[],$p$jscomp$88$$=0,$i$jscomp$331$$=0;$i$jscomp$331$$<$str$jscomp$72$$.length;$i$jscomp$331$$++){var $c$jscomp$205$$=$str$jscomp$72$$.charCodeAt($i$jscomp$331$$);$c$jscomp$205$$<128?$out$jscomp$14$$[$p$jscomp$88$$++]=$c$jscomp$205$$:($c$jscomp$205$$<2048?$out$jscomp$14$$[$p$jscomp$88$$++]=$c$jscomp$205$$>>6|192:(($c$jscomp$205$$&64512)==55296&&$i$jscomp$331$$+1<$str$jscomp$72$$.length&&($str$jscomp$72$$.charCodeAt($i$jscomp$331$$+
1)&64512)==56320?($c$jscomp$205$$=65536+(($c$jscomp$205$$&1023)<<10)+($str$jscomp$72$$.charCodeAt(++$i$jscomp$331$$)&1023),$out$jscomp$14$$[$p$jscomp$88$$++]=$c$jscomp$205$$>>18|240,$out$jscomp$14$$[$p$jscomp$88$$++]=$c$jscomp$205$$>>12&63|128):$out$jscomp$14$$[$p$jscomp$88$$++]=$c$jscomp$205$$>>12|224,$out$jscomp$14$$[$p$jscomp$88$$++]=$c$jscomp$205$$>>6&63|128),$out$jscomp$14$$[$p$jscomp$88$$++]=$c$jscomp$205$$&63|128)}return $out$jscomp$14$$};
$lambdaisland$uri$platform$hex__GT_byte$$=function($hex$$){return parseInt($hex$$,16)};
$lambdaisland$uri$normalize$char_seq$cljs$0core$0IFn$0_invoke$0arity$02$$=function($str$jscomp$75$$){for(var $cur_char_offset__$1$$=0,$G__31141_res$jscomp$19$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){if($cur_char_offset__$1$$>=$str$jscomp$75$$.length)return $G__31141_res$jscomp$19$$;var $G__31140_char_code$jscomp$inline_3610_next_offset$$=$str$jscomp$75$$.charCodeAt($cur_char_offset__$1$$);$G__31140_char_code$jscomp$inline_3610_next_offset$$=$cur_char_offset__$1$$+(55296<=$G__31140_char_code$jscomp$inline_3610_next_offset$$&&
$G__31140_char_code$jscomp$inline_3610_next_offset$$<=56319?2:1);$cur_char_offset__$1$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($str$jscomp$75$$,$cur_char_offset__$1$$,$G__31140_char_code$jscomp$inline_3610_next_offset$$);$G__31141_res$jscomp$19$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__31141_res$jscomp$19$$,$cur_char_offset__$1$$);$cur_char_offset__$1$$=$G__31140_char_code$jscomp$inline_3610_next_offset$$}};
$lambdaisland$uri$normalize$percent_encode$cljs$0core$0IFn$0_invoke$0arity$01$$=function($component$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($low_nibble$jscomp$inline_3614_p1__31103_SHARP_$$){var $byte$__$1$jscomp$inline_3613_high_nibble$jscomp$inline_3615$$=255&$low_nibble$jscomp$inline_3614_p1__31103_SHARP_$$;$low_nibble$jscomp$inline_3614_p1__31103_SHARP_$$=15&$byte$__$1$jscomp$inline_3613_high_nibble$jscomp$inline_3615$$;
$byte$__$1$jscomp$inline_3613_high_nibble$jscomp$inline_3615$$>>=4;return["%",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($lambdaisland$uri$platform$hex_digit$$.$cljs$core$IFn$_invoke$arity$1$?$lambdaisland$uri$platform$hex_digit$$.$cljs$core$IFn$_invoke$arity$1$($byte$__$1$jscomp$inline_3613_high_nibble$jscomp$inline_3615$$):$lambdaisland$uri$platform$hex_digit$$($byte$__$1$jscomp$inline_3613_high_nibble$jscomp$inline_3615$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($lambdaisland$uri$platform$hex_digit$$.$cljs$core$IFn$_invoke$arity$1$?
$lambdaisland$uri$platform$hex_digit$$.$cljs$core$IFn$_invoke$arity$1$($low_nibble$jscomp$inline_3614_p1__31103_SHARP_$$):$lambdaisland$uri$platform$hex_digit$$($low_nibble$jscomp$inline_3614_p1__31103_SHARP_$$))].join("")].join("")},$goog$crypt$textToByteArray$$($component$$)))};
$lambdaisland$uri$normalize$percent_encode$cljs$0core$0IFn$0_invoke$0arity$02$$=function($component$jscomp$1$$,$type$jscomp$227$$){var $char_class$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($lambdaisland$uri$normalize$character_classes$$,$type$jscomp$227$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__31104_SHARP_$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$re_find$$($char_class$$,
$p1__31104_SHARP_$$))?$lambdaisland$uri$normalize$percent_encode$cljs$0core$0IFn$0_invoke$0arity$01$$($p1__31104_SHARP_$$):$p1__31104_SHARP_$$},$lambdaisland$uri$normalize$char_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($component$jscomp$1$$)))};
$lambdaisland$uri$normalize$percent_decode$$=function($s$jscomp$349$$){return $APP.$cljs$core$truth_$$($s$jscomp$349$$)?$APP.$clojure$string$replace$$($s$jscomp$349$$,/(%[0-9A-Fa-f]{2})+/,function($arr$jscomp$inline_3617_bytes$jscomp$inline_14137_p__31112$$){var $out$jscomp$inline_14138_x$jscomp$798$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($arr$jscomp$inline_3617_bytes$jscomp$inline_14137_p__31112$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($arr$jscomp$inline_3617_bytes$jscomp$inline_14137_p__31112$$,
1,null);$arr$jscomp$inline_3617_bytes$jscomp$inline_14137_p__31112$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($lambdaisland$uri$platform$hex__GT_byte$$,$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$(1,$clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$02$$($out$jscomp$inline_14138_x$jscomp$798$$,/%/)));$arr$jscomp$inline_3617_bytes$jscomp$inline_14137_p__31112$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$arr$jscomp$inline_3617_bytes$jscomp$inline_14137_p__31112$$);
$out$jscomp$inline_14138_x$jscomp$798$$=[];for(var $pos$jscomp$inline_14139$$=0,$c$jscomp$inline_14140$$=0;$pos$jscomp$inline_14139$$<$arr$jscomp$inline_3617_bytes$jscomp$inline_14137_p__31112$$.length;){var $c1$jscomp$inline_14141_u$jscomp$inline_14145$$=$arr$jscomp$inline_3617_bytes$jscomp$inline_14137_p__31112$$[$pos$jscomp$inline_14139$$++];if($c1$jscomp$inline_14141_u$jscomp$inline_14145$$<128)$out$jscomp$inline_14138_x$jscomp$798$$[$c$jscomp$inline_14140$$++]=String.fromCharCode($c1$jscomp$inline_14141_u$jscomp$inline_14145$$);
else if($c1$jscomp$inline_14141_u$jscomp$inline_14145$$>191&&$c1$jscomp$inline_14141_u$jscomp$inline_14145$$<224){var $c2$jscomp$inline_14142$$=$arr$jscomp$inline_3617_bytes$jscomp$inline_14137_p__31112$$[$pos$jscomp$inline_14139$$++];$out$jscomp$inline_14138_x$jscomp$798$$[$c$jscomp$inline_14140$$++]=String.fromCharCode(($c1$jscomp$inline_14141_u$jscomp$inline_14145$$&31)<<6|$c2$jscomp$inline_14142$$&63)}else if($c1$jscomp$inline_14141_u$jscomp$inline_14145$$>239&&$c1$jscomp$inline_14141_u$jscomp$inline_14145$$<
365){$c2$jscomp$inline_14142$$=$arr$jscomp$inline_3617_bytes$jscomp$inline_14137_p__31112$$[$pos$jscomp$inline_14139$$++];var $c3$jscomp$inline_14143$$=$arr$jscomp$inline_3617_bytes$jscomp$inline_14137_p__31112$$[$pos$jscomp$inline_14139$$++],$c4$jscomp$inline_14144$$=$arr$jscomp$inline_3617_bytes$jscomp$inline_14137_p__31112$$[$pos$jscomp$inline_14139$$++];$c1$jscomp$inline_14141_u$jscomp$inline_14145$$=(($c1$jscomp$inline_14141_u$jscomp$inline_14145$$&7)<<18|($c2$jscomp$inline_14142$$&63)<<12|($c3$jscomp$inline_14143$$&
63)<<6|$c4$jscomp$inline_14144$$&63)-65536;$out$jscomp$inline_14138_x$jscomp$798$$[$c$jscomp$inline_14140$$++]=String.fromCharCode(55296+($c1$jscomp$inline_14141_u$jscomp$inline_14145$$>>10));$out$jscomp$inline_14138_x$jscomp$798$$[$c$jscomp$inline_14140$$++]=String.fromCharCode(56320+($c1$jscomp$inline_14141_u$jscomp$inline_14145$$&1023))}else $c2$jscomp$inline_14142$$=$arr$jscomp$inline_3617_bytes$jscomp$inline_14137_p__31112$$[$pos$jscomp$inline_14139$$++],$c3$jscomp$inline_14143$$=$arr$jscomp$inline_3617_bytes$jscomp$inline_14137_p__31112$$[$pos$jscomp$inline_14139$$++],
$out$jscomp$inline_14138_x$jscomp$798$$[$c$jscomp$inline_14140$$++]=String.fromCharCode(($c1$jscomp$inline_14141_u$jscomp$inline_14145$$&15)<<12|($c2$jscomp$inline_14142$$&63)<<6|$c3$jscomp$inline_14143$$&63)}return $out$jscomp$inline_14138_x$jscomp$798$$.join("")}):null};
$lambdaisland$uri$URI$$=function($scheme$jscomp$7$$,$user$jscomp$2$$,$password$jscomp$2$$,$host$jscomp$3$$,$port$jscomp$3$$,$path$jscomp$104$$,$query$jscomp$15$$,$fragment$jscomp$5$$,$__meta$jscomp$4$$,$__extmap$jscomp$4$$,$__hash$jscomp$55$$){this.scheme=$scheme$jscomp$7$$;this.$user$=$user$jscomp$2$$;this.password=$password$jscomp$2$$;this.host=$host$jscomp$3$$;this.port=$port$jscomp$3$$;this.path=$path$jscomp$104$$;this.query=$query$jscomp$15$$;this.$fragment$=$fragment$jscomp$5$$;this.$__meta$=
$__meta$jscomp$4$$;this.$__extmap$=$__extmap$jscomp$4$$;this.$__hash$=$__hash$jscomp$55$$;this.$cljs$lang$protocol_mask$partition0$$=2230716171;this.$cljs$lang$protocol_mask$partition1$$=139264};
$lambdaisland$uri$parse$$=function($scheme$jscomp$10_scheme$jscomp$inline_3638_uri$jscomp$51$$){var $authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$=$APP.$cljs$core$re_matches$$($lambdaisland$uri$uri_regex$$,$scheme$jscomp$10_scheme$jscomp$inline_3638_uri$jscomp$51$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$,1,null);$scheme$jscomp$10_scheme$jscomp$inline_3638_uri$jscomp$51$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$,2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$,
3,null);var $authority$jscomp$inline_3639_path$jscomp$107$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$,4,null),$path$jscomp$inline_3640_query$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$,5,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$,
6,null);var $fragment$jscomp$8_query$jscomp$inline_3641_vec__31238$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$,7,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$,8,null);$authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$,9,null);$fragment$jscomp$8_query$jscomp$inline_3641_vec__31238$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$scheme$jscomp$10_scheme$jscomp$inline_3638_uri$jscomp$51$$,$authority$jscomp$inline_3639_path$jscomp$107$$,$APP.$cljs$core$seq$$($path$jscomp$inline_3640_query$jscomp$18$$)?
$path$jscomp$inline_3640_query$jscomp$18$$:null,$fragment$jscomp$8_query$jscomp$inline_3641_vec__31238$$,$authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$],null);$scheme$jscomp$10_scheme$jscomp$inline_3638_uri$jscomp$51$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fragment$jscomp$8_query$jscomp$inline_3641_vec__31238$$,0,null);$authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fragment$jscomp$8_query$jscomp$inline_3641_vec__31238$$,1,null);$authority$jscomp$inline_3639_path$jscomp$107$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fragment$jscomp$8_query$jscomp$inline_3641_vec__31238$$,2,null);$path$jscomp$inline_3640_query$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fragment$jscomp$8_query$jscomp$inline_3641_vec__31238$$,3,null);$fragment$jscomp$8_query$jscomp$inline_3641_vec__31238$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fragment$jscomp$8_query$jscomp$inline_3641_vec__31238$$,4,null);if($APP.$cljs$core$truth_$$($authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$)){var $port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$=$APP.$cljs$core$re_matches$$($lambdaisland$uri$authority_regex$$,$authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$);
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$,1,null);$authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$,
2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$,3,null);var $password$jscomp$5_password$jscomp$inline_3647$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$,4,null),$host$jscomp$6_host$jscomp$inline_3648$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$,
5,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$,6,null);$port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$,7,null);$port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$=new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$,$password$jscomp$5_password$jscomp$inline_3647$$,$host$jscomp$6_host$jscomp$inline_3648$$,$port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$],null);$authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$,
0,null);$password$jscomp$5_password$jscomp$inline_3647$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$,1,null);$host$jscomp$6_host$jscomp$inline_3648$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$,2,null);$port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$,
3,null);return new $lambdaisland$uri$URI$$($scheme$jscomp$10_scheme$jscomp$inline_3638_uri$jscomp$51$$,$authority$jscomp$4_fragment$jscomp$inline_3642_user$jscomp$5_user$jscomp$inline_3646_vec__31226$jscomp$inline_3637$$,$password$jscomp$5_password$jscomp$inline_3647$$,$host$jscomp$6_host$jscomp$inline_3648$$,$port$jscomp$6_port$jscomp$inline_3649_vec__31233$jscomp$inline_3645_vec__31242$$,$authority$jscomp$inline_3639_path$jscomp$107$$,$path$jscomp$inline_3640_query$jscomp$18$$,$fragment$jscomp$8_query$jscomp$inline_3641_vec__31238$$,
null,null,null)}return new $lambdaisland$uri$URI$$($scheme$jscomp$10_scheme$jscomp$inline_3638_uri$jscomp$51$$,null,null,null,null,$authority$jscomp$inline_3639_path$jscomp$107$$,$path$jscomp$inline_3640_query$jscomp$18$$,$fragment$jscomp$8_query$jscomp$inline_3641_vec__31238$$,null,null,null)};$lambdaisland$uri$uri$$=function($uri_like$$){return $uri_like$$ instanceof $lambdaisland$uri$URI$$?$uri_like$$:$lambdaisland$uri$parse$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($uri_like$$))};
$lambdaisland$uri$remove_dot_segments$$=function($G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$){if($APP.$cljs$core$truth_$$($G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$)){$G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$=$clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$02$$($G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$,/(?=\/)/);for(var $G__31407_G__31409_G__31411_G__31413_G__31415_out$jscomp$16$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $G__31253_G__31414$$=$APP.$cljs$core$first$$($G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$);
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("/.",$G__31253_G__31414$$))$APP.$cljs$core$next$$($G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$)?$G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$=$APP.$cljs$core$next$$($G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$):($G__31407_G__31409_G__31411_G__31413_G__31415_out$jscomp$16$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__31407_G__31409_G__31411_G__31413_G__31415_out$jscomp$16$$,"/"),$G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$=
null);else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("/..",$G__31253_G__31414$$))$APP.$cljs$core$next$$($G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$)?($G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$=$APP.$cljs$core$next$$($G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$),$G__31407_G__31409_G__31411_G__31413_G__31415_out$jscomp$16$$=$APP.$cljs$core$vec$$($APP.$cljs$core$butlast$$($G__31407_G__31409_G__31411_G__31413_G__31415_out$jscomp$16$$))):($G__31407_G__31409_G__31411_G__31413_G__31415_out$jscomp$16$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$vec$$($APP.$cljs$core$butlast$$($G__31407_G__31409_G__31411_G__31413_G__31415_out$jscomp$16$$)),"/"),$G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$=null);else{if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$G__31253_G__31414$$))return $APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$1$($G__31407_G__31409_G__31411_G__31413_G__31415_out$jscomp$16$$);$G__31253_G__31414$$=$APP.$cljs$core$next$$($G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$);
$G__31407_G__31409_G__31411_G__31413_G__31415_out$jscomp$16$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__31407_G__31409_G__31411_G__31413_G__31415_out$jscomp$16$$,$APP.$cljs$core$first$$($G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$));$G__31406_G__31410_in$$jscomp$39_path$jscomp$109$$=$G__31253_G__31414$$}}}else return null};
$lambdaisland$uri$join_STAR_$$=function($JSCompiler_temp$jscomp$451_JSCompiler_temp$jscomp$452_base$jscomp$15$$,$JSCompiler_temp$jscomp$448_ref$jscomp$7$$){if($APP.$cljs$core$truth_$$($cljs$cst$748$scheme$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$448_ref$jscomp$7$$)))$JSCompiler_temp$jscomp$448_ref$jscomp$7$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$448_ref$jscomp$7$$,$APP.$cljs$cst$296$path$$,$lambdaisland$uri$remove_dot_segments$$);else{var $JSCompiler_temp_const$jscomp$449$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;if($APP.$cljs$core$truth_$$($APP.$cljs$cst$744$host$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$448_ref$jscomp$7$$)))$JSCompiler_temp$jscomp$451_JSCompiler_temp$jscomp$452_base$jscomp$15$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_temp$jscomp$448_ref$jscomp$7$$,$cljs$cst$748$scheme$$,$cljs$cst$748$scheme$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$451_JSCompiler_temp$jscomp$452_base$jscomp$15$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$747$query$$,$APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$448_ref$jscomp$7$$)]));else if($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$448_ref$jscomp$7$$)==null)$JSCompiler_temp$jscomp$451_JSCompiler_temp$jscomp$452_base$jscomp$15$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$451_JSCompiler_temp$jscomp$452_base$jscomp$15$$,
$APP.$cljs$cst$747$query$$,$APP.$cljs$core$some$$($APP.$cljs$cst$747$query$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$448_ref$jscomp$7$$,$JSCompiler_temp$jscomp$451_JSCompiler_temp$jscomp$452_base$jscomp$15$$],null)));else{var $JSCompiler_temp_const$jscomp$453$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$;var $JSCompiler_temp$jscomp$455_a$jscomp$inline_3651_path$jscomp$inline_11471$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$448_ref$jscomp$7$$);
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($JSCompiler_temp$jscomp$455_a$jscomp$inline_3651_path$jscomp$inline_11471$$),"/"))$JSCompiler_temp$jscomp$455_a$jscomp$inline_3651_path$jscomp$inline_11471$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$448_ref$jscomp$7$$);else{$JSCompiler_temp$jscomp$455_a$jscomp$inline_3651_path$jscomp$inline_11471$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$451_JSCompiler_temp$jscomp$452_base$jscomp$15$$);
var $b$jscomp$inline_3652$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$448_ref$jscomp$7$$);$JSCompiler_temp$jscomp$455_a$jscomp$inline_3651_path$jscomp$inline_11471$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,["/",null],null),null),$JSCompiler_temp$jscomp$455_a$jscomp$inline_3651_path$jscomp$inline_11471$$))?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$re_find$$(/^.*\//,
$JSCompiler_temp$jscomp$455_a$jscomp$inline_3651_path$jscomp$inline_11471$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$inline_3652$$)].join(""):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($b$jscomp$inline_3652$$),"/")?$b$jscomp$inline_3652$$:["/",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$inline_3652$$)].join("")}$JSCompiler_temp$jscomp$451_JSCompiler_temp$jscomp$452_base$jscomp$15$$=$JSCompiler_temp_const$jscomp$453$$.call($APP.$cljs$core$assoc$$,
$JSCompiler_temp$jscomp$451_JSCompiler_temp$jscomp$452_base$jscomp$15$$,$APP.$cljs$cst$296$path$$,$lambdaisland$uri$remove_dot_segments$$($JSCompiler_temp$jscomp$455_a$jscomp$inline_3651_path$jscomp$inline_11471$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$747$query$$,$APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$448_ref$jscomp$7$$)]))}$JSCompiler_temp$jscomp$448_ref$jscomp$7$$=$JSCompiler_temp_const$jscomp$449$$.call($APP.$cljs$core$assoc$$,
$JSCompiler_temp$jscomp$451_JSCompiler_temp$jscomp$452_base$jscomp$15$$,$APP.$cljs$cst$738$fragment$$,$APP.$cljs$cst$738$fragment$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$448_ref$jscomp$7$$))}return $JSCompiler_temp$jscomp$448_ref$jscomp$7$$};
$lambdaisland$uri$decode_param_pair$$=function($k$jscomp$420_param$jscomp$8$$){var $v$jscomp$197_vec__31265$$=$clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$03$$($k$jscomp$420_param$jscomp$8$$,/=/,2);$k$jscomp$420_param$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$197_vec__31265$$,0,null);$v$jscomp$197_vec__31265$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$197_vec__31265$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$($k$jscomp$420_param$jscomp$8$$)?$lambdaisland$uri$normalize$percent_decode$$($k$jscomp$420_param$jscomp$8$$):"",$APP.$cljs$core$truth_$$($v$jscomp$197_vec__31265$$)?$lambdaisland$uri$normalize$percent_decode$$($APP.$clojure$string$replace$$($v$jscomp$197_vec__31265$$,/\+/," ")):""],null)};
$APP.$lambdaisland$uri$query_string__GT_map$cljs$0core$0IFn$0_invoke$0arity$02$$=function($q$jscomp$34$$){var $into_map__31276__$1$$=$APP.$cljs$core$__destructure_map$$(null),$multikeys$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($into_map__31276__$1$$,$cljs$cst$761$multikeys$$,$cljs$cst$762$duplicates$$),$keywordize_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($into_map__31276__$1$$,$cljs$cst$763$keywordize_QMARK_$$,!0);$into_map__31276__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($into_map__31276__$1$$,
$cljs$cst$764$into$$);return $goog$string$internal$isEmptyOrWhitespace$$($goog$string$makeSafe$$($q$jscomp$34$$))?$into_map__31276__$1$$:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($m$jscomp$145$$,$p__31280_v$jscomp$198$$){var $k$jscomp$421_k__$1$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31280_v$jscomp$198$$,0,null);$p__31280_v$jscomp$198$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31280_v$jscomp$198$$,1,null);$k$jscomp$421_k__$1$jscomp$12$$=
$APP.$cljs$core$truth_$$($keywordize_QMARK_$$)?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$421_k__$1$jscomp$12$$):$k$jscomp$421_k__$1$jscomp$12$$;var $G__31284__$1$$=$multikeys$$ instanceof $APP.$cljs$core$Keyword$$?$multikeys$$.$fqn$:null;switch($G__31284__$1$$){case "never":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$145$$,$k$jscomp$421_k__$1$jscomp$12$$,$p__31280_v$jscomp$198$$);case "always":return $APP.$cljs$core$contains_QMARK_$$($m$jscomp$145$$,
$k$jscomp$421_k__$1$jscomp$12$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($m$jscomp$145$$,$k$jscomp$421_k__$1$jscomp$12$$,$APP.$cljs$core$conj$$,$p__31280_v$jscomp$198$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$145$$,$k$jscomp$421_k__$1$jscomp$12$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p__31280_v$jscomp$198$$],null));case "duplicates":return $APP.$cljs$core$contains_QMARK_$$($m$jscomp$145$$,$k$jscomp$421_k__$1$jscomp$12$$)?
$APP.$cljs$core$vector_QMARK_$$($m$jscomp$145$$.$cljs$core$IFn$_invoke$arity$1$?$m$jscomp$145$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$421_k__$1$jscomp$12$$):$m$jscomp$145$$($k$jscomp$421_k__$1$jscomp$12$$))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($m$jscomp$145$$,$k$jscomp$421_k__$1$jscomp$12$$,$APP.$cljs$core$conj$$,$p__31280_v$jscomp$198$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$145$$,$k$jscomp$421_k__$1$jscomp$12$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$m$jscomp$145$$.$cljs$core$IFn$_invoke$arity$1$?$m$jscomp$145$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$421_k__$1$jscomp$12$$):$m$jscomp$145$$($k$jscomp$421_k__$1$jscomp$12$$),$p__31280_v$jscomp$198$$],null)):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$145$$,$k$jscomp$421_k__$1$jscomp$12$$,$p__31280_v$jscomp$198$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__31284__$1$$)].join(""));
}},$APP.$cljs$core$truth_$$($into_map__31276__$1$$)?$into_map__31276__$1$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($lambdaisland$uri$decode_param_pair$$,$clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$02$$($q$jscomp$34$$,/&/)))};
$lambdaisland$uri$query_encode$$=function($s$jscomp$351$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__31295_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(" ",$p1__31295_SHARP_$$)?"+":$APP.$cljs$core$truth_$$($APP.$cljs$core$re_find$$(/[^a-zA-Z0-9\-\._~@\\/]/,$p1__31295_SHARP_$$))?$lambdaisland$uri$normalize$percent_encode$cljs$0core$0IFn$0_invoke$0arity$01$$($p1__31295_SHARP_$$):
$p1__31295_SHARP_$$},$lambdaisland$uri$normalize$char_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$351$$)))};
$lambdaisland$uri$encode_param_pair$$=function($k$jscomp$422$$,$v$jscomp$199$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($lambdaisland$uri$query_encode$$($cljs$core$simple_ident_QMARK_$$($k$jscomp$422$$)?$APP.$cljs$core$name$$($k$jscomp$422$$):$cljs$core$qualified_ident_QMARK_$$($k$jscomp$422$$)?[$APP.$cljs$core$namespace$$($k$jscomp$422$$),"/",$APP.$cljs$core$name$$($k$jscomp$422$$)].join(""):$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$422$$))),"\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($lambdaisland$uri$query_encode$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$199$$)))].join("")};
$lambdaisland$uri$map__GT_query_string$$=function($m$jscomp$146$$){return $APP.$cljs$core$seq$$($m$jscomp$146$$)?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$interpose$cljs$0core$0IFn$0_invoke$0arity$02$$("\x26",$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p__31307_v$jscomp$200$$){var $k$jscomp$423$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31307_v$jscomp$200$$,0,null);$p__31307_v$jscomp$200$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31307_v$jscomp$200$$,
1,null);return $p__31307_v$jscomp$200$$==null?$APP.$cljs$core$PersistentVector$EMPTY$$:$APP.$cljs$core$coll_QMARK_$$($p__31307_v$jscomp$200$$)?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($lambdaisland$uri$encode_param_pair$$,$k$jscomp$423$$),$p__31307_v$jscomp$200$$):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$lambdaisland$uri$encode_param_pair$$($k$jscomp$423$$,$p__31307_v$jscomp$200$$)],
null)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$m$jscomp$146$$])))):null};
$APP.$app$common$uri$uri$$=function($JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$){if(!($JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$ instanceof $lambdaisland$uri$URI$$))if($APP.$cljs$core$map_QMARK_$$($JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$)){var $G__31225$jscomp$inline_11479_extmap__5365__auto__$jscomp$inline_11478$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$,
$cljs$cst$748$scheme$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$750$user$$,$APP.$cljs$cst$751$password$$,$APP.$cljs$cst$744$host$$,$cljs$cst$752$port$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$747$query$$,$APP.$cljs$cst$738$fragment$$]));$G__31225$jscomp$inline_11479_extmap__5365__auto__$jscomp$inline_11478$$=$APP.$cljs$core$record_QMARK_$$($JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$G__31225$jscomp$inline_11479_extmap__5365__auto__$jscomp$inline_11478$$):$G__31225$jscomp$inline_11479_extmap__5365__auto__$jscomp$inline_11478$$;$JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$=new $lambdaisland$uri$URI$$($cljs$cst$748$scheme$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$),$cljs$cst$750$user$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$),
$APP.$cljs$cst$751$password$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$),$APP.$cljs$cst$744$host$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$),$cljs$cst$752$port$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$),$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$),
$APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$),$APP.$cljs$cst$738$fragment$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$),null,$APP.$cljs$core$not_empty$$($G__31225$jscomp$inline_11479_extmap__5365__auto__$jscomp$inline_11478$$),null)}else $JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$=$JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$==
null?$JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$:$lambdaisland$uri$parse$$($JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$);return $JSCompiler_temp$jscomp$10683_JSCompiler_temp$jscomp$10684_o$jscomp$166$$};$app$common$uri$default_encode_value$$=function($v$jscomp$202$$){return $v$jscomp$202$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$($v$jscomp$202$$):$v$jscomp$202$$};
$APP.$app$common$uri$map__GT_query_string$cljs$0core$0IFn$0_invoke$0arity$02$$=function($params$jscomp$8$$){var $map__32931__$1$$=$APP.$cljs$core$__destructure_map$$(null),$value_fn$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__32931__$1$$,$cljs$cst$766$value_fn$$,$app$common$uri$default_encode_value$$),$key_fn$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__32931__$1$$,$APP.$cljs$cst$291$key_fn$$,$APP.$cljs$core$identity$$);return $lambdaisland$uri$map__GT_query_string$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__32915_SHARP_$$){return $APP.$cljs$core$second$$($p1__32915_SHARP_$$)==null}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p__32934_v$jscomp$203$$){var $k$jscomp$425$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32934_v$jscomp$203$$,0,null);$p__32934_v$jscomp$203$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32934_v$jscomp$203$$,
1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$key_fn$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$key_fn$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$425$$):$key_fn$jscomp$2$$($k$jscomp$425$$),$value_fn$$.$cljs$core$IFn$_invoke$arity$1$?$value_fn$$.$cljs$core$IFn$_invoke$arity$1$($p__32934_v$jscomp$203$$):$value_fn$$($p__32934_v$jscomp$203$$)],null)})),$params$jscomp$8$$))};
$app$common$uri$ensure_path_slash$$=function($u$jscomp$4$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$uri$uri$$($u$jscomp$4$$),$APP.$cljs$cst$296$path$$,function($path$jscomp$110$$){return $APP.$cuerdas$core$ends_with_QMARK_$$($path$jscomp$110$$,"/")?$path$jscomp$110$$:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$110$$),"/"].join("")})};
$$jscomp$scope$624255649$2$bufferToHex$$=function($source$jscomp$23$$){$source$jscomp$23$$ instanceof Uint8Array||(ArrayBuffer.isView($source$jscomp$23$$)?$source$jscomp$23$$=new Uint8Array($source$jscomp$23$$.buffer,$source$jscomp$23$$.byteOffset,$source$jscomp$23$$.byteLength):Array.isArray($source$jscomp$23$$)&&($source$jscomp$23$$=Uint8Array.from($source$jscomp$23$$)));if($source$jscomp$23$$.length!=16)throw new RangeError("only 16 bytes array is allowed");let $i$jscomp$337$$=0;return $$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+
$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+"-"+$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+"-"+$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+
"-"+$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+"-"+$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]+
$$jscomp$scope$624255649$0$hexMap$$[$source$jscomp$23$$[$i$jscomp$337$$++]]};
$$jscomp$scope$m1561621495$9$nextLong$$=function(){$$jscomp$scope$m1561621495$1$fill$$($$jscomp$scope$m1561621495$8$tmpInt8$$);var $b$jscomp$inline_3658_view$jscomp$inline_3654$$=$$jscomp$scope$m1561621495$7$tmpView$$;const $a$jscomp$inline_3657$$=$b$jscomp$inline_3658_view$jscomp$inline_3654$$.getUint32(0,!1);$b$jscomp$inline_3658_view$jscomp$inline_3654$$=$b$jscomp$inline_3658_view$jscomp$inline_3654$$.getUint32(4,!1);const $leMask$jscomp$inline_3659$$=Number(!1),$beMask$jscomp$inline_3660$$=Number(!0);
return BigInt($a$jscomp$inline_3657$$*$beMask$jscomp$inline_3660$$+$b$jscomp$inline_3658_view$jscomp$inline_3654$$*$leMask$jscomp$inline_3659$$)<<32n|BigInt($a$jscomp$inline_3657$$*$leMask$jscomp$inline_3659$$+$b$jscomp$inline_3658_view$jscomp$inline_3654$$*$beMask$jscomp$inline_3660$$)};
$$jscomp$scope$m1561621495$4$setBigUint64$$=function($view$jscomp$6$$,$byteOffset$jscomp$22$$,$value$jscomp$296$$){const $lo$$=Number($value$jscomp$296$$&4294967295n);$view$jscomp$6$$.setUint32($byteOffset$jscomp$22$$,Number($value$jscomp$296$$>>32n),!1);$view$jscomp$6$$.setUint32($byteOffset$jscomp$22$$+4,$lo$$,!1)};$app$common$uuid$uuid$$=function($s$jscomp$353$$){return $APP.$cljs$core$uuid$$($s$jscomp$353$$)};
$APP.$app$common$uuid$parse$$=function($message$jscomp$43_s$jscomp$354$$){if(typeof $message$jscomp$43_s$jscomp$354$$==="string"&&$APP.$cljs$core$re_matches$$($app$common$uuid$regex$$,$message$jscomp$43_s$jscomp$354$$))return $APP.$cljs$core$uuid$$($message$jscomp$43_s$jscomp$354$$);$message$jscomp$43_s$jscomp$354$$=["invalid string '",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($message$jscomp$43_s$jscomp$354$$),"' for uuid"].join("");throw Error($message$jscomp$43_s$jscomp$354$$);};
$APP.$app$common$uuid$parse_STAR_$$=function($s$jscomp$355$$){try{return $APP.$app$common$uuid$parse$$($s$jscomp$355$$)}catch($e32890$$){return null}};$APP.$app$common$uuid$next$$=function(){return $app$common$uuid$uuid$$($app$common$uuid_impl$v8$$())};$app$common$uuid$zero_QMARK_$$=function($v$jscomp$204$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$v$jscomp$204$$)};
$APP.$app$common$uuid$get_u32$$=function($this$$jscomp$473$$){var $buffer$jscomp$27_buffer__$1$$=$this$$jscomp$473$$.__u32_buffer;return $buffer$jscomp$27_buffer__$1$$==null?($buffer$jscomp$27_buffer__$1$$=$app$common$uuid_impl$v8$$.$getUnsignedParts$($this$$jscomp$473$$.uuid),$this$$jscomp$473$$.__u32_buffer=$buffer$jscomp$27_buffer__$1$$):$buffer$jscomp$27_buffer__$1$$};
$clojure$test$check$random$longs$bit_count_impl$bit_count$$=function($high$jscomp$9_x$jscomp$800$$){var $low$jscomp$9$$=$high$jscomp$9_x$jscomp$800$$.$low_$;$high$jscomp$9_x$jscomp$800$$=$high$jscomp$9_x$jscomp$800$$.$high_$;return $arr$jscomp$inline_3665$$[$low$jscomp$9$$&255]+$arr$jscomp$inline_3665$$[$low$jscomp$9$$>>8&255]+$arr$jscomp$inline_3665$$[$low$jscomp$9$$>>16&255]+$arr$jscomp$inline_3665$$[$low$jscomp$9$$>>24&255]+$arr$jscomp$inline_3665$$[$high$jscomp$9_x$jscomp$800$$&255]+$arr$jscomp$inline_3665$$[$high$jscomp$9_x$jscomp$800$$>>
8&255]+$arr$jscomp$inline_3665$$[$high$jscomp$9_x$jscomp$800$$>>16&255]+$arr$jscomp$inline_3665$$[$high$jscomp$9_x$jscomp$800$$>>24&255]};
$clojure$test$check$random$longs$_STAR_$$=function($a00$jscomp$2_x$jscomp$803$$,$b00$jscomp$2_y$jscomp$280$$){var $a48$jscomp$2$$=$a00$jscomp$2_x$jscomp$803$$.$high_$>>>16,$a32$jscomp$2$$=$a00$jscomp$2_x$jscomp$803$$.$high_$&65535,$a16$jscomp$3$$=$a00$jscomp$2_x$jscomp$803$$.$low_$>>>16;$a00$jscomp$2_x$jscomp$803$$=$a00$jscomp$2_x$jscomp$803$$.$low_$&65535;var $b48$jscomp$2$$=$b00$jscomp$2_y$jscomp$280$$.$high_$>>>16,$b32$jscomp$2$$=$b00$jscomp$2_y$jscomp$280$$.$high_$&65535,$b16$jscomp$2$$=$b00$jscomp$2_y$jscomp$280$$.$low_$>>>
16;$b00$jscomp$2_y$jscomp$280$$=$b00$jscomp$2_y$jscomp$280$$.$low_$&65535;var $arr$jscomp$146$$=[0,0,0,0];$arr$jscomp$146$$[0]=$a00$jscomp$2_x$jscomp$803$$*$b00$jscomp$2_y$jscomp$280$$;$arr$jscomp$146$$[1]=$arr$jscomp$146$$[0]>>>16;$arr$jscomp$146$$[0]&=65535;$arr$jscomp$146$$[1]+=$a16$jscomp$3$$*$b00$jscomp$2_y$jscomp$280$$;$arr$jscomp$146$$[2]=$arr$jscomp$146$$[1]>>>16;$arr$jscomp$146$$[1]&=65535;$arr$jscomp$146$$[1]+=$a00$jscomp$2_x$jscomp$803$$*$b16$jscomp$2$$;$arr$jscomp$146$$[2]+=$arr$jscomp$146$$[1]>>>
16;$arr$jscomp$146$$[1]&=65535;$arr$jscomp$146$$[2]+=$a32$jscomp$2$$*$b00$jscomp$2_y$jscomp$280$$;$arr$jscomp$146$$[3]=$arr$jscomp$146$$[2]>>>16;$arr$jscomp$146$$[2]&=65535;$arr$jscomp$146$$[2]+=$a16$jscomp$3$$*$b16$jscomp$2$$;$arr$jscomp$146$$[3]+=$arr$jscomp$146$$[2]>>>16;$arr$jscomp$146$$[2]&=65535;$arr$jscomp$146$$[2]+=$a00$jscomp$2_x$jscomp$803$$*$b32$jscomp$2$$;$arr$jscomp$146$$[3]+=$arr$jscomp$146$$[2]>>>16;$arr$jscomp$146$$[2]&=65535;$arr$jscomp$146$$[3]=$arr$jscomp$146$$[3]+$a48$jscomp$2$$*
$b00$jscomp$2_y$jscomp$280$$+$a32$jscomp$2$$*$b16$jscomp$2$$+$a16$jscomp$3$$*$b32$jscomp$2$$+$a00$jscomp$2_x$jscomp$803$$*$b48$jscomp$2$$;$arr$jscomp$146$$[3]&=65535;return $module$contents$goog$math$Long_Long$fromBits$$($arr$jscomp$146$$[1]<<16|$arr$jscomp$146$$[0],$arr$jscomp$146$$[3]<<16|$arr$jscomp$146$$[2])};
$clojure$test$check$random$rand_long$$=function($JSCompiler_temp$jscomp$458_rng$jscomp$35$$){if($JSCompiler_temp$jscomp$458_rng$jscomp$35$$!=null&&$JSCompiler_temp$jscomp$458_rng$jscomp$35$$.$clojure$test$check$random$IRandom$rand_long$arity$1$!=null)$JSCompiler_temp$jscomp$458_rng$jscomp$35$$=$JSCompiler_temp$jscomp$458_rng$jscomp$35$$.$clojure$test$check$random$IRandom$rand_long$arity$1$($JSCompiler_temp$jscomp$458_rng$jscomp$35$$);else{var $m__5372__auto__$jscomp$inline_3674_m__5374__auto__$jscomp$inline_3673$$=
$clojure$test$check$random$rand_long$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$458_rng$jscomp$35$$==null?null:$JSCompiler_temp$jscomp$458_rng$jscomp$35$$)];if($m__5372__auto__$jscomp$inline_3674_m__5374__auto__$jscomp$inline_3673$$!=null)$JSCompiler_temp$jscomp$458_rng$jscomp$35$$=$m__5372__auto__$jscomp$inline_3674_m__5374__auto__$jscomp$inline_3673$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3674_m__5374__auto__$jscomp$inline_3673$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$458_rng$jscomp$35$$):
$m__5372__auto__$jscomp$inline_3674_m__5374__auto__$jscomp$inline_3673$$($JSCompiler_temp$jscomp$458_rng$jscomp$35$$);else if($m__5372__auto__$jscomp$inline_3674_m__5374__auto__$jscomp$inline_3673$$=$clojure$test$check$random$rand_long$$._,$m__5372__auto__$jscomp$inline_3674_m__5374__auto__$jscomp$inline_3673$$!=null)$JSCompiler_temp$jscomp$458_rng$jscomp$35$$=$m__5372__auto__$jscomp$inline_3674_m__5374__auto__$jscomp$inline_3673$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3674_m__5374__auto__$jscomp$inline_3673$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$458_rng$jscomp$35$$):
$m__5372__auto__$jscomp$inline_3674_m__5374__auto__$jscomp$inline_3673$$($JSCompiler_temp$jscomp$458_rng$jscomp$35$$);else throw $APP.$cljs$core$missing_protocol$$("IRandom.rand-long",$JSCompiler_temp$jscomp$458_rng$jscomp$35$$);}return $JSCompiler_temp$jscomp$458_rng$jscomp$35$$};
$clojure$test$check$random$rand_double$$=function($JSCompiler_temp$jscomp$459_rng$jscomp$37$$){if($JSCompiler_temp$jscomp$459_rng$jscomp$37$$!=null&&$JSCompiler_temp$jscomp$459_rng$jscomp$37$$.$clojure$test$check$random$IRandom$rand_double$arity$1$!=null)$JSCompiler_temp$jscomp$459_rng$jscomp$37$$=$JSCompiler_temp$jscomp$459_rng$jscomp$37$$.$clojure$test$check$random$IRandom$rand_double$arity$1$($JSCompiler_temp$jscomp$459_rng$jscomp$37$$);else{var $m__5372__auto__$jscomp$inline_3678_m__5374__auto__$jscomp$inline_3677$$=
$clojure$test$check$random$rand_double$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$459_rng$jscomp$37$$==null?null:$JSCompiler_temp$jscomp$459_rng$jscomp$37$$)];if($m__5372__auto__$jscomp$inline_3678_m__5374__auto__$jscomp$inline_3677$$!=null)$JSCompiler_temp$jscomp$459_rng$jscomp$37$$=$m__5372__auto__$jscomp$inline_3678_m__5374__auto__$jscomp$inline_3677$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3678_m__5374__auto__$jscomp$inline_3677$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$459_rng$jscomp$37$$):
$m__5372__auto__$jscomp$inline_3678_m__5374__auto__$jscomp$inline_3677$$($JSCompiler_temp$jscomp$459_rng$jscomp$37$$);else if($m__5372__auto__$jscomp$inline_3678_m__5374__auto__$jscomp$inline_3677$$=$clojure$test$check$random$rand_double$$._,$m__5372__auto__$jscomp$inline_3678_m__5374__auto__$jscomp$inline_3677$$!=null)$JSCompiler_temp$jscomp$459_rng$jscomp$37$$=$m__5372__auto__$jscomp$inline_3678_m__5374__auto__$jscomp$inline_3677$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3678_m__5374__auto__$jscomp$inline_3677$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$459_rng$jscomp$37$$):
$m__5372__auto__$jscomp$inline_3678_m__5374__auto__$jscomp$inline_3677$$($JSCompiler_temp$jscomp$459_rng$jscomp$37$$);else throw $APP.$cljs$core$missing_protocol$$("IRandom.rand-double",$JSCompiler_temp$jscomp$459_rng$jscomp$37$$);}return $JSCompiler_temp$jscomp$459_rng$jscomp$37$$};
$clojure$test$check$random$split$$=function($JSCompiler_temp$jscomp$460_rng$jscomp$39$$){if($JSCompiler_temp$jscomp$460_rng$jscomp$39$$!=null&&$JSCompiler_temp$jscomp$460_rng$jscomp$39$$.$clojure$test$check$random$IRandom$split$arity$1$!=null)$JSCompiler_temp$jscomp$460_rng$jscomp$39$$=$JSCompiler_temp$jscomp$460_rng$jscomp$39$$.$clojure$test$check$random$IRandom$split$arity$1$($JSCompiler_temp$jscomp$460_rng$jscomp$39$$);else{var $m__5372__auto__$jscomp$inline_3682_m__5374__auto__$jscomp$inline_3681$$=
$clojure$test$check$random$split$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$460_rng$jscomp$39$$==null?null:$JSCompiler_temp$jscomp$460_rng$jscomp$39$$)];if($m__5372__auto__$jscomp$inline_3682_m__5374__auto__$jscomp$inline_3681$$!=null)$JSCompiler_temp$jscomp$460_rng$jscomp$39$$=$m__5372__auto__$jscomp$inline_3682_m__5374__auto__$jscomp$inline_3681$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3682_m__5374__auto__$jscomp$inline_3681$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$460_rng$jscomp$39$$):
$m__5372__auto__$jscomp$inline_3682_m__5374__auto__$jscomp$inline_3681$$($JSCompiler_temp$jscomp$460_rng$jscomp$39$$);else if($m__5372__auto__$jscomp$inline_3682_m__5374__auto__$jscomp$inline_3681$$=$clojure$test$check$random$split$$._,$m__5372__auto__$jscomp$inline_3682_m__5374__auto__$jscomp$inline_3681$$!=null)$JSCompiler_temp$jscomp$460_rng$jscomp$39$$=$m__5372__auto__$jscomp$inline_3682_m__5374__auto__$jscomp$inline_3681$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3682_m__5374__auto__$jscomp$inline_3681$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$460_rng$jscomp$39$$):
$m__5372__auto__$jscomp$inline_3682_m__5374__auto__$jscomp$inline_3681$$($JSCompiler_temp$jscomp$460_rng$jscomp$39$$);else throw $APP.$cljs$core$missing_protocol$$("IRandom.split",$JSCompiler_temp$jscomp$460_rng$jscomp$39$$);}return $JSCompiler_temp$jscomp$460_rng$jscomp$39$$};
$clojure$test$check$random$split_n$$=function($JSCompiler_temp$jscomp$461_rng$jscomp$41$$,$n$jscomp$203$$){if($JSCompiler_temp$jscomp$461_rng$jscomp$41$$!=null&&$JSCompiler_temp$jscomp$461_rng$jscomp$41$$.$clojure$test$check$random$IRandom$split_n$arity$2$!=null)$JSCompiler_temp$jscomp$461_rng$jscomp$41$$=$JSCompiler_temp$jscomp$461_rng$jscomp$41$$.$clojure$test$check$random$IRandom$split_n$arity$2$($JSCompiler_temp$jscomp$461_rng$jscomp$41$$,$n$jscomp$203$$);else{var $m__5372__auto__$jscomp$inline_3687_m__5374__auto__$jscomp$inline_3686$$=
$clojure$test$check$random$split_n$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$461_rng$jscomp$41$$==null?null:$JSCompiler_temp$jscomp$461_rng$jscomp$41$$)];if($m__5372__auto__$jscomp$inline_3687_m__5374__auto__$jscomp$inline_3686$$!=null)$JSCompiler_temp$jscomp$461_rng$jscomp$41$$=$m__5372__auto__$jscomp$inline_3687_m__5374__auto__$jscomp$inline_3686$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3687_m__5374__auto__$jscomp$inline_3686$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$461_rng$jscomp$41$$,
$n$jscomp$203$$):$m__5372__auto__$jscomp$inline_3687_m__5374__auto__$jscomp$inline_3686$$($JSCompiler_temp$jscomp$461_rng$jscomp$41$$,$n$jscomp$203$$);else if($m__5372__auto__$jscomp$inline_3687_m__5374__auto__$jscomp$inline_3686$$=$clojure$test$check$random$split_n$$._,$m__5372__auto__$jscomp$inline_3687_m__5374__auto__$jscomp$inline_3686$$!=null)$JSCompiler_temp$jscomp$461_rng$jscomp$41$$=$m__5372__auto__$jscomp$inline_3687_m__5374__auto__$jscomp$inline_3686$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3687_m__5374__auto__$jscomp$inline_3686$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$461_rng$jscomp$41$$,
$n$jscomp$203$$):$m__5372__auto__$jscomp$inline_3687_m__5374__auto__$jscomp$inline_3686$$($JSCompiler_temp$jscomp$461_rng$jscomp$41$$,$n$jscomp$203$$);else throw $APP.$cljs$core$missing_protocol$$("IRandom.split-n",$JSCompiler_temp$jscomp$461_rng$jscomp$41$$);}return $JSCompiler_temp$jscomp$461_rng$jscomp$41$$};$clojure$test$check$random$bxoubsr$$=function($x$jscomp$810$$,$n$jscomp$204$$){return $JSCompiler_StaticMethods_shiftRightUnsigned$$($x$jscomp$810$$,$n$jscomp$204$$).xor($x$jscomp$810$$)};
$clojure$test$check$random$mix_64$$=function($n$jscomp$205$$){return $clojure$test$check$random$bxoubsr$$($clojure$test$check$random$longs$_STAR_$$($clojure$test$check$random$bxoubsr$$($clojure$test$check$random$longs$_STAR_$$($clojure$test$check$random$bxoubsr$$($n$jscomp$205$$,30),$clojure$test$check$random$mix_64_const_1$$),27),$clojure$test$check$random$mix_64_const_2$$),31)};
$clojure$test$check$random$mix_gamma$$=function($n$jscomp$206_z$jscomp$106$$){$n$jscomp$206_z$jscomp$106$$=$clojure$test$check$random$bxoubsr$$($clojure$test$check$random$longs$_STAR_$$($clojure$test$check$random$bxoubsr$$($clojure$test$check$random$longs$_STAR_$$($clojure$test$check$random$bxoubsr$$($n$jscomp$206_z$jscomp$106$$,33),$clojure$test$check$random$mix_gamma_const_1$$),33),$clojure$test$check$random$mix_gamma_const_2$$),33).or($clojure$test$check$random$longs$ONE$$);var $G__31297$jscomp$inline_3689$$=
$clojure$test$check$random$bxoubsr$$($n$jscomp$206_z$jscomp$106$$,1);return 24>($clojure$test$check$random$longs$bit_count_impl$bit_count$$.$cljs$core$IFn$_invoke$arity$1$?$clojure$test$check$random$longs$bit_count_impl$bit_count$$.$cljs$core$IFn$_invoke$arity$1$($G__31297$jscomp$inline_3689$$):$clojure$test$check$random$longs$bit_count_impl$bit_count$$($G__31297$jscomp$inline_3689$$))?$n$jscomp$206_z$jscomp$106$$.xor($clojure$test$check$random$mix_gamma_const_3$$):$n$jscomp$206_z$jscomp$106$$};
$clojure$test$check$random$JavaUtilSplittableRandom$$=function($gamma$$,$state$jscomp$8$$){this.gamma=$gamma$$;this.state=$state$jscomp$8$$};
$clojure$test$check$random$make_java_util_splittable_random$$=function($seed$jscomp$4$$){var $or__5025__auto__$jscomp$inline_3694$$=typeof $seed$jscomp$4$$==="number"?$module$contents$goog$math$Long_Long$fromNumber$$($seed$jscomp$4$$):$seed$jscomp$4$$ instanceof $module$contents$goog$math$Long_Long$$?$seed$jscomp$4$$:null;if(!$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_3694$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Bad random seed!",new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$768$seed$$,$seed$jscomp$4$$],null));return new $clojure$test$check$random$JavaUtilSplittableRandom$$($clojure$test$check$random$golden_gamma$$,$or__5025__auto__$jscomp$inline_3694$$)};$clojure$test$check$rose_tree$RoseTree$$=function($root$jscomp$15$$,$children$jscomp$123$$){this.root=$root$jscomp$15$$;this.children=$children$jscomp$123$$;this.$cljs$lang$protocol_mask$partition0$$=16;this.$cljs$lang$protocol_mask$partition1$$=0};$clojure$test$check$rose_tree$root$$=function($rose$$){return $rose$$.root};
$clojure$test$check$rose_tree$make_rose$$=function($root$jscomp$17$$,$children$jscomp$125$$){return new $clojure$test$check$rose_tree$RoseTree$$($root$jscomp$17$$,$children$jscomp$125$$)};
$clojure$test$check$rose_tree$permutations$$=function($roses$$){return function $clojure$test$check$rose_tree$permutations_$_iter__31357$$($s__31358$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__31358__$1$$=$s__31358$$;;){var $fs__5500__auto___temp__5825__auto__$jscomp$68$$=$APP.$cljs$core$seq$$($s__31358__$1$$);if($fs__5500__auto___temp__5825__auto__$jscomp$68$$){var $xs__6385__auto__$$=$fs__5500__auto___temp__5825__auto__$jscomp$68$$,$vec__31364$$=$APP.$cljs$core$first$$($xs__6385__auto__$$),
$rose$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__31364$$,0,null),$index$jscomp$131$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__31364$$,1,null);if($fs__5500__auto___temp__5825__auto__$jscomp$68$$=$APP.$cljs$core$seq$$(function($s__31358__$1$jscomp$1$$,$vec__31364$jscomp$1$$,$rose$jscomp$6$$,$index$jscomp$132$$,$xs__6385__auto__$jscomp$1$$,$temp__5825__auto__$jscomp$69$$){return function $clojure$test$check$rose_tree$permutations_$_iter__31357_$_iter__31359$$($s__31360$$){return new $APP.$cljs$core$LazySeq$$(null,
function($s__31358__$1$jscomp$2$$,$vec__31364$jscomp$2$$,$rose$jscomp$7$$,$index$jscomp$133$$){return function(){for(;;){var $s__31360__$2_temp__5825__auto____$1$jscomp$2$$=$APP.$cljs$core$seq$$($s__31360$$);if($s__31360__$2_temp__5825__auto____$1$jscomp$2$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__31360__$2_temp__5825__auto____$1$jscomp$2$$)){var $JSCompiler_inline_result$jscomp$470_c__5501__auto__$jscomp$4$$=$APP.$cljs$core$_chunked_first$$($s__31360__$2_temp__5825__auto____$1$jscomp$2$$),$size__5502__auto__$jscomp$4$$=
$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$470_c__5501__auto__$jscomp$4$$),$b__31362_child$jscomp$37$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$4$$);a:{for(var $i__31361$jscomp$inline_3699$$=0;;)if($i__31361$jscomp$inline_3699$$<$size__5502__auto__$jscomp$4$$){var $child$jscomp$inline_3700_x$jscomp$inline_11489$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$470_c__5501__auto__$jscomp$4$$,$i__31361$jscomp$inline_3699$$),$b$jscomp$inline_11488$$=$b__31362_child$jscomp$37$$;
$child$jscomp$inline_3700_x$jscomp$inline_11489$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($roses$$,$index$jscomp$133$$,$child$jscomp$inline_3700_x$jscomp$inline_11489$$);$b$jscomp$inline_11488$$.add($child$jscomp$inline_3700_x$jscomp$inline_11489$$);$i__31361$jscomp$inline_3699$$+=1}else{$JSCompiler_inline_result$jscomp$470_c__5501__auto__$jscomp$4$$=!0;break a}$JSCompiler_inline_result$jscomp$470_c__5501__auto__$jscomp$4$$=void 0}return $JSCompiler_inline_result$jscomp$470_c__5501__auto__$jscomp$4$$?
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__31362_child$jscomp$37$$),$clojure$test$check$rose_tree$permutations_$_iter__31357_$_iter__31359$$($APP.$cljs$core$_chunked_rest$$($s__31360__$2_temp__5825__auto____$1$jscomp$2$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__31362_child$jscomp$37$$),null)}$b__31362_child$jscomp$37$$=$APP.$cljs$core$first$$($s__31360__$2_temp__5825__auto____$1$jscomp$2$$);return $APP.$cljs$core$cons$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($roses$$,
$index$jscomp$133$$,$b__31362_child$jscomp$37$$),$clojure$test$check$rose_tree$permutations_$_iter__31357_$_iter__31359$$($APP.$cljs$core$rest$$($s__31360__$2_temp__5825__auto____$1$jscomp$2$$)))}return null}}}($s__31358__$1$jscomp$1$$,$vec__31364$jscomp$1$$,$rose$jscomp$6$$,$index$jscomp$132$$,$xs__6385__auto__$jscomp$1$$,$temp__5825__auto__$jscomp$69$$),null,null)}}($s__31358__$1$$,$vec__31364$$,$rose$jscomp$5$$,$index$jscomp$131$$,$xs__6385__auto__$$,$fs__5500__auto___temp__5825__auto__$jscomp$68$$)($rose$jscomp$5$$.children)))return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($fs__5500__auto___temp__5825__auto__$jscomp$68$$,
$clojure$test$check$rose_tree$permutations_$_iter__31357$$($APP.$cljs$core$rest$$($s__31358__$1$$)));$s__31358__$1$$=$APP.$cljs$core$rest$$($s__31358__$1$$)}else return null}},null,null)}($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vector$$,$roses$$,$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$03$$(0,Number.MAX_VALUE,1)))};
$clojure$test$check$rose_tree$remove$$=function($roses$jscomp$2$$){return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$134$$){return $clojure$test$check$rose_tree$exclude_nth$$($index$jscomp$134$$,$roses$jscomp$2$$)},$roses$jscomp$2$$),$clojure$test$check$rose_tree$permutations$$($APP.$cljs$core$vec$$($roses$jscomp$2$$)))};
$clojure$test$check$rose_tree$bifurcate$$=function($f$jscomp$455$$,$roses$jscomp$4$$){if(4<=$APP.$cljs$core$count$$($roses$jscomp$4$$)){var $left_count$$=$APP.$cljs$core$quot$$($APP.$cljs$core$count$$($roses$jscomp$4$$),2);return new $APP.$cljs$core$LazySeq$$(null,function(){return $APP.$cljs$core$cons$$(function(){var $G__31395$$=$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($roses$jscomp$4$$,0,$left_count$$);return $clojure$test$check$rose_tree$shrink_vector_STAR_$$.$cljs$core$IFn$_invoke$arity$2$?
$clojure$test$check$rose_tree$shrink_vector_STAR_$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$455$$,$G__31395$$):$clojure$test$check$rose_tree$shrink_vector_STAR_$$($f$jscomp$455$$,$G__31395$$)}(),new $APP.$cljs$core$LazySeq$$(null,function(){var $G__31401$jscomp$inline_3702_JSCompiler_inline_result$jscomp$471$$=$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($roses$jscomp$4$$,$left_count$$);$G__31401$jscomp$inline_3702_JSCompiler_inline_result$jscomp$471$$=$clojure$test$check$rose_tree$shrink_vector_STAR_$$.$cljs$core$IFn$_invoke$arity$2$?
$clojure$test$check$rose_tree$shrink_vector_STAR_$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$455$$,$G__31401$jscomp$inline_3702_JSCompiler_inline_result$jscomp$471$$):$clojure$test$check$rose_tree$shrink_vector_STAR_$$($f$jscomp$455$$,$G__31401$jscomp$inline_3702_JSCompiler_inline_result$jscomp$471$$);return new $APP.$cljs$core$List$$(null,$G__31401$jscomp$inline_3702_JSCompiler_inline_result$jscomp$471$$,null,1,null)},null,null))},null,null)}return null};
$clojure$test$check$rose_tree$shrink_vector_STAR_$$=function($f$jscomp$456$$,$roses$jscomp$5$$){var $thing$$=$clojure$test$check$rose_tree$shrink$$($f$jscomp$456$$,$roses$jscomp$5$$);return $clojure$test$check$rose_tree$make_rose$$($thing$$.root,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$rose_tree$bifurcate$$($f$jscomp$456$$,$roses$jscomp$5$$),$thing$$.children))};
$clojure$test$check$rose_tree$shrink_vector$$=function($empty_rose_f$jscomp$457$$,$roses$jscomp$6$$){var $rose$jscomp$8$$=$clojure$test$check$rose_tree$shrink_vector_STAR_$$($empty_rose_f$jscomp$457$$,$roses$jscomp$6$$);$empty_rose_f$jscomp$457$$=$clojure$test$check$rose_tree$make_rose$$($empty_rose_f$jscomp$457$$.$cljs$core$IFn$_invoke$arity$0$?$empty_rose_f$jscomp$457$$.$cljs$core$IFn$_invoke$arity$0$():$empty_rose_f$jscomp$457$$(),$APP.$cljs$core$PersistentVector$EMPTY$$);return $APP.$cljs$core$empty_QMARK_$$($roses$jscomp$6$$)?
$rose$jscomp$8$$:$clojure$test$check$rose_tree$make_rose$$($rose$jscomp$8$$.root,$APP.$cljs$core$cons$$($empty_rose_f$jscomp$457$$,$rose$jscomp$8$$.children))};
$clojure$test$check$generators$Generator$$=function($gen$jscomp$1$$,$__meta$jscomp$5$$,$__extmap$jscomp$5$$,$__hash$jscomp$56$$){this.$gen$=$gen$jscomp$1$$;this.$__meta$=$__meta$jscomp$5$$;this.$__extmap$=$__extmap$jscomp$5$$;this.$__hash$=$__hash$jscomp$56$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$clojure$test$check$generators$make_gen$$=function($generator_fn$jscomp$1$$){return new $clojure$test$check$generators$Generator$$($generator_fn$jscomp$1$$,null,null,null)};
$clojure$test$check$generators$call_gen$$=function($generator_fn$jscomp$2_map__32697__$1_p__32696$$,$rnd$$,$size$jscomp$47$$){$generator_fn$jscomp$2_map__32697__$1_p__32696$$=$APP.$cljs$core$__destructure_map$$($generator_fn$jscomp$2_map__32697__$1_p__32696$$);$generator_fn$jscomp$2_map__32697__$1_p__32696$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($generator_fn$jscomp$2_map__32697__$1_p__32696$$,$cljs$cst$573$gen$$);return $generator_fn$jscomp$2_map__32697__$1_p__32696$$.$cljs$core$IFn$_invoke$arity$2$?
$generator_fn$jscomp$2_map__32697__$1_p__32696$$.$cljs$core$IFn$_invoke$arity$2$($rnd$$,$size$jscomp$47$$):$generator_fn$jscomp$2_map__32697__$1_p__32696$$($rnd$$,$size$jscomp$47$$)};$clojure$test$check$generators$gen_pure$$=function($value$jscomp$297$$){return $clojure$test$check$generators$make_gen$$(function(){return $value$jscomp$297$$})};
$clojure$test$check$generators$gen_fmap$$=function($k$jscomp$427$$,$map__32703__$1_p__32702$$){$map__32703__$1_p__32702$$=$APP.$cljs$core$__destructure_map$$($map__32703__$1_p__32702$$);var $h$jscomp$110$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32703__$1_p__32702$$,$cljs$cst$573$gen$$);return $clojure$test$check$generators$make_gen$$(function($G__32706_rnd$jscomp$2$$,$size$jscomp$49$$){$G__32706_rnd$jscomp$2$$=$h$jscomp$110$$.$cljs$core$IFn$_invoke$arity$2$?$h$jscomp$110$$.$cljs$core$IFn$_invoke$arity$2$($G__32706_rnd$jscomp$2$$,
$size$jscomp$49$$):$h$jscomp$110$$($G__32706_rnd$jscomp$2$$,$size$jscomp$49$$);return $k$jscomp$427$$.$cljs$core$IFn$_invoke$arity$1$?$k$jscomp$427$$.$cljs$core$IFn$_invoke$arity$1$($G__32706_rnd$jscomp$2$$):$k$jscomp$427$$($G__32706_rnd$jscomp$2$$)})};
$clojure$test$check$generators$gen_bind$$=function($map__32710__$1_p__32709$$,$k$jscomp$428$$){$map__32710__$1_p__32709$$=$APP.$cljs$core$__destructure_map$$($map__32710__$1_p__32709$$);var $h$jscomp$111$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32710__$1_p__32709$$,$cljs$cst$573$gen$$);return $clojure$test$check$generators$make_gen$$(function($r2$jscomp$3_rnd$jscomp$3_vec__32713$$,$size$jscomp$50$$){$r2$jscomp$3_rnd$jscomp$3_vec__32713$$=$clojure$test$check$random$split$$($r2$jscomp$3_rnd$jscomp$3_vec__32713$$);
var $inner$jscomp$2_map__32716_map__32716__$1_r1$jscomp$3_result$jscomp$101$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r2$jscomp$3_rnd$jscomp$3_vec__32713$$,0,null);$r2$jscomp$3_rnd$jscomp$3_vec__32713$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r2$jscomp$3_rnd$jscomp$3_vec__32713$$,1,null);$inner$jscomp$2_map__32716_map__32716__$1_r1$jscomp$3_result$jscomp$101$$=$h$jscomp$111$$.$cljs$core$IFn$_invoke$arity$2$?$h$jscomp$111$$.$cljs$core$IFn$_invoke$arity$2$($inner$jscomp$2_map__32716_map__32716__$1_r1$jscomp$3_result$jscomp$101$$,
$size$jscomp$50$$):$h$jscomp$111$$($inner$jscomp$2_map__32716_map__32716__$1_r1$jscomp$3_result$jscomp$101$$,$size$jscomp$50$$);$inner$jscomp$2_map__32716_map__32716__$1_r1$jscomp$3_result$jscomp$101$$=$k$jscomp$428$$.$cljs$core$IFn$_invoke$arity$1$?$k$jscomp$428$$.$cljs$core$IFn$_invoke$arity$1$($inner$jscomp$2_map__32716_map__32716__$1_r1$jscomp$3_result$jscomp$101$$):$k$jscomp$428$$($inner$jscomp$2_map__32716_map__32716__$1_r1$jscomp$3_result$jscomp$101$$);$inner$jscomp$2_map__32716_map__32716__$1_r1$jscomp$3_result$jscomp$101$$=
$APP.$cljs$core$__destructure_map$$($inner$jscomp$2_map__32716_map__32716__$1_r1$jscomp$3_result$jscomp$101$$);$inner$jscomp$2_map__32716_map__32716__$1_r1$jscomp$3_result$jscomp$101$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($inner$jscomp$2_map__32716_map__32716__$1_r1$jscomp$3_result$jscomp$101$$,$cljs$cst$573$gen$$);return $inner$jscomp$2_map__32716_map__32716__$1_r1$jscomp$3_result$jscomp$101$$.$cljs$core$IFn$_invoke$arity$2$?$inner$jscomp$2_map__32716_map__32716__$1_r1$jscomp$3_result$jscomp$101$$.$cljs$core$IFn$_invoke$arity$2$($r2$jscomp$3_rnd$jscomp$3_vec__32713$$,
$size$jscomp$50$$):$inner$jscomp$2_map__32716_map__32716__$1_r1$jscomp$3_result$jscomp$101$$($r2$jscomp$3_rnd$jscomp$3_vec__32713$$,$size$jscomp$50$$)})};
$clojure$test$check$generators$gen_tuple$$=function($gens$$){return $clojure$test$check$generators$make_gen$$(function($rnd$jscomp$4$$,$size$jscomp$51$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$3$(function($p1__32729_SHARP_$$,$p2__32731_SHARP_$$){return $clojure$test$check$generators$call_gen$$($p1__32729_SHARP_$$,$p2__32731_SHARP_$$,$size$jscomp$51$$)},$gens$$,$clojure$test$check$random$split_n$$($rnd$jscomp$4$$,$APP.$cljs$core$count$$($gens$$)))})};
$clojure$test$check$generators$fmap$$=function($f$jscomp$460$$,$gen$jscomp$3$$){return $clojure$test$check$generators$gen_fmap$$(function($p1__32742_SHARP_$$){return $clojure$test$check$rose_tree$fmap$$($f$jscomp$460$$,$p1__32742_SHARP_$$)},$gen$jscomp$3$$)};$clojure$test$check$generators$return$0$$=function($value$jscomp$298$$){return $clojure$test$check$generators$gen_pure$$($clojure$test$check$rose_tree$make_rose$$($value$jscomp$298$$,$APP.$cljs$core$PersistentVector$EMPTY$$))};
$clojure$test$check$generators$bind_helper$$=function($f$jscomp$461$$){return function($rose$jscomp$11$$){return $clojure$test$check$generators$gen_fmap$$($clojure$test$check$rose_tree$join$$,$clojure$test$check$generators$make_gen$$(function($rnd$jscomp$5$$,$size$jscomp$52$$){return $clojure$test$check$rose_tree$fmap$$(function($p1__32754_SHARP_$$){return $clojure$test$check$generators$call_gen$$($f$jscomp$461$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$461$$.$cljs$core$IFn$_invoke$arity$1$($p1__32754_SHARP_$$):
$f$jscomp$461$$($p1__32754_SHARP_$$),$rnd$jscomp$5$$,$size$jscomp$52$$)},$rose$jscomp$11$$)}))}};$clojure$test$check$generators$bind$$=function($generator$$,$f$jscomp$462$$){return $clojure$test$check$generators$gen_bind$$($generator$$,$clojure$test$check$generators$bind_helper$$($f$jscomp$462$$))};
$clojure$test$check$generators$halfs$$=function($n$jscomp$209$$){return $APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__32814_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p1__32814_SHARP_$$)},$cljs$core$iterate$$(function($p1__32816_SHARP_$$){return $APP.$cljs$core$quot$$($p1__32816_SHARP_$$,2)},$n$jscomp$209$$))};
$clojure$test$check$generators$shrink_int$$=function($integer$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__32817_SHARP_$$){return $integer$$-$p1__32817_SHARP_$$},$clojure$test$check$generators$halfs$$($integer$$))};
$clojure$test$check$generators$rand_range$$=function($factor$jscomp$inline_3704_rnd$jscomp$6$$,$lower$jscomp$1$$,$upper$jscomp$1$$){$factor$jscomp$inline_3704_rnd$jscomp$6$$=$clojure$test$check$random$rand_double$$($factor$jscomp$inline_3704_rnd$jscomp$6$$);return $APP.$cljs$core$fix$$(Math.floor($lower$jscomp$1$$+($factor$jscomp$inline_3704_rnd$jscomp$6$$*(1+$upper$jscomp$1$$)-$factor$jscomp$inline_3704_rnd$jscomp$6$$*$lower$jscomp$1$$)))};
$clojure$test$check$generators$sized$$=function($sized_gen$$){return $clojure$test$check$generators$make_gen$$(function($rnd$jscomp$7$$,$size$jscomp$55$$){var $sized_gen__$1$$=$sized_gen$$.$cljs$core$IFn$_invoke$arity$1$?$sized_gen$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$55$$):$sized_gen$$($size$jscomp$55$$);return $clojure$test$check$generators$call_gen$$($sized_gen__$1$$,$rnd$jscomp$7$$,$size$jscomp$55$$)})};
$clojure$test$check$generators$resize$$=function($n$jscomp$210$$,$generator$jscomp$8_map__32831__$1$$){$generator$jscomp$8_map__32831__$1$$=$APP.$cljs$core$__destructure_map$$($generator$jscomp$8_map__32831__$1$$);var $gen$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($generator$jscomp$8_map__32831__$1$$,$cljs$cst$573$gen$$);return $clojure$test$check$generators$make_gen$$(function($rnd$jscomp$8$$){return $gen$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$gen$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($rnd$jscomp$8$$,
$n$jscomp$210$$):$gen$jscomp$4$$($rnd$jscomp$8$$,$n$jscomp$210$$)})};$clojure$test$check$generators$scale$$=function($f$jscomp$463$$,$generator$jscomp$9$$){return $clojure$test$check$generators$sized$$(function($n$jscomp$211$$){return $clojure$test$check$generators$resize$$($f$jscomp$463$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$463$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$211$$):$f$jscomp$463$$($n$jscomp$211$$),$generator$jscomp$9$$)})};
$clojure$test$check$generators$choose$$=function($lower$jscomp$2$$,$upper$jscomp$2$$){return $clojure$test$check$generators$make_gen$$(function($rnd$jscomp$9_value$jscomp$300$$){$rnd$jscomp$9_value$jscomp$300$$=$clojure$test$check$generators$rand_range$$($rnd$jscomp$9_value$jscomp$300$$,$lower$jscomp$2$$,$upper$jscomp$2$$);return $clojure$test$check$rose_tree$filter$$(function($p1__32838_SHARP_$$){return $p1__32838_SHARP_$$>=$lower$jscomp$2$$&&$p1__32838_SHARP_$$<=$upper$jscomp$2$$},$clojure$test$check$generators$int_rose_tree$$($rnd$jscomp$9_value$jscomp$300$$))})};
$clojure$test$check$generators$one_of$$=function($generators$$){return $clojure$test$check$generators$bind$$($clojure$test$check$generators$choose$$(0,$APP.$cljs$core$count$$($generators$$)-1),function($p1__32845_SHARP_$$){return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($generators$$,$p1__32845_SHARP_$$)})};
$clojure$test$check$generators$pick$$=function($likelihoods$$,$n$jscomp$212$$){return $APP.$cljs$core$count$$($APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__32846_SHARP_$$){return $p1__32846_SHARP_$$<=$n$jscomp$212$$},$APP.$cljs$core$rest$$($cljs$core$reductions$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_PLUS_$$,0,$likelihoods$$))))};
$clojure$test$check$generators$frequency$$=function($pairs$jscomp$3$$){var $pairs__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pos_QMARK_$$,$APP.$cljs$core$first$$),$pairs$jscomp$3$$),$total$jscomp$1$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$pairs__$1$$));return $clojure$test$check$generators$make_gen$$(function($rnd$jscomp$10$$,
$size$jscomp$56$$){return $clojure$test$check$generators$call_gen$$($clojure$test$check$generators$gen_bind$$($clojure$test$check$generators$choose$$(0,$total$jscomp$1$$-1),function($x$jscomp$813$$){var $idx$jscomp$50$$=$clojure$test$check$generators$pick$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$pairs__$1$$),$x$jscomp$813$$.root);return $clojure$test$check$generators$gen_fmap$$(function($rose$jscomp$12$$){return $clojure$test$check$rose_tree$make_rose$$($rose$jscomp$12$$.root,
new $APP.$cljs$core$LazySeq$$(null,function(){return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(function(){return function $clojure$test$check$generators$frequency_$_iter__32854$$($s__32855$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__32855__$2_temp__5825__auto__$jscomp$73$$=$APP.$cljs$core$seq$$($s__32855$$);if($s__32855__$2_temp__5825__auto__$jscomp$73$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__32855__$2_temp__5825__auto__$jscomp$73$$)){var $JSCompiler_inline_result$jscomp$473_c__5501__auto__$jscomp$5$$=
$APP.$cljs$core$_chunked_first$$($s__32855__$2_temp__5825__auto__$jscomp$73$$),$size__5502__auto__$jscomp$5$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$473_c__5501__auto__$jscomp$5$$),$b__32857_idx__$1$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$5$$);a:{for(var $i__32856$jscomp$inline_3708$$=0;;)if($i__32856$jscomp$inline_3708$$<$size__5502__auto__$jscomp$5$$){var $idx__$1$jscomp$inline_3709_x$jscomp$inline_11492$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$473_c__5501__auto__$jscomp$5$$,
$i__32856$jscomp$inline_3708$$),$b$jscomp$inline_11491$$=$b__32857_idx__$1$$;$idx__$1$jscomp$inline_3709_x$jscomp$inline_11492$$=$clojure$test$check$generators$call_gen$$($APP.$cljs$core$second$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($pairs__$1$$,$idx__$1$jscomp$inline_3709_x$jscomp$inline_11492$$)),$rnd$jscomp$10$$,$size$jscomp$56$$);$b$jscomp$inline_11491$$.add($idx__$1$jscomp$inline_3709_x$jscomp$inline_11492$$);$i__32856$jscomp$inline_3708$$+=1}else{$JSCompiler_inline_result$jscomp$473_c__5501__auto__$jscomp$5$$=
!0;break a}$JSCompiler_inline_result$jscomp$473_c__5501__auto__$jscomp$5$$=void 0}return $JSCompiler_inline_result$jscomp$473_c__5501__auto__$jscomp$5$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__32857_idx__$1$$),$clojure$test$check$generators$frequency_$_iter__32854$$($APP.$cljs$core$_chunked_rest$$($s__32855__$2_temp__5825__auto__$jscomp$73$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__32857_idx__$1$$),null)}$b__32857_idx__$1$$=$APP.$cljs$core$first$$($s__32855__$2_temp__5825__auto__$jscomp$73$$);
return $APP.$cljs$core$cons$$($clojure$test$check$generators$call_gen$$($APP.$cljs$core$second$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($pairs__$1$$,$b__32857_idx__$1$$)),$rnd$jscomp$10$$,$size$jscomp$56$$),$clojure$test$check$generators$frequency_$_iter__32854$$($APP.$cljs$core$rest$$($s__32855__$2_temp__5825__auto__$jscomp$73$$)))}return null}},null,null)}($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($idx$jscomp$50$$))}(),$rose$jscomp$12$$.children)},null,null))},
$APP.$cljs$core$second$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($pairs__$1$$,$idx$jscomp$50$$)))}),$rnd$jscomp$10$$,$size$jscomp$56$$)})};
$clojure$test$check$generators$elements$$=function($coll$jscomp$983$$){var $v$jscomp$205$$=$APP.$cljs$core$vec$$($coll$jscomp$983$$);return $clojure$test$check$generators$gen_fmap$$(function($p1__32860_SHARP_$$){return $clojure$test$check$rose_tree$fmap$$($v$jscomp$205$$,$p1__32860_SHARP_$$)},$clojure$test$check$generators$choose$$(0,$APP.$cljs$core$count$$($v$jscomp$205$$)-1))};
$clojure$test$check$generators$such_that_helper$$=function($pred$jscomp$36$$,$gen$jscomp$5$$,$map__32864__$1_p__32863_tries_left$$,$G__33355_r1$jscomp$5_rng$jscomp$44_rng__$1$jscomp$34$$,$G__33356_size$jscomp$57_size__$1$$){$map__32864__$1_p__32863_tries_left$$=$APP.$cljs$core$__destructure_map$$($map__32864__$1_p__32863_tries_left$$);var $ex_fn$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32864__$1_p__32863_tries_left$$,$cljs$cst$772$ex_fn$$),$max_tries$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32864__$1_p__32863_tries_left$$,
$cljs$cst$773$max_tries$$);for($map__32864__$1_p__32863_tries_left$$=$max_tries$$;;){if($map__32864__$1_p__32863_tries_left$$===0)throw function(){var $G__32870$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$351$pred$$,$pred$jscomp$36$$,$cljs$cst$573$gen$$,$gen$jscomp$5$$,$cljs$cst$773$max_tries$$,$max_tries$$],null);return $ex_fn$$.$cljs$core$IFn$_invoke$arity$1$?$ex_fn$$.$cljs$core$IFn$_invoke$arity$1$($G__32870$$):$ex_fn$$($G__32870$$)}();var $r2$jscomp$5_vec__32871$$=$clojure$test$check$random$split$$($G__33355_r1$jscomp$5_rng$jscomp$44_rng__$1$jscomp$34$$);
$G__33355_r1$jscomp$5_rng$jscomp$44_rng__$1$jscomp$34$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r2$jscomp$5_vec__32871$$,0,null);$r2$jscomp$5_vec__32871$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r2$jscomp$5_vec__32871$$,1,null);var $value$jscomp$301$$=$clojure$test$check$generators$call_gen$$($gen$jscomp$5$$,$G__33355_r1$jscomp$5_rng$jscomp$44_rng__$1$jscomp$34$$,$G__33356_size$jscomp$57_size__$1$$);if($APP.$cljs$core$truth_$$(function(){var $G__32875$$=$value$jscomp$301$$.root;
return $pred$jscomp$36$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$36$$.$cljs$core$IFn$_invoke$arity$1$($G__32875$$):$pred$jscomp$36$$($G__32875$$)}()))return $clojure$test$check$rose_tree$filter$$($pred$jscomp$36$$,$value$jscomp$301$$);$G__33355_r1$jscomp$5_rng$jscomp$44_rng__$1$jscomp$34$$=$r2$jscomp$5_vec__32871$$;$G__33356_size$jscomp$57_size__$1$$+=1;--$map__32864__$1_p__32863_tries_left$$}};
$clojure$test$check$generators$list$$=function($generator$jscomp$13$$){return $clojure$test$check$generators$gen_bind$$($clojure$test$check$generators$sized$$(function($p1__32938_SHARP_$$){return $clojure$test$check$generators$choose$$(0,$p1__32938_SHARP_$$)}),function($num_elements_rose$jscomp$2$$){return $clojure$test$check$generators$gen_fmap$$(function($roses$jscomp$10$$){return $clojure$test$check$rose_tree$shrink_vector$$($APP.$cljs$core$list$$,$roses$jscomp$10$$)},$clojure$test$check$generators$gen_tuple$$($APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($num_elements_rose$jscomp$2$$.root,
$generator$jscomp$13$$)))})};
$clojure$test$check$generators$coll_distinct_by_STAR_$$=function($empty_coll$$,$key_fn$jscomp$3$$,$shuffle_fn$$,$gen$jscomp$11$$,$G__33437_G__33442_rng$jscomp$45_size__$1$jscomp$1$$,$G__33441_rng2_size$jscomp$61_vec__32978$$,$num_elements$jscomp$1$$,$min_elements$jscomp$1$$,$max_tries$jscomp$2$$,$ex_fn$jscomp$1$$){var $rose_trees$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$G__33440_s$jscomp$363$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$rng__$1$jscomp$35$$=
$G__33437_G__33442_rng$jscomp$45_size__$1$jscomp$1$$;$G__33437_G__33442_rng$jscomp$45_size__$1$jscomp$1$$=$G__33441_rng2_size$jscomp$61_vec__32978$$;for(var $G__33438_G__33439_tries$$=0;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($max_tries$jscomp$2$$,$G__33438_G__33439_tries$$)&&$APP.$cljs$core$count$$($rose_trees$$)<$min_elements$jscomp$1$$)throw function(){var $G__32974$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$573$gen$$,$gen$jscomp$11$$,$cljs$cst$773$max_tries$$,
$max_tries$jscomp$2$$,$cljs$cst$775$num_elements$$,$num_elements$jscomp$1$$],null);return $ex_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$ex_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__32974$$):$ex_fn$jscomp$1$$($G__32974$$)}();if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($max_tries$jscomp$2$$,$G__33438_G__33439_tries$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($rose_trees$$),$num_elements$jscomp$1$$))return $clojure$test$check$rose_tree$shrink_vector$$(function(){return function(){function $G__33428$$($var_args$jscomp$533$$){var $G__33429__i_rest__32963_SHARP_$jscomp$1$$=
null;if(arguments.length>0){$G__33429__i_rest__32963_SHARP_$jscomp$1$$=0;for(var $G__33429__a$$=Array(arguments.length-0);$G__33429__i_rest__32963_SHARP_$jscomp$1$$<$G__33429__a$$.length;)$G__33429__a$$[$G__33429__i_rest__32963_SHARP_$jscomp$1$$]=arguments[$G__33429__i_rest__32963_SHARP_$jscomp$1$$+0],++$G__33429__i_rest__32963_SHARP_$jscomp$1$$;$G__33429__i_rest__32963_SHARP_$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__33429__a$$,0,null)}return $G__33428__delegate$$.call(this,$G__33429__i_rest__32963_SHARP_$jscomp$1$$)}
function $G__33428__delegate$$($rest__32963_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($empty_coll$$,$rest__32963_SHARP_$$)}$G__33428$$.$cljs$lang$maxFixedArity$=0;$G__33428$$.$cljs$lang$applyTo$=function($arglist__33430_rest__32963_SHARP_$jscomp$2$$){$arglist__33430_rest__32963_SHARP_$jscomp$2$$=$APP.$cljs$core$seq$$($arglist__33430_rest__32963_SHARP_$jscomp$2$$);return $G__33428__delegate$$($arglist__33430_rest__32963_SHARP_$jscomp$2$$)};$G__33428$$.$cljs$core$IFn$_invoke$arity$variadic$=
$G__33428__delegate$$;return $G__33428$$}()}($rose_trees$$,$G__33440_s$jscomp$363$$,$rng__$1$jscomp$35$$,$G__33437_G__33442_rng$jscomp$45_size__$1$jscomp$1$$,$G__33438_G__33439_tries$$),function(){var $G__32976$$=$rng__$1$jscomp$35$$,$G__32977$$=$APP.$cljs$core$_persistent_BANG_$$($rose_trees$$);return $shuffle_fn$$.$cljs$core$IFn$_invoke$arity$2$?$shuffle_fn$$.$cljs$core$IFn$_invoke$arity$2$($G__32976$$,$G__32977$$):$shuffle_fn$$($G__32976$$,$G__32977$$)}());$G__33441_rng2_size$jscomp$61_vec__32978$$=
$clojure$test$check$random$split$$($rng__$1$jscomp$35$$);var $rng1_rose$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__33441_rng2_size$jscomp$61_vec__32978$$,0,null);$G__33441_rng2_size$jscomp$61_vec__32978$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__33441_rng2_size$jscomp$61_vec__32978$$,1,null);$rng1_rose$jscomp$14$$=$clojure$test$check$generators$call_gen$$($gen$jscomp$11$$,$rng1_rose$jscomp$14$$,$G__33437_G__33442_rng$jscomp$45_size__$1$jscomp$1$$);
var $k$jscomp$430_root$jscomp$18$$=$rng1_rose$jscomp$14$$.root;$k$jscomp$430_root$jscomp$18$$=$key_fn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$key_fn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$430_root$jscomp$18$$):$key_fn$jscomp$3$$($k$jscomp$430_root$jscomp$18$$);$APP.$cljs$core$_lookup$$($G__33440_s$jscomp$363$$,$k$jscomp$430_root$jscomp$18$$)!=null?($G__33437_G__33442_rng$jscomp$45_size__$1$jscomp$1$$+=1,$G__33438_G__33439_tries$$+=1,$rng__$1$jscomp$35$$=$G__33441_rng2_size$jscomp$61_vec__32978$$):
($G__33438_G__33439_tries$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($rose_trees$$,$rng1_rose$jscomp$14$$),$G__33440_s$jscomp$363$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__33440_s$jscomp$363$$,$k$jscomp$430_root$jscomp$18$$),$rose_trees$$=$G__33438_G__33439_tries$$,$rng__$1$jscomp$35$$=$G__33441_rng2_size$jscomp$61_vec__32978$$,$G__33438_G__33439_tries$$=0)}};
$clojure$test$check$generators$distinct_by_QMARK_$$=function($f$jscomp$464$$,$coll$jscomp$986$$){var $or__5025__auto__$jscomp$145$$=$APP.$cljs$core$empty_QMARK_$$($coll$jscomp$986$$);return $or__5025__auto__$jscomp$145$$?$or__5025__auto__$jscomp$145$$:$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$distinct_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$464$$,$coll$jscomp$986$$))};
$clojure$test$check$generators$the_shuffle_fn$$=function($rng$jscomp$46$$,$card_coll$jscomp$987$$){var $empty_coll$jscomp$1$$=$APP.$cljs$core$empty$$($card_coll$jscomp$987$$),$v$jscomp$207$$=$APP.$cljs$core$vec$$($card_coll$jscomp$987$$);$card_coll$jscomp$987$$=$APP.$cljs$core$count$$($card_coll$jscomp$987$$);var $dec_card$$=$card_coll$jscomp$987$$-1;return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($empty_coll$jscomp$1$$,$APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__32982_rng2$jscomp$1_rng__$1$jscomp$37_vec__32986$$,
$i1$jscomp$inline_3714_idx$jscomp$51$$){var $JSCompiler_inline_result$jscomp$477_v__$1$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32982_rng2$jscomp$1_rng__$1$jscomp$37_vec__32986$$,0,null);$p__32982_rng2$jscomp$1_rng__$1$jscomp$37_vec__32986$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32982_rng2$jscomp$1_rng__$1$jscomp$37_vec__32986$$,1,null);$p__32982_rng2$jscomp$1_rng__$1$jscomp$37_vec__32986$$=$clojure$test$check$random$split$$($p__32982_rng2$jscomp$1_rng__$1$jscomp$37_vec__32986$$);
var $JSCompiler_temp_const$jscomp$476_rng1$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32982_rng2$jscomp$1_rng__$1$jscomp$37_vec__32986$$,0,null);$p__32982_rng2$jscomp$1_rng__$1$jscomp$37_vec__32986$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32982_rng2$jscomp$1_rng__$1$jscomp$37_vec__32986$$,1,null);var $i2$jscomp$inline_3715_p__32942$jscomp$inline_3713_swap_idx$$=$clojure$test$check$generators$rand_range$$($JSCompiler_temp_const$jscomp$476_rng1$jscomp$1$$,
$i1$jscomp$inline_3714_idx$jscomp$51$$,$dec_card$$);$JSCompiler_temp_const$jscomp$476_rng1$jscomp$1$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;$i2$jscomp$inline_3715_p__32942$jscomp$inline_3713_swap_idx$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$i1$jscomp$inline_3714_idx$jscomp$51$$,$i2$jscomp$inline_3715_p__32942$jscomp$inline_3713_swap_idx$$],null);$i1$jscomp$inline_3714_idx$jscomp$51$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i2$jscomp$inline_3715_p__32942$jscomp$inline_3713_swap_idx$$,
0,null);$i2$jscomp$inline_3715_p__32942$jscomp$inline_3713_swap_idx$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i2$jscomp$inline_3715_p__32942$jscomp$inline_3713_swap_idx$$,1,null);$JSCompiler_inline_result$jscomp$477_v__$1$jscomp$12$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_inline_result$jscomp$477_v__$1$jscomp$12$$,$i2$jscomp$inline_3715_p__32942$jscomp$inline_3713_swap_idx$$,$JSCompiler_inline_result$jscomp$477_v__$1$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?
$JSCompiler_inline_result$jscomp$477_v__$1$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($i1$jscomp$inline_3714_idx$jscomp$51$$):$JSCompiler_inline_result$jscomp$477_v__$1$jscomp$12$$($i1$jscomp$inline_3714_idx$jscomp$51$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$i1$jscomp$inline_3714_idx$jscomp$51$$,$JSCompiler_inline_result$jscomp$477_v__$1$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$477_v__$1$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($i2$jscomp$inline_3715_p__32942$jscomp$inline_3713_swap_idx$$):
$JSCompiler_inline_result$jscomp$477_v__$1$jscomp$12$$($i2$jscomp$inline_3715_p__32942$jscomp$inline_3713_swap_idx$$)]));return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$476_rng1$jscomp$1$$,[$JSCompiler_inline_result$jscomp$477_v__$1$jscomp$12$$,$p__32982_rng2$jscomp$1_rng__$1$jscomp$37_vec__32986$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$v$jscomp$207$$,$rng$jscomp$46$$],null),$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($card_coll$jscomp$987$$))))};
$clojure$test$check$generators$coll_distinct_by$$=function($empty_coll$jscomp$2$$,$key_fn$jscomp$4$$,$allows_dupes_QMARK_$$,$ordered_QMARK_$$,$gen$jscomp$12$$,$map__32997__$1_p__32996$$){$map__32997__$1_p__32996$$=$APP.$cljs$core$__destructure_map$$($map__32997__$1_p__32996$$);var $num_elements$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32997__$1_p__32996$$,$cljs$cst$775$num_elements$$),$min_elements$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32997__$1_p__32996$$,
$cljs$cst$776$min_elements$$),$max_elements$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32997__$1_p__32996$$,$cljs$cst$777$max_elements$$),$max_tries$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__32997__$1_p__32996$$,$cljs$cst$773$max_tries$$,10),$ex_fn$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__32997__$1_p__32996$$,$cljs$cst$772$ex_fn$$,function($p1__32989_SHARP_$$){return $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Couldn't generate enough distinct elements!",
$p1__32989_SHARP_$$)}),$shuffle_fn$jscomp$1$$=$APP.$cljs$core$truth_$$($ordered_QMARK_$$)?$clojure$test$check$generators$the_shuffle_fn$$:function($_rng$$,$coll$jscomp$988$$){return $coll$jscomp$988$$},$hard_min_elements$$=$APP.$cljs$core$truth_$$($num_elements$jscomp$2$$)?$num_elements$jscomp$2$$:$APP.$cljs$core$truth_$$($min_elements$jscomp$2$$)?$min_elements$jscomp$2$$:1;if($APP.$cljs$core$truth_$$($num_elements$jscomp$2$$)){var $size_pred$$=function($p1__32990_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($num_elements$jscomp$2$$,
$APP.$cljs$core$count$$($p1__32990_SHARP_$$))};return $clojure$test$check$generators$make_gen$$(function($rng$jscomp$47$$,$gen_size$$){return $clojure$test$check$rose_tree$filter$$($APP.$cljs$core$truth_$$($allows_dupes_QMARK_$$)?$cljs$core$every_pred$cljs$0core$0IFn$0_invoke$0arity$02$$($size_pred$$,function($p1__32991_SHARP_$$){return $clojure$test$check$generators$distinct_by_QMARK_$$($key_fn$jscomp$4$$,$p1__32991_SHARP_$$)}):$size_pred$$,$clojure$test$check$generators$coll_distinct_by_STAR_$$($empty_coll$jscomp$2$$,
$key_fn$jscomp$4$$,$shuffle_fn$jscomp$1$$,$gen$jscomp$12$$,$rng$jscomp$47$$,$gen_size$$,$num_elements$jscomp$2$$,$hard_min_elements$$,$max_tries$jscomp$3$$,$ex_fn$jscomp$2$$))})}var $min_elements__$1$$=$APP.$cljs$core$truth_$$($min_elements$jscomp$2$$)?$min_elements$jscomp$2$$:0;$size_pred$$=$APP.$cljs$core$truth_$$($max_elements$jscomp$1$$)?function($p1__32992_SHARP_$$){return $min_elements__$1$$<=$APP.$cljs$core$count$$($p1__32992_SHARP_$$)&&$APP.$cljs$core$count$$($p1__32992_SHARP_$$)<=$max_elements$jscomp$1$$}:
function($p1__32993_SHARP_$$){return $min_elements__$1$$<=$APP.$cljs$core$count$$($p1__32993_SHARP_$$)};return $clojure$test$check$generators$gen_bind$$($APP.$cljs$core$truth_$$($max_elements$jscomp$1$$)?$clojure$test$check$generators$choose$$($min_elements__$1$$,$max_elements$jscomp$1$$):$clojure$test$check$generators$sized$$(function($p1__32994_SHARP_$$){return $clojure$test$check$generators$choose$$($min_elements__$1$$,$min_elements__$1$$+$p1__32994_SHARP_$$)}),function($num_elements_rose$jscomp$3$$){var $num_elements__$1$$=
$num_elements_rose$jscomp$3$$.root;return $clojure$test$check$generators$make_gen$$(function($rng$jscomp$48$$,$gen_size$jscomp$1$$){return $clojure$test$check$rose_tree$filter$$($APP.$cljs$core$truth_$$($allows_dupes_QMARK_$$)?$cljs$core$every_pred$cljs$0core$0IFn$0_invoke$0arity$02$$($size_pred$$,function($p1__32995_SHARP_$$){return $clojure$test$check$generators$distinct_by_QMARK_$$($key_fn$jscomp$4$$,$p1__32995_SHARP_$$)}):$size_pred$$,$clojure$test$check$generators$coll_distinct_by_STAR_$$($empty_coll$jscomp$2$$,
$key_fn$jscomp$4$$,$shuffle_fn$jscomp$1$$,$gen$jscomp$12$$,$rng$jscomp$48$$,$gen_size$jscomp$1$$,$num_elements__$1$$,$hard_min_elements$$,$max_tries$jscomp$3$$,$ex_fn$jscomp$2$$))})})};$clojure$test$check$generators$vector_distinct_by$cljs$0core$0IFn$0_invoke$0arity$03$$=function($key_fn$jscomp$6$$,$gen$jscomp$18$$,$opts$jscomp$207$$){return $clojure$test$check$generators$coll_distinct_by$$($APP.$cljs$core$PersistentVector$EMPTY$$,$key_fn$jscomp$6$$,!0,!0,$gen$jscomp$18$$,$opts$jscomp$207$$)};
$clojure$test$check$generators$long__GT_large_integer$$=function($bit_count$$,$x$jscomp$815$$,$min$jscomp$45$$,$max$jscomp$45$$){for(var $res$jscomp$21$$=function(){var $G__33037$$=$JSCompiler_StaticMethods_toNumber$$($JSCompiler_StaticMethods_shiftRight$$($x$jscomp$815$$,64-$bit_count$$));return $min$jscomp$45$$===0?Math.abs($G__33037$$):$G__33037$$}();;){if($min$jscomp$45$$<=$res$jscomp$21$$&&$res$jscomp$21$$<=$max$jscomp$45$$)return $res$jscomp$21$$;var $res_SINGLEQUOTE_$$=-$res$jscomp$21$$;if($min$jscomp$45$$<=
$res_SINGLEQUOTE_$$&&$res_SINGLEQUOTE_$$<=$max$jscomp$45$$)return $res_SINGLEQUOTE_$$;$res$jscomp$21$$=function(){var $G__33038$$=$res$jscomp$21$$;if(!$APP.$cljs$core$even_QMARK_$$($res$jscomp$21$$)){var $fexpr__33042$$=$res$jscomp$21$$<0?$APP.$cljs$core$inc$$:$APP.$cljs$core$dec$$;return $fexpr__33042$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__33042$$.$cljs$core$IFn$_invoke$arity$1$($G__33038$$):$fexpr__33042$$($G__33038$$)}return $G__33038$$}()/2}};
$clojure$test$check$generators$large_integer_STAR__STAR_$$=function($min$jscomp$46$$,$max$jscomp$46$$){return $clojure$test$check$generators$sized$$(function($size$jscomp$62_size__$1$jscomp$3$$){$size$jscomp$62_size__$1$jscomp$3$$=$size$jscomp$62_size__$1$jscomp$3$$>1?$size$jscomp$62_size__$1$jscomp$3$$:1;return $clojure$test$check$generators$gen_fmap$$(function($bit_count$jscomp$1_rose$jscomp$15$$){var $vec__33044_x$jscomp$816$$=$bit_count$jscomp$1_rose$jscomp$15$$.root;$bit_count$jscomp$1_rose$jscomp$15$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33044_x$jscomp$816$$,0,null);$vec__33044_x$jscomp$816$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33044_x$jscomp$816$$,1,null);return $clojure$test$check$generators$int_rose_tree$$($clojure$test$check$generators$long__GT_large_integer$$($bit_count$jscomp$1_rose$jscomp$15$$,$vec__33044_x$jscomp$816$$,$min$jscomp$46$$,$max$jscomp$46$$))},$clojure$test$check$generators$tuple$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$clojure$test$check$generators$choose$$(1,
$size$jscomp$62_size__$1$jscomp$3$$<54?$size$jscomp$62_size__$1$jscomp$3$$:54),$clojure$test$check$generators$gen_raw_long$$])))})};
$clojure$test$check$generators$large_integer_STAR_$$=function($min$jscomp$47_p__33050$$){var $map__33051__$1_max$jscomp$47$$=$APP.$cljs$core$__destructure_map$$($min$jscomp$47_p__33050$$);$min$jscomp$47_p__33050$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33051__$1_max$jscomp$47$$,$APP.$cljs$cst$338$min$$);$map__33051__$1_max$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33051__$1_max$jscomp$47$$,$APP.$cljs$cst$339$max$$);var $min__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($min$jscomp$47_p__33050$$)?
$min$jscomp$47_p__33050$$:$clojure$test$check$generators$MIN_INTEGER$$,$max__$1$$=$APP.$cljs$core$truth_$$($map__33051__$1_max$jscomp$47$$)?$map__33051__$1_max$jscomp$47$$:$clojure$test$check$generators$MAX_INTEGER$$;return $clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__33047_SHARP_$$){return $min__$1$jscomp$1$$<=$p1__33047_SHARP_$$&&$p1__33047_SHARP_$$<=$max__$1$$},$min__$1$jscomp$1$$<=0&&0<=$max__$1$$?$clojure$test$check$generators$large_integer_STAR__STAR_$$($min__$1$jscomp$1$$,
$max__$1$$):$max__$1$$<0?$clojure$test$check$generators$fmap$$(function($p1__33048_SHARP_$$){return $max__$1$$+$p1__33048_SHARP_$$},$clojure$test$check$generators$large_integer_STAR__STAR_$$($min__$1$jscomp$1$$-$max__$1$$,0)):$clojure$test$check$generators$fmap$$(function($p1__33049_SHARP_$$){return $min__$1$jscomp$1$$+$p1__33049_SHARP_$$},$clojure$test$check$generators$large_integer_STAR__STAR_$$(0,$max__$1$$-$min__$1$jscomp$1$$)))};
$clojure$test$check$generators$get_exponent$$=function($res$jscomp$22_x$jscomp$818$$){if($res$jscomp$22_x$jscomp$818$$===0)return-1023;var $t$jscomp$46_x__$1$jscomp$20$$=Math.abs($res$jscomp$22_x$jscomp$818$$);$res$jscomp$22_x$jscomp$818$$=Math.floor(Math.log($t$jscomp$46_x__$1$jscomp$20$$)*Math.LOG2E);$t$jscomp$46_x__$1$jscomp$20$$*=Math.pow(2,-$res$jscomp$22_x$jscomp$818$$);return $t$jscomp$46_x__$1$jscomp$20$$<1?$res$jscomp$22_x$jscomp$818$$-1:2<=$t$jscomp$46_x__$1$jscomp$20$$?$res$jscomp$22_x$jscomp$818$$+
1:$res$jscomp$22_x$jscomp$818$$};
$clojure$test$check$generators$double_exp_and_sign$$=function($lower_bound$$,$upper_bound$$){function $gen_exp$$($lb$$,$ub$$){return $clojure$test$check$generators$sized$$(function($size$jscomp$64$$){var $qs8$$=1<<$APP.$cljs$core$quot$$(200<$size$jscomp$64$$?200:$size$jscomp$64$$,8);return $lb$$<=0&&0<=$ub$$?$clojure$test$check$generators$choose$$(function(){var $y__5111__auto__$jscomp$10$$=-$qs8$$;return $lb$$>$y__5111__auto__$jscomp$10$$?$lb$$:$y__5111__auto__$jscomp$10$$}(),$ub$$<$qs8$$?$ub$$:
$qs8$$):$ub$$<0?$clojure$test$check$generators$choose$$(function(){var $y__5111__auto__$jscomp$11$$=$ub$$-$qs8$$;return $lb$$>$y__5111__auto__$jscomp$11$$?$lb$$:$y__5111__auto__$jscomp$11$$}(),$ub$$):$clojure$test$check$generators$choose$$($lb$$,function(){var $y__5114__auto__$jscomp$14$$=$lb$$+$qs8$$;return $ub$$<$y__5114__auto__$jscomp$14$$?$ub$$:$y__5114__auto__$jscomp$14$$}())})}if($lower_bound$$==null&&$upper_bound$$==null)return $clojure$test$check$generators$tuple$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$gen_exp$$(-1023,
1023),$clojure$test$check$generators$elements$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,-1],null))]));var $lower_bound__$1$$=$APP.$cljs$core$truth_$$($lower_bound$$)?$lower_bound$$:$clojure$test$check$generators$MIN_NEG_VALUE$$,$upper_bound__$1$$=$APP.$cljs$core$truth_$$($upper_bound$$)?$upper_bound$$:$clojure$test$check$generators$MAX_POS_VALUE$$,$lbexp$$=function(){var $y__5111__auto__$jscomp$12$$=$clojure$test$check$generators$get_exponent$$($lower_bound__$1$$);
return-1023>$y__5111__auto__$jscomp$12$$?-1023:$y__5111__auto__$jscomp$12$$}(),$ubexp$$=function(){var $y__5111__auto__$jscomp$13$$=$clojure$test$check$generators$get_exponent$$($upper_bound__$1$$);return-1023>$y__5111__auto__$jscomp$13$$?-1023:$y__5111__auto__$jscomp$13$$}();return 0<=$lower_bound__$1$$?$clojure$test$check$generators$tuple$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$gen_exp$$($lbexp$$,$ubexp$$),$clojure$test$check$generators$return$0$$(1)])):
$upper_bound__$1$$<=0?$clojure$test$check$generators$tuple$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$gen_exp$$($ubexp$$,$lbexp$$),$clojure$test$check$generators$return$0$$(-1)])):$clojure$test$check$generators$fmap$$(function($p__33083$$){var $exp$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33083$$,0,null),$sign$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33083$$,1,null);return $sign$jscomp$2$$<
0&&$lbexp$$<$exp$jscomp$1$$||$sign$jscomp$2$$>0&&$ubexp$$<$exp$jscomp$1$$?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$exp$jscomp$1$$,-$sign$jscomp$2$$],null):$p__33083$$},$clojure$test$check$generators$tuple$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$gen_exp$$(-1023,$ubexp$$>$lbexp$$?$ubexp$$:$lbexp$$),$clojure$test$check$generators$elements$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,-1],null))])))};
$clojure$test$check$generators$double_finite$$=function($lower_bound$jscomp$1$$,$upper_bound$jscomp$1$$){var $pred$jscomp$39$$=$APP.$cljs$core$truth_$$($lower_bound$jscomp$1$$)?$APP.$cljs$core$truth_$$($upper_bound$jscomp$1$$)?function($p1__33093_SHARP_$$){return $lower_bound$jscomp$1$$<=$p1__33093_SHARP_$$&&$p1__33093_SHARP_$$<=$upper_bound$jscomp$1$$}:function($p1__33094_SHARP_$$){return $lower_bound$jscomp$1$$<=$p1__33094_SHARP_$$}:$APP.$cljs$core$truth_$$($upper_bound$jscomp$1$$)?function($p1__33095_SHARP_$$){return $p1__33095_SHARP_$$<=
$upper_bound$jscomp$1$$}:null,$G__33136$$=$clojure$test$check$generators$fmap$$(function($base$jscomp$17_p__33115_x__$1$jscomp$21_x__5110__auto__$jscomp$15$$){var $block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($base$jscomp$17_p__33115_x__$1$jscomp$21_x__5110__auto__$jscomp$15$$,0,null),$block_lb_exp$jscomp$3_low$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$,
0,null);$block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$,1,null);$base$jscomp$17_p__33115_x__$1$jscomp$21_x__5110__auto__$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($base$jscomp$17_p__33115_x__$1$jscomp$21_x__5110__auto__$jscomp$15$$,1,null)/4503599627370496+1;var $x$jscomp$819$$=$base$jscomp$17_p__33115_x__$1$jscomp$21_x__5110__auto__$jscomp$15$$*
Math.pow(2,$block_lb_exp$jscomp$3_low$jscomp$11$$)*$block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$;var $JSCompiler_inline_result$jscomp$10686_or__5025__auto__$jscomp$inline_11494$$=($JSCompiler_inline_result$jscomp$10686_or__5025__auto__$jscomp$inline_11494$$=$pred$jscomp$39$$==null)?$JSCompiler_inline_result$jscomp$10686_or__5025__auto__$jscomp$inline_11494$$:$pred$jscomp$39$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$39$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$819$$):$pred$jscomp$39$$($x$jscomp$819$$);
if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10686_or__5025__auto__$jscomp$inline_11494$$))return $x$jscomp$819$$;$block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$=$clojure$test$check$generators$block_bounds$$($block_lb_exp$jscomp$3_low$jscomp$11$$,$block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$);$block_lb_exp$jscomp$3_low$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$,
0,null);$block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$,1,null);$block_lb_exp$jscomp$3_low$jscomp$11$$=$APP.$cljs$core$truth_$$($lower_bound$jscomp$1$$)?$block_lb_exp$jscomp$3_low$jscomp$11$$>$lower_bound$jscomp$1$$?$block_lb_exp$jscomp$3_low$jscomp$11$$:$lower_bound$jscomp$1$$:$block_lb_exp$jscomp$3_low$jscomp$11$$;$block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$=
$APP.$cljs$core$truth_$$($upper_bound$jscomp$1$$)?$block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$<$upper_bound$jscomp$1$$?$block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$:$upper_bound$jscomp$1$$:$block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$;$base$jscomp$17_p__33115_x__$1$jscomp$21_x__5110__auto__$jscomp$15$$=$block_lb_exp$jscomp$3_low$jscomp$11$$+($block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$-$block_lb_exp$jscomp$3_low$jscomp$11$$)*($base$jscomp$17_p__33115_x__$1$jscomp$21_x__5110__auto__$jscomp$15$$-
1);$base$jscomp$17_p__33115_x__$1$jscomp$21_x__5110__auto__$jscomp$15$$=$base$jscomp$17_p__33115_x__$1$jscomp$21_x__5110__auto__$jscomp$15$$<$block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$?$base$jscomp$17_p__33115_x__$1$jscomp$21_x__5110__auto__$jscomp$15$$:$block_ub_high$jscomp$11_sign$jscomp$4_vec__33119_vec__33125$$;return $base$jscomp$17_p__33115_x__$1$jscomp$21_x__5110__auto__$jscomp$15$$>$block_lb_exp$jscomp$3_low$jscomp$11$$?$base$jscomp$17_p__33115_x__$1$jscomp$21_x__5110__auto__$jscomp$15$$:
$block_lb_exp$jscomp$3_low$jscomp$11$$},$clojure$test$check$generators$tuple$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$clojure$test$check$generators$double_exp_and_sign$$($lower_bound$jscomp$1$$,$upper_bound$jscomp$1$$),$clojure$test$check$generators$backwards_shrinking_significand$$])));return $APP.$cljs$core$truth_$$($pred$jscomp$39$$)?$clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$2$($pred$jscomp$39$$,$G__33136$$):
$G__33136$$};
$clojure$test$check$generators$double_STAR_$$=function($NaN_QMARK__frequency_arg_p__33137$$){var $G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$=$APP.$cljs$core$__destructure_map$$($NaN_QMARK__frequency_arg_p__33137$$),$G__33139__$3$jscomp$inline_11499_infinite_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$,$cljs$cst$778$infinite_QMARK_$$,!0);$NaN_QMARK__frequency_arg_p__33137$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$,$cljs$cst$779$NaN_QMARK_$$,
!0);var $min$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$,$APP.$cljs$cst$338$min$$);$G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$,$APP.$cljs$cst$339$max$$);var $G__33139$jscomp$inline_11496_G__33139__$1$jscomp$inline_11497$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[95,$clojure$test$check$generators$double_finite$$($min$jscomp$48$$,$G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$)],null)],null);$G__33139$jscomp$inline_11496_G__33139__$1$jscomp$inline_11497$$=($min$jscomp$48$$==null?$G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$==null||0<=$G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$:$G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$==
null?$min$jscomp$48$$<=0:$min$jscomp$48$$<=0&&0<=$G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($G__33139$jscomp$inline_11496_G__33139__$1$jscomp$inline_11497$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,$clojure$test$check$generators$return$0$$(0)],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,$clojure$test$check$generators$return$0$$(-0)],null)])):$G__33139$jscomp$inline_11496_G__33139__$1$jscomp$inline_11497$$;$G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__33139__$3$jscomp$inline_11499_infinite_QMARK_$$)?$G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$==null:$G__33139__$3$jscomp$inline_11499_infinite_QMARK_$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__33139$jscomp$inline_11496_G__33139__$1$jscomp$inline_11497$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,$clojure$test$check$generators$return$0$$($clojure$test$check$generators$POS_INFINITY$$)],null)):$G__33139$jscomp$inline_11496_G__33139__$1$jscomp$inline_11497$$;$G__33139__$3$jscomp$inline_11499_infinite_QMARK_$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__33139__$3$jscomp$inline_11499_infinite_QMARK_$$)?$min$jscomp$48$$==null:$G__33139__$3$jscomp$inline_11499_infinite_QMARK_$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,$clojure$test$check$generators$return$0$$($clojure$test$check$generators$NEG_INFINITY$$)],null)):$G__33139__$2$jscomp$inline_11498_map__33138__$1_max$jscomp$48$$;$NaN_QMARK__frequency_arg_p__33137$$=$APP.$cljs$core$truth_$$($NaN_QMARK__frequency_arg_p__33137$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__33139__$3$jscomp$inline_11499_infinite_QMARK_$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,$clojure$test$check$generators$return$0$$($clojure$test$check$generators$NAN$$)],null)):$G__33139__$3$jscomp$inline_11499_infinite_QMARK_$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($NaN_QMARK__frequency_arg_p__33137$$))?$APP.$cljs$core$second$$($APP.$cljs$core$first$$($NaN_QMARK__frequency_arg_p__33137$$)):$clojure$test$check$generators$frequency$$($NaN_QMARK__frequency_arg_p__33137$$)};
$clojure$test$check$generators$resize_symbolish_generator$$=function($g$jscomp$100$$){return $clojure$test$check$generators$scale$$(function($p1__33166_SHARP_$$){return $APP.$cljs$core$fix$$(Math.pow($p1__33166_SHARP_$$,.6))},$g$jscomp$100$$)};
$clojure$test$check$generators$base_simple_type$$=function($double_gen$$,$char_gen$$,$string_gen$$){return $clojure$test$check$generators$one_of$$(new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$clojure$test$check$generators$small_integer$$,$clojure$test$check$generators$large_integer$$,$double_gen$$,$char_gen$$,$string_gen$$,$clojure$test$check$generators$ratio$$,$clojure$test$check$generators$boolean$0$$,$clojure$test$check$generators$keyword$$,$clojure$test$check$generators$keyword_ns$$,
$clojure$test$check$generators$symbol$$,$clojure$test$check$generators$symbol_ns$$,$clojure$test$check$generators$uuid$$],null))};
$clojure$test$check$generators$hashable_QMARK_$$=function($JSCompiler_inline_result$jscomp$480_JSCompiler_temp$jscomp$479_x$jscomp$820$$){if(typeof $JSCompiler_inline_result$jscomp$480_JSCompiler_temp$jscomp$479_x$jscomp$820$$==="number"){var $or__5025__auto__$jscomp$inline_3723$$=isNaN($JSCompiler_inline_result$jscomp$480_JSCompiler_temp$jscomp$479_x$jscomp$820$$);$JSCompiler_inline_result$jscomp$480_JSCompiler_temp$jscomp$479_x$jscomp$820$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_3723$$)?
$or__5025__auto__$jscomp$inline_3723$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$generators$NEG_INFINITY$$,$JSCompiler_inline_result$jscomp$480_JSCompiler_temp$jscomp$479_x$jscomp$820$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$generators$POS_INFINITY$$,$JSCompiler_inline_result$jscomp$480_JSCompiler_temp$jscomp$479_x$jscomp$820$$);$JSCompiler_inline_result$jscomp$480_JSCompiler_temp$jscomp$479_x$jscomp$820$$=$APP.$cljs$core$not$$($JSCompiler_inline_result$jscomp$480_JSCompiler_temp$jscomp$479_x$jscomp$820$$)}else $JSCompiler_inline_result$jscomp$480_JSCompiler_temp$jscomp$479_x$jscomp$820$$=
!0;return $JSCompiler_inline_result$jscomp$480_JSCompiler_temp$jscomp$479_x$jscomp$820$$};
$clojure$test$check$generators$randomized$$=function($func$jscomp$3$$){return $clojure$test$check$generators$make_gen$$(function($r1$jscomp$7_rng$jscomp$50$$,$size$jscomp$66$$){var $r2$jscomp$7_vec__33221$$=$clojure$test$check$random$split$$($r1$jscomp$7_rng$jscomp$50$$);$r1$jscomp$7_rng$jscomp$50$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r2$jscomp$7_vec__33221$$,0,null);$r2$jscomp$7_vec__33221$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r2$jscomp$7_vec__33221$$,
1,null);return $clojure$test$check$generators$call_gen$$($func$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$func$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($r1$jscomp$7_rng$jscomp$50$$):$func$jscomp$3$$($r1$jscomp$7_rng$jscomp$50$$),$r2$jscomp$7_vec__33221$$,$size$jscomp$66$$)})};
$clojure$test$check$generators$recursive_gen$$=function($container_gen_fn$$,$scalar_gen$$){return $clojure$test$check$generators$sized$$(function($size$jscomp$67$$){return $clojure$test$check$generators$bind$$($clojure$test$check$generators$choose$$(0,$APP.$cljs$core$fix$$(Math.pow($size$jscomp$67$$,1.1))),function($max_leaf_count$$){return $clojure$test$check$generators$randomized$$(function($rng$jscomp$51_sizes$$){$rng$jscomp$51_sizes$$=$clojure$test$check$generators$random_pseudofactoring$$($max_leaf_count$$,
$rng$jscomp$51_sizes$$);var $sized_scalar_gen$$=$clojure$test$check$generators$resize$$($size$jscomp$67$$,$scalar_gen$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($g$jscomp$101$$,$size__$1$jscomp$4$$){return $clojure$test$check$generators$bind$$($clojure$test$check$generators$choose$$(0,10),function($x$jscomp$821$$){return $x$jscomp$821$$===0?$sized_scalar_gen$$:$clojure$test$check$generators$resize$$($size__$1$jscomp$4$$,$container_gen_fn$$.$cljs$core$IFn$_invoke$arity$1$?
$container_gen_fn$$.$cljs$core$IFn$_invoke$arity$1$($g$jscomp$101$$):$container_gen_fn$$($g$jscomp$101$$))})},$sized_scalar_gen$$,$rng$jscomp$51_sizes$$)})})})};$cljs$spec$gen$alpha$LazyVar$$=function($f$jscomp$465$$){this.f=$f$jscomp$465$$;this.$cached$=null;this.$cljs$lang$protocol_mask$partition0$$=32768;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$spec$gen$alpha$list$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($args$jscomp$143$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($g__15767__auto___33330$$),$args$jscomp$143$$)};$cljs$spec$gen$alpha$map$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($args$jscomp$144$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($g__15767__auto___33342$$),$args$jscomp$144$$)};
$cljs$spec$gen$alpha$set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($args$jscomp$146$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($g__15767__auto___33367$$),$args$jscomp$146$$)};$cljs$spec$gen$alpha$vector$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($args$jscomp$147$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($g__15767__auto___33374$$),$args$jscomp$147$$)};
$cljs$spec$gen$alpha$fmap$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($args$jscomp$149$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($g__15767__auto___33392$$),$args$jscomp$149$$)};$cljs$spec$gen$alpha$elements$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($args$jscomp$150$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($g__15767__auto___33400$$),$args$jscomp$150$$)};
$cljs$spec$gen$alpha$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($args$jscomp$153$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($g__15767__auto___33427$$),$args$jscomp$153$$)};$cljs$spec$gen$alpha$such_that$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($args$jscomp$154$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($g__15767__auto___33446$$),$args$jscomp$154$$)};
$cljs$spec$gen$alpha$return$0$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($args$jscomp$157$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($g__15767__auto___33474$$),$args$jscomp$157$$)};$cljs$spec$gen$alpha$large_integer_STAR_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($args$jscomp$158$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($g__15767__auto___33484$$),$args$jscomp$158$$)};
$cljs$spec$gen$alpha$any_printable$$=function($var_args$jscomp$564$$){for(var $args__5755__auto__$jscomp$87$$=[],$len__5749__auto___33532$$=arguments.length,$i__5750__auto___33533$$=0;;)if($i__5750__auto___33533$$<$len__5749__auto___33532$$)$args__5755__auto__$jscomp$87$$.push(arguments[$i__5750__auto___33533$$]),$i__5750__auto___33533$$+=1;else break;return $APP.$cljs$core$_deref$$($g__15780__auto___33530$$)};
$cljs$spec$gen$alpha$boolean$0$$=function($var_args$jscomp$565$$){for(var $args__5755__auto__$jscomp$88$$=[],$len__5749__auto___33544$$=arguments.length,$i__5750__auto___33545$$=0;;)if($i__5750__auto___33545$$<$len__5749__auto___33544$$)$args__5755__auto__$jscomp$88$$.push(arguments[$i__5750__auto___33545$$]),$i__5750__auto___33545$$+=1;else break;return $APP.$cljs$core$_deref$$($g__15780__auto___33536$$)};
$cljs$spec$gen$alpha$char$0$$=function($var_args$jscomp$566$$){for(var $args__5755__auto__$jscomp$89$$=[],$len__5749__auto___33551$$=arguments.length,$i__5750__auto___33552$$=0;;)if($i__5750__auto___33552$$<$len__5749__auto___33551$$)$args__5755__auto__$jscomp$89$$.push(arguments[$i__5750__auto___33552$$]),$i__5750__auto___33552$$+=1;else break;return $APP.$cljs$core$_deref$$($g__15780__auto___33547$$)};
$cljs$spec$gen$alpha$double$0$$=function($var_args$jscomp$570$$){for(var $args__5755__auto__$jscomp$93$$=[],$len__5749__auto___33592$$=arguments.length,$i__5750__auto___33593$$=0;;)if($i__5750__auto___33593$$<$len__5749__auto___33592$$)$args__5755__auto__$jscomp$93$$.push(arguments[$i__5750__auto___33593$$]),$i__5750__auto___33593$$+=1;else break;return $APP.$cljs$core$_deref$$($g__15780__auto___33585$$)};
$cljs$spec$gen$alpha$keyword$$=function($var_args$jscomp$572$$){for(var $args__5755__auto__$jscomp$95$$=[],$len__5749__auto___33606$$=arguments.length,$i__5750__auto___33607$$=0;;)if($i__5750__auto___33607$$<$len__5749__auto___33606$$)$args__5755__auto__$jscomp$95$$.push(arguments[$i__5750__auto___33607$$]),$i__5750__auto___33607$$+=1;else break;return $APP.$cljs$core$_deref$$($g__15780__auto___33605$$)};
$cljs$spec$gen$alpha$keyword_ns$$=function($var_args$jscomp$573$$){for(var $args__5755__auto__$jscomp$96$$=[],$len__5749__auto___33611$$=arguments.length,$i__5750__auto___33612$$=0;;)if($i__5750__auto___33612$$<$len__5749__auto___33611$$)$args__5755__auto__$jscomp$96$$.push(arguments[$i__5750__auto___33612$$]),$i__5750__auto___33612$$+=1;else break;return $APP.$cljs$core$_deref$$($g__15780__auto___33610$$)};
$cljs$spec$gen$alpha$large_integer$$=function($var_args$jscomp$574$$){for(var $args__5755__auto__$jscomp$97$$=[],$len__5749__auto___33615$$=arguments.length,$i__5750__auto___33618$$=0;;)if($i__5750__auto___33618$$<$len__5749__auto___33615$$)$args__5755__auto__$jscomp$97$$.push(arguments[$i__5750__auto___33618$$]),$i__5750__auto___33618$$+=1;else break;return $APP.$cljs$core$_deref$$($g__15780__auto___33614$$)};
$cljs$spec$gen$alpha$simple_type_printable$$=function($var_args$jscomp$577$$){for(var $args__5755__auto__$jscomp$100$$=[],$len__5749__auto___33633$$=arguments.length,$i__5750__auto___33634$$=0;;)if($i__5750__auto___33634$$<$len__5749__auto___33633$$)$args__5755__auto__$jscomp$100$$.push(arguments[$i__5750__auto___33634$$]),$i__5750__auto___33634$$+=1;else break;return $APP.$cljs$core$_deref$$($g__15780__auto___33631$$)};
$cljs$spec$gen$alpha$string_alphanumeric$$=function($var_args$jscomp$580$$){for(var $args__5755__auto__$jscomp$103$$=[],$len__5749__auto___33652$$=arguments.length,$i__5750__auto___33653$$=0;;)if($i__5750__auto___33653$$<$len__5749__auto___33652$$)$args__5755__auto__$jscomp$103$$.push(arguments[$i__5750__auto___33653$$]),$i__5750__auto___33653$$+=1;else break;return $APP.$cljs$core$_deref$$($g__15780__auto___33647$$)};
$cljs$spec$gen$alpha$symbol$$=function($var_args$jscomp$581$$){for(var $args__5755__auto__$jscomp$104$$=[],$len__5749__auto___33661$$=arguments.length,$i__5750__auto___33662$$=0;;)if($i__5750__auto___33662$$<$len__5749__auto___33661$$)$args__5755__auto__$jscomp$104$$.push(arguments[$i__5750__auto___33662$$]),$i__5750__auto___33662$$+=1;else break;return $APP.$cljs$core$_deref$$($g__15780__auto___33657$$)};
$cljs$spec$gen$alpha$symbol_ns$$=function($var_args$jscomp$582$$){for(var $args__5755__auto__$jscomp$105$$=[],$len__5749__auto___33666$$=arguments.length,$i__5750__auto___33667$$=0;;)if($i__5750__auto___33667$$<$len__5749__auto___33666$$)$args__5755__auto__$jscomp$105$$.push(arguments[$i__5750__auto___33667$$]),$i__5750__auto___33667$$+=1;else break;return $APP.$cljs$core$_deref$$($g__15780__auto___33665$$)};
$cljs$spec$gen$alpha$uuid$$=function($var_args$jscomp$583$$){for(var $args__5755__auto__$jscomp$106$$=[],$len__5749__auto___33672$$=arguments.length,$i__5750__auto___33673$$=0;;)if($i__5750__auto___33673$$<$len__5749__auto___33672$$)$args__5755__auto__$jscomp$106$$.push(arguments[$i__5750__auto___33673$$]),$i__5750__auto___33673$$+=1;else break;return $APP.$cljs$core$_deref$$($g__15780__auto___33669$$)};
$cljs$spec$gen$alpha$qualified_QMARK_$$=function($ident$jscomp$1$$){return $APP.$cljs$core$namespace$$($ident$jscomp$1$$)!=null};
$cljs$spec$gen$alpha$gen_for_pred$$=function($pred$jscomp$40$$){return $APP.$cljs$core$set_QMARK_$$($pred$jscomp$40$$)?$cljs$spec$gen$alpha$elements$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$pred$jscomp$40$$])):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($cljs$spec$gen$alpha$gen_builtins$$),$pred$jscomp$40$$)};
$malli$generator$_generator$$=function($JSCompiler_temp$jscomp$481_this$$jscomp$485$$,$options$jscomp$295$$){if($JSCompiler_temp$jscomp$481_this$$jscomp$485$$!=null&&$JSCompiler_temp$jscomp$481_this$$jscomp$485$$.$malli$generator$Generator$_generator$arity$2$!=null)$JSCompiler_temp$jscomp$481_this$$jscomp$485$$=$JSCompiler_temp$jscomp$481_this$$jscomp$485$$.$malli$generator$Generator$_generator$arity$2$($JSCompiler_temp$jscomp$481_this$$jscomp$485$$,$options$jscomp$295$$);else{var $m__5372__auto__$jscomp$inline_3728_m__5374__auto__$jscomp$inline_3727$$=
$malli$generator$_generator$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$481_this$$jscomp$485$$==null?null:$JSCompiler_temp$jscomp$481_this$$jscomp$485$$)];if($m__5372__auto__$jscomp$inline_3728_m__5374__auto__$jscomp$inline_3727$$!=null)$JSCompiler_temp$jscomp$481_this$$jscomp$485$$=$m__5372__auto__$jscomp$inline_3728_m__5374__auto__$jscomp$inline_3727$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3728_m__5374__auto__$jscomp$inline_3727$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$481_this$$jscomp$485$$,
$options$jscomp$295$$):$m__5372__auto__$jscomp$inline_3728_m__5374__auto__$jscomp$inline_3727$$($JSCompiler_temp$jscomp$481_this$$jscomp$485$$,$options$jscomp$295$$);else if($m__5372__auto__$jscomp$inline_3728_m__5374__auto__$jscomp$inline_3727$$=$malli$generator$_generator$$._,$m__5372__auto__$jscomp$inline_3728_m__5374__auto__$jscomp$inline_3727$$!=null)$JSCompiler_temp$jscomp$481_this$$jscomp$485$$=$m__5372__auto__$jscomp$inline_3728_m__5374__auto__$jscomp$inline_3727$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_3728_m__5374__auto__$jscomp$inline_3727$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$481_this$$jscomp$485$$,$options$jscomp$295$$):$m__5372__auto__$jscomp$inline_3728_m__5374__auto__$jscomp$inline_3727$$($JSCompiler_temp$jscomp$481_this$$jscomp$485$$,$options$jscomp$295$$);else throw $APP.$cljs$core$missing_protocol$$("Generator.-generator",$JSCompiler_temp$jscomp$481_this$$jscomp$485$$);}return $JSCompiler_temp$jscomp$481_this$$jscomp$485$$};
$malli$generator$_child$$=function($schema$jscomp$81$$,$options$jscomp$296$$){return $APP.$cljs$core$first$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$81$$,$options$jscomp$296$$))};
$malli$generator$_child_gen$$=function($G__34935_schema$jscomp$82$$,$options$jscomp$297$$){$G__34935_schema$jscomp$82$$=$malli$generator$_child$$($G__34935_schema$jscomp$82$$,$options$jscomp$297$$);return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($G__34935_schema$jscomp$82$$,$options$jscomp$297$$):$malli$generator$generator$$($G__34935_schema$jscomp$82$$,$options$jscomp$297$$)};
$malli$generator$_never_gen$$=function($map__34940__$1_p__34939$$){$map__34940__$1_p__34939$$=$APP.$cljs$core$__destructure_map$$($map__34940__$1_p__34939$$);var $original_generator_schema$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34940__$1_p__34939$$,$cljs$cst$851$malli_DOT_generator_SLASH_original_generator_schema$$);return $APP.$cljs$core$with_meta$$($clojure$test$check$generators$sized$$(function(){var $JSCompiler_temp_const$jscomp$482$$=$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$;
var $G__34941$jscomp$inline_3730_JSCompiler_inline_result$jscomp$484$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;$G__34941$jscomp$inline_3730_JSCompiler_inline_result$jscomp$484$$=$APP.$cljs$core$truth_$$($original_generator_schema$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__34941$jscomp$inline_3730_JSCompiler_inline_result$jscomp$484$$,$APP.$cljs$cst$298$schema$$,$original_generator_schema$$):$G__34941$jscomp$inline_3730_JSCompiler_inline_result$jscomp$484$$;return $JSCompiler_temp_const$jscomp$482$$.call($malli$core$_fail_BANG_$$,
$cljs$cst$852$malli_DOT_generator_SLASH_unsatisfiable_schema$$,$G__34941$jscomp$inline_3730_JSCompiler_inline_result$jscomp$484$$)}),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$853$malli_DOT_generator_SLASH_never_gen$$,!0,$cljs$cst$851$malli_DOT_generator_SLASH_original_generator_schema$$,$original_generator_schema$$],null))};$malli$generator$_unreachable_gen_QMARK_$$=function($g$jscomp$102$$){return $APP.$cljs$core$boolean$0$$($cljs$cst$853$malli_DOT_generator_SLASH_never_gen$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($g$jscomp$102$$)))};
$malli$generator$_not_unreachable$$=function($g$jscomp$103$$){return $malli$generator$_unreachable_gen_QMARK_$$($g$jscomp$103$$)?null:$g$jscomp$103$$};$malli$generator$_unreachable$$=function($g$jscomp$104$$){return $malli$generator$_unreachable_gen_QMARK_$$($g$jscomp$104$$)?$g$jscomp$104$$:null};
$malli$generator$_min_max$$=function($gen_min_map__34971_schema$jscomp$83$$,$gen_max_options$jscomp$298$$){$gen_min_map__34971_schema$jscomp$83$$=$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$2$($gen_min_map__34971_schema$jscomp$83$$,$gen_max_options$jscomp$298$$);var $map__34971__$1_max$jscomp$49$$=$APP.$cljs$core$__destructure_map$$($gen_min_map__34971_schema$jscomp$83$$);$gen_min_map__34971_schema$jscomp$83$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34971__$1_max$jscomp$49$$,
$cljs$cst$854$gen_SLASH_min$$);$gen_max_options$jscomp$298$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34971__$1_max$jscomp$49$$,$cljs$cst$855$gen_SLASH_max$$);var $min$jscomp$49$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34971__$1_max$jscomp$49$$,$APP.$cljs$cst$338$min$$);$map__34971__$1_max$jscomp$49$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34971__$1_max$jscomp$49$$,$APP.$cljs$cst$339$max$$);$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($min$jscomp$49$$)?
$APP.$cljs$core$truth_$$($gen_min_map__34971_schema$jscomp$83$$)?$gen_min_map__34971_schema$jscomp$83$$<$min$jscomp$49$$:$gen_min_map__34971_schema$jscomp$83$$:$min$jscomp$49$$)&&$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$856$malli_DOT_generator_SLASH_invalid_property$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$302$key$$,$cljs$cst$854$gen_SLASH_min$$,$APP.$cljs$cst$260$value$$,$gen_min_map__34971_schema$jscomp$83$$,$APP.$cljs$cst$338$min$$,$min$jscomp$49$$],
null));$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__34971__$1_max$jscomp$49$$)?$APP.$cljs$core$truth_$$($gen_max_options$jscomp$298$$)?$gen_max_options$jscomp$298$$>$map__34971__$1_max$jscomp$49$$:$gen_max_options$jscomp$298$$:$map__34971__$1_max$jscomp$49$$)&&$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$856$malli_DOT_generator_SLASH_invalid_property$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$302$key$$,$cljs$cst$855$gen_SLASH_max$$,$APP.$cljs$cst$260$value$$,
$gen_min_map__34971_schema$jscomp$83$$,$APP.$cljs$cst$339$max$$,$min$jscomp$49$$],null));return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,$APP.$cljs$core$truth_$$($gen_min_map__34971_schema$jscomp$83$$)?$gen_min_map__34971_schema$jscomp$83$$:$min$jscomp$49$$,$APP.$cljs$cst$339$max$$,$APP.$cljs$core$truth_$$($gen_max_options$jscomp$298$$)?$gen_max_options$jscomp$298$$:$map__34971__$1_max$jscomp$49$$],null)};
$malli$generator$gen_fmap$$=function($f$jscomp$467$$,$gen$jscomp$26$$){var $or__5025__auto__$jscomp$156$$=$malli$generator$_unreachable$$($gen$jscomp$26$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$156$$)?$or__5025__auto__$jscomp$156$$:$clojure$test$check$generators$fmap$$($f$jscomp$467$$,$gen$jscomp$26$$)};
$malli$generator$gen_fcat$$=function($gen$jscomp$27$$){return $malli$generator$gen_fmap$$(function($p1__34993_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,$p1__34993_SHARP_$$)},$gen$jscomp$27$$)};
$malli$generator$gen_tuple$$=function($gens$jscomp$2$$){var $or__5025__auto__$jscomp$157$$=$APP.$cljs$core$some$$($malli$generator$_unreachable$$,$gens$jscomp$2$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$157$$)?$or__5025__auto__$jscomp$157$$:$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$generators$tuple$$,$gens$jscomp$2$$)};
$malli$generator$gen_maybe$$=function($g$jscomp$105$$){return $malli$generator$_unreachable_gen_QMARK_$$($g$jscomp$105$$)?$malli$generator$nil_gen$$:$clojure$test$check$generators$one_of$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$malli$generator$nil_gen$$,$g$jscomp$105$$],null))};
$malli$generator$gen_double$$=function($opts$jscomp$212$$){return $clojure$test$check$generators$double_STAR_$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($malli$generator$double_default$$,$opts$jscomp$212$$),$APP.$cljs$cst$338$min$$,function($p1__35004_SHARP_$$){return $p1__35004_SHARP_$$==null?null:$p1__35004_SHARP_$$}),$APP.$cljs$cst$339$max$$,function($p1__35005_SHARP_$$){return $p1__35005_SHARP_$$==
null?null:$p1__35005_SHARP_$$}))};
$malli$generator$gen_vector$$=function($map__35016__$1_max$jscomp$50_p__35015$$,$g$jscomp$106$$){$map__35016__$1_max$jscomp$50_p__35015$$=$APP.$cljs$core$__destructure_map$$($map__35016__$1_max$jscomp$50_p__35015$$);var $min$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35016__$1_max$jscomp$50_p__35015$$,$APP.$cljs$cst$338$min$$);$map__35016__$1_max$jscomp$50_p__35015$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35016__$1_max$jscomp$50_p__35015$$,$APP.$cljs$cst$339$max$$);
return $malli$generator$_unreachable_gen_QMARK_$$($g$jscomp$106$$)?($APP.$cljs$core$truth_$$($min$jscomp$50$$)?$min$jscomp$50$$:0)===0?$clojure$test$check$generators$return$0$$($APP.$cljs$core$PersistentVector$EMPTY$$):$g$jscomp$106$$:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($min$jscomp$50$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($min$jscomp$50$$,$map__35016__$1_max$jscomp$50_p__35015$$):$min$jscomp$50$$)?$clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$2$($g$jscomp$106$$,
$min$jscomp$50$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($min$jscomp$50$$)?$map__35016__$1_max$jscomp$50_p__35015$$:$min$jscomp$50$$)?$clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$3$($g$jscomp$106$$,$min$jscomp$50$$,$map__35016__$1_max$jscomp$50_p__35015$$):$APP.$cljs$core$truth_$$($min$jscomp$50$$)?$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($clojure$test$check$generators$sized$$(function($p1__35012_SHARP_$$){return $clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$3$($g$jscomp$106$$,
$min$jscomp$50$$,$min$jscomp$50$$+$p1__35012_SHARP_$$)}),$cljs$cst$859$malli_DOT_generator_SLASH_generator_ast$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$860$op$$,$cljs$cst$861$vector_min$$,$cljs$cst$862$generator$$,$g$jscomp$106$$,$APP.$cljs$cst$338$min$$,$min$jscomp$50$$],null)):$APP.$cljs$core$truth_$$($map__35016__$1_max$jscomp$50_p__35015$$)?$clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$3$($g$jscomp$106$$,0,$map__35016__$1_max$jscomp$50_p__35015$$):$clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$1$($g$jscomp$106$$)};
$malli$generator$gen_vector_distinct_by$$=function($schema$jscomp$85$$,$map__35072__$1_p__35070$$,$f$jscomp$468$$,$g$jscomp$107$$){$map__35072__$1_p__35070$$=$APP.$cljs$core$__destructure_map$$($map__35072__$1_p__35070$$);var $min$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35072__$1_p__35070$$,$APP.$cljs$cst$338$min$$);return $malli$generator$_unreachable_gen_QMARK_$$($g$jscomp$107$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$cljs$core$truth_$$($min$jscomp$51$$)?
$min$jscomp$51$$:0)?$clojure$test$check$generators$return$0$$($APP.$cljs$core$PersistentVector$EMPTY$$):$g$jscomp$107$$:$clojure$test$check$generators$vector_distinct_by$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$468$$,$g$jscomp$107$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($min$jscomp$51$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($min$jscomp$51$$,$APP.$cljs$core$max$$):$min$jscomp$51$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$775$num_elements$$,$min$jscomp$51$$],null):$APP.$clojure$set$rename_keys$$($map__35072__$1_p__35070$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,$cljs$cst$776$min_elements$$,$APP.$cljs$cst$339$max$$,$cljs$cst$777$max_elements$$],null)),$cljs$cst$772$ex_fn$$,function($p1__35053_SHARP_$$){return $malli$core$_exception$$($cljs$cst$863$malli_DOT_generator_SLASH_distinct_generator_failure$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__35053_SHARP_$$,
$APP.$cljs$cst$298$schema$$,$schema$jscomp$85$$))}))};$malli$generator$_coll_gen$cljs$0core$0IFn$0_invoke$0arity$03$$=function($schema$jscomp$88$$,$f$jscomp$469$$,$options$jscomp$302$$){return $malli$generator$gen_fmap$$($f$jscomp$469$$,$malli$generator$gen_vector$$($malli$generator$_min_max$$($schema$jscomp$88$$,$options$jscomp$302$$),$malli$generator$_child_gen$$($schema$jscomp$88$$,$options$jscomp$302$$)))};
$malli$generator$_coll_distinct_gen$$=function($JSCompiler_inline_result$jscomp$485_schema$jscomp$90$$,$g$jscomp$inline_3734_options$jscomp$303$$){var $m$jscomp$inline_3733$$=$malli$generator$_min_max$$($JSCompiler_inline_result$jscomp$485_schema$jscomp$90$$,$g$jscomp$inline_3734_options$jscomp$303$$);$g$jscomp$inline_3734_options$jscomp$303$$=$malli$generator$_child_gen$$($JSCompiler_inline_result$jscomp$485_schema$jscomp$90$$,$g$jscomp$inline_3734_options$jscomp$303$$);$JSCompiler_inline_result$jscomp$485_schema$jscomp$90$$=
$malli$generator$gen_vector_distinct_by$$($JSCompiler_inline_result$jscomp$485_schema$jscomp$90$$,$m$jscomp$inline_3733$$,$APP.$cljs$core$identity$$,$g$jscomp$inline_3734_options$jscomp$303$$);return $malli$generator$gen_fmap$$($APP.$cljs$core$set$$,$JSCompiler_inline_result$jscomp$485_schema$jscomp$90$$)};
$malli$generator$__GT_such_that_opts$$=function($schema$jscomp$91$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$773$max_tries$$,100,$cljs$cst$772$ex_fn$$,function($p1__35171_SHARP_$$){return $malli$core$_exception$$($cljs$cst$864$malli_DOT_generator_SLASH_such_that_failure$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__35171_SHARP_$$,$APP.$cljs$cst$298$schema$$,$schema$jscomp$91$$))}],null)};
$malli$generator$gen_such_that$$=function($schema$jscomp$92$$,$pred$jscomp$41$$,$gen$jscomp$28$$){var $or__5025__auto__$jscomp$160$$=$malli$generator$_unreachable$$($gen$jscomp$28$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$160$$)?$or__5025__auto__$jscomp$160$$:$clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$3$($pred$jscomp$41$$,$gen$jscomp$28$$,$malli$generator$__GT_such_that_opts$$($schema$jscomp$92$$))};
$malli$generator$gen_one_of$$=function($options$jscomp$305$$,$gs$jscomp$1_temp__5827__auto__$jscomp$16$$){$gs$jscomp$1_temp__5827__auto__$jscomp$16$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($malli$generator$_not_unreachable$$),$gs$jscomp$1_temp__5827__auto__$jscomp$16$$));return $gs$jscomp$1_temp__5827__auto__$jscomp$16$$==null?$malli$generator$_never_gen$$($options$jscomp$305$$):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($gs$jscomp$1_temp__5827__auto__$jscomp$16$$))?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($gs$jscomp$1_temp__5827__auto__$jscomp$16$$,0):$clojure$test$check$generators$one_of$$($gs$jscomp$1_temp__5827__auto__$jscomp$16$$)};
$malli$generator$_seqable_gen$$=function($schema$jscomp$94$$,$options$jscomp$306$$){var $map__35198_map__35198__$1$$=$malli$generator$_min_max$$($schema$jscomp$94$$,$options$jscomp$306$$);$map__35198_map__35198__$1$$=$APP.$cljs$core$__destructure_map$$($map__35198_map__35198__$1$$);var $min$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35198_map__35198__$1$$,$APP.$cljs$cst$338$min$$),$el$jscomp$1$$=$malli$generator$_child$$($schema$jscomp$94$$,$options$jscomp$306$$);return $malli$generator$gen_one_of$$($options$jscomp$306$$,
function(){var $G__35199$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$(function(){var $G__35200$$=$APP.$cljs$core$PersistentVector$EMPTY$$;return $min$jscomp$52$$==null||$min$jscomp$52$$===0?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__35200$$,$malli$generator$nil_gen$$):$G__35200$$}(),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__35190_SHARP_$$){return $malli$generator$_coll_gen$cljs$0core$0IFn$0_invoke$0arity$03$$($schema$jscomp$94$$,
$p1__35190_SHARP_$$,$options$jscomp$306$$)}),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$identity$$,$APP.$cljs$core$vec$$,$cljs$core$eduction$$,function($p1__35191_SHARP_$$){return $APP.$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__35191_SHARP_$$)}],null)),$malli$generator$_coll_distinct_gen$$($schema$jscomp$94$$,$options$jscomp$306$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$498$tuple$$,
$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($el$jscomp$1$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$APP.$cljs$core$count$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($el$jscomp$1$$)))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__35199$$,function(){var $v$jscomp$208_vec__35201$$=$malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($el$jscomp$1$$),$G__35204_k$jscomp$431$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$208_vec__35201$$,
0,null);$v$jscomp$208_vec__35201$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$208_vec__35201$$,1,null);var $JSCompiler_temp_const$jscomp$487$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$or__5025__auto__$jscomp$inline_3736$$=$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$94$$);$G__35204_k$jscomp$431$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$JSCompiler_temp_const$jscomp$487$$,[$cljs$cst$463$map_of$$,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_3736$$)?
$or__5025__auto__$jscomp$inline_3736$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$G__35204_k$jscomp$431$$,$v$jscomp$208_vec__35201$$],null);return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35204_k$jscomp$431$$,$options$jscomp$306$$):$malli$generator$generator$$($G__35204_k$jscomp$431$$,$options$jscomp$306$$)}()):$G__35199$$}())};
$malli$generator$_or_gen$$=function($schema$jscomp$95$$,$options$jscomp$307$$){return $malli$generator$gen_one_of$$($options$jscomp$307$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__35207_SHARP_$$){return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__35207_SHARP_$$,$options$jscomp$307$$):$malli$generator$generator$$($p1__35207_SHARP_$$,$options$jscomp$307$$)},$malli$core$children$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$95$$,
$options$jscomp$307$$)))};
$malli$generator$_merge_keyword_dispatch_map_into_entries$$=function($schema$jscomp$96$$){var $dispatch$jscomp$3$$=$cljs$cst$532$dispatch$$.$cljs$core$IFn$_invoke$arity$1$($APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$96$$));return $dispatch$jscomp$3$$ instanceof $APP.$cljs$core$Keyword$$?$malli$util$transform_entries$cljs$0core$0IFn$0_invoke$0arity$03$$($schema$jscomp$96$$,function($p1__35211_SHARP_$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__35214$$){var $k$jscomp$432$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__35214$$,
0,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$379$malli_DOT_core_SLASH_default$$,$k$jscomp$432$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p__35214$$,2,$malli$util$merge$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$dispatch$jscomp$3$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,null,$k$jscomp$432$$],null)],null)],null)):$p__35214$$},$p1__35211_SHARP_$$)},$APP.$malli$core$options$cljs$0core$0IFn$0_invoke$0arity$02$$($schema$jscomp$96$$)):$schema$jscomp$96$$};
$malli$generator$_multi_gen$$=function($schema$jscomp$97$$,$options$jscomp$308$$){return $malli$generator$gen_one_of$$($options$jscomp$308$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($G__35227_p1__35224_SHARP_$$){$G__35227_p1__35224_SHARP_$$=$APP.$cljs$core$last$$($G__35227_p1__35224_SHARP_$$);return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35227_p1__35224_SHARP_$$,$options$jscomp$308$$):
$malli$generator$generator$$($G__35227_p1__35224_SHARP_$$,$options$jscomp$308$$)},$malli$core$entries$$.$cljs$core$IFn$_invoke$arity$2$($malli$generator$_merge_keyword_dispatch_map_into_entries$$($schema$jscomp$97$$),$options$jscomp$308$$)))};
$malli$generator$_build_map$$=function($kvs$jscomp$6$$){return $APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$70$$,$p__35230_v$jscomp$209$$){var $k$jscomp$433$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__35230_v$jscomp$209$$,0,null);$p__35230_v$jscomp$209$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__35230_v$jscomp$209$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$433$$,
$cljs$cst$379$malli_DOT_core_SLASH_default$$)&&$APP.$cljs$core$map_QMARK_$$($p__35230_v$jscomp$209$$)?$APP.$cljs$core$reduce_kv$$($APP.$cljs$core$assoc_BANG_$$,$acc$jscomp$70$$,$p__35230_v$jscomp$209$$):$k$jscomp$433$$==null?$acc$jscomp$70$$:$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$70$$,$k$jscomp$433$$,$p__35230_v$jscomp$209$$)},$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$kvs$jscomp$6$$))};
$malli$generator$_entry_gen$$=function($p__35239_s$jscomp$366$$,$G__35246_options$jscomp$309$$){var $k$jscomp$434$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__35239_s$jscomp$366$$,0,null);$p__35239_s$jscomp$366$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__35239_s$jscomp$366$$,1,null);$G__35246_options$jscomp$309$$=$malli$generator$gen_fmap$$(function($p1__35238_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$k$jscomp$434$$,$p1__35238_SHARP_$$],null)},$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($p__35239_s$jscomp$366$$,$G__35246_options$jscomp$309$$):$malli$generator$generator$$($p__35239_s$jscomp$366$$,$G__35246_options$jscomp$309$$));return $APP.$cljs$core$truth_$$($APP.$cljs$cst$450$optional$$.$cljs$core$IFn$_invoke$arity$1$($APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($p__35239_s$jscomp$366$$)))?
$malli$generator$gen_maybe$$($G__35246_options$jscomp$309$$):$G__35246_options$jscomp$309$$};$malli$generator$_map_gen$$=function($schema$jscomp$98$$,$options$jscomp$310$$){return $malli$generator$gen_fmap$$($malli$generator$_build_map$$,$malli$generator$gen_tuple$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__35250_SHARP_$$){return $malli$generator$_entry_gen$$($p1__35250_SHARP_$$,$options$jscomp$310$$)},$malli$core$entries$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$98$$))))};
$malli$generator$_map_of_gen$$=function($schema$jscomp$99$$,$options$jscomp$311$$){return $malli$generator$gen_fmap$$(function($p1__35258_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$p1__35258_SHARP_$$)},$malli$generator$gen_vector_distinct_by$$($schema$jscomp$99$$,$malli$generator$_min_max$$($schema$jscomp$99$$,$options$jscomp$311$$),function($p1__35256_SHARP_$$){return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__35256_SHARP_$$,
0)},$malli$generator$gen_tuple$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__35255_SHARP_$$){return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__35255_SHARP_$$,$options$jscomp$311$$):$malli$generator$generator$$($p1__35255_SHARP_$$,$options$jscomp$311$$)},$malli$core$children$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$99$$,$options$jscomp$311$$)))))};
$malli$generator$_identify_ref_schema$$=function($schema$jscomp$100$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$571$scope$$,$malli$registry$_schemas$$($malli$core$_registry$cljs$0core$0IFn$0_invoke$0arity$01$$($malli$core$_options$$($schema$jscomp$100$$))),$APP.$cljs$cst$725$name$$,$malli$core$_ref$$($schema$jscomp$100$$)],null)};
$malli$generator$_ref_gen$$=function($G__35275_schema$jscomp$101$$,$options$jscomp$312$$){var $ref_id$$=$malli$generator$_identify_ref_schema$$($G__35275_schema$jscomp$101$$),$or__5025__auto__$jscomp$162$$=$APP.$cljs$core$force$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$312$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$865$malli_DOT_generator_SLASH_rec_gen$$,$ref_id$$],null)));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$162$$))return $or__5025__auto__$jscomp$162$$;
var $scalar_ref_gen$$=new $APP.$cljs$core$Delay$$(function(){return $malli$generator$_never_gen$$($options$jscomp$312$$)}),$dschema$$=$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35275_schema$jscomp$101$$,null);$G__35275_schema$jscomp$101$$=function(){var $G__35280$$=$APP.$cljs$core$assoc_in$$($options$jscomp$312$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$865$malli_DOT_generator_SLASH_rec_gen$$,$ref_id$$],null),$scalar_ref_gen$$);
return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($dschema$$,$G__35280$$):$malli$generator$generator$$($dschema$$,$G__35280$$)}();return $cljs$core$_realized_QMARK_$$($scalar_ref_gen$$)?$clojure$test$check$generators$recursive_gen$$(function($G__35284_p1__35272_SHARP_$$){$G__35284_p1__35272_SHARP_$$=$APP.$cljs$core$assoc_in$$($options$jscomp$312$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$865$malli_DOT_generator_SLASH_rec_gen$$,$ref_id$$],null),$G__35284_p1__35272_SHARP_$$);return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($dschema$$,$G__35284_p1__35272_SHARP_$$):$malli$generator$generator$$($dschema$$,$G__35284_p1__35272_SHARP_$$)},$G__35275_schema$jscomp$101$$):$G__35275_schema$jscomp$101$$};
$malli$generator$__EQ__GT__gen$$=function($schema$jscomp$102$$,$options$jscomp$313$$){var $output_generator$$=function(){var $G__35292$$=$cljs$cst$564$output$$.$cljs$core$IFn$_invoke$arity$1$($malli$core$_function_info$$($schema$jscomp$102$$));return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35292$$,$options$jscomp$313$$):$malli$generator$generator$$($G__35292$$,$options$jscomp$313$$)}();return $clojure$test$check$generators$return$0$$($malli$core$_instrument$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$298$schema$$,$schema$jscomp$102$$],null),function(){function $G__35689$$($var_args$jscomp$587$$){var $G__35690__i__$jscomp$741$$=null;if(arguments.length>0){$G__35690__i__$jscomp$741$$=0;for(var $G__35690__a$$=Array(arguments.length-0);$G__35690__i__$jscomp$741$$<$G__35690__a$$.length;)$G__35690__a$$[$G__35690__i__$jscomp$741$$]=arguments[$G__35690__i__$jscomp$741$$+0],++$G__35690__i__$jscomp$741$$;$G__35690__i__$jscomp$741$$=new $APP.$cljs$core$IndexedSeq$$($G__35690__a$$,0,null)}return $G__35689__delegate$$.call(this,
$G__35690__i__$jscomp$741$$)}function $G__35689__delegate$$(){return $malli$generator$generate$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generate$cljs$0core$0IFn$0_invoke$0arity$02$$($output_generator$$,$options$jscomp$313$$):$malli$generator$generate$$($output_generator$$,$options$jscomp$313$$)}$G__35689$$.$cljs$lang$maxFixedArity$=0;$G__35689$$.$cljs$lang$applyTo$=function($_$jscomp$742_arglist__35691$$){$_$jscomp$742_arglist__35691$$=$APP.$cljs$core$seq$$($_$jscomp$742_arglist__35691$$);
return $G__35689__delegate$$($_$jscomp$742_arglist__35691$$)};$G__35689$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__35689__delegate$$;return $G__35689$$}()))};
$malli$generator$_function_gen$$=function($schema$jscomp$103$$,$options$jscomp$314$$){return $clojure$test$check$generators$return$0$$($malli$core$_instrument$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$298$schema$$,$schema$jscomp$103$$,$cljs$cst$573$gen$$,function($p1__35306_SHARP_$$){return $malli$generator$generate$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generate$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__35306_SHARP_$$,$options$jscomp$314$$):
$malli$generator$generate$$($p1__35306_SHARP_$$,$options$jscomp$314$$)}],null),null,$options$jscomp$314$$))};
$malli$generator$_re_entry_gen$$=function($e$jscomp$172_schema$jscomp$inline_3738$$,$G__35313$jscomp$inline_3740_options$jscomp$316$$){$e$jscomp$172_schema$jscomp$inline_3738$$=$APP.$cljs$core$vector_QMARK_$$($e$jscomp$172_schema$jscomp$inline_3738$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$172_schema$jscomp$inline_3738$$,2):$e$jscomp$172_schema$jscomp$inline_3738$$;$G__35313$jscomp$inline_3740_options$jscomp$316$$=$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?
$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$172_schema$jscomp$inline_3738$$,$G__35313$jscomp$inline_3740_options$jscomp$316$$):$malli$generator$generator$$($e$jscomp$172_schema$jscomp$inline_3738$$,$G__35313$jscomp$inline_3740_options$jscomp$316$$);return $APP.$cljs$core$not$$($malli$core$_regex_op_QMARK_$$($e$jscomp$172_schema$jscomp$inline_3738$$))?$malli$generator$gen_tuple$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$G__35313$jscomp$inline_3740_options$jscomp$316$$],null)):$G__35313$jscomp$inline_3740_options$jscomp$316$$};$malli$generator$_cat_gen$$=function($schema$jscomp$105$$,$options$jscomp$317$$){return $malli$generator$gen_fcat$$($malli$generator$gen_tuple$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__35323_SHARP_$$){return $malli$generator$_re_entry_gen$$($p1__35323_SHARP_$$,$options$jscomp$317$$)},$malli$core$children$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$105$$,$options$jscomp$317$$))))};
$malli$generator$_alt_gen$$=function($schema$jscomp$106$$,$options$jscomp$318$$){return $malli$generator$gen_one_of$$($options$jscomp$318$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__35326_SHARP_$$){return $malli$generator$_re_entry_gen$$($p1__35326_SHARP_$$,$options$jscomp$318$$)},$malli$core$children$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$106$$,$options$jscomp$318$$)))};
$malli$generator$_qualified_ident_gen$$=function($schema$jscomp$111$$,$mk_value_with_ns$$,$value_with_ns_gen_size$$,$pred$jscomp$42$$,$gen$jscomp$29$$){var $temp__5823__auto__$jscomp$71$$=$APP.$cljs$cst$394$namespace$$.$cljs$core$IFn$_invoke$arity$1$($APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$111$$));return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$71$$)?$malli$generator$gen_fmap$$(function($G__35352_k$jscomp$435$$){var $G__35351$$=$APP.$cljs$core$name$$($temp__5823__auto__$jscomp$71$$);
$G__35352_k$jscomp$435$$=$APP.$cljs$core$name$$($G__35352_k$jscomp$435$$);return $mk_value_with_ns$$.$cljs$core$IFn$_invoke$arity$2$?$mk_value_with_ns$$.$cljs$core$IFn$_invoke$arity$2$($G__35351$$,$G__35352_k$jscomp$435$$):$mk_value_with_ns$$($G__35351$$,$G__35352_k$jscomp$435$$)},$value_with_ns_gen_size$$):$malli$generator$gen_such_that$$($schema$jscomp$111$$,$pred$jscomp$42$$,$gen$jscomp$29$$)};
$malli$generator$gen_elements$$=function($es$jscomp$7$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($es$jscomp$7$$))?$clojure$test$check$generators$return$0$$($APP.$cljs$core$first$$($es$jscomp$7$$)):$clojure$test$check$generators$elements$$($es$jscomp$7$$)};
$malli$generator$double_gen$$=function($schema$jscomp$114$$,$options$jscomp$323$$){return $clojure$test$check$generators$double_STAR_$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([function(){var $props$jscomp$28$$=$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$114$$,$options$jscomp$323$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$778$infinite_QMARK_$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($props$jscomp$28$$,
$cljs$cst$857$gen_SLASH_infinite_QMARK_$$,!1),$cljs$cst$779$NaN_QMARK_$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($props$jscomp$28$$,$cljs$cst$858$gen_SLASH_NaN_QMARK_$$,!1)],null)}(),$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($malli$generator$_min_max$$($schema$jscomp$114$$,$options$jscomp$323$$),$APP.$cljs$cst$338$min$$,function($p1__35367_SHARP_$$){return $p1__35367_SHARP_$$==null?null:$p1__35367_SHARP_$$}),$APP.$cljs$cst$339$max$$,
function($p1__35368_SHARP_$$){return $p1__35368_SHARP_$$==null?null:$p1__35368_SHARP_$$})])))};
$malli$generator$_create_from_fmap$$=function($gen$jscomp$30$$,$props$jscomp$33_temp__5829__auto__$jscomp$6$$,$schema$jscomp$164$$,$options$jscomp$374$$){$props$jscomp$33_temp__5829__auto__$jscomp$6$$=$cljs$cst$871$gen_SLASH_fmap$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$33_temp__5829__auto__$jscomp$6$$);return $props$jscomp$33_temp__5829__auto__$jscomp$6$$==null?null:$clojure$test$check$generators$fmap$$($malli$core$eval$cljs$0core$0IFn$0_invoke$0arity$02$$($props$jscomp$33_temp__5829__auto__$jscomp$6$$,$APP.$cljs$core$truth_$$($options$jscomp$374$$)?
$options$jscomp$374$$:$APP.$malli$core$options$cljs$0core$0IFn$0_invoke$0arity$02$$($schema$jscomp$164$$)),$gen$jscomp$30$$)};
$malli$generator$_create$$=function($schema$jscomp$165$$,$options$jscomp$375$$){var $props$jscomp$34$$=$malli$impl$util$_merge$$($malli$core$type_properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$165$$),$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$165$$)),$gen$jscomp$31$$=function(){var $G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$=$APP.$cljs$core$contains_QMARK_$$($props$jscomp$34$$,
$cljs$cst$867$gen_SLASH_return$$)?$clojure$test$check$generators$return$0$$($cljs$cst$867$gen_SLASH_return$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$34$$)):null;if($APP.$cljs$core$truth_$$($G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$))return $G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$;
$G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$=$cljs$cst$868$gen_SLASH_elements$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$34$$);$G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$=
$G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$==null?null:$malli$generator$gen_elements$$($G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$);if($APP.$cljs$core$truth_$$($G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$))return $G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$;
$G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$=$cljs$cst$870$gen_SLASH_schema$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$34$$);$G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$=
$G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$==null?null:$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$,
$options$jscomp$375$$):$malli$generator$generator$$($G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$,$options$jscomp$375$$);if($APP.$cljs$core$truth_$$($G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$))return $G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$;
$G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$=$cljs$cst$869$gen_SLASH_gen$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$34$$);$G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$=
$APP.$cljs$core$truth_$$($G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$)?$G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$:$APP.$cljs$core$truth_$$($cljs$cst$868$gen_SLASH_elements$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$34$$))?
null:$malli$generator$_generator$$($schema$jscomp$165$$,$options$jscomp$375$$);return $APP.$cljs$core$truth_$$($G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$)?$G__35498$jscomp$inline_3766_G__35507$jscomp$inline_3770_or__5025__auto__$jscomp$167_or__5025__auto__$jscomp$inline_3775_or__5025__auto____$1$jscomp$20_or__5025__auto____$2$jscomp$6_or__5025__auto____$3$jscomp$3$$:
$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$872$malli_DOT_generator_SLASH_no_generator$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$873$options$$,$options$jscomp$375$$,$APP.$cljs$cst$298$schema$$,$schema$jscomp$165$$],null))}(),$or__5025__auto__$jscomp$166$$=$malli$generator$_create_from_fmap$$($gen$jscomp$31$$,$props$jscomp$34$$,$schema$jscomp$165$$,$options$jscomp$375$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$166$$)?$or__5025__auto__$jscomp$166$$:
$gen$jscomp$31$$};$malli$generator$generator$$=function($var_args$jscomp$588$$){switch(arguments.length){case 1:return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],null);case 2:return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$=function($_QMARK_schema$jscomp$123$$,$options$jscomp$376$$){return $APP.$cljs$core$truth_$$($cljs$cst$865$malli_DOT_generator_SLASH_rec_gen$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$376$$))?$malli$generator$_create$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$123$$,$options$jscomp$376$$),$options$jscomp$376$$):$malli$core$_cached$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$123$$,
$options$jscomp$376$$),$cljs$cst$862$generator$$,function($p1__35538_SHARP_$$){return $malli$generator$_create$$($p1__35538_SHARP_$$,$options$jscomp$376$$)})};
$malli$generator$generate$$=function($var_args$jscomp$589$$){switch(arguments.length){case 1:return $malli$generator$generate$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],null);case 2:return $malli$generator$generate$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$generator$generate$cljs$0core$0IFn$0_invoke$0arity$02$$=function($_QMARK_gen_or_schema$jscomp$1_gen$jscomp$32$$,$p__35556_seed$jscomp$12$$){var $map__35558__$1$$=$APP.$cljs$core$__destructure_map$$($p__35556_seed$jscomp$12$$);$p__35556_seed$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35558__$1$$,$cljs$cst$768$seed$$);var $size$jscomp$71$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__35558__$1$$,$APP.$cljs$cst$874$size$$,30);$_QMARK_gen_or_schema$jscomp$1_gen$jscomp$32$$=
$_QMARK_gen_or_schema$jscomp$1_gen$jscomp$32$$ instanceof $clojure$test$check$generators$Generator$$?$_QMARK_gen_or_schema$jscomp$1_gen$jscomp$32$$:$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($_QMARK_gen_or_schema$jscomp$1_gen$jscomp$32$$,$map__35558__$1$$);return $clojure$test$check$generators$call_gen$$($_QMARK_gen_or_schema$jscomp$1_gen$jscomp$32$$,$APP.$cljs$core$truth_$$($p__35556_seed$jscomp$12$$)?$clojure$test$check$random$make_java_util_splittable_random$$($p__35556_seed$jscomp$12$$):
$clojure$test$check$random$next_rng$$(),$size$jscomp$71$$).root};$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$=function($s$jscomp$367$$){return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$367$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$352$registry$$,$app$common$schema$registry$default_registry$$],null))};
$app$common$schema$generators$small_double$$=function($var_args$jscomp$596$$){for(var $args__5755__auto__$jscomp$109$$=[],$len__5749__auto___37008$$=arguments.length,$i__5750__auto___37009$$=0;;)if($i__5750__auto___37009$$<$len__5749__auto___37008$$)$args__5755__auto__$jscomp$109$$.push(arguments[$i__5750__auto___37009$$]),$i__5750__auto___37009$$+=1;else break;return $app$common$schema$generators$small_double$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$109$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$109$$.slice(0),
0,null):null)};
$app$common$schema$generators$small_double$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($min$jscomp$53_p__36974$$){var $map__36975__$1_max$jscomp$51$$=$APP.$cljs$core$__destructure_map$$($min$jscomp$53_p__36974$$);$min$jscomp$53_p__36974$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__36975__$1_max$jscomp$51$$,$APP.$cljs$cst$338$min$$,-100);$map__36975__$1_max$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__36975__$1_max$jscomp$51$$,$APP.$cljs$cst$339$max$$,100);
return $clojure$test$check$generators$fmap$$(function($p1__36971_SHARP_$$){return $APP.$app$common$math$precision$$($p1__36971_SHARP_$$,2)},$clojure$test$check$generators$double_STAR_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$338$min$$,$min$jscomp$53_p__36974$$,$APP.$cljs$cst$339$max$$,$map__36975__$1_max$jscomp$51$$,$cljs$cst$778$infinite_QMARK_$$,!1,$cljs$cst$779$NaN_QMARK_$$,!1],null)))};
$app$common$schema$generators$small_int$$=function($var_args$jscomp$597$$){for(var $args__5755__auto__$jscomp$110$$=[],$len__5749__auto___37011$$=arguments.length,$i__5750__auto___37012$$=0;;)if($i__5750__auto___37012$$<$len__5749__auto___37011$$)$args__5755__auto__$jscomp$110$$.push(arguments[$i__5750__auto___37012$$]),$i__5750__auto___37012$$+=1;else break;return $app$common$schema$generators$small_int$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$110$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$110$$.slice(0),
0,null):null)};
$app$common$schema$generators$small_int$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($min$jscomp$54_p__36988$$){var $map__36989__$1_max$jscomp$52$$=$APP.$cljs$core$__destructure_map$$($min$jscomp$54_p__36988$$);$min$jscomp$54_p__36988$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__36989__$1_max$jscomp$52$$,$APP.$cljs$cst$338$min$$,-100);$map__36989__$1_max$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__36989__$1_max$jscomp$52$$,$APP.$cljs$cst$339$max$$,100);
return $clojure$test$check$generators$large_integer_STAR_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,$min$jscomp$54_p__36988$$,$APP.$cljs$cst$339$max$$,$map__36989__$1_max$jscomp$52$$],null))};
$app$common$schema$generators$word_string$$=function(){var $$$__$1_$$__$2_$$__$3$$=$clojure$test$check$generators$resize$$(10,$clojure$test$check$generators$string_ascii$$);$$$__$1_$$__$2_$$__$3$$=$clojure$test$check$generators$fmap$$(function($v$jscomp$210$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$re_seq$$(/[A-Za-z]+/,$v$jscomp$210$$))},$$$__$1_$$__$2_$$__$3$$);$$$__$1_$$__$2_$$__$3$$=$clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$3$(function($v$jscomp$211$$){return $APP.$cljs$core$count$$($v$jscomp$211$$)>=
4},$$$__$1_$$__$2_$$__$3$$,100);return $clojure$test$check$generators$fmap$$($APP.$cuerdas$core$lower$$,$$$__$1_$$__$2_$$__$3$$)};$app$common$schema$generators$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($gens$jscomp$3$$){return $clojure$test$check$generators$one_of$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$gens$jscomp$3$$))};
$app$common$schema$generators$fmap$$=function($f$jscomp$476$$,$g$jscomp$114$$){return $clojure$test$check$generators$fmap$$($f$jscomp$476$$,$g$jscomp$114$$)};$app$common$schema$generators$filter$$=function($pred$jscomp$43$$,$gen$jscomp$34$$){return $clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$3$($pred$jscomp$43$$,$gen$jscomp$34$$,100)};
$app$common$schema$generators$mcat$$=function($f$jscomp$477$$,$g$jscomp$115$$){return $clojure$test$check$generators$bind$$($g$jscomp$115$$,$f$jscomp$477$$)};$app$common$schema$generators$tuple$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($opts$jscomp$217$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$generators$tuple$$,$opts$jscomp$217$$)};$app$common$schema$generators$set$$=function($g$jscomp$116$$){return $clojure$test$check$generators$set$$.$cljs$core$IFn$_invoke$arity$1$($g$jscomp$116$$)};
$malli$error$_pr_str$$=function($v$jscomp$214$$){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$214$$)};
$malli$error$_pred_min_max_error_fn$$=function($map__34903__$1_p__34902$$){$map__34903__$1_p__34902$$=$APP.$cljs$core$__destructure_map$$($map__34903__$1_p__34902$$);var $pred$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34903__$1_p__34902$$,$APP.$cljs$cst$351$pred$$),$message$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34903__$1_p__34902$$,$APP.$cljs$cst$141$message$$);return function($JSCompiler_inline_result$jscomp$10691_JSCompiler_temp$jscomp$10689_JSCompiler_temp$jscomp$10690_p__34904_value$jscomp$302$$){var $map__34905__$1_negated$$=
$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$10691_JSCompiler_temp$jscomp$10689_JSCompiler_temp$jscomp$10690_p__34904_value$jscomp$302$$),$map__34906_min$jscomp$55_schema$jscomp$168$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34905__$1_negated$$,$APP.$cljs$cst$298$schema$$);$JSCompiler_inline_result$jscomp$10691_JSCompiler_temp$jscomp$10689_JSCompiler_temp$jscomp$10690_p__34904_value$jscomp$302$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34905__$1_negated$$,
$APP.$cljs$cst$260$value$$);$map__34905__$1_negated$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34905__$1_negated$$,$cljs$cst$878$negated$$);$map__34906_min$jscomp$55_schema$jscomp$168$$=$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($map__34906_min$jscomp$55_schema$jscomp$168$$);var $map__34906__$1_max$jscomp$53$$=$APP.$cljs$core$__destructure_map$$($map__34906_min$jscomp$55_schema$jscomp$168$$);$map__34906_min$jscomp$55_schema$jscomp$168$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34906__$1_max$jscomp$53$$,
$APP.$cljs$cst$338$min$$);$map__34906__$1_max$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34906__$1_max$jscomp$53$$,$APP.$cljs$cst$339$max$$);if($APP.$cljs$core$not$$($pred$jscomp$44$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$44$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10691_JSCompiler_temp$jscomp$10689_JSCompiler_temp$jscomp$10690_p__34904_value$jscomp$302$$):$pred$jscomp$44$$($JSCompiler_inline_result$jscomp$10691_JSCompiler_temp$jscomp$10689_JSCompiler_temp$jscomp$10690_p__34904_value$jscomp$302$$)))$JSCompiler_inline_result$jscomp$10691_JSCompiler_temp$jscomp$10689_JSCompiler_temp$jscomp$10690_p__34904_value$jscomp$302$$=
$message$jscomp$44$$;else if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__34906_min$jscomp$55_schema$jscomp$168$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__34906_min$jscomp$55_schema$jscomp$168$$,$map__34906__$1_max$jscomp$53$$):$map__34906_min$jscomp$55_schema$jscomp$168$$))$JSCompiler_inline_result$jscomp$10691_JSCompiler_temp$jscomp$10689_JSCompiler_temp$jscomp$10690_p__34904_value$jscomp$302$$=["should be ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__34906_min$jscomp$55_schema$jscomp$168$$)].join("");
else{if($APP.$cljs$core$truth_$$($map__34906_min$jscomp$55_schema$jscomp$168$$)){var $fexpr__34916$jscomp$inline_11515$$=$APP.$cljs$core$truth_$$($map__34905__$1_negated$$)?$cljs$core$_GT__EQ_$$:$APP.$cljs$core$_LT_$$;$JSCompiler_inline_result$jscomp$10691_JSCompiler_temp$jscomp$10689_JSCompiler_temp$jscomp$10690_p__34904_value$jscomp$302$$=$fexpr__34916$jscomp$inline_11515$$.$cljs$core$IFn$_invoke$arity$2$?$fexpr__34916$jscomp$inline_11515$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10691_JSCompiler_temp$jscomp$10689_JSCompiler_temp$jscomp$10690_p__34904_value$jscomp$302$$,
$map__34906_min$jscomp$55_schema$jscomp$168$$):$fexpr__34916$jscomp$inline_11515$$($JSCompiler_inline_result$jscomp$10691_JSCompiler_temp$jscomp$10689_JSCompiler_temp$jscomp$10690_p__34904_value$jscomp$302$$,$map__34906_min$jscomp$55_schema$jscomp$168$$)}else $JSCompiler_inline_result$jscomp$10691_JSCompiler_temp$jscomp$10689_JSCompiler_temp$jscomp$10690_p__34904_value$jscomp$302$$=$map__34906_min$jscomp$55_schema$jscomp$168$$;$JSCompiler_inline_result$jscomp$10691_JSCompiler_temp$jscomp$10689_JSCompiler_temp$jscomp$10690_p__34904_value$jscomp$302$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10691_JSCompiler_temp$jscomp$10689_JSCompiler_temp$jscomp$10690_p__34904_value$jscomp$302$$)?["should be at least ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__34906_min$jscomp$55_schema$jscomp$168$$)].join(""):$APP.$cljs$core$truth_$$($map__34906__$1_max$jscomp$53$$)?["should be at most ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__34906__$1_max$jscomp$53$$)].join(""):$APP.$cljs$core$truth_$$($map__34905__$1_negated$$)?
$message$jscomp$44$$:null}return $JSCompiler_inline_result$jscomp$10691_JSCompiler_temp$jscomp$10689_JSCompiler_temp$jscomp$10690_p__34904_value$jscomp$302$$}};
$malli$error$_en_humanize_negation$$=function($p__34926$$,$options$jscomp$381$$){function $negated_QMARK_$$($p1__34923_SHARP_$$){return $APP.$goog$string$internal$startsWith$$($p1__34923_SHARP_$$,$prefix_35557$$)}function $remove_prefix$$($p1__34922_SHARP_$$){return $p1__34922_SHARP_$$.replace($prefix_35557$$,"")}var $map__34927__$1$$=$APP.$cljs$core$__destructure_map$$($p__34926$$),$schema$jscomp$169$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34927__$1$$,$APP.$cljs$cst$298$schema$$),
$negated$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34927__$1$$,$cljs$cst$878$negated$$);if($APP.$cljs$core$truth_$$($negated$jscomp$1$$)){var $G__34931_dschema$jscomp$1_or__5025__auto__$jscomp$168$$=function(){var $G__34933$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($map__34927__$1$$,$cljs$cst$878$negated$$);return $APP.$malli$error$error_message$cljs$0core$0IFn$0_invoke$0arity$02$$?$APP.$malli$error$error_message$cljs$0core$0IFn$0_invoke$0arity$02$$($G__34933$$,
$options$jscomp$381$$):$malli$error$error_message$$($G__34933$$,$options$jscomp$381$$)}();return $negated$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$negated$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__34931_dschema$jscomp$1_or__5025__auto__$jscomp$168$$):$negated$jscomp$1$$($G__34931_dschema$jscomp$1_or__5025__auto__$jscomp$168$$)}for(var $schema__$1$jscomp$5$$=$schema$jscomp$169$$;;){$G__34931_dschema$jscomp$1_or__5025__auto__$jscomp$168$$=function(){var $temp__5829__auto__$jscomp$7$$=function(){var $G__34959$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__34927__$1$$,$cljs$cst$878$negated$$,function($schema__$1$jscomp$6$$,$remove_prefix$jscomp$1$$,$negated_QMARK_$jscomp$1$$,$map__34927$jscomp$1$$,$map__34927__$1$jscomp$1$$,$error$jscomp$9$$,$schema$jscomp$170$$,$negated$jscomp$2$$,$prefix_35557$jscomp$1$$){return function($p1__34924_SHARP_$$){return $p1__34924_SHARP_$$==null?null:[$prefix_35557$jscomp$1$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__34924_SHARP_$$)].join("")}}($schema__$1$jscomp$5$$,
$remove_prefix$$,$negated_QMARK_$$,$p__34926$$,$map__34927__$1$$,$map__34927__$1$$,$schema$jscomp$169$$,$negated$jscomp$1$$,$prefix_35557$$));return $APP.$malli$error$error_message$cljs$0core$0IFn$0_invoke$0arity$02$$?$APP.$malli$error$error_message$cljs$0core$0IFn$0_invoke$0arity$02$$($G__34959$$,$options$jscomp$381$$):$malli$error$error_message$$($G__34959$$,$options$jscomp$381$$)}();if($temp__5829__auto__$jscomp$7$$==null)return null;if($negated_QMARK_$$($temp__5829__auto__$jscomp$7$$))return $remove_prefix$$($temp__5829__auto__$jscomp$7$$);
var $or__5025__auto__$jscomp$169$$=typeof $temp__5829__auto__$jscomp$7$$==="string"&&$APP.$goog$string$internal$startsWith$$($temp__5829__auto__$jscomp$7$$,"should not ")?$temp__5829__auto__$jscomp$7$$.replace("should not","should"):null;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$169$$)?$or__5025__auto__$jscomp$169$$:typeof $temp__5829__auto__$jscomp$7$$==="string"&&$APP.$goog$string$internal$startsWith$$($temp__5829__auto__$jscomp$7$$,"should ")?$temp__5829__auto__$jscomp$7$$.replace("should",
"should not"):null}();if($APP.$cljs$core$truth_$$($G__34931_dschema$jscomp$1_or__5025__auto__$jscomp$168$$))return $G__34931_dschema$jscomp$1_or__5025__auto__$jscomp$168$$;$G__34931_dschema$jscomp$1_or__5025__auto__$jscomp$168$$=$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$($schema__$1$jscomp$5$$,null);if($schema__$1$jscomp$5$$===$G__34931_dschema$jscomp$1_or__5025__auto__$jscomp$168$$)return null;$schema__$1$jscomp$5$$=$G__34931_dschema$jscomp$1_or__5025__auto__$jscomp$168$$}};
$malli$error$_forward_negation$$=function($G__34979$jscomp$inline_3779__QMARK_schema$jscomp$128_schema$jscomp$171$$,$negated$jscomp$3_p__34973$$,$G__34978_options$jscomp$382$$){var $map__34975__$1$$=$APP.$cljs$core$__destructure_map$$($negated$jscomp$3_p__34973$$);$negated$jscomp$3_p__34973$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34975__$1$$,$cljs$cst$878$negated$$);$G__34979$jscomp$inline_3779__QMARK_schema$jscomp$128_schema$jscomp$171$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($G__34979$jscomp$inline_3779__QMARK_schema$jscomp$128_schema$jscomp$171$$,
$G__34978_options$jscomp$382$$);$G__34979$jscomp$inline_3779__QMARK_schema$jscomp$128_schema$jscomp$171$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($map__34975__$1$$,$cljs$cst$878$negated$$),$APP.$cljs$cst$298$schema$$,$G__34979$jscomp$inline_3779__QMARK_schema$jscomp$128_schema$jscomp$171$$);$G__34978_options$jscomp$382$$=$APP.$malli$error$error_message$cljs$0core$0IFn$0_invoke$0arity$02$$?$APP.$malli$error$error_message$cljs$0core$0IFn$0_invoke$0arity$02$$($G__34979$jscomp$inline_3779__QMARK_schema$jscomp$128_schema$jscomp$171$$,
$G__34978_options$jscomp$382$$):$malli$error$error_message$$($G__34979$jscomp$inline_3779__QMARK_schema$jscomp$128_schema$jscomp$171$$,$G__34978_options$jscomp$382$$);return $negated$jscomp$3_p__34973$$.$cljs$core$IFn$_invoke$arity$1$?$negated$jscomp$3_p__34973$$.$cljs$core$IFn$_invoke$arity$1$($G__34978_options$jscomp$382$$):$negated$jscomp$3_p__34973$$($G__34978_options$jscomp$382$$)};
$APP.$malli$error$_maybe_localized$$=function($x$jscomp$827$$,$locale$$){return $APP.$cljs$core$map_QMARK_$$($x$jscomp$827$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$827$$,$locale$$):$x$jscomp$827$$};
$malli$error$_message$$=function($error$jscomp$16_or__5025__auto__$jscomp$170$$,$props$jscomp$35$$,$locale$jscomp$1$$,$JSCompiler_temp$jscomp$14041__QMARK_schema$jscomp$inline_14147_options$jscomp$388_options__$1$jscomp$59$$){$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$14041__QMARK_schema$jscomp$inline_14147_options$jscomp$388_options__$1$jscomp$59$$)||($JSCompiler_temp$jscomp$14041__QMARK_schema$jscomp$inline_14147_options$jscomp$388_options__$1$jscomp$59$$=$APP.$cljs$cst$298$schema$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$16_or__5025__auto__$jscomp$170$$),
$JSCompiler_temp$jscomp$14041__QMARK_schema$jscomp$inline_14147_options$jscomp$388_options__$1$jscomp$59$$=$APP.$malli$core$options$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$14041__QMARK_schema$jscomp$inline_14147_options$jscomp$388_options__$1$jscomp$59$$));if($APP.$cljs$core$truth_$$($props$jscomp$35$$)){var $fexpr__35206$jscomp$inline_11521_temp__5825__auto__$jscomp$inline_11520$$=$APP.$malli$error$_maybe_localized$$($APP.$cljs$cst$884$error_SLASH_fn$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$35$$),
$locale$jscomp$1$$);$APP.$cljs$core$truth_$$($fexpr__35206$jscomp$inline_11521_temp__5825__auto__$jscomp$inline_11520$$)?($fexpr__35206$jscomp$inline_11521_temp__5825__auto__$jscomp$inline_11520$$=$malli$core$eval$cljs$0core$0IFn$0_invoke$0arity$02$$($fexpr__35206$jscomp$inline_11521_temp__5825__auto__$jscomp$inline_11520$$,$JSCompiler_temp$jscomp$14041__QMARK_schema$jscomp$inline_14147_options$jscomp$388_options__$1$jscomp$59$$),$error$jscomp$16_or__5025__auto__$jscomp$170$$=$fexpr__35206$jscomp$inline_11521_temp__5825__auto__$jscomp$inline_11520$$.$cljs$core$IFn$_invoke$arity$2$?
$fexpr__35206$jscomp$inline_11521_temp__5825__auto__$jscomp$inline_11520$$.$cljs$core$IFn$_invoke$arity$2$($error$jscomp$16_or__5025__auto__$jscomp$170$$,$JSCompiler_temp$jscomp$14041__QMARK_schema$jscomp$inline_14147_options$jscomp$388_options__$1$jscomp$59$$):$fexpr__35206$jscomp$inline_11521_temp__5825__auto__$jscomp$inline_11520$$($error$jscomp$16_or__5025__auto__$jscomp$170$$,$JSCompiler_temp$jscomp$14041__QMARK_schema$jscomp$inline_14147_options$jscomp$388_options__$1$jscomp$59$$)):$error$jscomp$16_or__5025__auto__$jscomp$170$$=
null;return $APP.$cljs$core$truth_$$($error$jscomp$16_or__5025__auto__$jscomp$170$$)?$error$jscomp$16_or__5025__auto__$jscomp$170$$:$APP.$malli$error$_maybe_localized$$($APP.$cljs$cst$882$error_SLASH_message$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$35$$),$locale$jscomp$1$$)}return null};
$malli$error$error_message$$=function($var_args$jscomp$604$$){switch(arguments.length){case 1:return $APP.$malli$error$error_message$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],null);case 2:return $APP.$malli$error$error_message$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$malli$error$error_message$cljs$0core$0IFn$0_invoke$0arity$02$$=function($map__35385__$1_p__35383$$,$map__35386__$1_p__35384$$){$map__35385__$1_p__35383$$=$APP.$cljs$core$__destructure_map$$($map__35385__$1_p__35383$$);var $schema$jscomp$184$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35385__$1_p__35383$$,$APP.$cljs$cst$298$schema$$),$or__5025__auto____$6$jscomp$1_or__5025__auto____$7$jscomp$1_type$jscomp$228$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35385__$1_p__35383$$,
$APP.$cljs$cst$139$type$$);$map__35386__$1_p__35384$$=$APP.$cljs$core$__destructure_map$$($map__35386__$1_p__35384$$);var $errors$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__35386__$1_p__35384$$,$APP.$cljs$cst$570$errors$$,$malli$error$default_errors$$),$unknown$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__35386__$1_p__35384$$,$cljs$cst$895$unknown$$,!0),$locale$jscomp$3_or__5025__auto____$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35386__$1_p__35384$$,
$APP.$cljs$cst$888$locale$$),$default_locale$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__35386__$1_p__35384$$,$APP.$cljs$cst$889$default_locale$$,$APP.$cljs$cst$883$en$$),$or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$=$malli$error$_message$$($map__35385__$1_p__35383$$,$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$184$$),
$locale$jscomp$3_or__5025__auto____$8$$,$map__35386__$1_p__35384$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$))return $or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$;$or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$=
$malli$error$_message$$($map__35385__$1_p__35383$$,$malli$core$type_properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$184$$),$locale$jscomp$3_or__5025__auto____$8$$,$map__35386__$1_p__35384$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$))return $or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$;
$or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$=$malli$error$_message$$($map__35385__$1_p__35383$$,$errors$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$errors$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$6$jscomp$1_or__5025__auto____$7$jscomp$1_type$jscomp$228$$):$errors$jscomp$7$$($or__5025__auto____$6$jscomp$1_or__5025__auto____$7$jscomp$1_type$jscomp$228$$),
$locale$jscomp$3_or__5025__auto____$8$$,$map__35386__$1_p__35384$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$))return $or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$;$or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$=
$malli$error$_message$$($map__35385__$1_p__35383$$,function(){var $G__35389$$=$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$184$$);return $errors$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$errors$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($G__35389$$):$errors$jscomp$7$$($G__35389$$)}(),$locale$jscomp$3_or__5025__auto____$8$$,$map__35386__$1_p__35384$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$))return $or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$;
$or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$=$malli$error$_message$$($map__35385__$1_p__35383$$,$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$184$$),$default_locale$jscomp$1$$,$map__35386__$1_p__35384$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$))return $or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$;
$or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$=$malli$error$_message$$($map__35385__$1_p__35383$$,$malli$core$type_properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$184$$),$default_locale$jscomp$1$$,$map__35386__$1_p__35384$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$))return $or__5025__auto__$jscomp$175_or__5025__auto____$1$jscomp$21_or__5025__auto____$2$jscomp$7_or__5025__auto____$3$jscomp$4_or__5025__auto____$4$jscomp$3_or__5025__auto____$5$jscomp$1$$;
$or__5025__auto____$6$jscomp$1_or__5025__auto____$7$jscomp$1_type$jscomp$228$$=$malli$error$_message$$($map__35385__$1_p__35383$$,$errors$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$errors$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$6$jscomp$1_or__5025__auto____$7$jscomp$1_type$jscomp$228$$):$errors$jscomp$7$$($or__5025__auto____$6$jscomp$1_or__5025__auto____$7$jscomp$1_type$jscomp$228$$),$default_locale$jscomp$1$$,$map__35386__$1_p__35384$$);if($APP.$cljs$core$truth_$$($or__5025__auto____$6$jscomp$1_or__5025__auto____$7$jscomp$1_type$jscomp$228$$))return $or__5025__auto____$6$jscomp$1_or__5025__auto____$7$jscomp$1_type$jscomp$228$$;
$or__5025__auto____$6$jscomp$1_or__5025__auto____$7$jscomp$1_type$jscomp$228$$=$malli$error$_message$$($map__35385__$1_p__35383$$,function(){var $G__35396$$=$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$184$$);return $errors$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$errors$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($G__35396$$):$errors$jscomp$7$$($G__35396$$)}(),$default_locale$jscomp$1$$,$map__35386__$1_p__35384$$);if($APP.$cljs$core$truth_$$($or__5025__auto____$6$jscomp$1_or__5025__auto____$7$jscomp$1_type$jscomp$228$$))return $or__5025__auto____$6$jscomp$1_or__5025__auto____$7$jscomp$1_type$jscomp$228$$;
$locale$jscomp$3_or__5025__auto____$8$$=$APP.$cljs$core$truth_$$($unknown$$)?$malli$error$_message$$($map__35385__$1_p__35383$$,$errors$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$errors$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$880$malli_DOT_error_SLASH_unknown$$):$errors$jscomp$7$$($cljs$cst$880$malli_DOT_error_SLASH_unknown$$),$locale$jscomp$3_or__5025__auto____$8$$,$map__35386__$1_p__35384$$):$unknown$$;return $APP.$cljs$core$truth_$$($locale$jscomp$3_or__5025__auto____$8$$)?$locale$jscomp$3_or__5025__auto____$8$$:
$APP.$cljs$core$truth_$$($unknown$$)?$malli$error$_message$$($map__35385__$1_p__35383$$,$errors$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$errors$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$880$malli_DOT_error_SLASH_unknown$$):$errors$jscomp$7$$($cljs$cst$880$malli_DOT_error_SLASH_unknown$$),$default_locale$jscomp$1$$,$map__35386__$1_p__35384$$):$unknown$$};
$cljs$math$floor$$=function($a$jscomp$281$$){if($a$jscomp$281$$!=null)return Math.floor($a$jscomp$281$$);throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Unexpected Null passed to floor",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$516$fn$$,"floor"],null));};$cljs$math$round$$=function($a$jscomp$285$$){return isNaN($a$jscomp$285$$)?0:isFinite($a$jscomp$285$$)?Math.round($a$jscomp$285$$):Infinity===$a$jscomp$285$$?Number.MAX_SAFE_INTEGER:Number.MIN_SAFE_INTEGER};
$cljs$math$power_of_two$$=function($h$jscomp$inline_3789_n$jscomp$218$$){$h$jscomp$inline_3789_n$jscomp$218$$=$h$jscomp$inline_3789_n$jscomp$218$$+1023<<20&2146435072;var $a$jscomp$inline_3791_i$jscomp$inline_3793$$=new ArrayBuffer(8);new Float64Array($a$jscomp$inline_3791_i$jscomp$inline_3793$$);$a$jscomp$inline_3791_i$jscomp$inline_3793$$=new Uint32Array($a$jscomp$inline_3791_i$jscomp$inline_3793$$);$a$jscomp$inline_3791_i$jscomp$inline_3793$$[$cljs$math$LO$$]=0;$a$jscomp$inline_3791_i$jscomp$inline_3793$$[$cljs$math$HI$$]=
$h$jscomp$inline_3789_n$jscomp$218$$};
$goog$date$Interval$$=function($opt_years$$,$opt_months$$,$opt_days$$,$opt_hours$jscomp$1$$,$opt_minutes$$,$opt_seconds$jscomp$1$$){typeof $opt_years$$==="string"?(this.$years$=$opt_years$$==$goog$date$Interval$YEARS$$?$opt_months$$:0,this.$months$=$opt_years$$==$goog$date$Interval$MONTHS$$?$opt_months$$:0,this.$days$=$opt_years$$==$goog$date$Interval$DAYS$$?$opt_months$$:0,this.$hours$=$opt_years$$==$goog$date$Interval$HOURS$$?$opt_months$$:0,this.$minutes$=$opt_years$$==$goog$date$Interval$MINUTES$$?
$opt_months$$:0,this.$seconds$=$opt_years$$==$goog$date$Interval$SECONDS$$?$opt_months$$:0):(this.$years$=$opt_years$$||0,this.$months$=$opt_months$$||0,this.$days$=$opt_days$$||0,this.$hours$=$opt_hours$jscomp$1$$||0,this.$minutes$=$opt_minutes$$||0,this.$seconds$=$opt_seconds$jscomp$1$$||0)};
$goog$date$Date$$=function($expectedDate_opt_year$$,$opt_month$jscomp$1$$,$opt_date$jscomp$1$$){typeof $expectedDate_opt_year$$==="number"?(this.$date$=$JSCompiler_StaticMethods_buildDate_$$($expectedDate_opt_year$$,$opt_month$jscomp$1$$||0,$opt_date$jscomp$1$$||1),$JSCompiler_StaticMethods_maybeFixDst_$$(this,$opt_date$jscomp$1$$||1)):$goog$isObject$$($expectedDate_opt_year$$)?(this.$date$=$JSCompiler_StaticMethods_buildDate_$$($expectedDate_opt_year$$.getFullYear(),$expectedDate_opt_year$$.getMonth(),
$expectedDate_opt_year$$.getDate()),$JSCompiler_StaticMethods_maybeFixDst_$$(this,$expectedDate_opt_year$$.getDate())):(this.$date$=new Date(Date.now()),$expectedDate_opt_year$$=this.$date$.getDate(),this.$date$.setHours(0),this.$date$.setMinutes(0),this.$date$.setSeconds(0),this.$date$.setMilliseconds(0),$JSCompiler_StaticMethods_maybeFixDst_$$(this,$expectedDate_opt_year$$))};
$JSCompiler_StaticMethods_buildDate_$$=function($fullYear$$,$d$jscomp$160_month$jscomp$7$$,$date$jscomp$10$$){$d$jscomp$160_month$jscomp$7$$=new Date($fullYear$$,$d$jscomp$160_month$jscomp$7$$,$date$jscomp$10$$);$fullYear$$>=0&&$fullYear$$<100&&$d$jscomp$160_month$jscomp$7$$.setFullYear($d$jscomp$160_month$jscomp$7$$.getFullYear()-1900);return $d$jscomp$160_month$jscomp$7$$};
$JSCompiler_StaticMethods_maybeFixDst_$$=function($JSCompiler_StaticMethods_maybeFixDst_$self$$,$expected$jscomp$1$$){$JSCompiler_StaticMethods_maybeFixDst_$self$$.getDate()!=$expected$jscomp$1$$&&$JSCompiler_StaticMethods_maybeFixDst_$self$$.$date$.setUTCHours($JSCompiler_StaticMethods_maybeFixDst_$self$$.$date$.getUTCHours()+($JSCompiler_StaticMethods_maybeFixDst_$self$$.getDate()<$expected$jscomp$1$$?1:-1))};
$goog$date$DateTime$$=function($opt_year$jscomp$1$$,$opt_month$jscomp$2$$,$opt_date$jscomp$2$$,$opt_hours$jscomp$2$$,$opt_minutes$jscomp$1$$,$opt_seconds$jscomp$2$$,$opt_milliseconds$$){this.$date$=typeof $opt_year$jscomp$1$$==="number"?new Date($opt_year$jscomp$1$$,$opt_month$jscomp$2$$||0,$opt_date$jscomp$2$$||1,$opt_hours$jscomp$2$$||0,$opt_minutes$jscomp$1$$||0,$opt_seconds$jscomp$2$$||0,$opt_milliseconds$$||0):new Date($opt_year$jscomp$1$$&&$opt_year$jscomp$1$$.getTime?$opt_year$jscomp$1$$.getTime():
Date.now())};
$goog$date$UtcDateTime$$=function($opt_year$jscomp$2_timestamp$jscomp$1$$,$opt_month$jscomp$3$$,$opt_date$jscomp$3$$,$opt_hours$jscomp$3$$,$opt_minutes$jscomp$2$$,$opt_seconds$jscomp$3$$,$opt_milliseconds$jscomp$1$$){$opt_year$jscomp$2_timestamp$jscomp$1$$=typeof $opt_year$jscomp$2_timestamp$jscomp$1$$==="number"?Date.UTC($opt_year$jscomp$2_timestamp$jscomp$1$$,$opt_month$jscomp$3$$||0,$opt_date$jscomp$3$$||1,$opt_hours$jscomp$3$$||0,$opt_minutes$jscomp$2$$||0,$opt_seconds$jscomp$3$$||0,$opt_milliseconds$jscomp$1$$||
0):$opt_year$jscomp$2_timestamp$jscomp$1$$?$opt_year$jscomp$2_timestamp$jscomp$1$$.getTime():Date.now();this.$date$=new Date($opt_year$jscomp$2_timestamp$jscomp$1$$)};
$malli$transform$_string__GT_long$$=function($x$jscomp$848$$){if(typeof $x$jscomp$848$$==="string")try{var $x_SINGLEQUOTE_$jscomp$2$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$re_find$$(/\D/,$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$848$$,1)))?NaN:parseInt($x$jscomp$848$$,10);return $APP.$cljs$core$truth_$$(isNaN($x_SINGLEQUOTE_$jscomp$2$$))?$x$jscomp$848$$:$x_SINGLEQUOTE_$jscomp$2$$>Number.MAX_SAFE_INTEGER?$x$jscomp$848$$:$x_SINGLEQUOTE_$jscomp$2$$<Number.MIN_SAFE_INTEGER?$x$jscomp$848$$:
$x_SINGLEQUOTE_$jscomp$2$$}catch($e34983$$){if($e34983$$ instanceof Error)return $x$jscomp$848$$;throw $e34983$$;}else return $x$jscomp$848$$};$malli$transform$_string__GT_float$$=function($x$jscomp$849$$){if(typeof $x$jscomp$849$$==="string"){var $or__5025__auto__$jscomp$180$$=$APP.$cljs$core$parse_double$$($x$jscomp$849$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$180$$)?$or__5025__auto__$jscomp$180$$:$x$jscomp$849$$}return $x$jscomp$849$$};
$malli$transform$_string__GT_double$$=function($x$jscomp$850$$){if(typeof $x$jscomp$850$$==="string"){var $or__5025__auto__$jscomp$181$$=$APP.$cljs$core$parse_double$$($x$jscomp$850$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$181$$)?$or__5025__auto__$jscomp$181$$:$x$jscomp$850$$}return $x$jscomp$850$$};$malli$transform$_number__GT_float$$=function($x$jscomp$851$$){return $x$jscomp$851$$};$malli$transform$_number__GT_double$$=function($x$jscomp$852$$){return $x$jscomp$852$$};
$malli$transform$_number__GT_long$$=function($x$jscomp$853$$){return $APP.$cljs$core$integer_QMARK_$$($x$jscomp$853$$)?$x$jscomp$853$$:typeof $x$jscomp$853$$==="number"&&$x$jscomp$853$$===$cljs$math$round$$($x$jscomp$853$$)?$cljs$math$round$$($x$jscomp$853$$):$x$jscomp$853$$};$malli$transform$_string__GT_keyword$$=function($x$jscomp$854$$){return typeof $x$jscomp$854$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$854$$):$x$jscomp$854$$};
$malli$transform$_string__GT_boolean$$=function($x$jscomp$855$$){return typeof $x$jscomp$855$$==="string"?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("true",$x$jscomp$855$$)?!0:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("false",$x$jscomp$855$$)?!1:$x$jscomp$855$$:$x$jscomp$855$$};
$malli$transform$_string__GT_uuid$$=function($x$jscomp$856$$){if(typeof $x$jscomp$856$$==="string"){var $temp__5823__auto__$jscomp$73$$=$APP.$cljs$core$re_matches$$($malli$transform$uuid_re$$,$x$jscomp$856$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$73$$)?$APP.$cljs$core$uuid$$($temp__5823__auto__$jscomp$73$$):$x$jscomp$856$$}return $x$jscomp$856$$};
$malli$transform$_string__GT_date$$=function($x$jscomp$857$$){if(typeof $x$jscomp$857$$==="string")try{var $JSCompiler_temp_const$jscomp$495$$=Date,$ret$jscomp$inline_3821$$=new $goog$date$UtcDateTime$$(2E3),$formatted$jscomp$inline_11524_twoDigitYear$jscomp$inline_14172$$=$x$jscomp$857$$;$formatted$jscomp$inline_11524_twoDigitYear$jscomp$inline_14172$$=$goog$string$internal$trim$$($formatted$jscomp$inline_11524_twoDigitYear$jscomp$inline_14172$$);var $delim$jscomp$inline_11525$$=$formatted$jscomp$inline_11524_twoDigitYear$jscomp$inline_14172$$.indexOf("T")==
-1?" ":"T",$parts$jscomp$inline_11526$$=$formatted$jscomp$inline_11524_twoDigitYear$jscomp$inline_14172$$.split($delim$jscomp$inline_11525$$);var $parts$jscomp$inline_14151$$=$parts$jscomp$inline_11526$$[0].match($goog$date$splitDateStringRegex_$$);if($parts$jscomp$inline_14151$$){var $month$jscomp$inline_14152$$=Number($parts$jscomp$inline_14151$$[2]),$date$jscomp$inline_14153$$=Number($parts$jscomp$inline_14151$$[3]),$dayOfYear$jscomp$inline_14154$$=Number($parts$jscomp$inline_14151$$[4]),$week$jscomp$inline_14155$$=
Number($parts$jscomp$inline_14151$$[5]),$dayOfWeek$jscomp$inline_14156$$=Number($parts$jscomp$inline_14151$$[6])||1;$ret$jscomp$inline_3821$$.setFullYear(Number($parts$jscomp$inline_14151$$[1]));if($dayOfYear$jscomp$inline_14154$$)$ret$jscomp$inline_3821$$.setDate(1),$ret$jscomp$inline_3821$$.setMonth(0),$ret$jscomp$inline_3821$$.add(new $goog$date$Interval$$($goog$date$Interval$DAYS$$,$dayOfYear$jscomp$inline_14154$$-1));else if($week$jscomp$inline_14155$$){$ret$jscomp$inline_3821$$.setMonth(0);
$ret$jscomp$inline_3821$$.setDate(1);var $jan1WeekDay$jscomp$inline_14157$$=$ret$jscomp$inline_3821$$.getDay()||7;$ret$jscomp$inline_3821$$.add(new $goog$date$Interval$$($goog$date$Interval$DAYS$$,($jan1WeekDay$jscomp$inline_14157$$<=4?1-$jan1WeekDay$jscomp$inline_14157$$:8-$jan1WeekDay$jscomp$inline_14157$$)+(Number($dayOfWeek$jscomp$inline_14156$$)+7*(Number($week$jscomp$inline_14155$$)-1))-1))}else $month$jscomp$inline_14152$$&&($ret$jscomp$inline_3821$$.setDate(1),$ret$jscomp$inline_3821$$.setMonth($month$jscomp$inline_14152$$-
1)),$date$jscomp$inline_14153$$&&$ret$jscomp$inline_3821$$.setDate($date$jscomp$inline_14153$$);var $JSCompiler_inline_result$jscomp$14042$$=!0}else $JSCompiler_inline_result$jscomp$14042$$=!1;var $JSCompiler_temp$jscomp$14043$$;if($JSCompiler_temp$jscomp$14043$$=$JSCompiler_inline_result$jscomp$14042$$){var $JSCompiler_temp$jscomp$14044$$;if(!($JSCompiler_temp$jscomp$14044$$=$parts$jscomp$inline_11526$$.length<2)){var $formatted$jscomp$inline_14160$$=$parts$jscomp$inline_11526$$[1],$timezoneParts$jscomp$inline_14161$$=
$formatted$jscomp$inline_14160$$.match($goog$date$splitTimezoneStringRegex_$$);if($timezoneParts$jscomp$inline_14161$$){var $formattedTime$jscomp$inline_14163$$=$formatted$jscomp$inline_14160$$.substring(0,$formatted$jscomp$inline_14160$$.length-$timezoneParts$jscomp$inline_14161$$[0].length);if($timezoneParts$jscomp$inline_14161$$[0]==="Z")var $offsetMinutes$jscomp$inline_14162$$=0;else $offsetMinutes$jscomp$inline_14162$$=Number($timezoneParts$jscomp$inline_14161$$[2])*60+Number($timezoneParts$jscomp$inline_14161$$[3]),
$offsetMinutes$jscomp$inline_14162$$*=$timezoneParts$jscomp$inline_14161$$[1]=="-"?1:-1}else $formattedTime$jscomp$inline_14163$$=$formatted$jscomp$inline_14160$$;var $timeParts$jscomp$inline_14164$$=$formattedTime$jscomp$inline_14163$$.match($goog$date$splitTimeStringRegex_$$);if($timeParts$jscomp$inline_14164$$){if($timezoneParts$jscomp$inline_14161$$){var $year$jscomp$inline_14165$$=$ret$jscomp$inline_3821$$.getYear(),$month$jscomp$inline_14166$$=$ret$jscomp$inline_3821$$.getMonth(),$day$jscomp$inline_14167$$=
$ret$jscomp$inline_3821$$.getDate(),$hour$jscomp$inline_14168$$=Number($timeParts$jscomp$inline_14164$$[1]),$minute$jscomp$inline_14169$$=Number($timeParts$jscomp$inline_14164$$[2])||0,$second$jscomp$inline_14170$$=Number($timeParts$jscomp$inline_14164$$[3])||0,$millisecond$jscomp$inline_14171$$=$timeParts$jscomp$inline_14164$$[4]?Number($timeParts$jscomp$inline_14164$$[4])*1E3:0;($formatted$jscomp$inline_11524_twoDigitYear$jscomp$inline_14172$$=$year$jscomp$inline_14165$$>=0&&$year$jscomp$inline_14165$$<
100)&&($year$jscomp$inline_14165$$+=400);let $utc$jscomp$inline_14173$$=Date.UTC($year$jscomp$inline_14165$$,$month$jscomp$inline_14166$$,$day$jscomp$inline_14167$$,$hour$jscomp$inline_14168$$,$minute$jscomp$inline_14169$$,$second$jscomp$inline_14170$$,$millisecond$jscomp$inline_14171$$);$formatted$jscomp$inline_11524_twoDigitYear$jscomp$inline_14172$$&&($utc$jscomp$inline_14173$$-=126227808E5);$ret$jscomp$inline_3821$$.setTime($utc$jscomp$inline_14173$$+$offsetMinutes$jscomp$inline_14162$$*6E4)}else $ret$jscomp$inline_3821$$.setHours(Number($timeParts$jscomp$inline_14164$$[1])),
$ret$jscomp$inline_3821$$.setMinutes(Number($timeParts$jscomp$inline_14164$$[2])||0),$ret$jscomp$inline_3821$$.setSeconds(Number($timeParts$jscomp$inline_14164$$[3])||0),$ret$jscomp$inline_3821$$.setMilliseconds($timeParts$jscomp$inline_14164$$[4]?Number($timeParts$jscomp$inline_14164$$[4])*1E3:0);$JSCompiler_temp$jscomp$14044$$=!0}else $JSCompiler_temp$jscomp$14044$$=!1}$JSCompiler_temp$jscomp$14043$$=$JSCompiler_temp$jscomp$14044$$}return new $JSCompiler_temp_const$jscomp$495$$(($JSCompiler_temp$jscomp$14043$$?
$ret$jscomp$inline_3821$$:null).getTime())}catch($e35020$$){if($e35020$$ instanceof Error)return $x$jscomp$857$$;throw $e35020$$;}else return $x$jscomp$857$$};$malli$transform$_string__GT_symbol$$=function($x$jscomp$858$$){return typeof $x$jscomp$858$$==="string"?$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$858$$):$x$jscomp$858$$};$malli$transform$_any__GT_string$$=function($x$jscomp$860$$){return $x$jscomp$860$$==null?null:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$860$$)};
$malli$transform$_date__GT_string$$=function($x$jscomp$862$$){if($cljs$core$inst_QMARK_$$($x$jscomp$862$$))try{return $x$jscomp$862$$.toISOString()}catch($e35071$$){if($e35071$$ instanceof Error)return $x$jscomp$862$$;throw $e35071$$;}else return $x$jscomp$862$$};
$malli$transform$_transform_map_keys$cljs$0core$0IFn$0_invoke$0arity$01$$=function(){var $xform$jscomp$10$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p__35134_v$jscomp$219$$){var $k$jscomp$439$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__35134_v$jscomp$219$$,0,null);$p__35134_v$jscomp$219$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__35134_v$jscomp$219$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$malli$core$_keyword__GT_string$$.$cljs$core$IFn$_invoke$arity$1$?$malli$core$_keyword__GT_string$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$439$$):$malli$core$_keyword__GT_string$$($k$jscomp$439$$),$p__35134_v$jscomp$219$$],null)});return function($p1__35099_SHARP_$$){return $APP.$cljs$core$map_QMARK_$$($p1__35099_SHARP_$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$empty$$($p1__35099_SHARP_$$),$xform$jscomp$10$$,$p1__35099_SHARP_$$):$p1__35099_SHARP_$$}};
$malli$transform$_transform_if_valid$$=function($f$jscomp$487$$,$schema$jscomp$189$$){var $validator$jscomp$32$$=$malli$core$_validator$$($schema$jscomp$189$$);return function($x$jscomp$863$$){var $out$jscomp$18$$=$f$jscomp$487$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$487$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$863$$):$f$jscomp$487$$($x$jscomp$863$$);return $APP.$cljs$core$truth_$$($validator$jscomp$32$$.$cljs$core$IFn$_invoke$arity$1$?$validator$jscomp$32$$.$cljs$core$IFn$_invoke$arity$1$($out$jscomp$18$$):
$validator$jscomp$32$$($out$jscomp$18$$))?$out$jscomp$18$$:$x$jscomp$863$$}};$malli$transform$_sequential__GT_set$$=function($x$jscomp$864$$){return $APP.$cljs$core$set_QMARK_$$($x$jscomp$864$$)?$x$jscomp$864$$:$APP.$cljs$core$sequential_QMARK_$$($x$jscomp$864$$)?$APP.$cljs$core$set$$($x$jscomp$864$$):$x$jscomp$864$$};
$malli$transform$_sequential__GT_vector$$=function($x$jscomp$865$$){return $APP.$cljs$core$vector_QMARK_$$($x$jscomp$865$$)?$x$jscomp$865$$:$APP.$cljs$core$sequential_QMARK_$$($x$jscomp$865$$)?$APP.$cljs$core$vec$$($x$jscomp$865$$):$x$jscomp$865$$};
$malli$transform$_sequential_or_set__GT_vector$$=function($x$jscomp$866$$){return $APP.$cljs$core$vector_QMARK_$$($x$jscomp$866$$)?$x$jscomp$866$$:$APP.$cljs$core$set_QMARK_$$($x$jscomp$866$$)?$APP.$cljs$core$vec$$($x$jscomp$866$$):$APP.$cljs$core$sequential_QMARK_$$($x$jscomp$866$$)?$APP.$cljs$core$vec$$($x$jscomp$866$$):$x$jscomp$866$$};
$malli$transform$_sequential_or_set__GT_seq$$=function($x$jscomp$867$$){return $APP.$cljs$core$vector_QMARK_$$($x$jscomp$867$$)?$APP.$cljs$core$seq$$($x$jscomp$867$$):$APP.$cljs$core$set_QMARK_$$($x$jscomp$867$$)?$APP.$cljs$core$seq$$($x$jscomp$867$$):$x$jscomp$867$$};
$malli$transform$_infer_child_compiler$$=function($x_coders$$){return function($G__35183__$1_G__35183__$2_schema$jscomp$190$$){$G__35183__$1_G__35183__$2_schema$jscomp$190$$=$G__35183__$1_G__35183__$2_schema$jscomp$190$$==null?null:$malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($G__35183__$1_G__35183__$2_schema$jscomp$190$$);$G__35183__$1_G__35183__$2_schema$jscomp$190$$=$G__35183__$1_G__35183__$2_schema$jscomp$190$$==null?null:$malli$core$_infer$$($G__35183__$1_G__35183__$2_schema$jscomp$190$$);
return $G__35183__$1_G__35183__$2_schema$jscomp$190$$==null?null:$x_coders$$.$cljs$core$IFn$_invoke$arity$1$?$x_coders$$.$cljs$core$IFn$_invoke$arity$1$($G__35183__$1_G__35183__$2_schema$jscomp$190$$):$x_coders$$($G__35183__$1_G__35183__$2_schema$jscomp$190$$)}};
$malli$transform$_add_child_compilers$$=function($x_coders$jscomp$1$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($x_coders$jscomp$1$$,$APP.$cljs$cst$499$enum$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$411$compile$$,$malli$transform$_infer_child_compiler$$($x_coders$jscomp$1$$)],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$711$_EQ_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$411$compile$$,$malli$transform$_infer_child_compiler$$($x_coders$jscomp$1$$)],
null)]))};
$malli$transform$_base_json_decoders$$=function(){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$423$qualified_symbol$$,$cljs$cst$681$simple_keyword_QMARK_$$,$cljs$cst$345$double$$,$cljs$cst$686$uuid_QMARK_$$,$cljs$cst$688$inst_QMARK_$$,$cljs$cst$678$simple_ident_QMARK_$$,$cljs$cst$667$int_QMARK_$$,$cljs$cst$344$int$$,$cljs$cst$673$float_QMARK_$$,$cljs$cst$420$float$$,$APP.$cljs$cst$219$symbol$$,$cljs$cst$677$ident_QMARK_$$,$cljs$cst$422$qualified_keyword$$,$cljs$cst$669$neg_int_QMARK_$$,$cljs$cst$683$symbol_QMARK_$$,
$cljs$cst$679$qualified_ident_QMARK_$$,$cljs$cst$680$keyword_QMARK_$$,$cljs$cst$684$simple_symbol_QMARK_$$,$cljs$cst$666$integer_QMARK_$$,$cljs$cst$700$zero_QMARK_$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$682$qualified_keyword_QMARK_$$,$cljs$cst$685$qualified_symbol_QMARK_$$,$cljs$cst$670$nat_int_QMARK_$$,$cljs$cst$424$uuid$$,$APP.$cljs$cst$203$set$$,$cljs$cst$674$double_QMARK_$$,$cljs$cst$668$pos_int_QMARK_$$],[$malli$transform$_string__GT_symbol$$,$malli$transform$_string__GT_keyword$$,$malli$transform$_number__GT_double$$,
$malli$transform$_string__GT_uuid$$,$malli$transform$_string__GT_date$$,$malli$transform$_string__GT_keyword$$,$malli$transform$_number__GT_long$$,$malli$transform$_number__GT_long$$,$malli$transform$_number__GT_float$$,$malli$transform$_number__GT_float$$,$malli$transform$_string__GT_symbol$$,$malli$transform$_string__GT_keyword$$,$malli$transform$_string__GT_keyword$$,$malli$transform$_number__GT_long$$,$malli$transform$_string__GT_symbol$$,$malli$transform$_string__GT_keyword$$,$malli$transform$_string__GT_keyword$$,
$malli$transform$_string__GT_symbol$$,$malli$transform$_number__GT_long$$,$malli$transform$_number__GT_long$$,$malli$transform$_string__GT_keyword$$,$malli$transform$_string__GT_keyword$$,$malli$transform$_string__GT_symbol$$,$malli$transform$_number__GT_long$$,$malli$transform$_string__GT_uuid$$,$malli$transform$_sequential__GT_set$$,$malli$transform$_number__GT_double$$,$malli$transform$_number__GT_long$$])};
$malli$transform$_base_json_encoders$$=function(){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$423$qualified_symbol$$,$cljs$cst$681$simple_keyword_QMARK_$$,$cljs$cst$686$uuid_QMARK_$$,$cljs$cst$688$inst_QMARK_$$,$APP.$cljs$cst$219$symbol$$,$cljs$cst$422$qualified_keyword$$,$cljs$cst$683$symbol_QMARK_$$,$cljs$cst$680$keyword_QMARK_$$,$cljs$cst$684$simple_symbol_QMARK_$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$682$qualified_keyword_QMARK_$$,$cljs$cst$685$qualified_symbol_QMARK_$$,
$cljs$cst$424$uuid$$],[$malli$transform$_any__GT_string$$,$malli$core$_keyword__GT_string$$,$malli$transform$_any__GT_string$$,$malli$transform$_date__GT_string$$,$malli$transform$_any__GT_string$$,$malli$core$_keyword__GT_string$$,$malli$transform$_any__GT_string$$,$malli$core$_keyword__GT_string$$,$malli$transform$_any__GT_string$$,$malli$core$_keyword__GT_string$$,$malli$core$_keyword__GT_string$$,$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$])};
$malli$transform$_string_decoders$$=function(){return $malli$transform$_add_child_compilers$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$transform$_base_json_decoders$$(),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$699$true_QMARK_$$,$cljs$cst$710$_LT__EQ_$$,$cljs$cst$345$double$$,$cljs$cst$712$not_EQ_$$,$cljs$cst$667$int_QMARK_$$,$cljs$cst$344$int$$,$cljs$cst$707$_GT_$$,$cljs$cst$673$float_QMARK_$$,
$cljs$cst$420$float$$,$cljs$cst$698$false_QMARK_$$,$cljs$cst$669$neg_int_QMARK_$$,$APP.$cljs$cst$200$vector$$,$cljs$cst$708$_GT__EQ_$$,$cljs$cst$666$integer_QMARK_$$,$cljs$cst$463$map_of$$,$cljs$cst$700$zero_QMARK_$$,$cljs$cst$670$nat_int_QMARK_$$,$cljs$cst$675$boolean_QMARK_$$,$cljs$cst$665$number_QMARK_$$,$cljs$cst$674$double_QMARK_$$,$APP.$cljs$cst$421$boolean$$,$cljs$cst$709$_LT_$$,$cljs$cst$668$pos_int_QMARK_$$],[$malli$transform$_string__GT_boolean$$,$malli$transform$_string__GT_long$$,$malli$transform$_string__GT_double$$,
$malli$transform$_string__GT_long$$,$malli$transform$_string__GT_long$$,$malli$transform$_string__GT_long$$,$malli$transform$_string__GT_long$$,$malli$transform$_string__GT_float$$,$malli$transform$_string__GT_float$$,$malli$transform$_string__GT_boolean$$,$malli$transform$_string__GT_long$$,$malli$transform$_sequential__GT_vector$$,$malli$transform$_string__GT_long$$,$malli$transform$_string__GT_long$$,$malli$transform$_transform_map_keys$cljs$0core$0IFn$0_invoke$0arity$01$$(),$malli$transform$_string__GT_long$$,
$malli$transform$_string__GT_long$$,$malli$transform$_string__GT_boolean$$,$malli$transform$_string__GT_double$$,$malli$transform$_string__GT_double$$,$malli$transform$_string__GT_boolean$$,$malli$transform$_string__GT_long$$,$malli$transform$_string__GT_long$$])])))};
$malli$transform$t_malli$0transform35235$$=function($_QMARK_transformers$$,$__GT_data$$,$__GT_eval$$,$__GT_chain$$,$chain$$,$chain_SINGLEQUOTE_$$,$meta35236$$){this.$_QMARK_transformers$=$_QMARK_transformers$$;this.$__GT_data$=$__GT_data$$;this.$__GT_eval$=$__GT_eval$$;this.$__GT_chain$=$__GT_chain$$;this.$chain$=$chain$$;this.$chain_SINGLEQUOTE_$=$chain_SINGLEQUOTE_$$;this.$meta35236$=$meta35236$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$malli$transform$collection_transformer$$=function(){var $coders$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$200$vector$$,$malli$transform$_sequential_or_set__GT_vector$$,$cljs$cst$720$sequential$$,$malli$transform$_sequential_or_set__GT_seq$$,$APP.$cljs$cst$203$set$$,$malli$transform$_sequential__GT_set$$,$APP.$cljs$cst$498$tuple$$,$malli$transform$_sequential__GT_vector$$],null);return $malli$transform$transformer$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$cljs$cst$916$decoders$$,$coders$$,$cljs$cst$918$encoders$$,$coders$$],null)]))};$APP.$app$common$schema$schema$$=function($s$jscomp$376$$){return $malli$core$schema_QMARK_$$($s$jscomp$376$$)?$s$jscomp$376$$:$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$376$$,$app$common$schema$default_options$$)};$app$common$schema$form$$=function($s$jscomp$382$$){return $malli$core$form$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$382$$,$app$common$schema$default_options$$)};
$APP.$app$common$schema$merge$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($items$jscomp$13$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$util$merge$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$schema$schema$$,$items$jscomp$13$$))};
$APP.$app$common$schema$dissoc_key$$=function($s$jscomp$386_s__$1$jscomp$13$$){$s$jscomp$386_s__$1$jscomp$13$$=$APP.$app$common$schema$schema$$($s$jscomp$386_s__$1$jscomp$13$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$386_s__$1$jscomp$13$$),$APP.$cljs$cst$202$map$$))return $malli$util$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$386_s__$1$jscomp$13$$,$APP.$cljs$cst$266$id$$);var $temp__5823__auto__$jscomp$76$$=
$APP.$malli$util$find_first$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$386_s__$1$jscomp$13$$,function($s_SINGLEQUOTE_$jscomp$1$$,$path$jscomp$119$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($s_SINGLEQUOTE_$jscomp$1$$),$APP.$cljs$cst$202$map$$)?$path$jscomp$119$$:null});return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$76$$)?$malli$util$update_in$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($s$jscomp$386_s__$1$jscomp$13$$,
$temp__5823__auto__$jscomp$76$$):$s$jscomp$386_s__$1$jscomp$13$$};
$app$common$schema$keys$$=function($schema_SINGLEQUOTE_$jscomp$1_schema_SINGLEQUOTE___$1$$){$schema_SINGLEQUOTE_$jscomp$1_schema_SINGLEQUOTE___$1$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($schema_SINGLEQUOTE_$jscomp$1_schema_SINGLEQUOTE___$1$$,$app$common$schema$default_options$$);var $G__40134$$=$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($schema_SINGLEQUOTE_$jscomp$1_schema_SINGLEQUOTE___$1$$);switch($G__40134$$ instanceof $APP.$cljs$core$Keyword$$?$G__40134$$.$fqn$:
null){case "map":return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$app$common$schema$xf_COLON_map_key$$,$malli$core$entries$$.$cljs$core$IFn$_invoke$arity$2$($schema_SINGLEQUOTE_$jscomp$1_schema_SINGLEQUOTE___$1$$,$app$common$schema$default_options$$));case "merge":return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$app$common$schema$xf_COLON_map_key$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($malli$core$entries$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($schema_SINGLEQUOTE_$jscomp$1_schema_SINGLEQUOTE___$1$$)])));default:throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("not supported schema type",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($schema_SINGLEQUOTE_$jscomp$1_schema_SINGLEQUOTE___$1$$)],null));}};
$APP.$app$common$schema$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($s$jscomp$391_s__$1$jscomp$14$$,$args$jscomp$188$$){$s$jscomp$391_s__$1$jscomp$14$$=$APP.$app$common$schema$schema$$($s$jscomp$391_s__$1$jscomp$14$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$4$($malli$core$_update_properties$$,$s$jscomp$391_s__$1$jscomp$14$$,$APP.$cljs$core$assoc$$,$args$jscomp$188$$)};
$app$common$schema$_transform_map_keys$cljs$0core$0IFn$0_invoke$0arity$01$$=function($f$jscomp$494$$){var $xform$jscomp$12$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p__40147_v$jscomp$225$$){var $k$jscomp$448$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__40147_v$jscomp$225$$,0,null);$p__40147_v$jscomp$225$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__40147_v$jscomp$225$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$f$jscomp$494$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$494$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$448$$):$f$jscomp$494$$($k$jscomp$448$$),$p__40147_v$jscomp$225$$],null)});return function($p1__40142_SHARP_$$){return $APP.$cljs$core$map_QMARK_$$($p1__40142_SHARP_$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$empty$$($p1__40142_SHARP_$$),$xform$jscomp$12$$,$p1__40142_SHARP_$$):$p1__40142_SHARP_$$}};
$app$common$schema$json_transformer$$=function(){var $map_of_key_decoders$jscomp$1$$=$malli$transform$_string_decoders$$();return $malli$transform$transformer$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$cljs$cst$923$json$$,$cljs$cst$916$decoders$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($malli$transform$_add_child_compilers$$($malli$transform$_base_json_decoders$$()),
$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$411$compile$$,function($schema$jscomp$202$$){var $key_schema$jscomp$4$$=function(){var $G__40164__$1$$=$schema$jscomp$202$$==null?null:$malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$202$$);return $G__40164__$1$$==null?null:$APP.$cljs$core$first$$($G__40164__$1$$)}(),$or__5025__auto__$jscomp$188$$=function(){var $G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$=
$key_schema$jscomp$4$$==null?null:$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($key_schema$jscomp$4$$);$G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$=$G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$==null?null:$map_of_key_decoders$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$map_of_key_decoders$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$):$map_of_key_decoders$jscomp$1$$($G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$);
$G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$=$G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$==null?null:$malli$transform$_interceptor$$($G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$,$schema$jscomp$202$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);$G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$=$G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$==
null?null:$malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$01$$($G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$);$G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$=$G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$==null?null:$malli$core$_comp$$.$cljs$core$IFn$_invoke$arity$2$($G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$,$malli$core$_keyword__GT_string$$);$G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$=
$G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$==null?null:$malli$transform$_transform_if_valid$$($G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$,$key_schema$jscomp$4$$);return $G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$==null?null:$app$common$schema$_transform_map_keys$cljs$0core$0IFn$0_invoke$0arity$01$$($G__40165__$1_G__40165__$2_G__40165__$3_G__40165__$4_G__40165__$5_G__40165__$6$$)}();return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$188$$)?
$or__5025__auto__$jscomp$188$$:$app$common$schema$_transform_map_keys$cljs$0core$0IFn$0_invoke$0arity$01$$($malli$core$_keyword__GT_string$$)}],null)),$cljs$cst$918$encoders$$,$malli$transform$_add_child_compilers$$($malli$transform$_base_json_encoders$$())],null),$malli$transform$collection_transformer$$()]))};
$app$common$schema$string_transformer$$=function(){return $malli$transform$transformer$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$transform$transformer$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$,$cljs$cst$916$decoders$$,$malli$transform$_string_decoders$$(),$cljs$cst$918$encoders$$,
$malli$transform$_add_child_compilers$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$transform$_base_json_encoders$$(),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$710$_LT__EQ_$$,$cljs$cst$345$double$$,$cljs$cst$712$not_EQ_$$,$cljs$cst$667$int_QMARK_$$,$cljs$cst$344$int$$,$cljs$cst$707$_GT_$$,$cljs$cst$420$float$$,$cljs$cst$669$neg_int_QMARK_$$,$cljs$cst$708$_GT__EQ_$$,$cljs$cst$666$integer_QMARK_$$,
$cljs$cst$700$zero_QMARK_$$,$cljs$cst$906$float$$,$cljs$cst$670$nat_int_QMARK_$$,$cljs$cst$907$double$$,$cljs$cst$709$_LT_$$,$cljs$cst$668$pos_int_QMARK_$$],[$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$,
$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$,$malli$transform$_any__GT_string$$])])))],null)])),$malli$transform$collection_transformer$$()]))};
$app$common$schema$validator$$=function($_QMARK_schema$jscomp$inline_3831_s$jscomp$396$$){$_QMARK_schema$jscomp$inline_3831_s$jscomp$396$$=$APP.$app$common$schema$schema$$($_QMARK_schema$jscomp$inline_3831_s$jscomp$396$$);return $malli$core$validator$cljs$0core$0IFn$0_invoke$0arity$02$$($_QMARK_schema$jscomp$inline_3831_s$jscomp$396$$,null)};
$app$common$schema$encoder$cljs$0core$0IFn$0_invoke$0arity$02$$=function($or__5025__auto__$jscomp$inline_3836_s$jscomp$398$$){var $options$jscomp$inline_3835$$=$app$common$schema$default_options$$;$or__5025__auto__$jscomp$inline_3836_s$jscomp$398$$=$malli$core$_transformer$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($or__5025__auto__$jscomp$inline_3836_s$jscomp$398$$,$options$jscomp$inline_3835$$),$malli$core$_into_transformer$$($app$common$schema$string_transformer$$),$cljs$cst$648$encode$$,
$options$jscomp$inline_3835$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_3836_s$jscomp$398$$)?$or__5025__auto__$jscomp$inline_3836_s$jscomp$398$$:$APP.$cljs$core$identity$$};
$app$common$schema$lazy_validator$$=function($s$jscomp$402$$){var $vfn$$=new $APP.$cljs$core$Delay$$(function(){return $app$common$schema$validator$$($s$jscomp$402$$)});return function($v$jscomp$227$$){var $fexpr__40189$$=$APP.$cljs$core$_deref$$($vfn$$);return $fexpr__40189$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__40189$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$227$$):$fexpr__40189$$($v$jscomp$227$$)}};
$app$common$schema$lazy_decoder$$=function($s$jscomp$404$$){var $vfn$jscomp$2$$=new $APP.$cljs$core$Delay$$(function(){var $s$jscomp$inline_3838$$=$APP.$cljs$core$delay_QMARK_$$($s$jscomp$404$$)?$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$404$$,null):$s$jscomp$404$$;return $malli$core$decoder$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$inline_3838$$)});return function($v$jscomp$229$$){var $fexpr__40191$$=$APP.$cljs$core$_deref$$($vfn$jscomp$2$$);return $fexpr__40191$$.$cljs$core$IFn$_invoke$arity$1$?
$fexpr__40191$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$229$$):$fexpr__40191$$($v$jscomp$229$$)}};
$APP.$app$common$schema$humanize_explain$$=function($var_args$jscomp$628$$){for(var $args__5755__auto__$jscomp$119$$=[],$len__5749__auto___40591$$=arguments.length,$i__5750__auto___40592$$=0;;)if($i__5750__auto___40592$$<$len__5749__auto___40591$$)$args__5755__auto__$jscomp$119$$.push(arguments[$i__5750__auto___40592$$]),$i__5750__auto___40592$$+=1;else break;return $app$common$schema$humanize_explain$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$119$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$119$$.slice(1),0,null):null)};
$app$common$schema$humanize_explain$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($map__40198__$1_p__40196_value$jscomp$318$$,$length$jscomp$35_p__40197$$){$map__40198__$1_p__40196_value$jscomp$318$$=$APP.$cljs$core$__destructure_map$$($map__40198__$1_p__40196_value$jscomp$318$$);var $errors$jscomp$11_errors__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40198__$1_p__40196_value$jscomp$318$$,$APP.$cljs$cst$570$errors$$);$map__40198__$1_p__40196_value$jscomp$318$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40198__$1_p__40196_value$jscomp$318$$,
$APP.$cljs$cst$260$value$$);var $level$jscomp$31_map__40199__$1$$=$APP.$cljs$core$__destructure_map$$($length$jscomp$35_p__40197$$);$length$jscomp$35_p__40197$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$31_map__40199__$1$$,$APP.$cljs$cst$255$length$$);$level$jscomp$31_map__40199__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$31_map__40199__$1$$,$APP.$cljs$cst$284$level$$);$errors$jscomp$11_errors__$1$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__40193_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__40193_SHARP_$$,
$APP.$cljs$cst$298$schema$$,$app$common$schema$form$$)},$errors$jscomp$11_errors__$1$$);var $sb__5670__auto__$jscomp$1$$=new $APP.$goog$string$StringBuffer$$,$_STAR_print_newline_STAR__orig_val__40200_40598$$=$APP.$cljs$core$_STAR_print_newline_STAR_$$,$_STAR_print_fn_STAR__orig_val__40201_40599$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$1$$){return $sb__5670__auto__$jscomp$1$$.append($x__5671__auto__$jscomp$1$$)};
try{$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Errors:"])),$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$pprint$pprint_str$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($errors$jscomp$11_errors__$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$290$width$$,
100,$APP.$cljs$cst$284$level$$,15,$APP.$cljs$cst$255$length$$,20],null)]))])),$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Value:"])),$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$pprint$pprint_str$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($map__40198__$1_p__40196_value$jscomp$318$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$290$width$$,160,$APP.$cljs$cst$284$level$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$31_map__40199__$1$$,8),$APP.$cljs$cst$255$length$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($length$jscomp$35_p__40197$$,12)],null)]))]))}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=$_STAR_print_fn_STAR__orig_val__40201_40599$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__40200_40598$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$1$$)};
$app$common$schema$check_fn$$=function($var_args$jscomp$630$$){for(var $args__5755__auto__$jscomp$120$$=[],$len__5749__auto___40610$$=arguments.length,$i__5750__auto___40611$$=0;;)if($i__5750__auto___40611$$<$len__5749__auto___40610$$)$args__5755__auto__$jscomp$120$$.push(arguments[$i__5750__auto___40611$$]),$i__5750__auto___40611$$+=1;else break;return $app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$120$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$120$$.slice(1),
0,null):null)};
$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($s$jscomp$408$$,$hint$jscomp$1_p__40221$$){var $code$jscomp$4_map__40223__$1$$=$APP.$cljs$core$__destructure_map$$($hint$jscomp$1_p__40221$$);$hint$jscomp$1_p__40221$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$4_map__40223__$1$$,$APP.$cljs$cst$275$hint$$);var $type$jscomp$232$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$4_map__40223__$1$$,$APP.$cljs$cst$139$type$$);$code$jscomp$4_map__40223__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$4_map__40223__$1$$,$APP.$cljs$cst$273$code$$);var $s__$1$jscomp$15$$=function(){try{return $APP.$app$common$schema$schema$$($s$jscomp$408$$)}catch($e40226$$){var $cause$jscomp$4$$=$e40226$$,$data$jscomp$103$$=$APP.$cljs$core$ex_data$$($cause$jscomp$4$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$358$malli_DOT_core_SLASH_invalid_schema$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$103$$)))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid schema\n",
$app$common$pprint$pprint_str$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$103$$))].join(""),$APP.$cljs$core$PersistentArrayMap$EMPTY$$);throw $cause$jscomp$4$$;}}(),$validator_STAR_$$=new $APP.$cljs$core$Delay$$(function(){return $malli$core$validator$cljs$0core$0IFn$0_invoke$0arity$02$$($s__$1$jscomp$15$$,null)}),$explainer_STAR_$$=new $APP.$cljs$core$Delay$$(function(){return $APP.$malli$core$explainer$cljs$0core$0IFn$0_invoke$0arity$02$$($s__$1$jscomp$15$$,null)}),
$hint__$1$$=$hint$jscomp$1_p__40221$$?$hint$jscomp$1_p__40221$$:"check error",$type__$1$$=$type$jscomp$232$$?$type$jscomp$232$$:$APP.$cljs$cst$272$assertion$$,$code__$1$$=$code$jscomp$4_map__40223__$1$$?$code$jscomp$4_map__40223__$1$$:$cljs$cst$931$data_validation$$;return function($explain_40615_value$jscomp$320$$){var $explain_fn_40614_validate_fn$$=$APP.$cljs$core$_deref$$($validator_STAR_$$);if($explain_fn_40614_validate_fn$$.$cljs$core$IFn$_invoke$arity$1$?!$explain_fn_40614_validate_fn$$.$cljs$core$IFn$_invoke$arity$1$($explain_40615_value$jscomp$320$$):
!$explain_fn_40614_validate_fn$$($explain_40615_value$jscomp$320$$))throw $explain_fn_40614_validate_fn$$=$APP.$cljs$core$_deref$$($explainer_STAR_$$),$explain_40615_value$jscomp$320$$=$explain_fn_40614_validate_fn$$.$cljs$core$IFn$_invoke$arity$1$?$explain_fn_40614_validate_fn$$.$cljs$core$IFn$_invoke$arity$1$($explain_40615_value$jscomp$320$$):$explain_fn_40614_validate_fn$$($explain_40615_value$jscomp$320$$),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$($hint__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$139$type$$,$type__$1$$,$APP.$cljs$cst$273$code$$,$code__$1$$,$APP.$cljs$cst$275$hint$$,$hint__$1$$,$APP.$cljs$cst$932$app_DOT_common_DOT_schema_SLASH_explain$$,$explain_40615_value$jscomp$320$$],null));return $explain_40615_value$jscomp$320$$}};
$APP.$app$common$schema$coercer$$=function($var_args$jscomp$631$$){for(var $args__5755__auto__$jscomp$121$$=[],$len__5749__auto___40617$$=arguments.length,$i__5750__auto___40618$$=0;;)if($i__5750__auto___40618$$<$len__5749__auto___40617$$)$args__5755__auto__$jscomp$121$$.push(arguments[$i__5750__auto___40618$$]),$i__5750__auto___40618$$+=1;else break;return $app$common$schema$coercer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$121$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$121$$.slice(1),
0,null):null)};
$app$common$schema$coercer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($schema$jscomp$204$$,$opts$jscomp$221_p__40237$$){$opts$jscomp$221_p__40237$$=$APP.$cljs$core$__destructure_map$$($opts$jscomp$221_p__40237$$);var $decode_fn$$=$app$common$schema$lazy_decoder$$($schema$jscomp$204$$),$check_fn$$=$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($schema$jscomp$204$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$opts$jscomp$221_p__40237$$]));return function($data$jscomp$104$$){return $check_fn$$($decode_fn$$($data$jscomp$104$$))}};
$app$common$schema$type_schema$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__40253_params$jscomp$9$$){$p__40253_params$jscomp$9$$=$APP.$cljs$core$__destructure_map$$($p__40253_params$jscomp$9$$);return $malli$core$_simple_schema$$($p__40253_params$jscomp$9$$)};$app$common$schema$coll_schema$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__40264_params$jscomp$10$$){$p__40264_params$jscomp$10$$=$APP.$cljs$core$__destructure_map$$($p__40264_params$jscomp$10$$);return $malli$core$_collection_schema$$($p__40264_params$jscomp$10$$)};
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($params$jscomp$11$$){if($APP.$cljs$core$map_QMARK_$$($params$jscomp$11$$)){var $mdata$$=$APP.$cljs$core$meta$$($params$jscomp$11$$),$type$jscomp$233$$=function(){var $or__5025__auto__$jscomp$192_or__5025__auto____$1$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$$,$cljs$cst$933$app_DOT_common_DOT_schema_SLASH_id$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$192_or__5025__auto____$1$jscomp$25$$))return $or__5025__auto__$jscomp$192_or__5025__auto____$1$jscomp$25$$;
$or__5025__auto__$jscomp$192_or__5025__auto____$1$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$$,$cljs$cst$934$app_DOT_common_DOT_schema_SLASH_type$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$192_or__5025__auto____$1$jscomp$25$$)?$or__5025__auto__$jscomp$192_or__5025__auto____$1$jscomp$25$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$11$$,$APP.$cljs$cst$139$type$$)}(),$s$jscomp$410$$=$malli$core$_simple_schema$$($params$jscomp$11$$);
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$common$schema$registry$registry$$,$APP.$cljs$core$assoc$$,$type$jscomp$233$$,$s$jscomp$410$$);return $s$jscomp$410$$}if($APP.$cljs$core$vector_QMARK_$$($params$jscomp$11$$))return $mdata$$=$APP.$cljs$core$meta$$($params$jscomp$11$$),$type$jscomp$233$$=function(){var $or__5025__auto__$jscomp$193$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$$,$cljs$cst$933$app_DOT_common_DOT_schema_SLASH_id$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$193$$)?
$or__5025__auto__$jscomp$193$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$$,$cljs$cst$934$app_DOT_common_DOT_schema_SLASH_type$$)}(),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$common$schema$registry$registry$$,$APP.$cljs$core$assoc$$,$type$jscomp$233$$,$params$jscomp$11$$),$params$jscomp$11$$;if($malli$core$into_schema_QMARK_$$($params$jscomp$11$$))return $type$jscomp$233$$=$malli$core$_type$$($params$jscomp$11$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$common$schema$registry$registry$$,
$APP.$cljs$core$assoc$$,$type$jscomp$233$$,$params$jscomp$11$$),$params$jscomp$11$$;throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Invalid Arguments",$APP.$cljs$core$PersistentArrayMap$EMPTY$$);};$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($type$jscomp$234$$,$params$jscomp$12$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$common$schema$registry$registry$$,$APP.$cljs$core$assoc$$,$type$jscomp$234$$,$params$jscomp$12$$)};
$app$common$schema$parse_uuid$$=function($s$jscomp$411$$){if($APP.$cljs$core$uuid_QMARK_$$($s$jscomp$411$$))return $s$jscomp$411$$;if($APP.$cuerdas$core$empty_QMARK_$$($s$jscomp$411$$))return null;try{return $APP.$app$common$uuid$parse$$($s$jscomp$411$$)}catch($e40286$$){return $s$jscomp$411$$}};$app$common$schema$encode_uuid$$=function($v$jscomp$231$$){return $APP.$cljs$core$uuid_QMARK_$$($v$jscomp$231$$)?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$231$$):$v$jscomp$231$$};
$APP.$app$common$schema$parse_email$$=function($s$jscomp$412$$){var $JSCompiler_inline_result$jscomp$499_and__5023__auto__$jscomp$inline_3841$$=($JSCompiler_inline_result$jscomp$499_and__5023__auto__$jscomp$inline_3841$$=typeof $s$jscomp$412$$==="string")?$APP.$cljs$core$re_matches$$($app$common$schema$email_re$$,$s$jscomp$412$$):$JSCompiler_inline_result$jscomp$499_and__5023__auto__$jscomp$inline_3841$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$499_and__5023__auto__$jscomp$inline_3841$$)?
$s$jscomp$412$$:null};$app$common$schema$parse_long$$=function($v$jscomp$240$$){try{var $or__5025__auto__$jscomp$198$$=typeof $v$jscomp$240$$==="string"?$APP.$cljs$core$parse_long$$($v$jscomp$240$$):$v$jscomp$240$$}catch($e40478$jscomp$inline_3843$$){$or__5025__auto__$jscomp$198$$=null}return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$198$$)?$or__5025__auto__$jscomp$198$$:$v$jscomp$240$$};
$app$common$schema$parse_double$$=function($v$jscomp$243$$){try{var $or__5025__auto__$jscomp$200$$=typeof $v$jscomp$243$$==="string"?$APP.$cljs$core$parse_double$$($v$jscomp$243$$):$v$jscomp$243$$}catch($e40484$jscomp$inline_3845$$){$or__5025__auto__$jscomp$200$$=null}return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$200$$)?$or__5025__auto__$jscomp$200$$:$v$jscomp$243$$};
$app$common$schema$parse_boolean$$=function($v$jscomp$248$$){if(typeof $v$jscomp$248$$==="string")switch($APP.$cuerdas$core$lower$$($v$jscomp$248$$)){case "true":case "t":case "1":return!0;case "false":case "f":case "0":return!1;default:return $v$jscomp$248$$}else return $v$jscomp$248$$};
$app$common$schema$parse_keyword$$=function($v$jscomp$249$$){return typeof $v$jscomp$249$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($app$common$json$read_kebab_key$$($v$jscomp$249$$)):$v$jscomp$249$$};$app$common$schema$decode_uri$$=function($val$jscomp$121$$){return $val$jscomp$121$$ instanceof $lambdaisland$uri$URI$$?$val$jscomp$121$$:$APP.$app$common$uri$uri$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$121$$))};
$cljs$spec$alpha$conform_STAR_$$=function($JSCompiler_temp$jscomp$500_spec$jscomp$1$$,$x$jscomp$875$$){if($JSCompiler_temp$jscomp$500_spec$jscomp$1$$!=null&&$JSCompiler_temp$jscomp$500_spec$jscomp$1$$.$cljs$spec$alpha$Spec$conform_STAR_$arity$2$!=null)$JSCompiler_temp$jscomp$500_spec$jscomp$1$$=$JSCompiler_temp$jscomp$500_spec$jscomp$1$$.$cljs$spec$alpha$Spec$conform_STAR_$arity$2$($JSCompiler_temp$jscomp$500_spec$jscomp$1$$,$x$jscomp$875$$);else{var $m__5372__auto__$jscomp$inline_3850_m__5374__auto__$jscomp$inline_3849$$=
$cljs$spec$alpha$conform_STAR_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$500_spec$jscomp$1$$==null?null:$JSCompiler_temp$jscomp$500_spec$jscomp$1$$)];if($m__5372__auto__$jscomp$inline_3850_m__5374__auto__$jscomp$inline_3849$$!=null)$JSCompiler_temp$jscomp$500_spec$jscomp$1$$=$m__5372__auto__$jscomp$inline_3850_m__5374__auto__$jscomp$inline_3849$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3850_m__5374__auto__$jscomp$inline_3849$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$500_spec$jscomp$1$$,
$x$jscomp$875$$):$m__5372__auto__$jscomp$inline_3850_m__5374__auto__$jscomp$inline_3849$$($JSCompiler_temp$jscomp$500_spec$jscomp$1$$,$x$jscomp$875$$);else if($m__5372__auto__$jscomp$inline_3850_m__5374__auto__$jscomp$inline_3849$$=$cljs$spec$alpha$conform_STAR_$$._,$m__5372__auto__$jscomp$inline_3850_m__5374__auto__$jscomp$inline_3849$$!=null)$JSCompiler_temp$jscomp$500_spec$jscomp$1$$=$m__5372__auto__$jscomp$inline_3850_m__5374__auto__$jscomp$inline_3849$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3850_m__5374__auto__$jscomp$inline_3849$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$500_spec$jscomp$1$$,
$x$jscomp$875$$):$m__5372__auto__$jscomp$inline_3850_m__5374__auto__$jscomp$inline_3849$$($JSCompiler_temp$jscomp$500_spec$jscomp$1$$,$x$jscomp$875$$);else throw $APP.$cljs$core$missing_protocol$$("Spec.conform*",$JSCompiler_temp$jscomp$500_spec$jscomp$1$$);}return $JSCompiler_temp$jscomp$500_spec$jscomp$1$$};
$APP.$cljs$spec$alpha$explain_STAR_$$=function($JSCompiler_temp$jscomp$501_spec$jscomp$5$$,$path$jscomp$121$$,$via$jscomp$3$$,$in$$jscomp$42$$,$x$jscomp$877$$){if($JSCompiler_temp$jscomp$501_spec$jscomp$5$$!=null&&$JSCompiler_temp$jscomp$501_spec$jscomp$5$$.$cljs$spec$alpha$Spec$explain_STAR_$arity$5$!=null)$JSCompiler_temp$jscomp$501_spec$jscomp$5$$=$JSCompiler_temp$jscomp$501_spec$jscomp$5$$.$cljs$spec$alpha$Spec$explain_STAR_$arity$5$($JSCompiler_temp$jscomp$501_spec$jscomp$5$$,$path$jscomp$121$$,
$via$jscomp$3$$,$in$$jscomp$42$$,$x$jscomp$877$$);else{var $m__5372__auto__$jscomp$inline_3858_m__5374__auto__$jscomp$inline_3857$$=$APP.$cljs$spec$alpha$explain_STAR_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$501_spec$jscomp$5$$==null?null:$JSCompiler_temp$jscomp$501_spec$jscomp$5$$)];if($m__5372__auto__$jscomp$inline_3858_m__5374__auto__$jscomp$inline_3857$$!=null)$JSCompiler_temp$jscomp$501_spec$jscomp$5$$=$m__5372__auto__$jscomp$inline_3858_m__5374__auto__$jscomp$inline_3857$$.$cljs$core$IFn$_invoke$arity$5$?
$m__5372__auto__$jscomp$inline_3858_m__5374__auto__$jscomp$inline_3857$$.$cljs$core$IFn$_invoke$arity$5$($JSCompiler_temp$jscomp$501_spec$jscomp$5$$,$path$jscomp$121$$,$via$jscomp$3$$,$in$$jscomp$42$$,$x$jscomp$877$$):$m__5372__auto__$jscomp$inline_3858_m__5374__auto__$jscomp$inline_3857$$($JSCompiler_temp$jscomp$501_spec$jscomp$5$$,$path$jscomp$121$$,$via$jscomp$3$$,$in$$jscomp$42$$,$x$jscomp$877$$);else if($m__5372__auto__$jscomp$inline_3858_m__5374__auto__$jscomp$inline_3857$$=$APP.$cljs$spec$alpha$explain_STAR_$$._,
$m__5372__auto__$jscomp$inline_3858_m__5374__auto__$jscomp$inline_3857$$!=null)$JSCompiler_temp$jscomp$501_spec$jscomp$5$$=$m__5372__auto__$jscomp$inline_3858_m__5374__auto__$jscomp$inline_3857$$.$cljs$core$IFn$_invoke$arity$5$?$m__5372__auto__$jscomp$inline_3858_m__5374__auto__$jscomp$inline_3857$$.$cljs$core$IFn$_invoke$arity$5$($JSCompiler_temp$jscomp$501_spec$jscomp$5$$,$path$jscomp$121$$,$via$jscomp$3$$,$in$$jscomp$42$$,$x$jscomp$877$$):$m__5372__auto__$jscomp$inline_3858_m__5374__auto__$jscomp$inline_3857$$($JSCompiler_temp$jscomp$501_spec$jscomp$5$$,
$path$jscomp$121$$,$via$jscomp$3$$,$in$$jscomp$42$$,$x$jscomp$877$$);else throw $APP.$cljs$core$missing_protocol$$("Spec.explain*",$JSCompiler_temp$jscomp$501_spec$jscomp$5$$);}return $JSCompiler_temp$jscomp$501_spec$jscomp$5$$};
$cljs$spec$alpha$with_gen_STAR_$$=function($JSCompiler_temp$jscomp$502_spec$jscomp$9$$,$gfn$jscomp$2$$){if($JSCompiler_temp$jscomp$502_spec$jscomp$9$$!=null&&$JSCompiler_temp$jscomp$502_spec$jscomp$9$$.$cljs$spec$alpha$Spec$with_gen_STAR_$arity$2$!=null)$JSCompiler_temp$jscomp$502_spec$jscomp$9$$=$JSCompiler_temp$jscomp$502_spec$jscomp$9$$.$cljs$spec$alpha$Spec$with_gen_STAR_$arity$2$($JSCompiler_temp$jscomp$502_spec$jscomp$9$$,$gfn$jscomp$2$$);else{var $m__5372__auto__$jscomp$inline_3863_m__5374__auto__$jscomp$inline_3862$$=
$cljs$spec$alpha$with_gen_STAR_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$502_spec$jscomp$9$$==null?null:$JSCompiler_temp$jscomp$502_spec$jscomp$9$$)];if($m__5372__auto__$jscomp$inline_3863_m__5374__auto__$jscomp$inline_3862$$!=null)$JSCompiler_temp$jscomp$502_spec$jscomp$9$$=$m__5372__auto__$jscomp$inline_3863_m__5374__auto__$jscomp$inline_3862$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3863_m__5374__auto__$jscomp$inline_3862$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$502_spec$jscomp$9$$,
$gfn$jscomp$2$$):$m__5372__auto__$jscomp$inline_3863_m__5374__auto__$jscomp$inline_3862$$($JSCompiler_temp$jscomp$502_spec$jscomp$9$$,$gfn$jscomp$2$$);else if($m__5372__auto__$jscomp$inline_3863_m__5374__auto__$jscomp$inline_3862$$=$cljs$spec$alpha$with_gen_STAR_$$._,$m__5372__auto__$jscomp$inline_3863_m__5374__auto__$jscomp$inline_3862$$!=null)$JSCompiler_temp$jscomp$502_spec$jscomp$9$$=$m__5372__auto__$jscomp$inline_3863_m__5374__auto__$jscomp$inline_3862$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3863_m__5374__auto__$jscomp$inline_3862$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$502_spec$jscomp$9$$,
$gfn$jscomp$2$$):$m__5372__auto__$jscomp$inline_3863_m__5374__auto__$jscomp$inline_3862$$($JSCompiler_temp$jscomp$502_spec$jscomp$9$$,$gfn$jscomp$2$$);else throw $APP.$cljs$core$missing_protocol$$("Spec.with-gen*",$JSCompiler_temp$jscomp$502_spec$jscomp$9$$);}return $JSCompiler_temp$jscomp$502_spec$jscomp$9$$};
$cljs$spec$alpha$reg_resolve$$=function($k$jscomp$451_spec$jscomp$13_spec$jscomp$inline_3867$$){if($cljs$core$ident_QMARK_$$($k$jscomp$451_spec$jscomp$13_spec$jscomp$inline_3867$$)){var $JSCompiler_temp$jscomp$503_reg$jscomp$1$$=$APP.$cljs$core$_deref$$($cljs$spec$alpha$registry_ref$$);$k$jscomp$451_spec$jscomp$13_spec$jscomp$inline_3867$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$503_reg$jscomp$1$$,$k$jscomp$451_spec$jscomp$13_spec$jscomp$inline_3867$$);if($cljs$core$ident_QMARK_$$($k$jscomp$451_spec$jscomp$13_spec$jscomp$inline_3867$$))a:{for(;;)if($cljs$core$ident_QMARK_$$($k$jscomp$451_spec$jscomp$13_spec$jscomp$inline_3867$$))$k$jscomp$451_spec$jscomp$13_spec$jscomp$inline_3867$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$503_reg$jscomp$1$$,$k$jscomp$451_spec$jscomp$13_spec$jscomp$inline_3867$$);else{$JSCompiler_temp$jscomp$503_reg$jscomp$1$$=$k$jscomp$451_spec$jscomp$13_spec$jscomp$inline_3867$$;break a}$JSCompiler_temp$jscomp$503_reg$jscomp$1$$=void 0}else $JSCompiler_temp$jscomp$503_reg$jscomp$1$$=$k$jscomp$451_spec$jscomp$13_spec$jscomp$inline_3867$$;return $JSCompiler_temp$jscomp$503_reg$jscomp$1$$}return $k$jscomp$451_spec$jscomp$13_spec$jscomp$inline_3867$$};
$cljs$spec$alpha$reg_resolve_BANG_$$=function($k$jscomp$452$$){if($cljs$core$ident_QMARK_$$($k$jscomp$452$$)){var $or__5025__auto__$jscomp$203$$=$cljs$spec$alpha$reg_resolve$$($k$jscomp$452$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$203$$))return $or__5025__auto__$jscomp$203$$;throw Error(["Unable to resolve spec: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$452$$)].join(""));}return $k$jscomp$452$$};
$cljs$spec$alpha$spec_QMARK_$$=function($x$jscomp$878$$){return $x$jscomp$878$$!=null&&$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$878$$.$cljs$spec$alpha$Spec$$?$x$jscomp$878$$:null};$cljs$spec$alpha$regex_QMARK_$$=function($x$jscomp$879$$){var $and__5023__auto__$jscomp$146$$=$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$879$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$146$$)?$x$jscomp$879$$:$and__5023__auto__$jscomp$146$$};
$cljs$spec$alpha$with_name$$=function($spec$jscomp$14$$,$name$jscomp$131$$){return $cljs$core$ident_QMARK_$$($spec$jscomp$14$$)?$spec$jscomp$14$$:$APP.$cljs$core$truth_$$($cljs$spec$alpha$regex_QMARK_$$($spec$jscomp$14$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($spec$jscomp$14$$,$cljs$cst$976$cljs_DOT_spec_DOT_alpha_SLASH_name$$,$name$jscomp$131$$):$spec$jscomp$14$$!=null&&($spec$jscomp$14$$.$cljs$lang$protocol_mask$partition0$$&131072||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$spec$jscomp$14$$.$cljs$core$IMeta$$)?
$APP.$cljs$core$with_meta$$($spec$jscomp$14$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$meta$$($spec$jscomp$14$$),$cljs$cst$976$cljs_DOT_spec_DOT_alpha_SLASH_name$$,$name$jscomp$131$$)):null};
$cljs$spec$alpha$spec_name$$=function($spec$jscomp$15$$){return $cljs$core$ident_QMARK_$$($spec$jscomp$15$$)?$spec$jscomp$15$$:$APP.$cljs$core$truth_$$($cljs$spec$alpha$regex_QMARK_$$($spec$jscomp$15$$))?$cljs$cst$976$cljs_DOT_spec_DOT_alpha_SLASH_name$$.$cljs$core$IFn$_invoke$arity$1$($spec$jscomp$15$$):$spec$jscomp$15$$!=null&&($spec$jscomp$15$$.$cljs$lang$protocol_mask$partition0$$&131072||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$spec$jscomp$15$$.$cljs$core$IMeta$$)?$cljs$cst$976$cljs_DOT_spec_DOT_alpha_SLASH_name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($spec$jscomp$15$$)):
null};
$cljs$spec$alpha$maybe_spec$$=function($spec_or_k$$){var $s$jscomp$414$$=function(){var $and__5023__auto__$jscomp$inline_3869_or__5025__auto__$jscomp$204_or__5025__auto____$1$jscomp$26_or__5025__auto____$2$jscomp$9$$=($and__5023__auto__$jscomp$inline_3869_or__5025__auto__$jscomp$204_or__5025__auto____$1$jscomp$26_or__5025__auto____$2$jscomp$9$$=$cljs$core$ident_QMARK_$$($spec_or_k$$))?$cljs$spec$alpha$reg_resolve$$($spec_or_k$$):$and__5023__auto__$jscomp$inline_3869_or__5025__auto__$jscomp$204_or__5025__auto____$1$jscomp$26_or__5025__auto____$2$jscomp$9$$;if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_3869_or__5025__auto__$jscomp$204_or__5025__auto____$1$jscomp$26_or__5025__auto____$2$jscomp$9$$))return $and__5023__auto__$jscomp$inline_3869_or__5025__auto__$jscomp$204_or__5025__auto____$1$jscomp$26_or__5025__auto____$2$jscomp$9$$;
$and__5023__auto__$jscomp$inline_3869_or__5025__auto__$jscomp$204_or__5025__auto____$1$jscomp$26_or__5025__auto____$2$jscomp$9$$=$cljs$spec$alpha$spec_QMARK_$$($spec_or_k$$);if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_3869_or__5025__auto__$jscomp$204_or__5025__auto____$1$jscomp$26_or__5025__auto____$2$jscomp$9$$))return $and__5023__auto__$jscomp$inline_3869_or__5025__auto__$jscomp$204_or__5025__auto____$1$jscomp$26_or__5025__auto____$2$jscomp$9$$;$and__5023__auto__$jscomp$inline_3869_or__5025__auto__$jscomp$204_or__5025__auto____$1$jscomp$26_or__5025__auto____$2$jscomp$9$$=
$cljs$spec$alpha$regex_QMARK_$$($spec_or_k$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_3869_or__5025__auto__$jscomp$204_or__5025__auto____$1$jscomp$26_or__5025__auto____$2$jscomp$9$$)?$and__5023__auto__$jscomp$inline_3869_or__5025__auto__$jscomp$204_or__5025__auto____$1$jscomp$26_or__5025__auto____$2$jscomp$9$$:null}();return $APP.$cljs$core$truth_$$($cljs$spec$alpha$regex_QMARK_$$($s$jscomp$414$$))?$cljs$spec$alpha$with_name$$($cljs$spec$alpha$regex_spec_impl$$($s$jscomp$414$$,
null),$cljs$spec$alpha$spec_name$$($s$jscomp$414$$)):$s$jscomp$414$$};$cljs$spec$alpha$the_spec$$=function($spec_or_k$jscomp$1$$){var $or__5025__auto__$jscomp$205$$=$cljs$spec$alpha$maybe_spec$$($spec_or_k$jscomp$1$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$205$$))return $or__5025__auto__$jscomp$205$$;if($cljs$core$ident_QMARK_$$($spec_or_k$jscomp$1$$))throw Error(["Unable to resolve spec: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($spec_or_k$jscomp$1$$)].join(""));return null};
$cljs$spec$alpha$fn_sym$$=function($f_n_xs$jscomp$23_xs__$1$jscomp$6$$){if($goog$string$internal$isEmptyOrWhitespace$$($goog$string$makeSafe$$($f_n_xs$jscomp$23_xs__$1$jscomp$6$$)))return null;$f_n_xs$jscomp$23_xs__$1$jscomp$6$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$demunge$$,$clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$02$$($f_n_xs$jscomp$23_xs__$1$jscomp$6$$,"$"));if(2<=$APP.$cljs$core$count$$($f_n_xs$jscomp$23_xs__$1$jscomp$6$$)&&$APP.$cljs$core$every_QMARK_$$(function($p1__33821_SHARP_$$){return!$goog$string$internal$isEmptyOrWhitespace$$($goog$string$makeSafe$$($p1__33821_SHARP_$$))},
$f_n_xs$jscomp$23_xs__$1$jscomp$6$$)){var $vec__33824_y$jscomp$295$$=$APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$butlast$$,$APP.$cljs$core$last$$)($f_n_xs$jscomp$23_xs__$1$jscomp$6$$);$f_n_xs$jscomp$23_xs__$1$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33824_y$jscomp$295$$,0,null);$vec__33824_y$jscomp$295$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33824_y$jscomp$295$$,1,null);return $APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$([$APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$(".",
$f_n_xs$jscomp$23_xs__$1$jscomp$6$$),"/",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($vec__33824_y$jscomp$295$$)].join(""))}return null};$cljs$spec$alpha$invalid_QMARK_$$=function($ret$jscomp$72$$){return $APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$,$ret$jscomp$72$$)};
$cljs$spec$alpha$with_gen$$=function($spec$jscomp$20_spec__$1$$,$gen_fn$$){$spec$jscomp$20_spec__$1$$=$cljs$spec$alpha$reg_resolve$$($spec$jscomp$20_spec__$1$$);return $APP.$cljs$core$truth_$$($cljs$spec$alpha$regex_QMARK_$$($spec$jscomp$20_spec__$1$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($spec$jscomp$20_spec__$1$$,$cljs$cst$980$cljs_DOT_spec_DOT_alpha_SLASH_gfn$$,$gen_fn$$):$cljs$spec$alpha$with_gen_STAR_$$($APP.$cljs$spec$alpha$specize$$.$cljs$core$IFn$_invoke$arity$1$($spec$jscomp$20_spec__$1$$),
$gen_fn$$)};
$cljs$spec$alpha$def_impl$$=function($k$jscomp$455$$,$form$jscomp$115_spec_35163__$1$$,$spec$jscomp$28$$){if($spec$jscomp$28$$==null)$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($cljs$spec$alpha$registry_ref$$,$APP.$cljs$core$dissoc$$,$k$jscomp$455$$);else{var $JSCompiler_inline_result$jscomp$505_or__5025__auto__$jscomp$inline_3873_or__5025__auto____$1$jscomp$inline_3874$$=$cljs$spec$alpha$spec_QMARK_$$($spec$jscomp$28$$);$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$505_or__5025__auto__$jscomp$inline_3873_or__5025__auto____$1$jscomp$inline_3874$$)||($JSCompiler_inline_result$jscomp$505_or__5025__auto__$jscomp$inline_3873_or__5025__auto____$1$jscomp$inline_3874$$=
$cljs$spec$alpha$regex_QMARK_$$($spec$jscomp$28$$),$JSCompiler_inline_result$jscomp$505_or__5025__auto__$jscomp$inline_3873_or__5025__auto____$1$jscomp$inline_3874$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$505_or__5025__auto__$jscomp$inline_3873_or__5025__auto____$1$jscomp$inline_3874$$)?$JSCompiler_inline_result$jscomp$505_or__5025__auto__$jscomp$inline_3873_or__5025__auto____$1$jscomp$inline_3874$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($cljs$spec$alpha$registry_ref$$),
$spec$jscomp$28$$));$form$jscomp$115_spec_35163__$1$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$505_or__5025__auto__$jscomp$inline_3873_or__5025__auto____$1$jscomp$inline_3874$$)?$spec$jscomp$28$$:$cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$115_spec_35163__$1$$,$spec$jscomp$28$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($cljs$spec$alpha$registry_ref$$,$APP.$cljs$core$assoc$$,$k$jscomp$455$$,$cljs$spec$alpha$with_name$$($form$jscomp$115_spec_35163__$1$$,
$k$jscomp$455$$))}};
$cljs$spec$alpha$dt$cljs$0core$0IFn$0_invoke$0arity$04$$=function($pred$jscomp$52$$,$x$jscomp$888$$,$form$jscomp$117$$,$cpred_QMARK_$$){if($APP.$cljs$core$truth_$$($pred$jscomp$52$$)){var $temp__5823__auto__$jscomp$81$$=$cljs$spec$alpha$the_spec$$($pred$jscomp$52$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$81$$))return $cljs$spec$alpha$conform_STAR_$$($APP.$cljs$spec$alpha$specize$$.$cljs$core$IFn$_invoke$arity$1$($temp__5823__auto__$jscomp$81$$),$x$jscomp$888$$);if($cljs$core$ifn_QMARK_$$($pred$jscomp$52$$))return $APP.$cljs$core$truth_$$($cpred_QMARK_$$)?
$pred$jscomp$52$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$52$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$888$$):$pred$jscomp$52$$($x$jscomp$888$$):$APP.$cljs$core$truth_$$($pred$jscomp$52$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$52$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$888$$):$pred$jscomp$52$$($x$jscomp$888$$))?$x$jscomp$888$$:$cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$;throw Error([$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$form$jscomp$117$$])),
" is not a fn, expected predicate fn"].join(""));}return $x$jscomp$888$$};$APP.$cljs$spec$alpha$valid_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($spec$jscomp$30_spec__$1$jscomp$2$$,$x$jscomp$889$$){$spec$jscomp$30_spec__$1$jscomp$2$$=$APP.$cljs$spec$alpha$specize$$.$cljs$core$IFn$_invoke$arity$1$($spec$jscomp$30_spec__$1$jscomp$2$$);return!$cljs$spec$alpha$invalid_QMARK_$$($cljs$spec$alpha$conform_STAR_$$($spec$jscomp$30_spec__$1$jscomp$2$$,$x$jscomp$889$$))};
$cljs$spec$alpha$explain_1$$=function($form$jscomp$120_temp__5823__auto__$jscomp$inline_3879$$,$pred$jscomp$55_pred__$1$jscomp$5$$,$JSCompiler_temp$jscomp$507_path$jscomp$127$$,$JSCompiler_inline_result$jscomp$508_via$jscomp$5$$,$in$$jscomp$44$$,$v$jscomp$252$$){$pred$jscomp$55_pred__$1$jscomp$5$$=$cljs$spec$alpha$maybe_spec$$($pred$jscomp$55_pred__$1$jscomp$5$$);$APP.$cljs$core$truth_$$($cljs$spec$alpha$spec_QMARK_$$($pred$jscomp$55_pred__$1$jscomp$5$$))?($form$jscomp$120_temp__5823__auto__$jscomp$inline_3879$$=
$cljs$spec$alpha$spec_name$$($pred$jscomp$55_pred__$1$jscomp$5$$),$JSCompiler_inline_result$jscomp$508_via$jscomp$5$$=$APP.$cljs$core$truth_$$($form$jscomp$120_temp__5823__auto__$jscomp$inline_3879$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$508_via$jscomp$5$$,$form$jscomp$120_temp__5823__auto__$jscomp$inline_3879$$):$JSCompiler_inline_result$jscomp$508_via$jscomp$5$$,$JSCompiler_temp$jscomp$507_path$jscomp$127$$=$APP.$cljs$spec$alpha$explain_STAR_$$($pred$jscomp$55_pred__$1$jscomp$5$$,
$JSCompiler_temp$jscomp$507_path$jscomp$127$$,$JSCompiler_inline_result$jscomp$508_via$jscomp$5$$,$in$$jscomp$44$$,$v$jscomp$252$$)):$JSCompiler_temp$jscomp$507_path$jscomp$127$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$296$path$$,$JSCompiler_temp$jscomp$507_path$jscomp$127$$,$APP.$cljs$cst$351$pred$$,$form$jscomp$120_temp__5823__auto__$jscomp$inline_3879$$,$APP.$cljs$cst$108$val$$,
$v$jscomp$252$$,$APP.$cljs$cst$143$via$$,$JSCompiler_inline_result$jscomp$508_via$jscomp$5$$,$APP.$cljs$cst$297$in$$,$in$$jscomp$44$$],null)],null);return $JSCompiler_temp$jscomp$507_path$jscomp$127$$};
$cljs$spec$alpha$t_cljs$0spec$0alpha34071$$=function($keys__GT_specnames$$,$opt$$,$req_un$$,$opt_un$$,$map__34069$$,$gfn$jscomp$4$$,$pred_exprs$$,$keys_pred$$,$argm$$,$opt_keys$$,$req_specs$$,$p__34067$$,$req$$,$id$jscomp$19$$,$req_keys$$,$opt_specs$jscomp$1$$,$k__GT_s$$,$pred_forms$$,$meta34072$$){this.$keys__GT_specnames$=$keys__GT_specnames$$;this.$opt$=$opt$$;this.$req_un$=$req_un$$;this.$opt_un$=$opt_un$$;this.$map__34069$=$map__34069$$;this.$gfn$=$gfn$jscomp$4$$;this.$pred_exprs$=$pred_exprs$$;
this.$keys_pred$=$keys_pred$$;this.$argm$=$argm$$;this.$opt_keys$=$opt_keys$$;this.$req_specs$=$req_specs$$;this.$p__34067$=$p__34067$$;this.$req$=$req$$;this.id=$id$jscomp$19$$;this.$req_keys$=$req_keys$$;this.$opt_specs$=$opt_specs$jscomp$1$$;this.$k__GT_s$=$k__GT_s$$;this.$pred_forms$=$pred_forms$$;this.$meta34072$=$meta34072$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$spec$alpha$map_spec_impl$$=function($p__34067$jscomp$2$$){var $map__34069__$1$$=$APP.$cljs$core$__destructure_map$$($p__34067$jscomp$2$$),$opt$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34069__$1$$,$APP.$cljs$cst$993$opt$$),$req_un$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34069__$1$$,$cljs$cst$994$req_un$$),$opt_un$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34069__$1$$,$cljs$cst$995$opt_un$$),$gfn$jscomp$6$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34069__$1$$,$cljs$cst$990$gfn$$),$pred_exprs$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34069__$1$$,$cljs$cst$1014$pred_exprs$$),$keys_pred$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34069__$1$$,$cljs$cst$1015$keys_pred$$),$opt_keys$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34069__$1$$,$cljs$cst$1016$opt_keys$$),$req_specs$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34069__$1$$,
$cljs$cst$1017$req_specs$$),$req$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34069__$1$$,$cljs$cst$992$req$$),$req_keys$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34069__$1$$,$cljs$cst$1018$req_keys$$),$opt_specs$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34069__$1$$,$cljs$cst$1019$opt_specs$$),$pred_forms$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34069__$1$$,$cljs$cst$1020$pred_forms$$),
$k__GT_s$jscomp$2$$=$APP.$cljs$core$zipmap$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($req_keys$jscomp$2$$,$opt_keys$jscomp$2$$),$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($req_specs$jscomp$2$$,$opt_specs$jscomp$3$$)),$id$jscomp$21$$=$cljs$core$random_uuid$$();return new $cljs$spec$alpha$t_cljs$0spec$0alpha34071$$(function($p1__34063_SHARP_$$){var $or__5025__auto__$jscomp$213$$=$k__GT_s$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$k__GT_s$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($p1__34063_SHARP_$$):
$k__GT_s$jscomp$2$$($p1__34063_SHARP_$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$213$$)?$or__5025__auto__$jscomp$213$$:$p1__34063_SHARP_$$},$opt$jscomp$2$$,$req_un$jscomp$2$$,$opt_un$jscomp$2$$,$map__34069__$1$$,$gfn$jscomp$6$$,$pred_exprs$jscomp$2$$,$keys_pred$jscomp$2$$,$map__34069__$1$$,$opt_keys$jscomp$2$$,$req_specs$jscomp$2$$,$p__34067$jscomp$2$$,$req$jscomp$2$$,$id$jscomp$21$$,$req_keys$jscomp$2$$,$opt_specs$jscomp$3$$,$k__GT_s$jscomp$2$$,$pred_forms$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$spec$alpha$t_cljs$0spec$0alpha34147$$=function($form$jscomp$122$$,$pred$jscomp$57$$,$gfn$jscomp$7$$,$cpred_QMARK_$jscomp$1$$,$unc$$,$meta34148$$){this.form=$form$jscomp$122$$;this.$pred$=$pred$jscomp$57$$;this.$gfn$=$gfn$jscomp$7$$;this.$cpred_QMARK_$=$cpred_QMARK_$jscomp$1$$;this.$unc$=$unc$$;this.$meta34148$=$meta34148$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$04$$=function($form$jscomp$124$$,$pred$jscomp$59$$){return $cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$05$$($form$jscomp$124$$,$pred$jscomp$59$$,null,null,null)};
$cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$05$$=function($G__34146_form$jscomp$125$$,$pred$jscomp$60$$,$gfn$jscomp$10$$,$cpred_QMARK_$jscomp$4$$,$unc$jscomp$2$$){return $APP.$cljs$core$truth_$$($cljs$spec$alpha$spec_QMARK_$$($pred$jscomp$60$$))?$APP.$cljs$core$truth_$$($gfn$jscomp$10$$)?$cljs$spec$alpha$with_gen$$($pred$jscomp$60$$,$gfn$jscomp$10$$):$pred$jscomp$60$$:$APP.$cljs$core$truth_$$($cljs$spec$alpha$regex_QMARK_$$($pred$jscomp$60$$))?$cljs$spec$alpha$regex_spec_impl$$($pred$jscomp$60$$,
$gfn$jscomp$10$$):$cljs$core$ident_QMARK_$$($pred$jscomp$60$$)?($G__34146_form$jscomp$125$$=$cljs$spec$alpha$the_spec$$($pred$jscomp$60$$),$APP.$cljs$core$truth_$$($gfn$jscomp$10$$)?$cljs$spec$alpha$with_gen$$($G__34146_form$jscomp$125$$,$gfn$jscomp$10$$):$G__34146_form$jscomp$125$$):new $cljs$spec$alpha$t_cljs$0spec$0alpha34147$$($G__34146_form$jscomp$125$$,$pred$jscomp$60$$,$gfn$jscomp$10$$,$cpred_QMARK_$jscomp$4$$,$unc$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$spec$alpha$and_preds$$=function($first__34254_pred__$1$jscomp$6_ret__$1$jscomp$11_x$jscomp$909$$,$G__34244__$1_G__35295_preds$jscomp$9_preds__$2_seq__34253_seq__34253__$1$$,$forms$jscomp$14_nret_ret__$2$jscomp$3$$){var $G__34245__$1_G__35296_first__34257_forms__$2_seq__34247_seq__34250$$=$APP.$cljs$core$seq$$($G__34244__$1_G__35295_preds$jscomp$9_preds__$2_seq__34253_seq__34253__$1$$);$APP.$cljs$core$first$$($G__34245__$1_G__35296_first__34257_forms__$2_seq__34247_seq__34250$$);$APP.$cljs$core$next$$($G__34245__$1_G__35296_first__34257_forms__$2_seq__34247_seq__34250$$);
$G__34245__$1_G__35296_first__34257_forms__$2_seq__34247_seq__34250$$=$APP.$cljs$core$seq$$($forms$jscomp$14_nret_ret__$2$jscomp$3$$);$APP.$cljs$core$first$$($G__34245__$1_G__35296_first__34257_forms__$2_seq__34247_seq__34250$$);$APP.$cljs$core$next$$($G__34245__$1_G__35296_first__34257_forms__$2_seq__34247_seq__34250$$);for($G__34245__$1_G__35296_first__34257_forms__$2_seq__34247_seq__34250$$=$forms$jscomp$14_nret_ret__$2$jscomp$3$$;;){$forms$jscomp$14_nret_ret__$2$jscomp$3$$=$first__34254_pred__$1$jscomp$6_ret__$1$jscomp$11_x$jscomp$909$$;
$G__34244__$1_G__35295_preds$jscomp$9_preds__$2_seq__34253_seq__34253__$1$$=$APP.$cljs$core$seq$$($G__34244__$1_G__35295_preds$jscomp$9_preds__$2_seq__34253_seq__34253__$1$$);$first__34254_pred__$1$jscomp$6_ret__$1$jscomp$11_x$jscomp$909$$=$APP.$cljs$core$first$$($G__34244__$1_G__35295_preds$jscomp$9_preds__$2_seq__34253_seq__34253__$1$$);$G__34244__$1_G__35295_preds$jscomp$9_preds__$2_seq__34253_seq__34253__$1$$=$APP.$cljs$core$next$$($G__34244__$1_G__35295_preds$jscomp$9_preds__$2_seq__34253_seq__34253__$1$$);
var $seq__34256_seq__34256__$1$$=$APP.$cljs$core$seq$$($G__34245__$1_G__35296_first__34257_forms__$2_seq__34247_seq__34250$$);$G__34245__$1_G__35296_first__34257_forms__$2_seq__34247_seq__34250$$=$APP.$cljs$core$first$$($seq__34256_seq__34256__$1$$);$seq__34256_seq__34256__$1$$=$APP.$cljs$core$next$$($seq__34256_seq__34256__$1$$);var $form__$1$jscomp$1$$=$G__34245__$1_G__35296_first__34257_forms__$2_seq__34247_seq__34250$$;$G__34245__$1_G__35296_first__34257_forms__$2_seq__34247_seq__34250$$=$seq__34256_seq__34256__$1$$;
if($APP.$cljs$core$truth_$$($first__34254_pred__$1$jscomp$6_ret__$1$jscomp$11_x$jscomp$909$$)){$forms$jscomp$14_nret_ret__$2$jscomp$3$$=$cljs$spec$alpha$dt$cljs$0core$0IFn$0_invoke$0arity$04$$($first__34254_pred__$1$jscomp$6_ret__$1$jscomp$11_x$jscomp$909$$,$forms$jscomp$14_nret_ret__$2$jscomp$3$$,$form__$1$jscomp$1$$,null);if($cljs$spec$alpha$invalid_QMARK_$$($forms$jscomp$14_nret_ret__$2$jscomp$3$$))return $cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$;$first__34254_pred__$1$jscomp$6_ret__$1$jscomp$11_x$jscomp$909$$=
$forms$jscomp$14_nret_ret__$2$jscomp$3$$}else return $forms$jscomp$14_nret_ret__$2$jscomp$3$$}};
$cljs$spec$alpha$explain_pred_list$$=function($G__34277__$1_forms$jscomp$15_forms__$2$jscomp$1_seq__34293_seq__34293__$1$$,$G__35303_preds$jscomp$10_ret__$2$jscomp$4$$,$path$jscomp$137$$,$via$jscomp$11$$,$in$$jscomp$50$$,$first__34294_form__$1$jscomp$2_ret__$1$jscomp$12_x$jscomp$910$$){var $G__34278__$1_first__34297_nret$jscomp$1_seq__34283_seq__34286$$=$APP.$cljs$core$seq$$($G__34277__$1_forms$jscomp$15_forms__$2$jscomp$1_seq__34293_seq__34293__$1$$);$APP.$cljs$core$first$$($G__34278__$1_first__34297_nret$jscomp$1_seq__34283_seq__34286$$);
$APP.$cljs$core$next$$($G__34278__$1_first__34297_nret$jscomp$1_seq__34283_seq__34286$$);$G__34278__$1_first__34297_nret$jscomp$1_seq__34283_seq__34286$$=$APP.$cljs$core$seq$$($G__35303_preds$jscomp$10_ret__$2$jscomp$4$$);$APP.$cljs$core$first$$($G__34278__$1_first__34297_nret$jscomp$1_seq__34283_seq__34286$$);$APP.$cljs$core$next$$($G__34278__$1_first__34297_nret$jscomp$1_seq__34283_seq__34286$$);for($G__34278__$1_first__34297_nret$jscomp$1_seq__34283_seq__34286$$=$G__35303_preds$jscomp$10_ret__$2$jscomp$4$$;;){$G__35303_preds$jscomp$10_ret__$2$jscomp$4$$=
$first__34294_form__$1$jscomp$2_ret__$1$jscomp$12_x$jscomp$910$$;$G__34277__$1_forms$jscomp$15_forms__$2$jscomp$1_seq__34293_seq__34293__$1$$=$APP.$cljs$core$seq$$($G__34277__$1_forms$jscomp$15_forms__$2$jscomp$1_seq__34293_seq__34293__$1$$);$first__34294_form__$1$jscomp$2_ret__$1$jscomp$12_x$jscomp$910$$=$APP.$cljs$core$first$$($G__34277__$1_forms$jscomp$15_forms__$2$jscomp$1_seq__34293_seq__34293__$1$$);$G__34277__$1_forms$jscomp$15_forms__$2$jscomp$1_seq__34293_seq__34293__$1$$=$APP.$cljs$core$next$$($G__34277__$1_forms$jscomp$15_forms__$2$jscomp$1_seq__34293_seq__34293__$1$$);
var $G__35304_pred__$1$jscomp$7_seq__34296$$=$APP.$cljs$core$seq$$($G__34278__$1_first__34297_nret$jscomp$1_seq__34283_seq__34286$$);$G__34278__$1_first__34297_nret$jscomp$1_seq__34283_seq__34286$$=$APP.$cljs$core$first$$($G__35304_pred__$1$jscomp$7_seq__34296$$);var $preds__$2$jscomp$1_seq__34296__$1$$=$APP.$cljs$core$next$$($G__35304_pred__$1$jscomp$7_seq__34296$$);$G__35304_pred__$1$jscomp$7_seq__34296$$=$G__34278__$1_first__34297_nret$jscomp$1_seq__34283_seq__34286$$;if($APP.$cljs$core$truth_$$($G__35304_pred__$1$jscomp$7_seq__34296$$)){$G__34278__$1_first__34297_nret$jscomp$1_seq__34283_seq__34286$$=
$cljs$spec$alpha$dt$cljs$0core$0IFn$0_invoke$0arity$04$$($G__35304_pred__$1$jscomp$7_seq__34296$$,$G__35303_preds$jscomp$10_ret__$2$jscomp$4$$,$first__34294_form__$1$jscomp$2_ret__$1$jscomp$12_x$jscomp$910$$,null);if($cljs$spec$alpha$invalid_QMARK_$$($G__34278__$1_first__34297_nret$jscomp$1_seq__34283_seq__34286$$))return $cljs$spec$alpha$explain_1$$($first__34294_form__$1$jscomp$2_ret__$1$jscomp$12_x$jscomp$910$$,$G__35304_pred__$1$jscomp$7_seq__34296$$,$path$jscomp$137$$,$via$jscomp$11$$,$in$$jscomp$50$$,
$G__35303_preds$jscomp$10_ret__$2$jscomp$4$$);$G__35303_preds$jscomp$10_ret__$2$jscomp$4$$=$G__34277__$1_forms$jscomp$15_forms__$2$jscomp$1_seq__34293_seq__34293__$1$$;$G__35304_pred__$1$jscomp$7_seq__34296$$=$preds__$2$jscomp$1_seq__34296__$1$$;$first__34294_form__$1$jscomp$2_ret__$1$jscomp$12_x$jscomp$910$$=$G__34278__$1_first__34297_nret$jscomp$1_seq__34283_seq__34286$$;$G__34277__$1_forms$jscomp$15_forms__$2$jscomp$1_seq__34293_seq__34293__$1$$=$G__35303_preds$jscomp$10_ret__$2$jscomp$4$$;$G__34278__$1_first__34297_nret$jscomp$1_seq__34283_seq__34286$$=
$G__35304_pred__$1$jscomp$7_seq__34296$$}else return null}};
$cljs$spec$alpha$coll_prob$$=function($JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$,$kfn_pred$jscomp$68$$,$kform_kform__$1$$,$distinct$$,$JSCompiler_inline_result$jscomp$10698_and__5023__auto__$jscomp$inline_11528_count$jscomp$53$$,$min_count$jscomp$1$$,$max_count$$,$path$jscomp$140$$,$via$jscomp$13$$,$in$$jscomp$52$$){$kfn_pred$jscomp$68$$=$APP.$cljs$core$truth_$$($kfn_pred$jscomp$68$$)?$kfn_pred$jscomp$68$$:$APP.$cljs$core$coll_QMARK_$$;$kform_kform__$1$$=$APP.$cljs$core$truth_$$($kform_kform__$1$$)?
$kform_kform__$1$$:$cljs$cst$1044$cljs_DOT_core_SLASH_coll_QMARK_$$;$cljs$spec$alpha$invalid_QMARK_$$($cljs$spec$alpha$dt$cljs$0core$0IFn$0_invoke$0arity$04$$($kfn_pred$jscomp$68$$,$JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$,$cljs$cst$977$cljs_DOT_spec_DOT_alpha_SLASH_unknown$$,null))?$JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$=$cljs$spec$alpha$explain_1$$($kform_kform__$1$$,$kfn_pred$jscomp$68$$,$path$jscomp$140$$,$via$jscomp$13$$,$in$$jscomp$52$$,
$JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10698_and__5023__auto__$jscomp$inline_11528_count$jscomp$53$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10698_and__5023__auto__$jscomp$inline_11528_count$jscomp$53$$,$cljs$core$bounded_count$$($JSCompiler_inline_result$jscomp$10698_and__5023__auto__$jscomp$inline_11528_count$jscomp$53$$,$JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$)):
$JSCompiler_inline_result$jscomp$10698_and__5023__auto__$jscomp$inline_11528_count$jscomp$53$$)?$JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$296$path$$,$path$jscomp$140$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$List$$(null,
$cljs$cst$1032$cljs_DOT_core_SLASH__EQ_$$,null,1,null),new $APP.$cljs$core$List$$(null,$JSCompiler_inline_result$jscomp$10698_and__5023__auto__$jscomp$inline_11528_count$jscomp$53$$,null,1,null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$List$$(null,$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$List$$(null,$cljs$cst$1033$cljs_DOT_core_SLASH_count$$,
null,1,null),new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$979$_PERCENT_$$,null,1,null)))),null,1,null)])))),$APP.$cljs$cst$108$val$$,$JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$,$APP.$cljs$cst$143$via$$,$via$jscomp$13$$,$APP.$cljs$cst$297$in$$,$in$$jscomp$52$$],null)],null):($JSCompiler_inline_result$jscomp$10698_and__5023__auto__$jscomp$inline_11528_count$jscomp$53$$=$APP.$cljs$core$truth_$$($min_count$jscomp$1$$)?$min_count$jscomp$1$$:$max_count$$,$JSCompiler_inline_result$jscomp$10698_and__5023__auto__$jscomp$inline_11528_count$jscomp$53$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10698_and__5023__auto__$jscomp$inline_11528_count$jscomp$53$$)?!(($APP.$cljs$core$truth_$$($min_count$jscomp$1$$)?$min_count$jscomp$1$$:0)<=$cljs$core$bounded_count$$($APP.$cljs$core$truth_$$($max_count$$)?$max_count$$+1:$min_count$jscomp$1$$,$JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$)&&$cljs$core$bounded_count$$($APP.$cljs$core$truth_$$($max_count$$)?$max_count$$+1:$min_count$jscomp$1$$,$JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$)<=
($APP.$cljs$core$truth_$$($max_count$$)?$max_count$$:9007199254740991)):$JSCompiler_inline_result$jscomp$10698_and__5023__auto__$jscomp$inline_11528_count$jscomp$53$$,$JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10698_and__5023__auto__$jscomp$inline_11528_count$jscomp$53$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$296$path$$,$path$jscomp$140$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$List$$(null,$cljs$cst$1045$cljs_DOT_core_SLASH__LT__EQ_$$,null,1,null),new $APP.$cljs$core$List$$(null,$APP.$cljs$core$truth_$$($min_count$jscomp$1$$)?$min_count$jscomp$1$$:0,null,1,null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$List$$(null,
$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$List$$(null,$cljs$cst$1033$cljs_DOT_core_SLASH_count$$,null,1,null),new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$979$_PERCENT_$$,null,1,null)))),null,1,null),new $APP.$cljs$core$List$$(null,$APP.$cljs$core$truth_$$($max_count$$)?$max_count$$:9007199254740991,null,1,null)])))),$APP.$cljs$cst$108$val$$,$JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$,
$APP.$cljs$cst$143$via$$,$via$jscomp$13$$,$APP.$cljs$cst$297$in$$,$in$$jscomp$52$$],null)],null):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($distinct$$)?!$APP.$cljs$core$empty_QMARK_$$($JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$)&&$APP.$cljs$core$not$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$distinct_QMARK_$$,$JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$)):$distinct$$)?new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$296$path$$,$path$jscomp$140$$,$APP.$cljs$cst$351$pred$$,$cljs$cst$1046$distinct_QMARK_$$,$APP.$cljs$cst$108$val$$,$JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$,$APP.$cljs$cst$143$via$$,$via$jscomp$13$$,$APP.$cljs$cst$297$in$$,$in$$jscomp$52$$],null)],null):null);return $JSCompiler_temp$jscomp$10696_JSCompiler_temp$jscomp$10697_x$jscomp$917$$};
$cljs$spec$alpha$t_cljs$0spec$0alpha34417$$=function($form$jscomp$134$$,$max_count$jscomp$1$$,$check_QMARK_$$,$gfn$jscomp$26$$,$gen_max$jscomp$1$$,$pred$jscomp$69$$,$cpred$$,$conform_keys$$,$kind_form$$,$addcv$$,$cfns$$,$describe_form$$,$distinct$jscomp$1$$,$spec$jscomp$33$$,$p__34414$$,$kfn$jscomp$1$$,$gen_into$$,$map__34415$$,$count$jscomp$54$$,$min_count$jscomp$2$$,$opts$jscomp$224$$,$kind$jscomp$19$$,$conform_all$$,$conform_into$$,$meta34418$$){this.form=$form$jscomp$134$$;this.$max_count$=$max_count$jscomp$1$$;
this.$check_QMARK_$=$check_QMARK_$$;this.$gfn$=$gfn$jscomp$26$$;this.$gen_max$=$gen_max$jscomp$1$$;this.$pred$=$pred$jscomp$69$$;this.$cpred$=$cpred$$;this.$conform_keys$=$conform_keys$$;this.$kind_form$=$kind_form$$;this.$addcv$=$addcv$$;this.$cfns$=$cfns$$;this.$describe_form$=$describe_form$$;this.distinct=$distinct$jscomp$1$$;this.$spec$=$spec$jscomp$33$$;this.$p__34414$=$p__34414$$;this.$kfn$=$kfn$jscomp$1$$;this.$gen_into$=$gen_into$$;this.$map__34415$=$map__34415$$;this.count=$count$jscomp$54$$;
this.$min_count$=$min_count$jscomp$2$$;this.$opts$=$opts$jscomp$224$$;this.kind=$kind$jscomp$19$$;this.$conform_all$=$conform_all$$;this.$conform_into$=$conform_into$$;this.$meta34418$=$meta34418$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$spec$alpha$every_impl$cljs$0core$0IFn$0_invoke$0arity$04$$=function($form$jscomp$137$$,$pred$jscomp$72$$,$p__34414$jscomp$2$$,$gfn$jscomp$28$$){function $addcv$jscomp$2$$($ret$jscomp$89$$,$i$jscomp$367$$,$v$jscomp$263$$,$cv$jscomp$5$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($ret$jscomp$89$$,$cv$jscomp$5$$)}var $map__34415__$1$$=$APP.$cljs$core$__destructure_map$$($p__34414$jscomp$2$$),$max_count$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34415__$1$$,
$cljs$cst$1072$max_count$$),$kind_form$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34415__$1$$,$cljs$cst$1073$cljs_DOT_spec_DOT_alpha_SLASH_kind_form$$),$gen_max$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__34415__$1$$,$cljs$cst$1074$gen_max$$,20),$cpred$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34415__$1$$,$cljs$cst$1075$cljs_DOT_spec_DOT_alpha_SLASH_cpred$$),$conform_keys$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34415__$1$$,
$cljs$cst$1076$conform_keys$$),$describe_form$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34415__$1$$,$cljs$cst$1077$cljs_DOT_spec_DOT_alpha_SLASH_describe$$),$distinct$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34415__$1$$,$cljs$cst$1078$distinct$$),$kfn$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34415__$1$$,$cljs$cst$1079$cljs_DOT_spec_DOT_alpha_SLASH_kfn$$),$count$jscomp$56$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34415__$1$$,
$APP.$cljs$cst$1080$count$$),$min_count$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34415__$1$$,$cljs$cst$1081$min_count$$),$kind$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34415__$1$$,$APP.$cljs$cst$947$kind$$),$conform_all$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34415__$1$$,$cljs$cst$1082$cljs_DOT_spec_DOT_alpha_SLASH_conform_all$$),$conform_into$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34415__$1$$,
$cljs$cst$764$into$$),$gen_into$jscomp$2$$=$APP.$cljs$core$truth_$$($conform_into$jscomp$2$$)?$APP.$cljs$core$empty$$($conform_into$jscomp$2$$):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cljs$spec$alpha$empty_coll$$,$kind_form$jscomp$2$$),$spec$jscomp$35$$=new $APP.$cljs$core$Delay$$(function(){return $APP.$cljs$spec$alpha$specize$$.$cljs$core$IFn$_invoke$arity$1$($pred$jscomp$72$$)});return new $cljs$spec$alpha$t_cljs$0spec$0alpha34417$$($form$jscomp$137$$,$max_count$jscomp$3$$,function($p1__34403_SHARP_$$){return $APP.$cljs$spec$alpha$valid_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_deref$$($spec$jscomp$35$$),
$p1__34403_SHARP_$$)},$gfn$jscomp$28$$,$gen_max$jscomp$3$$,$pred$jscomp$72$$,$cpred$jscomp$2$$,$conform_keys$jscomp$2$$,$kind_form$jscomp$2$$,$addcv$jscomp$2$$,function($x$jscomp$924$$){return $APP.$cljs$core$vector_QMARK_$$($x$jscomp$924$$)&&($APP.$cljs$core$not$$($conform_into$jscomp$2$$)||$APP.$cljs$core$vector_QMARK_$$($conform_into$jscomp$2$$))?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$identity$$,function($ret$jscomp$90$$,$i$jscomp$368$$,
$v$jscomp$264$$,$cv$jscomp$6$$){return $v$jscomp$264$$===$cv$jscomp$6$$?$ret$jscomp$90$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($ret$jscomp$90$$,$i$jscomp$368$$,$cv$jscomp$6$$)},$APP.$cljs$core$identity$$],null):$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$155_or__5025__auto__$jscomp$229$$=$APP.$cljs$core$map_QMARK_$$($x$jscomp$924$$);return $and__5023__auto__$jscomp$155_or__5025__auto__$jscomp$229$$?($and__5023__auto__$jscomp$155_or__5025__auto__$jscomp$229$$=
$APP.$cljs$core$truth_$$($kind$jscomp$21$$)?$APP.$cljs$core$not$$($conform_into$jscomp$2$$):$kind$jscomp$21$$,$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$155_or__5025__auto__$jscomp$229$$)?$and__5023__auto__$jscomp$155_or__5025__auto__$jscomp$229$$:$APP.$cljs$core$map_QMARK_$$($conform_into$jscomp$2$$)):$and__5023__auto__$jscomp$155_or__5025__auto__$jscomp$229$$}())?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$($conform_keys$jscomp$2$$)?
$APP.$cljs$core$empty$$:$APP.$cljs$core$identity$$,function($ret$jscomp$91$$,$i$jscomp$369$$,$v$jscomp$265$$,$cv$jscomp$7$$){return $v$jscomp$265$$===$cv$jscomp$7$$&&$APP.$cljs$core$not$$($conform_keys$jscomp$2$$)?$ret$jscomp$91$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($ret$jscomp$91$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$truth_$$($conform_keys$jscomp$2$$)?$cv$jscomp$7$$:$v$jscomp$265$$,0),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cv$jscomp$7$$,
1))},$APP.$cljs$core$identity$$],null):$APP.$cljs$core$list_QMARK_$$($conform_into$jscomp$2$$)||$APP.$cljs$core$seq_QMARK_$$($conform_into$jscomp$2$$)||$APP.$cljs$core$not$$($conform_into$jscomp$2$$)&&($APP.$cljs$core$list_QMARK_$$($x$jscomp$924$$)||$APP.$cljs$core$seq_QMARK_$$($x$jscomp$924$$))?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$empty$$,$addcv$jscomp$2$$,$APP.$cljs$core$reverse$$],null):new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[function($p1__34405_SHARP_$$){return $APP.$cljs$core$empty$$($APP.$cljs$core$truth_$$($conform_into$jscomp$2$$)?$conform_into$jscomp$2$$:$p1__34405_SHARP_$$)},$addcv$jscomp$2$$,$APP.$cljs$core$identity$$],null)},$describe_form$jscomp$2$$,$distinct$jscomp$3$$,$spec$jscomp$35$$,$p__34414$jscomp$2$$,function(){return $APP.$cljs$core$truth_$$($kfn$jscomp$3$$)?$kfn$jscomp$3$$:function($i$jscomp$366$$){return $i$jscomp$366$$}}(),$gen_into$jscomp$2$$,$map__34415__$1$$,
$count$jscomp$56$$,$min_count$jscomp$4$$,$map__34415__$1$$,$kind$jscomp$21$$,$conform_all$jscomp$2$$,$conform_into$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$cljs$spec$alpha$accept$$=function($x$jscomp$925$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$,$cljs$cst$1083$cljs_DOT_spec_DOT_alpha_SLASH_accept$$,$cljs$cst$1084$ret$$,$x$jscomp$925$$],null)};
$cljs$spec$alpha$accept_QMARK_$$=function($map__34484__$1_op_p__34483$$){$map__34484__$1_op_p__34483$$=$APP.$cljs$core$__destructure_map$$($map__34484__$1_op_p__34483$$);$map__34484__$1_op_p__34483$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34484__$1_op_p__34483$$,$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1083$cljs_DOT_spec_DOT_alpha_SLASH_accept$$,$map__34484__$1_op_p__34483$$)};
$cljs$spec$alpha$rep_STAR_$$=function($p1$jscomp$11$$,$p2$jscomp$10$$,$ret$jscomp$93$$,$r$jscomp$67_splice$$,$form$jscomp$138$$){return $APP.$cljs$core$truth_$$($p1$jscomp$11$$)?($r$jscomp$67_splice$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$,$cljs$cst$1090$cljs_DOT_spec_DOT_alpha_SLASH_rep$$,$APP.$cljs$cst$1091$p2$$,$p2$jscomp$10$$,$cljs$cst$1092$splice$$,$r$jscomp$67_splice$$,$cljs$cst$1087$forms$$,$form$jscomp$138$$,$APP.$cljs$cst$266$id$$,
$cljs$core$random_uuid$$()],null),$cljs$spec$alpha$accept_QMARK_$$($p1$jscomp$11$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($r$jscomp$67_splice$$,$APP.$cljs$cst$1093$p1$$,$p2$jscomp$10$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$1084$ret$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($ret$jscomp$93$$,$cljs$cst$1084$ret$$.$cljs$core$IFn$_invoke$arity$1$($p1$jscomp$11$$))])):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($r$jscomp$67_splice$$,
$APP.$cljs$cst$1093$p1$$,$p1$jscomp$11$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$1084$ret$$,$ret$jscomp$93$$]))):null};
$cljs$spec$alpha$filter_alt$$=function($pks_ps$jscomp$9$$,$ks$jscomp$44$$,$forms$jscomp$24$$,$f$jscomp$500$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($ks$jscomp$44$$)?$ks$jscomp$44$$:$forms$jscomp$24$$)?($pks_ps$jscomp$9$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($G__34535_p1__34529_SHARP_$$){$G__34535_p1__34529_SHARP_$$=$APP.$cljs$core$first$$($G__34535_p1__34529_SHARP_$$);return $f$jscomp$500$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$500$$.$cljs$core$IFn$_invoke$arity$1$($G__34535_p1__34529_SHARP_$$):
$f$jscomp$500$$($G__34535_p1__34529_SHARP_$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$vector$$,$pks_ps$jscomp$9$$,function(){var $or__5025__auto__$jscomp$232$$=$APP.$cljs$core$seq$$($ks$jscomp$44$$);return $or__5025__auto__$jscomp$232$$?$or__5025__auto__$jscomp$232$$:$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$(null)}(),function(){var $or__5025__auto__$jscomp$233$$=$APP.$cljs$core$seq$$($forms$jscomp$24$$);return $or__5025__auto__$jscomp$233$$?$or__5025__auto__$jscomp$233$$:
$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$(null)}())),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$seq$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$pks_ps$jscomp$9$$)),$APP.$cljs$core$truth_$$($ks$jscomp$44$$)?$APP.$cljs$core$seq$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$pks_ps$jscomp$9$$)):null,$APP.$cljs$core$truth_$$($forms$jscomp$24$$)?
$APP.$cljs$core$seq$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__34530_SHARP_$$){return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__34530_SHARP_$$,2)},$pks_ps$jscomp$9$$)):null],null)):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$seq$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$500$$,$pks_ps$jscomp$9$$)),$ks$jscomp$44$$,$forms$jscomp$24$$],null)};
$cljs$spec$alpha$alt_STAR_$$=function($JSCompiler_temp$jscomp$509_JSCompiler_temp$jscomp$510_JSCompiler_temp$jscomp$511_first__34552_ps$jscomp$10_ret$jscomp$inline_3891$$,$k1$jscomp$6_ks$jscomp$45_seq__34551$$,$forms$jscomp$25_ret$jscomp$94_vec__34550$$){var $forms__$1$jscomp$2_vec__34547$$=$cljs$spec$alpha$filter_alt$$($JSCompiler_temp$jscomp$509_JSCompiler_temp$jscomp$510_JSCompiler_temp$jscomp$511_first__34552_ps$jscomp$10_ret$jscomp$inline_3891$$,$k1$jscomp$6_ks$jscomp$45_seq__34551$$,$forms$jscomp$25_ret$jscomp$94_vec__34550$$,
$APP.$cljs$core$identity$$);$forms$jscomp$25_ret$jscomp$94_vec__34550$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($forms__$1$jscomp$2_vec__34547$$,0,null);$k1$jscomp$6_ks$jscomp$45_seq__34551$$=$APP.$cljs$core$seq$$($forms$jscomp$25_ret$jscomp$94_vec__34550$$);$JSCompiler_temp$jscomp$509_JSCompiler_temp$jscomp$510_JSCompiler_temp$jscomp$511_first__34552_ps$jscomp$10_ret$jscomp$inline_3891$$=$APP.$cljs$core$first$$($k1$jscomp$6_ks$jscomp$45_seq__34551$$);var $seq__34551__$1$$=$APP.$cljs$core$next$$($k1$jscomp$6_ks$jscomp$45_seq__34551$$),
$vec__34553$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($forms__$1$jscomp$2_vec__34547$$,1,null);$k1$jscomp$6_ks$jscomp$45_seq__34551$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__34553$$,0,null);$forms__$1$jscomp$2_vec__34547$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($forms__$1$jscomp$2_vec__34547$$,2,null);return $APP.$cljs$core$truth_$$($forms$jscomp$25_ret$jscomp$94_vec__34550$$)?($forms$jscomp$25_ret$jscomp$94_vec__34550$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$,$cljs$cst$1097$cljs_DOT_spec_DOT_alpha_SLASH_alt$$,$cljs$cst$1085$ps$$,$forms$jscomp$25_ret$jscomp$94_vec__34550$$,$cljs$cst$1086$ks$$,$vec__34553$$,$cljs$cst$1087$forms$$,$forms__$1$jscomp$2_vec__34547$$],null),$seq__34551__$1$$==null?$APP.$cljs$core$truth_$$($k1$jscomp$6_ks$jscomp$45_seq__34551$$)&&($cljs$spec$alpha$accept_QMARK_$$($JSCompiler_temp$jscomp$509_JSCompiler_temp$jscomp$510_JSCompiler_temp$jscomp$511_first__34552_ps$jscomp$10_ret$jscomp$inline_3891$$)?
($JSCompiler_temp$jscomp$509_JSCompiler_temp$jscomp$510_JSCompiler_temp$jscomp$511_first__34552_ps$jscomp$10_ret$jscomp$inline_3891$$=$cljs$cst$1084$ret$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$509_JSCompiler_temp$jscomp$510_JSCompiler_temp$jscomp$511_first__34552_ps$jscomp$10_ret$jscomp$inline_3891$$),$JSCompiler_temp$jscomp$509_JSCompiler_temp$jscomp$510_JSCompiler_temp$jscomp$511_first__34552_ps$jscomp$10_ret$jscomp$inline_3891$$=$cljs$spec$alpha$accept$$(new $APP.$cljs$core$MapEntry$$($k1$jscomp$6_ks$jscomp$45_seq__34551$$,
$JSCompiler_temp$jscomp$509_JSCompiler_temp$jscomp$510_JSCompiler_temp$jscomp$511_first__34552_ps$jscomp$10_ret$jscomp$inline_3891$$,null))):$JSCompiler_temp$jscomp$509_JSCompiler_temp$jscomp$510_JSCompiler_temp$jscomp$511_first__34552_ps$jscomp$10_ret$jscomp$inline_3891$$=$forms$jscomp$25_ret$jscomp$94_vec__34550$$):$JSCompiler_temp$jscomp$509_JSCompiler_temp$jscomp$510_JSCompiler_temp$jscomp$511_first__34552_ps$jscomp$10_ret$jscomp$inline_3891$$=$forms$jscomp$25_ret$jscomp$94_vec__34550$$,$JSCompiler_temp$jscomp$509_JSCompiler_temp$jscomp$510_JSCompiler_temp$jscomp$511_first__34552_ps$jscomp$10_ret$jscomp$inline_3891$$):
null};$cljs$spec$alpha$alt2$$=function($p1$jscomp$13$$,$p2$jscomp$11$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($p1$jscomp$13$$)?$p2$jscomp$11$$:$p1$jscomp$13$$)?$cljs$spec$alpha$alt_STAR_$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1$jscomp$13$$,$p2$jscomp$11$$]),null,null):$APP.$cljs$core$truth_$$($p1$jscomp$13$$)?$p1$jscomp$13$$:$p2$jscomp$11$$};
$cljs$spec$alpha$add_ret$$=function($fexpr__34650$jscomp$inline_3898_map__34648_p$jscomp$102_ret$jscomp$98_splice$jscomp$1$$,$JSCompiler_inline_result$jscomp$513_r$jscomp$69$$,$G__34652$jscomp$inline_3897_k$jscomp$472$$){$fexpr__34650$jscomp$inline_3898_map__34648_p$jscomp$102_ret$jscomp$98_splice$jscomp$1$$=$cljs$spec$alpha$reg_resolve_BANG_$$($fexpr__34650$jscomp$inline_3898_map__34648_p$jscomp$102_ret$jscomp$98_splice$jscomp$1$$);var $map__34648__$1_ret$jscomp$inline_3896$$=$APP.$cljs$core$__destructure_map$$($fexpr__34650$jscomp$inline_3898_map__34648_p$jscomp$102_ret$jscomp$98_splice$jscomp$1$$),
$op$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34648__$1_ret$jscomp$inline_3896$$,$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34648__$1_ret$jscomp$inline_3896$$,$cljs$cst$1085$ps$$);$fexpr__34650$jscomp$inline_3898_map__34648_p$jscomp$102_ret$jscomp$98_splice$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34648__$1_ret$jscomp$inline_3896$$,$cljs$cst$1092$splice$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,
$op$jscomp$4$$))return $JSCompiler_inline_result$jscomp$513_r$jscomp$69$$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1097$cljs_DOT_spec_DOT_alpha_SLASH_alt$$,$op$jscomp$4$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1083$cljs_DOT_spec_DOT_alpha_SLASH_accept$$,$op$jscomp$4$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1095$cljs_DOT_spec_DOT_alpha_SLASH_amp$$,$op$jscomp$4$$))return $fexpr__34650$jscomp$inline_3898_map__34648_p$jscomp$102_ret$jscomp$98_splice$jscomp$1$$=
$cljs$spec$alpha$preturn$$($map__34648__$1_ret$jscomp$inline_3896$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($fexpr__34650$jscomp$inline_3898_map__34648_p$jscomp$102_ret$jscomp$98_splice$jscomp$1$$,$cljs$cst$1098$cljs_DOT_spec_DOT_alpha_SLASH_nil$$)?$JSCompiler_inline_result$jscomp$513_r$jscomp$69$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$513_r$jscomp$69$$,$APP.$cljs$core$truth_$$($G__34652$jscomp$inline_3897_k$jscomp$472$$)?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$G__34652$jscomp$inline_3897_k$jscomp$472$$,
$fexpr__34650$jscomp$inline_3898_map__34648_p$jscomp$102_ret$jscomp$98_splice$jscomp$1$$]):$fexpr__34650$jscomp$inline_3898_map__34648_p$jscomp$102_ret$jscomp$98_splice$jscomp$1$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1090$cljs_DOT_spec_DOT_alpha_SLASH_rep$$,$op$jscomp$4$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1089$cljs_DOT_spec_DOT_alpha_SLASH_pcat$$,$op$jscomp$4$$))return $map__34648__$1_ret$jscomp$inline_3896$$=$cljs$spec$alpha$preturn$$($map__34648__$1_ret$jscomp$inline_3896$$),
$APP.$cljs$core$empty_QMARK_$$($map__34648__$1_ret$jscomp$inline_3896$$)||($G__34652$jscomp$inline_3897_k$jscomp$472$$=$APP.$cljs$core$truth_$$($G__34652$jscomp$inline_3897_k$jscomp$472$$)?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$G__34652$jscomp$inline_3897_k$jscomp$472$$,$map__34648__$1_ret$jscomp$inline_3896$$]):$map__34648__$1_ret$jscomp$inline_3896$$,$fexpr__34650$jscomp$inline_3898_map__34648_p$jscomp$102_ret$jscomp$98_splice$jscomp$1$$=$APP.$cljs$core$truth_$$($fexpr__34650$jscomp$inline_3898_map__34648_p$jscomp$102_ret$jscomp$98_splice$jscomp$1$$)?
$APP.$cljs$core$into$$:$APP.$cljs$core$conj$$,$JSCompiler_inline_result$jscomp$513_r$jscomp$69$$=$fexpr__34650$jscomp$inline_3898_map__34648_p$jscomp$102_ret$jscomp$98_splice$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$fexpr__34650$jscomp$inline_3898_map__34648_p$jscomp$102_ret$jscomp$98_splice$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$513_r$jscomp$69$$,$G__34652$jscomp$inline_3897_k$jscomp$472$$):$fexpr__34650$jscomp$inline_3898_map__34648_p$jscomp$102_ret$jscomp$98_splice$jscomp$1$$($JSCompiler_inline_result$jscomp$513_r$jscomp$69$$,
$G__34652$jscomp$inline_3897_k$jscomp$472$$)),$JSCompiler_inline_result$jscomp$513_r$jscomp$69$$;throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($op$jscomp$4$$)].join(""));};
$cljs$spec$alpha$op_describe$$=function($JSCompiler_temp$jscomp$514_forms$jscomp$31_map__34686_p$jscomp$104$$){$JSCompiler_temp$jscomp$514_forms$jscomp$31_map__34686_p$jscomp$104$$=$cljs$spec$alpha$reg_resolve_BANG_$$($JSCompiler_temp$jscomp$514_forms$jscomp$31_map__34686_p$jscomp$104$$);var $map__34686__$1_or__5025__auto__$jscomp$inline_3900$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$514_forms$jscomp$31_map__34686_p$jscomp$104$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34686__$1_or__5025__auto__$jscomp$inline_3900$$,
$cljs$cst$1085$ps$$);$JSCompiler_temp$jscomp$514_forms$jscomp$31_map__34686_p$jscomp$104$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34686__$1_or__5025__auto__$jscomp$inline_3900$$,$cljs$cst$1087$forms$$);var $rep_PLUS_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34686__$1_or__5025__auto__$jscomp$inline_3900$$,$cljs$cst$1088$rep_PLUS_$$),$op$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34686__$1_or__5025__auto__$jscomp$inline_3900$$,
$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$),$splice$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34686__$1_or__5025__auto__$jscomp$inline_3900$$,$cljs$cst$1092$splice$$),$ks$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34686__$1_or__5025__auto__$jscomp$inline_3900$$,$cljs$cst$1086$ks$$),$maybe$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34686__$1_or__5025__auto__$jscomp$inline_3900$$,$APP.$cljs$cst$522$maybe$$),
$amp$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34686__$1_or__5025__auto__$jscomp$inline_3900$$,$cljs$cst$1096$amp$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34686__$1_or__5025__auto__$jscomp$inline_3900$$,$APP.$cljs$cst$1093$p1$$);if($APP.$cljs$core$truth_$$($map__34686__$1_or__5025__auto__$jscomp$inline_3900$$)){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1083$cljs_DOT_spec_DOT_alpha_SLASH_accept$$,$op$jscomp$6$$))return null;
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$op$jscomp$6$$))return $map__34686__$1_or__5025__auto__$jscomp$inline_3900$$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1095$cljs_DOT_spec_DOT_alpha_SLASH_amp$$,$op$jscomp$6$$))return $APP.$cljs$core$cons$$($cljs$cst$1099$cljs_DOT_spec_DOT_alpha_SLASH__AMPERSAND_$$,$APP.$cljs$core$cons$$($amp$jscomp$1$$,$JSCompiler_temp$jscomp$514_forms$jscomp$31_map__34686_p$jscomp$104$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1089$cljs_DOT_spec_DOT_alpha_SLASH_pcat$$,
$op$jscomp$6$$))return $APP.$cljs$core$truth_$$($rep_PLUS_$jscomp$2$$)?$JSCompiler_temp$jscomp$514_forms$jscomp$31_map__34686_p$jscomp$104$$=new $APP.$cljs$core$List$$(null,$cljs$cst$1100$cljs_DOT_spec_DOT_alpha_SLASH__PLUS_$$,new $APP.$cljs$core$List$$(null,$rep_PLUS_$jscomp$2$$,null,1,null),2,null):($map__34686__$1_or__5025__auto__$jscomp$inline_3900$$=$APP.$cljs$core$seq$$($ks$jscomp$50$$),$JSCompiler_temp$jscomp$514_forms$jscomp$31_map__34686_p$jscomp$104$$=$APP.$cljs$core$cons$$($cljs$cst$1101$cljs_DOT_spec_DOT_alpha_SLASH_cat$$,
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$vector$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__34686__$1_or__5025__auto__$jscomp$inline_3900$$?$map__34686__$1_or__5025__auto__$jscomp$inline_3900$$:$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1102$_$$),$JSCompiler_temp$jscomp$514_forms$jscomp$31_map__34686_p$jscomp$104$$])))),$JSCompiler_temp$jscomp$514_forms$jscomp$31_map__34686_p$jscomp$104$$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1097$cljs_DOT_spec_DOT_alpha_SLASH_alt$$,
$op$jscomp$6$$))return $APP.$cljs$core$truth_$$($maybe$jscomp$1$$)?new $APP.$cljs$core$List$$(null,$cljs$cst$1103$cljs_DOT_spec_DOT_alpha_SLASH__QMARK_$$,new $APP.$cljs$core$List$$(null,$maybe$jscomp$1$$,null,1,null),2,null):$APP.$cljs$core$cons$$($cljs$cst$1104$cljs_DOT_spec_DOT_alpha_SLASH_alt$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$vector$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$ks$jscomp$50$$,$JSCompiler_temp$jscomp$514_forms$jscomp$31_map__34686_p$jscomp$104$$])));
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1090$cljs_DOT_spec_DOT_alpha_SLASH_rep$$,$op$jscomp$6$$))return new $APP.$cljs$core$List$$(null,$APP.$cljs$core$truth_$$($splice$jscomp$3$$)?$cljs$cst$1100$cljs_DOT_spec_DOT_alpha_SLASH__PLUS_$$:$cljs$cst$1094$cljs_DOT_spec_DOT_alpha_SLASH__STAR_$$,new $APP.$cljs$core$List$$(null,$JSCompiler_temp$jscomp$514_forms$jscomp$31_map__34686_p$jscomp$104$$,null,1,null),2,null);throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($op$jscomp$6$$)].join(""));
}return null};
$cljs$spec$alpha$re_conform$$=function($p$jscomp$107_ret$jscomp$102_temp__5823__auto__$jscomp$89$$,$G__35531_p__34770_vec__34771$$){for(;;){var $seq__34772_seq__34772__$1_xs$jscomp$24$$=$APP.$cljs$core$seq$$($G__35531_p__34770_vec__34771$$),$first__34773_x$jscomp$929$$=$APP.$cljs$core$first$$($seq__34772_seq__34772__$1_xs$jscomp$24$$);$seq__34772_seq__34772__$1_xs$jscomp$24$$=$APP.$cljs$core$next$$($seq__34772_seq__34772__$1_xs$jscomp$24$$);if($APP.$cljs$core$empty_QMARK_$$($G__35531_p__34770_vec__34771$$))return $APP.$cljs$core$truth_$$($cljs$spec$alpha$accept_nil_QMARK_$$($p$jscomp$107_ret$jscomp$102_temp__5823__auto__$jscomp$89$$))?($p$jscomp$107_ret$jscomp$102_temp__5823__auto__$jscomp$89$$=
$cljs$spec$alpha$preturn$$($p$jscomp$107_ret$jscomp$102_temp__5823__auto__$jscomp$89$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$107_ret$jscomp$102_temp__5823__auto__$jscomp$89$$,$cljs$cst$1098$cljs_DOT_spec_DOT_alpha_SLASH_nil$$)?null:$p$jscomp$107_ret$jscomp$102_temp__5823__auto__$jscomp$89$$):$cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$;$p$jscomp$107_ret$jscomp$102_temp__5823__auto__$jscomp$89$$=$cljs$spec$alpha$deriv$$($p$jscomp$107_ret$jscomp$102_temp__5823__auto__$jscomp$89$$,
$first__34773_x$jscomp$929$$);if($APP.$cljs$core$truth_$$($p$jscomp$107_ret$jscomp$102_temp__5823__auto__$jscomp$89$$))$G__35531_p__34770_vec__34771$$=$seq__34772_seq__34772__$1_xs$jscomp$24$$;else return $cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$}};
$cljs$spec$alpha$t_cljs$0spec$0alpha34794$$=function($re$jscomp$19$$,$gfn$jscomp$30$$,$meta34795$$){this.re=$re$jscomp$19$$;this.$gfn$=$gfn$jscomp$30$$;this.$meta34795$=$meta34795$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};$cljs$spec$alpha$regex_spec_impl$$=function($re$jscomp$21$$,$gfn$jscomp$32$$){return new $cljs$spec$alpha$t_cljs$0spec$0alpha34794$$($re$jscomp$21$$,$gfn$jscomp$32$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$common$exceptions$exception_QMARK_$$=function($v$jscomp$270$$){return $v$jscomp$270$$ instanceof Error};
$app$common$exceptions$explain$$=function($var_args$jscomp$651$$){for(var $args__5755__auto__$jscomp$127$$=[],$len__5749__auto___40891$$=arguments.length,$i__5750__auto___40892$$=0;;)if($i__5750__auto___40892$$<$len__5749__auto___40891$$)$args__5755__auto__$jscomp$127$$.push(arguments[$i__5750__auto___40892$$]),$i__5750__auto___40892$$+=1;else break;return $app$common$exceptions$explain$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$127$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$127$$.slice(1),
0,null):null)};
$app$common$exceptions$explain$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($data$jscomp$107_exp$jscomp$6$$,$opts$jscomp$228_p__40822$$){$opts$jscomp$228_p__40822$$=$APP.$cljs$core$__destructure_map$$($opts$jscomp$228_p__40822$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$984$reason$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$107_exp$jscomp$6$$),$cljs$cst$1137$integrant_DOT_core_SLASH_build_failed_spec$$)&&$APP.$cljs$core$contains_QMARK_$$($data$jscomp$107_exp$jscomp$6$$,$cljs$cst$650$explain$$))return $app$common$exceptions$explain$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cljs$cst$650$explain$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$107_exp$jscomp$6$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$opts$jscomp$228_p__40822$$]));if($APP.$cljs$core$contains_QMARK_$$($data$jscomp$107_exp$jscomp$6$$,$APP.$cljs$cst$932$app_DOT_common_DOT_schema_SLASH_explain$$)){$data$jscomp$107_exp$jscomp$6$$=$APP.$cljs$cst$932$app_DOT_common_DOT_schema_SLASH_explain$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$107_exp$jscomp$6$$);var $sanitize_map$$=function $app$common$exceptions$sanitize_map$$($m$jscomp$157$$){return $APP.$cljs$core$reduce_kv$$(function($JSCompiler_temp$jscomp$302_acc$jscomp$78$$,
$k$jscomp$479$$,$JSCompiler_temp$jscomp$305_s$jscomp$inline_3927_v$jscomp$271$$){var $JSCompiler_temp_const$jscomp$303_k_STAR_$jscomp$1$$=typeof $k$jscomp$479$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$479$$):$k$jscomp$479$$;if($APP.$cljs$core$contains_QMARK_$$($app$common$exceptions$sensitive_fields$$,$JSCompiler_temp_const$jscomp$303_k_STAR_$jscomp$1$$)){$JSCompiler_temp_const$jscomp$303_k_STAR_$jscomp$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;
if($APP.$cljs$core$map_QMARK_$$($JSCompiler_temp$jscomp$305_s$jscomp$inline_3927_v$jscomp$271$$))$JSCompiler_temp$jscomp$305_s$jscomp$inline_3927_v$jscomp$271$$=$app$common$exceptions$sanitize_map$$($JSCompiler_temp$jscomp$305_s$jscomp$inline_3927_v$jscomp$271$$);else{$JSCompiler_temp$jscomp$305_s$jscomp$inline_3927_v$jscomp$271$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$305_s$jscomp$inline_3927_v$jscomp$271$$);var $n$jscomp$inline_3928$$=$JSCompiler_temp$jscomp$305_s$jscomp$inline_3927_v$jscomp$271$$.length;
$JSCompiler_temp$jscomp$305_s$jscomp$inline_3927_v$jscomp$271$$=$n$jscomp$inline_3928$$===0?$JSCompiler_temp$jscomp$305_s$jscomp$inline_3927_v$jscomp$271$$:$APP.$cljs$core$truth_$$(!0)?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($n$jscomp$inline_3928$$,"*")):$n$jscomp$inline_3928$$<10?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($n$jscomp$inline_3928$$,
"*")):[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$305_s$jscomp$inline_3927_v$jscomp$271$$,0,5),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($n$jscomp$inline_3928$$-5,"*")))].join("")}$JSCompiler_temp$jscomp$302_acc$jscomp$78$$=$JSCompiler_temp_const$jscomp$303_k_STAR_$jscomp$1$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp$jscomp$302_acc$jscomp$78$$,
$k$jscomp$479$$,$JSCompiler_temp$jscomp$305_s$jscomp$inline_3927_v$jscomp$271$$)}else $JSCompiler_temp$jscomp$302_acc$jscomp$78$$=$APP.$cljs$core$map_QMARK_$$($JSCompiler_temp$jscomp$305_s$jscomp$inline_3927_v$jscomp$271$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$302_acc$jscomp$78$$,$k$jscomp$479$$,$app$common$exceptions$sanitize_map$$($JSCompiler_temp$jscomp$305_s$jscomp$inline_3927_v$jscomp$271$$)):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$302_acc$jscomp$78$$,
$k$jscomp$479$$,$JSCompiler_temp$jscomp$305_s$jscomp$inline_3927_v$jscomp$271$$);return $JSCompiler_temp$jscomp$302_acc$jscomp$78$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$m$jscomp$157$$)};return $app$common$schema$humanize_explain$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($exp__$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($exp__$1$$))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($exp__$1$$,$APP.$cljs$cst$260$value$$,
$sanitize_map$$):$exp__$1$$}($data$jscomp$107_exp$jscomp$6$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$opts$jscomp$228_p__40822$$]))}return null};
$app$common$exceptions$format_throwable$$=function($var_args$jscomp$652$$){for(var $args__5755__auto__$jscomp$128$$=[],$len__5749__auto___40898$$=arguments.length,$i__5750__auto___40899$$=0;;)if($i__5750__auto___40899$$<$len__5749__auto___40898$$)$args__5755__auto__$jscomp$128$$.push(arguments[$i__5750__auto___40899$$]),$i__5750__auto___40899$$+=1;else break;return $app$common$exceptions$format_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$128$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$128$$.slice(1),0,null):null)};
$app$common$exceptions$format_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($cause$jscomp$5$$,$_STAR_print_newline_STAR__orig_val__40850_40901_p__40845$$){$APP.$cljs$core$__destructure_map$$($_STAR_print_newline_STAR__orig_val__40850_40901_p__40845$$);var $sb__5670__auto__$jscomp$5$$=new $APP.$goog$string$StringBuffer$$;$_STAR_print_newline_STAR__orig_val__40850_40901_p__40845$$=$APP.$cljs$core$_STAR_print_newline_STAR_$$;var $_STAR_print_fn_STAR__orig_val__40851_40902$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;
$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$5$$){return $sb__5670__auto__$jscomp$5$$.append($x__5671__auto__$jscomp$5$$)};try{$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d"]));var $temp__5825__auto___40905$$=$APP.$cljs$core$ex_data$$($cause$jscomp$5$$);if($APP.$cljs$core$truth_$$($temp__5825__auto___40905$$)){var $temp__5825__auto___40907__$1$$=
function(){var $or__5025__auto__$jscomp$251$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5825__auto___40905$$,$APP.$cljs$cst$275$hint$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$251$$)?$or__5025__auto__$jscomp$251$$:$APP.$cljs$core$ex_message$$($cause$jscomp$5$$)}();$APP.$cljs$core$truth_$$($temp__5825__auto___40907__$1$$)&&$APP.$cljs$core$truth_$$($APP.$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5825__auto___40907__$1$$,"\n"))&&($APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Hint:"])),
$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["--------------------"])),$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$temp__5825__auto___40907__$1$$])),$APP.$cljs$core$println$$());var $temp__5825__auto___40909__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5825__auto___40905$$,$APP.$cljs$cst$932$app_DOT_common_DOT_schema_SLASH_explain$$);
$APP.$cljs$core$truth_$$($temp__5825__auto___40909__$1$$)&&($APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Explain:"])),$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["--------------------"])),$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$schema$humanize_explain$$($temp__5825__auto___40909__$1$$)])),
$APP.$cljs$core$println$$());var $temp__5825__auto___40911__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5825__auto___40905$$,$cljs$cst$650$explain$$);$APP.$cljs$core$truth_$$($temp__5825__auto___40911__$1$$)&&($APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Server Explain:"])),$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["--------------------"])),
$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$temp__5825__auto___40911__$1$$])));$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Data:"]));$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["--------------------"]));$app$common$pprint$pprint$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($temp__5825__auto___40905$$,
$APP.$cljs$cst$932$app_DOT_common_DOT_schema_SLASH_explain$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$650$explain$$])));$APP.$cljs$core$println$$()}$APP.$cljs$core$truth_$$($cause$jscomp$5$$.stack)&&($APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Trace:"])),$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["--------------------"])),
$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cause$jscomp$5$$.stack])));$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d"]))}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=$_STAR_print_fn_STAR__orig_val__40851_40902$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=
$_STAR_print_newline_STAR__orig_val__40850_40901_p__40845$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$5$$)};$app$common$exceptions$first_line$$=function($s$jscomp$453$$){var $break_index$$=$APP.$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$453$$,"\n");return $break_index$$>0?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$453$$,0,$break_index$$):$s$jscomp$453$$};
$APP.$app$common$exceptions$print_throwable$$=function($var_args$jscomp$653$$){for(var $args__5755__auto__$jscomp$129$$=[],$len__5749__auto___40920$$=arguments.length,$i__5750__auto___40921$$=0;;)if($i__5750__auto___40921$$<$len__5749__auto___40920$$)$args__5755__auto__$jscomp$129$$.push(arguments[$i__5750__auto___40921$$]),$i__5750__auto___40921$$+=1;else break;return $app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$129$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$129$$.slice(1),0,null):null)};
$app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($cause$jscomp$6$$,$opts$jscomp$230_p__40871_prefix$jscomp$15_title$jscomp$12$$){$opts$jscomp$230_p__40871_prefix$jscomp$15_title$jscomp$12$$=$APP.$cljs$core$__destructure_map$$($opts$jscomp$230_p__40871_prefix$jscomp$15_title$jscomp$12$$);$opts$jscomp$230_p__40871_prefix$jscomp$15_title$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($opts$jscomp$230_p__40871_prefix$jscomp$15_title$jscomp$12$$,$APP.$cljs$cst$971$prefix$$);
var $G__40875$jscomp$inline_14183_G__40877$jscomp$inline_14185_or__5025__auto__$jscomp$inline_14184$$=$APP.$cljs$cst$275$hint$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($cause$jscomp$6$$));$G__40875$jscomp$inline_14183_G__40877$jscomp$inline_14185_or__5025__auto__$jscomp$inline_14184$$=$G__40875$jscomp$inline_14183_G__40877$jscomp$inline_14185_or__5025__auto__$jscomp$inline_14184$$==null?null:$app$common$exceptions$first_line$$($G__40875$jscomp$inline_14183_G__40877$jscomp$inline_14185_or__5025__auto__$jscomp$inline_14184$$);
$G__40875$jscomp$inline_14183_G__40877$jscomp$inline_14185_or__5025__auto__$jscomp$inline_14184$$=$APP.$cljs$core$truth_$$($G__40875$jscomp$inline_14183_G__40877$jscomp$inline_14185_or__5025__auto__$jscomp$inline_14184$$)?$G__40875$jscomp$inline_14183_G__40877$jscomp$inline_14185_or__5025__auto__$jscomp$inline_14184$$:$APP.$cljs$core$ex_message$$($cause$jscomp$6$$);$opts$jscomp$230_p__40871_prefix$jscomp$15_title$jscomp$12$$=typeof $opts$jscomp$230_p__40871_prefix$jscomp$15_title$jscomp$12$$==="string"?
[$opts$jscomp$230_p__40871_prefix$jscomp$15_title$jscomp$12$$,": ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__40875$jscomp$inline_14183_G__40877$jscomp$inline_14185_or__5025__auto__$jscomp$inline_14184$$)].join(""):$G__40875$jscomp$inline_14183_G__40877$jscomp$inline_14185_or__5025__auto__$jscomp$inline_14184$$;console.group($opts$jscomp$230_p__40871_prefix$jscomp$15_title$jscomp$12$$);try{console.log($app$common$exceptions$format_throwable$$($cause$jscomp$6$$));for(var $cause__$1$$=
$cljs$core$ex_cause$$($cause$jscomp$6$$);;)if($APP.$cljs$core$truth_$$($cause__$1$$))console.log("\nCaused by:"),console.log($app$common$exceptions$format_throwable$$($cause__$1$$)),$cause__$1$$=$cljs$core$ex_cause$$($cause__$1$$);else return null}finally{console.groupEnd()}};
$APP.$app$common$exceptions$get_hint$$=function($G__40886_cause$jscomp$7$$){var $G__40884$jscomp$inline_3932_G__40884__$1$jscomp$inline_3933_or__5025__auto__$jscomp$253$$=$APP.$cljs$core$ex_data$$($G__40886_cause$jscomp$7$$);$G__40884$jscomp$inline_3932_G__40884__$1$jscomp$inline_3933_or__5025__auto__$jscomp$253$$=$G__40884$jscomp$inline_3932_G__40884__$1$jscomp$inline_3933_or__5025__auto__$jscomp$253$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__40884$jscomp$inline_3932_G__40884__$1$jscomp$inline_3933_or__5025__auto__$jscomp$253$$,
$APP.$cljs$cst$275$hint$$);$G__40884$jscomp$inline_3932_G__40884__$1$jscomp$inline_3933_or__5025__auto__$jscomp$253$$=$G__40884$jscomp$inline_3932_G__40884__$1$jscomp$inline_3933_or__5025__auto__$jscomp$253$$==null?null:$app$common$exceptions$first_line$$($G__40884$jscomp$inline_3932_G__40884__$1$jscomp$inline_3933_or__5025__auto__$jscomp$253$$);if($APP.$cljs$core$truth_$$($G__40884$jscomp$inline_3932_G__40884__$1$jscomp$inline_3933_or__5025__auto__$jscomp$253$$))return $G__40884$jscomp$inline_3932_G__40884__$1$jscomp$inline_3933_or__5025__auto__$jscomp$253$$;
$G__40886_cause$jscomp$7$$=$APP.$cljs$core$ex_message$$($G__40886_cause$jscomp$7$$);return $G__40886_cause$jscomp$7$$==null?null:$app$common$exceptions$first_line$$($G__40886_cause$jscomp$7$$)};$APP.$app$common$time$now$$=function(){return new Date};$APP.$app$common$time$inst_QMARK_$$=function($o$jscomp$178$$){return $o$jscomp$178$$ instanceof Date};
$APP.$app$common$time$timeago$$=function($v$jscomp$274$$){return $APP.$cljs$core$truth_$$($v$jscomp$274$$)?$shadow$js$shim$module$0date_fns$0formatDistanceToNowStrict$0default$$($v$jscomp$274$$,{includeSeconds:!0,addSuffix:!0}):null};
$APP.$app$common$time$inst$$=function($s$jscomp$454$$){if($s$jscomp$454$$==null||$APP.$app$common$time$inst_QMARK_$$($s$jscomp$454$$))return $s$jscomp$454$$;if($APP.$cljs$core$int_QMARK_$$($s$jscomp$454$$))return new Date($s$jscomp$454$$);if(typeof $s$jscomp$454$$==="string")return $shadow$js$shim$module$0date_fns$0parseISO$0default$$($s$jscomp$454$$);throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("invalid parameters",$APP.$cljs$core$PersistentArrayMap$EMPTY$$);};
$app$common$time$plus$$=function($ta$jscomp$1$$){var $d$jscomp$162$$=$APP.$app$common$time$now$$();if($APP.$app$common$time$inst_QMARK_$$($d$jscomp$162$$))return $shadow$js$shim$module$0date_fns$0add$0default$$($d$jscomp$162$$,$ta$jscomp$1$$);throw Error("unsupported type");};
$APP.$app$common$time$minus$$=function($ta$jscomp$2$$){var $d$jscomp$163$$=$APP.$app$common$time$now$$();if($APP.$app$common$time$inst_QMARK_$$($d$jscomp$163$$))return $shadow$js$shim$module$0date_fns$0sub$0default$$($d$jscomp$163$$,$ta$jscomp$2$$);throw Error("unsupported type");};$APP.$app$common$time$diff_ms$$=function($t1$jscomp$1$$){return $shadow$js$shim$module$0date_fns$0differenceInMilliseconds$0default$$($APP.$app$common$time$now$$(),$t1$jscomp$1$$)};
$app$common$time$set_default_locale$$=function($locale$jscomp$4_temp__5825__auto__$jscomp$84$$){$locale$jscomp$4_temp__5825__auto__$jscomp$84$$=$app$common$time$locales$$[$locale$jscomp$4_temp__5825__auto__$jscomp$84$$];return $APP.$cljs$core$truth_$$($locale$jscomp$4_temp__5825__auto__$jscomp$84$$)?$shadow$js$shim$module$0date_fns$0setDefaultOptions$0default$$({locale:$locale$jscomp$4_temp__5825__auto__$jscomp$84$$}):null};
$app$common$time$tpoint_ms$$=function(){var $p1$jscomp$22$$=performance.now();return function(){return performance.now()-$p1$jscomp$22$$}};
$promesa$protocols$_rejected_QMARK_$$=function($JSCompiler_temp$jscomp$517_it$jscomp$38$$){if($JSCompiler_temp$jscomp$517_it$jscomp$38$$!=null&&$JSCompiler_temp$jscomp$517_it$jscomp$38$$.$promesa$protocols$IState$_rejected_QMARK_$arity$1$!=null)$JSCompiler_temp$jscomp$517_it$jscomp$38$$=$JSCompiler_temp$jscomp$517_it$jscomp$38$$.$promesa$protocols$IState$_rejected_QMARK_$arity$1$($JSCompiler_temp$jscomp$517_it$jscomp$38$$);else{var $m__5372__auto__$jscomp$inline_3937_m__5374__auto__$jscomp$inline_3936$$=
$promesa$protocols$_rejected_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$517_it$jscomp$38$$==null?null:$JSCompiler_temp$jscomp$517_it$jscomp$38$$)];if($m__5372__auto__$jscomp$inline_3937_m__5374__auto__$jscomp$inline_3936$$!=null)$JSCompiler_temp$jscomp$517_it$jscomp$38$$=$m__5372__auto__$jscomp$inline_3937_m__5374__auto__$jscomp$inline_3936$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3937_m__5374__auto__$jscomp$inline_3936$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$517_it$jscomp$38$$):
$m__5372__auto__$jscomp$inline_3937_m__5374__auto__$jscomp$inline_3936$$($JSCompiler_temp$jscomp$517_it$jscomp$38$$);else if($m__5372__auto__$jscomp$inline_3937_m__5374__auto__$jscomp$inline_3936$$=$promesa$protocols$_rejected_QMARK_$$._,$m__5372__auto__$jscomp$inline_3937_m__5374__auto__$jscomp$inline_3936$$!=null)$JSCompiler_temp$jscomp$517_it$jscomp$38$$=$m__5372__auto__$jscomp$inline_3937_m__5374__auto__$jscomp$inline_3936$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3937_m__5374__auto__$jscomp$inline_3936$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$517_it$jscomp$38$$):
$m__5372__auto__$jscomp$inline_3937_m__5374__auto__$jscomp$inline_3936$$($JSCompiler_temp$jscomp$517_it$jscomp$38$$);else throw $APP.$cljs$core$missing_protocol$$("IState.-rejected?",$JSCompiler_temp$jscomp$517_it$jscomp$38$$);}return $JSCompiler_temp$jscomp$517_it$jscomp$38$$};
$promesa$protocols$_pending_QMARK_$$=function($JSCompiler_temp$jscomp$518_it$jscomp$40$$){if($JSCompiler_temp$jscomp$518_it$jscomp$40$$!=null&&$JSCompiler_temp$jscomp$518_it$jscomp$40$$.$promesa$protocols$IState$_pending_QMARK_$arity$1$!=null)$JSCompiler_temp$jscomp$518_it$jscomp$40$$=$JSCompiler_temp$jscomp$518_it$jscomp$40$$.$promesa$protocols$IState$_pending_QMARK_$arity$1$($JSCompiler_temp$jscomp$518_it$jscomp$40$$);else{var $m__5372__auto__$jscomp$inline_3941_m__5374__auto__$jscomp$inline_3940$$=
$promesa$protocols$_pending_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$518_it$jscomp$40$$==null?null:$JSCompiler_temp$jscomp$518_it$jscomp$40$$)];if($m__5372__auto__$jscomp$inline_3941_m__5374__auto__$jscomp$inline_3940$$!=null)$JSCompiler_temp$jscomp$518_it$jscomp$40$$=$m__5372__auto__$jscomp$inline_3941_m__5374__auto__$jscomp$inline_3940$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3941_m__5374__auto__$jscomp$inline_3940$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$518_it$jscomp$40$$):
$m__5372__auto__$jscomp$inline_3941_m__5374__auto__$jscomp$inline_3940$$($JSCompiler_temp$jscomp$518_it$jscomp$40$$);else if($m__5372__auto__$jscomp$inline_3941_m__5374__auto__$jscomp$inline_3940$$=$promesa$protocols$_pending_QMARK_$$._,$m__5372__auto__$jscomp$inline_3941_m__5374__auto__$jscomp$inline_3940$$!=null)$JSCompiler_temp$jscomp$518_it$jscomp$40$$=$m__5372__auto__$jscomp$inline_3941_m__5374__auto__$jscomp$inline_3940$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3941_m__5374__auto__$jscomp$inline_3940$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$518_it$jscomp$40$$):
$m__5372__auto__$jscomp$inline_3941_m__5374__auto__$jscomp$inline_3940$$($JSCompiler_temp$jscomp$518_it$jscomp$40$$);else throw $APP.$cljs$core$missing_protocol$$("IState.-pending?",$JSCompiler_temp$jscomp$518_it$jscomp$40$$);}return $JSCompiler_temp$jscomp$518_it$jscomp$40$$};
$promesa$protocols$_promise$$=function($JSCompiler_temp$jscomp$519_it$jscomp$42$$){if($JSCompiler_temp$jscomp$519_it$jscomp$42$$!=null&&$JSCompiler_temp$jscomp$519_it$jscomp$42$$.$promesa$protocols$IPromiseFactory$_promise$arity$1$!=null)$JSCompiler_temp$jscomp$519_it$jscomp$42$$=$JSCompiler_temp$jscomp$519_it$jscomp$42$$.$promesa$protocols$IPromiseFactory$_promise$arity$1$($JSCompiler_temp$jscomp$519_it$jscomp$42$$);else{var $m__5372__auto__$jscomp$inline_3945_m__5374__auto__$jscomp$inline_3944$$=
$promesa$protocols$_promise$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$519_it$jscomp$42$$==null?null:$JSCompiler_temp$jscomp$519_it$jscomp$42$$)];if($m__5372__auto__$jscomp$inline_3945_m__5374__auto__$jscomp$inline_3944$$!=null)$JSCompiler_temp$jscomp$519_it$jscomp$42$$=$m__5372__auto__$jscomp$inline_3945_m__5374__auto__$jscomp$inline_3944$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3945_m__5374__auto__$jscomp$inline_3944$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$519_it$jscomp$42$$):
$m__5372__auto__$jscomp$inline_3945_m__5374__auto__$jscomp$inline_3944$$($JSCompiler_temp$jscomp$519_it$jscomp$42$$);else if($m__5372__auto__$jscomp$inline_3945_m__5374__auto__$jscomp$inline_3944$$=$promesa$protocols$_promise$$._,$m__5372__auto__$jscomp$inline_3945_m__5374__auto__$jscomp$inline_3944$$!=null)$JSCompiler_temp$jscomp$519_it$jscomp$42$$=$m__5372__auto__$jscomp$inline_3945_m__5374__auto__$jscomp$inline_3944$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3945_m__5374__auto__$jscomp$inline_3944$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$519_it$jscomp$42$$):
$m__5372__auto__$jscomp$inline_3945_m__5374__auto__$jscomp$inline_3944$$($JSCompiler_temp$jscomp$519_it$jscomp$42$$);else throw $APP.$cljs$core$missing_protocol$$("IPromiseFactory.-promise",$JSCompiler_temp$jscomp$519_it$jscomp$42$$);}return $JSCompiler_temp$jscomp$519_it$jscomp$42$$};
$promesa$protocols$_cancelled_QMARK_$$=function($JSCompiler_temp$jscomp$520_it$jscomp$46$$){if($JSCompiler_temp$jscomp$520_it$jscomp$46$$!=null&&$JSCompiler_temp$jscomp$520_it$jscomp$46$$.$promesa$protocols$ICancellable$_cancelled_QMARK_$arity$1$!=null)$JSCompiler_temp$jscomp$520_it$jscomp$46$$=$JSCompiler_temp$jscomp$520_it$jscomp$46$$.$promesa$protocols$ICancellable$_cancelled_QMARK_$arity$1$($JSCompiler_temp$jscomp$520_it$jscomp$46$$);else{var $m__5372__auto__$jscomp$inline_3949_m__5374__auto__$jscomp$inline_3948$$=
$promesa$protocols$_cancelled_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$520_it$jscomp$46$$==null?null:$JSCompiler_temp$jscomp$520_it$jscomp$46$$)];if($m__5372__auto__$jscomp$inline_3949_m__5374__auto__$jscomp$inline_3948$$!=null)$JSCompiler_temp$jscomp$520_it$jscomp$46$$=$m__5372__auto__$jscomp$inline_3949_m__5374__auto__$jscomp$inline_3948$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3949_m__5374__auto__$jscomp$inline_3948$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$520_it$jscomp$46$$):
$m__5372__auto__$jscomp$inline_3949_m__5374__auto__$jscomp$inline_3948$$($JSCompiler_temp$jscomp$520_it$jscomp$46$$);else if($m__5372__auto__$jscomp$inline_3949_m__5374__auto__$jscomp$inline_3948$$=$promesa$protocols$_cancelled_QMARK_$$._,$m__5372__auto__$jscomp$inline_3949_m__5374__auto__$jscomp$inline_3948$$!=null)$JSCompiler_temp$jscomp$520_it$jscomp$46$$=$m__5372__auto__$jscomp$inline_3949_m__5374__auto__$jscomp$inline_3948$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_3949_m__5374__auto__$jscomp$inline_3948$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$520_it$jscomp$46$$):
$m__5372__auto__$jscomp$inline_3949_m__5374__auto__$jscomp$inline_3948$$($JSCompiler_temp$jscomp$520_it$jscomp$46$$);else throw $APP.$cljs$core$missing_protocol$$("ICancellable.-cancelled?",$JSCompiler_temp$jscomp$520_it$jscomp$46$$);}return $JSCompiler_temp$jscomp$520_it$jscomp$46$$};
$APP.$promesa$protocols$_resolve_BANG_$$=function($JSCompiler_temp$jscomp$521_it$jscomp$48$$,$v$jscomp$278$$){if($JSCompiler_temp$jscomp$521_it$jscomp$48$$!=null&&$JSCompiler_temp$jscomp$521_it$jscomp$48$$.$promesa$protocols$ICompletable$_resolve_BANG_$arity$2$!=null)$JSCompiler_temp$jscomp$521_it$jscomp$48$$=$JSCompiler_temp$jscomp$521_it$jscomp$48$$.$promesa$protocols$ICompletable$_resolve_BANG_$arity$2$($JSCompiler_temp$jscomp$521_it$jscomp$48$$,$v$jscomp$278$$);else{var $m__5372__auto__$jscomp$inline_3954_m__5374__auto__$jscomp$inline_3953$$=
$APP.$promesa$protocols$_resolve_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$521_it$jscomp$48$$==null?null:$JSCompiler_temp$jscomp$521_it$jscomp$48$$)];if($m__5372__auto__$jscomp$inline_3954_m__5374__auto__$jscomp$inline_3953$$!=null)$JSCompiler_temp$jscomp$521_it$jscomp$48$$=$m__5372__auto__$jscomp$inline_3954_m__5374__auto__$jscomp$inline_3953$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3954_m__5374__auto__$jscomp$inline_3953$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$521_it$jscomp$48$$,
$v$jscomp$278$$):$m__5372__auto__$jscomp$inline_3954_m__5374__auto__$jscomp$inline_3953$$($JSCompiler_temp$jscomp$521_it$jscomp$48$$,$v$jscomp$278$$);else if($m__5372__auto__$jscomp$inline_3954_m__5374__auto__$jscomp$inline_3953$$=$APP.$promesa$protocols$_resolve_BANG_$$._,$m__5372__auto__$jscomp$inline_3954_m__5374__auto__$jscomp$inline_3953$$!=null)$JSCompiler_temp$jscomp$521_it$jscomp$48$$=$m__5372__auto__$jscomp$inline_3954_m__5374__auto__$jscomp$inline_3953$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_3954_m__5374__auto__$jscomp$inline_3953$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$521_it$jscomp$48$$,$v$jscomp$278$$):$m__5372__auto__$jscomp$inline_3954_m__5374__auto__$jscomp$inline_3953$$($JSCompiler_temp$jscomp$521_it$jscomp$48$$,$v$jscomp$278$$);else throw $APP.$cljs$core$missing_protocol$$("ICompletable.-resolve!",$JSCompiler_temp$jscomp$521_it$jscomp$48$$);}return $JSCompiler_temp$jscomp$521_it$jscomp$48$$};
$APP.$promesa$protocols$_reject_BANG_$$=function($JSCompiler_temp$jscomp$522_it$jscomp$50$$,$e$jscomp$182$$){if($JSCompiler_temp$jscomp$522_it$jscomp$50$$!=null&&$JSCompiler_temp$jscomp$522_it$jscomp$50$$.$promesa$protocols$ICompletable$_reject_BANG_$arity$2$!=null)$JSCompiler_temp$jscomp$522_it$jscomp$50$$=$JSCompiler_temp$jscomp$522_it$jscomp$50$$.$promesa$protocols$ICompletable$_reject_BANG_$arity$2$($JSCompiler_temp$jscomp$522_it$jscomp$50$$,$e$jscomp$182$$);else{var $m__5372__auto__$jscomp$inline_3959_m__5374__auto__$jscomp$inline_3958$$=
$APP.$promesa$protocols$_reject_BANG_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$522_it$jscomp$50$$==null?null:$JSCompiler_temp$jscomp$522_it$jscomp$50$$)];if($m__5372__auto__$jscomp$inline_3959_m__5374__auto__$jscomp$inline_3958$$!=null)$JSCompiler_temp$jscomp$522_it$jscomp$50$$=$m__5372__auto__$jscomp$inline_3959_m__5374__auto__$jscomp$inline_3958$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3959_m__5374__auto__$jscomp$inline_3958$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$522_it$jscomp$50$$,
$e$jscomp$182$$):$m__5372__auto__$jscomp$inline_3959_m__5374__auto__$jscomp$inline_3958$$($JSCompiler_temp$jscomp$522_it$jscomp$50$$,$e$jscomp$182$$);else if($m__5372__auto__$jscomp$inline_3959_m__5374__auto__$jscomp$inline_3958$$=$APP.$promesa$protocols$_reject_BANG_$$._,$m__5372__auto__$jscomp$inline_3959_m__5374__auto__$jscomp$inline_3958$$!=null)$JSCompiler_temp$jscomp$522_it$jscomp$50$$=$m__5372__auto__$jscomp$inline_3959_m__5374__auto__$jscomp$inline_3958$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3959_m__5374__auto__$jscomp$inline_3958$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$522_it$jscomp$50$$,
$e$jscomp$182$$):$m__5372__auto__$jscomp$inline_3959_m__5374__auto__$jscomp$inline_3958$$($JSCompiler_temp$jscomp$522_it$jscomp$50$$,$e$jscomp$182$$);else throw $APP.$cljs$core$missing_protocol$$("ICompletable.-reject!",$JSCompiler_temp$jscomp$522_it$jscomp$50$$);}return $JSCompiler_temp$jscomp$522_it$jscomp$50$$};$promesa$protocols$IExecutor$$=function(){};
$promesa$protocols$_exec_BANG_$$=function($it$jscomp$52$$,$task$jscomp$1$$){if($it$jscomp$52$$!=null&&$it$jscomp$52$$.$promesa$protocols$IExecutor$_exec_BANG_$arity$2$!=null)$it$jscomp$52$$.$promesa$protocols$IExecutor$_exec_BANG_$arity$2$($it$jscomp$52$$,$task$jscomp$1$$);else{var $m__5372__auto__$jscomp$inline_3964_m__5374__auto__$jscomp$inline_3963$$=$promesa$protocols$_exec_BANG_$$[$APP.$goog$typeOf$$($it$jscomp$52$$==null?null:$it$jscomp$52$$)];if($m__5372__auto__$jscomp$inline_3964_m__5374__auto__$jscomp$inline_3963$$!=
null)$m__5372__auto__$jscomp$inline_3964_m__5374__auto__$jscomp$inline_3963$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3964_m__5374__auto__$jscomp$inline_3963$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$52$$,$task$jscomp$1$$):$m__5372__auto__$jscomp$inline_3964_m__5374__auto__$jscomp$inline_3963$$($it$jscomp$52$$,$task$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_3964_m__5374__auto__$jscomp$inline_3963$$=$promesa$protocols$_exec_BANG_$$._,$m__5372__auto__$jscomp$inline_3964_m__5374__auto__$jscomp$inline_3963$$!=
null)$m__5372__auto__$jscomp$inline_3964_m__5374__auto__$jscomp$inline_3963$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_3964_m__5374__auto__$jscomp$inline_3963$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$52$$,$task$jscomp$1$$):$m__5372__auto__$jscomp$inline_3964_m__5374__auto__$jscomp$inline_3963$$($it$jscomp$52$$,$task$jscomp$1$$);else throw $APP.$cljs$core$missing_protocol$$("IExecutor.-exec!",$it$jscomp$52$$);}};
$promesa$protocols$_schedule_BANG_$$=function($it$jscomp$58$$,$ms$jscomp$6$$,$func$jscomp$5$$){if($it$jscomp$58$$!=null&&$it$jscomp$58$$.$promesa$protocols$IScheduler$_schedule_BANG_$arity$3$!=null)$it$jscomp$58$$.$promesa$protocols$IScheduler$_schedule_BANG_$arity$3$($it$jscomp$58$$,$ms$jscomp$6$$,$func$jscomp$5$$);else{var $m__5372__auto__$jscomp$inline_3970_m__5374__auto__$jscomp$inline_3969$$=$promesa$protocols$_schedule_BANG_$$[$APP.$goog$typeOf$$($it$jscomp$58$$==null?null:$it$jscomp$58$$)];
if($m__5372__auto__$jscomp$inline_3970_m__5374__auto__$jscomp$inline_3969$$!=null)$m__5372__auto__$jscomp$inline_3970_m__5374__auto__$jscomp$inline_3969$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_3970_m__5374__auto__$jscomp$inline_3969$$.$cljs$core$IFn$_invoke$arity$3$($it$jscomp$58$$,$ms$jscomp$6$$,$func$jscomp$5$$):$m__5372__auto__$jscomp$inline_3970_m__5374__auto__$jscomp$inline_3969$$($it$jscomp$58$$,$ms$jscomp$6$$,$func$jscomp$5$$);else if($m__5372__auto__$jscomp$inline_3970_m__5374__auto__$jscomp$inline_3969$$=
$promesa$protocols$_schedule_BANG_$$._,$m__5372__auto__$jscomp$inline_3970_m__5374__auto__$jscomp$inline_3969$$!=null)$m__5372__auto__$jscomp$inline_3970_m__5374__auto__$jscomp$inline_3969$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_3970_m__5374__auto__$jscomp$inline_3969$$.$cljs$core$IFn$_invoke$arity$3$($it$jscomp$58$$,$ms$jscomp$6$$,$func$jscomp$5$$):$m__5372__auto__$jscomp$inline_3970_m__5374__auto__$jscomp$inline_3969$$($it$jscomp$58$$,$ms$jscomp$6$$,$func$jscomp$5$$);else throw $APP.$cljs$core$missing_protocol$$("IScheduler.-schedule!",
$it$jscomp$58$$);}};$$jscomp$scope$84173391$27$transition$$=function($p$jscomp$109$$,$state$jscomp$11$$,$value$jscomp$335$$){$p$jscomp$109$$[$$jscomp$scope$84173391$4$STATE$$]!==$state$jscomp$11$$&&$p$jscomp$109$$[$$jscomp$scope$84173391$4$STATE$$]===$$jscomp$scope$84173391$0$PENDING$$&&($p$jscomp$109$$[$$jscomp$scope$84173391$4$STATE$$]=$state$jscomp$11$$,$p$jscomp$109$$[$$jscomp$scope$84173391$5$VALUE$$]=$value$jscomp$335$$,$$jscomp$scope$84173391$25$processNextTick$$($p$jscomp$109$$))};
$$jscomp$scope$84173391$26$resolveTask$$=function($task$jscomp$6$$,$state$jscomp$12$$,$value$jscomp$336$$){$task$jscomp$6$$.complete!==void 0&&($task$jscomp$6$$.type===$$jscomp$scope$84173391$8$RESOLVE_TYPE_MAP$$?$state$jscomp$12$$===$$jscomp$scope$84173391$2$REJECTED$$?$task$jscomp$6$$.complete(null,$value$jscomp$336$$):$task$jscomp$6$$.complete($value$jscomp$336$$,null):$task$jscomp$6$$.type===$$jscomp$scope$84173391$6$RESOLVE_TYPE_FLATTEN$$?$value$jscomp$336$$ instanceof $APP.$$jscomp$scope$84173391$14$PromiseImpl$$?
$value$jscomp$336$$.handle(($v$jscomp$280$$,$c$jscomp$214$$)=>{$c$jscomp$214$$?$$jscomp$scope$84173391$26$resolveTask$$($task$jscomp$6$$,$$jscomp$scope$84173391$2$REJECTED$$,$c$jscomp$214$$):$$jscomp$scope$84173391$26$resolveTask$$($task$jscomp$6$$,$$jscomp$scope$84173391$1$RESOLVED$$,$v$jscomp$280$$)}):$$jscomp$scope$84173391$19$isThenable$$($value$jscomp$336$$)?$value$jscomp$336$$.then($v$jscomp$281$$=>{$$jscomp$scope$84173391$26$resolveTask$$($task$jscomp$6$$,$$jscomp$scope$84173391$1$RESOLVED$$,
$v$jscomp$281$$)},$c$jscomp$215$$=>{$$jscomp$scope$84173391$26$resolveTask$$($task$jscomp$6$$,$$jscomp$scope$84173391$2$REJECTED$$,$c$jscomp$215$$)}):$state$jscomp$12$$===$$jscomp$scope$84173391$2$REJECTED$$?$task$jscomp$6$$.complete(null,$value$jscomp$336$$):$task$jscomp$6$$.complete($value$jscomp$336$$,null):$task$jscomp$6$$.type===$$jscomp$scope$84173391$7$RESOLVE_TYPE_BIND$$?$value$jscomp$336$$ instanceof $APP.$$jscomp$scope$84173391$14$PromiseImpl$$?$value$jscomp$336$$.handle(($v$jscomp$282$$,
$c$jscomp$216$$)=>{$task$jscomp$6$$.complete($v$jscomp$282$$,$c$jscomp$216$$)}):$$jscomp$scope$84173391$19$isThenable$$($value$jscomp$336$$)?$value$jscomp$336$$.then($v$jscomp$283$$=>{$task$jscomp$6$$.complete($v$jscomp$283$$,null)},$c$jscomp$217$$=>{$task$jscomp$6$$.complete(null,$c$jscomp$217$$)}):$task$jscomp$6$$.complete(null,new TypeError("expected thenable")):$task$jscomp$6$$.complete(null,new TypeError("internal: invalid resolve type")))};
$$jscomp$scope$84173391$25$processNextTick$$=function($p$jscomp$110$$){if($p$jscomp$110$$[$$jscomp$scope$84173391$3$QUEUE$$].length!==0)for(var $value$jscomp$337$$=$p$jscomp$110$$[$$jscomp$scope$84173391$5$VALUE$$],$state$jscomp$13$$=$p$jscomp$110$$[$$jscomp$scope$84173391$4$STATE$$],$task$jscomp$7$$,$rvalue$$;$p$jscomp$110$$[$$jscomp$scope$84173391$3$QUEUE$$].length;){$task$jscomp$7$$=$p$jscomp$110$$[$$jscomp$scope$84173391$3$QUEUE$$].shift();try{$state$jscomp$13$$===$$jscomp$scope$84173391$1$RESOLVED$$?
$rvalue$$=$task$jscomp$7$$.resolve($value$jscomp$337$$):$state$jscomp$13$$===$$jscomp$scope$84173391$2$REJECTED$$?$rvalue$$=$task$jscomp$7$$.reject($value$jscomp$337$$):($rvalue$$=new TypeError("invalid state"),$state$jscomp$13$$=$$jscomp$scope$84173391$2$REJECTED$$)}catch($e$jscomp$184$$){$state$jscomp$13$$=$$jscomp$scope$84173391$2$REJECTED$$,$rvalue$$=$task$jscomp$7$$.type===$$jscomp$scope$84173391$7$RESOLVE_TYPE_BIND$$?$promesa$impl$promise$rejected$$($e$jscomp$184$$):$e$jscomp$184$$}$$jscomp$scope$84173391$26$resolveTask$$($task$jscomp$7$$,
$state$jscomp$13$$,$rvalue$$)}};$$jscomp$scope$84173391$24$process$$=function($p$jscomp$111$$){$p$jscomp$111$$[$$jscomp$scope$84173391$4$STATE$$]!==$$jscomp$scope$84173391$0$PENDING$$&&$$jscomp$scope$84173391$15$nextTick$$($$jscomp$scope$84173391$25$processNextTick$$,$p$jscomp$111$$)};$$jscomp$scope$84173391$23$completeDeferredFn$$=function($deferred$$){return($value$jscomp$338$$,$cause$jscomp$8$$)=>{$cause$jscomp$8$$?$deferred$$.reject($cause$jscomp$8$$):$deferred$$.resolve($value$jscomp$338$$)}};
$$jscomp$scope$84173391$19$isThenable$$=function($o$jscomp$182$$){return $goog$isObject$$($o$jscomp$182$$)?typeof $o$jscomp$182$$.then==="function":!1};
$APP.$JSCompiler_StaticMethods_fmap$$=function($JSCompiler_StaticMethods_fmap$self$$,$resolve$jscomp$3$$){const $deferred$jscomp$2$$=new $APP.$$jscomp$scope$84173391$14$PromiseImpl$$;$JSCompiler_StaticMethods_fmap$self$$[$$jscomp$scope$84173391$3$QUEUE$$].push({type:$$jscomp$scope$84173391$8$RESOLVE_TYPE_MAP$$,resolve:$resolve$jscomp$3$$??$$jscomp$scope$84173391$9$defaultResolveMapHandler$$,reject:$$jscomp$scope$84173391$12$defaultRejectHandler$$,complete:$$jscomp$scope$84173391$23$completeDeferredFn$$($deferred$jscomp$2$$)});
$$jscomp$scope$84173391$24$process$$($JSCompiler_StaticMethods_fmap$self$$);return $deferred$jscomp$2$$};
$JSCompiler_StaticMethods_fbind$$=function($JSCompiler_StaticMethods_fbind$self$$,$resolve$jscomp$4$$,$reject$jscomp$3$$){const $deferred$jscomp$3$$=new $APP.$$jscomp$scope$84173391$14$PromiseImpl$$;$JSCompiler_StaticMethods_fbind$self$$[$$jscomp$scope$84173391$3$QUEUE$$].push({type:$$jscomp$scope$84173391$7$RESOLVE_TYPE_BIND$$,resolve:$resolve$jscomp$4$$??$$jscomp$scope$84173391$10$defaultResolveBindHandler$$,reject:$reject$jscomp$3$$??$$jscomp$scope$84173391$12$defaultRejectHandler$$,complete:$$jscomp$scope$84173391$23$completeDeferredFn$$($deferred$jscomp$3$$)});
$$jscomp$scope$84173391$24$process$$($JSCompiler_StaticMethods_fbind$self$$);return $deferred$jscomp$3$$};$APP.$promesa$impl$promise$resolved$$=function($value$jscomp$343$$){if($value$jscomp$343$$===null)return $$jscomp$scope$84173391$28$NULL_PROMISE$$;const $p$jscomp$115$$=new $APP.$$jscomp$scope$84173391$14$PromiseImpl$$;$p$jscomp$115$$[$$jscomp$scope$84173391$4$STATE$$]=$$jscomp$scope$84173391$1$RESOLVED$$;$p$jscomp$115$$[$$jscomp$scope$84173391$5$VALUE$$]=$value$jscomp$343$$;return $p$jscomp$115$$};
$promesa$impl$promise$rejected$$=function($reason$jscomp$13$$){const $p$jscomp$116$$=new $APP.$$jscomp$scope$84173391$14$PromiseImpl$$;$p$jscomp$116$$[$$jscomp$scope$84173391$4$STATE$$]=$$jscomp$scope$84173391$2$REJECTED$$;$p$jscomp$116$$[$$jscomp$scope$84173391$5$VALUE$$]=$reason$jscomp$13$$;return $p$jscomp$116$$};
$promesa$impl$promise$create$$=function($promise$$){if($promise$$ instanceof $APP.$$jscomp$scope$84173391$14$PromiseImpl$$)return $promise$$;if($$jscomp$scope$84173391$19$isThenable$$($promise$$)){const $deferred$jscomp$4$$=new $APP.$$jscomp$scope$84173391$14$PromiseImpl$$;$promise$$.then($v$jscomp$292$$=>{$deferred$jscomp$4$$.resolve($v$jscomp$292$$)},$c$jscomp$219$$=>{$deferred$jscomp$4$$.reject($c$jscomp$219$$)});return $deferred$jscomp$4$$}return $promise$$ instanceof Error?$promesa$impl$promise$rejected$$($promise$$):
$APP.$promesa$impl$promise$resolved$$($promise$$)};
$APP.$promesa$impl$promise$coerce$$=function($promise$jscomp$1$$){if($promise$jscomp$1$$ instanceof $APP.$$jscomp$scope$84173391$14$PromiseImpl$$)return $promise$jscomp$1$$;if($$jscomp$scope$84173391$19$isThenable$$($promise$jscomp$1$$)){const $deferred$jscomp$5$$=new $APP.$$jscomp$scope$84173391$14$PromiseImpl$$;$promise$jscomp$1$$.then($v$jscomp$293$$=>{$deferred$jscomp$5$$.resolve($v$jscomp$293$$)},$c$jscomp$220$$=>{$deferred$jscomp$5$$.reject($c$jscomp$220$$)});return $deferred$jscomp$5$$}return $APP.$promesa$impl$promise$resolved$$($promise$jscomp$1$$)};
$promesa$exec$resolve_executor$cljs$0core$0IFn$0_invoke$0arity$01$$=function($executor$jscomp$18$$){if($executor$jscomp$18$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$executor$jscomp$18$$.$promesa$protocols$IExecutor$$||($executor$jscomp$18$$.$cljs$lang$protocol_mask$partition$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($promesa$protocols$IExecutor$$,$executor$jscomp$18$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($promesa$protocols$IExecutor$$,$executor$jscomp$18$$))return $executor$jscomp$18$$;
if($executor$jscomp$18$$==null)return $APP.$cljs$core$_deref$$($promesa$exec$default_executor$$);if($APP.$cljs$core$delay_QMARK_$$($executor$jscomp$18$$))return $promesa$exec$resolve_executor$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$_deref$$($executor$jscomp$18$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$executor$jscomp$18$$))return $APP.$cljs$core$_deref$$($promesa$exec$default_executor$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1141$cached$$,
$executor$jscomp$18$$))return $APP.$cljs$core$_deref$$($promesa$exec$default_cached_executor$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$205$default$$,$executor$jscomp$18$$))return $APP.$cljs$core$_deref$$($promesa$exec$default_executor$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1142$current_thread$$,$executor$jscomp$18$$))return $APP.$cljs$core$_deref$$($promesa$exec$default_current_thread_executor$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1143$vthread$$,
$executor$jscomp$18$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1144$thread$$,$executor$jscomp$18$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1145$virtual$$,$executor$jscomp$18$$))return $APP.$cljs$core$_deref$$($promesa$exec$default_executor$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1146$same_thread$$,$executor$jscomp$18$$))return $APP.$cljs$core$_deref$$($promesa$exec$default_current_thread_executor$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1147$platform$$,
$executor$jscomp$18$$))return $APP.$cljs$core$_deref$$($promesa$exec$default_executor$$);throw new TypeError("invalid executor");};$promesa$exec$exec_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$544$$){$promesa$protocols$_exec_BANG_$$($promesa$exec$resolve_executor$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$logging$_STAR_default_executor_STAR_$$),$f$jscomp$544$$)};
$promesa$exec$schedule_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($JSCompiler_temp$jscomp$10699_scheduler$jscomp$2$$,$ms$jscomp$8$$,$f$jscomp$550$$){$JSCompiler_temp$jscomp$10699_scheduler$jscomp$2$$=$JSCompiler_temp$jscomp$10699_scheduler$jscomp$2$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$205$default$$,$JSCompiler_temp$jscomp$10699_scheduler$jscomp$2$$)?$APP.$cljs$core$_deref$$($promesa$exec$default_scheduler$$):$APP.$cljs$core$delay_QMARK_$$($JSCompiler_temp$jscomp$10699_scheduler$jscomp$2$$)?
$APP.$cljs$core$_deref$$($JSCompiler_temp$jscomp$10699_scheduler$jscomp$2$$):$JSCompiler_temp$jscomp$10699_scheduler$jscomp$2$$;$promesa$protocols$_schedule_BANG_$$($JSCompiler_temp$jscomp$10699_scheduler$jscomp$2$$,$ms$jscomp$8$$,$f$jscomp$550$$)};$promesa$exec$Scheduler$$=function(){};
$promesa$exec$scheduled_executor$$=function($var_args$jscomp$676$$){for(var $args__5755__auto__$jscomp$130_map__35643__$1$jscomp$inline_3977$$=[],$len__5749__auto___35709$$=arguments.length,$i__5750__auto___35710$$=0;;)if($i__5750__auto___35710$$<$len__5749__auto___35709$$)$args__5755__auto__$jscomp$130_map__35643__$1$jscomp$inline_3977$$.push(arguments[$i__5750__auto___35710$$]),$i__5750__auto___35710$$+=1;else break;$args__5755__auto__$jscomp$130_map__35643__$1$jscomp$inline_3977$$=$APP.$cljs$core$__destructure_map$$(0<
$args__5755__auto__$jscomp$130_map__35643__$1$jscomp$inline_3977$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$130_map__35643__$1$jscomp$inline_3977$$.slice(0),0,null):null);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($args__5755__auto__$jscomp$130_map__35643__$1$jscomp$inline_3977$$,$cljs$cst$1148$parallelism$$,1);return new $promesa$exec$Scheduler$$};
$promesa$exec$t_promesa$0exec35644$$=function($meta35645$$){this.$meta35645$=$meta35645$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};$promesa$exec$current_thread_executor$$=function(){return new $promesa$exec$t_promesa$0exec35644$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$promesa$exec$t_promesa$0exec35651$$=function($meta35652$$){this.$meta35652$=$meta35652$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};$promesa$exec$microtask_executor$$=function(){return new $promesa$exec$t_promesa$0exec35651$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$common$logging$get_parent_logger$$=function($logger$$){var $lindex$$=$logger$$.lastIndexOf(".");return $logger$$.slice(0,$lindex$$>0?$lindex$$:0)};
$APP.$app$common$logging$enabled_QMARK_$$=function($JSCompiler_inline_result$jscomp$530_logger$jscomp$2$$,$JSCompiler_temp_const$jscomp$529_level$jscomp$32$$){$JSCompiler_temp_const$jscomp$529_level$jscomp$32$$=$APP.$app$common$logging$level__GT_int$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$logging$level__GT_int$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$529_level$jscomp$32$$):$APP.$app$common$logging$level__GT_int$$($JSCompiler_temp_const$jscomp$529_level$jscomp$32$$);
a:{var $logger_SINGLEQUOTE_$jscomp$inline_3981_val$jscomp$inline_3980$$=$APP.$app$common$logging$loggers$$.get($JSCompiler_inline_result$jscomp$530_logger$jscomp$2$$);if($logger_SINGLEQUOTE_$jscomp$inline_3981_val$jscomp$inline_3980$$>0)$JSCompiler_inline_result$jscomp$530_logger$jscomp$2$$=$logger_SINGLEQUOTE_$jscomp$inline_3981_val$jscomp$inline_3980$$;else{for($logger_SINGLEQUOTE_$jscomp$inline_3981_val$jscomp$inline_3980$$=$app$common$logging$get_parent_logger$$($JSCompiler_inline_result$jscomp$530_logger$jscomp$2$$);;){var $val__$1$jscomp$inline_3982$$=
$APP.$app$common$logging$loggers$$.get($logger_SINGLEQUOTE_$jscomp$inline_3981_val$jscomp$inline_3980$$);if($val__$1$jscomp$inline_3982$$!=null){$APP.$app$common$logging$loggers$$.set($JSCompiler_inline_result$jscomp$530_logger$jscomp$2$$,$val__$1$jscomp$inline_3982$$);$JSCompiler_inline_result$jscomp$530_logger$jscomp$2$$=$val__$1$jscomp$inline_3982$$;break a}if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",$logger_SINGLEQUOTE_$jscomp$inline_3981_val$jscomp$inline_3980$$)){$APP.$app$common$logging$loggers$$.set($JSCompiler_inline_result$jscomp$530_logger$jscomp$2$$,
100);$JSCompiler_inline_result$jscomp$530_logger$jscomp$2$$=100;break a}$logger_SINGLEQUOTE_$jscomp$inline_3981_val$jscomp$inline_3980$$=$app$common$logging$get_parent_logger$$($logger_SINGLEQUOTE_$jscomp$inline_3981_val$jscomp$inline_3980$$)}$JSCompiler_inline_result$jscomp$530_logger$jscomp$2$$=void 0}}return $JSCompiler_temp_const$jscomp$529_level$jscomp$32$$>=$JSCompiler_inline_result$jscomp$530_logger$jscomp$2$$};
$app$common$logging$level__GT_color$$=function($level$jscomp$33$$){switch($level$jscomp$33$$ instanceof $APP.$cljs$core$Keyword$$?$level$jscomp$33$$.$fqn$:null){case "error":return"#c82829";case "warn":return"#f5871f";case "info":return"#4271ae";case "debug":return"#969896";case "trace":return"#8e908c";default:var $hint$jscomp$2$$=["invalid level provided to `level-\x3ecolor` function: ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$level$jscomp$33$$]))].join("");
throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$($hint$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$284$level$$,$level$jscomp$33$$],null));}};
$app$common$logging$level__GT_name$$=function($level$jscomp$34$$){switch($level$jscomp$34$$ instanceof $APP.$cljs$core$Keyword$$?$level$jscomp$34$$.$fqn$:null){case "debug":return"DBG";case "trace":return"TRC";case "info":return"INF";case "warn":return"WRN";case "error":return"ERR";default:var $hint$jscomp$3$$=["invalid level provided to `level-\x3ename` function: ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$level$jscomp$34$$]))].join("");
throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$($hint$jscomp$3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$284$level$$,$level$jscomp$34$$],null));}};
$APP.$app$common$logging$level__GT_int$$=function($level$jscomp$35$$){switch($level$jscomp$35$$ instanceof $APP.$cljs$core$Keyword$$?$level$jscomp$35$$.$fqn$:null){case "trace":return 10;case "debug":return 20;case "info":return 30;case "warn":return 40;case "error":return 50;default:var $hint$jscomp$4$$=["invalid level provided to `level-\x3eint` function: ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$level$jscomp$35$$]))].join("");
throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$($hint$jscomp$4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$284$level$$,$level$jscomp$35$$],null));}};
$app$common$logging$get_special_props$$=function($props$jscomp$49$$){return $APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__42563_v$jscomp$297$$){var $k$jscomp$481$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__42563_v$jscomp$297$$,0,null);$p__42563_v$jscomp$297$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__42563_v$jscomp$297$$,1,null);return $cljs$core$qualified_ident_QMARK_$$($k$jscomp$481$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("js",
$APP.$cljs$core$namespace$$($k$jscomp$481$$))?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1152$js$$,$APP.$cljs$core$name$$($k$jscomp$481$$),$APP.$cljs$core$object_QMARK_$$($p__42563_v$jscomp$297$$)?$p__42563_v$jscomp$297$$:$APP.$cljs$core$clj__GT_js$$($p__42563_v$jscomp$297$$)],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("error",$APP.$cljs$core$namespace$$($k$jscomp$481$$))?new $APP.$cljs$core$PersistentVector$$(null,3,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$849$error$$,$APP.$cljs$core$name$$($k$jscomp$481$$),$p__42563_v$jscomp$297$$],null):null:null},$APP.$cljs$core$seq$$($props$jscomp$49$$))};
$APP.$app$common$logging$emit_log$$=function($props$jscomp$50$$,$cause$jscomp$22$$,$logger$jscomp$3$$,$level$jscomp$36$$,$sync_QMARK_$$){function $logfn$$(){var $context__$1_lrecord__$1_props__$2$$=$APP.$cljs$core$truth_$$($sync_QMARK_$$)?$props__$1$jscomp$2$$:$APP.$cljs$core$_deref$$($props__$1$jscomp$2$$),$props__$3$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$linked$map$empty_linked_map$$,$context__$1_lrecord__$1_props__$2$$);$context__$1_lrecord__$1_props__$2$$=$APP.$cljs$core$empty_QMARK_$$(null)&&
$APP.$cljs$core$empty_QMARK_$$(null)?$APP.$cljs$core$PersistentArrayMap$EMPTY$$:$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([null,null])));var $lrecord$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$cljs$cst$1157$app_DOT_common_DOT_logging_SLASH_id$$,$APP.$app$common$uuid$next$$(),$cljs$cst$1159$app_DOT_common_DOT_logging_SLASH_timestamp$$,$ts$jscomp$7$$,
$cljs$cst$1164$app_DOT_common_DOT_logging_SLASH_message$$,new $APP.$cljs$core$Delay$$(function(){a:{var $G__42665$jscomp$inline_3994_G__42668$jscomp$inline_3997_G__42671$jscomp$inline_4000_JSCompiler_inline_result$jscomp$531_message$jscomp$inline_4003_props__$1$jscomp$inline_3987$$=$APP.$cljs$core$seq$$($props__$3$$);for(var $G__42666$jscomp$inline_3995_G__42669$jscomp$inline_3998_G__42672$jscomp$inline_4001_result$jscomp$inline_3988$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$G__42667$jscomp$inline_3996_G__42670$jscomp$inline_3999_G__42673$jscomp$inline_4002_body$jscomp$inline_3989$$=
null;;){var $temp__5823__auto__$jscomp$inline_3990_v$jscomp$inline_3993_vec__42546$jscomp$inline_3991$$=$APP.$cljs$core$first$$($G__42665$jscomp$inline_3994_G__42668$jscomp$inline_3997_G__42671$jscomp$inline_4000_JSCompiler_inline_result$jscomp$531_message$jscomp$inline_4003_props__$1$jscomp$inline_3987$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_3990_v$jscomp$inline_3993_vec__42546$jscomp$inline_3991$$)){var $k$jscomp$inline_3992$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($temp__5823__auto__$jscomp$inline_3990_v$jscomp$inline_3993_vec__42546$jscomp$inline_3991$$,
0,null);$temp__5823__auto__$jscomp$inline_3990_v$jscomp$inline_3993_vec__42546$jscomp$inline_3991$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($temp__5823__auto__$jscomp$inline_3990_v$jscomp$inline_3993_vec__42546$jscomp$inline_3991$$,1,null);$cljs$core$simple_ident_QMARK_$$($k$jscomp$inline_3992$$)?($G__42665$jscomp$inline_3994_G__42668$jscomp$inline_3997_G__42671$jscomp$inline_4000_JSCompiler_inline_result$jscomp$531_message$jscomp$inline_4003_props__$1$jscomp$inline_3987$$=$APP.$cljs$core$next$$($G__42665$jscomp$inline_3994_G__42668$jscomp$inline_3997_G__42671$jscomp$inline_4000_JSCompiler_inline_result$jscomp$531_message$jscomp$inline_4003_props__$1$jscomp$inline_3987$$),
$G__42666$jscomp$inline_3995_G__42669$jscomp$inline_3998_G__42672$jscomp$inline_4001_result$jscomp$inline_3988$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__42666$jscomp$inline_3995_G__42669$jscomp$inline_3998_G__42672$jscomp$inline_4001_result$jscomp$inline_3988$$,[$APP.$cljs$core$name$$($k$jscomp$inline_3992$$),"\x3d",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$temp__5823__auto__$jscomp$inline_3990_v$jscomp$inline_3993_vec__42546$jscomp$inline_3991$$]))].join(""))):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1151$app_DOT_common_DOT_logging_SLASH_body$$,$k$jscomp$inline_3992$$)?($G__42665$jscomp$inline_3994_G__42668$jscomp$inline_3997_G__42671$jscomp$inline_4000_JSCompiler_inline_result$jscomp$531_message$jscomp$inline_4003_props__$1$jscomp$inline_3987$$=$APP.$cljs$core$next$$($G__42665$jscomp$inline_3994_G__42668$jscomp$inline_3997_G__42671$jscomp$inline_4000_JSCompiler_inline_result$jscomp$531_message$jscomp$inline_4003_props__$1$jscomp$inline_3987$$),
$G__42667$jscomp$inline_3996_G__42670$jscomp$inline_3999_G__42673$jscomp$inline_4002_body$jscomp$inline_3989$$=$temp__5823__auto__$jscomp$inline_3990_v$jscomp$inline_3993_vec__42546$jscomp$inline_3991$$):$G__42665$jscomp$inline_3994_G__42668$jscomp$inline_3997_G__42671$jscomp$inline_4000_JSCompiler_inline_result$jscomp$531_message$jscomp$inline_4003_props__$1$jscomp$inline_3987$$=$APP.$cljs$core$next$$($G__42665$jscomp$inline_3994_G__42668$jscomp$inline_3997_G__42671$jscomp$inline_4000_JSCompiler_inline_result$jscomp$531_message$jscomp$inline_4003_props__$1$jscomp$inline_3987$$)}else{$G__42665$jscomp$inline_3994_G__42668$jscomp$inline_3997_G__42671$jscomp$inline_4000_JSCompiler_inline_result$jscomp$531_message$jscomp$inline_4003_props__$1$jscomp$inline_3987$$=
$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$G__42666$jscomp$inline_3995_G__42669$jscomp$inline_3998_G__42672$jscomp$inline_4001_result$jscomp$inline_3988$$);$G__42665$jscomp$inline_3994_G__42668$jscomp$inline_3997_G__42671$jscomp$inline_4000_JSCompiler_inline_result$jscomp$531_message$jscomp$inline_4003_props__$1$jscomp$inline_3987$$=typeof $G__42667$jscomp$inline_3996_G__42670$jscomp$inline_3999_G__42673$jscomp$inline_4002_body$jscomp$inline_3989$$==="string"?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__42665$jscomp$inline_3994_G__42668$jscomp$inline_3997_G__42671$jscomp$inline_4000_JSCompiler_inline_result$jscomp$531_message$jscomp$inline_4003_props__$1$jscomp$inline_3987$$),
"\n",$G__42667$jscomp$inline_3996_G__42670$jscomp$inline_3999_G__42673$jscomp$inline_4002_body$jscomp$inline_3989$$].join(""):$G__42665$jscomp$inline_3994_G__42668$jscomp$inline_3997_G__42671$jscomp$inline_4000_JSCompiler_inline_result$jscomp$531_message$jscomp$inline_4003_props__$1$jscomp$inline_3987$$;break a}}$G__42665$jscomp$inline_3994_G__42668$jscomp$inline_3997_G__42671$jscomp$inline_4000_JSCompiler_inline_result$jscomp$531_message$jscomp$inline_4003_props__$1$jscomp$inline_3987$$=void 0}return $G__42665$jscomp$inline_3994_G__42668$jscomp$inline_3997_G__42671$jscomp$inline_4000_JSCompiler_inline_result$jscomp$531_message$jscomp$inline_4003_props__$1$jscomp$inline_3987$$}),
$cljs$cst$1158$app_DOT_common_DOT_logging_SLASH_props$$,$props__$3$$,$cljs$cst$1153$app_DOT_common_DOT_logging_SLASH_context$$,$context__$1_lrecord__$1_props__$2$$,$cljs$cst$1156$app_DOT_common_DOT_logging_SLASH_level$$,$level$jscomp$36$$,$cljs$cst$1155$app_DOT_common_DOT_logging_SLASH_logger$$,$logger$jscomp$3$$],null);$context__$1_lrecord__$1_props__$2$$=function(){return $cause$jscomp$22$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($lrecord$$,$cljs$cst$1165$app_DOT_common_DOT_logging_SLASH_cause$$,
$cause$jscomp$22$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$1166$app_DOT_common_DOT_logging_SLASH_trace$$,new $APP.$cljs$core$Delay$$(function(){return $cause$jscomp$22$$.stack})])):$lrecord$$}();return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$common$logging$log_record$$,$APP.$cljs$core$constantly$$($context__$1_lrecord__$1_props__$2$$))}var $props__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($sync_QMARK_$$)?$APP.$cljs$core$_deref$$($props$jscomp$50$$):
$props$jscomp$50$$,$ts$jscomp$7$$=Date.now();$APP.$cljs$core$truth_$$($sync_QMARK_$$)?$logfn$$():$promesa$exec$exec_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($logfn$$)};
$APP.$app$common$logging$setup_BANG_$$=function(){var $config$jscomp$10$$=$APP.$cljs$core$__destructure_map$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5319$app$$,$APP.$cljs$cst$1161$info$$],null));$APP.$cljs$core$run_BANG_$$(function($level$jscomp$38_p__42645$$){var $logger$jscomp$5_logger__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($level$jscomp$38_p__42645$$,0,null);$level$jscomp$38_p__42645$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($level$jscomp$38_p__42645$$,
1,null);$logger$jscomp$5_logger__$1$$=$logger$jscomp$5_logger__$1$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$($logger$jscomp$5_logger__$1$$):$logger$jscomp$5_logger__$1$$;return $APP.$app$common$logging$loggers$$.set($logger$jscomp$5_logger__$1$$,$APP.$app$common$logging$level__GT_int$$($level$jscomp$38_p__42645$$))},$config$jscomp$10$$)};
$cljs_bean$from$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$=function($coll$jscomp$990$$,$x$jscomp$943$$,$JSCompiler_temp$jscomp$533_JSCompiler_temp$jscomp$534_idx$jscomp$53_start$jscomp$159_y__5111__auto__$jscomp$inline_4005$$){var $len$jscomp$59$$=$APP.$cljs$core$count$$($coll$jscomp$990$$);if($JSCompiler_temp$jscomp$533_JSCompiler_temp$jscomp$534_idx$jscomp$53_start$jscomp$159_y__5111__auto__$jscomp$inline_4005$$>=$len$jscomp$59$$)return-1;!($JSCompiler_temp$jscomp$533_JSCompiler_temp$jscomp$534_idx$jscomp$53_start$jscomp$159_y__5111__auto__$jscomp$inline_4005$$>
0)&&$JSCompiler_temp$jscomp$533_JSCompiler_temp$jscomp$534_idx$jscomp$53_start$jscomp$159_y__5111__auto__$jscomp$inline_4005$$<0&&($JSCompiler_temp$jscomp$533_JSCompiler_temp$jscomp$534_idx$jscomp$53_start$jscomp$159_y__5111__auto__$jscomp$inline_4005$$+=$len$jscomp$59$$,$JSCompiler_temp$jscomp$533_JSCompiler_temp$jscomp$534_idx$jscomp$53_start$jscomp$159_y__5111__auto__$jscomp$inline_4005$$=0>$JSCompiler_temp$jscomp$533_JSCompiler_temp$jscomp$534_idx$jscomp$53_start$jscomp$159_y__5111__auto__$jscomp$inline_4005$$?
0:$JSCompiler_temp$jscomp$533_JSCompiler_temp$jscomp$534_idx$jscomp$53_start$jscomp$159_y__5111__auto__$jscomp$inline_4005$$);for(;;)if($JSCompiler_temp$jscomp$533_JSCompiler_temp$jscomp$534_idx$jscomp$53_start$jscomp$159_y__5111__auto__$jscomp$inline_4005$$<$len$jscomp$59$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($coll$jscomp$990$$,$JSCompiler_temp$jscomp$533_JSCompiler_temp$jscomp$534_idx$jscomp$53_start$jscomp$159_y__5111__auto__$jscomp$inline_4005$$),
$x$jscomp$943$$))return $JSCompiler_temp$jscomp$533_JSCompiler_temp$jscomp$534_idx$jscomp$53_start$jscomp$159_y__5111__auto__$jscomp$inline_4005$$;$JSCompiler_temp$jscomp$533_JSCompiler_temp$jscomp$534_idx$jscomp$53_start$jscomp$159_y__5111__auto__$jscomp$inline_4005$$+=1}else return-1};
$cljs_bean$from$cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$=function($coll$jscomp$992$$,$x$jscomp$945$$,$JSCompiler_temp$jscomp$535_idx$jscomp$54_start$jscomp$160$$){var $len$jscomp$60_x__5113__auto__$jscomp$inline_4007$$=$APP.$cljs$core$count$$($coll$jscomp$992$$);if($len$jscomp$60_x__5113__auto__$jscomp$inline_4007$$===0)return-1;$JSCompiler_temp$jscomp$535_idx$jscomp$54_start$jscomp$160$$>0?(--$len$jscomp$60_x__5113__auto__$jscomp$inline_4007$$,$JSCompiler_temp$jscomp$535_idx$jscomp$54_start$jscomp$160$$=
$len$jscomp$60_x__5113__auto__$jscomp$inline_4007$$<$JSCompiler_temp$jscomp$535_idx$jscomp$54_start$jscomp$160$$?$len$jscomp$60_x__5113__auto__$jscomp$inline_4007$$:$JSCompiler_temp$jscomp$535_idx$jscomp$54_start$jscomp$160$$):$JSCompiler_temp$jscomp$535_idx$jscomp$54_start$jscomp$160$$=$JSCompiler_temp$jscomp$535_idx$jscomp$54_start$jscomp$160$$<0?$len$jscomp$60_x__5113__auto__$jscomp$inline_4007$$+$JSCompiler_temp$jscomp$535_idx$jscomp$54_start$jscomp$160$$:$JSCompiler_temp$jscomp$535_idx$jscomp$54_start$jscomp$160$$;
for(;;)if($JSCompiler_temp$jscomp$535_idx$jscomp$54_start$jscomp$160$$>=0){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($coll$jscomp$992$$,$JSCompiler_temp$jscomp$535_idx$jscomp$54_start$jscomp$160$$),$x$jscomp$945$$))return $JSCompiler_temp$jscomp$535_idx$jscomp$54_start$jscomp$160$$;--$JSCompiler_temp$jscomp$535_idx$jscomp$54_start$jscomp$160$$}else return-1};
$cljs_bean$from$cljs$core$equiv_sequential$$=function($G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$,$G__37035$jscomp$inline_4012_y$jscomp$296_ys$jscomp$inline_4010$$){if($APP.$cljs$core$sequential_QMARK_$$($G__37035$jscomp$inline_4012_y$jscomp$296_ys$jscomp$inline_4010$$))if($cljs$core$counted_QMARK_$$($G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$)&&$cljs$core$counted_QMARK_$$($G__37035$jscomp$inline_4012_y$jscomp$296_ys$jscomp$inline_4010$$)&&
$APP.$cljs$core$count$$($G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$)!==$APP.$cljs$core$count$$($G__37035$jscomp$inline_4012_y$jscomp$296_ys$jscomp$inline_4010$$))$G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$=!1;else a:{$G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$=$APP.$cljs$core$seq$$($G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$);
for($G__37035$jscomp$inline_4012_y$jscomp$296_ys$jscomp$inline_4010$$=$APP.$cljs$core$seq$$($G__37035$jscomp$inline_4012_y$jscomp$296_ys$jscomp$inline_4010$$);;){if($G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$==null){$G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$=$G__37035$jscomp$inline_4012_y$jscomp$296_ys$jscomp$inline_4010$$==null;break a}if($G__37035$jscomp$inline_4012_y$jscomp$296_ys$jscomp$inline_4010$$!=
null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$),$APP.$cljs$core$first$$($G__37035$jscomp$inline_4012_y$jscomp$296_ys$jscomp$inline_4010$$)))$G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$=$APP.$cljs$core$next$$($G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$),
$G__37035$jscomp$inline_4012_y$jscomp$296_ys$jscomp$inline_4010$$=$APP.$cljs$core$next$$($G__37035$jscomp$inline_4012_y$jscomp$296_ys$jscomp$inline_4010$$);else{$G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$=!1;break a}}$G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$=void 0}else $G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$=
null;return $APP.$cljs$core$boolean$0$$($G__37034$jscomp$inline_4011_JSCompiler_temp$jscomp$537_JSCompiler_temp$jscomp$538_x$jscomp$946_xs$jscomp$inline_4009$$)};
$cljs_bean$from$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$=function($cicoll$jscomp$2$$,$f$jscomp$564$$){var $cnt$jscomp$36$$=$cicoll$jscomp$2$$.$cljs$core$ICounted$_count$arity$1$(null);if($cnt$jscomp$36$$===0)return $f$jscomp$564$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$564$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$564$$();for(var $G__36994$jscomp$inline_4014_nval$jscomp$6_val$jscomp$129$$=$cicoll$jscomp$2$$.$cljs$core$IIndexed$_nth$arity$2$(null,0),$G__37040_n$jscomp$237$$=
1;;)if($G__37040_n$jscomp$237$$<$cnt$jscomp$36$$){var $G__36996$jscomp$inline_4015$$=$cicoll$jscomp$2$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__37040_n$jscomp$237$$);$G__36994$jscomp$inline_4014_nval$jscomp$6_val$jscomp$129$$=$f$jscomp$564$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$564$$.$cljs$core$IFn$_invoke$arity$2$($G__36994$jscomp$inline_4014_nval$jscomp$6_val$jscomp$129$$,$G__36996$jscomp$inline_4015$$):$f$jscomp$564$$($G__36994$jscomp$inline_4014_nval$jscomp$6_val$jscomp$129$$,$G__36996$jscomp$inline_4015$$);
if($cljs$core$reduced_QMARK_$$($G__36994$jscomp$inline_4014_nval$jscomp$6_val$jscomp$129$$))return $APP.$cljs$core$_deref$$($G__36994$jscomp$inline_4014_nval$jscomp$6_val$jscomp$129$$);$G__37040_n$jscomp$237$$+=1}else return $G__36994$jscomp$inline_4014_nval$jscomp$6_val$jscomp$129$$};
$cljs_bean$from$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$=function($cicoll$jscomp$3$$,$f$jscomp$565$$,$G__37042_n$jscomp$238_val$jscomp$130$$){var $cnt$jscomp$37$$=$cicoll$jscomp$3$$.$cljs$core$ICounted$_count$arity$1$(null),$G__36998$jscomp$inline_4017_nval$jscomp$7_val__$1$jscomp$9$$=$G__37042_n$jscomp$238_val$jscomp$130$$;for($G__37042_n$jscomp$238_val$jscomp$130$$=0;;)if($G__37042_n$jscomp$238_val$jscomp$130$$<$cnt$jscomp$37$$){var $G__36999$jscomp$inline_4018$$=$cicoll$jscomp$3$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$G__37042_n$jscomp$238_val$jscomp$130$$);$G__36998$jscomp$inline_4017_nval$jscomp$7_val__$1$jscomp$9$$=$f$jscomp$565$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$565$$.$cljs$core$IFn$_invoke$arity$2$($G__36998$jscomp$inline_4017_nval$jscomp$7_val__$1$jscomp$9$$,$G__36999$jscomp$inline_4018$$):$f$jscomp$565$$($G__36998$jscomp$inline_4017_nval$jscomp$7_val__$1$jscomp$9$$,$G__36999$jscomp$inline_4018$$);if($cljs$core$reduced_QMARK_$$($G__36998$jscomp$inline_4017_nval$jscomp$7_val__$1$jscomp$9$$))return $APP.$cljs$core$_deref$$($G__36998$jscomp$inline_4017_nval$jscomp$7_val__$1$jscomp$9$$);
$G__37042_n$jscomp$238_val$jscomp$130$$+=1}else return $G__36998$jscomp$inline_4017_nval$jscomp$7_val__$1$jscomp$9$$};$cljs_bean$core$primitive_QMARK_$$=function($x$jscomp$948$$){return typeof $x$jscomp$948$$==="number"||typeof $x$jscomp$948$$==="string"||$APP.$cljs$core$boolean_QMARK_$$($x$jscomp$948$$)||$x$jscomp$948$$==null};
$cljs_bean$core$__GT_val$$=function($x$jscomp$949$$,$prop__GT_key$$,$key__GT_prop$$,$transform$jscomp$4$$){var $temp__5827__auto__$jscomp$19$$=$transform$jscomp$4$$!=null?$transform$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$transform$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$949$$):$transform$jscomp$4$$($x$jscomp$949$$):null;return $temp__5827__auto__$jscomp$19$$==null?$cljs_bean$core$primitive_QMARK_$$($x$jscomp$949$$)?$x$jscomp$949$$:$APP.$cljs$core$object_QMARK_$$($x$jscomp$949$$)?
new $cljs_bean$core$Bean$$(null,$x$jscomp$949$$,$prop__GT_key$$,$key__GT_prop$$,$transform$jscomp$4$$,!0,null,null,null):$APP.$cljs$core$array_QMARK_$$($x$jscomp$949$$)?new $cljs_bean$core$ArrayVector$$(null,$prop__GT_key$$,$key__GT_prop$$,$transform$jscomp$4$$,$x$jscomp$949$$,null):$x$jscomp$949$$:$temp__5827__auto__$jscomp$19$$};
$cljs_bean$core$unwrap$$=function($x$jscomp$950$$){return $cljs_bean$core$primitive_QMARK_$$($x$jscomp$950$$)?$x$jscomp$950$$:$x$jscomp$950$$ instanceof $cljs_bean$core$Bean$$?$x$jscomp$950$$.$obj$:$x$jscomp$950$$ instanceof $cljs_bean$core$ArrayVector$$?$x$jscomp$950$$.$arr$:$x$jscomp$950$$};
$cljs_bean$core$snapshot$$=function($x$jscomp$951$$,$prop__GT_key$jscomp$1$$,$key__GT_prop$jscomp$1$$,$transform$jscomp$5$$,$recursive_QMARK_$$){var $result$jscomp$119$$=$APP.$cljs$core$volatile_BANG_$$($APP.$cljs$core$_as_transient$$($cljs_bean$core$empty_map$$));$module$contents$goog$object_forEach$$($x$jscomp$951$$,function($v$jscomp$299$$,$k$jscomp$486$$){return $result$jscomp$119$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$119$$.$cljs$core$IDeref$_deref$arity$1$(null),
$prop__GT_key$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$prop__GT_key$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$486$$):$prop__GT_key$jscomp$1$$($k$jscomp$486$$),$APP.$cljs$core$truth_$$($recursive_QMARK_$$)?$cljs_bean$core$__GT_val$$($v$jscomp$299$$,$prop__GT_key$jscomp$1$$,$key__GT_prop$jscomp$1$$,$transform$jscomp$5$$):$v$jscomp$299$$))});return $APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$_deref$$($result$jscomp$119$$))};
$cljs_bean$core$snapshot_arr$$=function($JSCompiler_inline_result$jscomp$10703_arr$jscomp$147$$){a:{for(var $l__5611__auto__$jscomp$inline_11547$$=$JSCompiler_inline_result$jscomp$10703_arr$jscomp$147$$.length,$ret$jscomp$inline_11548$$=$APP.$cljs$core$aclone$$($JSCompiler_inline_result$jscomp$10703_arr$jscomp$147$$),$idx$jscomp$inline_11549$$=0;;)if($idx$jscomp$inline_11549$$<$l__5611__auto__$jscomp$inline_11547$$){var $JSCompiler_temp_const$jscomp$inline_11550$$=$idx$jscomp$inline_11549$$;var $G__40112$jscomp$inline_11552_JSCompiler_inline_result$jscomp$inline_11551$$=
$JSCompiler_inline_result$jscomp$10703_arr$jscomp$147$$[$idx$jscomp$inline_11549$$];$G__40112$jscomp$inline_11552_JSCompiler_inline_result$jscomp$inline_11551$$=$cljs_bean$core$__GT_clj$cljs$0core$0IFn$0_invoke$0arity$01$$?$cljs_bean$core$__GT_clj$cljs$0core$0IFn$0_invoke$0arity$01$$($G__40112$jscomp$inline_11552_JSCompiler_inline_result$jscomp$inline_11551$$):$cljs_bean$core$__GT_clj$$($G__40112$jscomp$inline_11552_JSCompiler_inline_result$jscomp$inline_11551$$);$ret$jscomp$inline_11548$$[$JSCompiler_temp_const$jscomp$inline_11550$$]=
$G__40112$jscomp$inline_11552_JSCompiler_inline_result$jscomp$inline_11551$$;$idx$jscomp$inline_11549$$+=1}else{$JSCompiler_inline_result$jscomp$10703_arr$jscomp$147$$=$ret$jscomp$inline_11548$$;break a}$JSCompiler_inline_result$jscomp$10703_arr$jscomp$147$$=void 0}return $APP.$cljs$core$vec$$($JSCompiler_inline_result$jscomp$10703_arr$jscomp$147$$)};
$cljs_bean$core$indexed_entry$$=function($G__40126$jscomp$inline_4022_obj$jscomp$109$$,$JSCompiler_inline_result$jscomp$548_prop__GT_key$jscomp$2$$,$key__GT_prop$jscomp$2$$,$transform$jscomp$6$$,$recursive_QMARK_$jscomp$1$$,$JSCompiler_temp_const$jscomp$547_arr$jscomp$148$$,$i$jscomp$373_prop$jscomp$9$$){$i$jscomp$373_prop$jscomp$9$$=$JSCompiler_temp_const$jscomp$547_arr$jscomp$148$$[$i$jscomp$373_prop$jscomp$9$$];$JSCompiler_temp_const$jscomp$547_arr$jscomp$148$$=$JSCompiler_inline_result$jscomp$548_prop__GT_key$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?
$JSCompiler_inline_result$jscomp$548_prop__GT_key$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($i$jscomp$373_prop$jscomp$9$$):$JSCompiler_inline_result$jscomp$548_prop__GT_key$jscomp$2$$($i$jscomp$373_prop$jscomp$9$$);$G__40126$jscomp$inline_4022_obj$jscomp$109$$=$G__40126$jscomp$inline_4022_obj$jscomp$109$$[$i$jscomp$373_prop$jscomp$9$$];$JSCompiler_inline_result$jscomp$548_prop__GT_key$jscomp$2$$=$recursive_QMARK_$jscomp$1$$?$cljs_bean$core$__GT_val$$($G__40126$jscomp$inline_4022_obj$jscomp$109$$,
$JSCompiler_inline_result$jscomp$548_prop__GT_key$jscomp$2$$,$key__GT_prop$jscomp$2$$,$transform$jscomp$6$$):$G__40126$jscomp$inline_4022_obj$jscomp$109$$;return new $APP.$cljs$core$MapEntry$$($JSCompiler_temp_const$jscomp$547_arr$jscomp$148$$,$JSCompiler_inline_result$jscomp$548_prop__GT_key$jscomp$2$$,null)};
$cljs_bean$core$compatible_key_QMARK_$$=function($k$jscomp$487$$,$prop__GT_key$jscomp$3$$){return $k$jscomp$487$$ instanceof $APP.$cljs$core$Keyword$$&&$prop__GT_key$jscomp$3$$===$APP.$cljs$core$keyword$$||typeof $k$jscomp$487$$==="string"&&$prop__GT_key$jscomp$3$$===$APP.$cljs$core$identity$$};
$cljs_bean$core$compatible_value_QMARK_$$=function($v$jscomp$300$$,$recursive_QMARK_$jscomp$2$$){return $cljs_bean$core$primitive_QMARK_$$($v$jscomp$300$$)||!($APP.$cljs$core$map_QMARK_$$($v$jscomp$300$$)&&!($v$jscomp$300$$ instanceof $cljs_bean$core$Bean$$)||$APP.$cljs$core$vector_QMARK_$$($v$jscomp$300$$)&&!($v$jscomp$300$$ instanceof $cljs_bean$core$ArrayVector$$))&&$APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($recursive_QMARK_$jscomp$2$$)?$APP.$cljs$core$object_QMARK_$$($v$jscomp$300$$)||$APP.$cljs$core$array_QMARK_$$($v$jscomp$300$$):
$recursive_QMARK_$jscomp$2$$)};
$cljs_bean$core$TransientBean$$=function($obj$jscomp$110$$,$prop__GT_key$jscomp$5$$,$key__GT_prop$jscomp$3$$,$transform$jscomp$7$$,$recursive_QMARK_$jscomp$4$$,$__cnt$$){this.$editable_QMARK_$=!0;this.$obj$=$obj$jscomp$110$$;this.$prop__GT_key$=$prop__GT_key$jscomp$5$$;this.$key__GT_prop$=$key__GT_prop$jscomp$3$$;this.transform=$transform$jscomp$7$$;this.$recursive_QMARK_$=$recursive_QMARK_$jscomp$4$$;this.$__cnt$=$__cnt$$;this.$cljs$lang$protocol_mask$partition0$$=259;this.$cljs$lang$protocol_mask$partition1$$=
56};$cljs_bean$core$BeanIterator$$=function($obj$jscomp$112$$,$prop__GT_key$jscomp$7$$,$key__GT_prop$jscomp$5$$,$transform$jscomp$9$$,$recursive_QMARK_$jscomp$6$$,$arr$jscomp$149$$,$cnt$jscomp$41$$){this.$obj$=$obj$jscomp$112$$;this.$prop__GT_key$=$prop__GT_key$jscomp$7$$;this.$key__GT_prop$=$key__GT_prop$jscomp$5$$;this.transform=$transform$jscomp$9$$;this.$recursive_QMARK_$=$recursive_QMARK_$jscomp$6$$;this.$arr$=$arr$jscomp$149$$;this.i=0;this.$cnt$=$cnt$jscomp$41$$};
$cljs_bean$core$BeanSeq$$=function($obj$jscomp$114$$,$prop__GT_key$jscomp$9$$,$key__GT_prop$jscomp$7$$,$transform$jscomp$11$$,$recursive_QMARK_$jscomp$8$$,$arr$jscomp$151$$,$i$jscomp$376$$,$meta$jscomp$67$$){this.$obj$=$obj$jscomp$114$$;this.$prop__GT_key$=$prop__GT_key$jscomp$9$$;this.$key__GT_prop$=$key__GT_prop$jscomp$7$$;this.transform=$transform$jscomp$11$$;this.$recursive_QMARK_$=$recursive_QMARK_$jscomp$8$$;this.$arr$=$arr$jscomp$151$$;this.i=$i$jscomp$376$$;this.$meta$=$meta$jscomp$67$$;this.$cljs$lang$protocol_mask$partition0$$=
2179858686;this.$cljs$lang$protocol_mask$partition1$$=8192};
$cljs_bean$core$Bean$$=function($meta$jscomp$69$$,$obj$jscomp$116$$,$prop__GT_key$jscomp$11$$,$key__GT_prop$jscomp$9$$,$transform$jscomp$13$$,$recursive_QMARK_$jscomp$10$$,$__arr$$,$__cnt$jscomp$2$$,$__hash$jscomp$58$$){this.$meta$=$meta$jscomp$69$$;this.$obj$=$obj$jscomp$116$$;this.$prop__GT_key$=$prop__GT_key$jscomp$11$$;this.$key__GT_prop$=$key__GT_prop$jscomp$9$$;this.transform=$transform$jscomp$13$$;this.$recursive_QMARK_$=$recursive_QMARK_$jscomp$10$$;this.$__arr$=$__arr$$;this.$__cnt$=$__cnt$jscomp$2$$;
this.$__hash$=$__hash$jscomp$58$$;this.$cljs$lang$protocol_mask$partition0$$=2164131599;this.$cljs$lang$protocol_mask$partition1$$=139268};
$cljs_bean$core$TransientArrayVector$$=function($arr$jscomp$153$$,$prop__GT_key$jscomp$13$$,$key__GT_prop$jscomp$11$$,$transform$jscomp$15$$){this.$editable_QMARK_$=!0;this.$arr$=$arr$jscomp$153$$;this.$prop__GT_key$=$prop__GT_key$jscomp$13$$;this.$key__GT_prop$=$key__GT_prop$jscomp$11$$;this.transform=$transform$jscomp$15$$;this.$cljs$lang$protocol_mask$partition1$$=88;this.$cljs$lang$protocol_mask$partition0$$=275};
$cljs_bean$core$ArrayVectorIterator$$=function($prop__GT_key$jscomp$15$$,$key__GT_prop$jscomp$13$$,$transform$jscomp$17$$,$arr$jscomp$155$$,$cnt$jscomp$43$$){this.$prop__GT_key$=$prop__GT_key$jscomp$15$$;this.$key__GT_prop$=$key__GT_prop$jscomp$13$$;this.transform=$transform$jscomp$17$$;this.$arr$=$arr$jscomp$155$$;this.i=0;this.$cnt$=$cnt$jscomp$43$$};
$cljs_bean$core$ArrayVectorSeq$$=function($prop__GT_key$jscomp$17$$,$key__GT_prop$jscomp$15$$,$transform$jscomp$19$$,$arr$jscomp$157$$,$i$jscomp$380$$,$meta$jscomp$71$$){this.$prop__GT_key$=$prop__GT_key$jscomp$17$$;this.$key__GT_prop$=$key__GT_prop$jscomp$15$$;this.transform=$transform$jscomp$19$$;this.$arr$=$arr$jscomp$157$$;this.i=$i$jscomp$380$$;this.$meta$=$meta$jscomp$71$$;this.$cljs$lang$protocol_mask$partition0$$=2179858686;this.$cljs$lang$protocol_mask$partition1$$=8192};
$cljs_bean$core$ArrayVector$$=function($meta$jscomp$73$$,$prop__GT_key$jscomp$19$$,$key__GT_prop$jscomp$17$$,$transform$jscomp$21$$,$arr$jscomp$159$$,$__hash$jscomp$60$$){this.$meta$=$meta$jscomp$73$$;this.$prop__GT_key$=$prop__GT_key$jscomp$19$$;this.$key__GT_prop$=$key__GT_prop$jscomp$17$$;this.transform=$transform$jscomp$21$$;this.$arr$=$arr$jscomp$159$$;this.$__hash$=$__hash$jscomp$60$$;this.$cljs$lang$protocol_mask$partition0$$=2315150111;this.$cljs$lang$protocol_mask$partition1$$=141316};
$cljs_bean$core$default_key__GT_prop$$=function($x$jscomp$972$$){return $x$jscomp$972$$ instanceof $APP.$cljs$core$Keyword$$?$x$jscomp$972$$.$fqn$:null};
$cljs_bean$core$__GT_clj$$=function($var_args$jscomp$684$$){switch(arguments.length){case 1:return $cljs_bean$core$__GT_clj$cljs$0core$0IFn$0_invoke$0arity$01$$(arguments[0]);default:for(var $args_arr__5774__auto__$jscomp$87$$=[],$len__5749__auto___40848$$=arguments.length,$i__5750__auto___40849$$=0;;)if($i__5750__auto___40849$$<$len__5749__auto___40848$$)$args_arr__5774__auto__$jscomp$87$$.push(arguments[$i__5750__auto___40849$$]),$i__5750__auto___40849$$+=1;else break;return $cljs_bean$core$__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
1<$args_arr__5774__auto__$jscomp$87$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$87$$.slice(1),0,null):null)}};$cljs_bean$core$__GT_clj$cljs$0core$0IFn$0_invoke$0arity$01$$=function($x$jscomp$976$$){return $cljs_bean$core$__GT_val$$($x$jscomp$976$$,$APP.$cljs$core$keyword$$,$cljs_bean$core$default_key__GT_prop$$,null)};
$cljs_bean$core$__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($x$jscomp$977$$,$keywordize_keys$jscomp$2_opts$jscomp$238$$){var $map__40639__$1_transform$jscomp$24$$=$APP.$cljs$core$__destructure_map$$($keywordize_keys$jscomp$2_opts$jscomp$238$$);$keywordize_keys$jscomp$2_opts$jscomp$238$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40639__$1_transform$jscomp$24$$,$APP.$cljs$cst$127$keywordize_keys$$);var $prop__GT_key$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40639__$1_transform$jscomp$24$$,
$cljs$cst$1287$prop__GT_key$$),$key__GT_prop$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40639__$1_transform$jscomp$24$$,$cljs$cst$1288$key__GT_prop$$);$map__40639__$1_transform$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40639__$1_transform$jscomp$24$$,$APP.$cljs$cst$1289$transform$$);return $keywordize_keys$jscomp$2_opts$jscomp$238$$===!1?$cljs_bean$core$__GT_val$$($x$jscomp$977$$,$APP.$cljs$core$identity$$,$APP.$cljs$core$identity$$,$map__40639__$1_transform$jscomp$24$$):
$prop__GT_key$jscomp$22$$!=null&&$key__GT_prop$jscomp$20$$!=null?$cljs_bean$core$__GT_val$$($x$jscomp$977$$,$prop__GT_key$jscomp$22$$,$key__GT_prop$jscomp$20$$,$map__40639__$1_transform$jscomp$24$$):$cljs_bean$core$__GT_val$$($x$jscomp$977$$,$APP.$cljs$core$keyword$$,$cljs_bean$core$default_key__GT_prop$$,$map__40639__$1_transform$jscomp$24$$)};
$rumext$v2$util$ident__GT_key$$=function($nword_nword__$1$$){$nword_nword__$1$$=typeof $nword_nword__$1$$==="string"?$nword_nword__$1$$:$APP.$cljs$core$name$$($nword_nword__$1$$);return $APP.$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($nword_nword__$1$$,"-")==null?$nword_nword__$1$$:$APP.$cuerdas$core$starts_with_QMARK_$$($nword_nword__$1$$,"-")?$APP.$cuerdas$core$capital$$($cuerdas$core$camel$$($nword_nword__$1$$)):$cuerdas$core$camel$$($nword_nword__$1$$)};
$APP.$rumext$v2$util$map__GT_obj$$=function($o$jscomp$195$$){if($o$jscomp$195$$!=null&&Object.getPrototypeOf($o$jscomp$195$$)===Object.prototype)return $o$jscomp$195$$;if($APP.$cljs$core$map_QMARK_$$($o$jscomp$195$$)){var $m$jscomp$158$$={};$APP.$cljs$core$run_BANG_$$(function($p__40827_v$jscomp$312$$){var $k$jscomp$518$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__40827_v$jscomp$312$$,0,null);$p__40827_v$jscomp$312$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__40827_v$jscomp$312$$,
1,null);return $m$jscomp$158$$[$APP.$cljs$core$name$$($k$jscomp$518$$)]=$p__40827_v$jscomp$312$$},$o$jscomp$195$$);return $m$jscomp$158$$}throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("unable to create obj",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$142$data$$,$o$jscomp$195$$],null));};
$APP.$rumext$v2$util$map__GT_props$cljs$0core$0IFn$0_invoke$0arity$01$$=function($o$jscomp$196$$){return $rumext$v2$util$map__GT_props$cljs$0core$0IFn$0_invoke$0arity$02$$($o$jscomp$196$$,!1)};
$rumext$v2$util$map__GT_props$cljs$0core$0IFn$0_invoke$0arity$02$$=function($o$jscomp$197$$,$recursive_QMARK_$jscomp$12$$){if($APP.$cljs$core$object_QMARK_$$($o$jscomp$197$$))return $o$jscomp$197$$;var $level$jscomp$39$$=$recursive_QMARK_$jscomp$12$$===!0?1:$recursive_QMARK_$jscomp$12$$;return $APP.$cljs$core$reduce_kv$$(function($res$jscomp$25$$,$JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$,$v$jscomp$313_v_40880__$2_v__$1$jscomp$26$$){$v$jscomp$313_v_40880__$2_v__$1$jscomp$26$$=
$v$jscomp$313_v_40880__$2_v__$1$jscomp$26$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$($v$jscomp$313_v_40880__$2_v__$1$jscomp$26$$):$v$jscomp$313_v_40880__$2_v__$1$jscomp$26$$;typeof $JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$!=="string"&&($JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$ instanceof
$APP.$cljs$core$Keyword$$?$APP.$cljs$core$int_QMARK_$$($level$jscomp$39$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$level$jscomp$39$$)?$JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$=$rumext$v2$util$ident__GT_key$$($JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$):($JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$=
typeof $JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$==="string"?$JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$:$APP.$cljs$core$name$$($JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$),$JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$,"class")?"className":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$,"for")?"htmlFor":$APP.$cuerdas$core$starts_with_QMARK_$$($JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$,
"--")?$JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$:$APP.$cuerdas$core$starts_with_QMARK_$$($JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$,"data-")?$JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$:$APP.$cuerdas$core$starts_with_QMARK_$$($JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$,
"aria-")?$JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$:$rumext$v2$util$ident__GT_key$$($JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$)):$JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$=null);$JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$!=
null&&($v$jscomp$313_v_40880__$2_v__$1$jscomp$26$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$,"style")&&$APP.$cljs$core$map_QMARK_$$($v$jscomp$313_v_40880__$2_v__$1$jscomp$26$$)?$rumext$v2$util$map__GT_props$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$313_v_40880__$2_v__$1$jscomp$26$$,!0):$APP.$cljs$core$int_QMARK_$$($level$jscomp$39$$)&&$APP.$cljs$core$map_QMARK_$$($v$jscomp$313_v_40880__$2_v__$1$jscomp$26$$)?
$rumext$v2$util$map__GT_props$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$313_v_40880__$2_v__$1$jscomp$26$$,$level$jscomp$39$$+1):$v$jscomp$313_v_40880__$2_v__$1$jscomp$26$$,$res$jscomp$25$$[$JSCompiler_temp$jscomp$551_JSCompiler_temp$jscomp$552_JSCompiler_temp$jscomp$553_k$jscomp$519_k__$1$jscomp$19_nword__$1$jscomp$inline_4076$$]=$v$jscomp$313_v_40880__$2_v__$1$jscomp$26$$);return $res$jscomp$25$$},{},$o$jscomp$197$$)};
$APP.$rumext$v2$util$wrap_props$$=function($JSCompiler_inline_result$jscomp$554_props$jscomp$52$$){if($APP.$cljs$core$object_QMARK_$$($JSCompiler_inline_result$jscomp$554_props$jscomp$52$$)){a:{for(var $keys$jscomp$inline_4079$$=Object.keys($JSCompiler_inline_result$jscomp$554_props$jscomp$52$$),$len$jscomp$inline_4080$$=$keys$jscomp$inline_4079$$.length,$G__40873$jscomp$inline_4084_i$jscomp$inline_4081$$=0,$G__40874$jscomp$inline_4085_r$jscomp$inline_4082$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);;)if($G__40873$jscomp$inline_4084_i$jscomp$inline_4081$$<
$len$jscomp$inline_4080$$){var $key$jscomp$inline_4083$$=$keys$jscomp$inline_4079$$[$G__40873$jscomp$inline_4084_i$jscomp$inline_4081$$];$G__40873$jscomp$inline_4084_i$jscomp$inline_4081$$+=1;$G__40874$jscomp$inline_4085_r$jscomp$inline_4082$$=$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($G__40874$jscomp$inline_4085_r$jscomp$inline_4082$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$inline_4083$$),$JSCompiler_inline_result$jscomp$554_props$jscomp$52$$[$key$jscomp$inline_4083$$])}else{$JSCompiler_inline_result$jscomp$554_props$jscomp$52$$=
$APP.$cljs$core$_persistent_BANG_$$($G__40874$jscomp$inline_4085_r$jscomp$inline_4082$$);break a}$JSCompiler_inline_result$jscomp$554_props$jscomp$52$$=void 0}return $JSCompiler_inline_result$jscomp$554_props$jscomp$52$$}if($APP.$cljs$core$map_QMARK_$$($JSCompiler_inline_result$jscomp$554_props$jscomp$52$$))return $JSCompiler_inline_result$jscomp$554_props$jscomp$52$$;if($JSCompiler_inline_result$jscomp$554_props$jscomp$52$$==null)return $APP.$cljs$core$PersistentArrayMap$EMPTY$$;throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Unexpected props",
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$575$props$$,$JSCompiler_inline_result$jscomp$554_props$jscomp$52$$],null));};$rumext$v2$util$prop__GT_key$$=function($k$jscomp$520$$){return typeof $k$jscomp$520$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$kebab$$($k$jscomp$520$$)):$k$jscomp$520$$};
$rumext$v2$util$key__GT_prop$$=function($x$jscomp$981$$){return $x$jscomp$981$$ instanceof $APP.$cljs$core$Keyword$$?$cuerdas$core$camel$$($x$jscomp$981$$.$fqn$):null};$APP.$rumext$v2$util$bean$$=function($o$jscomp$198$$){return $cljs_bean$core$__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($o$jscomp$198$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$1287$prop__GT_key$$,$rumext$v2$util$prop__GT_key$$,$cljs$cst$1288$key__GT_prop$$,$rumext$v2$util$key__GT_prop$$]))};
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$=function($obj$jscomp$119$$,$k$jscomp$522$$){return $obj$jscomp$119$$!=null?$obj$jscomp$119$$[$k$jscomp$522$$]:null};
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$=function($obj$jscomp$120_result$jscomp$121$$,$k$jscomp$523$$,$default$$jscomp$44$$){$obj$jscomp$120_result$jscomp$121$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($obj$jscomp$120_result$jscomp$121$$,$k$jscomp$523$$);return void 0===$obj$jscomp$120_result$jscomp$121$$?$default$$jscomp$44$$:$obj$jscomp$120_result$jscomp$121$$};$APP.$app$util$object$clone$$=function($a$jscomp$295$$){return Object.assign({},$a$jscomp$295$$)};
$APP.$app$util$object$merge$cljs$0core$0IFn$0_invoke$0arity$02$$=function($a$jscomp$298$$,$b$jscomp$225$$){return Object.assign({},$a$jscomp$298$$,$b$jscomp$225$$)};$APP.$app$util$object$set_BANG_$$=function($obj$jscomp$122$$,$key$jscomp$258$$,$value$jscomp$344$$){$obj$jscomp$122$$[$key$jscomp$258$$]=$value$jscomp$344$$;return $obj$jscomp$122$$};$APP.$app$util$object$unset_BANG_$$=function($obj$jscomp$123$$,$key$jscomp$259$$){delete $obj$jscomp$123$$[$key$jscomp$259$$];return $obj$jscomp$123$$};
$promesa$impl$coerce$$=function($v$jscomp$320$$){return $APP.$promesa$impl$promise$coerce$$($v$jscomp$320$$)};$promesa$impl$extend_promise_BANG_$$=function($t$jscomp$54$$){$t$jscomp$54$$.prototype.$promesa$protocols$IPromiseFactory$_promise$arity$1$=function(){return $promesa$impl$promise$create$$(this)}};$module$contents$goog$Thenable_Thenable$isImplementedBy$$=function($object$jscomp$10$$){if(!$object$jscomp$10$$)return!1;try{return!!$object$jscomp$10$$.$goog_Thenable}catch($e$jscomp$191$$){return!1}};
$module$contents$goog$labs$userAgent$platform_isIphone$$=function(){return $module$contents$goog$labs$userAgent$util_matchUserAgent$$("iPhone")&&!$module$contents$goog$labs$userAgent$util_matchUserAgent$$("iPod")&&!$module$contents$goog$labs$userAgent$util_matchUserAgent$$("iPad")};$module$contents$goog$labs$userAgent$platform_isIos$$=function(){$module$contents$goog$labs$userAgent$platform_isIphone$$()||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("iPad")||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("iPod")};
$APP.$goog$dom$getElement$$=function($element$jscomp$17$$){return $goog$dom$getElementHelper_$$(document,$element$jscomp$17$$)};$goog$dom$getElementHelper_$$=function($doc$jscomp$13$$,$element$jscomp$19$$){return typeof $element$jscomp$19$$==="string"?$doc$jscomp$13$$.getElementById($element$jscomp$19$$):$element$jscomp$19$$};
$APP.$goog$dom$getElementByClass$$=function($JSCompiler_temp$jscomp$558_className$jscomp$2$$,$opt_el$jscomp$3$$){var $doc$jscomp$inline_4095_parent$jscomp$108$$=$opt_el$jscomp$3$$||document;if($doc$jscomp$inline_4095_parent$jscomp$108$$.getElementsByClassName)$JSCompiler_temp$jscomp$558_className$jscomp$2$$=$doc$jscomp$inline_4095_parent$jscomp$108$$.getElementsByClassName($JSCompiler_temp$jscomp$558_className$jscomp$2$$)[0];else{$doc$jscomp$inline_4095_parent$jscomp$108$$=document;var $parent$jscomp$inline_4097$$=
$opt_el$jscomp$3$$||$doc$jscomp$inline_4095_parent$jscomp$108$$;$JSCompiler_temp$jscomp$558_className$jscomp$2$$=$parent$jscomp$inline_4097$$.querySelectorAll&&$parent$jscomp$inline_4097$$.querySelector&&$JSCompiler_temp$jscomp$558_className$jscomp$2$$?$parent$jscomp$inline_4097$$.querySelector($JSCompiler_temp$jscomp$558_className$jscomp$2$$?"."+$JSCompiler_temp$jscomp$558_className$jscomp$2$$:""):$APP.$goog$dom$getElementsByTagNameAndClass_$$($doc$jscomp$inline_4095_parent$jscomp$108$$,"*",$JSCompiler_temp$jscomp$558_className$jscomp$2$$,
$opt_el$jscomp$3$$)[0]||null}return $JSCompiler_temp$jscomp$558_className$jscomp$2$$||null};
$APP.$goog$dom$getElementsByTagNameAndClass_$$=function($arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$,$els_opt_tag$jscomp$2$$,$opt_class$jscomp$2$$,$len$jscomp$64_opt_el$jscomp$4$$){$arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$=$len$jscomp$64_opt_el$jscomp$4$$||$arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$;var $className$jscomp$6_tagName$jscomp$16$$=$els_opt_tag$jscomp$2$$&&$els_opt_tag$jscomp$2$$!="*"?String($els_opt_tag$jscomp$2$$).toUpperCase():"";if($arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$.querySelectorAll&&
$arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$.querySelector&&($className$jscomp$6_tagName$jscomp$16$$||$opt_class$jscomp$2$$))return $arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$.querySelectorAll($className$jscomp$6_tagName$jscomp$16$$+($opt_class$jscomp$2$$?"."+$opt_class$jscomp$2$$:""));if($opt_class$jscomp$2$$&&$arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$.getElementsByClassName){$els_opt_tag$jscomp$2$$=$arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$.getElementsByClassName($opt_class$jscomp$2$$);
if($className$jscomp$6_tagName$jscomp$16$$){$arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$={};for(var $i$jscomp$388$$=$len$jscomp$64_opt_el$jscomp$4$$=0,$el$jscomp$2$$;$el$jscomp$2$$=$els_opt_tag$jscomp$2$$[$i$jscomp$388$$];$i$jscomp$388$$++)$className$jscomp$6_tagName$jscomp$16$$==$el$jscomp$2$$.nodeName&&($arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$[$len$jscomp$64_opt_el$jscomp$4$$++]=$el$jscomp$2$$);$arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$.length=$len$jscomp$64_opt_el$jscomp$4$$;
return $arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$}return $els_opt_tag$jscomp$2$$}$els_opt_tag$jscomp$2$$=$arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$.getElementsByTagName($className$jscomp$6_tagName$jscomp$16$$||"*");if($opt_class$jscomp$2$$){$arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$={};for($i$jscomp$388$$=$len$jscomp$64_opt_el$jscomp$4$$=0;$el$jscomp$2$$=$els_opt_tag$jscomp$2$$[$i$jscomp$388$$];$i$jscomp$388$$++){$className$jscomp$6_tagName$jscomp$16$$=$el$jscomp$2$$.className;
var $JSCompiler_temp$jscomp$66$$;if($JSCompiler_temp$jscomp$66$$=typeof $className$jscomp$6_tagName$jscomp$16$$.split=="function")$JSCompiler_temp$jscomp$66$$=$module$contents$goog$array_indexOf$$($className$jscomp$6_tagName$jscomp$16$$.split(/\s+/),$opt_class$jscomp$2$$)>=0;$JSCompiler_temp$jscomp$66$$&&($arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$[$len$jscomp$64_opt_el$jscomp$4$$++]=$el$jscomp$2$$)}$arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$.length=$len$jscomp$64_opt_el$jscomp$4$$;
return $arrayLike$jscomp$1_doc$jscomp$15_parent$jscomp$110$$}return $els_opt_tag$jscomp$2$$};
$goog$dom$setProperties$$=function($element$jscomp$22$$,$properties$jscomp$87$$){$module$contents$goog$object_forEach$$($properties$jscomp$87$$,function($val$jscomp$136$$,$key$jscomp$262$$){$val$jscomp$136$$&&typeof $val$jscomp$136$$=="object"&&$val$jscomp$136$$.$implementsGoogStringTypedString$&&($val$jscomp$136$$=$val$jscomp$136$$.$getTypedStringValue$());$key$jscomp$262$$=="style"?$element$jscomp$22$$.style.cssText=$val$jscomp$136$$:$key$jscomp$262$$=="class"?$element$jscomp$22$$.className=$val$jscomp$136$$:
$key$jscomp$262$$=="for"?$element$jscomp$22$$.htmlFor=$val$jscomp$136$$:$goog$dom$DIRECT_ATTRIBUTE_MAP_$$.hasOwnProperty($key$jscomp$262$$)?$element$jscomp$22$$.setAttribute($goog$dom$DIRECT_ATTRIBUTE_MAP_$$[$key$jscomp$262$$],$val$jscomp$136$$):$APP.$goog$string$internal$startsWith$$($key$jscomp$262$$,"aria-")||$APP.$goog$string$internal$startsWith$$($key$jscomp$262$$,"data-")?$element$jscomp$22$$.setAttribute($key$jscomp$262$$,$val$jscomp$136$$):$element$jscomp$22$$[$key$jscomp$262$$]=$val$jscomp$136$$})};
$goog$dom$append_$$=function($doc$jscomp$23$$,$parent$jscomp$112$$,$args$jscomp$198$$){function $childHandler$$($child$jscomp$42$$){$child$jscomp$42$$&&$parent$jscomp$112$$.appendChild(typeof $child$jscomp$42$$==="string"?$doc$jscomp$23$$.createTextNode($child$jscomp$42$$):$child$jscomp$42$$)}for(var $i$jscomp$389$$=1;$i$jscomp$389$$<$args$jscomp$198$$.length;$i$jscomp$389$$++){var $arg$jscomp$12$$=$args$jscomp$198$$[$i$jscomp$389$$];if(!$goog$isArrayLike$$($arg$jscomp$12$$)||$goog$isObject$$($arg$jscomp$12$$)&&
$arg$jscomp$12$$.nodeType>0)$childHandler$$($arg$jscomp$12$$);else{a:{if($arg$jscomp$12$$&&typeof $arg$jscomp$12$$.length=="number"){if($goog$isObject$$($arg$jscomp$12$$)){var $JSCompiler_inline_result$jscomp$560$$=typeof $arg$jscomp$12$$.item=="function"||typeof $arg$jscomp$12$$.item=="string";break a}if(typeof $arg$jscomp$12$$==="function"){$JSCompiler_inline_result$jscomp$560$$=typeof $arg$jscomp$12$$.item=="function";break a}}$JSCompiler_inline_result$jscomp$560$$=!1}$module$contents$goog$array_forEach$$($JSCompiler_inline_result$jscomp$560$$?
$module$contents$goog$array_toArray$$($arg$jscomp$12$$):$arg$jscomp$12$$,$childHandler$$)}}};$goog$dom$createElement_$$=function($doc$jscomp$24$$,$name$jscomp$143$$){$name$jscomp$143$$=String($name$jscomp$143$$);$doc$jscomp$24$$.contentType==="application/xhtml+xml"&&($name$jscomp$143$$=$name$jscomp$143$$.toLowerCase());return $doc$jscomp$24$$.createElement($name$jscomp$143$$)};
$goog$dom$removeNode$$=function($node$jscomp$132$$){return $node$jscomp$132$$&&$node$jscomp$132$$.parentNode?$node$jscomp$132$$.parentNode.removeChild($node$jscomp$132$$):null};$goog$dom$DomHelper$$=function($opt_document$jscomp$1$$){this.$document_$=$opt_document$jscomp$1$$||$APP.$goog$global$$.document||document};
$goog$async$nextTick$getNextTickImpl_$$=function(){var $Channel$$=$APP.$goog$global$$.MessageChannel;typeof $Channel$$==="undefined"&&typeof window!=="undefined"&&window.postMessage&&window.addEventListener&&!$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Presto")&&($Channel$$=function(){var $doc$jscomp$35_iframe$jscomp$2_onmessage$$=$goog$dom$createElement_$$(document,"IFRAME");$doc$jscomp$35_iframe$jscomp$2_onmessage$$.style.display="none";document.documentElement.appendChild($doc$jscomp$35_iframe$jscomp$2_onmessage$$);
var $win$jscomp$13$$=$doc$jscomp$35_iframe$jscomp$2_onmessage$$.contentWindow;$doc$jscomp$35_iframe$jscomp$2_onmessage$$=$win$jscomp$13$$.document;$doc$jscomp$35_iframe$jscomp$2_onmessage$$.open();$doc$jscomp$35_iframe$jscomp$2_onmessage$$.close();var $message$jscomp$49$$="callImmediate"+Math.random(),$origin$jscomp$1$$=$win$jscomp$13$$.location.protocol=="file:"?"*":$win$jscomp$13$$.location.protocol+"//"+$win$jscomp$13$$.location.host;$doc$jscomp$35_iframe$jscomp$2_onmessage$$=$goog$bind$$(function($e$jscomp$194$$){if(($origin$jscomp$1$$==
"*"||$e$jscomp$194$$.origin==$origin$jscomp$1$$)&&$e$jscomp$194$$.data==$message$jscomp$49$$)this.port1.onmessage()},this);$win$jscomp$13$$.addEventListener("message",$doc$jscomp$35_iframe$jscomp$2_onmessage$$,!1);this.port1={};this.port2={postMessage:function(){$win$jscomp$13$$.postMessage($message$jscomp$49$$,$origin$jscomp$1$$)}}});if(typeof $Channel$$!=="undefined"&&!$module$contents$goog$labs$userAgent$browser_matchIE$$()){var $channel$jscomp$1$$=new $Channel$$,$head$jscomp$7$$={},$tail$jscomp$8$$=
$head$jscomp$7$$;$channel$jscomp$1$$.port1.onmessage=function(){if($head$jscomp$7$$.next!==void 0){$head$jscomp$7$$=$head$jscomp$7$$.next;var $cb$jscomp$2$$=$head$jscomp$7$$.cb;$head$jscomp$7$$.cb=null;$cb$jscomp$2$$()}};return function($cb$jscomp$3$$){$tail$jscomp$8$$.next={cb:$cb$jscomp$3$$};$tail$jscomp$8$$=$tail$jscomp$8$$.next;$channel$jscomp$1$$.port2.postMessage(0)}}return function($cb$jscomp$4$$){$APP.$goog$global$$.setTimeout($cb$jscomp$4$$,0)}};
$goog$Promise$$=function($resolver$jscomp$1$$){this.$state_$=$goog$Promise$State_$PENDING$$;this.$result_$=void 0;this.$callbackEntriesTail_$=this.$callbackEntries_$=this.$parent_$=null;this.$hadUnhandledRejection_$=this.$executing_$=!1;if($resolver$jscomp$1$$!=$goog$functions$UNDEFINED$$)try{var $self$jscomp$32$$=this;$resolver$jscomp$1$$.call(void 0,function($value$jscomp$346$$){$JSCompiler_StaticMethods_resolve_$$($self$jscomp$32$$,$goog$Promise$State_$FULFILLED$$,$value$jscomp$346$$)},function($reason$jscomp$15$$){$JSCompiler_StaticMethods_resolve_$$($self$jscomp$32$$,
$goog$Promise$State_$REJECTED$$,$reason$jscomp$15$$)})}catch($e$jscomp$197$$){$JSCompiler_StaticMethods_resolve_$$(this,$goog$Promise$State_$REJECTED$$,$e$jscomp$197$$)}};$goog$Promise$CallbackEntry_$$=function(){this.next=this.context=this.$onRejected$=this.$onFulfilled$=this.$child$=null;this.$always$=!1};
$goog$Promise$getCallbackEntry_$$=function($onFulfilled$$,$onRejected$jscomp$1$$,$context$jscomp$8$$){var $entry$jscomp$24$$=$goog$Promise$freelist_$$.get();$entry$jscomp$24$$.$onFulfilled$=$onFulfilled$$;$entry$jscomp$24$$.$onRejected$=$onRejected$jscomp$1$$;$entry$jscomp$24$$.context=$context$jscomp$8$$;return $entry$jscomp$24$$};
$JSCompiler_StaticMethods_cancelInternal_$$=function($JSCompiler_StaticMethods_cancelInternal_$self$$,$err$jscomp$8$$){if($JSCompiler_StaticMethods_cancelInternal_$self$$.$state_$==$goog$Promise$State_$PENDING$$)if($JSCompiler_StaticMethods_cancelInternal_$self$$.$parent_$){var $JSCompiler_StaticMethods_cancelChild_$self$jscomp$inline_4115$$=$JSCompiler_StaticMethods_cancelInternal_$self$$.$parent_$;if($JSCompiler_StaticMethods_cancelChild_$self$jscomp$inline_4115$$.$callbackEntries_$){for(var $childCount$jscomp$inline_4118_previous$jscomp$inline_11576$$=
0,$childEntry$jscomp$inline_4119$$=null,$beforeChildEntry$jscomp$inline_4120$$=null,$entry$jscomp$inline_4121$$=$JSCompiler_StaticMethods_cancelChild_$self$jscomp$inline_4115$$.$callbackEntries_$;$entry$jscomp$inline_4121$$&&($entry$jscomp$inline_4121$$.$always$||($childCount$jscomp$inline_4118_previous$jscomp$inline_11576$$++,$entry$jscomp$inline_4121$$.$child$==$JSCompiler_StaticMethods_cancelInternal_$self$$&&($childEntry$jscomp$inline_4119$$=$entry$jscomp$inline_4121$$),!($childEntry$jscomp$inline_4119$$&&
$childCount$jscomp$inline_4118_previous$jscomp$inline_11576$$>1)));$entry$jscomp$inline_4121$$=$entry$jscomp$inline_4121$$.next)$childEntry$jscomp$inline_4119$$||($beforeChildEntry$jscomp$inline_4120$$=$entry$jscomp$inline_4121$$);$childEntry$jscomp$inline_4119$$&&($JSCompiler_StaticMethods_cancelChild_$self$jscomp$inline_4115$$.$state_$==$goog$Promise$State_$PENDING$$&&$childCount$jscomp$inline_4118_previous$jscomp$inline_11576$$==1?$JSCompiler_StaticMethods_cancelInternal_$$($JSCompiler_StaticMethods_cancelChild_$self$jscomp$inline_4115$$,
$err$jscomp$8$$):($beforeChildEntry$jscomp$inline_4120$$?($childCount$jscomp$inline_4118_previous$jscomp$inline_11576$$=$beforeChildEntry$jscomp$inline_4120$$,$childCount$jscomp$inline_4118_previous$jscomp$inline_11576$$.next==$JSCompiler_StaticMethods_cancelChild_$self$jscomp$inline_4115$$.$callbackEntriesTail_$&&($JSCompiler_StaticMethods_cancelChild_$self$jscomp$inline_4115$$.$callbackEntriesTail_$=$childCount$jscomp$inline_4118_previous$jscomp$inline_11576$$),$childCount$jscomp$inline_4118_previous$jscomp$inline_11576$$.next=
$childCount$jscomp$inline_4118_previous$jscomp$inline_11576$$.next.next):$JSCompiler_StaticMethods_popEntry_$$($JSCompiler_StaticMethods_cancelChild_$self$jscomp$inline_4115$$),$JSCompiler_StaticMethods_executeCallback_$$($JSCompiler_StaticMethods_cancelChild_$self$jscomp$inline_4115$$,$childEntry$jscomp$inline_4119$$,$goog$Promise$State_$REJECTED$$,$err$jscomp$8$$)))}$JSCompiler_StaticMethods_cancelInternal_$self$$.$parent_$=null}else $JSCompiler_StaticMethods_resolve_$$($JSCompiler_StaticMethods_cancelInternal_$self$$,
$goog$Promise$State_$REJECTED$$,$err$jscomp$8$$)};
$JSCompiler_StaticMethods_addCallbackEntry_$$=function($JSCompiler_StaticMethods_addCallbackEntry_$self$$,$callbackEntry$$){$JSCompiler_StaticMethods_addCallbackEntry_$self$$.$callbackEntries_$||$JSCompiler_StaticMethods_addCallbackEntry_$self$$.$state_$!=$goog$Promise$State_$FULFILLED$$&&$JSCompiler_StaticMethods_addCallbackEntry_$self$$.$state_$!=$goog$Promise$State_$REJECTED$$||$JSCompiler_StaticMethods_scheduleCallbacks_$$($JSCompiler_StaticMethods_addCallbackEntry_$self$$);$JSCompiler_StaticMethods_addCallbackEntry_$self$$.$callbackEntriesTail_$?
$JSCompiler_StaticMethods_addCallbackEntry_$self$$.$callbackEntriesTail_$.next=$callbackEntry$$:$JSCompiler_StaticMethods_addCallbackEntry_$self$$.$callbackEntries_$=$callbackEntry$$;$JSCompiler_StaticMethods_addCallbackEntry_$self$$.$callbackEntriesTail_$=$callbackEntry$$};
$JSCompiler_StaticMethods_addChildPromise_$$=function($JSCompiler_StaticMethods_addChildPromise_$self$$,$onFulfilled$jscomp$2$$,$onRejected$jscomp$4$$,$opt_context$jscomp$7$$){var $callbackEntry$jscomp$1$$=$goog$Promise$getCallbackEntry_$$(null,null,null);$callbackEntry$jscomp$1$$.$child$=new $goog$Promise$$(function($resolve$jscomp$11$$,$reject$jscomp$10$$){$callbackEntry$jscomp$1$$.$onFulfilled$=$onFulfilled$jscomp$2$$?function($value$jscomp$350$$){try{var $result$jscomp$124$$=$onFulfilled$jscomp$2$$.call($opt_context$jscomp$7$$,
$value$jscomp$350$$);$resolve$jscomp$11$$($result$jscomp$124$$)}catch($err$jscomp$10$$){$reject$jscomp$10$$($err$jscomp$10$$)}}:$resolve$jscomp$11$$;$callbackEntry$jscomp$1$$.$onRejected$=$onRejected$jscomp$4$$?function($reason$jscomp$18$$){try{var $result$jscomp$125$$=$onRejected$jscomp$4$$.call($opt_context$jscomp$7$$,$reason$jscomp$18$$);$result$jscomp$125$$===void 0&&$reason$jscomp$18$$ instanceof $goog$Promise$CancellationError$$?$reject$jscomp$10$$($reason$jscomp$18$$):$resolve$jscomp$11$$($result$jscomp$125$$)}catch($err$jscomp$11$$){$reject$jscomp$10$$($err$jscomp$11$$)}}:
$reject$jscomp$10$$});$callbackEntry$jscomp$1$$.$child$.$parent_$=$JSCompiler_StaticMethods_addChildPromise_$self$$;$JSCompiler_StaticMethods_addCallbackEntry_$$($JSCompiler_StaticMethods_addChildPromise_$self$$,$callbackEntry$jscomp$1$$);return $callbackEntry$jscomp$1$$.$child$};
$JSCompiler_StaticMethods_resolve_$$=function($JSCompiler_StaticMethods_resolve_$self$$,$state$jscomp$18$$,$x$jscomp$983$$){if($JSCompiler_StaticMethods_resolve_$self$$.$state_$==$goog$Promise$State_$PENDING$$){$JSCompiler_StaticMethods_resolve_$self$$===$x$jscomp$983$$&&($state$jscomp$18$$=$goog$Promise$State_$REJECTED$$,$x$jscomp$983$$=new TypeError("Promise cannot resolve to itself"));$JSCompiler_StaticMethods_resolve_$self$$.$state_$=1;a:{var $value$jscomp$inline_4126$$=$x$jscomp$983$$,$onFulfilled$jscomp$inline_4127$$=
$JSCompiler_StaticMethods_resolve_$self$$.$unblockAndFulfill_$,$onRejected$jscomp$inline_4128$$=$JSCompiler_StaticMethods_resolve_$self$$.$unblockAndReject_$;if($value$jscomp$inline_4126$$ instanceof $goog$Promise$$){$JSCompiler_StaticMethods_addCallbackEntry_$$($value$jscomp$inline_4126$$,$goog$Promise$getCallbackEntry_$$($onFulfilled$jscomp$inline_4127$$||$goog$functions$UNDEFINED$$,$onRejected$jscomp$inline_4128$$||null,$JSCompiler_StaticMethods_resolve_$self$$));var $JSCompiler_inline_result$jscomp$561$$=
!0}else if($module$contents$goog$Thenable_Thenable$isImplementedBy$$($value$jscomp$inline_4126$$))$value$jscomp$inline_4126$$.then($onFulfilled$jscomp$inline_4127$$,$onRejected$jscomp$inline_4128$$,$JSCompiler_StaticMethods_resolve_$self$$),$JSCompiler_inline_result$jscomp$561$$=!0;else{if($goog$isObject$$($value$jscomp$inline_4126$$))try{var $then$jscomp$inline_4130$$=$value$jscomp$inline_4126$$.then;if(typeof $then$jscomp$inline_4130$$==="function"){$goog$Promise$tryThen_$$($value$jscomp$inline_4126$$,
$then$jscomp$inline_4130$$,$onFulfilled$jscomp$inline_4127$$,$onRejected$jscomp$inline_4128$$,$JSCompiler_StaticMethods_resolve_$self$$);$JSCompiler_inline_result$jscomp$561$$=!0;break a}}catch($e$jscomp$inline_4131$$){$onRejected$jscomp$inline_4128$$.call($JSCompiler_StaticMethods_resolve_$self$$,$e$jscomp$inline_4131$$);$JSCompiler_inline_result$jscomp$561$$=!0;break a}$JSCompiler_inline_result$jscomp$561$$=!1}}$JSCompiler_inline_result$jscomp$561$$||($JSCompiler_StaticMethods_resolve_$self$$.$result_$=
$x$jscomp$983$$,$JSCompiler_StaticMethods_resolve_$self$$.$state_$=$state$jscomp$18$$,$JSCompiler_StaticMethods_resolve_$self$$.$parent_$=null,$JSCompiler_StaticMethods_scheduleCallbacks_$$($JSCompiler_StaticMethods_resolve_$self$$),$state$jscomp$18$$!=$goog$Promise$State_$REJECTED$$||$x$jscomp$983$$ instanceof $goog$Promise$CancellationError$$||$goog$Promise$addUnhandledRejection_$$($JSCompiler_StaticMethods_resolve_$self$$,$x$jscomp$983$$))}};
$goog$Promise$tryThen_$$=function($thenable$jscomp$1$$,$then$jscomp$1$$,$onFulfilled$jscomp$4$$,$onRejected$jscomp$6$$,$context$jscomp$10$$){function $reject$jscomp$11$$($reason$jscomp$20$$){$called$jscomp$1$$||($called$jscomp$1$$=!0,$onRejected$jscomp$6$$.call($context$jscomp$10$$,$reason$jscomp$20$$))}function $resolve$jscomp$12$$($value$jscomp$353$$){$called$jscomp$1$$||($called$jscomp$1$$=!0,$onFulfilled$jscomp$4$$.call($context$jscomp$10$$,$value$jscomp$353$$))}var $called$jscomp$1$$=!1;try{$then$jscomp$1$$.call($thenable$jscomp$1$$,
$resolve$jscomp$12$$,$reject$jscomp$11$$)}catch($e$jscomp$199$$){$reject$jscomp$11$$($e$jscomp$199$$)}};$JSCompiler_StaticMethods_scheduleCallbacks_$$=function($JSCompiler_StaticMethods_scheduleCallbacks_$self$$){$JSCompiler_StaticMethods_scheduleCallbacks_$self$$.$executing_$||($JSCompiler_StaticMethods_scheduleCallbacks_$self$$.$executing_$=!0,$module$contents$goog$async$run_run$$($JSCompiler_StaticMethods_scheduleCallbacks_$self$$.$executeCallbacks_$,$JSCompiler_StaticMethods_scheduleCallbacks_$self$$))};
$JSCompiler_StaticMethods_popEntry_$$=function($JSCompiler_StaticMethods_popEntry_$self$$){var $entry$jscomp$29$$=null;$JSCompiler_StaticMethods_popEntry_$self$$.$callbackEntries_$&&($entry$jscomp$29$$=$JSCompiler_StaticMethods_popEntry_$self$$.$callbackEntries_$,$JSCompiler_StaticMethods_popEntry_$self$$.$callbackEntries_$=$entry$jscomp$29$$.next,$entry$jscomp$29$$.next=null);$JSCompiler_StaticMethods_popEntry_$self$$.$callbackEntries_$||($JSCompiler_StaticMethods_popEntry_$self$$.$callbackEntriesTail_$=
null);return $entry$jscomp$29$$};
$JSCompiler_StaticMethods_executeCallback_$$=function($JSCompiler_StaticMethods_executeCallback_$self_p$jscomp$inline_4134$$,$callbackEntry$jscomp$2$$,$state$jscomp$19$$,$result$jscomp$126$$){if($state$jscomp$19$$==$goog$Promise$State_$REJECTED$$&&$callbackEntry$jscomp$2$$.$onRejected$&&!$callbackEntry$jscomp$2$$.$always$)for(;$JSCompiler_StaticMethods_executeCallback_$self_p$jscomp$inline_4134$$&&$JSCompiler_StaticMethods_executeCallback_$self_p$jscomp$inline_4134$$.$hadUnhandledRejection_$;$JSCompiler_StaticMethods_executeCallback_$self_p$jscomp$inline_4134$$=$JSCompiler_StaticMethods_executeCallback_$self_p$jscomp$inline_4134$$.$parent_$)$JSCompiler_StaticMethods_executeCallback_$self_p$jscomp$inline_4134$$.$hadUnhandledRejection_$=
!1;if($callbackEntry$jscomp$2$$.$child$)$callbackEntry$jscomp$2$$.$child$.$parent_$=null,$goog$Promise$invokeCallback_$$($callbackEntry$jscomp$2$$,$state$jscomp$19$$,$result$jscomp$126$$);else try{$callbackEntry$jscomp$2$$.$always$?$callbackEntry$jscomp$2$$.$onFulfilled$.call($callbackEntry$jscomp$2$$.context):$goog$Promise$invokeCallback_$$($callbackEntry$jscomp$2$$,$state$jscomp$19$$,$result$jscomp$126$$)}catch($err$jscomp$12$$){$goog$Promise$handleRejection_$$.call(null,$err$jscomp$12$$)}$goog$Promise$freelist_$$.put($callbackEntry$jscomp$2$$)};
$goog$Promise$invokeCallback_$$=function($callbackEntry$jscomp$3$$,$state$jscomp$20$$,$result$jscomp$127$$){$state$jscomp$20$$==$goog$Promise$State_$FULFILLED$$?$callbackEntry$jscomp$3$$.$onFulfilled$.call($callbackEntry$jscomp$3$$.context,$result$jscomp$127$$):$callbackEntry$jscomp$3$$.$onRejected$&&$callbackEntry$jscomp$3$$.$onRejected$.call($callbackEntry$jscomp$3$$.context,$result$jscomp$127$$)};
$goog$Promise$addUnhandledRejection_$$=function($promise$jscomp$10$$,$reason$jscomp$21$$){$promise$jscomp$10$$.$hadUnhandledRejection_$=!0;$module$contents$goog$async$run_run$$(function(){$promise$jscomp$10$$.$hadUnhandledRejection_$&&$goog$Promise$handleRejection_$$.call(null,$reason$jscomp$21$$)})};$goog$Promise$CancellationError$$=function($opt_message$jscomp$14$$){$module$contents$goog$debug$Error_DebugError$$.call(this,$opt_message$jscomp$14$$)};
$goog$async$Deferred$$=function($opt_onCancelFunction$$,$opt_defaultScope$$){this.$sequence_$=[];this.$onCancelFunction_$=$opt_onCancelFunction$$;this.$defaultScope_$=$opt_defaultScope$$||null;this.$hadError_$=this.$fired_$=!1;this.$result_$=void 0;this.$silentlyCanceled_$=this.$blocking_$=this.$blocked_$=!1;this.$unhandledErrorId_$=0;this.$parent_$=null;this.$branches_$=0};
$JSCompiler_StaticMethods_updateResult_$$=function($JSCompiler_StaticMethods_updateResult_$self$$,$isSuccess$jscomp$1$$,$res$jscomp$27$$){$JSCompiler_StaticMethods_updateResult_$self$$.$fired_$=!0;$JSCompiler_StaticMethods_updateResult_$self$$.$result_$=$res$jscomp$27$$;$JSCompiler_StaticMethods_updateResult_$self$$.$hadError_$=!$isSuccess$jscomp$1$$;$JSCompiler_StaticMethods_fire_$$($JSCompiler_StaticMethods_updateResult_$self$$)};
$JSCompiler_StaticMethods_check_$$=function($JSCompiler_StaticMethods_check_$self$$){if($JSCompiler_StaticMethods_check_$self$$.$fired_$){if(!$JSCompiler_StaticMethods_check_$self$$.$silentlyCanceled_$)throw new $goog$async$Deferred$AlreadyCalledError$$($JSCompiler_StaticMethods_check_$self$$);$JSCompiler_StaticMethods_check_$self$$.$silentlyCanceled_$=!1}};
$JSCompiler_StaticMethods_hasErrback_$$=function($JSCompiler_StaticMethods_hasErrback_$self$$){return $module$contents$goog$array_some$$($JSCompiler_StaticMethods_hasErrback_$self$$.$sequence_$,function($sequenceRow$$){return typeof $sequenceRow$$[1]==="function"})};
$JSCompiler_StaticMethods_fire_$$=function($JSCompiler_StaticMethods_fire_$self$$){if($JSCompiler_StaticMethods_fire_$self$$.$unhandledErrorId_$&&$JSCompiler_StaticMethods_fire_$self$$.$fired_$&&$JSCompiler_StaticMethods_hasErrback_$$($JSCompiler_StaticMethods_fire_$self$$)){var $deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$=$JSCompiler_StaticMethods_fire_$self$$.$unhandledErrorId_$,$error$jscomp$inline_4143_unhandledException$$=$goog$async$Deferred$errorMap_$$[$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$];
$error$jscomp$inline_4143_unhandledException$$&&($APP.$goog$global$$.clearTimeout($error$jscomp$inline_4143_unhandledException$$.$id_$),delete $goog$async$Deferred$errorMap_$$[$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$]);$JSCompiler_StaticMethods_fire_$self$$.$unhandledErrorId_$=0}$JSCompiler_StaticMethods_fire_$self$$.$parent_$&&($JSCompiler_StaticMethods_fire_$self$$.$parent_$.$branches_$--,delete $JSCompiler_StaticMethods_fire_$self$$.$parent_$);$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$=
$JSCompiler_StaticMethods_fire_$self$$.$result_$;for(var $isNewlyBlocked_onErrback$$=$error$jscomp$inline_4143_unhandledException$$=!1;$JSCompiler_StaticMethods_fire_$self$$.$sequence_$.length&&!$JSCompiler_StaticMethods_fire_$self$$.$blocked_$;){var $scope$jscomp$3_sequenceEntry$$=$JSCompiler_StaticMethods_fire_$self$$.$sequence_$.shift(),$callback$jscomp$75_f$jscomp$593$$=$scope$jscomp$3_sequenceEntry$$[0];const $errback$$=$scope$jscomp$3_sequenceEntry$$[1];$scope$jscomp$3_sequenceEntry$$=$scope$jscomp$3_sequenceEntry$$[2];
if($callback$jscomp$75_f$jscomp$593$$=$JSCompiler_StaticMethods_fire_$self$$.$hadError_$?$errback$$:$callback$jscomp$75_f$jscomp$593$$)try{var $onCallback_ret$jscomp$115$$=$callback$jscomp$75_f$jscomp$593$$.call($scope$jscomp$3_sequenceEntry$$||$JSCompiler_StaticMethods_fire_$self$$.$defaultScope_$,$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$);$onCallback_ret$jscomp$115$$===$goog$async$Deferred$CONVERTED_TO_PROMISE_$$&&($onCallback_ret$jscomp$115$$=void 0);$onCallback_ret$jscomp$115$$!==
void 0&&($JSCompiler_StaticMethods_fire_$self$$.$hadError_$=$JSCompiler_StaticMethods_fire_$self$$.$hadError_$&&($onCallback_ret$jscomp$115$$==$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$||$onCallback_ret$jscomp$115$$ instanceof Error),$JSCompiler_StaticMethods_fire_$self$$.$result_$=$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$=$onCallback_ret$jscomp$115$$);if($module$contents$goog$Thenable_Thenable$isImplementedBy$$($deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$)||
typeof $APP.$goog$global$$.Promise==="function"&&$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$ instanceof $APP.$goog$global$$.Promise)$isNewlyBlocked_onErrback$$=!0,$JSCompiler_StaticMethods_fire_$self$$.$blocked_$=!0}catch($ex$jscomp$11$$){$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$=$ex$jscomp$11$$,$JSCompiler_StaticMethods_fire_$self$$.$hadError_$=!0,$JSCompiler_StaticMethods_hasErrback_$$($JSCompiler_StaticMethods_fire_$self$$)||($error$jscomp$inline_4143_unhandledException$$=
!0)}}$JSCompiler_StaticMethods_fire_$self$$.$result_$=$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$;$isNewlyBlocked_onErrback$$&&($onCallback_ret$jscomp$115$$=$goog$bind$$($JSCompiler_StaticMethods_fire_$self$$.$continue_$,$JSCompiler_StaticMethods_fire_$self$$,!0),$isNewlyBlocked_onErrback$$=$goog$bind$$($JSCompiler_StaticMethods_fire_$self$$.$continue_$,$JSCompiler_StaticMethods_fire_$self$$,!1),$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$ instanceof
$goog$async$Deferred$$?($deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$.addCallbacks($onCallback_ret$jscomp$115$$,$isNewlyBlocked_onErrback$$),$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$.$blocking_$=!0):$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$.then($onCallback_ret$jscomp$115$$,$isNewlyBlocked_onErrback$$));$error$jscomp$inline_4143_unhandledException$$&&($deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$=
new $goog$async$Deferred$Error_$$($deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$),$goog$async$Deferred$errorMap_$$[$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$.$id_$]=$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$,$JSCompiler_StaticMethods_fire_$self$$.$unhandledErrorId_$=$deferredError$jscomp$inline_4146_id$jscomp$inline_4142_res$jscomp$30$$.$id_$)};$goog$async$Deferred$AlreadyCalledError$$=function(){$module$contents$goog$debug$Error_DebugError$$.call(this)};
$goog$async$Deferred$CanceledError$$=function(){$module$contents$goog$debug$Error_DebugError$$.call(this)};$goog$async$Deferred$Error_$$=function($error$jscomp$30$$){this.$id_$=$APP.$goog$global$$.setTimeout($goog$bind$$(this.throwError,this),0);this.$error_$=$error$jscomp$30$$};$$jscomp$scope$1087077126$0$createMockedEventEmitter$$=function(){return{addListener(){},removeListener(){},addEventListener(){},removeEventListener(){},dispatchEvent(){return!0}}};
$app$util$globals$event$$=function($name$jscomp$145$$,$detail$jscomp$3$$){const $options$jscomp$408$$={};$detail$jscomp$3$$!==void 0&&($options$jscomp$408$$.detail=$detail$jscomp$3$$);return new CustomEvent($name$jscomp$145$$,$options$jscomp$408$$)};$app$util$globals$dispatch_BANG_$$=function(...$args$jscomp$204$$){$APP.$app$util$globals$document$$.dispatchEvent(...$args$jscomp$204$$)};$app$util$globals$unlisten$$=function(...$args$jscomp$206$$){$APP.$app$util$globals$document$$.removeEventListener(...$args$jscomp$206$$)};
$com$cognitect$transit$util$randHex$$=function(){return Math.round(Math.random()*15).toString(16)};$com$cognitect$transit$caching$isCacheable$$=function($string$jscomp$9$$,$asMapKey_c1$jscomp$20$$){if($string$jscomp$9$$.length>3){if($asMapKey_c1$jscomp$20$$)return!0;$asMapKey_c1$jscomp$20$$=$string$jscomp$9$$.charAt(1);return $string$jscomp$9$$.charAt(0)==="~"?$asMapKey_c1$jscomp$20$$===":"||$asMapKey_c1$jscomp$20$$==="$"||$asMapKey_c1$jscomp$20$$==="#":!1}return!1};
$com$cognitect$transit$caching$idxToCode$$=function($idx$jscomp$60_loc$jscomp$3$$){var $hi$jscomp$5$$=Math.floor($idx$jscomp$60_loc$jscomp$3$$/44);$idx$jscomp$60_loc$jscomp$3$$=String.fromCharCode($idx$jscomp$60_loc$jscomp$3$$%44+48);return $hi$jscomp$5$$===0?"^"+$idx$jscomp$60_loc$jscomp$3$$:"^"+String.fromCharCode($hi$jscomp$5$$+48)+$idx$jscomp$60_loc$jscomp$3$$};$com$cognitect$transit$caching$WriteCache$$=function(){this.$cacheSize$=this.$gen$=this.$idx$=0;this.cache={}};
$com$cognitect$transit$caching$ReadCache$$=function(){this.$idx$=0;this.cache=[]};
$com$cognitect$transit$eq$equals$$=function($x$jscomp$984$$,$y$jscomp$300$$){if($x$jscomp$984$$==null)return $y$jscomp$300$$==null;if($x$jscomp$984$$===$y$jscomp$300$$)return!0;if(typeof $x$jscomp$984$$==="object"){if($com$cognitect$transit$util$isArray$$($x$jscomp$984$$)){if($com$cognitect$transit$util$isArray$$($y$jscomp$300$$)&&$x$jscomp$984$$.length===$y$jscomp$300$$.length){for(var $i$jscomp$399_xklen$$=0;$i$jscomp$399_xklen$$<$x$jscomp$984$$.length;$i$jscomp$399_xklen$$++)if(!$com$cognitect$transit$eq$equals$$($x$jscomp$984$$[$i$jscomp$399_xklen$$],
$y$jscomp$300$$[$i$jscomp$399_xklen$$]))return!1;return!0}return!1}if($x$jscomp$984$$.$com$cognitect$transit$equals$)return $x$jscomp$984$$.$com$cognitect$transit$equals$($y$jscomp$300$$);if($y$jscomp$300$$!=null&&typeof $y$jscomp$300$$==="object"){if($y$jscomp$300$$.$com$cognitect$transit$equals$)return $y$jscomp$300$$.$com$cognitect$transit$equals$($x$jscomp$984$$);$i$jscomp$399_xklen$$=0;var $yklen$$=$com$cognitect$transit$util$objectKeys$$($y$jscomp$300$$).length,$p$jscomp$128$$;for($p$jscomp$128$$ in $x$jscomp$984$$)if($x$jscomp$984$$.hasOwnProperty($p$jscomp$128$$)&&
($i$jscomp$399_xklen$$++,!$y$jscomp$300$$.hasOwnProperty($p$jscomp$128$$)||!$com$cognitect$transit$eq$equals$$($x$jscomp$984$$[$p$jscomp$128$$],$y$jscomp$300$$[$p$jscomp$128$$])))return!1;return $i$jscomp$399_xklen$$===$yklen$$}}return!1};$com$cognitect$transit$eq$hashCombine$$=function($seed$jscomp$14$$,$hash$jscomp$25$$){return $seed$jscomp$14$$^$hash$jscomp$25$$+2654435769+($seed$jscomp$14$$<<6)+($seed$jscomp$14$$>>2)};
$com$cognitect$transit$eq$hashMapLike$$=function($m$jscomp$159$$){var $code$jscomp$7$$=0;if($m$jscomp$159$$.forEach!=null)$m$jscomp$159$$.forEach(function($val$jscomp$139$$,$key$jscomp$265$$){$code$jscomp$7$$=($code$jscomp$7$$+($com$cognitect$transit$eq$hashCode$$($key$jscomp$265$$)^$com$cognitect$transit$eq$hashCode$$($val$jscomp$139$$)))%4503599627370496});else for(var $keys$jscomp$44$$=$com$cognitect$transit$util$objectKeys$$($m$jscomp$159$$),$i$jscomp$401$$=0;$i$jscomp$401$$<$keys$jscomp$44$$.length;$i$jscomp$401$$++){var $key$jscomp$264$$=
$keys$jscomp$44$$[$i$jscomp$401$$],$val$jscomp$138$$=$m$jscomp$159$$[$key$jscomp$264$$];$code$jscomp$7$$=($code$jscomp$7$$+($com$cognitect$transit$eq$hashCode$$($key$jscomp$264$$)^$com$cognitect$transit$eq$hashCode$$($val$jscomp$138$$)))%4503599627370496}return $code$jscomp$7$$};
$com$cognitect$transit$eq$hashArrayLike$$=function($arr$jscomp$162$$){var $code$jscomp$8$$=0;if($com$cognitect$transit$util$isArray$$($arr$jscomp$162$$))for(var $i$jscomp$402$$=0;$i$jscomp$402$$<$arr$jscomp$162$$.length;$i$jscomp$402$$++)$code$jscomp$8$$=$com$cognitect$transit$eq$hashCombine$$($code$jscomp$8$$,$com$cognitect$transit$eq$hashCode$$($arr$jscomp$162$$[$i$jscomp$402$$]));else $arr$jscomp$162$$.forEach&&$arr$jscomp$162$$.forEach(function($x$jscomp$985$$){$code$jscomp$8$$=$com$cognitect$transit$eq$hashCombine$$($code$jscomp$8$$,
$com$cognitect$transit$eq$hashCode$$($x$jscomp$985$$))});return $code$jscomp$8$$};
$com$cognitect$transit$eq$hashCode$$=function($JSCompiler_inline_result$jscomp$568_x$jscomp$986$$){if($JSCompiler_inline_result$jscomp$568_x$jscomp$986$$==null)return 0;switch(typeof $JSCompiler_inline_result$jscomp$568_x$jscomp$986$$){case "number":return $JSCompiler_inline_result$jscomp$568_x$jscomp$986$$;case "boolean":return $JSCompiler_inline_result$jscomp$568_x$jscomp$986$$===!0?1:0;case "string":var $cached$jscomp$inline_4151_code$jscomp$9_code$jscomp$inline_4152$$=$com$cognitect$transit$eq$stringCodeCache$$[$JSCompiler_inline_result$jscomp$568_x$jscomp$986$$];
if($cached$jscomp$inline_4151_code$jscomp$9_code$jscomp$inline_4152$$!=null)$JSCompiler_inline_result$jscomp$568_x$jscomp$986$$=$cached$jscomp$inline_4151_code$jscomp$9_code$jscomp$inline_4152$$;else{for(var $i$jscomp$inline_4153$$=$cached$jscomp$inline_4151_code$jscomp$9_code$jscomp$inline_4152$$=0;$i$jscomp$inline_4153$$<$JSCompiler_inline_result$jscomp$568_x$jscomp$986$$.length;++$i$jscomp$inline_4153$$)$cached$jscomp$inline_4151_code$jscomp$9_code$jscomp$inline_4152$$=31*$cached$jscomp$inline_4151_code$jscomp$9_code$jscomp$inline_4152$$+
$JSCompiler_inline_result$jscomp$568_x$jscomp$986$$.charCodeAt($i$jscomp$inline_4153$$),$cached$jscomp$inline_4151_code$jscomp$9_code$jscomp$inline_4152$$%=4294967296;$com$cognitect$transit$eq$stringCodeCacheSize$$++;$com$cognitect$transit$eq$stringCodeCacheSize$$>=256&&($com$cognitect$transit$eq$stringCodeCache$$={},$com$cognitect$transit$eq$stringCodeCacheSize$$=1);$JSCompiler_inline_result$jscomp$568_x$jscomp$986$$=$com$cognitect$transit$eq$stringCodeCache$$[$JSCompiler_inline_result$jscomp$568_x$jscomp$986$$]=
$cached$jscomp$inline_4151_code$jscomp$9_code$jscomp$inline_4152$$}return $JSCompiler_inline_result$jscomp$568_x$jscomp$986$$;case "function":return $cached$jscomp$inline_4151_code$jscomp$9_code$jscomp$inline_4152$$=$JSCompiler_inline_result$jscomp$568_x$jscomp$986$$.transit$hashCode$,$cached$jscomp$inline_4151_code$jscomp$9_code$jscomp$inline_4152$$||($cached$jscomp$inline_4151_code$jscomp$9_code$jscomp$inline_4152$$=$com$cognitect$transit$eq$hashCodeCounter$$,typeof Object.defineProperty!="undefined"?
Object.defineProperty($JSCompiler_inline_result$jscomp$568_x$jscomp$986$$,"transit$hashCode$",{value:$cached$jscomp$inline_4151_code$jscomp$9_code$jscomp$inline_4152$$,enumerable:!1}):$JSCompiler_inline_result$jscomp$568_x$jscomp$986$$.transit$hashCode$=$cached$jscomp$inline_4151_code$jscomp$9_code$jscomp$inline_4152$$,$com$cognitect$transit$eq$hashCodeCounter$$++),$cached$jscomp$inline_4151_code$jscomp$9_code$jscomp$inline_4152$$;default:return $JSCompiler_inline_result$jscomp$568_x$jscomp$986$$ instanceof
Date?$JSCompiler_inline_result$jscomp$568_x$jscomp$986$$.valueOf():$com$cognitect$transit$util$isArray$$($JSCompiler_inline_result$jscomp$568_x$jscomp$986$$)?$com$cognitect$transit$eq$hashArrayLike$$($JSCompiler_inline_result$jscomp$568_x$jscomp$986$$):$JSCompiler_inline_result$jscomp$568_x$jscomp$986$$.$com$cognitect$transit$hashCode$?$JSCompiler_inline_result$jscomp$568_x$jscomp$986$$.$com$cognitect$transit$hashCode$():$com$cognitect$transit$eq$hashMapLike$$($JSCompiler_inline_result$jscomp$568_x$jscomp$986$$)}};
$com$cognitect$transit$types$TaggedValue$$=function($tag$jscomp$33$$,$rep$$){this.tag=$tag$jscomp$33$$;this.rep=$rep$$;this.$hashCode$=-1};$com$cognitect$transit$types$taggedValue$$=function($tag$jscomp$34$$,$rep$jscomp$1$$){return new $com$cognitect$transit$types$TaggedValue$$($tag$jscomp$34$$,$rep$jscomp$1$$)};$com$cognitect$transit$types$Keyword$$=function($name$jscomp$146$$){this.$_name$=$name$jscomp$146$$;this.$hashCode$=-1};
$com$cognitect$transit$types$Symbol$$=function($name$jscomp$147$$){this.$_name$=$name$jscomp$147$$;this.$hashCode$=-1};
$com$cognitect$transit$types$hexFor$$=function($aLong$$,$i$jscomp$404_sidx$$,$eidx$$){var $ret$jscomp$117$$="";$eidx$$=$eidx$$||$i$jscomp$404_sidx$$+1;for(var $shift$jscomp$27$$=(7-$i$jscomp$404_sidx$$)*8,$mask$jscomp$10$$=(new $module$contents$goog$math$Long_Long$$(255,0)).shiftLeft($shift$jscomp$27$$);$i$jscomp$404_sidx$$<$eidx$$;$i$jscomp$404_sidx$$++,$shift$jscomp$27$$-=8,$mask$jscomp$10$$=$JSCompiler_StaticMethods_shiftRightUnsigned$$($mask$jscomp$10$$,8)){var $s$jscomp$466$$=$JSCompiler_StaticMethods_shiftRightUnsigned$$($aLong$$.and($mask$jscomp$10$$),
$shift$jscomp$27$$).toString(16);$s$jscomp$466$$.length==1&&($s$jscomp$466$$="0"+$s$jscomp$466$$);$ret$jscomp$117$$+=$s$jscomp$466$$}return $ret$jscomp$117$$};$com$cognitect$transit$types$UUID$$=function($high$jscomp$12$$,$low$jscomp$12$$){this.high=$high$jscomp$12$$;this.low=$low$jscomp$12$$;this.$hashCode$=-1};$com$cognitect$transit$types$TransitArrayMapIterator$$=function($entries$jscomp$7$$,$type$jscomp$236$$){this.entries=$entries$jscomp$7$$;this.type=$type$jscomp$236$$||0;this.$idx$=0};
$com$cognitect$transit$types$TransitMapIterator$$=function($map$jscomp$17$$,$type$jscomp$237$$){this.map=$map$jscomp$17$$;this.type=$type$jscomp$237$$||0;this.keys=this.map.$getKeys$();this.$idx$=0;this.$bucket$=null;this.$bucketIdx$=0};
$com$cognitect$transit$types$mapEquals$$=function($entries$jscomp$8_me$jscomp$2$$,$you$$){if($entries$jscomp$8_me$jscomp$2$$ instanceof $com$cognitect$transit$types$TransitMap$$&&($you$$ instanceof $com$cognitect$transit$types$TransitArrayMap$$||$you$$ instanceof $com$cognitect$transit$types$TransitMap$$)){if($entries$jscomp$8_me$jscomp$2$$.size!==$you$$.size)return!1;for(var $code$jscomp$10_kslen$$ in $entries$jscomp$8_me$jscomp$2$$.map)for(var $bucket$jscomp$2_i$jscomp$406$$=$entries$jscomp$8_me$jscomp$2$$.map[$code$jscomp$10_kslen$$],
$j$jscomp$103_ks$jscomp$53$$=0;$j$jscomp$103_ks$jscomp$53$$<$bucket$jscomp$2_i$jscomp$406$$.length;$j$jscomp$103_ks$jscomp$53$$+=2)if(!$com$cognitect$transit$eq$equals$$($bucket$jscomp$2_i$jscomp$406$$[$j$jscomp$103_ks$jscomp$53$$+1],$you$$.get($bucket$jscomp$2_i$jscomp$406$$[$j$jscomp$103_ks$jscomp$53$$])))return!1;return!0}if($entries$jscomp$8_me$jscomp$2$$ instanceof $com$cognitect$transit$types$TransitArrayMap$$&&($you$$ instanceof $com$cognitect$transit$types$TransitArrayMap$$||$you$$ instanceof
$com$cognitect$transit$types$TransitMap$$)){if($entries$jscomp$8_me$jscomp$2$$.size!==$you$$.size)return!1;$entries$jscomp$8_me$jscomp$2$$=$entries$jscomp$8_me$jscomp$2$$.$_entries$;for($j$jscomp$103_ks$jscomp$53$$=0;$j$jscomp$103_ks$jscomp$53$$<$entries$jscomp$8_me$jscomp$2$$.length;$j$jscomp$103_ks$jscomp$53$$+=2)if(!$com$cognitect$transit$eq$equals$$($entries$jscomp$8_me$jscomp$2$$[$j$jscomp$103_ks$jscomp$53$$+1],$you$$.get($entries$jscomp$8_me$jscomp$2$$[$j$jscomp$103_ks$jscomp$53$$])))return!1;
return!0}if($you$$!=null&&typeof $you$$==="object"&&($j$jscomp$103_ks$jscomp$53$$=$com$cognitect$transit$util$objectKeys$$($you$$),$code$jscomp$10_kslen$$=$j$jscomp$103_ks$jscomp$53$$.length,$entries$jscomp$8_me$jscomp$2$$.size===$code$jscomp$10_kslen$$)){for($bucket$jscomp$2_i$jscomp$406$$=0;$bucket$jscomp$2_i$jscomp$406$$<$code$jscomp$10_kslen$$;$bucket$jscomp$2_i$jscomp$406$$++){var $k$jscomp$527$$=$j$jscomp$103_ks$jscomp$53$$[$bucket$jscomp$2_i$jscomp$406$$];if(!$entries$jscomp$8_me$jscomp$2$$.has($k$jscomp$527$$)||
!$com$cognitect$transit$eq$equals$$($you$$[$k$jscomp$527$$],$entries$jscomp$8_me$jscomp$2$$.get($k$jscomp$527$$)))return!1}return!0}return!1};$com$cognitect$transit$types$print$$=function($x$jscomp$996$$){return $x$jscomp$996$$==null?"null":$APP.$goog$typeOf$$($x$jscomp$996$$)==="array"?"["+$x$jscomp$996$$.toString()+"]":$APP.$goog$typeOf$$($x$jscomp$996$$)==="string"?'"'+$x$jscomp$996$$+'"':$x$jscomp$996$$.toString()};
$com$cognitect$transit$types$printMap$$=function($map$jscomp$18$$){var $idx$jscomp$65$$=0,$str$jscomp$83$$="TransitMap {";$map$jscomp$18$$.forEach(function($v$jscomp$326$$,$k$jscomp$528$$){$str$jscomp$83$$+=$com$cognitect$transit$types$print$$($k$jscomp$528$$)+" \x3d\x3e "+$com$cognitect$transit$types$print$$($v$jscomp$326$$);$idx$jscomp$65$$<$map$jscomp$18$$.size-1&&($str$jscomp$83$$+=", ");$idx$jscomp$65$$++});return $str$jscomp$83$$+"}"};
$com$cognitect$transit$types$printSet$$=function($set$jscomp$2$$){var $idx$jscomp$66$$=0,$str$jscomp$84$$="TransitSet {";$set$jscomp$2$$.forEach(function($v$jscomp$327$$){$str$jscomp$84$$+=$com$cognitect$transit$types$print$$($v$jscomp$327$$);$idx$jscomp$66$$<$set$jscomp$2$$.size-1&&($str$jscomp$84$$+=", ");$idx$jscomp$66$$++});return $str$jscomp$84$$+"}"};
$com$cognitect$transit$types$TransitArrayMap$$=function($entries$jscomp$9$$){this.$_entries$=$entries$jscomp$9$$;this.$backingMap$=null;this.$hashCode$=-1;this.size=$entries$jscomp$9$$.length/2;this.$accesses$=0};
$JSCompiler_StaticMethods_convert$$=function($JSCompiler_StaticMethods_convert$self$$){if($JSCompiler_StaticMethods_convert$self$$.$backingMap$)throw Error("Invalid operation, already converted");if($JSCompiler_StaticMethods_convert$self$$.size<8)return!1;$JSCompiler_StaticMethods_convert$self$$.$accesses$++;return $JSCompiler_StaticMethods_convert$self$$.$accesses$>32?($JSCompiler_StaticMethods_convert$self$$.$backingMap$=$com$cognitect$transit$types$map$$($JSCompiler_StaticMethods_convert$self$$.$_entries$,
!1,!0),$JSCompiler_StaticMethods_convert$self$$.$_entries$=[],!0):!1};$com$cognitect$transit$types$TransitMap$$=function($keys$jscomp$45$$,$map$jscomp$19$$,$size$jscomp$80$$){this.map=$map$jscomp$19$$||{};this.$_keys$=$keys$jscomp$45$$||[];this.size=$size$jscomp$80$$||0;this.$hashCode$=-1};
$com$cognitect$transit$types$map$$=function($arr$jscomp$163$$,$checkDups_i$jscomp$419$$,$code$jscomp$15_hashMap_j$jscomp$107$$){$arr$jscomp$163$$=$arr$jscomp$163$$||[];$checkDups_i$jscomp$419$$=$checkDups_i$jscomp$419$$===!1?$checkDups_i$jscomp$419$$:!0;if(($code$jscomp$15_hashMap_j$jscomp$107$$!==!0||!$code$jscomp$15_hashMap_j$jscomp$107$$)&&$arr$jscomp$163$$.length<=64){if($checkDups_i$jscomp$419$$){var $map$jscomp$20_t$jscomp$55$$=$arr$jscomp$163$$;$arr$jscomp$163$$=[];for($checkDups_i$jscomp$419$$=
0;$checkDups_i$jscomp$419$$<$map$jscomp$20_t$jscomp$55$$.length;$checkDups_i$jscomp$419$$+=2){var $keys$jscomp$47_seen$jscomp$9$$=!1;for($code$jscomp$15_hashMap_j$jscomp$107$$=0;$code$jscomp$15_hashMap_j$jscomp$107$$<$arr$jscomp$163$$.length;$code$jscomp$15_hashMap_j$jscomp$107$$+=2)if($com$cognitect$transit$eq$equals$$($arr$jscomp$163$$[$code$jscomp$15_hashMap_j$jscomp$107$$],$map$jscomp$20_t$jscomp$55$$[$checkDups_i$jscomp$419$$])){$arr$jscomp$163$$[$code$jscomp$15_hashMap_j$jscomp$107$$+1]=$map$jscomp$20_t$jscomp$55$$[$checkDups_i$jscomp$419$$+
1];$keys$jscomp$47_seen$jscomp$9$$=!0;break}$keys$jscomp$47_seen$jscomp$9$$||($arr$jscomp$163$$.push($map$jscomp$20_t$jscomp$55$$[$checkDups_i$jscomp$419$$]),$arr$jscomp$163$$.push($map$jscomp$20_t$jscomp$55$$[$checkDups_i$jscomp$419$$+1]))}}return new $com$cognitect$transit$types$TransitArrayMap$$($arr$jscomp$163$$)}$map$jscomp$20_t$jscomp$55$$={};$keys$jscomp$47_seen$jscomp$9$$=[];var $size$jscomp$81$$=0;for($checkDups_i$jscomp$419$$=0;$checkDups_i$jscomp$419$$<$arr$jscomp$163$$.length;$checkDups_i$jscomp$419$$+=
2){$code$jscomp$15_hashMap_j$jscomp$107$$=$com$cognitect$transit$eq$hashCode$$($arr$jscomp$163$$[$checkDups_i$jscomp$419$$]);var $bucket$jscomp$9$$=$map$jscomp$20_t$jscomp$55$$[$code$jscomp$15_hashMap_j$jscomp$107$$];if($bucket$jscomp$9$$==null)$keys$jscomp$47_seen$jscomp$9$$.push($code$jscomp$15_hashMap_j$jscomp$107$$),$map$jscomp$20_t$jscomp$55$$[$code$jscomp$15_hashMap_j$jscomp$107$$]=[$arr$jscomp$163$$[$checkDups_i$jscomp$419$$],$arr$jscomp$163$$[$checkDups_i$jscomp$419$$+1]],$size$jscomp$81$$++;
else{var $newEntry$jscomp$1$$=!0;for($code$jscomp$15_hashMap_j$jscomp$107$$=0;$code$jscomp$15_hashMap_j$jscomp$107$$<$bucket$jscomp$9$$.length;$code$jscomp$15_hashMap_j$jscomp$107$$+=2)if($com$cognitect$transit$eq$equals$$($bucket$jscomp$9$$[$code$jscomp$15_hashMap_j$jscomp$107$$],$arr$jscomp$163$$[$checkDups_i$jscomp$419$$])){$bucket$jscomp$9$$[$code$jscomp$15_hashMap_j$jscomp$107$$+1]=$arr$jscomp$163$$[$checkDups_i$jscomp$419$$+1];$newEntry$jscomp$1$$=!1;break}$newEntry$jscomp$1$$&&($bucket$jscomp$9$$.push($arr$jscomp$163$$[$checkDups_i$jscomp$419$$]),
$bucket$jscomp$9$$.push($arr$jscomp$163$$[$checkDups_i$jscomp$419$$+1]),$size$jscomp$81$$++)}}return new $com$cognitect$transit$types$TransitMap$$($keys$jscomp$47_seen$jscomp$9$$,$map$jscomp$20_t$jscomp$55$$,$size$jscomp$81$$)};$com$cognitect$transit$types$TransitSet$$=function($map$jscomp$21$$){this.map=$map$jscomp$21$$;this.size=$map$jscomp$21$$.size};
$com$cognitect$transit$types$set$$=function($arr$jscomp$164$$){$arr$jscomp$164$$=$arr$jscomp$164$$||[];for(var $map$jscomp$22$$={},$keys$jscomp$48$$=[],$size$jscomp$82$$=0,$i$jscomp$420$$=0;$i$jscomp$420$$<$arr$jscomp$164$$.length;$i$jscomp$420$$++){var $code$jscomp$16_newEntry$jscomp$2$$=$com$cognitect$transit$eq$hashCode$$($arr$jscomp$164$$[$i$jscomp$420$$]),$vals$jscomp$10$$=$map$jscomp$22$$[$code$jscomp$16_newEntry$jscomp$2$$];if($vals$jscomp$10$$==null)$keys$jscomp$48$$.push($code$jscomp$16_newEntry$jscomp$2$$),
$map$jscomp$22$$[$code$jscomp$16_newEntry$jscomp$2$$]=[$arr$jscomp$164$$[$i$jscomp$420$$],$arr$jscomp$164$$[$i$jscomp$420$$]],$size$jscomp$82$$++;else{$code$jscomp$16_newEntry$jscomp$2$$=!0;for(var $j$jscomp$108$$=0;$j$jscomp$108$$<$vals$jscomp$10$$.length;$j$jscomp$108$$+=2)if($com$cognitect$transit$eq$equals$$($vals$jscomp$10$$[$j$jscomp$108$$],$arr$jscomp$164$$[$i$jscomp$420$$])){$code$jscomp$16_newEntry$jscomp$2$$=!1;break}$code$jscomp$16_newEntry$jscomp$2$$&&($vals$jscomp$10$$.push($arr$jscomp$164$$[$i$jscomp$420$$]),
$vals$jscomp$10$$.push($arr$jscomp$164$$[$i$jscomp$420$$]),$size$jscomp$82$$++)}}return new $com$cognitect$transit$types$TransitSet$$(new $com$cognitect$transit$types$TransitMap$$($keys$jscomp$48$$,$map$jscomp$22$$,$size$jscomp$82$$))};$com$cognitect$transit$impl$decoder$Tag$$=function($s$jscomp$473$$){this.$str$=$s$jscomp$473$$};
$com$cognitect$transit$impl$decoder$Decoder$$=function($JSCompiler_inline_result$jscomp$573_options$jscomp$409$$){this.options=$JSCompiler_inline_result$jscomp$573_options$jscomp$409$$||{};this.$handlers$={};for(var $h$jscomp$115$$ in this.$defaults$.$handlers$)this.$handlers$[$h$jscomp$115$$]=this.$defaults$.$handlers$[$h$jscomp$115$$];for($h$jscomp$115$$ in this.options.handlers){a:{switch($h$jscomp$115$$){case "_":case "s":case "?":case "i":case "d":case "b":case "'":case "array":case "map":$JSCompiler_inline_result$jscomp$573_options$jscomp$409$$=
!0;break a}$JSCompiler_inline_result$jscomp$573_options$jscomp$409$$=!1}if($JSCompiler_inline_result$jscomp$573_options$jscomp$409$$)throw Error('Cannot override handler for ground type "'+$h$jscomp$115$$+'"');this.$handlers$[$h$jscomp$115$$]=this.options.handlers[$h$jscomp$115$$]}this.$preferStrings$=this.options.preferStrings!=null?this.options.preferStrings:this.$defaults$.$preferStrings$;this.$preferBuffers$=this.options.preferBuffers!=null?this.options.preferBuffers:this.$defaults$.$preferBuffers$;
this.$defaultHandler$=this.options.defaultHandler||this.$defaults$.$defaultHandler$;this.$mapBuilder$=this.options.mapBuilder;this.$arrayBuilder$=this.options.arrayBuilder};
$JSCompiler_StaticMethods_decodeArray$$=function($JSCompiler_StaticMethods_decodeArray$self$$,$node$jscomp$155_val$jscomp$143$$,$cache$jscomp$78$$,$asMapKey$jscomp$8$$,$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$){if($i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$){var $arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$=[];for($i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$=0;$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$<$node$jscomp$155_val$jscomp$143$$.length;$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$++)$arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$.push($JSCompiler_StaticMethods_decodeArray$self$$.decode($node$jscomp$155_val$jscomp$143$$[$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$],
$cache$jscomp$78$$,$asMapKey$jscomp$8$$,!1));return $arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$}$arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$=$cache$jscomp$78$$&&$cache$jscomp$78$$.$idx$;if($node$jscomp$155_val$jscomp$143$$.length===2&&typeof $node$jscomp$155_val$jscomp$143$$[0]==="string"&&($i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$=$JSCompiler_StaticMethods_decodeArray$self$$.decode($node$jscomp$155_val$jscomp$143$$[0],$cache$jscomp$78$$,!1,!1))&&$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$ instanceof
$com$cognitect$transit$impl$decoder$Tag$$)return $node$jscomp$155_val$jscomp$143$$=$node$jscomp$155_val$jscomp$143$$[1],$arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$=$JSCompiler_StaticMethods_decodeArray$self$$.$handlers$[$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$.$str$],$arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$!=null?$arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$=$arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$($JSCompiler_StaticMethods_decodeArray$self$$.decode($node$jscomp$155_val$jscomp$143$$,
$cache$jscomp$78$$,$asMapKey$jscomp$8$$,!0),$JSCompiler_StaticMethods_decodeArray$self$$):$com$cognitect$transit$types$taggedValue$$($i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$.$str$,$JSCompiler_StaticMethods_decodeArray$self$$.decode($node$jscomp$155_val$jscomp$143$$,$cache$jscomp$78$$,$asMapKey$jscomp$8$$,!1));$cache$jscomp$78$$&&$arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$!=$cache$jscomp$78$$.$idx$&&($cache$jscomp$78$$.$idx$=$arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$);
if($JSCompiler_StaticMethods_decodeArray$self$$.$arrayBuilder$){if($node$jscomp$155_val$jscomp$143$$.length<=32&&$JSCompiler_StaticMethods_decodeArray$self$$.$arrayBuilder$.fromArray){$arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$=[];for($i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$=0;$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$<$node$jscomp$155_val$jscomp$143$$.length;$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$++)$arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$.push($JSCompiler_StaticMethods_decodeArray$self$$.decode($node$jscomp$155_val$jscomp$143$$[$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$],
$cache$jscomp$78$$,$asMapKey$jscomp$8$$,!1));return $JSCompiler_StaticMethods_decodeArray$self$$.$arrayBuilder$.fromArray($arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$,$node$jscomp$155_val$jscomp$143$$)}$arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$=$JSCompiler_StaticMethods_decodeArray$self$$.$arrayBuilder$.init($node$jscomp$155_val$jscomp$143$$);for($i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$=0;$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$<$node$jscomp$155_val$jscomp$143$$.length;$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$++)$arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$=
$JSCompiler_StaticMethods_decodeArray$self$$.$arrayBuilder$.add($arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$,$JSCompiler_StaticMethods_decodeArray$self$$.decode($node$jscomp$155_val$jscomp$143$$[$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$],$cache$jscomp$78$$,$asMapKey$jscomp$8$$,!1),$node$jscomp$155_val$jscomp$143$$);return $JSCompiler_StaticMethods_decodeArray$self$$.$arrayBuilder$.finalize($arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$,$node$jscomp$155_val$jscomp$143$$)}$arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$=
[];for($i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$=0;$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$<$node$jscomp$155_val$jscomp$143$$.length;$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$++)$arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$.push($JSCompiler_StaticMethods_decodeArray$self$$.decode($node$jscomp$155_val$jscomp$143$$[$i$jscomp$423_tag$jscomp$36_tagValue$jscomp$4$$],$cache$jscomp$78$$,$asMapKey$jscomp$8$$,!1));return $arr$jscomp$165_cacheIdx_handler$jscomp$12_ret$jscomp$127$$};
$JSCompiler_StaticMethods_parseString$$=function($JSCompiler_StaticMethods_parseString$self$$,$string$jscomp$14$$){if($string$jscomp$14$$.charAt(0)==="~"){var $c$jscomp$227$$=$string$jscomp$14$$.charAt(1);if($c$jscomp$227$$==="~"||$c$jscomp$227$$==="^"||$c$jscomp$227$$==="`")return $string$jscomp$14$$.substring(1);if($c$jscomp$227$$==="#")return new $com$cognitect$transit$impl$decoder$Tag$$($string$jscomp$14$$.substring(2));var $handler$jscomp$13$$=$JSCompiler_StaticMethods_parseString$self$$.$handlers$[$c$jscomp$227$$];
return $handler$jscomp$13$$==null?$JSCompiler_StaticMethods_parseString$self$$.$defaultHandler$($c$jscomp$227$$,$string$jscomp$14$$.substring(2)):$handler$jscomp$13$$($string$jscomp$14$$.substring(2),$JSCompiler_StaticMethods_parseString$self$$)}return $string$jscomp$14$$};$com$cognitect$transit$impl$reader$JSONUnmarshaller$$=function($opts$jscomp$243$$){this.$decoder$=new $com$cognitect$transit$impl$decoder$Decoder$$($opts$jscomp$243$$)};
$com$cognitect$transit$impl$reader$Reader$$=function($unmarshaller$$,$options$jscomp$411$$){this.$unmarshaller$=$unmarshaller$$;this.options=$options$jscomp$411$$||{};this.cache=this.options.cache?this.options.cache:new $com$cognitect$transit$caching$ReadCache$$};
$com$cognitect$transit$handlers$typeTag$$=function($ctor$jscomp$3$$){if($ctor$jscomp$3$$==null)return"null";if($ctor$jscomp$3$$===String)return"string";if($ctor$jscomp$3$$===Boolean)return"boolean";if($ctor$jscomp$3$$===Number)return"number";if($ctor$jscomp$3$$===Array)return"array";if($ctor$jscomp$3$$===Object)return"map";var $tag$jscomp$37$$=$ctor$jscomp$3$$[$com$cognitect$transit$handlers$ctorGuidProperty$$];$tag$jscomp$37$$==null&&(typeof Object.defineProperty!="undefined"?($tag$jscomp$37$$=++$com$cognitect$transit$handlers$ctorGuid$$,
Object.defineProperty($ctor$jscomp$3$$,$com$cognitect$transit$handlers$ctorGuidProperty$$,{value:$tag$jscomp$37$$,enumerable:!1})):$ctor$jscomp$3$$[$com$cognitect$transit$handlers$ctorGuidProperty$$]=$tag$jscomp$37$$=++$com$cognitect$transit$handlers$ctorGuid$$);return $tag$jscomp$37$$};
$com$cognitect$transit$handlers$padZeros$$=function($n$jscomp$252_s$jscomp$475$$,$m$jscomp$162$$){$n$jscomp$252_s$jscomp$475$$=$n$jscomp$252_s$jscomp$475$$.toString();for(var $i$jscomp$424$$=$n$jscomp$252_s$jscomp$475$$.length;$i$jscomp$424$$<$m$jscomp$162$$;$i$jscomp$424$$++)$n$jscomp$252_s$jscomp$475$$="0"+$n$jscomp$252_s$jscomp$475$$;return $n$jscomp$252_s$jscomp$475$$};$com$cognitect$transit$handlers$NilHandler$$=function(){};$com$cognitect$transit$handlers$StringHandler$$=function(){};
$com$cognitect$transit$handlers$NumberHandler$$=function(){};$com$cognitect$transit$handlers$IntegerHandler$$=function(){};$com$cognitect$transit$handlers$BooleanHandler$$=function(){};$com$cognitect$transit$handlers$ArrayHandler$$=function(){};$com$cognitect$transit$handlers$MapHandler$$=function(){};$com$cognitect$transit$handlers$VerboseDateHandler$$=function(){};$com$cognitect$transit$handlers$DateHandler$$=function(){};$com$cognitect$transit$handlers$UUIDHandler$$=function(){};
$com$cognitect$transit$handlers$KeywordHandler$$=function(){};$com$cognitect$transit$handlers$SymbolHandler$$=function(){};$com$cognitect$transit$handlers$TaggedHandler$$=function(){};$com$cognitect$transit$handlers$TransitSetHandler$$=function(){};$com$cognitect$transit$handlers$TransitArrayMapHandler$$=function(){};$com$cognitect$transit$handlers$TransitMapHandler$$=function(){};$com$cognitect$transit$handlers$BufferHandler$$=function(){};$com$cognitect$transit$handlers$Uint8ArrayHandler$$=function(){};
$com$cognitect$transit$handlers$Handlers$$=function(){this.$handlers$={};this.set(null,new $com$cognitect$transit$handlers$NilHandler$$);this.set(String,new $com$cognitect$transit$handlers$StringHandler$$);this.set(Number,new $com$cognitect$transit$handlers$NumberHandler$$);this.set($module$contents$goog$math$Long_Long$$,new $com$cognitect$transit$handlers$IntegerHandler$$);this.set(Boolean,new $com$cognitect$transit$handlers$BooleanHandler$$);this.set(Array,new $com$cognitect$transit$handlers$ArrayHandler$$);
this.set(Object,new $com$cognitect$transit$handlers$MapHandler$$);this.set(Date,new $com$cognitect$transit$handlers$DateHandler$$);this.set($com$cognitect$transit$types$UUID$$,new $com$cognitect$transit$handlers$UUIDHandler$$);this.set($com$cognitect$transit$types$Keyword$$,new $com$cognitect$transit$handlers$KeywordHandler$$);this.set($com$cognitect$transit$types$Symbol$$,new $com$cognitect$transit$handlers$SymbolHandler$$);this.set($com$cognitect$transit$types$TaggedValue$$,new $com$cognitect$transit$handlers$TaggedHandler$$);
this.set($com$cognitect$transit$types$TransitSet$$,new $com$cognitect$transit$handlers$TransitSetHandler$$);this.set($com$cognitect$transit$types$TransitArrayMap$$,new $com$cognitect$transit$handlers$TransitArrayMapHandler$$);this.set($com$cognitect$transit$types$TransitMap$$,new $com$cognitect$transit$handlers$TransitMapHandler$$);typeof $APP.$goog$global$$.$Buffer$!="undefined"&&this.set($APP.$goog$global$$.$Buffer$,new $com$cognitect$transit$handlers$BufferHandler$$);typeof Uint8Array!="undefined"&&
this.set(Uint8Array,new $com$cognitect$transit$handlers$Uint8ArrayHandler$$)};
$com$cognitect$transit$impl$writer$JSONMarshaller$$=function($opts$jscomp$244_optsHandlers$$){this.$opts$=$opts$jscomp$244_optsHandlers$$||{};this.$preferStrings$=this.$opts$.preferStrings!=null?this.$opts$.preferStrings:!0;this.$objectBuilder$=this.$opts$.objectBuilder||null;this.transform=this.$opts$.transform||null;this.$handlers$=new $com$cognitect$transit$handlers$Handlers$$;if($opts$jscomp$244_optsHandlers$$=this.$opts$.handlers){if($com$cognitect$transit$util$isArray$$($opts$jscomp$244_optsHandlers$$)||!$opts$jscomp$244_optsHandlers$$.forEach)throw Error('transit writer "handlers" option must be a map');
var $self$jscomp$34$$=this;$opts$jscomp$244_optsHandlers$$.forEach(function($v$jscomp$409$$,$k$jscomp$541$$){if($k$jscomp$541$$!==void 0)$self$jscomp$34$$.$handlers$.set($k$jscomp$541$$,$v$jscomp$409$$);else throw Error("Cannot create handler for JavaScript undefined");})}this.$handlerForForeign$=this.$opts$.handlerForForeign;this.$unpack$=this.$opts$.unpack||function($x$jscomp$1005$$){return $x$jscomp$1005$$ instanceof $com$cognitect$transit$types$TransitArrayMap$$&&$x$jscomp$1005$$.$backingMap$===
null?$x$jscomp$1005$$.$_entries$:!1};this.$verbose$=this.$opts$&&this.$opts$.verbose||!1};$JSCompiler_StaticMethods_emitString$$=function($prefix$jscomp$16_string$jscomp$16$$,$tag$jscomp$40$$,$s$jscomp$476$$,$asMapKey$jscomp$11$$,$cache$jscomp$82$$){$prefix$jscomp$16_string$jscomp$16$$=$prefix$jscomp$16_string$jscomp$16$$+$tag$jscomp$40$$+$s$jscomp$476$$;return $cache$jscomp$82$$?$cache$jscomp$82$$.write($prefix$jscomp$16_string$jscomp$16$$,$asMapKey$jscomp$11$$):$prefix$jscomp$16_string$jscomp$16$$};
$com$cognitect$transit$impl$writer$emitObjects$$=function($em$jscomp$1$$,$iterable$jscomp$6$$,$cache$jscomp$88$$){var $ret$jscomp$130$$=[];if($com$cognitect$transit$util$isArray$$($iterable$jscomp$6$$))for(var $i$jscomp$427$$=0;$i$jscomp$427$$<$iterable$jscomp$6$$.length;$i$jscomp$427$$++)$ret$jscomp$130$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$1$$,$iterable$jscomp$6$$[$i$jscomp$427$$],!1,$cache$jscomp$88$$));else $iterable$jscomp$6$$.forEach(function($v$jscomp$410$$){$ret$jscomp$130$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$1$$,
$v$jscomp$410$$,!1,$cache$jscomp$88$$))});return $ret$jscomp$130$$};$com$cognitect$transit$impl$writer$isStringableKey$$=function($em$jscomp$3_h$jscomp$127$$,$k$jscomp$543$$){return typeof $k$jscomp$543$$!=="string"?($em$jscomp$3_h$jscomp$127$$=$em$jscomp$3_h$jscomp$127$$.handler($k$jscomp$543$$))&&$em$jscomp$3_h$jscomp$127$$.tag($k$jscomp$543$$).length===1:!0};
$com$cognitect$transit$impl$writer$stringableKeys$$=function($em$jscomp$4$$,$i$jscomp$429_obj$jscomp$141$$){var $arr$jscomp$167_iter$jscomp$11$$=$em$jscomp$4$$.$unpack$($i$jscomp$429_obj$jscomp$141$$),$stringableKeys$$=!0;if($arr$jscomp$167_iter$jscomp$11$$){for($i$jscomp$429_obj$jscomp$141$$=0;$i$jscomp$429_obj$jscomp$141$$<$arr$jscomp$167_iter$jscomp$11$$.length&&($stringableKeys$$=$com$cognitect$transit$impl$writer$isStringableKey$$($em$jscomp$4$$,$arr$jscomp$167_iter$jscomp$11$$[$i$jscomp$429_obj$jscomp$141$$]),
$stringableKeys$$);$i$jscomp$429_obj$jscomp$141$$+=2);return $stringableKeys$$}if($i$jscomp$429_obj$jscomp$141$$.keys){$arr$jscomp$167_iter$jscomp$11$$=$i$jscomp$429_obj$jscomp$141$$.keys();var $step$jscomp$27$$=null;if($arr$jscomp$167_iter$jscomp$11$$.next){for($step$jscomp$27$$=$arr$jscomp$167_iter$jscomp$11$$.next();!$step$jscomp$27$$.done;){$stringableKeys$$=$com$cognitect$transit$impl$writer$isStringableKey$$($em$jscomp$4$$,$step$jscomp$27$$.value);if(!$stringableKeys$$)break;$step$jscomp$27$$=
$arr$jscomp$167_iter$jscomp$11$$.next()}return $stringableKeys$$}}if($i$jscomp$429_obj$jscomp$141$$.forEach)return $i$jscomp$429_obj$jscomp$141$$.forEach(function($v$jscomp$411$$,$k$jscomp$544$$){$stringableKeys$$=$stringableKeys$$&&$com$cognitect$transit$impl$writer$isStringableKey$$($em$jscomp$4$$,$k$jscomp$544$$)}),$stringableKeys$$;throw Error("Cannot walk keys of object type "+($i$jscomp$429_obj$jscomp$141$$==null?null:$i$jscomp$429_obj$jscomp$141$$.constructor).name);};
$com$cognitect$transit$impl$writer$isForeignObject$$=function($x$jscomp$1006$$){if($x$jscomp$1006$$.constructor.transit$isObject)return!0;var $isObject_ret$jscomp$131$$=$x$jscomp$1006$$.constructor.toString();$isObject_ret$jscomp$131$$=$isObject_ret$jscomp$131$$.substr(9);$isObject_ret$jscomp$131$$=$isObject_ret$jscomp$131$$.substr(0,$isObject_ret$jscomp$131$$.indexOf("("));$isObject_ret$jscomp$131$$=$isObject_ret$jscomp$131$$=="Object";typeof Object.defineProperty!="undefined"?Object.defineProperty($x$jscomp$1006$$.constructor,
"transit$isObject",{value:$isObject_ret$jscomp$131$$,enumerable:!1}):$x$jscomp$1006$$.constructor.transit$isObject=$isObject_ret$jscomp$131$$;return $isObject_ret$jscomp$131$$};
$com$cognitect$transit$impl$writer$emitMap$$=function($em$jscomp$5$$,$obj$jscomp$142$$,$cache$jscomp$90$$){var $arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$=null,$rep$jscomp$3$$=null,$tag$jscomp$41$$=null;$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$=null;var $i$jscomp$430_name$jscomp$148$$=0;if($obj$jscomp$142$$.constructor===Object||$obj$jscomp$142$$.forEach!=null||$em$jscomp$5$$.$handlerForForeign$&&$com$cognitect$transit$impl$writer$isForeignObject$$($obj$jscomp$142$$)){if($em$jscomp$5$$.$verbose$){if($obj$jscomp$142$$.forEach!=
null)if($com$cognitect$transit$impl$writer$stringableKeys$$($em$jscomp$5$$,$obj$jscomp$142$$)){var $ret$jscomp$132$$={};$obj$jscomp$142$$.forEach(function($v$jscomp$412$$,$k$jscomp$545$$){$ret$jscomp$132$$[$com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,$k$jscomp$545$$,!0,!1)]=$com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,$v$jscomp$412$$,!1,$cache$jscomp$90$$)})}else{$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$=$em$jscomp$5$$.$unpack$($obj$jscomp$142$$);$rep$jscomp$3$$=[];
$tag$jscomp$41$$=$JSCompiler_StaticMethods_emitString$$("~#","cmap","",!0,$cache$jscomp$90$$);if($arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$)for(;$i$jscomp$430_name$jscomp$148$$<$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$.length;$i$jscomp$430_name$jscomp$148$$+=2)$rep$jscomp$3$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$[$i$jscomp$430_name$jscomp$148$$],!1,!1)),$rep$jscomp$3$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,
$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$[$i$jscomp$430_name$jscomp$148$$+1],!1,$cache$jscomp$90$$));else $obj$jscomp$142$$.forEach(function($v$jscomp$413$$,$k$jscomp$546$$){$rep$jscomp$3$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,$k$jscomp$546$$,!1,!1));$rep$jscomp$3$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,$v$jscomp$413$$,!1,$cache$jscomp$90$$))});$ret$jscomp$132$$={};$ret$jscomp$132$$[$tag$jscomp$41$$]=$rep$jscomp$3$$}else for($arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$=
$com$cognitect$transit$util$objectKeys$$($obj$jscomp$142$$),$ret$jscomp$132$$={};$i$jscomp$430_name$jscomp$148$$<$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$.length;$i$jscomp$430_name$jscomp$148$$++)$ret$jscomp$132$$[$com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$[$i$jscomp$430_name$jscomp$148$$],!0,!1)]=$com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,$obj$jscomp$142$$[$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$[$i$jscomp$430_name$jscomp$148$$]],
!1,$cache$jscomp$90$$);return $ret$jscomp$132$$}if($obj$jscomp$142$$.forEach!=null){if($com$cognitect$transit$impl$writer$stringableKeys$$($em$jscomp$5$$,$obj$jscomp$142$$)){$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$=$em$jscomp$5$$.$unpack$($obj$jscomp$142$$);$ret$jscomp$132$$=["^ "];if($arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$)for(;$i$jscomp$430_name$jscomp$148$$<$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$.length;$i$jscomp$430_name$jscomp$148$$+=2)$ret$jscomp$132$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,
$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$[$i$jscomp$430_name$jscomp$148$$],!0,$cache$jscomp$90$$)),$ret$jscomp$132$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$[$i$jscomp$430_name$jscomp$148$$+1],!1,$cache$jscomp$90$$));else $obj$jscomp$142$$.forEach(function($v$jscomp$414$$,$k$jscomp$547$$){$ret$jscomp$132$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,$k$jscomp$547$$,!0,$cache$jscomp$90$$));$ret$jscomp$132$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,
$v$jscomp$414$$,!1,$cache$jscomp$90$$))});return $ret$jscomp$132$$}$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$=$em$jscomp$5$$.$unpack$($obj$jscomp$142$$);$rep$jscomp$3$$=[];$tag$jscomp$41$$=$JSCompiler_StaticMethods_emitString$$("~#","cmap","",!0,$cache$jscomp$90$$);if($arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$)for(;$i$jscomp$430_name$jscomp$148$$<$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$.length;$i$jscomp$430_name$jscomp$148$$+=2)$rep$jscomp$3$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,
$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$[$i$jscomp$430_name$jscomp$148$$],!1,$cache$jscomp$90$$)),$rep$jscomp$3$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$[$i$jscomp$430_name$jscomp$148$$+1],!1,$cache$jscomp$90$$));else $obj$jscomp$142$$.forEach(function($v$jscomp$415$$,$k$jscomp$548$$){$rep$jscomp$3$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,$k$jscomp$548$$,!1,$cache$jscomp$90$$));$rep$jscomp$3$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,
$v$jscomp$415$$,!1,$cache$jscomp$90$$))});return[$tag$jscomp$41$$,$rep$jscomp$3$$]}$ret$jscomp$132$$=["^ "];for($arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$=$com$cognitect$transit$util$objectKeys$$($obj$jscomp$142$$);$i$jscomp$430_name$jscomp$148$$<$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$.length;$i$jscomp$430_name$jscomp$148$$++)$ret$jscomp$132$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$[$i$jscomp$430_name$jscomp$148$$],!0,$cache$jscomp$90$$)),
$ret$jscomp$132$$.push($com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,$obj$jscomp$142$$[$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$[$i$jscomp$430_name$jscomp$148$$]],!1,$cache$jscomp$90$$));return $ret$jscomp$132$$}if($em$jscomp$5$$.$objectBuilder$!=null)return $em$jscomp$5$$.$objectBuilder$($obj$jscomp$142$$,function($k$jscomp$549$$){return $com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,$k$jscomp$549$$,!0,$cache$jscomp$90$$)},function($v$jscomp$416$$){return $com$cognitect$transit$impl$writer$marshal$$($em$jscomp$5$$,
$v$jscomp$416$$,!1,$cache$jscomp$90$$)});$i$jscomp$430_name$jscomp$148$$=($obj$jscomp$142$$==null?null:$obj$jscomp$142$$.constructor).name;$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$=Error("Cannot write "+$i$jscomp$430_name$jscomp$148$$);$arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$.data={$obj$:$obj$jscomp$142$$,type:$i$jscomp$430_name$jscomp$148$$};throw $arr$jscomp$168_err$jscomp$16_ks$jscomp$57$$;};
$com$cognitect$transit$impl$writer$marshal$$=function($JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$,$k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$,$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$){$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$.transform!==
null&&($k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$=$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$.transform($k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$));var $h$jscomp$129_ret$jscomp$inline_11611$$=$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$.handler($k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$)||
($JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$.$handlerForForeign$?$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$.$handlerForForeign$($k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$,$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$.$handlers$):null),$tag$jscomp$44_tag$jscomp$inline_4239$$=
$h$jscomp$129_ret$jscomp$inline_11611$$?$h$jscomp$129_ret$jscomp$inline_11611$$.tag($k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$):null,$rep$jscomp$6_rep$jscomp$inline_4240$$=$h$jscomp$129_ret$jscomp$inline_11611$$?$h$jscomp$129_ret$jscomp$inline_11611$$.rep($k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$):null;if($h$jscomp$129_ret$jscomp$inline_11611$$!=null&&$tag$jscomp$44_tag$jscomp$inline_4239$$!=null)switch($tag$jscomp$44_tag$jscomp$inline_4239$$){case "_":return $asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$?
$JSCompiler_StaticMethods_emitString$$("~","_","",$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$):null;case "s":return $rep$jscomp$6_rep$jscomp$inline_4240$$.length>0?($JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$=$rep$jscomp$6_rep$jscomp$inline_4240$$.charAt(0),$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$=
$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$==="~"||$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$==="^"||$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$==="`"?"~"+$rep$jscomp$6_rep$jscomp$inline_4240$$:$rep$jscomp$6_rep$jscomp$inline_4240$$):$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$=
$rep$jscomp$6_rep$jscomp$inline_4240$$,$JSCompiler_StaticMethods_emitString$$("","",$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$,$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$);case "?":return $asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$?$JSCompiler_StaticMethods_emitString$$("~",
"?",$rep$jscomp$6_rep$jscomp$inline_4240$$.toString()[0],$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$):$rep$jscomp$6_rep$jscomp$inline_4240$$;case "i":return $rep$jscomp$6_rep$jscomp$inline_4240$$===Infinity?$JSCompiler_StaticMethods_emitString$$("~","z","INF",$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$):
$rep$jscomp$6_rep$jscomp$inline_4240$$===-Infinity?$JSCompiler_StaticMethods_emitString$$("~","z","-INF",$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$):isNaN($rep$jscomp$6_rep$jscomp$inline_4240$$)?$JSCompiler_StaticMethods_emitString$$("~","z","NaN",$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$):
$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$||typeof $rep$jscomp$6_rep$jscomp$inline_4240$$==="string"||$rep$jscomp$6_rep$jscomp$inline_4240$$ instanceof $module$contents$goog$math$Long_Long$$?$JSCompiler_StaticMethods_emitString$$("~","i",$rep$jscomp$6_rep$jscomp$inline_4240$$.toString(),$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$):
$rep$jscomp$6_rep$jscomp$inline_4240$$;case "d":return $asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$?$JSCompiler_StaticMethods_emitString$$($rep$jscomp$6_rep$jscomp$inline_4240$$.$ESC$,"d",$rep$jscomp$6_rep$jscomp$inline_4240$$,$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$):$rep$jscomp$6_rep$jscomp$inline_4240$$;case "b":return $JSCompiler_StaticMethods_emitString$$("~",
"b",$rep$jscomp$6_rep$jscomp$inline_4240$$,$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$);case "'":return $JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$.$verbose$?($asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$={},$k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$=
$JSCompiler_StaticMethods_emitString$$("~#","'","",!0,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$),$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$[$k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$]=$com$cognitect$transit$impl$writer$marshal$$($JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$,$rep$jscomp$6_rep$jscomp$inline_4240$$,
!1,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$),$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$=$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$):$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$=[$JSCompiler_StaticMethods_emitString$$("~#",
"'","",!0,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$),$com$cognitect$transit$impl$writer$marshal$$($JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$,$rep$jscomp$6_rep$jscomp$inline_4240$$,!1,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$)],$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$;
case "array":return $com$cognitect$transit$impl$writer$emitObjects$$($JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$,$rep$jscomp$6_rep$jscomp$inline_4240$$,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$);case "map":return $com$cognitect$transit$impl$writer$emitMap$$($JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$,
$rep$jscomp$6_rep$jscomp$inline_4240$$,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$);default:a:{if($tag$jscomp$44_tag$jscomp$inline_4239$$.length===1){if(typeof $rep$jscomp$6_rep$jscomp$inline_4240$$==="string"){$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$=$JSCompiler_StaticMethods_emitString$$("~",$tag$jscomp$44_tag$jscomp$inline_4239$$,
$rep$jscomp$6_rep$jscomp$inline_4240$$,$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$);break a}if($asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$||$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$.$preferStrings$){($JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$=
$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$.$verbose$&&$h$jscomp$129_ret$jscomp$inline_11611$$.getVerboseHandler())?($tag$jscomp$44_tag$jscomp$inline_4239$$=$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$.tag($k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$),$rep$jscomp$6_rep$jscomp$inline_4240$$=$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$.stringRep($k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$,
$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$)):$rep$jscomp$6_rep$jscomp$inline_4240$$=$h$jscomp$129_ret$jscomp$inline_11611$$.stringRep($k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$,$h$jscomp$129_ret$jscomp$inline_11611$$);if($rep$jscomp$6_rep$jscomp$inline_4240$$!==null){$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$=
$JSCompiler_StaticMethods_emitString$$("~",$tag$jscomp$44_tag$jscomp$inline_4239$$,$rep$jscomp$6_rep$jscomp$inline_4240$$,$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$);break a}$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$=Error('Tag "'+$tag$jscomp$44_tag$jscomp$inline_4239$$+
'" cannot be encoded as string');$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$.data={tag:$tag$jscomp$44_tag$jscomp$inline_4239$$,rep:$rep$jscomp$6_rep$jscomp$inline_4240$$,$obj$:$k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$};throw $JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$;}}$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$=
$tag$jscomp$44_tag$jscomp$inline_4239$$;$k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$=$rep$jscomp$6_rep$jscomp$inline_4240$$;$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$.$verbose$?($h$jscomp$129_ret$jscomp$inline_11611$$={},$h$jscomp$129_ret$jscomp$inline_11611$$[$JSCompiler_StaticMethods_emitString$$("~#",$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$,"",!0,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$)]=
$com$cognitect$transit$impl$writer$marshal$$($JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$,$k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$,!1,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$),$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$=
$h$jscomp$129_ret$jscomp$inline_11611$$):$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$=[$JSCompiler_StaticMethods_emitString$$("~#",$asMapKey$jscomp$17_ret$jscomp$inline_4234_tag$jscomp$inline_11608$$,"",!0,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$),$com$cognitect$transit$impl$writer$marshal$$($JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$,
$k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$,!1,$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$)]}return $JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$}else throw $JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$=($k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$==
null?null:$k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$.constructor).name,$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$=Error("Cannot write "+$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$),$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$.data={$obj$:$k$jscomp$inline_4235_obj$jscomp$144_obj$jscomp$inline_4241_rep$jscomp$inline_11609$$,
type:$JSCompiler_inline_result$jscomp$583_JSCompiler_inline_result$jscomp$584_cache$jscomp$93_err$jscomp$inline_4245_name$jscomp$149$$},$JSCompiler_inline_result$jscomp$579_c$jscomp$inline_4213_em$jscomp$8_err$jscomp$18_vh$jscomp$inline_4244$$;};$com$cognitect$transit$impl$writer$Writer$$=function($marshaller$$,$options$jscomp$412$$){this.$_marshaller$=$marshaller$$;this.options=$options$jscomp$412$$||{};this.cache=this.options.cache===!1?null:this.options.cache?this.options.cache:new $com$cognitect$transit$caching$WriteCache$$};
$com$cognitect$transit$reader$$=function($type$jscomp$239_unmarshaller$jscomp$1$$,$opts$jscomp$246$$){if($type$jscomp$239_unmarshaller$jscomp$1$$==="json"||$type$jscomp$239_unmarshaller$jscomp$1$$==="json-verbose"||$type$jscomp$239_unmarshaller$jscomp$1$$==null)return $type$jscomp$239_unmarshaller$jscomp$1$$=new $com$cognitect$transit$impl$reader$JSONUnmarshaller$$($opts$jscomp$246$$),new $com$cognitect$transit$impl$reader$Reader$$($type$jscomp$239_unmarshaller$jscomp$1$$,$opts$jscomp$246$$);throw Error("Cannot create reader of type "+
$type$jscomp$239_unmarshaller$jscomp$1$$);};
$com$cognitect$transit$writer$$=function($marshaller$jscomp$1_type$jscomp$240$$,$err$jscomp$20_opts$jscomp$247$$){if($marshaller$jscomp$1_type$jscomp$240$$==="json"||$marshaller$jscomp$1_type$jscomp$240$$==="json-verbose"||$marshaller$jscomp$1_type$jscomp$240$$==null)return $marshaller$jscomp$1_type$jscomp$240$$==="json-verbose"&&($err$jscomp$20_opts$jscomp$247$$==null&&($err$jscomp$20_opts$jscomp$247$$={}),$err$jscomp$20_opts$jscomp$247$$.verbose=!0),$marshaller$jscomp$1_type$jscomp$240$$=new $com$cognitect$transit$impl$writer$JSONMarshaller$$($err$jscomp$20_opts$jscomp$247$$),
new $com$cognitect$transit$impl$writer$Writer$$($marshaller$jscomp$1_type$jscomp$240$$,$err$jscomp$20_opts$jscomp$247$$);$err$jscomp$20_opts$jscomp$247$$=Error('Type must be "json"');$err$jscomp$20_opts$jscomp$247$$.data={type:$marshaller$jscomp$1_type$jscomp$240$$};throw $err$jscomp$20_opts$jscomp$247$$;};
$cognitect$transit$opts_merge$$=function($a$jscomp$309$$,$b$jscomp$235$$){for(var $c__5548__auto___40312_k_40318_seq__40108_40300_temp__5825__auto___40310$$=$APP.$cljs$core$seq$$($module$contents$goog$object_getKeys$$($b$jscomp$235$$)),$G__40314_chunk__40109_40301_seq__40108_40311__$1$$=null,$G__40315_count__40110_40302$$=0,$G__40313_i__40111_40303$$=0;;)if($G__40313_i__40111_40303$$<$G__40315_count__40110_40302$$){var $k_40304$$=$G__40314_chunk__40109_40301_seq__40108_40311__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$G__40313_i__40111_40303$$);$a$jscomp$309$$[$k_40304$$]=$APP.$module$contents$goog$object_get$$($b$jscomp$235$$,$k_40304$$);$G__40313_i__40111_40303$$+=1}else if($c__5548__auto___40312_k_40318_seq__40108_40300_temp__5825__auto___40310$$=$APP.$cljs$core$seq$$($c__5548__auto___40312_k_40318_seq__40108_40300_temp__5825__auto___40310$$))$G__40314_chunk__40109_40301_seq__40108_40311__$1$$=$c__5548__auto___40312_k_40318_seq__40108_40300_temp__5825__auto___40310$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__40314_chunk__40109_40301_seq__40108_40311__$1$$)?
($c__5548__auto___40312_k_40318_seq__40108_40300_temp__5825__auto___40310$$=$APP.$cljs$core$_chunked_first$$($G__40314_chunk__40109_40301_seq__40108_40311__$1$$),$G__40313_i__40111_40303$$=$APP.$cljs$core$_chunked_rest$$($G__40314_chunk__40109_40301_seq__40108_40311__$1$$),$G__40314_chunk__40109_40301_seq__40108_40311__$1$$=$c__5548__auto___40312_k_40318_seq__40108_40300_temp__5825__auto___40310$$,$G__40315_count__40110_40302$$=$APP.$cljs$core$count$$($c__5548__auto___40312_k_40318_seq__40108_40300_temp__5825__auto___40310$$),
$c__5548__auto___40312_k_40318_seq__40108_40300_temp__5825__auto___40310$$=$G__40313_i__40111_40303$$):($c__5548__auto___40312_k_40318_seq__40108_40300_temp__5825__auto___40310$$=$APP.$cljs$core$first$$($G__40314_chunk__40109_40301_seq__40108_40311__$1$$),$a$jscomp$309$$[$c__5548__auto___40312_k_40318_seq__40108_40300_temp__5825__auto___40310$$]=$APP.$module$contents$goog$object_get$$($b$jscomp$235$$,$c__5548__auto___40312_k_40318_seq__40108_40300_temp__5825__auto___40310$$),$c__5548__auto___40312_k_40318_seq__40108_40300_temp__5825__auto___40310$$=
$APP.$cljs$core$next$$($G__40314_chunk__40109_40301_seq__40108_40311__$1$$),$G__40314_chunk__40109_40301_seq__40108_40311__$1$$=null,$G__40315_count__40110_40302$$=0),$G__40313_i__40111_40303$$=0;else break;return $a$jscomp$309$$};$cognitect$transit$MapBuilder$$=function(){};$cognitect$transit$VectorBuilder$$=function(){};
$cognitect$transit$reader$cljs$0core$0IFn$0_invoke$0arity$02$$=function($type$jscomp$242$$,$opts$jscomp$248$$){return $com$cognitect$transit$reader$$($APP.$cljs$core$name$$($type$jscomp$242$$),$cognitect$transit$opts_merge$$({handlers:$APP.$cljs$core$clj__GT_js$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,6,["$",function($v$jscomp$421$$){return $APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$421$$)},
":",function($v$jscomp$422$$){return $APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$422$$)},"set",function($v$jscomp$423$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$v$jscomp$423$$)},"list",function($v$jscomp$424$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$List$EMPTY$$,$v$jscomp$424$$.reverse())},"cmap",function($v$jscomp$425$$){for(var $i$jscomp$431$$=0,$G__40342_ret$jscomp$137$$=
$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);;)if($i$jscomp$431$$<$v$jscomp$425$$.length){var $G__40341$$=$i$jscomp$431$$+2;$G__40342_ret$jscomp$137$$=$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($G__40342_ret$jscomp$137$$,$v$jscomp$425$$[$i$jscomp$431$$],$v$jscomp$425$$[$i$jscomp$431$$+1]);$i$jscomp$431$$=$G__40341$$}else return $APP.$cljs$core$_persistent_BANG_$$($G__40342_ret$jscomp$137$$)},"with-meta",function($v$jscomp$426$$){return $APP.$cljs$core$with_meta$$($v$jscomp$426$$[0],
$v$jscomp$426$$[1])}],null),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1299$handlers$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$248$$),$APP.$cljs$cst$205$default$$)]))),defaultHandler:$APP.$cljs$cst$205$default$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1299$handlers$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$248$$)),mapBuilder:new $cognitect$transit$MapBuilder$$,arrayBuilder:new $cognitect$transit$VectorBuilder$$,preferStrings:!1,preferBuffers:!1},$APP.$cljs$core$clj__GT_js$$($APP.$clojure$set$rename_keys$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($opts$jscomp$248$$,
$APP.$cljs$cst$1299$handlers$$),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1300$array_builder$$,$cljs$cst$1301$arrayBuilder$$,$cljs$cst$1302$map_builder$$,$cljs$cst$1303$mapBuilder$$,$cljs$cst$1304$prefer_strings$$,$cljs$cst$1305$preferStrings$$,$cljs$cst$1306$prefer_buffers$$,$cljs$cst$1307$preferBuffers$$],null)))))};$cognitect$transit$KeywordHandler$$=function(){};$cognitect$transit$SymbolHandler$$=function(){};$cognitect$transit$ListHandler$$=function(){};
$cognitect$transit$MapHandler$$=function(){};$cognitect$transit$SetHandler$$=function(){};$cognitect$transit$VectorHandler$$=function(){};$cognitect$transit$UUIDHandler$$=function(){};$cognitect$transit$WithMeta$$=function($value$jscomp$361$$,$meta$jscomp$75$$){this.value=$value$jscomp$361$$;this.$meta$=$meta$jscomp$75$$};$cognitect$transit$WithMetaHandler$$=function(){};
$cognitect$transit$writer$cljs$0core$0IFn$0_invoke$0arity$02$$=function($type$jscomp$244$$,$opts$jscomp$249$$){var $list_handler$$=new $cognitect$transit$ListHandler$$,$map_handler$$=new $cognitect$transit$MapHandler$$,$set_handler$$=new $cognitect$transit$SetHandler$$,$vector_handler$$=new $cognitect$transit$VectorHandler$$,$handlers$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$core$PersistentHashMap$$,
$APP.$cljs$core$Cons$$,$APP.$cljs$core$PersistentArrayMap$$,$APP.$cljs$core$NodeSeq$$,$cljs$core$PersistentQueue$$,$APP.$cljs$core$IndexedSeq$$,$APP.$cljs$core$Keyword$$,$APP.$cljs$core$BlackNode$$,$cljs$core$EmptyList$$,$APP.$cljs$core$LazySeq$$,$APP.$cljs$core$Subvec$$,$cljs$core$PersistentQueueSeq$$,$APP.$cljs$core$ArrayNodeSeq$$,$cljs$core$ValSeq$$,$cognitect$transit$WithMeta$$,$APP.$cljs$core$PersistentArrayMapSeq$$,$APP.$cljs$core$PersistentVector$$,$APP.$cljs$core$List$$,$APP.$cljs$core$RSeq$$,
$APP.$cljs$core$PersistentHashSet$$,$APP.$cljs$core$PersistentTreeMap$$,$cljs$core$KeySeq$$,$APP.$cljs$core$ChunkedSeq$$,$cljs$core$PersistentTreeSet$$,$APP.$cljs$core$ChunkedCons$$,$APP.$cljs$core$Symbol$$,$cljs$core$UUID$$,$cljs$core$Range$$,$cljs$core$PersistentTreeMapSeq$$,$APP.$cljs$core$RedNode$$],[$map_handler$$,$list_handler$$,$map_handler$$,$list_handler$$,$list_handler$$,$list_handler$$,new $cognitect$transit$KeywordHandler$$,$vector_handler$$,$list_handler$$,$list_handler$$,$vector_handler$$,
$list_handler$$,$list_handler$$,$list_handler$$,new $cognitect$transit$WithMetaHandler$$,$list_handler$$,$vector_handler$$,$list_handler$$,$list_handler$$,$set_handler$$,$map_handler$$,$list_handler$$,$list_handler$$,$set_handler$$,$list_handler$$,new $cognitect$transit$SymbolHandler$$,new $cognitect$transit$UUIDHandler$$,$list_handler$$,$list_handler$$,$vector_handler$$]),typeof $cljs$$!=="undefined"&&typeof $cljs$core$$!=="undefined"&&typeof $cljs$core$Eduction$$!=="undefined"?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$cljs$core$Eduction$$,
$list_handler$$]):null,typeof $cljs$$!=="undefined"&&typeof $cljs$core$$!=="undefined"&&typeof $cljs$core$Repeat$$!=="undefined"?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$cljs$core$Repeat$$,$list_handler$$]):null,typeof $cljs$$!=="undefined"&&typeof $cljs$core$$!=="undefined"&&typeof $APP.$cljs$core$MapEntry$$!=="undefined"?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$APP.$cljs$core$MapEntry$$,$vector_handler$$]):null,$APP.$cljs$cst$1299$handlers$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$249$$)]));
return $com$cognitect$transit$writer$$($APP.$cljs$core$name$$($type$jscomp$244$$),$cognitect$transit$opts_merge$$({objectBuilder:function($m$jscomp$167$$,$kfn$jscomp$4$$,$vfn$jscomp$4$$){return $APP.$cljs$core$reduce_kv$$(function($obj$jscomp$151$$,$k$jscomp$552$$,$v$jscomp$451$$){$obj$jscomp$151$$.push($kfn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$kfn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$552$$):$kfn$jscomp$4$$($k$jscomp$552$$),$vfn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$vfn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$451$$):
$vfn$jscomp$4$$($v$jscomp$451$$));return $obj$jscomp$151$$},["^ "],$m$jscomp$167$$)},handlers:function(){var $x40211$$=$cljs$core$_clone$$($handlers$$);$x40211$$.forEach=function($f$jscomp$595$$){for(var $G__40447_seq__40214_seq__40214__$1_temp__5825__auto__$jscomp$86$$=$APP.$cljs$core$seq$$(this),$c__5548__auto__$jscomp$10_chunk__40215_vec__40230$$=null,$G__40449_count__40216$$=0,$i__40217$$=0;;)if($i__40217$$<$G__40449_count__40216$$){var $v$jscomp$452_vec__40227$$=$c__5548__auto__$jscomp$10_chunk__40215_vec__40230$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$i__40217$$),$G__40448_k$jscomp$553$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$452_vec__40227$$,0,null);$v$jscomp$452_vec__40227$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$452_vec__40227$$,1,null);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$205$default$$,$G__40448_k$jscomp$553$$)?$f$jscomp$595$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$595$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$452_vec__40227$$,"default"):$f$jscomp$595$$($v$jscomp$452_vec__40227$$,
"default"):$f$jscomp$595$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$595$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$452_vec__40227$$,$G__40448_k$jscomp$553$$):$f$jscomp$595$$($v$jscomp$452_vec__40227$$,$G__40448_k$jscomp$553$$);$i__40217$$+=1}else if($G__40447_seq__40214_seq__40214__$1_temp__5825__auto__$jscomp$86$$=$APP.$cljs$core$seq$$($G__40447_seq__40214_seq__40214__$1_temp__5825__auto__$jscomp$86$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__40447_seq__40214_seq__40214__$1_temp__5825__auto__$jscomp$86$$)?
($c__5548__auto__$jscomp$10_chunk__40215_vec__40230$$=$APP.$cljs$core$_chunked_first$$($G__40447_seq__40214_seq__40214__$1_temp__5825__auto__$jscomp$86$$),$G__40447_seq__40214_seq__40214__$1_temp__5825__auto__$jscomp$86$$=$APP.$cljs$core$_chunked_rest$$($G__40447_seq__40214_seq__40214__$1_temp__5825__auto__$jscomp$86$$),$G__40448_k$jscomp$553$$=$c__5548__auto__$jscomp$10_chunk__40215_vec__40230$$,$G__40449_count__40216$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$10_chunk__40215_vec__40230$$),
$c__5548__auto__$jscomp$10_chunk__40215_vec__40230$$=$G__40448_k$jscomp$553$$):($c__5548__auto__$jscomp$10_chunk__40215_vec__40230$$=$APP.$cljs$core$first$$($G__40447_seq__40214_seq__40214__$1_temp__5825__auto__$jscomp$86$$),$G__40448_k$jscomp$553$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$10_chunk__40215_vec__40230$$,0,null),$v$jscomp$452_vec__40227$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$10_chunk__40215_vec__40230$$,
1,null),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$205$default$$,$G__40448_k$jscomp$553$$)?$f$jscomp$595$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$595$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$452_vec__40227$$,"default"):$f$jscomp$595$$($v$jscomp$452_vec__40227$$,"default"):$f$jscomp$595$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$595$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$452_vec__40227$$,$G__40448_k$jscomp$553$$):$f$jscomp$595$$($v$jscomp$452_vec__40227$$,$G__40448_k$jscomp$553$$),
$G__40447_seq__40214_seq__40214__$1_temp__5825__auto__$jscomp$86$$=$APP.$cljs$core$next$$($G__40447_seq__40214_seq__40214__$1_temp__5825__auto__$jscomp$86$$),$c__5548__auto__$jscomp$10_chunk__40215_vec__40230$$=null,$G__40449_count__40216$$=0),$i__40217$$=0;else return null};return $x40211$$}(),unpack:function($x$jscomp$1008$$){return $x$jscomp$1008$$ instanceof $APP.$cljs$core$PersistentArrayMap$$?$x$jscomp$1008$$.$arr$:!1}},$APP.$cljs$core$clj__GT_js$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($opts$jscomp$249$$,
$APP.$cljs$cst$1299$handlers$$))))};$cognitect$transit$fn_or_val$$=function($f$jscomp$596$$){return $APP.$cljs$core$fn_QMARK_$$($f$jscomp$596$$)?$f$jscomp$596$$:$APP.$cljs$core$constantly$$($f$jscomp$596$$)};
$cognitect$transit$t_cognitect$0transit40239$$=function($tag_fn$$,$rep_fn$$,$str_rep_fn$$,$verbose_handler_fn$$,$meta40240$$){this.$tag_fn$=$tag_fn$$;this.$rep_fn$=$rep_fn$$;this.$str_rep_fn$=$str_rep_fn$$;this.$verbose_handler_fn$=$verbose_handler_fn$$;this.$meta40240$=$meta40240$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$cognitect$transit$write_handler$cljs$0core$0IFn$0_invoke$0arity$04$$=function($tag_fn$jscomp$4_tag_fn__$1$$,$rep_fn$jscomp$4_rep_fn__$1$$){$tag_fn$jscomp$4_tag_fn__$1$$=$cognitect$transit$fn_or_val$$($tag_fn$jscomp$4_tag_fn__$1$$);$rep_fn$jscomp$4_rep_fn__$1$$=$cognitect$transit$fn_or_val$$($rep_fn$jscomp$4_rep_fn__$1$$);var $str_rep_fn__$1$$=$cognitect$transit$fn_or_val$$(null),$verbose_handler_fn__$1$$=$cognitect$transit$fn_or_val$$(null);return new $cognitect$transit$t_cognitect$0transit40239$$($tag_fn$jscomp$4_tag_fn__$1$$,
$rep_fn$jscomp$4_rep_fn__$1$$,$str_rep_fn__$1$$,$verbose_handler_fn__$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cognitect$transit$write_meta$$=function($x$jscomp$1020$$){if($x$jscomp$1020$$!=null&&($x$jscomp$1020$$.$cljs$lang$protocol_mask$partition0$$&131072||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$1020$$.$cljs$core$IMeta$$)){var $m$jscomp$168$$=$x$jscomp$1020$$.$cljs$core$IMeta$_meta$arity$1$(null);return $m$jscomp$168$$!=null?new $cognitect$transit$WithMeta$$($x$jscomp$1020$$.$cljs$core$IWithMeta$_with_meta$arity$2$(null,null),$m$jscomp$168$$):$x$jscomp$1020$$}return $x$jscomp$1020$$};
$app$common$transit$Pointer$$=function($id$jscomp$35$$,$metadata$$){this.id=$id$jscomp$35$$;this.metadata=$metadata$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0};$APP.$app$common$transit$pointer_QMARK_$$=function($o$jscomp$208$$){return $o$jscomp$208$$ instanceof $app$common$transit$Pointer$$};
$APP.$app$common$transit$add_handlers_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($cwh_handlers$jscomp$1_whs$$){function $merge_and_clean$$($m1$jscomp$3$$,$m2$jscomp$3$$){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$m1$jscomp$3$$,$m2$jscomp$3$$])))}var $crh_rhs$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1315$rfn$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($id$jscomp$38_p__40381$$){var $map__40382__$1_rfn$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$38_p__40381$$);$id$jscomp$38_p__40381$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40382__$1_rfn$$,$APP.$cljs$cst$266$id$$);$map__40382__$1_rfn$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40382__$1_rfn$$,
$APP.$cljs$cst$1315$rfn$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$38_p__40381$$,$map__40382__$1_rfn$$],null)})),$cwh_handlers$jscomp$1_whs$$);$cwh_handlers$jscomp$1_whs$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1314$wfn$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($id$jscomp$37_p__40378$$){var $map__40379__$1_wfn$$=
$APP.$cljs$core$__destructure_map$$($id$jscomp$37_p__40378$$);$id$jscomp$37_p__40378$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40379__$1_wfn$$,$APP.$cljs$cst$266$id$$);var $class$$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40379__$1_wfn$$,$APP.$cljs$cst$1291$class$$);$map__40379__$1_wfn$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40379__$1_wfn$$,$APP.$cljs$cst$1314$wfn$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$class$$jscomp$1$$,$cognitect$transit$write_handler$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$core$constantly$$($id$jscomp$37_p__40378$$),$map__40379__$1_wfn$$)],null)})),$cwh_handlers$jscomp$1_whs$$);$cwh_handlers$jscomp$1_whs$$=$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$common$transit$write_handlers$$,$merge_and_clean$$,$cwh_handlers$jscomp$1_whs$$);$crh_rhs$$=$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$common$transit$read_handlers$$,$merge_and_clean$$,
$crh_rhs$$);$APP.$cljs$core$reset_BANG_$$($app$common$transit$write_handler_map$$,$cwh_handlers$jscomp$1_whs$$);$APP.$cljs$core$reset_BANG_$$($app$common$transit$read_handler_map$$,$crh_rhs$$)};
$APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$=function($data$jscomp$111$$,$opts$jscomp$250_params__$1$jscomp$3$$){var $type$jscomp$245$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$2$($opts$jscomp$250_params__$1$jscomp$3$$,$cljs$cst$923$json$$),$params$jscomp$14$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1299$handlers$$,$APP.$cljs$core$_deref$$($app$common$transit$write_handler_map$$),$cljs$cst$1316$handlerForForeign$$,function($x$jscomp$1021$$){return $x$jscomp$1021$$!=
null&&$APP.$cljs$core$fn_QMARK_$$($x$jscomp$1021$$.getTime)&&$x$jscomp$1021$$.getTime()!=null?$app$common$transit$date_write_handler$$:null}],null);$opts$jscomp$250_params__$1$jscomp$3$$=$APP.$cljs$core$truth_$$($cljs$cst$1317$with_meta$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$250_params__$1$jscomp$3$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($params$jscomp$14$$,$APP.$cljs$cst$1289$transform$$,$cognitect$transit$write_meta$$):$params$jscomp$14$$;return $cognitect$transit$writer$cljs$0core$0IFn$0_invoke$0arity$02$$($type$jscomp$245$$,
$opts$jscomp$250_params__$1$jscomp$3$$).write($data$jscomp$111$$)};
$beicon$v2$operators$scheduler$$=function($G__40245__$1_type$jscomp$247$$){$G__40245__$1_type$jscomp$247$$=$G__40245__$1_type$jscomp$247$$ instanceof $APP.$cljs$core$Keyword$$?$G__40245__$1_type$jscomp$247$$.$fqn$:null;switch($G__40245__$1_type$jscomp$247$$){case "asap":return $APP.$shadow$js$shim$module$0rxjs$$.asapScheduler;case "async":return $APP.$shadow$js$shim$module$0rxjs$$.asyncScheduler;case "queue":return $APP.$shadow$js$shim$module$0rxjs$$.queueScheduler;case "af":return $APP.$shadow$js$shim$module$0rxjs$$.animationFrameScheduler;
case "animation-frame":return $APP.$shadow$js$shim$module$0rxjs$$.animationFrameScheduler;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__40245__$1_type$jscomp$247$$)].join(""));}};
$beicon$v2$operators$filter$$=function($f$jscomp$597$$){return $APP.$shadow$js$shim$module$0rxjs$$.filter(function($p1__40251_SHARP_$$){return $APP.$cljs$core$boolean$0$$($f$jscomp$597$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$597$$.$cljs$core$IFn$_invoke$arity$1$($p1__40251_SHARP_$$):$f$jscomp$597$$($p1__40251_SHARP_$$))})};
$beicon$v2$operators$map$$=function($f$jscomp$598$$){return $APP.$shadow$js$shim$module$0rxjs$$.map(function($p1__40252_SHARP_$$){return $f$jscomp$598$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$598$$.$cljs$core$IFn$_invoke$arity$1$($p1__40252_SHARP_$$):$f$jscomp$598$$($p1__40252_SHARP_$$)})};
$beicon$v2$operators$merge_map$cljs$0core$0IFn$0_invoke$0arity$01$$=function($f$jscomp$600$$){return $APP.$shadow$js$shim$module$0rxjs$$.mergeMap(function($p1__40269_SHARP_$$){return $f$jscomp$600$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$600$$.$cljs$core$IFn$_invoke$arity$1$($p1__40269_SHARP_$$):$f$jscomp$600$$($p1__40269_SHARP_$$)})};
$beicon$v2$operators$switch_map$$=function($f$jscomp$602$$){return $APP.$shadow$js$shim$module$0rxjs$$.switchMap(function($p1__40287_SHARP_$$){return $f$jscomp$602$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$602$$.$cljs$core$IFn$_invoke$arity$1$($p1__40287_SHARP_$$):$f$jscomp$602$$($p1__40287_SHARP_$$)})};
$beicon$v2$operators$mapcat$$=function($f$jscomp$603$$){return $APP.$shadow$js$shim$module$0rxjs$$.concatMap(function($p1__40289_SHARP_$$){return $f$jscomp$603$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$603$$.$cljs$core$IFn$_invoke$arity$1$($p1__40289_SHARP_$$):$f$jscomp$603$$($p1__40289_SHARP_$$)})};
$beicon$v2$operators$take_while$$=function($f$jscomp$606$$){return $APP.$shadow$js$shim$module$0rxjs$$.takeWhile(function($p1__40317_SHARP_$$){return $APP.$cljs$core$boolean$0$$($f$jscomp$606$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$606$$.$cljs$core$IFn$_invoke$arity$1$($p1__40317_SHARP_$$):$f$jscomp$606$$($p1__40317_SHARP_$$))})};
$beicon$v2$operators$reduce$cljs$0core$0IFn$0_invoke$0arity$01$$=function($f$jscomp$607$$){return $APP.$shadow$js$shim$module$0rxjs$$.reduce(function($p1__40324_SHARP_$$,$p2__40325_SHARP_$$){return $f$jscomp$607$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$607$$.$cljs$core$IFn$_invoke$arity$2$($p1__40324_SHARP_$$,$p2__40325_SHARP_$$):$f$jscomp$607$$($p1__40324_SHARP_$$,$p2__40325_SHARP_$$)})};
$beicon$v2$operators$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$608$$,$seed$jscomp$15$$){return $APP.$shadow$js$shim$module$0rxjs$$.reduce(function($p1__40326_SHARP_$$,$p2__40327_SHARP_$$){return $f$jscomp$608$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$608$$.$cljs$core$IFn$_invoke$arity$2$($p1__40326_SHARP_$$,$p2__40327_SHARP_$$):$f$jscomp$608$$($p1__40326_SHARP_$$,$p2__40327_SHARP_$$)},$seed$jscomp$15$$)};
$beicon$v2$operators$scan$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$610$$,$seed$jscomp$16$$){return $APP.$shadow$js$shim$module$0rxjs$$.scan(function($p1__40338_SHARP_$$,$p2__40339_SHARP_$$){return $f$jscomp$610$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$610$$.$cljs$core$IFn$_invoke$arity$2$($p1__40338_SHARP_$$,$p2__40339_SHARP_$$):$f$jscomp$610$$($p1__40338_SHARP_$$,$p2__40339_SHARP_$$)},$seed$jscomp$16$$)};
$beicon$v2$operators$with_latest$$=function(...$args$jscomp$207$$){const $resultSelector$$=typeof $args$jscomp$207$$[0]==="function"?$args$jscomp$207$$.shift():void 0;return $resultSelector$$===void 0?$APP.$shadow$js$shim$module$0rxjs$$.withLatestFrom(...$args$jscomp$207$$):$APP.$shadow$js$shim$module$0rxjs$$.withLatestFrom(...$args$jscomp$207$$,$resultSelector$$)};
$beicon$v2$operators$catch$0$$=function($handler$jscomp$17$$){return $APP.$shadow$js$shim$module$0rxjs$$.catchError(function($error$jscomp$34_value$jscomp$364$$,$source$jscomp$25$$){$error$jscomp$34_value$jscomp$364$$=$handler$jscomp$17$$.$cljs$core$IFn$_invoke$arity$2$?$handler$jscomp$17$$.$cljs$core$IFn$_invoke$arity$2$($error$jscomp$34_value$jscomp$364$$,$source$jscomp$25$$):$handler$jscomp$17$$($error$jscomp$34_value$jscomp$364$$,$source$jscomp$25$$);return $error$jscomp$34_value$jscomp$364$$ instanceof
$APP.$shadow$js$shim$module$0rxjs$$.Observable?$error$jscomp$34_value$jscomp$364$$:$APP.$shadow$js$shim$module$0rxjs$$.EMPTY})};$APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$=function(){return $APP.$shadow$js$shim$module$0rxjs$$.distinctUntilChanged()};
$beicon$v2$operators$timeout$cljs$0core$0IFn$0_invoke$0arity$02$$=function($with$$$){return $APP.$shadow$js$shim$module$0rxjs$$.timeout({each:400,"with":$with$$$ instanceof $APP.$shadow$js$shim$module$0rxjs$$.Observable?function(){return $with$$$}:$with$$$})};$APP.$beicon$v2$operators$pipe$$=function(...$fns$$){const $input$jscomp$64$$=$fns$$.pop();return $fns$$.reduce(($prev$jscomp$6$$,$fn$jscomp$20$$)=>$fn$jscomp$20$$($prev$jscomp$6$$),$input$jscomp$64$$)};
$beicon$v2$operators$comp$$=function(...$fns$jscomp$1$$){return $source$jscomp$27$$=>$fns$jscomp$1$$.reduce(($prev$jscomp$7$$,$fn$jscomp$21$$)=>$fn$jscomp$21$$($prev$jscomp$7$$),$source$jscomp$27$$)};
$beicon$v2$operators$observe_on$cljs$0core$0IFn$0_invoke$0arity$01$$=function($sch$$){if($sch$$ instanceof $APP.$shadow$js$shim$module$0rxjs$$.Scheduler)return $APP.$shadow$js$shim$module$0rxjs$$.observeOn($sch$$);if($sch$$ instanceof $APP.$cljs$core$Keyword$$)return $beicon$v2$operators$observe_on$cljs$0core$0IFn$0_invoke$0arity$01$$($beicon$v2$operators$scheduler$$($sch$$));throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("invalid arguments",new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$1324$sch$$,$sch$$],null));};$beicon$v2$core$push_BANG_$$=function($b$jscomp$237$$,$v$jscomp$456$$){return $b$jscomp$237$$.next($v$jscomp$456$$)};$APP.$beicon$v2$core$create$$=function($sf$$){return new $beicon$v2$core$Observable$$(function($subs$jscomp$5$$){try{return $sf$$.$cljs$core$IFn$_invoke$arity$1$?$sf$$.$cljs$core$IFn$_invoke$arity$1$($subs$jscomp$5$$):$sf$$($subs$jscomp$5$$)}catch($e40616$$){return $subs$jscomp$5$$.error($e40616$$)}})};$APP.$beicon$v2$core$subject$$=function(){return new $beicon$v2$core$Subject$$};
$APP.$beicon$v2$core$behavior_subject$$=function($v$jscomp$459$$){return new $beicon$v2$core$BehaviorSubject$$($v$jscomp$459$$)};$APP.$beicon$v2$core$from$$=function($v$jscomp$460$$){return $v$jscomp$460$$==null?$APP.$shadow$js$shim$module$0rxjs$$.EMPTY:$APP.$shadow$js$shim$module$0rxjs$$.from($v$jscomp$460$$)};
$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$=function($atm$jscomp$1$$,$map__40650__$1_p__40648$$){$map__40650__$1_p__40648$$=$APP.$cljs$core$__destructure_map$$($map__40650__$1_p__40648$$);var $emit_current_value_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__40650__$1_p__40648$$,$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!1);return $APP.$beicon$v2$core$create$$(function($subs$jscomp$6$$){var $JSCompiler_temp_const$jscomp$10652$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$;
$cljs$core$gensym_counter$$==null&&($cljs$core$gensym_counter$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(0));var $JSCompiler_inline_result$jscomp$10654$$=$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$("beicon"),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$gensym_counter$$,$APP.$cljs$core$inc$$))].join(""));var $key$jscomp$268$$=$JSCompiler_temp_const$jscomp$10652$$.call($APP.$cljs$core$keyword$$,
$JSCompiler_inline_result$jscomp$10654$$);$APP.$cljs$core$truth_$$($emit_current_value_QMARK_$$)&&$subs$jscomp$6$$.next($APP.$cljs$core$_deref$$($atm$jscomp$1$$));$APP.$cljs$core$add_watch$$($atm$jscomp$1$$,$key$jscomp$268$$,function($_$jscomp$985$$,$___$1$jscomp$639$$,$___$2$jscomp$73$$,$val$jscomp$144$$){return $subs$jscomp$6$$.next($val$jscomp$144$$)});return function(){return $APP.$cljs$core$remove_watch$$($atm$jscomp$1$$,$key$jscomp$268$$)}})};$APP.$beicon$v2$core$empty$$=function(){return $APP.$shadow$js$shim$module$0rxjs$$.EMPTY};
$APP.$beicon$v2$core$throw$0$$=function($e$jscomp$205$$){return $APP.$cljs$core$fn_QMARK_$$($e$jscomp$205$$)?$APP.$shadow$js$shim$module$0rxjs$$.throwError($e$jscomp$205$$):$APP.$shadow$js$shim$module$0rxjs$$.throwError(function(){return $e$jscomp$205$$})};
$APP.$beicon$v2$core$zip$$=function(...$sources$jscomp$2$$){const $projectFunction$$=typeof $sources$jscomp$2$$[0]==="function"?$sources$jscomp$2$$.shift():void 0;return $projectFunction$$===void 0?$APP.$shadow$js$shim$module$0rxjs$$.zip(...$sources$jscomp$2$$):$APP.$shadow$js$shim$module$0rxjs$$.zip(...$sources$jscomp$2$$,$projectFunction$$)};$APP.$beicon$v2$core$concat$$=function(...$args$jscomp$209$$){$args$jscomp$209$$=$args$jscomp$209$$.filter($APP.$cljs$core$some_QMARK_$$);return $APP.$shadow$js$shim$module$0rxjs$$.concat(...$args$jscomp$209$$)};
$APP.$beicon$v2$core$merge$$=function(...$args$jscomp$210_sources$jscomp$3$$){$args$jscomp$210_sources$jscomp$3$$=$args$jscomp$210_sources$jscomp$3$$.filter($APP.$cljs$core$some_QMARK_$$);return $args$jscomp$210_sources$jscomp$3$$.length?$args$jscomp$210_sources$jscomp$3$$.length===1?$APP.$shadow$js$shim$module$0rxjs$$.from($args$jscomp$210_sources$jscomp$3$$[0]):$APP.$shadow$js$shim$module$0rxjs$$.mergeAll(Infinity)($APP.$shadow$js$shim$module$0rxjs$$.from($args$jscomp$210_sources$jscomp$3$$)):$APP.$shadow$js$shim$module$0rxjs$$.EMPTY};
$APP.$beicon$v2$core$combine_latest$$=function(...$sources$jscomp$4$$){const $projectFunction$jscomp$1$$=typeof $sources$jscomp$4$$[0]==="function"?$sources$jscomp$4$$.shift():void 0;return $APP.$shadow$js$shim$module$0rxjs$$.combineLatest($sources$jscomp$4$$,$projectFunction$jscomp$1$$)};
$APP.$beicon$v2$core$_dispose$$=function($JSCompiler_temp$jscomp$588__$jscomp$987$$){if($JSCompiler_temp$jscomp$588__$jscomp$987$$!=null&&$JSCompiler_temp$jscomp$588__$jscomp$987$$.$beicon$v2$core$IDisposable$_dispose$arity$1$!=null)$JSCompiler_temp$jscomp$588__$jscomp$987$$=$JSCompiler_temp$jscomp$588__$jscomp$987$$.$beicon$v2$core$IDisposable$_dispose$arity$1$($JSCompiler_temp$jscomp$588__$jscomp$987$$);else{var $m__5372__auto__$jscomp$inline_4271_m__5374__auto__$jscomp$inline_4270$$=$APP.$beicon$v2$core$_dispose$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$588__$jscomp$987$$==
null?null:$JSCompiler_temp$jscomp$588__$jscomp$987$$)];if($m__5372__auto__$jscomp$inline_4271_m__5374__auto__$jscomp$inline_4270$$!=null)$JSCompiler_temp$jscomp$588__$jscomp$987$$=$m__5372__auto__$jscomp$inline_4271_m__5374__auto__$jscomp$inline_4270$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_4271_m__5374__auto__$jscomp$inline_4270$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$588__$jscomp$987$$):$m__5372__auto__$jscomp$inline_4271_m__5374__auto__$jscomp$inline_4270$$($JSCompiler_temp$jscomp$588__$jscomp$987$$);
else if($m__5372__auto__$jscomp$inline_4271_m__5374__auto__$jscomp$inline_4270$$=$APP.$beicon$v2$core$_dispose$$._,$m__5372__auto__$jscomp$inline_4271_m__5374__auto__$jscomp$inline_4270$$!=null)$JSCompiler_temp$jscomp$588__$jscomp$987$$=$m__5372__auto__$jscomp$inline_4271_m__5374__auto__$jscomp$inline_4270$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_4271_m__5374__auto__$jscomp$inline_4270$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$588__$jscomp$987$$):$m__5372__auto__$jscomp$inline_4271_m__5374__auto__$jscomp$inline_4270$$($JSCompiler_temp$jscomp$588__$jscomp$987$$);
else throw $APP.$cljs$core$missing_protocol$$("IDisposable.-dispose",$JSCompiler_temp$jscomp$588__$jscomp$987$$);}return $JSCompiler_temp$jscomp$588__$jscomp$987$$};$APP.$beicon$v2$core$dispose_BANG_$$=function($v$jscomp$461$$){return $APP.$beicon$v2$core$_dispose$$($v$jscomp$461$$)};
$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$=function($ob$jscomp$4$$,$nf$$){return $nf$$!=null&&Object.getPrototypeOf($nf$$)===Object.prototype||$nf$$ instanceof $beicon$v2$core$Subject$$?$ob$jscomp$4$$.subscribe($nf$$):$APP.$cljs$core$map_QMARK_$$($nf$$)?$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$04$$($ob$jscomp$4$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($nf$$,$APP.$cljs$cst$1328$next$$,$beicon$v2$core$noop$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($nf$$,
$APP.$cljs$cst$849$error$$,$beicon$v2$core$noop$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($nf$$,$cljs$cst$826$complete$$,$beicon$v2$core$noop$$)):$ob$jscomp$4$$.subscribe({next:$nf$$})};$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ob$jscomp$5$$,$next_fn$$,$error_fn$$){return $ob$jscomp$5$$.subscribe({next:$next_fn$$,error:$error_fn$$})};
$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$04$$=function($ob$jscomp$6$$,$next_fn$jscomp$1$$,$error_fn$jscomp$1$$,$complete_fn$$){return $ob$jscomp$6$$.subscribe({next:$next_fn$jscomp$1$$,error:$error_fn$jscomp$1$$,complete:$complete_fn$$})};$APP.$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($ob$jscomp$7$$,$nf$jscomp$1$$){return $APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($ob$jscomp$7$$,$nf$jscomp$1$$)};
$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$=function($ob$jscomp$9$$,$next_fn$jscomp$3$$,$error_fn$jscomp$3$$,$complete_fn$jscomp$1$$){return $APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$04$$($ob$jscomp$9$$,$next_fn$jscomp$3$$,$error_fn$jscomp$3$$,$complete_fn$jscomp$1$$)};
$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($nf$jscomp$2$$,$ob$jscomp$12$$){return $APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($ob$jscomp$12$$,$nf$jscomp$2$$)};$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($nf$jscomp$3$$,$ef$$,$ob$jscomp$13$$){return $APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$03$$($ob$jscomp$13$$,$nf$jscomp$3$$,$ef$$)};
$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$=function($nf$jscomp$4$$,$ef$jscomp$1$$,$cf$jscomp$1$$,$ob$jscomp$14$$){return $APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$04$$($ob$jscomp$14$$,$nf$jscomp$4$$,$ef$jscomp$1$$,$cf$jscomp$1$$)};$APP.$beicon$v2$core$share$$=function($ob$jscomp$18$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$share$$(),$ob$jscomp$18$$)};
$beicon$v2$core$if_empty$$=function($ob$jscomp$19$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$if_empty$$($cljs$cst$4201$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_streams_SLASH_empty$$),$ob$jscomp$19$$)};$beicon$v2$core$merge_all$cljs$0core$0IFn$0_invoke$0arity$02$$=function($ob$jscomp$21$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$merge_all$$(2),$ob$jscomp$21$$)};
$APP.$beicon$v2$core$filter$$=function($f$jscomp$619$$,$ob$jscomp$22$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$filter$$($f$jscomp$619$$),$ob$jscomp$22$$)};$APP.$beicon$v2$core$map$$=function($f$jscomp$620$$,$ob$jscomp$23$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$map$$($f$jscomp$620$$),$ob$jscomp$23$$)};
$APP.$beicon$v2$core$merge_map$$=function($f$jscomp$622$$,$ob$jscomp$25$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$merge_map$cljs$0core$0IFn$0_invoke$0arity$01$$($f$jscomp$622$$),$ob$jscomp$25$$)};$APP.$beicon$v2$core$switch_map$$=function($f$jscomp$623$$,$ob$jscomp$26$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$switch_map$$($f$jscomp$623$$),$ob$jscomp$26$$)};
$APP.$beicon$v2$core$mapcat$$=function($f$jscomp$624$$,$ob$jscomp$27$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$mapcat$$($f$jscomp$624$$),$ob$jscomp$27$$)};$beicon$v2$core$concat_all$$=function($ob$jscomp$28$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$merge_all$$(1),$ob$jscomp$28$$)};$APP.$beicon$v2$core$take$$=function($ob$jscomp$33$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$take$$(1),$ob$jscomp$33$$)};
$beicon$v2$core$take_while$$=function($f$jscomp$626$$,$ob$jscomp$35$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$take_while$$($f$jscomp$626$$),$ob$jscomp$35$$)};$APP.$beicon$v2$core$take_until$$=function($other$jscomp$164$$,$ob$jscomp$36$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$take_until$$($other$jscomp$164$$),$ob$jscomp$36$$)};$APP.$beicon$v2$core$first$$=function($ob$jscomp$37$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$take$$(1),$ob$jscomp$37$$)};
$APP.$beicon$v2$core$last$$=function($ob$jscomp$38$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$take_last$$(1),$ob$jscomp$38$$)};$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$627$$,$ob$jscomp$39$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$reduce$cljs$0core$0IFn$0_invoke$0arity$01$$($f$jscomp$627$$),$ob$jscomp$39$$)};
$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$=function($f$jscomp$628$$,$seed$jscomp$18$$,$ob$jscomp$40$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$628$$,$seed$jscomp$18$$),$ob$jscomp$40$$)};
$APP.$beicon$v2$core$scan$cljs$0core$0IFn$0_invoke$0arity$03$$=function($f$jscomp$630$$,$seed$jscomp$19$$,$ob$jscomp$42$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$scan$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$630$$,$seed$jscomp$19$$),$ob$jscomp$42$$)};$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$=function($o1$jscomp$1$$,$source$jscomp$29$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$with_latest$$($o1$jscomp$1$$),$source$jscomp$29$$)};
$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$03$$=function($o1$jscomp$2$$,$o2$jscomp$1$$,$source$jscomp$30$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$with_latest$$($o1$jscomp$2$$,$o2$jscomp$1$$),$source$jscomp$30$$)};
$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$04$$=function($o1$jscomp$3$$,$o2$jscomp$2$$,$o3$$,$source$jscomp$31$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$with_latest$$($o1$jscomp$3$$,$o2$jscomp$2$$,$o3$$),$source$jscomp$31$$)};$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$=function($handler$jscomp$18$$,$ob$jscomp$51$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$catch$0$$($handler$jscomp$18$$),$ob$jscomp$51$$)};
$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$=function($JSCompiler_inline_result$jscomp$587_f$jscomp$633$$,$ob$jscomp$53$$){if($JSCompiler_inline_result$jscomp$587_f$jscomp$633$$!=null&&Object.getPrototypeOf($JSCompiler_inline_result$jscomp$587_f$jscomp$633$$)===Object.prototype||$APP.$cljs$core$fn_QMARK_$$($JSCompiler_inline_result$jscomp$587_f$jscomp$633$$))$JSCompiler_inline_result$jscomp$587_f$jscomp$633$$=$APP.$shadow$js$shim$module$0rxjs$$.tap($JSCompiler_inline_result$jscomp$587_f$jscomp$633$$);
else throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("invalid argiments",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$598$f$$,$JSCompiler_inline_result$jscomp$587_f$jscomp$633$$],null));return $APP.$beicon$v2$operators$pipe$$($JSCompiler_inline_result$jscomp$587_f$jscomp$633$$,$ob$jscomp$53$$)};
$APP.$beicon$v2$core$throttle$cljs$0core$0IFn$0_invoke$0arity$02$$=function($ms$jscomp$18$$,$ob$jscomp$56$$){return $APP.$beicon$v2$operators$pipe$$($APP.$shadow$js$shim$module$0rxjs$$.throttleTime($ms$jscomp$18$$),$ob$jscomp$56$$)};$APP.$beicon$v2$core$debounce$$=function($ms$jscomp$20$$,$ob$jscomp$58$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$debounce$$($ms$jscomp$20$$),$ob$jscomp$58$$)};
$beicon$v2$core$sample$$=function($ms$jscomp$21$$,$ob$jscomp$59$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$sample$$($ms$jscomp$21$$),$ob$jscomp$59$$)};$APP.$beicon$v2$core$ignore$$=function($ob$jscomp$61$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$ignore$$(),$ob$jscomp$61$$)};$APP.$beicon$v2$core$finalize$$=function($f$jscomp$636$$,$ob$jscomp$62$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$finalize$$($f$jscomp$636$$),$ob$jscomp$62$$)};
$APP.$beicon$v2$core$buffer$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ob$jscomp$64$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$buffer$$(2,1),$ob$jscomp$64$$)};$APP.$beicon$v2$core$buffer_time$cljs$0core$0IFn$0_invoke$0arity$02$$=function($ms$jscomp$22$$,$ob$jscomp$65$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$buffer_time$$($ms$jscomp$22$$),$ob$jscomp$65$$)};
$APP.$beicon$v2$core$buffer_until$$=function($notifier$$,$ob$jscomp$68$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$buffer_until$$($notifier$$),$ob$jscomp$68$$)};$APP.$beicon$v2$core$timeout$cljs$0core$0IFn$0_invoke$0arity$03$$=function($with$$jscomp$1$$,$ob$jscomp$73$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$timeout$cljs$0core$0IFn$0_invoke$0arity$02$$($with$$jscomp$1$$),$ob$jscomp$73$$)};
$APP.$beicon$v2$core$delay$$=function($ms$jscomp$27$$,$ob$jscomp$74$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$delay$$($ms$jscomp$27$$),$ob$jscomp$74$$)};$APP.$beicon$v2$core$delay_at_least$$=function($ms$jscomp$28$$,$ob$jscomp$75$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$comp$$($beicon$v2$operators$combine_latest$$($APP.$shadow$js$shim$module$0rxjs$$.timer($ms$jscomp$28$$)),$beicon$v2$operators$map$$($APP.$cljs$core$first$$)),$ob$jscomp$75$$)};
$APP.$beicon$v2$core$observe_on$$=function($sch$jscomp$4$$,$ob$jscomp$80$$){return $APP.$beicon$v2$operators$pipe$$($beicon$v2$operators$observe_on$cljs$0core$0IFn$0_invoke$0arity$01$$($sch$jscomp$4$$),$ob$jscomp$80$$)};
$APP.$app$util$rxops$throttle_fn$$=function($f$jscomp$638$$){function $x42507$$(){var $ctime$$=Date.now(),$ltime$$=$JSCompiler_object_inline_lastExecTime_50$$,$args$jscomp$212_timeout_id$$=arguments;$JSCompiler_object_inline_context_52$$=this;$JSCompiler_object_inline_args_53$$=$args$jscomp$212_timeout_id$$;$args$jscomp$212_timeout_id$$=$JSCompiler_object_inline_timeoutId_51$$;return $ctime$$-$ltime$$>=50?($args$jscomp$212_timeout_id$$&&(clearTimeout($args$jscomp$212_timeout_id$$),$JSCompiler_object_inline_timeoutId_51$$=
null),$execute_fn$$()):$args$jscomp$212_timeout_id$$?null:$JSCompiler_object_inline_timeoutId_51$$=setTimeout($execute_fn$$,50-($ctime$$-$ltime$$))}function $execute_fn$$(){$f$jscomp$638$$.apply($JSCompiler_object_inline_context_52$$,$JSCompiler_object_inline_args_53$$);$JSCompiler_object_inline_lastExecTime_50$$=Date.now();return $JSCompiler_object_inline_timeoutId_51$$=null}var $JSCompiler_object_inline_lastExecTime_50$$=0,$JSCompiler_object_inline_timeoutId_51$$=null,$JSCompiler_object_inline_context_52$$=
null,$JSCompiler_object_inline_args_53$$=null;$x42507$$.$beicon$v2$core$IDisposable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$x42507$$.$beicon$v2$core$IDisposable$_dispose$arity$1$=function(){clearTimeout($JSCompiler_object_inline_timeoutId_51$$);$JSCompiler_object_inline_lastExecTime_50$$=0;return $JSCompiler_object_inline_timeoutId_51$$=null};return $x42507$$};
$app$util$rxops$throttle$$=function(){return function($source$jscomp$35$$){return $APP.$beicon$v2$core$create$$(function($subs$jscomp$7$$){var $next_fn$jscomp$4$$=$APP.$app$util$rxops$throttle_fn$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($beicon$v2$core$push_BANG_$$,$subs$jscomp$7$$));return $beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($source$jscomp$35$$,$next_fn$jscomp$4$$,function($cause$jscomp$25$$){$APP.$beicon$v2$core$_dispose$$($next_fn$jscomp$4$$);return $subs$jscomp$7$$.error($cause$jscomp$25$$)},
function(){$APP.$beicon$v2$core$_dispose$$($next_fn$jscomp$4$$);return $subs$jscomp$7$$.complete()})})}};
$APP.$app$util$functions$debounce$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$640$$,$timeout$jscomp$6$$){var $G__42954$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1318$leading$$,null,!0,null,!1,null,$cljs$cst$1319$trailing$$,null],null),null);return $app$util$functions$ext_debounce$$.$cljs$core$IFn$_invoke$arity$3$?$app$util$functions$ext_debounce$$.$cljs$core$IFn$_invoke$arity$3$($f$jscomp$640$$,$timeout$jscomp$6$$,$G__42954$$):
$app$util$functions$ext_debounce$$($f$jscomp$640$$,$timeout$jscomp$6$$,$G__42954$$)};
$okulary$util$doiter$$=function($iterable$jscomp$9_iterator$jscomp$11$$,$f$jscomp$643$$){$iterable$jscomp$9_iterator$jscomp$11$$=$iterable$jscomp$9_iterator$jscomp$11$$[Symbol.iterator].call($iterable$jscomp$9_iterator$jscomp$11$$);for(var $G__40809_40812_chunk$jscomp$17$$=$iterable$jscomp$9_iterator$jscomp$11$$.next();;){if($G__40809_40812_chunk$jscomp$17$$.done)return null;$G__40809_40812_chunk$jscomp$17$$=$G__40809_40812_chunk$jscomp$17$$.value;$f$jscomp$643$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$643$$.$cljs$core$IFn$_invoke$arity$1$($G__40809_40812_chunk$jscomp$17$$):
$f$jscomp$643$$($G__40809_40812_chunk$jscomp$17$$);$G__40809_40812_chunk$jscomp$17$$=$iterable$jscomp$9_iterator$jscomp$11$$.next()}};$app$util$storage$encode_key$$=function($prefix$jscomp$17$$,$k$jscomp$554_kn$$){var $kns$$=$APP.$cljs$core$namespace$$($k$jscomp$554_kn$$);$k$jscomp$554_kn$$=$APP.$cljs$core$name$$($k$jscomp$554_kn$$);return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($prefix$jscomp$17$$),":",$kns$$,"/",$k$jscomp$554_kn$$].join("")};
$app$util$storage$load_data$$=function($backend$jscomp$1$$,$prefix$jscomp$20$$){if($backend$jscomp$1$$!=null)for(var $length$jscomp$37$$=$backend$jscomp$1$$.length,$index$jscomp$142_prefix$jscomp$inline_11620$$=0,$result$jscomp$131_result$jscomp$inline_4283$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);;)if($index$jscomp$142_prefix$jscomp$inline_11620$$<$length$jscomp$37$$){var $G__43670$$=$index$jscomp$142_prefix$jscomp$inline_11620$$+1;a:{var $backend$jscomp$inline_4281$$=
$backend$jscomp$1$$,$k$jscomp$inline_11621_prefix$jscomp$inline_4282$$=$prefix$jscomp$20$$;try{var $key$jscomp$inline_4285$$=$backend$jscomp$inline_4281$$.key($index$jscomp$142_prefix$jscomp$inline_11620$$);$index$jscomp$142_prefix$jscomp$inline_11620$$=$k$jscomp$inline_11621_prefix$jscomp$inline_4282$$;$k$jscomp$inline_11621_prefix$jscomp$inline_4282$$=$key$jscomp$inline_4285$$;if($APP.$cuerdas$core$starts_with_QMARK_$$($k$jscomp$inline_11621_prefix$jscomp$inline_4282$$,$index$jscomp$142_prefix$jscomp$inline_11620$$)){var $l$jscomp$inline_11622$$=
$APP.$cljs$core$count$$($index$jscomp$142_prefix$jscomp$inline_11620$$)+1,$k__$1$jscomp$inline_11623$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$inline_11621_prefix$jscomp$inline_4282$$,$l$jscomp$inline_11622$$);if($APP.$cuerdas$core$starts_with_QMARK_$$($k__$1$jscomp$inline_11623$$,"/"))var $key_SINGLEQUOTE_$jscomp$inline_4286$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($k__$1$jscomp$inline_11623$$,1));
else{var $vec__43599$jscomp$inline_11624$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$03$$($k__$1$jscomp$inline_11623$$,"/",2),$kns$jscomp$inline_11625$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__43599$jscomp$inline_11624$$,0,null),$kn$jscomp$inline_11626$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__43599$jscomp$inline_11624$$,1,null);$key_SINGLEQUOTE_$jscomp$inline_4286$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$($kns$jscomp$inline_11625$$,
$kn$jscomp$inline_11626$$)}}else $key_SINGLEQUOTE_$jscomp$inline_4286$$=null;if($APP.$cljs$core$truth_$$($key_SINGLEQUOTE_$jscomp$inline_4286$$)){var $val$jscomp$inline_4287$$=$backend$jscomp$inline_4281$$.getItem($key$jscomp$inline_4285$$);var $G__43671$$=$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$131_result$jscomp$inline_4283$$,$key_SINGLEQUOTE_$jscomp$inline_4286$$,$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$inline_4287$$));
break a}$G__43671$$=$result$jscomp$131_result$jscomp$inline_4283$$;break a}catch($e43608$jscomp$inline_4288$$){$G__43671$$=$result$jscomp$131_result$jscomp$inline_4283$$;break a}$G__43671$$=void 0}$index$jscomp$142_prefix$jscomp$inline_11620$$=$G__43670$$;$result$jscomp$131_result$jscomp$inline_4283$$=$G__43671$$}else return $APP.$cljs$core$_persistent_BANG_$$($result$jscomp$131_result$jscomp$inline_4283$$);else return $APP.$cljs$core$PersistentArrayMap$EMPTY$$};
$app$util$storage$set_item$$=function($storage$$,$val$jscomp$146$$){$storage$$!=null&&$storage$$.setItem("penpot-last-reload-timestamp",$val$jscomp$146$$)};$app$util$storage$get_item$$=function(){var $storage$jscomp$1$$=$app$util$storage$session_storage$$;return $storage$jscomp$1$$!=null?$storage$jscomp$1$$.getItem("penpot-last-reload-timestamp"):null};
$app$util$storage$t_app$0util$0storage43623$$=function($last_data$$,$curr_data$$,$on_change$$,$backend$jscomp$2$$,$watches$jscomp$2$$,$update_key$$,$prefix$jscomp$21$$,$on_change_STAR_$$,$initial$jscomp$1$$,$meta43624$$){this.$last_data$=$last_data$$;this.$curr_data$=$curr_data$$;this.$on_change$=$on_change$$;this.$backend$=$backend$jscomp$2$$;this.$watches$=$watches$jscomp$2$$;this.$update_key$=$update_key$$;this.prefix=$prefix$jscomp$21$$;this.$on_change_STAR_$=$on_change_STAR_$$;this.initial=$initial$jscomp$1$$;
this.$meta43624$=$meta43624$$;this.$cljs$lang$protocol_mask$partition0$$=426240;this.$cljs$lang$protocol_mask$partition1$$=114690};
$app$util$storage$create_storage$$=function($backend$jscomp$4$$,$prefix$jscomp$23$$){function $on_change_STAR_$jscomp$2$$($curr_state$$){var $prev_state$$=$last_data$jscomp$2$$.content;try{return $APP.$cljs$core$run_BANG_$$(function($key$jscomp$275$$){var $prev_val$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($prev_state$$,$key$jscomp$275$$),$curr_val$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($curr_state$$,$key$jscomp$275$$);return $curr_val$$===$prev_val$$?null:$update_key$jscomp$2$$($key$jscomp$275$$,
$curr_val$$)},$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keys$$($curr_state$$),$APP.$cljs$core$keys$$($prev_state$$))))}finally{$last_data$jscomp$2$$.content=$curr_state$$}}function $update_key$jscomp$2$$($key$jscomp$274$$,$val$jscomp$147$$){return $backend$jscomp$4$$!=null?$val$jscomp$147$$!=null?$backend$jscomp$4$$.setItem($app$util$storage$encode_key$$($prefix$jscomp$23$$,
$key$jscomp$274$$),$APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($val$jscomp$147$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1317$with_meta$$,!0],null))):$backend$jscomp$4$$.removeItem($app$util$storage$encode_key$$($prefix$jscomp$23$$,$key$jscomp$274$$)):null}var $initial$jscomp$3$$=$app$util$storage$load_data$$($backend$jscomp$4$$,$prefix$jscomp$23$$),$curr_data$jscomp$2$$={content:$initial$jscomp$3$$},$last_data$jscomp$2$$={content:$initial$jscomp$3$$},
$watches$jscomp$4$$=new Map,$on_change$jscomp$2$$=$APP.$app$util$functions$debounce$cljs$0core$0IFn$0_invoke$0arity$02$$($on_change_STAR_$jscomp$2$$,2E3);return new $app$util$storage$t_app$0util$0storage43623$$($last_data$jscomp$2$$,$curr_data$jscomp$2$$,$on_change$jscomp$2$$,$backend$jscomp$4$$,$watches$jscomp$4$$,$update_key$jscomp$2$$,$prefix$jscomp$23$$,$on_change_STAR_$jscomp$2$$,$initial$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$util$timers$t_app$0util$0timers42504$$=function($ms$jscomp$29$$,$func$jscomp$6$$,$sem$$,$meta42505$$){this.ms=$ms$jscomp$29$$;this.$func$=$func$jscomp$6$$;this.$sem$=$sem$$;this.$meta42505$=$meta42505$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$=function($func$jscomp$8$$){return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(0,$func$jscomp$8$$)};
$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$=function($ms$jscomp$31$$,$func$jscomp$9$$){var $sem$jscomp$2$$=setTimeout(function(){return $func$jscomp$9$$.$cljs$core$IFn$_invoke$arity$0$?$func$jscomp$9$$.$cljs$core$IFn$_invoke$arity$0$():$func$jscomp$9$$()},$ms$jscomp$31$$);return new $app$util$timers$t_app$0util$0timers42504$$($ms$jscomp$31$$,$func$jscomp$9$$,$sem$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$util$timers$dispose_BANG_$$=function($v$jscomp$462$$){return $APP.$beicon$v2$core$_dispose$$($v$jscomp$462$$)};
$APP.$app$util$timers$asap$$=function($f$jscomp$650$$){return Promise.resolve(null).then(function(){return $f$jscomp$650$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$650$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$650$$()})};
$app$util$timers$t_app$0util$0timers42521$$=function($ms$jscomp$32$$,$func$jscomp$10$$,$sem$jscomp$3$$,$meta42522$$){this.ms=$ms$jscomp$32$$;this.$func$=$func$jscomp$10$$;this.$sem$=$sem$jscomp$3$$;this.$meta42522$=$meta42522$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$APP.$app$util$timers$interval$$=function($ms$jscomp$34$$,$func$jscomp$12$$){var $sem$jscomp$5$$=setInterval(function(){return $func$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$?$func$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$():$func$jscomp$12$$()},$ms$jscomp$34$$);return new $app$util$timers$t_app$0util$0timers42521$$($ms$jscomp$34$$,$func$jscomp$12$$,$sem$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$util$timers$t_app$0util$0timers42549$$=function($func$jscomp$13$$,$sem$jscomp$6$$,$meta42550$$){this.$func$=$func$jscomp$13$$;this.$sem$=$sem$jscomp$6$$;this.$meta42550$=$meta42550$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$=function($func$jscomp$16$$){var $sem$jscomp$8$$=$app$util$timers$request_idle_callback$$(function(){return $func$jscomp$16$$.$cljs$core$IFn$_invoke$arity$0$?$func$jscomp$16$$.$cljs$core$IFn$_invoke$arity$0$():$func$jscomp$16$$()});return new $app$util$timers$t_app$0util$0timers42549$$($func$jscomp$16$$,$sem$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$util$timers$idle_then_raf$$=function($f$jscomp$652$$){return $APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return(0,$APP.$app$util$timers$request_animation_frame$$)($f$jscomp$652$$)})};
$APP.$app$config$throttled_reload$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($map__43776__$1_now$jscomp$3_p__43775$$){$map__43776__$1_now$jscomp$3_p__43775$$=$APP.$cljs$core$__destructure_map$$($map__43776__$1_now$jscomp$3_p__43775$$);var $reason$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__43776__$1_now$jscomp$3_p__43775$$,$APP.$cljs$cst$984$reason$$);$map__43776__$1_now$jscomp$3_p__43775$$=$APP.$app$common$time$now$$();var $prev_ts$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($app$util$storage$get_item$$());
if($prev_ts$$!=null&&$map__43776__$1_now$jscomp$3_p__43775$$-$prev_ts$$<3E4)return $APP.$app$common$logging$enabled_QMARK_$$("app.config",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"reload suppressed (cooldown active)"],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$984$reason$$,$reason$jscomp$23$$],null)],null)}),null,"app.config",$APP.$cljs$cst$1162$warn$$,!1),!1;$APP.$app$common$logging$enabled_QMARK_$$("app.config",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"forcing page reload"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$984$reason$$,$reason$jscomp$23$$],null)],null)}),null,"app.config",$APP.$cljs$cst$1162$warn$$,!1);$app$util$storage$set_item$$($app$util$storage$session_storage$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__43776__$1_now$jscomp$3_p__43775$$));$APP.$app$util$timers$asap$$(function(){return $APP.$app$util$globals$location$$.reload(!0)});
return!0};$APP.$app$config$external_feature_flag$$=function($flag$jscomp$2$$){var $f$jscomp$653$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"externalFeatureFlag");return $APP.$cljs$core$fn_QMARK_$$($f$jscomp$653$$)?$f$jscomp$653$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$653$$.$cljs$core$IFn$_invoke$arity$2$($flag$jscomp$2$$,"test"):$f$jscomp$653$$($flag$jscomp$2$$,"test"):null};
$APP.$app$config$external_session_id$$=function(){var $f$jscomp$654$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"externalSessionId");return $APP.$cljs$core$fn_QMARK_$$($f$jscomp$654$$)?$f$jscomp$654$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$654$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$654$$():null};
$APP.$app$config$check_browser_QMARK_$$=function($candidate$jscomp$4$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($candidate$jscomp$4$$,$APP.$cljs$cst$1346$safari$$)?$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1346$safari$$,null,$APP.$cljs$cst$1347$safari_16$$,null,$APP.$cljs$cst$1348$safari_18$$,null,$APP.$cljs$cst$1352$safari_17$$,null,$APP.$cljs$cst$1353$safari_26$$,null],null),
null),$app$config$browser$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($candidate$jscomp$4$$,$app$config$browser$$)};$APP.$app$config$check_platform_QMARK_$$=function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1354$macos$$,$app$config$platform$$)};
$APP.$app$config$resolve_profile_photo_url$$=function($p__43883_photo_id$$){var $color$jscomp$3_map__43885__$1$$=$APP.$cljs$core$__destructure_map$$($p__43883_photo_id$$);$p__43883_photo_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$3_map__43885__$1$$,$APP.$cljs$cst$1359$photo_id$$);var $fullname$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$3_map__43885__$1$$,$APP.$cljs$cst$1360$fullname$$),$name$jscomp$151$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$3_map__43885__$1$$,
$APP.$cljs$cst$725$name$$);$color$jscomp$3_map__43885__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$3_map__43885__$1$$,$APP.$cljs$cst$1298$color$$);return $p__43883_photo_id$$==null?(0,$APP.$app$util$avatars$generate$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,$APP.$cljs$core$truth_$$($fullname$$)?$fullname$$:$name$jscomp$151$$,$APP.$cljs$cst$1298$color$$,$color$jscomp$3_map__43885__$1$$],null)):""+($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,
"assets/by-id/",$p__43883_photo_id$$]))??"")};
$APP.$app$config$resolve_team_photo_url$$=function($p__43892_photo_id$jscomp$1$$){var $map__43894__$1_name$jscomp$152$$=$APP.$cljs$core$__destructure_map$$($p__43892_photo_id$jscomp$1$$);$p__43892_photo_id$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__43894__$1_name$jscomp$152$$,$APP.$cljs$cst$1359$photo_id$$);$map__43894__$1_name$jscomp$152$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__43894__$1_name$jscomp$152$$,$APP.$cljs$cst$725$name$$);return $p__43892_photo_id$jscomp$1$$==
null?(0,$APP.$app$util$avatars$generate$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$map__43894__$1_name$jscomp$152$$],null)):""+($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"assets/by-id/",$p__43892_photo_id$jscomp$1$$]))??"")};
$APP.$app$config$resolve_media$$=function($id$jscomp$40$$){return""+($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"assets/by-id/",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$40$$)]))??"")};
$app$config$resolve_href$$=function($href_resource$$){$href_resource$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$uri$ensure_path_slash$$($APP.$app$config$public_uri$$),$href_resource$$])),$APP.$cljs$cst$296$path$$);return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($href_resource$$),"?version\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version_tag$$)].join("")};
$cljs$pprint$prn$$=function($var_args$jscomp$743$$){for(var $args__5755__auto__$jscomp$138$$=[],$len__5749__auto___45625$$=arguments.length,$i__5750__auto___45626$$=0;;)if($i__5750__auto___45626$$<$len__5749__auto___45625$$)$args__5755__auto__$jscomp$138$$.push(arguments[$i__5750__auto___45626$$]),$i__5750__auto___45626$$+=1;else break;$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($cljs$pprint$pr$$,0<$args__5755__auto__$jscomp$138$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$138$$.slice(0),
0,null):null);$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"\n")};$cljs$pprint$char_code$$=function($c$jscomp$233$$){if(typeof $c$jscomp$233$$==="number")return $c$jscomp$233$$;if(typeof $c$jscomp$233$$==="string"&&$c$jscomp$233$$.length===1)return $c$jscomp$233$$.charCodeAt(0);throw Error("Argument to char must be a character or number");};
$cljs$pprint$map_passing_context$$=function($func$jscomp$17$$,$context$jscomp$12_initial_context_result$jscomp$132$$,$G__45633_acc$jscomp$80_lis$$){var $G__45632_lis__$1_remainder$jscomp$3$$=$G__45633_acc$jscomp$80_lis$$;for($G__45633_acc$jscomp$80_lis$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){if($APP.$cljs$core$empty_QMARK_$$($G__45632_lis__$1_remainder$jscomp$3$$))return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__45633_acc$jscomp$80_lis$$,
$context$jscomp$12_initial_context_result$jscomp$132$$],null);var $G__45631_this$$jscomp$514_vec__43015$$=$APP.$cljs$core$first$$($G__45632_lis__$1_remainder$jscomp$3$$);$G__45632_lis__$1_remainder$jscomp$3$$=$APP.$cljs$core$next$$($G__45632_lis__$1_remainder$jscomp$3$$);$G__45631_this$$jscomp$514_vec__43015$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($func$jscomp$17$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__45631_this$$jscomp$514_vec__43015$$,
$context$jscomp$12_initial_context_result$jscomp$132$$],null));$context$jscomp$12_initial_context_result$jscomp$132$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__45631_this$$jscomp$514_vec__43015$$,0,null);$G__45631_this$$jscomp$514_vec__43015$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__45631_this$$jscomp$514_vec__43015$$,1,null);$G__45633_acc$jscomp$80_lis$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__45633_acc$jscomp$80_lis$$,$context$jscomp$12_initial_context_result$jscomp$132$$);
$context$jscomp$12_initial_context_result$jscomp$132$$=$G__45631_this$$jscomp$514_vec__43015$$}};
$cljs$pprint$consume$$=function($func$jscomp$18$$,$G__45635_acc$jscomp$81_initial_context$jscomp$1$$){var $context$jscomp$13_result$jscomp$133$$=$G__45635_acc$jscomp$81_initial_context$jscomp$1$$;for($G__45635_acc$jscomp$81_initial_context$jscomp$1$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $G__45634_new_context$jscomp$1_vec__43024$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($func$jscomp$18$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$context$jscomp$13_result$jscomp$133$$],null));$context$jscomp$13_result$jscomp$133$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__45634_new_context$jscomp$1_vec__43024$$,0,null);$G__45634_new_context$jscomp$1_vec__43024$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__45634_new_context$jscomp$1_vec__43024$$,1,null);if($APP.$cljs$core$not$$($context$jscomp$13_result$jscomp$133$$))return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$G__45635_acc$jscomp$81_initial_context$jscomp$1$$,$G__45634_new_context$jscomp$1_vec__43024$$],null);$G__45635_acc$jscomp$81_initial_context$jscomp$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__45635_acc$jscomp$81_initial_context$jscomp$1$$,$context$jscomp$13_result$jscomp$133$$);$context$jscomp$13_result$jscomp$133$$=$G__45634_new_context$jscomp$1_vec__43024$$}};
$cljs$pprint$unzip_map$$=function($m$jscomp$169$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,function(){return function $cljs$pprint$unzip_map_$_iter__43050$$($s__43051$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__43051__$2_temp__5825__auto__$jscomp$87$$=$APP.$cljs$core$seq$$($s__43051$$);if($s__43051__$2_temp__5825__auto__$jscomp$87$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__43051__$2_temp__5825__auto__$jscomp$87$$)){var $JSCompiler_inline_result$jscomp$594_c__5501__auto__$jscomp$6_vec__43068_vec__43071$$=
$APP.$cljs$core$_chunked_first$$($s__43051__$2_temp__5825__auto__$jscomp$87$$),$size__5502__auto__$jscomp$6_v1$jscomp$17$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$594_c__5501__auto__$jscomp$6_vec__43068_vec__43071$$),$b__43053_k$jscomp$559$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$6_v1$jscomp$17$$);a:{for(var $i__43052$jscomp$inline_4310$$=0;;)if($i__43052$jscomp$inline_4310$$<$size__5502__auto__$jscomp$6_v1$jscomp$17$$){var $vec__43055$jscomp$inline_4311_vec__43058$jscomp$inline_4313$$=
$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$594_c__5501__auto__$jscomp$6_vec__43068_vec__43071$$,$i__43052$jscomp$inline_4310$$),$k$jscomp$inline_4312$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__43055$jscomp$inline_4311_vec__43058$jscomp$inline_4313$$,0,null);$vec__43055$jscomp$inline_4311_vec__43058$jscomp$inline_4313$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__43055$jscomp$inline_4311_vec__43058$jscomp$inline_4313$$,1,null);var $v1$jscomp$inline_4314$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__43055$jscomp$inline_4311_vec__43058$jscomp$inline_4313$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__43055$jscomp$inline_4311_vec__43058$jscomp$inline_4313$$,1,null);$b__43053_k$jscomp$559$$.add(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$inline_4312$$,$v1$jscomp$inline_4314$$],null));$i__43052$jscomp$inline_4310$$+=1}else{$JSCompiler_inline_result$jscomp$594_c__5501__auto__$jscomp$6_vec__43068_vec__43071$$=
!0;break a}$JSCompiler_inline_result$jscomp$594_c__5501__auto__$jscomp$6_vec__43068_vec__43071$$=void 0}return $JSCompiler_inline_result$jscomp$594_c__5501__auto__$jscomp$6_vec__43068_vec__43071$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__43053_k$jscomp$559$$),$cljs$pprint$unzip_map_$_iter__43050$$($APP.$cljs$core$_chunked_rest$$($s__43051__$2_temp__5825__auto__$jscomp$87$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__43053_k$jscomp$559$$),null)}$JSCompiler_inline_result$jscomp$594_c__5501__auto__$jscomp$6_vec__43068_vec__43071$$=
$APP.$cljs$core$first$$($s__43051__$2_temp__5825__auto__$jscomp$87$$);$b__43053_k$jscomp$559$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$594_c__5501__auto__$jscomp$6_vec__43068_vec__43071$$,0,null);$JSCompiler_inline_result$jscomp$594_c__5501__auto__$jscomp$6_vec__43068_vec__43071$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$594_c__5501__auto__$jscomp$6_vec__43068_vec__43071$$,1,null);$size__5502__auto__$jscomp$6_v1$jscomp$17$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$594_c__5501__auto__$jscomp$6_vec__43068_vec__43071$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$594_c__5501__auto__$jscomp$6_vec__43068_vec__43071$$,1,null);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__43053_k$jscomp$559$$,$size__5502__auto__$jscomp$6_v1$jscomp$17$$],null),
$cljs$pprint$unzip_map_$_iter__43050$$($APP.$cljs$core$rest$$($s__43051__$2_temp__5825__auto__$jscomp$87$$)))}return null}},null,null)}($m$jscomp$169$$)}()),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,function(){return function $cljs$pprint$unzip_map_$_iter__43075$$($s__43076$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__43076__$2_temp__5825__auto__$jscomp$88$$=$APP.$cljs$core$seq$$($s__43076$$);if($s__43076__$2_temp__5825__auto__$jscomp$88$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__43076__$2_temp__5825__auto__$jscomp$88$$)){var $JSCompiler_inline_result$jscomp$595_c__5501__auto__$jscomp$7_v2$jscomp$13_vec__43094_vec__43097$$=
$APP.$cljs$core$_chunked_first$$($s__43076__$2_temp__5825__auto__$jscomp$88$$),$size__5502__auto__$jscomp$7$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$595_c__5501__auto__$jscomp$7_v2$jscomp$13_vec__43094_vec__43097$$),$b__43078_k$jscomp$561$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$7$$);a:{for(var $i__43077$jscomp$inline_4316$$=0;;)if($i__43077$jscomp$inline_4316$$<$size__5502__auto__$jscomp$7$$){var $v2$jscomp$inline_4320_vec__43083$jscomp$inline_4317_vec__43086$jscomp$inline_4319$$=
$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$595_c__5501__auto__$jscomp$7_v2$jscomp$13_vec__43094_vec__43097$$,$i__43077$jscomp$inline_4316$$),$k$jscomp$inline_4318$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v2$jscomp$inline_4320_vec__43083$jscomp$inline_4317_vec__43086$jscomp$inline_4319$$,0,null);$v2$jscomp$inline_4320_vec__43083$jscomp$inline_4317_vec__43086$jscomp$inline_4319$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v2$jscomp$inline_4320_vec__43083$jscomp$inline_4317_vec__43086$jscomp$inline_4319$$,
1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v2$jscomp$inline_4320_vec__43083$jscomp$inline_4317_vec__43086$jscomp$inline_4319$$,0,null);$v2$jscomp$inline_4320_vec__43083$jscomp$inline_4317_vec__43086$jscomp$inline_4319$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v2$jscomp$inline_4320_vec__43083$jscomp$inline_4317_vec__43086$jscomp$inline_4319$$,1,null);$b__43078_k$jscomp$561$$.add(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$k$jscomp$inline_4318$$,$v2$jscomp$inline_4320_vec__43083$jscomp$inline_4317_vec__43086$jscomp$inline_4319$$],null));$i__43077$jscomp$inline_4316$$+=1}else{$JSCompiler_inline_result$jscomp$595_c__5501__auto__$jscomp$7_v2$jscomp$13_vec__43094_vec__43097$$=!0;break a}$JSCompiler_inline_result$jscomp$595_c__5501__auto__$jscomp$7_v2$jscomp$13_vec__43094_vec__43097$$=void 0}return $JSCompiler_inline_result$jscomp$595_c__5501__auto__$jscomp$7_v2$jscomp$13_vec__43094_vec__43097$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__43078_k$jscomp$561$$),
$cljs$pprint$unzip_map_$_iter__43075$$($APP.$cljs$core$_chunked_rest$$($s__43076__$2_temp__5825__auto__$jscomp$88$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__43078_k$jscomp$561$$),null)}$JSCompiler_inline_result$jscomp$595_c__5501__auto__$jscomp$7_v2$jscomp$13_vec__43094_vec__43097$$=$APP.$cljs$core$first$$($s__43076__$2_temp__5825__auto__$jscomp$88$$);$b__43078_k$jscomp$561$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$595_c__5501__auto__$jscomp$7_v2$jscomp$13_vec__43094_vec__43097$$,
0,null);$JSCompiler_inline_result$jscomp$595_c__5501__auto__$jscomp$7_v2$jscomp$13_vec__43094_vec__43097$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$595_c__5501__auto__$jscomp$7_v2$jscomp$13_vec__43094_vec__43097$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$595_c__5501__auto__$jscomp$7_v2$jscomp$13_vec__43094_vec__43097$$,0,null);$JSCompiler_inline_result$jscomp$595_c__5501__auto__$jscomp$7_v2$jscomp$13_vec__43094_vec__43097$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$595_c__5501__auto__$jscomp$7_v2$jscomp$13_vec__43094_vec__43097$$,1,null);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__43078_k$jscomp$561$$,$JSCompiler_inline_result$jscomp$595_c__5501__auto__$jscomp$7_v2$jscomp$13_vec__43094_vec__43097$$],null),$cljs$pprint$unzip_map_$_iter__43075$$($APP.$cljs$core$rest$$($s__43076__$2_temp__5825__auto__$jscomp$88$$)))}return null}},
null,null)}($m$jscomp$169$$)}())],null)};
$cljs$pprint$tuple_map$$=function($m$jscomp$170$$,$v1$jscomp$21$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,function(){return function $cljs$pprint$tuple_map_$_iter__43100$$($s__43101$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__43101__$2_temp__5825__auto__$jscomp$89$$=$APP.$cljs$core$seq$$($s__43101$$);if($s__43101__$2_temp__5825__auto__$jscomp$89$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__43101__$2_temp__5825__auto__$jscomp$89$$)){var $JSCompiler_inline_result$jscomp$596_c__5501__auto__$jscomp$8_v$jscomp$463_vec__43116$$=$APP.$cljs$core$_chunked_first$$($s__43101__$2_temp__5825__auto__$jscomp$89$$),
$size__5502__auto__$jscomp$8$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$596_c__5501__auto__$jscomp$8_v$jscomp$463_vec__43116$$),$b__43103_k$jscomp$563$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$8$$);a:{for(var $i__43102$jscomp$inline_4322$$=0;;)if($i__43102$jscomp$inline_4322$$<$size__5502__auto__$jscomp$8$$){var $v$jscomp$inline_4325_vec__43112$jscomp$inline_4323$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$596_c__5501__auto__$jscomp$8_v$jscomp$463_vec__43116$$,
$i__43102$jscomp$inline_4322$$),$k$jscomp$inline_4324$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$inline_4325_vec__43112$jscomp$inline_4323$$,0,null);$v$jscomp$inline_4325_vec__43112$jscomp$inline_4323$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$inline_4325_vec__43112$jscomp$inline_4323$$,1,null);$b__43103_k$jscomp$563$$.add(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$inline_4324$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$v$jscomp$inline_4325_vec__43112$jscomp$inline_4323$$,$v1$jscomp$21$$],null)],null));$i__43102$jscomp$inline_4322$$+=1}else{$JSCompiler_inline_result$jscomp$596_c__5501__auto__$jscomp$8_v$jscomp$463_vec__43116$$=!0;break a}$JSCompiler_inline_result$jscomp$596_c__5501__auto__$jscomp$8_v$jscomp$463_vec__43116$$=void 0}return $JSCompiler_inline_result$jscomp$596_c__5501__auto__$jscomp$8_v$jscomp$463_vec__43116$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__43103_k$jscomp$563$$),
$cljs$pprint$tuple_map_$_iter__43100$$($APP.$cljs$core$_chunked_rest$$($s__43101__$2_temp__5825__auto__$jscomp$89$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__43103_k$jscomp$563$$),null)}$JSCompiler_inline_result$jscomp$596_c__5501__auto__$jscomp$8_v$jscomp$463_vec__43116$$=$APP.$cljs$core$first$$($s__43101__$2_temp__5825__auto__$jscomp$89$$);$b__43103_k$jscomp$563$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$596_c__5501__auto__$jscomp$8_v$jscomp$463_vec__43116$$,
0,null);$JSCompiler_inline_result$jscomp$596_c__5501__auto__$jscomp$8_v$jscomp$463_vec__43116$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$596_c__5501__auto__$jscomp$8_v$jscomp$463_vec__43116$$,1,null);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__43103_k$jscomp$563$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_inline_result$jscomp$596_c__5501__auto__$jscomp$8_v$jscomp$463_vec__43116$$,
$v1$jscomp$21$$],null)],null),$cljs$pprint$tuple_map_$_iter__43100$$($APP.$cljs$core$rest$$($s__43101__$2_temp__5825__auto__$jscomp$89$$)))}return null}},null,null)}($m$jscomp$170$$)}())};
$cljs$pprint$_ppflush$$=function(){var $JSCompiler_temp$jscomp$599_pp$jscomp$2$$=$cljs$core$_STAR_out_STAR_$$;if($JSCompiler_temp$jscomp$599_pp$jscomp$2$$!=null&&$JSCompiler_temp$jscomp$599_pp$jscomp$2$$.$cljs$pprint$IPrettyFlush$_ppflush$arity$1$!=null)$JSCompiler_temp$jscomp$599_pp$jscomp$2$$=$JSCompiler_temp$jscomp$599_pp$jscomp$2$$.$cljs$pprint$IPrettyFlush$_ppflush$arity$1$($JSCompiler_temp$jscomp$599_pp$jscomp$2$$);else{var $m__5372__auto__$jscomp$inline_4331_m__5374__auto__$jscomp$inline_4330$$=
$cljs$pprint$_ppflush$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$599_pp$jscomp$2$$==null?null:$JSCompiler_temp$jscomp$599_pp$jscomp$2$$)];if($m__5372__auto__$jscomp$inline_4331_m__5374__auto__$jscomp$inline_4330$$!=null)$JSCompiler_temp$jscomp$599_pp$jscomp$2$$=$m__5372__auto__$jscomp$inline_4331_m__5374__auto__$jscomp$inline_4330$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_4331_m__5374__auto__$jscomp$inline_4330$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$599_pp$jscomp$2$$):
$m__5372__auto__$jscomp$inline_4331_m__5374__auto__$jscomp$inline_4330$$($JSCompiler_temp$jscomp$599_pp$jscomp$2$$);else if($m__5372__auto__$jscomp$inline_4331_m__5374__auto__$jscomp$inline_4330$$=$cljs$pprint$_ppflush$$._,$m__5372__auto__$jscomp$inline_4331_m__5374__auto__$jscomp$inline_4330$$!=null)$JSCompiler_temp$jscomp$599_pp$jscomp$2$$=$m__5372__auto__$jscomp$inline_4331_m__5374__auto__$jscomp$inline_4330$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_4331_m__5374__auto__$jscomp$inline_4330$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$599_pp$jscomp$2$$):
$m__5372__auto__$jscomp$inline_4331_m__5374__auto__$jscomp$inline_4330$$($JSCompiler_temp$jscomp$599_pp$jscomp$2$$);else throw $APP.$cljs$core$missing_protocol$$("IPrettyFlush.-ppflush",$JSCompiler_temp$jscomp$599_pp$jscomp$2$$);}return $JSCompiler_temp$jscomp$599_pp$jscomp$2$$};
$cljs$pprint$get_field$$=function($G__43154_this$$jscomp$515$$,$sym$jscomp$22$$){$G__43154_this$$jscomp$515$$=$APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($G__43154_this$$jscomp$515$$));return $sym$jscomp$22$$.$cljs$core$IFn$_invoke$arity$1$?$sym$jscomp$22$$.$cljs$core$IFn$_invoke$arity$1$($G__43154_this$$jscomp$515$$):$sym$jscomp$22$$($G__43154_this$$jscomp$515$$)};
$cljs$pprint$set_field$$=function($this$$jscomp$516$$,$sym$jscomp$23$$,$new_val$jscomp$1$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$516$$),$APP.$cljs$core$assoc$$,$sym$jscomp$23$$,$new_val$jscomp$1$$)};$cljs$pprint$get_column$$=function($this$$jscomp$517$$){return $cljs$pprint$get_field$$($this$$jscomp$517$$,$cljs$cst$1362$cur$$)};
$cljs$pprint$get_max_column$$=function($this$$jscomp$519$$){return $cljs$pprint$get_field$$($this$$jscomp$519$$,$APP.$cljs$cst$339$max$$)};
$cljs$pprint$c_write_char$$=function($this$$jscomp$522$$,$c$jscomp$236$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$236$$,"\n")?($cljs$pprint$set_field$$($this$$jscomp$522$$,$cljs$cst$1362$cur$$,0),$cljs$pprint$set_field$$($this$$jscomp$522$$,$APP.$cljs$cst$209$line$$,$cljs$pprint$get_field$$($this$$jscomp$522$$,$APP.$cljs$cst$209$line$$)+1)):$cljs$pprint$set_field$$($this$$jscomp$522$$,$cljs$cst$1362$cur$$,$cljs$pprint$get_field$$($this$$jscomp$522$$,$cljs$cst$1362$cur$$)+
1);return $APP.$cljs$core$_write$$($cljs$pprint$get_field$$($this$$jscomp$522$$,$APP.$cljs$cst$1278$base$$),$c$jscomp$236$$)};$cljs$pprint$t_cljs$0pprint43189$$=function($writer$jscomp$141$$,$max_columns$$,$fields$jscomp$2$$,$meta43190$$){this.$writer$=$writer$jscomp$141$$;this.$max_columns$=$max_columns$$;this.$fields$=$fields$jscomp$2$$;this.$meta43190$=$meta43190$$;this.$cljs$lang$protocol_mask$partition0$$=1074167808;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$pprint$logical_block$$=function($parent$jscomp$124$$,$section$$,$start_col$$,$indent$$,$done_nl$$,$intra_block_nl$$,$prefix$jscomp$24$$,$per_line_prefix$$,$suffix$jscomp$9$$,$logical_block_callback$$,$__meta$jscomp$7$$,$__extmap$jscomp$7$$,$__hash$jscomp$62$$){this.parent=$parent$jscomp$124$$;this.section=$section$$;this.$start_col$=$start_col$$;this.$indent$=$indent$$;this.$done_nl$=$done_nl$$;this.$intra_block_nl$=$intra_block_nl$$;this.prefix=$prefix$jscomp$24$$;this.$per_line_prefix$=$per_line_prefix$$;
this.$suffix$=$suffix$jscomp$9$$;this.$logical_block_callback$=$logical_block_callback$$;this.$__meta$=$__meta$jscomp$7$$;this.$__extmap$=$__extmap$jscomp$7$$;this.$__hash$=$__hash$jscomp$62$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$cljs$pprint$ancestor_QMARK_$$=function($parent$jscomp$126$$,$child$jscomp$49_child__$1$$){for($child$jscomp$49_child__$1$$=$APP.$cljs$cst$1365$parent$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$49_child__$1$$);;){if($child$jscomp$49_child__$1$$==null)return!1;if($parent$jscomp$126$$===$child$jscomp$49_child__$1$$)return!0;$child$jscomp$49_child__$1$$=$APP.$cljs$cst$1365$parent$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$49_child__$1$$)}};
$cljs$pprint$buffer_blob$$=function($type_tag$$,$data$jscomp$114$$,$trailing_white_space$$,$start_pos$$,$end_pos$$,$__meta$jscomp$8$$,$__extmap$jscomp$8$$,$__hash$jscomp$63$$){this.$type_tag$=$type_tag$$;this.data=$data$jscomp$114$$;this.$trailing_white_space$=$trailing_white_space$$;this.$start_pos$=$start_pos$$;this.$end_pos$=$end_pos$$;this.$__meta$=$__meta$jscomp$8$$;this.$__extmap$=$__extmap$jscomp$8$$;this.$__hash$=$__hash$jscomp$63$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=
139264};
$cljs$pprint$nl_t$$=function($type_tag$jscomp$2$$,$type$jscomp$249$$,$logical_block$$,$start_pos$jscomp$3$$,$end_pos$jscomp$3$$,$__meta$jscomp$9$$,$__extmap$jscomp$9$$,$__hash$jscomp$64$$){this.$type_tag$=$type_tag$jscomp$2$$;this.type=$type$jscomp$249$$;this.$logical_block$=$logical_block$$;this.$start_pos$=$start_pos$jscomp$3$$;this.$end_pos$=$end_pos$jscomp$3$$;this.$__meta$=$__meta$jscomp$9$$;this.$__extmap$=$__extmap$jscomp$9$$;this.$__hash$=$__hash$jscomp$64$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;
this.$cljs$lang$protocol_mask$partition1$$=139264};
$cljs$pprint$start_block_t$$=function($type_tag$jscomp$4$$,$logical_block$jscomp$3$$,$start_pos$jscomp$6$$,$end_pos$jscomp$6$$,$__meta$jscomp$10$$,$__extmap$jscomp$10$$,$__hash$jscomp$65$$){this.$type_tag$=$type_tag$jscomp$4$$;this.$logical_block$=$logical_block$jscomp$3$$;this.$start_pos$=$start_pos$jscomp$6$$;this.$end_pos$=$end_pos$jscomp$6$$;this.$__meta$=$__meta$jscomp$10$$;this.$__extmap$=$__extmap$jscomp$10$$;this.$__hash$=$__hash$jscomp$65$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;
this.$cljs$lang$protocol_mask$partition1$$=139264};
$cljs$pprint$end_block_t$$=function($type_tag$jscomp$6$$,$logical_block$jscomp$6$$,$start_pos$jscomp$9$$,$end_pos$jscomp$9$$,$__meta$jscomp$11$$,$__extmap$jscomp$11$$,$__hash$jscomp$66$$){this.$type_tag$=$type_tag$jscomp$6$$;this.$logical_block$=$logical_block$jscomp$6$$;this.$start_pos$=$start_pos$jscomp$9$$;this.$end_pos$=$end_pos$jscomp$9$$;this.$__meta$=$__meta$jscomp$11$$;this.$__extmap$=$__extmap$jscomp$11$$;this.$__hash$=$__hash$jscomp$66$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;
this.$cljs$lang$protocol_mask$partition1$$=139264};
$cljs$pprint$indent_t$$=function($type_tag$jscomp$8$$,$logical_block$jscomp$9$$,$relative_to$$,$offset$jscomp$37$$,$start_pos$jscomp$12$$,$end_pos$jscomp$12$$,$__meta$jscomp$12$$,$__extmap$jscomp$12$$,$__hash$jscomp$67$$){this.$type_tag$=$type_tag$jscomp$8$$;this.$logical_block$=$logical_block$jscomp$9$$;this.$relative_to$=$relative_to$$;this.offset=$offset$jscomp$37$$;this.$start_pos$=$start_pos$jscomp$12$$;this.$end_pos$=$end_pos$jscomp$12$$;this.$__meta$=$__meta$jscomp$12$$;this.$__extmap$=$__extmap$jscomp$12$$;
this.$__hash$=$__hash$jscomp$67$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$cljs$pprint$write_tokens$$=function($this$$jscomp$529$$,$G__45738_seq__43576_seq__43576__$1_temp__5825__auto__$jscomp$91_tokens$$,$force_trailing_whitespace$$){$G__45738_seq__43576_seq__43576__$1_temp__5825__auto__$jscomp$91_tokens$$=$APP.$cljs$core$seq$$($G__45738_seq__43576_seq__43576__$1_temp__5825__auto__$jscomp$91_tokens$$);for(var $c__5548__auto__$jscomp$11_chunk__43577_temp__5823__auto___45742_tws_45743$$=null,$G__45740_count__43578$$=0,$i__43579$$=0;;)if($i__43579$$<$G__45740_count__43578$$){var $G__45739_token$jscomp$35_tws_45733_tws_45744$$=
$c__5548__auto__$jscomp$11_chunk__43577_temp__5823__auto___45742_tws_45743$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__43579$$);if(!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1383$type_tag$$.$cljs$core$IFn$_invoke$arity$1$($G__45739_token$jscomp$35_tws_45733_tws_45744$$),$cljs$cst$1393$nl_t$$)){var $temp__5823__auto___45731_tws_45732$$=$cljs$cst$1384$trailing_white_space$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$529$$)));
$APP.$cljs$core$truth_$$($temp__5823__auto___45731_tws_45732$$)&&$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$529$$))),$temp__5823__auto___45731_tws_45732$$)}$cljs$pprint$write_token$$.$cljs$core$IFn$_invoke$arity$2$($this$$jscomp$529$$,$G__45739_token$jscomp$35_tws_45733_tws_45744$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$529$$),$APP.$cljs$core$assoc$$,
$cljs$cst$1384$trailing_white_space$$,$cljs$cst$1384$trailing_white_space$$.$cljs$core$IFn$_invoke$arity$1$($G__45739_token$jscomp$35_tws_45733_tws_45744$$));$G__45739_token$jscomp$35_tws_45733_tws_45744$$=$cljs$cst$1384$trailing_white_space$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$529$$)));$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($force_trailing_whitespace$$)?$G__45739_token$jscomp$35_tws_45733_tws_45744$$:$force_trailing_whitespace$$)&&
($APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$529$$))),$G__45739_token$jscomp$35_tws_45733_tws_45744$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$529$$),$APP.$cljs$core$assoc$$,$cljs$cst$1384$trailing_white_space$$,null));$i__43579$$+=1}else if($G__45738_seq__43576_seq__43576__$1_temp__5825__auto__$jscomp$91_tokens$$=$APP.$cljs$core$seq$$($G__45738_seq__43576_seq__43576__$1_temp__5825__auto__$jscomp$91_tokens$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__45738_seq__43576_seq__43576__$1_temp__5825__auto__$jscomp$91_tokens$$)?
($c__5548__auto__$jscomp$11_chunk__43577_temp__5823__auto___45742_tws_45743$$=$APP.$cljs$core$_chunked_first$$($G__45738_seq__43576_seq__43576__$1_temp__5825__auto__$jscomp$91_tokens$$),$G__45738_seq__43576_seq__43576__$1_temp__5825__auto__$jscomp$91_tokens$$=$APP.$cljs$core$_chunked_rest$$($G__45738_seq__43576_seq__43576__$1_temp__5825__auto__$jscomp$91_tokens$$),$G__45739_token$jscomp$35_tws_45733_tws_45744$$=$c__5548__auto__$jscomp$11_chunk__43577_temp__5823__auto___45742_tws_45743$$,$G__45740_count__43578$$=
$APP.$cljs$core$count$$($c__5548__auto__$jscomp$11_chunk__43577_temp__5823__auto___45742_tws_45743$$),$c__5548__auto__$jscomp$11_chunk__43577_temp__5823__auto___45742_tws_45743$$=$G__45739_token$jscomp$35_tws_45733_tws_45744$$):($G__45739_token$jscomp$35_tws_45733_tws_45744$$=$APP.$cljs$core$first$$($G__45738_seq__43576_seq__43576__$1_temp__5825__auto__$jscomp$91_tokens$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1383$type_tag$$.$cljs$core$IFn$_invoke$arity$1$($G__45739_token$jscomp$35_tws_45733_tws_45744$$),
$cljs$cst$1393$nl_t$$)||($c__5548__auto__$jscomp$11_chunk__43577_temp__5823__auto___45742_tws_45743$$=$cljs$cst$1384$trailing_white_space$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$529$$))),$APP.$cljs$core$truth_$$($c__5548__auto__$jscomp$11_chunk__43577_temp__5823__auto___45742_tws_45743$$)&&$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$529$$))),
$c__5548__auto__$jscomp$11_chunk__43577_temp__5823__auto___45742_tws_45743$$)),$cljs$pprint$write_token$$.$cljs$core$IFn$_invoke$arity$2$($this$$jscomp$529$$,$G__45739_token$jscomp$35_tws_45733_tws_45744$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$529$$),$APP.$cljs$core$assoc$$,$cljs$cst$1384$trailing_white_space$$,$cljs$cst$1384$trailing_white_space$$.$cljs$core$IFn$_invoke$arity$1$($G__45739_token$jscomp$35_tws_45733_tws_45744$$)),$G__45739_token$jscomp$35_tws_45733_tws_45744$$=
$cljs$cst$1384$trailing_white_space$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$529$$))),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($force_trailing_whitespace$$)?$G__45739_token$jscomp$35_tws_45733_tws_45744$$:$force_trailing_whitespace$$)&&($APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$529$$))),$G__45739_token$jscomp$35_tws_45733_tws_45744$$),
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$529$$),$APP.$cljs$core$assoc$$,$cljs$cst$1384$trailing_white_space$$,null)),$G__45738_seq__43576_seq__43576__$1_temp__5825__auto__$jscomp$91_tokens$$=$APP.$cljs$core$next$$($G__45738_seq__43576_seq__43576__$1_temp__5825__auto__$jscomp$91_tokens$$),$c__5548__auto__$jscomp$11_chunk__43577_temp__5823__auto___45742_tws_45743$$=null,$G__45740_count__43578$$=0),$i__43579$$=0;else break};
$cljs$pprint$tokens_fit_QMARK_$$=function($JSCompiler_temp_const$jscomp$601_this$$jscomp$530$$,$JSCompiler_inline_result$jscomp$602_l__$1$jscomp$inline_4339_tokens$jscomp$1$$){var $maxcol$$=$cljs$pprint$get_max_column$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($JSCompiler_temp_const$jscomp$601_this$$jscomp$530$$)))),$JSCompiler_temp$jscomp$600$$;($JSCompiler_temp$jscomp$600$$=$maxcol$$==null)||($JSCompiler_temp_const$jscomp$601_this$$jscomp$530$$=
$cljs$pprint$get_column$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($JSCompiler_temp_const$jscomp$601_this$$jscomp$530$$)))),$JSCompiler_inline_result$jscomp$602_l__$1$jscomp$inline_4339_tokens$jscomp$1$$=($JSCompiler_inline_result$jscomp$602_l__$1$jscomp$inline_4339_tokens$jscomp$1$$=$APP.$cljs$core$seq$$($JSCompiler_inline_result$jscomp$602_l__$1$jscomp$inline_4339_tokens$jscomp$1$$))?$cljs$cst$1381$end_pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($JSCompiler_inline_result$jscomp$602_l__$1$jscomp$inline_4339_tokens$jscomp$1$$))-
$cljs$cst$1382$start_pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($JSCompiler_inline_result$jscomp$602_l__$1$jscomp$inline_4339_tokens$jscomp$1$$)):0,$JSCompiler_temp$jscomp$600$$=$JSCompiler_temp_const$jscomp$601_this$$jscomp$530$$+$JSCompiler_inline_result$jscomp$602_l__$1$jscomp$inline_4339_tokens$jscomp$1$$<$maxcol$$);return $JSCompiler_temp$jscomp$600$$};
$cljs$pprint$linear_nl_QMARK_$$=function($this$$jscomp$531$$,$lb$jscomp$3_or__5025__auto__$jscomp$266$$,$section$jscomp$2$$){$lb$jscomp$3_or__5025__auto__$jscomp$266$$=$APP.$cljs$core$deref$$($cljs$cst$1368$done_nl$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$3_or__5025__auto__$jscomp$266$$));return $APP.$cljs$core$truth_$$($lb$jscomp$3_or__5025__auto__$jscomp$266$$)?$lb$jscomp$3_or__5025__auto__$jscomp$266$$:!$cljs$pprint$tokens_fit_QMARK_$$($this$$jscomp$531$$,$section$jscomp$2$$)};
$cljs$pprint$miser_nl_QMARK_$$=function($this$$jscomp$532$$,$lb$jscomp$4$$,$section$jscomp$3$$){var $and__5023__auto____$2$jscomp$10_miser_width$$=$cljs$cst$1411$miser_width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$532$$))),$maxcol$jscomp$1$$=$cljs$pprint$get_max_column$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$532$$))));return $APP.$cljs$core$truth_$$($and__5023__auto____$2$jscomp$10_miser_width$$)?
$APP.$cljs$core$truth_$$($maxcol$jscomp$1$$)?($and__5023__auto____$2$jscomp$10_miser_width$$=$APP.$cljs$core$deref$$($cljs$cst$1367$start_col$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$4$$))>=$maxcol$jscomp$1$$-$and__5023__auto____$2$jscomp$10_miser_width$$)?$cljs$pprint$linear_nl_QMARK_$$($this$$jscomp$532$$,$lb$jscomp$4$$,$section$jscomp$3$$):$and__5023__auto____$2$jscomp$10_miser_width$$:$maxcol$jscomp$1$$:$and__5023__auto____$2$jscomp$10_miser_width$$};
$cljs$pprint$get_section$$=function($buffer$jscomp$29$$){var $nl$jscomp$1_section$jscomp$7$$=$APP.$cljs$core$first$$($buffer$jscomp$29$$),$lb$jscomp$8$$=$cljs$cst$1391$logical_block$$.$cljs$core$IFn$_invoke$arity$1$($nl$jscomp$1_section$jscomp$7$$);$nl$jscomp$1_section$jscomp$7$$=$APP.$cljs$core$seq$$($APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__43618_SHARP_$$){return!($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1383$type_tag$$.$cljs$core$IFn$_invoke$arity$1$($p1__43618_SHARP_$$),
$cljs$cst$1393$nl_t$$)&&$cljs$pprint$ancestor_QMARK_$$($cljs$cst$1391$logical_block$$.$cljs$core$IFn$_invoke$arity$1$($p1__43618_SHARP_$$),$lb$jscomp$8$$))},$APP.$cljs$core$next$$($buffer$jscomp$29$$)));return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$nl$jscomp$1_section$jscomp$7$$,$APP.$cljs$core$seq$$($APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$count$$($nl$jscomp$1_section$jscomp$7$$)+1,$buffer$jscomp$29$$))],null)};
$cljs$pprint$get_sub_section$$=function($buffer$jscomp$30$$){var $nl$jscomp$2$$=$APP.$cljs$core$first$$($buffer$jscomp$30$$),$lb$jscomp$9$$=$cljs$cst$1391$logical_block$$.$cljs$core$IFn$_invoke$arity$1$($nl$jscomp$2$$);return $APP.$cljs$core$seq$$($APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__43619_SHARP_$$){var $nl_lb$$=$cljs$cst$1391$logical_block$$.$cljs$core$IFn$_invoke$arity$1$($p1__43619_SHARP_$$);return!($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1383$type_tag$$.$cljs$core$IFn$_invoke$arity$1$($p1__43619_SHARP_$$),
$cljs$cst$1393$nl_t$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($nl_lb$$,$lb$jscomp$9$$)||$cljs$pprint$ancestor_QMARK_$$($nl_lb$$,$lb$jscomp$9$$)))},$APP.$cljs$core$next$$($buffer$jscomp$30$$)))};
$cljs$pprint$emit_nl$$=function($JSCompiler_inline_result$jscomp$607_lb__$1$jscomp$inline_4342_this$$jscomp$536$$,$lb$jscomp$11_nl$jscomp$3$$){$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($JSCompiler_inline_result$jscomp$607_lb__$1$jscomp$inline_4342_this$$jscomp$536$$))),"\n");$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($JSCompiler_inline_result$jscomp$607_lb__$1$jscomp$inline_4342_this$$jscomp$536$$),
$APP.$cljs$core$assoc$$,$cljs$cst$1384$trailing_white_space$$,null);$lb$jscomp$11_nl$jscomp$3$$=$cljs$cst$1391$logical_block$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$11_nl$jscomp$3$$);var $istr_45753_prefix$jscomp$26$$=$cljs$cst$1370$per_line_prefix$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$11_nl$jscomp$3$$);$APP.$cljs$core$truth_$$($istr_45753_prefix$jscomp$26$$)&&$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($JSCompiler_inline_result$jscomp$607_lb__$1$jscomp$inline_4342_this$$jscomp$536$$))),
$istr_45753_prefix$jscomp$26$$);$istr_45753_prefix$jscomp$26$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$deref$$($APP.$cljs$cst$294$indent$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$11_nl$jscomp$3$$))-$APP.$cljs$core$count$$($istr_45753_prefix$jscomp$26$$)," "));$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($JSCompiler_inline_result$jscomp$607_lb__$1$jscomp$inline_4342_this$$jscomp$536$$))),
$istr_45753_prefix$jscomp$26$$);a:{$APP.$cljs$core$reset_BANG_$$($cljs$cst$1369$intra_block_nl$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$11_nl$jscomp$3$$),!0);$APP.$cljs$core$reset_BANG_$$($cljs$cst$1368$done_nl$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$11_nl$jscomp$3$$),!0);for($JSCompiler_inline_result$jscomp$607_lb__$1$jscomp$inline_4342_this$$jscomp$536$$=$APP.$cljs$cst$1365$parent$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$11_nl$jscomp$3$$);;)if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$607_lb__$1$jscomp$inline_4342_this$$jscomp$536$$))$APP.$cljs$core$reset_BANG_$$($cljs$cst$1368$done_nl$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$607_lb__$1$jscomp$inline_4342_this$$jscomp$536$$),
!0),$APP.$cljs$core$reset_BANG_$$($cljs$cst$1369$intra_block_nl$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$607_lb__$1$jscomp$inline_4342_this$$jscomp$536$$),!0),$JSCompiler_inline_result$jscomp$607_lb__$1$jscomp$inline_4342_this$$jscomp$536$$=$APP.$cljs$cst$1365$parent$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$607_lb__$1$jscomp$inline_4342_this$$jscomp$536$$);else{$JSCompiler_inline_result$jscomp$607_lb__$1$jscomp$inline_4342_this$$jscomp$536$$=null;
break a}$JSCompiler_inline_result$jscomp$607_lb__$1$jscomp$inline_4342_this$$jscomp$536$$=void 0}return $JSCompiler_inline_result$jscomp$607_lb__$1$jscomp$inline_4342_this$$jscomp$536$$};
$cljs$pprint$split_at_newline$$=function($tokens$jscomp$2$$){var $pre$$=$APP.$cljs$core$seq$$($APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__43622_SHARP_$$){return!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1383$type_tag$$.$cljs$core$IFn$_invoke$arity$1$($p1__43622_SHARP_$$),$cljs$cst$1393$nl_t$$)},$tokens$jscomp$2$$));return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$pre$$,$APP.$cljs$core$seq$$($APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$count$$($pre$$),
$tokens$jscomp$2$$))],null)};
$cljs$pprint$write_line$$=function($this$$jscomp$538$$){for(var $buffer$jscomp$31$$=$APP.$cljs$cst$194$buffer$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$538$$)));;){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$538$$),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$194$buffer$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$buffer$jscomp$31$$));if($cljs$pprint$tokens_fit_QMARK_$$($this$$jscomp$538$$,
$buffer$jscomp$31$$))return null;var $new_buffer$$=$cljs$pprint$write_token_string$$($this$$jscomp$538$$,$buffer$jscomp$31$$);if($buffer$jscomp$31$$!==$new_buffer$$)$buffer$jscomp$31$$=$new_buffer$$;else return null}};
$cljs$pprint$add_to_buffer$$=function($this$$jscomp$539$$,$token$jscomp$36$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$539$$),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$194$buffer$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$194$buffer$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$539$$))),$token$jscomp$36$$));return $cljs$pprint$tokens_fit_QMARK_$$($this$$jscomp$539$$,
$APP.$cljs$cst$194$buffer$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$539$$))))?null:$cljs$pprint$write_line$$($this$$jscomp$539$$)};
$cljs$pprint$write_white_space$$=function($this$$jscomp$541$$){var $temp__5825__auto__$jscomp$92$$=$cljs$cst$1384$trailing_white_space$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$541$$)));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$92$$)?($APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$541$$))),$temp__5825__auto__$jscomp$92$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$541$$),
$APP.$cljs$core$assoc$$,$cljs$cst$1384$trailing_white_space$$,null)):null};
$cljs$pprint$write_initial_lines$$=function($this$$jscomp$542$$,$prefix$jscomp$27_s$jscomp$487$$){var $lines$$=$clojure$string$split$cljs$0core$0IFn$0_invoke$0arity$03$$($prefix$jscomp$27_s$jscomp$487$$,"\n",-1);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($lines$$),1))return $prefix$jscomp$27_s$jscomp$487$$;$prefix$jscomp$27_s$jscomp$487$$=$cljs$cst$1370$per_line_prefix$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($cljs$cst$1404$logical_blocks$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$542$$)))));var $c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$=
$APP.$cljs$core$first$$($lines$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1405$buffering$$,$APP.$cljs$cst$320$mode$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$542$$))))){var $G__45772_chunk__43643_45760_oldpos_45757_seq__43642_45769__$1$$=$APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$542$$))),$G__45773_count__43644_45761_newpos_45758$$=$G__45772_chunk__43643_45760_oldpos_45757_seq__43642_45769__$1$$+
$APP.$cljs$core$count$$($c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$542$$),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1406$pos$$,$G__45773_count__43644_45761_newpos_45758$$);$cljs$pprint$add_to_buffer$$($this$$jscomp$542$$,new $cljs$pprint$buffer_blob$$($cljs$cst$1390$buffer_blob$$,$c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$,
null,$G__45772_chunk__43643_45760_oldpos_45757_seq__43642_45769__$1$$,$G__45773_count__43644_45761_newpos_45758$$,null,null,null));$cljs$pprint$write_line$$($this$$jscomp$542$$);$c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$=$APP.$cljs$cst$194$buffer$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$542$$)));$APP.$cljs$core$truth_$$($c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$)&&
($cljs$pprint$write_tokens$$($this$$jscomp$542$$,$c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$,!0),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$542$$),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$194$buffer$$,$APP.$cljs$core$PersistentVector$EMPTY$$))}else $cljs$pprint$write_white_space$$($this$$jscomp$542$$),$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$542$$))),
$c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$);$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$542$$))),"\n");$c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$=$APP.$cljs$core$seq$$($APP.$cljs$core$next$$($APP.$cljs$core$butlast$$($lines$$)));
$G__45772_chunk__43643_45760_oldpos_45757_seq__43642_45769__$1$$=null;for(var $G__45771_i__43645_45762$$=$G__45773_count__43644_45761_newpos_45758$$=0;;)if($G__45771_i__43645_45762$$<$G__45773_count__43644_45761_newpos_45758$$){var $l_45763__$1$$=$G__45772_chunk__43643_45760_oldpos_45757_seq__43642_45769__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__45771_i__43645_45762$$);$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$542$$))),
$l_45763__$1$$);$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$542$$))),"\n");$APP.$cljs$core$truth_$$($prefix$jscomp$27_s$jscomp$487$$)&&$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$542$$))),$prefix$jscomp$27_s$jscomp$487$$);$G__45771_i__43645_45762$$+=1}else if($c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$=
$APP.$cljs$core$seq$$($c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$))$G__45772_chunk__43643_45760_oldpos_45757_seq__43642_45769__$1$$=$c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__45772_chunk__43643_45760_oldpos_45757_seq__43642_45769__$1$$)?($c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$=
$APP.$cljs$core$_chunked_first$$($G__45772_chunk__43643_45760_oldpos_45757_seq__43642_45769__$1$$),$G__45771_i__43645_45762$$=$APP.$cljs$core$_chunked_rest$$($G__45772_chunk__43643_45760_oldpos_45757_seq__43642_45769__$1$$),$G__45772_chunk__43643_45760_oldpos_45757_seq__43642_45769__$1$$=$c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$,$G__45773_count__43644_45761_newpos_45758$$=$APP.$cljs$core$count$$($c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$),
$c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$=$G__45771_i__43645_45762$$):($c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$=$APP.$cljs$core$first$$($G__45772_chunk__43643_45760_oldpos_45757_seq__43642_45769__$1$$),$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$542$$))),
$c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$),$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$542$$))),"\n"),$APP.$cljs$core$truth_$$($prefix$jscomp$27_s$jscomp$487$$)&&$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$542$$))),
$prefix$jscomp$27_s$jscomp$487$$),$c__5548__auto___45770_l$jscomp$92_l_45775__$1_seq__43642_45759_temp__5823__auto__$jscomp$inline_4346_temp__5825__auto___45768$$=$APP.$cljs$core$next$$($G__45772_chunk__43643_45760_oldpos_45757_seq__43642_45769__$1$$),$G__45772_chunk__43643_45760_oldpos_45757_seq__43642_45769__$1$$=null,$G__45773_count__43644_45761_newpos_45758$$=0),$G__45771_i__43645_45762$$=0;else break;$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$542$$),
$APP.$cljs$core$assoc$$,$cljs$cst$1405$buffering$$,$cljs$cst$1407$writing$$);return $APP.$cljs$core$last$$($lines$$)};
$cljs$pprint$t_cljs$0pprint43666$$=function($writer$jscomp$145$$,$max_columns$jscomp$3$$,$miser_width$jscomp$1$$,$lb$jscomp$12$$,$fields$jscomp$5$$,$meta43667$$){this.$writer$=$writer$jscomp$145$$;this.$max_columns$=$max_columns$jscomp$3$$;this.$miser_width$=$miser_width$jscomp$1$$;this.lb=$lb$jscomp$12$$;this.$fields$=$fields$jscomp$5$$;this.$meta43667$=$meta43667$$;this.$cljs$lang$protocol_mask$partition0$$=1074167808;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$pprint$pretty_writer$$=function($writer$jscomp$147$$){var $max_columns$jscomp$5$$=$cljs$pprint$_STAR_print_right_margin_STAR_$$,$miser_width$jscomp$3$$=$cljs$pprint$_STAR_print_miser_width_STAR_$$,$lb$jscomp$14$$=new $cljs$pprint$logical_block$$(null,null,$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
null,null,null,null,null,null,null),$fields$jscomp$7$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$1404$logical_blocks$$,$cljs$cst$1411$miser_width$$,$cljs$cst$1412$buffer_block$$,$cljs$cst$1413$pretty_writer$$,$cljs$cst$1414$sections$$,$APP.$cljs$cst$320$mode$$,$APP.$cljs$cst$1406$pos$$,$cljs$cst$1384$trailing_white_space$$,$APP.$cljs$cst$1278$base$$,$cljs$cst$1415$buffer_level$$,$APP.$cljs$cst$194$buffer$$],[$lb$jscomp$14$$,
$miser_width$jscomp$3$$,$lb$jscomp$14$$,!0,null,$cljs$cst$1407$writing$$,0,null,new $cljs$pprint$t_cljs$0pprint43189$$($writer$jscomp$147$$,$max_columns$jscomp$5$$,$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$339$max$$,$max_columns$jscomp$5$$,$cljs$cst$1362$cur$$,0,$APP.$cljs$cst$209$line$$,0,$APP.$cljs$cst$1278$base$$,$writer$jscomp$147$$],null)),$APP.$cljs$core$PersistentArrayMap$EMPTY$$),1,$APP.$cljs$core$PersistentVector$EMPTY$$]));
return new $cljs$pprint$t_cljs$0pprint43666$$($writer$jscomp$147$$,$max_columns$jscomp$5$$,$miser_width$jscomp$3$$,$lb$jscomp$14$$,$fields$jscomp$7$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$pprint$start_block$$=function($newpos$jscomp$2_prefix$jscomp$28$$,$lb$jscomp$15_suffix$jscomp$12$$){var $col$jscomp$20_this$$jscomp$547$$=$cljs$core$_STAR_out_STAR_$$;$lb$jscomp$15_suffix$jscomp$12$$=new $cljs$pprint$logical_block$$($cljs$cst$1404$logical_blocks$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($col$jscomp$20_this$$jscomp$547$$))),null,$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(0),
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$newpos$jscomp$2_prefix$jscomp$28$$,null,$lb$jscomp$15_suffix$jscomp$12$$,null,null,null,null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($col$jscomp$20_this$$jscomp$547$$),$APP.$cljs$core$assoc$$,$cljs$cst$1404$logical_blocks$$,$lb$jscomp$15_suffix$jscomp$12$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$320$mode$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($col$jscomp$20_this$$jscomp$547$$))),
$cljs$cst$1407$writing$$)){$cljs$pprint$write_white_space$$($col$jscomp$20_this$$jscomp$547$$);var $oldpos$jscomp$2_temp__5825__auto___45782$$=$cljs$cst$1372$logical_block_callback$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($col$jscomp$20_this$$jscomp$547$$)));$APP.$cljs$core$truth_$$($oldpos$jscomp$2_temp__5825__auto___45782$$)&&($oldpos$jscomp$2_temp__5825__auto___45782$$.$cljs$core$IFn$_invoke$arity$1$?$oldpos$jscomp$2_temp__5825__auto___45782$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1292$start$$):
$oldpos$jscomp$2_temp__5825__auto___45782$$($APP.$cljs$cst$1292$start$$));$APP.$cljs$core$truth_$$($newpos$jscomp$2_prefix$jscomp$28$$)&&$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($col$jscomp$20_this$$jscomp$547$$))),$newpos$jscomp$2_prefix$jscomp$28$$);$col$jscomp$20_this$$jscomp$547$$=$cljs$pprint$get_column$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($col$jscomp$20_this$$jscomp$547$$))));
$APP.$cljs$core$reset_BANG_$$($lb$jscomp$15_suffix$jscomp$12$$.$start_col$,$col$jscomp$20_this$$jscomp$547$$);$APP.$cljs$core$reset_BANG_$$($lb$jscomp$15_suffix$jscomp$12$$.$indent$,$col$jscomp$20_this$$jscomp$547$$)}else $oldpos$jscomp$2_temp__5825__auto___45782$$=$APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($col$jscomp$20_this$$jscomp$547$$))),$newpos$jscomp$2_prefix$jscomp$28$$=$oldpos$jscomp$2_temp__5825__auto___45782$$+($APP.$cljs$core$truth_$$($newpos$jscomp$2_prefix$jscomp$28$$)?
$APP.$cljs$core$count$$($newpos$jscomp$2_prefix$jscomp$28$$):0),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($col$jscomp$20_this$$jscomp$547$$),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1406$pos$$,$newpos$jscomp$2_prefix$jscomp$28$$),$cljs$pprint$add_to_buffer$$($col$jscomp$20_this$$jscomp$547$$,new $cljs$pprint$start_block_t$$($cljs$cst$1394$start_block_t$$,$lb$jscomp$15_suffix$jscomp$12$$,$oldpos$jscomp$2_temp__5825__auto___45782$$,$newpos$jscomp$2_prefix$jscomp$28$$,
null,null,null))};
$cljs$pprint$end_block$$=function(){var $this$$jscomp$548$$=$cljs$core$_STAR_out_STAR_$$,$lb$jscomp$16$$=$cljs$cst$1404$logical_blocks$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$548$$))),$newpos_45788_suffix$jscomp$13$$=$APP.$cljs$cst$1371$suffix$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$16$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$320$mode$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$548$$))),$cljs$cst$1407$writing$$)){$cljs$pprint$write_white_space$$($this$$jscomp$548$$);
$APP.$cljs$core$truth_$$($newpos_45788_suffix$jscomp$13$$)&&$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$548$$))),$newpos_45788_suffix$jscomp$13$$);var $oldpos_45787_temp__5825__auto___45784$$=$cljs$cst$1372$logical_block_callback$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$548$$)));$APP.$cljs$core$truth_$$($oldpos_45787_temp__5825__auto___45784$$)&&
($oldpos_45787_temp__5825__auto___45784$$.$cljs$core$IFn$_invoke$arity$1$?$oldpos_45787_temp__5825__auto___45784$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1293$end$$):$oldpos_45787_temp__5825__auto___45784$$($APP.$cljs$cst$1293$end$$))}else $oldpos_45787_temp__5825__auto___45784$$=$APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$548$$))),$newpos_45788_suffix$jscomp$13$$=$oldpos_45787_temp__5825__auto___45784$$+($APP.$cljs$core$truth_$$($newpos_45788_suffix$jscomp$13$$)?
$APP.$cljs$core$count$$($newpos_45788_suffix$jscomp$13$$):0),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$548$$),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1406$pos$$,$newpos_45788_suffix$jscomp$13$$),$cljs$pprint$add_to_buffer$$($this$$jscomp$548$$,new $cljs$pprint$end_block_t$$($cljs$cst$1395$end_block_t$$,$lb$jscomp$16$$,$oldpos_45787_temp__5825__auto___45784$$,$newpos_45788_suffix$jscomp$13$$,null,null,null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$548$$),
$APP.$cljs$core$assoc$$,$cljs$cst$1404$logical_blocks$$,$APP.$cljs$cst$1365$parent$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$16$$))};
$cljs$pprint$pretty_writer_QMARK_$$=function($x$jscomp$1027$$){var $and__5023__auto__$jscomp$173$$=$x$jscomp$1027$$!=null?$x$jscomp$1027$$.$cljs$lang$protocol_mask$partition0$$&32768||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$1027$$.$cljs$core$IDeref$$?!0:$x$jscomp$1027$$.$cljs$lang$protocol_mask$partition0$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IDeref$$,$x$jscomp$1027$$):$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IDeref$$,$x$jscomp$1027$$);return $and__5023__auto__$jscomp$173$$?
$cljs$cst$1413$pretty_writer$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($x$jscomp$1027$$))):$and__5023__auto__$jscomp$173$$};
$cljs$pprint$write_out$$=function($object$jscomp$11$$){var $and__5023__auto__$jscomp$inline_4358_and__5023__auto____$1$jscomp$inline_4359_length_reached$$=$cljs$pprint$_STAR_current_length_STAR_$$;$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_4358_and__5023__auto____$1$jscomp$inline_4359_length_reached$$)&&($and__5023__auto__$jscomp$inline_4358_and__5023__auto____$1$jscomp$inline_4359_length_reached$$=$cljs$core$_STAR_print_length_STAR_$$,$and__5023__auto__$jscomp$inline_4358_and__5023__auto____$1$jscomp$inline_4359_length_reached$$=
$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_4358_and__5023__auto____$1$jscomp$inline_4359_length_reached$$)?$cljs$pprint$_STAR_current_length_STAR_$$>=$cljs$core$_STAR_print_length_STAR_$$:$and__5023__auto__$jscomp$inline_4358_and__5023__auto____$1$jscomp$inline_4359_length_reached$$);$APP.$cljs$core$not$$($cljs$pprint$_STAR_print_pretty_STAR_$$)?$cljs$pprint$pr$$.call(null,$object$jscomp$11$$):$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_4358_and__5023__auto____$1$jscomp$inline_4359_length_reached$$)?
$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"..."):($APP.$cljs$core$truth_$$($cljs$pprint$_STAR_current_length_STAR_$$)&&($cljs$pprint$_STAR_current_length_STAR_$$+=1),$cljs$pprint$_STAR_print_pprint_dispatch_STAR_$$.call(null,$object$jscomp$11$$));return $and__5023__auto__$jscomp$inline_4358_and__5023__auto____$1$jscomp$inline_4359_length_reached$$};
$cljs$pprint$check_enumerated_arg$$=function($arg$jscomp$13$$,$choices$jscomp$1$$){if($APP.$cljs$core$not$$($choices$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$choices$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($arg$jscomp$13$$):$choices$jscomp$1$$($arg$jscomp$13$$)))throw Error(["Bad argument: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($arg$jscomp$13$$),". It must be one of ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($choices$jscomp$1$$)].join(""));};
$cljs$pprint$level_exceeded$$=function(){var $and__5023__auto__$jscomp$175$$=$cljs$core$_STAR_print_level_STAR_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$175$$)?$cljs$pprint$_STAR_current_level_STAR_$$>=$cljs$core$_STAR_print_level_STAR_$$:$and__5023__auto__$jscomp$175$$};
$cljs$pprint$pprint_newline$$=function($kind$jscomp$22$$){$cljs$pprint$check_enumerated_arg$$($kind$jscomp$22$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1402$mandatory$$,null,$cljs$cst$288$miser$$,null,$APP.$cljs$cst$1403$fill$$,null,$APP.$cljs$cst$287$linear$$,null],null),null));var $this$$jscomp$inline_4362$$=$cljs$core$_STAR_out_STAR_$$;$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$inline_4362$$),
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$320$mode$$,$cljs$cst$1405$buffering$$);var $pos$jscomp$inline_4363$$=$APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$inline_4362$$))),$logical_block$jscomp$inline_11674$$=$cljs$cst$1404$logical_blocks$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$inline_4362$$)));$cljs$pprint$add_to_buffer$$($this$$jscomp$inline_4362$$,new $cljs$pprint$nl_t$$($cljs$cst$1393$nl_t$$,
$kind$jscomp$22$$,$logical_block$jscomp$inline_11674$$,$pos$jscomp$inline_4363$$,$pos$jscomp$inline_4363$$,null,null,null))};
$cljs$pprint$pprint_indent$$=function($JSCompiler_inline_result$jscomp$inline_11683_relative_to$jscomp$4$$,$n$jscomp$265$$){$cljs$pprint$check_enumerated_arg$$($JSCompiler_inline_result$jscomp$inline_11683_relative_to$jscomp$4$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1400$block$$,null,$cljs$cst$1401$current$$,null],null),null));var $this$$jscomp$inline_11680$$=$cljs$core$_STAR_out_STAR_$$,$lb$jscomp$inline_11681$$=$cljs$cst$1404$logical_blocks$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$inline_11680$$)));
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$320$mode$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$inline_11680$$))),$cljs$cst$1407$writing$$)){$cljs$pprint$write_white_space$$($this$$jscomp$inline_11680$$);var $JSCompiler_temp_const$jscomp$inline_11682_pos$jscomp$inline_11684$$=$APP.$cljs$cst$294$indent$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$inline_11681$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1400$block$$,$JSCompiler_inline_result$jscomp$inline_11683_relative_to$jscomp$4$$):$APP.$cljs$core$_EQ_$$($APP.$cljs$cst$1400$block$$,$JSCompiler_inline_result$jscomp$inline_11683_relative_to$jscomp$4$$)))$JSCompiler_inline_result$jscomp$inline_11683_relative_to$jscomp$4$$=$APP.$cljs$core$deref$$($cljs$cst$1367$start_col$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$inline_11681$$));else if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1401$current$$,$JSCompiler_inline_result$jscomp$inline_11683_relative_to$jscomp$4$$):$APP.$cljs$core$_EQ_$$($cljs$cst$1401$current$$,$JSCompiler_inline_result$jscomp$inline_11683_relative_to$jscomp$4$$)))$JSCompiler_inline_result$jscomp$inline_11683_relative_to$jscomp$4$$=$cljs$pprint$get_column$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$inline_11680$$))));
else throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$inline_11683_relative_to$jscomp$4$$)].join(""));$APP.$cljs$core$reset_BANG_$$($JSCompiler_temp_const$jscomp$inline_11682_pos$jscomp$inline_11684$$,$n$jscomp$265$$+$JSCompiler_inline_result$jscomp$inline_11683_relative_to$jscomp$4$$)}else $JSCompiler_temp_const$jscomp$inline_11682_pos$jscomp$inline_11684$$=$APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$inline_11680$$))),
$cljs$pprint$add_to_buffer$$($this$$jscomp$inline_11680$$,new $cljs$pprint$indent_t$$($cljs$cst$1399$indent_t$$,$lb$jscomp$inline_11681$$,$JSCompiler_inline_result$jscomp$inline_11683_relative_to$jscomp$4$$,$n$jscomp$265$$,$JSCompiler_temp_const$jscomp$inline_11682_pos$jscomp$inline_11684$$,$JSCompiler_temp_const$jscomp$inline_11682_pos$jscomp$inline_11684$$,null,null,null))};
$cljs$pprint$cl_format$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($writer$jscomp$149$$,$compiled_format_format_in$$,$args$jscomp$213_navigator__$1$$){$compiled_format_format_in$$=typeof $compiled_format_format_in$$==="string"?$cljs$pprint$compile_format$$($compiled_format_format_in$$):$compiled_format_format_in$$;$args$jscomp$213_navigator__$1$$=$cljs$pprint$init_navigator$$($args$jscomp$213_navigator__$1$$);a:{var $sb$jscomp$inline_4368$$=new $APP.$goog$string$StringBuffer$$,$real_stream$jscomp$inline_4369$$=
$APP.$cljs$core$not$$($writer$jscomp$149$$)||$writer$jscomp$149$$===!0?new $cljs$core$StringBufferWriter$$($sb$jscomp$inline_4368$$):$writer$jscomp$149$$,$wrapped_stream$jscomp$inline_4370$$=$cljs$pprint$needs_pretty$$($compiled_format_format_in$$)&&$APP.$cljs$core$not$$($cljs$pprint$pretty_writer_QMARK_$$($real_stream$jscomp$inline_4369$$))?$APP.$cljs$core$truth_$$($cljs$pprint$pretty_writer_QMARK_$$($real_stream$jscomp$inline_4369$$))?$real_stream$jscomp$inline_4369$$:$cljs$pprint$pretty_writer$$($real_stream$jscomp$inline_4369$$):
$real_stream$jscomp$inline_4369$$,$_STAR_out_STAR__orig_val__45203$jscomp$inline_4371$$=$cljs$core$_STAR_out_STAR_$$;$cljs$core$_STAR_out_STAR_$$=$wrapped_stream$jscomp$inline_4370$$;try{try{$cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($compiled_format_format_in$$,$args$jscomp$213_navigator__$1$$)}finally{$real_stream$jscomp$inline_4369$$!==$wrapped_stream$jscomp$inline_4370$$&&$cljs$core$_flush$$($wrapped_stream$jscomp$inline_4370$$)}var $JSCompiler_inline_result$jscomp$646$$=
$APP.$cljs$core$not$$($writer$jscomp$149$$)?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$inline_4368$$):$writer$jscomp$149$$===!0?$cljs$core$string_print$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$inline_4368$$)):null;break a}finally{$cljs$core$_STAR_out_STAR_$$=$_STAR_out_STAR__orig_val__45203$jscomp$inline_4371$$}$JSCompiler_inline_result$jscomp$646$$=void 0}return $JSCompiler_inline_result$jscomp$646$$};
$cljs$pprint$format_error$$=function($full_message_message$jscomp$51$$,$offset$jscomp$41$$){$full_message_message$jscomp$51$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($full_message_message$jscomp$51$$),"\n",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$pprint$_STAR_format_str_STAR_$$),"\n",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($offset$jscomp$41$$,
" "))),"^\n"].join("");throw Error($full_message_message$jscomp$51$$);};
$cljs$pprint$arg_navigator$$=function($seq$jscomp$2$$,$rest$jscomp$16$$,$pos$jscomp$89$$,$__meta$jscomp$13$$,$__extmap$jscomp$13$$,$__hash$jscomp$68$$){this.$seq$=$seq$jscomp$2$$;this.$rest$=$rest$jscomp$16$$;this.pos=$pos$jscomp$89$$;this.$__meta$=$__meta$jscomp$13$$;this.$__extmap$=$__extmap$jscomp$13$$;this.$__hash$=$__hash$jscomp$68$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$cljs$pprint$init_navigator$$=function($s$jscomp$489_s__$1$jscomp$46$$){$s$jscomp$489_s__$1$jscomp$46$$=$APP.$cljs$core$seq$$($s$jscomp$489_s__$1$jscomp$46$$);return new $cljs$pprint$arg_navigator$$($s$jscomp$489_s__$1$jscomp$46$$,$s$jscomp$489_s__$1$jscomp$46$$,0,null,null,null)};
$cljs$pprint$next_arg$$=function($navigator$jscomp$4$$){var $rst$jscomp$1$$=$cljs$cst$1426$rest$$.$cljs$core$IFn$_invoke$arity$1$($navigator$jscomp$4$$);if($APP.$cljs$core$truth_$$($rst$jscomp$1$$))return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($rst$jscomp$1$$),new $cljs$pprint$arg_navigator$$($cljs$cst$1425$seq$$.$cljs$core$IFn$_invoke$arity$1$($navigator$jscomp$4$$),$APP.$cljs$core$next$$($rst$jscomp$1$$),$APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($navigator$jscomp$4$$)+
1,null,null,null)],null);throw Error("Not enough arguments for format definition");};
$cljs$pprint$get_format_arg$$=function($compiled_format$jscomp$1_navigator$jscomp$6_raw_format$$){var $navigator__$1$jscomp$1_vec__44009$$=$cljs$pprint$next_arg$$($compiled_format$jscomp$1_navigator$jscomp$6_raw_format$$);$compiled_format$jscomp$1_navigator$jscomp$6_raw_format$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$1_vec__44009$$,0,null);$navigator__$1$jscomp$1_vec__44009$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$1_vec__44009$$,
1,null);$compiled_format$jscomp$1_navigator$jscomp$6_raw_format$$=typeof $compiled_format$jscomp$1_navigator$jscomp$6_raw_format$$==="string"?$cljs$pprint$compile_format$$($compiled_format$jscomp$1_navigator$jscomp$6_raw_format$$):$compiled_format$jscomp$1_navigator$jscomp$6_raw_format$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$compiled_format$jscomp$1_navigator$jscomp$6_raw_format$$,$navigator__$1$jscomp$1_vec__44009$$],null)};
$cljs$pprint$absolute_reposition$$=function($navigator$jscomp$7$$,$G__44024_position$jscomp$4$$){return $G__44024_position$jscomp$4$$>=$APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($navigator$jscomp$7$$)?($G__44024_position$jscomp$4$$=$APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($navigator$jscomp$7$$)-$G__44024_position$jscomp$4$$,$cljs$pprint$relative_reposition$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$pprint$relative_reposition$$.$cljs$core$IFn$_invoke$arity$2$($navigator$jscomp$7$$,
$G__44024_position$jscomp$4$$):$cljs$pprint$relative_reposition$$($navigator$jscomp$7$$,$G__44024_position$jscomp$4$$)):new $cljs$pprint$arg_navigator$$($cljs$cst$1425$seq$$.$cljs$core$IFn$_invoke$arity$1$($navigator$jscomp$7$$),$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($G__44024_position$jscomp$4$$,$cljs$cst$1425$seq$$.$cljs$core$IFn$_invoke$arity$1$($navigator$jscomp$7$$)),$G__44024_position$jscomp$4$$,null,null,null)};
$cljs$pprint$relative_reposition$$=function($navigator$jscomp$8$$,$position$jscomp$5$$){var $newpos$jscomp$3$$=$APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($navigator$jscomp$8$$)+$position$jscomp$5$$;return $position$jscomp$5$$<0?$cljs$pprint$absolute_reposition$$($navigator$jscomp$8$$,$newpos$jscomp$3$$):new $cljs$pprint$arg_navigator$$($cljs$cst$1425$seq$$.$cljs$core$IFn$_invoke$arity$1$($navigator$jscomp$8$$),$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($position$jscomp$5$$,
$cljs$cst$1426$rest$$.$cljs$core$IFn$_invoke$arity$1$($navigator$jscomp$8$$)),$newpos$jscomp$3$$,null,null,null)};
$cljs$pprint$compiled_directive$$=function($func$jscomp$20$$,$def$jscomp$1$$,$params$jscomp$16$$,$offset$jscomp$42$$,$__meta$jscomp$14$$,$__extmap$jscomp$14$$,$__hash$jscomp$69$$){this.$func$=$func$jscomp$20$$;this.$def$=$def$jscomp$1$$;this.params=$params$jscomp$16$$;this.offset=$offset$jscomp$42$$;this.$__meta$=$__meta$jscomp$14$$;this.$__extmap$=$__extmap$jscomp$14$$;this.$__hash$=$__hash$jscomp$69$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=
139264};
$cljs$pprint$realize_parameter$$=function($offset$jscomp$44_p__44186_vec__44194$$,$navigator$jscomp$9_real_param$$){var $param$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offset$jscomp$44_p__44186_vec__44194$$,0,null);$offset$jscomp$44_p__44186_vec__44194$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offset$jscomp$44_p__44186_vec__44194$$,1,null);var $new_navigator_raw_val_vec__44198$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offset$jscomp$44_p__44186_vec__44194$$,0,
null);$offset$jscomp$44_p__44186_vec__44194$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offset$jscomp$44_p__44186_vec__44194$$,1,null);$new_navigator_raw_val_vec__44198$$=$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null],null),null),$param$jscomp$9$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_navigator_raw_val_vec__44198$$,
$navigator$jscomp$9_real_param$$],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_navigator_raw_val_vec__44198$$,$cljs$cst$1434$parameter_from_args$$)?$cljs$pprint$next_arg$$($navigator$jscomp$9_real_param$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_navigator_raw_val_vec__44198$$,$cljs$cst$1435$remaining_arg_count$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$count$$($cljs$cst$1426$rest$$.$cljs$core$IFn$_invoke$arity$1$($navigator$jscomp$9_real_param$$)),
$navigator$jscomp$9_real_param$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_navigator_raw_val_vec__44198$$,$navigator$jscomp$9_real_param$$],null);$navigator$jscomp$9_real_param$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_navigator_raw_val_vec__44198$$,0,null);$new_navigator_raw_val_vec__44198$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_navigator_raw_val_vec__44198$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$param$jscomp$9$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$navigator$jscomp$9_real_param$$,$offset$jscomp$44_p__44186_vec__44194$$],null)],null),$new_navigator_raw_val_vec__44198$$],null)};
$cljs$pprint$realize_parameter_list$$=function($pairs$jscomp$4_parameter_map$$,$navigator$jscomp$10_new_navigator$jscomp$1_vec__44206$$){$navigator$jscomp$10_new_navigator$jscomp$1_vec__44206$$=$cljs$pprint$map_passing_context$$($cljs$pprint$realize_parameter$$,$navigator$jscomp$10_new_navigator$jscomp$1_vec__44206$$,$pairs$jscomp$4_parameter_map$$);$pairs$jscomp$4_parameter_map$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$10_new_navigator$jscomp$1_vec__44206$$,0,null);
$navigator$jscomp$10_new_navigator$jscomp$1_vec__44206$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$10_new_navigator$jscomp$1_vec__44206$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$pairs$jscomp$4_parameter_map$$),$navigator$jscomp$10_new_navigator$jscomp$1_vec__44206$$],null)};
$cljs$pprint$format_ascii$$=function($base_output_print_func$$,$params$jscomp$18$$,$arg_navigator_arg_navigator__$1_vec__44237$$){$arg_navigator_arg_navigator__$1_vec__44237$$=$cljs$pprint$next_arg$$($arg_navigator_arg_navigator__$1_vec__44237$$);var $arg$jscomp$14_base_width_chars$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($arg_navigator_arg_navigator__$1_vec__44237$$,0,null);$arg_navigator_arg_navigator__$1_vec__44237$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($arg_navigator_arg_navigator__$1_vec__44237$$,
1,null);if($APP.$cljs$core$integer_QMARK_$$($arg$jscomp$14_base_width_chars$jscomp$2$$))if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$pprint$_STAR_print_base_STAR_$$,10))var $JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($arg$jscomp$14_base_width_chars$jscomp$2$$),$APP.$cljs$core$truth_$$($cljs$pprint$_STAR_print_radix_STAR_$$)?
".":null].join("");else{$JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$=$APP.$cljs$core$str$$;var $JSCompiler_temp_const$jscomp$inline_11693$$=$JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$.$cljs$core$IFn$_invoke$arity$1$;if($APP.$cljs$core$truth_$$($cljs$pprint$_STAR_print_radix_STAR_$$)){var $JSCompiler_temp$jscomp$inline_11694_or__5025__auto__$jscomp$inline_11695$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cljs$pprint$special_radix_markers$$,$cljs$pprint$_STAR_print_base_STAR_$$);$JSCompiler_temp$jscomp$inline_11694_or__5025__auto__$jscomp$inline_11695$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$inline_11694_or__5025__auto__$jscomp$inline_11695$$)?$JSCompiler_temp$jscomp$inline_11694_or__5025__auto__$jscomp$inline_11695$$:["#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$pprint$_STAR_print_base_STAR_$$),"r"].join("")}else $JSCompiler_temp$jscomp$inline_11694_or__5025__auto__$jscomp$inline_11695$$=
null;$JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$=[$JSCompiler_temp_const$jscomp$inline_11693$$.call($JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$,$JSCompiler_temp$jscomp$inline_11694_or__5025__auto__$jscomp$inline_11695$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$pprint$base_str$$($cljs$pprint$_STAR_print_base_STAR_$$,
$arg$jscomp$14_base_width_chars$jscomp$2$$))].join("")}else $JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$=null;$base_output_print_func$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$)?$JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$:
$base_output_print_func$$.$cljs$core$IFn$_invoke$arity$1$?$base_output_print_func$$.$cljs$core$IFn$_invoke$arity$1$($arg$jscomp$14_base_width_chars$jscomp$2$$):$base_output_print_func$$($arg$jscomp$14_base_width_chars$jscomp$2$$);$arg$jscomp$14_base_width_chars$jscomp$2$$=$base_output_print_func$$.length;$JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$=$arg$jscomp$14_base_width_chars$jscomp$2$$+
$cljs$cst$1436$minpad$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$18$$);$JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$=$JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$>=$cljs$cst$1437$mincol$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$18$$)?
$JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$:$JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$+($APP.$cljs$core$quot$$($cljs$cst$1437$mincol$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$18$$)-$JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$-
1,$cljs$cst$1438$colinc$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$18$$))+1)*$cljs$cst$1438$colinc$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$18$$);$arg$jscomp$14_base_width_chars$jscomp$2$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$inline_11690_JSCompiler_temp$jscomp$inline_11691_JSCompiler_temp_const$jscomp$inline_11692_min_width_or__5025__auto__$jscomp$inline_4375_width$jscomp$32$$-
$arg$jscomp$14_base_width_chars$jscomp$2$$,$cljs$cst$1439$padchar$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$18$$)));$APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$18$$))?$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($arg$jscomp$14_base_width_chars$jscomp$2$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($base_output_print_func$$)].join("")])):
$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($base_output_print_func$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($arg$jscomp$14_base_width_chars$jscomp$2$$)].join("")]));return $arg_navigator_arg_navigator__$1_vec__44237$$};
$cljs$pprint$remainders$$=function($base$jscomp$19$$,$val$jscomp$149$$){return $APP.$cljs$core$reverse$$($APP.$cljs$core$first$$($cljs$pprint$consume$$(function($p1__44267_SHARP_$$){return $p1__44267_SHARP_$$>0?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$rem$$($p1__44267_SHARP_$$,$base$jscomp$19$$),$APP.$cljs$core$quot$$($p1__44267_SHARP_$$,$base$jscomp$19$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[null,null],null)},$val$jscomp$149$$)))};
$cljs$pprint$base_str$$=function($base$jscomp$20$$,$val$jscomp$150$$){return $val$jscomp$150$$===0?"0":$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__44281_SHARP_$$){return $p1__44281_SHARP_$$<10?$APP.$cljs$core$char$0$$($cljs$pprint$char_code$$("0")+$p1__44281_SHARP_$$):$APP.$cljs$core$char$0$$($cljs$pprint$char_code$$("a")+($p1__44281_SHARP_$$-10))},$cljs$pprint$remainders$$($base$jscomp$20$$,$val$jscomp$150$$)))};
$cljs$pprint$group_by_STAR_$$=function($unit$jscomp$4$$,$lis$jscomp$1$$){return $APP.$cljs$core$reverse$$($APP.$cljs$core$first$$($cljs$pprint$consume$$(function($x$jscomp$1029$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$seq$$($APP.$cljs$core$reverse$$($APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($unit$jscomp$4$$,$x$jscomp$1029$$))),$APP.$cljs$core$seq$$($APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($unit$jscomp$4$$,
$x$jscomp$1029$$))],null)},$APP.$cljs$core$reverse$$($lis$jscomp$1$$))))};
$cljs$pprint$format_integer$$=function($base$jscomp$22_group_str_45840_padded_str_45842_signed_str_45841$$,$params$jscomp$19$$,$arg_navigator$jscomp$1_arg_navigator__$1$jscomp$1_vec__44327$$){$arg_navigator$jscomp$1_arg_navigator__$1$jscomp$1_vec__44327$$=$cljs$pprint$next_arg$$($arg_navigator$jscomp$1_arg_navigator__$1$jscomp$1_vec__44327$$);var $arg$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($arg_navigator$jscomp$1_arg_navigator__$1$jscomp$1_vec__44327$$,0,null);$arg_navigator$jscomp$1_arg_navigator__$1$jscomp$1_vec__44327$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($arg_navigator$jscomp$1_arg_navigator__$1$jscomp$1_vec__44327$$,1,null);if($APP.$cljs$core$integer_QMARK_$$($arg$jscomp$15$$)||typeof $arg$jscomp$15$$==="number"&&!isNaN($arg$jscomp$15$$)&&$arg$jscomp$15$$!==Infinity&&parseFloat($arg$jscomp$15$$)!==parseInt($arg$jscomp$15$$,10)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($arg$jscomp$15$$,Math.floor($arg$jscomp$15$$))){var $neg_45837$$=$arg$jscomp$15$$<0,$raw_str_45839$$=$cljs$pprint$base_str$$($base$jscomp$22_group_str_45840_padded_str_45842_signed_str_45841$$,
$neg_45837$$?-$arg$jscomp$15$$:$arg$jscomp$15$$);$base$jscomp$22_group_str_45840_padded_str_45842_signed_str_45841$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$19$$))?function(){var $groups$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__44323_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$p1__44323_SHARP_$$)},$cljs$pprint$group_by_STAR_$$($cljs$cst$1440$commainterval$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$19$$),
$raw_str_45839$$)),$commas$$=$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$count$$($groups$$),$cljs$cst$1441$commachar$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$19$$));return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$next$$($APP.$cljs$core$interleave$$.$cljs$core$IFn$_invoke$arity$2$($commas$$,$groups$$)))}():$raw_str_45839$$;$base$jscomp$22_group_str_45840_padded_str_45842_signed_str_45841$$=$neg_45837$$?["-",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$22_group_str_45840_padded_str_45842_signed_str_45841$$)].join(""):$APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$19$$))?["+",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$22_group_str_45840_padded_str_45842_signed_str_45841$$)].join(""):$base$jscomp$22_group_str_45840_padded_str_45842_signed_str_45841$$;$base$jscomp$22_group_str_45840_padded_str_45842_signed_str_45841$$=
$base$jscomp$22_group_str_45840_padded_str_45842_signed_str_45841$$.length<$cljs$cst$1437$mincol$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$19$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$1437$mincol$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$19$$)-$base$jscomp$22_group_str_45840_padded_str_45842_signed_str_45841$$.length,$cljs$cst$1439$padchar$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$19$$)))),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$22_group_str_45840_padded_str_45842_signed_str_45841$$)].join(""):$base$jscomp$22_group_str_45840_padded_str_45842_signed_str_45841$$;$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$base$jscomp$22_group_str_45840_padded_str_45842_signed_str_45841$$]))}else $cljs$pprint$format_ascii$$($cljs$core$print_str$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1437$mincol$$,
$cljs$cst$1437$mincol$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$19$$),$cljs$cst$1438$colinc$$,1,$cljs$cst$1436$minpad$$,0,$cljs$cst$1439$padchar$$,$cljs$cst$1439$padchar$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$19$$),$cljs$cst$1433$at$$,!0],null),$cljs$pprint$init_navigator$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$arg$jscomp$15$$],null)));return $arg_navigator$jscomp$1_arg_navigator__$1$jscomp$1_vec__44327$$};
$cljs$pprint$format_simple_cardinal$$=function($num$jscomp$25_tens$$){var $hundreds$$=$APP.$cljs$core$quot$$($num$jscomp$25_tens$$,100);$num$jscomp$25_tens$$=$APP.$cljs$core$rem$$($num$jscomp$25_tens$$,100);var $JSCompiler_temp_const$jscomp$619$$=$hundreds$$>0?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$pprint$english_cardinal_units$$,$hundreds$$))," hundred"].join(""):null,$JSCompiler_temp_const$jscomp$618$$=$APP.$cljs$core$str$$,
$JSCompiler_temp_const$jscomp$617$$=$JSCompiler_temp_const$jscomp$618$$.$cljs$core$IFn$_invoke$arity$1$;if($num$jscomp$25_tens$$>0)if($num$jscomp$25_tens$$<20)var $JSCompiler_temp$jscomp$620_JSCompiler_temp$jscomp$621_ten_digit$jscomp$inline_4377$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$pprint$english_cardinal_units$$,$num$jscomp$25_tens$$);else{$JSCompiler_temp$jscomp$620_JSCompiler_temp$jscomp$621_ten_digit$jscomp$inline_4377$$=$APP.$cljs$core$quot$$($num$jscomp$25_tens$$,
10);var $unit_digit$jscomp$inline_4378$$=$APP.$cljs$core$rem$$($num$jscomp$25_tens$$,10);$JSCompiler_temp$jscomp$620_JSCompiler_temp$jscomp$621_ten_digit$jscomp$inline_4377$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$620_JSCompiler_temp$jscomp$621_ten_digit$jscomp$inline_4377$$>0?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$pprint$english_cardinal_tens$$,$JSCompiler_temp$jscomp$620_JSCompiler_temp$jscomp$621_ten_digit$jscomp$inline_4377$$):null),
$JSCompiler_temp$jscomp$620_JSCompiler_temp$jscomp$621_ten_digit$jscomp$inline_4377$$>0&&$unit_digit$jscomp$inline_4378$$>0?"-":null,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($unit_digit$jscomp$inline_4378$$>0?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$pprint$english_cardinal_units$$,$unit_digit$jscomp$inline_4378$$):null)].join("")}else $JSCompiler_temp$jscomp$620_JSCompiler_temp$jscomp$621_ten_digit$jscomp$inline_4377$$=null;return[$JSCompiler_temp_const$jscomp$619$$,
$hundreds$$>0&&$num$jscomp$25_tens$$>0?" ":null,$JSCompiler_temp_const$jscomp$617$$.call($JSCompiler_temp_const$jscomp$618$$,$JSCompiler_temp$jscomp$620_JSCompiler_temp$jscomp$621_ten_digit$jscomp$inline_4377$$)].join("")};
$cljs$pprint$add_english_scales$$=function($G__45849_parts$jscomp$18_remainder$jscomp$5$$,$offset$jscomp$45$$){var $G__45847_cnt$jscomp$45_pos$jscomp$91$$=$APP.$cljs$core$count$$($G__45849_parts$jscomp$18_remainder$jscomp$5$$),$G__45846_acc$jscomp$83$$=$APP.$cljs$core$PersistentVector$EMPTY$$;--$G__45847_cnt$jscomp$45_pos$jscomp$91$$;var $G__45848_this$$jscomp$552$$=$APP.$cljs$core$first$$($G__45849_parts$jscomp$18_remainder$jscomp$5$$);for($G__45849_parts$jscomp$18_remainder$jscomp$5$$=$APP.$cljs$core$next$$($G__45849_parts$jscomp$18_remainder$jscomp$5$$);;){if($G__45849_parts$jscomp$18_remainder$jscomp$5$$==
null)return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$interpose$cljs$0core$0IFn$0_invoke$0arity$02$$(", ",$G__45846_acc$jscomp$83$$))),$APP.$cljs$core$empty_QMARK_$$($G__45848_this$$jscomp$552$$)||$APP.$cljs$core$empty_QMARK_$$($G__45846_acc$jscomp$83$$)?null:", ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__45848_this$$jscomp$552$$),!$APP.$cljs$core$empty_QMARK_$$($G__45848_this$$jscomp$552$$)&&
$G__45847_cnt$jscomp$45_pos$jscomp$91$$+$offset$jscomp$45$$>0?[" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$pprint$english_scale_numbers$$,$G__45847_cnt$jscomp$45_pos$jscomp$91$$+$offset$jscomp$45$$))].join(""):null].join("");$G__45846_acc$jscomp$83$$=$APP.$cljs$core$empty_QMARK_$$($G__45848_this$$jscomp$552$$)?$G__45846_acc$jscomp$83$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__45846_acc$jscomp$83$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__45848_this$$jscomp$552$$),
" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$pprint$english_scale_numbers$$,$G__45847_cnt$jscomp$45_pos$jscomp$91$$+$offset$jscomp$45$$))].join(""));--$G__45847_cnt$jscomp$45_pos$jscomp$91$$;$G__45848_this$$jscomp$552$$=$APP.$cljs$core$first$$($G__45849_parts$jscomp$18_remainder$jscomp$5$$);$G__45849_parts$jscomp$18_remainder$jscomp$5$$=$APP.$cljs$core$next$$($G__45849_parts$jscomp$18_remainder$jscomp$5$$)}};
$cljs$pprint$format_roman$$=function($table$jscomp$1$$,$navigator$jscomp$13_navigator__$1$jscomp$4_vec__44499$$){$navigator$jscomp$13_navigator__$1$jscomp$4_vec__44499$$=$cljs$pprint$next_arg$$($navigator$jscomp$13_navigator__$1$jscomp$4_vec__44499$$);var $G__45879_acc_45875_arg$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$13_navigator__$1$jscomp$4_vec__44499$$,0,null);$navigator$jscomp$13_navigator__$1$jscomp$4_vec__44499$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$13_navigator__$1$jscomp$4_vec__44499$$,
1,null);if(typeof $G__45879_acc_45875_arg$jscomp$18$$==="number"&&$G__45879_acc_45875_arg$jscomp$18$$>0&&$G__45879_acc_45875_arg$jscomp$18$$<4E3){var $G__45881_digits_45874_digits_45877__$1$$=$cljs$pprint$remainders$$(10,$G__45879_acc_45875_arg$jscomp$18$$);$G__45879_acc_45875_arg$jscomp$18$$=$APP.$cljs$core$PersistentVector$EMPTY$$;for(var $G__45880_pos_45876$$=$APP.$cljs$core$count$$($G__45881_digits_45874_digits_45877__$1$$)-1;;)if($APP.$cljs$core$empty_QMARK_$$($G__45881_digits_45874_digits_45877__$1$$)){$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$G__45879_acc_45875_arg$jscomp$18$$)]));break}else{var $digit_45878$$=$APP.$cljs$core$first$$($G__45881_digits_45874_digits_45877__$1$$);$G__45879_acc_45875_arg$jscomp$18$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$digit_45878$$)?$G__45879_acc_45875_arg$jscomp$18$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__45879_acc_45875_arg$jscomp$18$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($table$jscomp$1$$,
$G__45880_pos_45876$$),$digit_45878$$-1));--$G__45880_pos_45876$$;$G__45881_digits_45874_digits_45877__$1$$=$APP.$cljs$core$next$$($G__45881_digits_45874_digits_45877__$1$$)}}else $cljs$pprint$format_integer$$(10,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1437$mincol$$,0,$cljs$cst$1439$padchar$$," ",$cljs$cst$1441$commachar$$,",",$cljs$cst$1440$commainterval$$,3,$APP.$cljs$cst$1432$colon$$,!0],null),$cljs$pprint$init_navigator$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$G__45879_acc_45875_arg$jscomp$18$$],null)));return $navigator$jscomp$13_navigator__$1$jscomp$4_vec__44499$$};
$cljs$pprint$pretty_character$$=function($navigator__$1$jscomp$5_params$jscomp$25_vec__44517$$,$base_char_c$jscomp$238_navigator$jscomp$16$$){$navigator__$1$jscomp$5_params$jscomp$25_vec__44517$$=$cljs$pprint$next_arg$$($base_char_c$jscomp$238_navigator$jscomp$16$$);$base_char_c$jscomp$238_navigator$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$5_params$jscomp$25_vec__44517$$,0,null);$navigator__$1$jscomp$5_params$jscomp$25_vec__44517$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$5_params$jscomp$25_vec__44517$$,
1,null);var $as_int_meta$jscomp$79$$=$cljs$pprint$char_code$$($base_char_c$jscomp$238_navigator$jscomp$16$$);$base_char_c$jscomp$238_navigator$jscomp$16$$=$as_int_meta$jscomp$79$$&127;$as_int_meta$jscomp$79$$&=128;var $special$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cljs$pprint$special_chars$$,$base_char_c$jscomp$238_navigator$jscomp$16$$);$as_int_meta$jscomp$79$$>0&&$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Meta-"]));
$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($special$$)?$special$$:$base_char_c$jscomp$238_navigator$jscomp$16$$<32?["Control-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$char$0$$($base_char_c$jscomp$238_navigator$jscomp$16$$+64))].join(""):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($base_char_c$jscomp$238_navigator$jscomp$16$$,127)?"Control-?":$APP.$cljs$core$char$0$$($base_char_c$jscomp$238_navigator$jscomp$16$$)]));
return $navigator__$1$jscomp$5_params$jscomp$25_vec__44517$$};
$cljs$pprint$readable_character$$=function($expr__44528_45883_params$jscomp$26$$,$c$jscomp$239_navigator$jscomp$17$$){var $navigator__$1$jscomp$6_vec__44524$$=$cljs$pprint$next_arg$$($c$jscomp$239_navigator$jscomp$17$$);$c$jscomp$239_navigator$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$6_vec__44524$$,0,null);$navigator__$1$jscomp$6_vec__44524$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$6_vec__44524$$,1,null);$expr__44528_45883_params$jscomp$26$$=
$cljs$cst$1442$char_format$$.$cljs$core$IFn$_invoke$arity$1$($expr__44528_45883_params$jscomp$26$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("o",$expr__44528_45883_params$jscomp$26$$):$APP.$cljs$core$_EQ_$$("o",$expr__44528_45883_params$jscomp$26$$)))$cljs$pprint$cl_format$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(!0,"\\o~3,'0o",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$pprint$char_code$$($c$jscomp$239_navigator$jscomp$17$$)]));
else if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("u",$expr__44528_45883_params$jscomp$26$$):$APP.$cljs$core$_EQ_$$("u",$expr__44528_45883_params$jscomp$26$$)))$cljs$pprint$cl_format$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(!0,"\\u~4,'0x",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$pprint$char_code$$($c$jscomp$239_navigator$jscomp$17$$)]));else if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$expr__44528_45883_params$jscomp$26$$):$APP.$cljs$core$_EQ_$$(null,$expr__44528_45883_params$jscomp$26$$)))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("\b",$c$jscomp$239_navigator$jscomp$17$$):$APP.$cljs$core$_EQ_$$("\b",$c$jscomp$239_navigator$jscomp$17$$))?"\\backspace":$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(" ",$c$jscomp$239_navigator$jscomp$17$$):$APP.$cljs$core$_EQ_$$(" ",$c$jscomp$239_navigator$jscomp$17$$))?"\\space":$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("\t",$c$jscomp$239_navigator$jscomp$17$$):$APP.$cljs$core$_EQ_$$("\t",$c$jscomp$239_navigator$jscomp$17$$))?"\\tab":$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("\n",$c$jscomp$239_navigator$jscomp$17$$):$APP.$cljs$core$_EQ_$$("\n",$c$jscomp$239_navigator$jscomp$17$$))?"\\newline":$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("\f",$c$jscomp$239_navigator$jscomp$17$$):$APP.$cljs$core$_EQ_$$("\f",$c$jscomp$239_navigator$jscomp$17$$))?"\\formfeed":$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("\r",$c$jscomp$239_navigator$jscomp$17$$):$APP.$cljs$core$_EQ_$$("\r",$c$jscomp$239_navigator$jscomp$17$$))?"\\return":$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$('"',$c$jscomp$239_navigator$jscomp$17$$):$APP.$cljs$core$_EQ_$$('"',$c$jscomp$239_navigator$jscomp$17$$))?'\\"':$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("\\",$c$jscomp$239_navigator$jscomp$17$$):$APP.$cljs$core$_EQ_$$("\\",$c$jscomp$239_navigator$jscomp$17$$))?"\\\\":["\\",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$239_navigator$jscomp$17$$)].join(""));else throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expr__44528_45883_params$jscomp$26$$)].join(""));return $navigator__$1$jscomp$6_vec__44524$$};
$cljs$pprint$plain_character$$=function($char$$jscomp$4_params$jscomp$27$$,$navigator$jscomp$18_navigator__$1$jscomp$7_vec__44535$$){$navigator$jscomp$18_navigator__$1$jscomp$7_vec__44535$$=$cljs$pprint$next_arg$$($navigator$jscomp$18_navigator__$1$jscomp$7_vec__44535$$);$char$$jscomp$4_params$jscomp$27$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$18_navigator__$1$jscomp$7_vec__44535$$,0,null);$navigator$jscomp$18_navigator__$1$jscomp$7_vec__44535$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$18_navigator__$1$jscomp$7_vec__44535$$,
1,null);$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$char$$jscomp$4_params$jscomp$27$$]));return $navigator$jscomp$18_navigator__$1$jscomp$7_vec__44535$$};
$cljs$pprint$abort_QMARK_$$=function($context$jscomp$15_token$jscomp$37$$){$context$jscomp$15_token$jscomp$37$$=$APP.$cljs$core$first$$($context$jscomp$15_token$jscomp$37$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1443$up_arrow$$,$context$jscomp$15_token$jscomp$37$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1444$colon_up_arrow$$,$context$jscomp$15_token$jscomp$37$$)};
$cljs$pprint$execute_sub_format$$=function($format$jscomp$22$$,$args$jscomp$214$$,$base_args$$){return $APP.$cljs$core$second$$($cljs$pprint$map_passing_context$$(function($element$jscomp$39$$,$args__$1$jscomp$5_context$jscomp$16_vec__44548$$){if($cljs$pprint$abort_QMARK_$$($args__$1$jscomp$5_context$jscomp$16_vec__44548$$))return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$args__$1$jscomp$5_context$jscomp$16_vec__44548$$],null);$args__$1$jscomp$5_context$jscomp$16_vec__44548$$=
$cljs$pprint$realize_parameter_list$$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($element$jscomp$39$$),$args__$1$jscomp$5_context$jscomp$16_vec__44548$$);var $params$jscomp$28_params__$1$jscomp$4_params__$2$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($args__$1$jscomp$5_context$jscomp$16_vec__44548$$,0,null);$args__$1$jscomp$5_context$jscomp$16_vec__44548$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($args__$1$jscomp$5_context$jscomp$16_vec__44548$$,
1,null);var $offsets$jscomp$10_vec__44551$$=$cljs$pprint$unzip_map$$($params$jscomp$28_params__$1$jscomp$4_params__$2$jscomp$2$$);$params$jscomp$28_params__$1$jscomp$4_params__$2$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offsets$jscomp$10_vec__44551$$,0,null);$offsets$jscomp$10_vec__44551$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offsets$jscomp$10_vec__44551$$,1,null);$params$jscomp$28_params__$1$jscomp$4_params__$2$jscomp$2$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($params$jscomp$28_params__$1$jscomp$4_params__$2$jscomp$2$$,
$cljs$cst$1445$base_args$$,$base_args$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1428$func$$.$cljs$core$IFn$_invoke$arity$1$($element$jscomp$39$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$params$jscomp$28_params__$1$jscomp$4_params__$2$jscomp$2$$,$args__$1$jscomp$5_context$jscomp$16_vec__44548$$,$offsets$jscomp$10_vec__44551$$],
null))],null)},$args$jscomp$214$$,$format$jscomp$22$$))};
$cljs$pprint$float_parts$$=function($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$){$e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$=$clojure$string$lower_case$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$));var $delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$=$e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$.indexOf("e"),$dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$=
$e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$.indexOf(".");$e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$=$delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$<0?$dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$<0?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$,
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$.length-1)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$,0,$dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$,
$dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$+1)].join(""),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$-1)],null):$dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$<0?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$,
0,$delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$,$delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$+1)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$,
0,1),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$,2,$delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$)].join(""),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$,$delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$+1)],null);$delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$,
0,null);$e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$,1,null);a:if($dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$=$APP.$cljs$core$count$$($delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$),$dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$>
0&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$,$APP.$cljs$core$count$$($delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$)-1),"0")){for(--$dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$;;){if($dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$<
0){$delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$="";break a}if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$,$dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$),"0"))--$dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$;else{$delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$=
$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$,0,$dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$+1);break a}}$delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$=void 0}a:{$dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$=$delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$;var $len$jscomp$inline_4395$$=
$APP.$cljs$core$count$$($dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$);if($len$jscomp$inline_4395$$>0&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$,0),"0")){for(var $n$jscomp$inline_4396$$=0;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($n$jscomp$inline_4396$$,
$len$jscomp$inline_4395$$)||!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$,$n$jscomp$inline_4396$$),"0")){$dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$,
$n$jscomp$inline_4396$$);break a}$n$jscomp$inline_4396$$+=1}$dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$=void 0}}$delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$=$APP.$cljs$core$count$$($delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$)-$APP.$cljs$core$count$$($dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$);$e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$=
$APP.$cljs$core$count$$($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$)>0&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$,0),"+")?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$,1):$e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$;
return $APP.$cljs$core$empty_QMARK_$$($dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["0",0],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$dotloc$jscomp$inline_4386_len$jscomp$inline_4390_m2$jscomp$4_n$jscomp$inline_4391_s$jscomp$inline_4393$$,parseInt($e$jscomp$209_e__$1$jscomp$7_f$jscomp$659_s$jscomp$inline_4384_vec__44565$$,
10)-$delta$jscomp$6_exploc$jscomp$inline_4385_m$jscomp$172_m1$jscomp$4$$],null)};
$cljs$pprint$round_str$$=function($expanded_m$jscomp$173_result$jscomp$136$$,$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$,$JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$,$round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$)?$JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$:
$round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$)){var $e1$jscomp$6_len$jscomp$68$$=$APP.$cljs$core$count$$($expanded_m$jscomp$173_result$jscomp$136$$);$round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$=$APP.$cljs$core$truth_$$($round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$)?2>$round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$?2:$round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$:0;$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$)?
$JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$=$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$+$JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$+1:$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$>=0?($JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$=
$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$+1,--$round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$,$JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$=$JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$>$round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$?
$JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$:$round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$):$JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$=$round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$+$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$;
var $len__$1$jscomp$2_vec__44573$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$,0)?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[["0",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expanded_m$jscomp$173_result$jscomp$136$$)].join(""),$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$+
1,1,$e1$jscomp$6_len$jscomp$68$$+1],null):new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$expanded_m$jscomp$173_result$jscomp$136$$,$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$,$JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$,$e1$jscomp$6_len$jscomp$68$$],null);$JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($len__$1$jscomp$2_vec__44573$$,0,null);$e1$jscomp$6_len$jscomp$68$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($len__$1$jscomp$2_vec__44573$$,1,null);$round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($len__$1$jscomp$2_vec__44573$$,2,null);$len__$1$jscomp$2_vec__44573$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($len__$1$jscomp$2_vec__44573$$,
3,null);if($APP.$cljs$core$truth_$$($round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$)){if($round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$<0)return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["0",0,!1],null);if($len__$1$jscomp$2_vec__44573$$>$round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$){$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$,
$round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$);$expanded_m$jscomp$173_result$jscomp$136$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$,0,$round_pos__$1_w$jscomp$16_w__$1_y__5111__auto__$jscomp$inline_11698$$);if($cljs$pprint$char_code$$($e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$)>=$cljs$pprint$char_code$$("5")){a:{$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$=
$APP.$cljs$core$count$$($expanded_m$jscomp$173_result$jscomp$136$$)-1;for($JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$=$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$|0;;){if($JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$<0){$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$=
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$str$$,"1",$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$+1,"0"));break a}if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("9",$expanded_m$jscomp$173_result$jscomp$136$$.charAt($JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$)))--$JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$;
else{$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$str$$,$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($expanded_m$jscomp$173_result$jscomp$136$$,0,$JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$),$APP.$cljs$core$char$0$$($cljs$pprint$char_code$$($expanded_m$jscomp$173_result$jscomp$136$$.charAt($JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$))+
1),$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$-$JSCompiler_temp$jscomp$10728_JSCompiler_temp$jscomp$10729_d$jscomp$191_i$jscomp$inline_14201_m1$jscomp$5_round_pos_x__5110__auto__$jscomp$inline_11697$$,"0"));break a}}$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$=void 0}$expanded_m$jscomp$173_result$jscomp$136$$=$APP.$cljs$core$count$$($e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$)>
$expanded_m$jscomp$173_result$jscomp$136$$.length;return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$expanded_m$jscomp$173_result$jscomp$136$$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$,0,$APP.$cljs$core$count$$($e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$)-1):$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$,$e1$jscomp$6_len$jscomp$68$$,
$expanded_m$jscomp$173_result$jscomp$136$$],null)}return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$expanded_m$jscomp$173_result$jscomp$136$$,$e1$jscomp$6_len$jscomp$68$$,!1],null)}}}return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$expanded_m$jscomp$173_result$jscomp$136$$,$e$jscomp$210_len_1$jscomp$inline_14200_round_char_round_up_result$$,!1],null)};
$cljs$pprint$get_fixed$$=function($m$jscomp$176_m1$jscomp$inline_4402$$,$JSCompiler_inline_result$jscomp$630_e$jscomp$213_loc$jscomp$inline_4409$$,$JSCompiler_inline_result$jscomp$629_d$jscomp$193_target_len$jscomp$inline_4405$$){var $len$jscomp$inline_4404_vec__44582$jscomp$inline_4401$$=$JSCompiler_inline_result$jscomp$630_e$jscomp$213_loc$jscomp$inline_4409$$<0?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$(-$JSCompiler_inline_result$jscomp$630_e$jscomp$213_loc$jscomp$inline_4409$$-1,"0"))),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($m$jscomp$176_m1$jscomp$inline_4402$$)].join(""),-1],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$m$jscomp$176_m1$jscomp$inline_4402$$,$JSCompiler_inline_result$jscomp$630_e$jscomp$213_loc$jscomp$inline_4409$$],null);$m$jscomp$176_m1$jscomp$inline_4402$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($len$jscomp$inline_4404_vec__44582$jscomp$inline_4401$$,0,null);var $e1$jscomp$inline_4403$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($len$jscomp$inline_4404_vec__44582$jscomp$inline_4401$$,1,null);$len$jscomp$inline_4404_vec__44582$jscomp$inline_4401$$=$APP.$cljs$core$count$$($m$jscomp$176_m1$jscomp$inline_4402$$);$JSCompiler_inline_result$jscomp$629_d$jscomp$193_target_len$jscomp$inline_4405$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$629_d$jscomp$193_target_len$jscomp$inline_4405$$)?
$e1$jscomp$inline_4403$$+$JSCompiler_inline_result$jscomp$629_d$jscomp$193_target_len$jscomp$inline_4405$$+1:$e1$jscomp$inline_4403$$+1;$JSCompiler_inline_result$jscomp$629_d$jscomp$193_target_len$jscomp$inline_4405$$=$len$jscomp$inline_4404_vec__44582$jscomp$inline_4401$$<$JSCompiler_inline_result$jscomp$629_d$jscomp$193_target_len$jscomp$inline_4405$$?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($m$jscomp$176_m1$jscomp$inline_4402$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$629_d$jscomp$193_target_len$jscomp$inline_4405$$-$len$jscomp$inline_4404_vec__44582$jscomp$inline_4401$$,"0")))].join(""):$m$jscomp$176_m1$jscomp$inline_4402$$;$JSCompiler_inline_result$jscomp$630_e$jscomp$213_loc$jscomp$inline_4409$$<0?$JSCompiler_inline_result$jscomp$630_e$jscomp$213_loc$jscomp$inline_4409$$=[".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$629_d$jscomp$193_target_len$jscomp$inline_4405$$)].join(""):
($JSCompiler_inline_result$jscomp$630_e$jscomp$213_loc$jscomp$inline_4409$$+=1,$JSCompiler_inline_result$jscomp$630_e$jscomp$213_loc$jscomp$inline_4409$$=[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$629_d$jscomp$193_target_len$jscomp$inline_4405$$,0,$JSCompiler_inline_result$jscomp$630_e$jscomp$213_loc$jscomp$inline_4409$$),".",$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$629_d$jscomp$193_target_len$jscomp$inline_4405$$,
$JSCompiler_inline_result$jscomp$630_e$jscomp$213_loc$jscomp$inline_4409$$)].join(""));return $JSCompiler_inline_result$jscomp$630_e$jscomp$213_loc$jscomp$inline_4409$$};
$cljs$pprint$insert_scaled_decimal$$=function($m$jscomp$177$$,$k$jscomp$565$$){return $k$jscomp$565$$<0?[".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($m$jscomp$177$$)].join(""):[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$177$$,0,$k$jscomp$565$$),".",$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$177$$,$k$jscomp$565$$)].join("")};
$cljs$pprint$fixed_float$$=function($params$jscomp$29$$,$navigator$jscomp$19_navigator__$1$jscomp$8_vec__44605$$){var $w$jscomp$17$$=$cljs$cst$1446$w$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$29$$),$d$jscomp$194_fixed_repr__$1$$=$cljs$cst$1447$d$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$29$$);$navigator$jscomp$19_navigator__$1$jscomp$8_vec__44605$$=$cljs$pprint$next_arg$$($navigator$jscomp$19_navigator__$1$jscomp$8_vec__44605$$);var $arg$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$19_navigator__$1$jscomp$8_vec__44605$$,
0,null);$navigator$jscomp$19_navigator__$1$jscomp$8_vec__44605$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$19_navigator__$1$jscomp$8_vec__44605$$,1,null);var $abs_add_sign_vec__44608_vec__44611$$=$arg$jscomp$19$$<0?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["-",-$arg$jscomp$19$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["+",$arg$jscomp$19$$],null),$sign$jscomp$8$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($abs_add_sign_vec__44608_vec__44611$$,0,null);$abs_add_sign_vec__44608_vec__44611$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($abs_add_sign_vec__44608_vec__44611$$,1,null);$abs_add_sign_vec__44608_vec__44611$$=$cljs$pprint$float_parts$$($abs_add_sign_vec__44608_vec__44611$$);var $fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($abs_add_sign_vec__44608_vec__44611$$,
0,null),$prepend_zero_prepend_zero_45901__$1_scaled_exp_scaled_exp__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($abs_add_sign_vec__44608_vec__44611$$,1,null)+$cljs$cst$733$k$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$29$$);$abs_add_sign_vec__44608_vec__44611$$=function(){var $or__5025__auto__$jscomp$271$$=$cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$29$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$271$$)?$or__5025__auto__$jscomp$271$$:$arg$jscomp$19$$<
0}();var $append_zero_append_zero_45902__$1$$=$APP.$cljs$core$not$$($d$jscomp$194_fixed_repr__$1$$)&&$APP.$cljs$core$count$$($fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$)-1<=$prepend_zero_prepend_zero_45901__$1_scaled_exp_scaled_exp__$1$$,$expanded$jscomp$1_vec__44614$$=$cljs$pprint$round_str$$($fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$,$prepend_zero_prepend_zero_45901__$1_scaled_exp_scaled_exp__$1$$,$d$jscomp$194_fixed_repr__$1$$,$APP.$cljs$core$truth_$$($w$jscomp$17$$)?
$w$jscomp$17$$-($APP.$cljs$core$truth_$$($abs_add_sign_vec__44608_vec__44611$$)?1:0):null);$fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($expanded$jscomp$1_vec__44614$$,0,null);$prepend_zero_prepend_zero_45901__$1_scaled_exp_scaled_exp__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($expanded$jscomp$1_vec__44614$$,1,null);$expanded$jscomp$1_vec__44614$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($expanded$jscomp$1_vec__44614$$,
2,null);$fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$=$cljs$pprint$get_fixed$$($fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$,$APP.$cljs$core$truth_$$($expanded$jscomp$1_vec__44614$$)?$prepend_zero_prepend_zero_45901__$1_scaled_exp_scaled_exp__$1$$+1:$prepend_zero_prepend_zero_45901__$1_scaled_exp_scaled_exp__$1$$,$d$jscomp$194_fixed_repr__$1$$);$d$jscomp$194_fixed_repr__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($w$jscomp$17$$)?$APP.$cljs$core$truth_$$($d$jscomp$194_fixed_repr__$1$$)?
$d$jscomp$194_fixed_repr__$1$$>=1&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$.charAt(0),"0")&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$.charAt(1),".")&&$fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$.length>$w$jscomp$17$$-($APP.$cljs$core$truth_$$($abs_add_sign_vec__44608_vec__44611$$)?1:0):$d$jscomp$194_fixed_repr__$1$$:
$w$jscomp$17$$)?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$,1):$fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$;$prepend_zero_prepend_zero_45901__$1_scaled_exp_scaled_exp__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($d$jscomp$194_fixed_repr__$1$$),".");if($APP.$cljs$core$truth_$$($w$jscomp$17$$)){$fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$=
$d$jscomp$194_fixed_repr__$1$$.length;$fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$=$APP.$cljs$core$truth_$$($abs_add_sign_vec__44608_vec__44611$$)?$fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$+1:$fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$;$prepend_zero_prepend_zero_45901__$1_scaled_exp_scaled_exp__$1$$=$prepend_zero_prepend_zero_45901__$1_scaled_exp_scaled_exp__$1$$&&!($fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$>=
$w$jscomp$17$$);$append_zero_append_zero_45902__$1$$=$append_zero_append_zero_45902__$1$$&&!($fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$>=$w$jscomp$17$$);var $full_len_45903$$=$prepend_zero_prepend_zero_45901__$1_scaled_exp_scaled_exp__$1$$||$append_zero_append_zero_45902__$1$$?$fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$+1:$fixed_repr_len_45899_mantissa_rounded_mantissa_signed_len_45900$$;$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$177$$=
$full_len_45903$$>$w$jscomp$17$$;return $and__5023__auto__$jscomp$177$$?$cljs$cst$1448$overflowchar$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$29$$):$and__5023__auto__$jscomp$177$$}())?$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($w$jscomp$17$$,$cljs$cst$1448$overflowchar$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$29$$)))])):
$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($w$jscomp$17$$-$full_len_45903$$,$cljs$cst$1439$padchar$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$29$$)))),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($abs_add_sign_vec__44608_vec__44611$$)?
$sign$jscomp$8$$:null),$prepend_zero_prepend_zero_45901__$1_scaled_exp_scaled_exp__$1$$?"0":null,$d$jscomp$194_fixed_repr__$1$$,$append_zero_append_zero_45902__$1$$?"0":null].join("")]))}else $cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($abs_add_sign_vec__44608_vec__44611$$)?$sign$jscomp$8$$:null),$prepend_zero_prepend_zero_45901__$1_scaled_exp_scaled_exp__$1$$?
"0":null,$d$jscomp$194_fixed_repr__$1$$,$append_zero_append_zero_45902__$1$$?"0":null].join("")]));return $navigator$jscomp$19_navigator__$1$jscomp$8_vec__44605$$};
$cljs$pprint$exponential_float$$=function($params$jscomp$30$$,$navigator$jscomp$20_navigator__$1$jscomp$9_vec__44647$$){$navigator$jscomp$20_navigator__$1$jscomp$9_vec__44647$$=$cljs$pprint$next_arg$$($navigator$jscomp$20_navigator__$1$jscomp$9_vec__44647$$);var $arg$jscomp$20$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$20_navigator__$1$jscomp$9_vec__44647$$,0,null);$navigator$jscomp$20_navigator__$1$jscomp$9_vec__44647$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$20_navigator__$1$jscomp$9_vec__44647$$,
1,null);var $G__44653_45907_G__44653_45915__$1_add_sign_45924_vec__44657_45916$$=$cljs$pprint$float_parts$$($arg$jscomp$20$$<0?-$arg$jscomp$20$$:$arg$jscomp$20$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__44653_45907_G__44653_45915__$1_add_sign_45924_vec__44657_45916$$,0,null);for($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__44653_45907_G__44653_45915__$1_add_sign_45924_vec__44657_45916$$,1,null);;){var $full_mantissa_45937_mantissa_45917__$1_scaled_mantissa_45931_vec__44662_45933$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__44653_45907_G__44653_45915__$1_add_sign_45924_vec__44657_45916$$,0,null),$append_zero_45948__$1_exp_45918__$1_len_45944_signed_len_45945$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__44653_45907_G__44653_45915__$1_add_sign_45924_vec__44657_45916$$,1,null),$w_45919$$=$cljs$cst$1446$w$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$30$$),$append_zero_45938_d_45920$$=$cljs$cst$1447$d$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$30$$),
$e_45921$$=$cljs$cst$1449$e$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$30$$),$k_45922$$=$cljs$cst$733$k$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$30$$),$expchar_45923_scaled_exp_str_45928__$1$$=function(){var $or__5025__auto__$jscomp$272$$=$cljs$cst$1450$exponentchar$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$30$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$272$$)?$or__5025__auto__$jscomp$272$$:"E"}();$G__44653_45907_G__44653_45915__$1_add_sign_45924_vec__44657_45916$$=
function(){var $or__5025__auto__$jscomp$273$$=$cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$30$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$273$$)?$or__5025__auto__$jscomp$273$$:$arg$jscomp$20$$<0}();var $prepend_zero_45925_prepend_zero_45946__$1$$=$k_45922$$<=0,$base_mantissa_width_45930_rounded_mantissa_45934_scaled_exp_45926_w_mantissa_45932$$=$append_zero_45948__$1_exp_45918__$1_len_45944_signed_len_45945$$-($k_45922$$-1),$incr_exp_45936_scaled_exp_str_45927$$=
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(Math.abs($base_mantissa_width_45930_rounded_mantissa_45934_scaled_exp_45926_w_mantissa_45932$$));$expchar_45923_scaled_exp_str_45928__$1$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expchar_45923_scaled_exp_str_45928__$1$$),$base_mantissa_width_45930_rounded_mantissa_45934_scaled_exp_45926_w_mantissa_45932$$<0?"-":"+",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($e_45921$$)?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($e_45921$$-$incr_exp_45936_scaled_exp_str_45927$$.length,"0")):null),$incr_exp_45936_scaled_exp_str_45927$$].join("");var $exp_width_45929$$=$expchar_45923_scaled_exp_str_45928__$1$$.length;$base_mantissa_width_45930_rounded_mantissa_45934_scaled_exp_45926_w_mantissa_45932$$=$APP.$cljs$core$count$$($full_mantissa_45937_mantissa_45917__$1_scaled_mantissa_45931_vec__44662_45933$$);$full_mantissa_45937_mantissa_45917__$1_scaled_mantissa_45931_vec__44662_45933$$=
[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$(-$k_45922$$,"0"))),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($full_mantissa_45937_mantissa_45917__$1_scaled_mantissa_45931_vec__44662_45933$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($append_zero_45938_d_45920$$)?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($append_zero_45938_d_45920$$-($base_mantissa_width_45930_rounded_mantissa_45934_scaled_exp_45926_w_mantissa_45932$$-1)-($k_45922$$<0?-$k_45922$$:0),"0")):null)].join("");$base_mantissa_width_45930_rounded_mantissa_45934_scaled_exp_45926_w_mantissa_45932$$=$APP.$cljs$core$truth_$$($w_45919$$)?$w_45919$$-$exp_width_45929$$:null;$full_mantissa_45937_mantissa_45917__$1_scaled_mantissa_45931_vec__44662_45933$$=$cljs$pprint$round_str$$($full_mantissa_45937_mantissa_45917__$1_scaled_mantissa_45931_vec__44662_45933$$,
0,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k_45922$$,0)?$append_zero_45938_d_45920$$-1:$k_45922$$>0?$append_zero_45938_d_45920$$:$k_45922$$<0?$append_zero_45938_d_45920$$-1:null,$APP.$cljs$core$truth_$$($base_mantissa_width_45930_rounded_mantissa_45934_scaled_exp_45926_w_mantissa_45932$$)?$base_mantissa_width_45930_rounded_mantissa_45934_scaled_exp_45926_w_mantissa_45932$$-($APP.$cljs$core$truth_$$($G__44653_45907_G__44653_45915__$1_add_sign_45924_vec__44657_45916$$)?1:0):null);$base_mantissa_width_45930_rounded_mantissa_45934_scaled_exp_45926_w_mantissa_45932$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($full_mantissa_45937_mantissa_45917__$1_scaled_mantissa_45931_vec__44662_45933$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($full_mantissa_45937_mantissa_45917__$1_scaled_mantissa_45931_vec__44662_45933$$,1,null);$incr_exp_45936_scaled_exp_str_45927$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($full_mantissa_45937_mantissa_45917__$1_scaled_mantissa_45931_vec__44662_45933$$,2,null);$full_mantissa_45937_mantissa_45917__$1_scaled_mantissa_45931_vec__44662_45933$$=
$cljs$pprint$insert_scaled_decimal$$($base_mantissa_width_45930_rounded_mantissa_45934_scaled_exp_45926_w_mantissa_45932$$,$k_45922$$);$append_zero_45938_d_45920$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k_45922$$,$APP.$cljs$core$count$$($base_mantissa_width_45930_rounded_mantissa_45934_scaled_exp_45926_w_mantissa_45932$$))&&$append_zero_45938_d_45920$$==null;if($APP.$cljs$core$not$$($incr_exp_45936_scaled_exp_str_45927$$)){if($APP.$cljs$core$truth_$$($w_45919$$)){$append_zero_45948__$1_exp_45918__$1_len_45944_signed_len_45945$$=
$full_mantissa_45937_mantissa_45917__$1_scaled_mantissa_45931_vec__44662_45933$$.length+$exp_width_45929$$;$append_zero_45948__$1_exp_45918__$1_len_45944_signed_len_45945$$=$APP.$cljs$core$truth_$$($G__44653_45907_G__44653_45915__$1_add_sign_45924_vec__44657_45916$$)?$append_zero_45948__$1_exp_45918__$1_len_45944_signed_len_45945$$+1:$append_zero_45948__$1_exp_45918__$1_len_45944_signed_len_45945$$;var $full_len_45947$$=($prepend_zero_45925_prepend_zero_45946__$1$$=$prepend_zero_45925_prepend_zero_45946__$1$$&&
!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($append_zero_45948__$1_exp_45918__$1_len_45944_signed_len_45945$$,$w_45919$$))?$append_zero_45948__$1_exp_45918__$1_len_45944_signed_len_45945$$+1:$append_zero_45948__$1_exp_45918__$1_len_45944_signed_len_45945$$;$append_zero_45948__$1_exp_45918__$1_len_45944_signed_len_45945$$=$append_zero_45938_d_45920$$&&$full_len_45947$$<$w_45919$$;$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$178_and__5023__auto__$jscomp$inline_4412_or__5025__auto__$jscomp$inline_4411$$=
$full_len_45947$$>$w_45919$$;$and__5023__auto__$jscomp$178_and__5023__auto__$jscomp$inline_4412_or__5025__auto__$jscomp$inline_4411$$||($and__5023__auto__$jscomp$178_and__5023__auto__$jscomp$inline_4412_or__5025__auto__$jscomp$inline_4411$$=$e_45921$$,$and__5023__auto__$jscomp$178_and__5023__auto__$jscomp$inline_4412_or__5025__auto__$jscomp$inline_4411$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$178_and__5023__auto__$jscomp$inline_4412_or__5025__auto__$jscomp$inline_4411$$)?$exp_width_45929$$-
2>$e_45921$$:$and__5023__auto__$jscomp$178_and__5023__auto__$jscomp$inline_4412_or__5025__auto__$jscomp$inline_4411$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$178_and__5023__auto__$jscomp$inline_4412_or__5025__auto__$jscomp$inline_4411$$)?$cljs$cst$1448$overflowchar$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$30$$):$and__5023__auto__$jscomp$178_and__5023__auto__$jscomp$inline_4412_or__5025__auto__$jscomp$inline_4411$$}())?$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($w_45919$$,$cljs$cst$1448$overflowchar$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$30$$)))])):$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($w_45919$$-$full_len_45947$$-
($append_zero_45948__$1_exp_45918__$1_len_45944_signed_len_45945$$?1:0),$cljs$cst$1439$padchar$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$30$$)))),$APP.$cljs$core$truth_$$($G__44653_45907_G__44653_45915__$1_add_sign_45924_vec__44657_45916$$)?$arg$jscomp$20$$<0?"-":"+":null,$prepend_zero_45925_prepend_zero_45946__$1$$?"0":null,$full_mantissa_45937_mantissa_45917__$1_scaled_mantissa_45931_vec__44662_45933$$,$append_zero_45948__$1_exp_45918__$1_len_45944_signed_len_45945$$?"0":null,$expchar_45923_scaled_exp_str_45928__$1$$].join("")]))}else $cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[$APP.$cljs$core$truth_$$($G__44653_45907_G__44653_45915__$1_add_sign_45924_vec__44657_45916$$)?
$arg$jscomp$20$$<0?"-":"+":null,$prepend_zero_45925_prepend_zero_45946__$1$$?"0":null,$full_mantissa_45937_mantissa_45917__$1_scaled_mantissa_45931_vec__44662_45933$$,$append_zero_45938_d_45920$$?"0":null,$expchar_45923_scaled_exp_str_45928__$1$$].join("")]));break}else $G__44653_45907_G__44653_45915__$1_add_sign_45924_vec__44657_45916$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$base_mantissa_width_45930_rounded_mantissa_45934_scaled_exp_45926_w_mantissa_45932$$,
$append_zero_45948__$1_exp_45918__$1_len_45944_signed_len_45945$$+1],null)}return $navigator$jscomp$20_navigator__$1$jscomp$9_vec__44647$$};
$cljs$pprint$general_float$$=function($navigator__$1$jscomp$10_params$jscomp$31$$,$navigator$jscomp$21$$,$offsets$jscomp$12$$){var $dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$=$cljs$pprint$next_arg$$($navigator$jscomp$21$$),$arg$jscomp$21_ee$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$,1,null);$dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$=
$cljs$pprint$float_parts$$($arg$jscomp$21_ee$$<0?-$arg$jscomp$21_ee$$:$arg$jscomp$21_ee$$);var $JSCompiler_temp$jscomp$10730_d__$1$jscomp$1_mantissa$jscomp$1_x__5110__auto__$jscomp$inline_11700$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$,0,null);$dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$,1,null);var $w$jscomp$18_ww$$=
$cljs$cst$1446$w$$.$cljs$core$IFn$_invoke$arity$1$($navigator__$1$jscomp$10_params$jscomp$31$$),$d$jscomp$195_y__5111__auto__$jscomp$inline_11701$$=$cljs$cst$1447$d$$.$cljs$core$IFn$_invoke$arity$1$($navigator__$1$jscomp$10_params$jscomp$31$$),$e$jscomp$214$$=$cljs$cst$1449$e$$.$cljs$core$IFn$_invoke$arity$1$($navigator__$1$jscomp$10_params$jscomp$31$$);$dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($arg$jscomp$21_ee$$,0)?0:$dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$+
1;$arg$jscomp$21_ee$$=$APP.$cljs$core$truth_$$($e$jscomp$214$$)?$e$jscomp$214$$+2:4;$w$jscomp$18_ww$$=$APP.$cljs$core$truth_$$($w$jscomp$18_ww$$)?$w$jscomp$18_ww$$-$arg$jscomp$21_ee$$:null;$APP.$cljs$core$truth_$$($d$jscomp$195_y__5111__auto__$jscomp$inline_11701$$)?$JSCompiler_temp$jscomp$10730_d__$1$jscomp$1_mantissa$jscomp$1_x__5110__auto__$jscomp$inline_11700$$=$d$jscomp$195_y__5111__auto__$jscomp$inline_11701$$:($JSCompiler_temp$jscomp$10730_d__$1$jscomp$1_mantissa$jscomp$1_x__5110__auto__$jscomp$inline_11700$$=
$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$10730_d__$1$jscomp$1_mantissa$jscomp$1_x__5110__auto__$jscomp$inline_11700$$),$d$jscomp$195_y__5111__auto__$jscomp$inline_11701$$=$dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$<7?$dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$:7,$JSCompiler_temp$jscomp$10730_d__$1$jscomp$1_mantissa$jscomp$1_x__5110__auto__$jscomp$inline_11700$$=$JSCompiler_temp$jscomp$10730_d__$1$jscomp$1_mantissa$jscomp$1_x__5110__auto__$jscomp$inline_11700$$>$d$jscomp$195_y__5111__auto__$jscomp$inline_11701$$?
$JSCompiler_temp$jscomp$10730_d__$1$jscomp$1_mantissa$jscomp$1_x__5110__auto__$jscomp$inline_11700$$:$d$jscomp$195_y__5111__auto__$jscomp$inline_11701$$);$dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$=$JSCompiler_temp$jscomp$10730_d__$1$jscomp$1_mantissa$jscomp$1_x__5110__auto__$jscomp$inline_11700$$-$dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$;return 0<=$dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$&&$dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$<=$JSCompiler_temp$jscomp$10730_d__$1$jscomp$1_mantissa$jscomp$1_x__5110__auto__$jscomp$inline_11700$$?
($navigator__$1$jscomp$10_params$jscomp$31$$=$cljs$pprint$fixed_float$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$1446$w$$,$w$jscomp$18_ww$$,$cljs$cst$1447$d$$,$dd_exp$jscomp$8_n$jscomp$267_vec__44685_vec__44688$$,$cljs$cst$733$k$$,0,$cljs$cst$1448$overflowchar$$,$cljs$cst$1448$overflowchar$$.$cljs$core$IFn$_invoke$arity$1$($navigator__$1$jscomp$10_params$jscomp$31$$),$cljs$cst$1439$padchar$$,$cljs$cst$1439$padchar$$.$cljs$core$IFn$_invoke$arity$1$($navigator__$1$jscomp$10_params$jscomp$31$$),
$cljs$cst$1433$at$$,$cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($navigator__$1$jscomp$10_params$jscomp$31$$)],null),$navigator$jscomp$21$$,$offsets$jscomp$12$$),$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($arg$jscomp$21_ee$$," "))])),$navigator__$1$jscomp$10_params$jscomp$31$$):
$cljs$pprint$exponential_float$$($navigator__$1$jscomp$10_params$jscomp$31$$,$navigator$jscomp$21$$,$offsets$jscomp$12$$)};
$cljs$pprint$dollar_float$$=function($params$jscomp$32$$,$navigator$jscomp$22_navigator__$1$jscomp$11_vec__44699$$){$navigator$jscomp$22_navigator__$1$jscomp$11_vec__44699$$=$cljs$pprint$next_arg$$($navigator$jscomp$22_navigator__$1$jscomp$11_vec__44699$$);var $arg$jscomp$22$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$22_navigator__$1$jscomp$11_vec__44699$$,0,null);$navigator$jscomp$22_navigator__$1$jscomp$11_vec__44699$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$22_navigator__$1$jscomp$11_vec__44699$$,
1,null);var $vec__44702_w$jscomp$19$$=$cljs$pprint$float_parts$$(Math.abs($arg$jscomp$22$$)),$mantissa$jscomp$2_rounded_mantissa$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__44702_w$jscomp$19$$,0,null),$exp$jscomp$9_scaled_exp$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__44702_w$jscomp$19$$,1,null),$d$jscomp$196_fixed_repr$jscomp$1_full_len$$=$cljs$cst$1447$d$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$32$$),$full_repr_n$jscomp$268$$=
$cljs$cst$1451$n$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$32$$);$vec__44702_w$jscomp$19$$=$cljs$cst$1446$w$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$32$$);var $add_sign$jscomp$1$$=function(){var $or__5025__auto__$jscomp$275$$=$cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$32$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$275$$)?$or__5025__auto__$jscomp$275$$:$arg$jscomp$22$$<0}(),$expanded$jscomp$2_vec__44705$$=$cljs$pprint$round_str$$($mantissa$jscomp$2_rounded_mantissa$jscomp$1$$,
$exp$jscomp$9_scaled_exp$jscomp$1$$,$d$jscomp$196_fixed_repr$jscomp$1_full_len$$,null);$mantissa$jscomp$2_rounded_mantissa$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($expanded$jscomp$2_vec__44705$$,0,null);$exp$jscomp$9_scaled_exp$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($expanded$jscomp$2_vec__44705$$,1,null);$expanded$jscomp$2_vec__44705$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($expanded$jscomp$2_vec__44705$$,2,null);$d$jscomp$196_fixed_repr$jscomp$1_full_len$$=
$cljs$pprint$get_fixed$$($mantissa$jscomp$2_rounded_mantissa$jscomp$1$$,$APP.$cljs$core$truth_$$($expanded$jscomp$2_vec__44705$$)?$exp$jscomp$9_scaled_exp$jscomp$1$$+1:$exp$jscomp$9_scaled_exp$jscomp$1$$,$d$jscomp$196_fixed_repr$jscomp$1_full_len$$);$full_repr_n$jscomp$268$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($full_repr_n$jscomp$268$$-$d$jscomp$196_fixed_repr$jscomp$1_full_len$$.indexOf("."),
"0"))),$d$jscomp$196_fixed_repr$jscomp$1_full_len$$].join("");$d$jscomp$196_fixed_repr$jscomp$1_full_len$$=$full_repr_n$jscomp$268$$.length+($APP.$cljs$core$truth_$$($add_sign$jscomp$1$$)?1:0);$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$180$$=$APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$32$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$180$$)?
$add_sign$jscomp$1$$:$and__5023__auto__$jscomp$180$$}())?$arg$jscomp$22$$<0?"-":"+":null,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($vec__44702_w$jscomp$19$$-$d$jscomp$196_fixed_repr$jscomp$1_full_len$$,$cljs$cst$1439$padchar$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$32$$)))),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$181$$=
$APP.$cljs$core$not$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$32$$));return $and__5023__auto__$jscomp$181$$?$add_sign$jscomp$1$$:$and__5023__auto__$jscomp$181$$}())?$arg$jscomp$22$$<0?"-":"+":null,$full_repr_n$jscomp$268$$].join("")]));return $navigator$jscomp$22_navigator__$1$jscomp$11_vec__44699$$};
$cljs$pprint$choice_conditional$$=function($params$jscomp$33$$,$arg__$1$jscomp$2_arg_navigator$jscomp$2_clause$$){var $arg$jscomp$23_navigator__$1$jscomp$12_vec__44724$$=$APP.$cljs$cst$1452$selector$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$33$$);$arg$jscomp$23_navigator__$1$jscomp$12_vec__44724$$=$APP.$cljs$core$truth_$$($arg$jscomp$23_navigator__$1$jscomp$12_vec__44724$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$arg$jscomp$23_navigator__$1$jscomp$12_vec__44724$$,
$arg__$1$jscomp$2_arg_navigator$jscomp$2_clause$$],null):$cljs$pprint$next_arg$$($arg__$1$jscomp$2_arg_navigator$jscomp$2_clause$$);$arg__$1$jscomp$2_arg_navigator$jscomp$2_clause$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($arg$jscomp$23_navigator__$1$jscomp$12_vec__44724$$,0,null);$arg$jscomp$23_navigator__$1$jscomp$12_vec__44724$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($arg$jscomp$23_navigator__$1$jscomp$12_vec__44724$$,1,null);var $clauses$$=$cljs$cst$1453$clauses$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$33$$);
$arg__$1$jscomp$2_arg_navigator$jscomp$2_clause$$=$arg__$1$jscomp$2_arg_navigator$jscomp$2_clause$$<0||$arg__$1$jscomp$2_arg_navigator$jscomp$2_clause$$>=$APP.$cljs$core$count$$($clauses$$)?$APP.$cljs$core$first$$($cljs$cst$225$else$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$33$$)):$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($clauses$$,$arg__$1$jscomp$2_arg_navigator$jscomp$2_clause$$);return $APP.$cljs$core$truth_$$($arg__$1$jscomp$2_arg_navigator$jscomp$2_clause$$)?$cljs$pprint$execute_sub_format$$($arg__$1$jscomp$2_arg_navigator$jscomp$2_clause$$,
$arg$jscomp$23_navigator__$1$jscomp$12_vec__44724$$,$cljs$cst$1445$base_args$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$33$$)):$arg$jscomp$23_navigator__$1$jscomp$12_vec__44724$$};
$cljs$pprint$boolean_conditional$$=function($params$jscomp$34$$,$arg$jscomp$24_arg_navigator$jscomp$3_clause$jscomp$1$$){var $navigator__$1$jscomp$13_vec__44732$$=$cljs$pprint$next_arg$$($arg$jscomp$24_arg_navigator$jscomp$3_clause$jscomp$1$$);$arg$jscomp$24_arg_navigator$jscomp$3_clause$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$13_vec__44732$$,0,null);$navigator__$1$jscomp$13_vec__44732$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$13_vec__44732$$,
1,null);var $clauses$jscomp$1$$=$cljs$cst$1453$clauses$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$34$$);$arg$jscomp$24_arg_navigator$jscomp$3_clause$jscomp$1$$=$APP.$cljs$core$truth_$$($arg$jscomp$24_arg_navigator$jscomp$3_clause$jscomp$1$$)?$APP.$cljs$core$second$$($clauses$jscomp$1$$):$APP.$cljs$core$first$$($clauses$jscomp$1$$);return $APP.$cljs$core$truth_$$($arg$jscomp$24_arg_navigator$jscomp$3_clause$jscomp$1$$)?$cljs$pprint$execute_sub_format$$($arg$jscomp$24_arg_navigator$jscomp$3_clause$jscomp$1$$,
$navigator__$1$jscomp$13_vec__44732$$,$cljs$cst$1445$base_args$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$34$$)):$navigator__$1$jscomp$13_vec__44732$$};
$cljs$pprint$check_arg_conditional$$=function($params$jscomp$35$$,$arg_navigator$jscomp$4$$){var $navigator__$1$jscomp$14_vec__44736$$=$cljs$pprint$next_arg$$($arg_navigator$jscomp$4$$),$arg$jscomp$25$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$14_vec__44736$$,0,null);$navigator__$1$jscomp$14_vec__44736$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$14_vec__44736$$,1,null);var $clause$jscomp$2_clauses$jscomp$2$$=$cljs$cst$1453$clauses$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$35$$);
$clause$jscomp$2_clauses$jscomp$2$$=$APP.$cljs$core$truth_$$($arg$jscomp$25$$)?$APP.$cljs$core$first$$($clause$jscomp$2_clauses$jscomp$2$$):null;return $APP.$cljs$core$truth_$$($arg$jscomp$25$$)?$APP.$cljs$core$truth_$$($clause$jscomp$2_clauses$jscomp$2$$)?$cljs$pprint$execute_sub_format$$($clause$jscomp$2_clauses$jscomp$2$$,$arg_navigator$jscomp$4$$,$cljs$cst$1445$base_args$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$35$$)):$arg_navigator$jscomp$4$$:$navigator__$1$jscomp$14_vec__44736$$};
$cljs$pprint$iterate_sublist$$=function($params$jscomp$36$$,$clause$jscomp$3_navigator$jscomp$23$$){var $max_count$jscomp$4$$=$cljs$cst$1454$max_iterations$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$36$$),$navigator__$1$jscomp$15_navigator__$2_param_clause_vec__44744_vec__44747$$=$APP.$cljs$core$first$$($cljs$cst$1453$clauses$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$36$$));$navigator__$1$jscomp$15_navigator__$2_param_clause_vec__44744_vec__44747$$=$APP.$cljs$core$empty_QMARK_$$($navigator__$1$jscomp$15_navigator__$2_param_clause_vec__44744_vec__44747$$)?
$cljs$pprint$get_format_arg$$($clause$jscomp$3_navigator$jscomp$23$$):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$navigator__$1$jscomp$15_navigator__$2_param_clause_vec__44744_vec__44747$$,$clause$jscomp$3_navigator$jscomp$23$$],null);$clause$jscomp$3_navigator$jscomp$23$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$15_navigator__$2_param_clause_vec__44744_vec__44747$$,0,null);$navigator__$1$jscomp$15_navigator__$2_param_clause_vec__44744_vec__44747$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$15_navigator__$2_param_clause_vec__44744_vec__44747$$,1,null);$navigator__$1$jscomp$15_navigator__$2_param_clause_vec__44744_vec__44747$$=$cljs$pprint$next_arg$$($navigator__$1$jscomp$15_navigator__$2_param_clause_vec__44744_vec__44747$$);var $arg_list_args__$1$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$15_navigator__$2_param_clause_vec__44744_vec__44747$$,0,null);$navigator__$1$jscomp$15_navigator__$2_param_clause_vec__44744_vec__44747$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$15_navigator__$2_param_clause_vec__44744_vec__44747$$,1,null);var $G__45958_count$jscomp$58$$=0;$arg_list_args__$1$jscomp$6$$=$cljs$pprint$init_navigator$$($arg_list_args__$1$jscomp$6$$);for(var $G__45959_iter_result_last_pos_or__5025__auto__$jscomp$inline_4414$$=-1;;){if($APP.$cljs$core$not$$($max_count$jscomp$4$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($arg_list_args__$1$jscomp$6$$),
$G__45959_iter_result_last_pos_or__5025__auto__$jscomp$inline_4414$$)&&$G__45958_count$jscomp$58$$>1)throw Error("%{ construct not consuming any arguments: Infinite loop!");$G__45959_iter_result_last_pos_or__5025__auto__$jscomp$inline_4414$$=$APP.$cljs$core$empty_QMARK_$$($cljs$cst$1426$rest$$.$cljs$core$IFn$_invoke$arity$1$($arg_list_args__$1$jscomp$6$$))&&($APP.$cljs$core$not$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1455$right_params$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$36$$)))||
$G__45958_count$jscomp$58$$>0);if($APP.$cljs$core$truth_$$($G__45959_iter_result_last_pos_or__5025__auto__$jscomp$inline_4414$$?$G__45959_iter_result_last_pos_or__5025__auto__$jscomp$inline_4414$$:$APP.$cljs$core$truth_$$($max_count$jscomp$4$$)?$G__45958_count$jscomp$58$$>=$max_count$jscomp$4$$:$max_count$jscomp$4$$))return $navigator__$1$jscomp$15_navigator__$2_param_clause_vec__44744_vec__44747$$;$G__45959_iter_result_last_pos_or__5025__auto__$jscomp$inline_4414$$=$cljs$pprint$execute_sub_format$$($clause$jscomp$3_navigator$jscomp$23$$,
$arg_list_args__$1$jscomp$6$$,$cljs$cst$1445$base_args$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$36$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1443$up_arrow$$,$APP.$cljs$core$first$$($G__45959_iter_result_last_pos_or__5025__auto__$jscomp$inline_4414$$)))return $navigator__$1$jscomp$15_navigator__$2_param_clause_vec__44744_vec__44747$$;$G__45958_count$jscomp$58$$+=1;var $G__45960$$=$APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($arg_list_args__$1$jscomp$6$$);
$arg_list_args__$1$jscomp$6$$=$G__45959_iter_result_last_pos_or__5025__auto__$jscomp$inline_4414$$;$G__45959_iter_result_last_pos_or__5025__auto__$jscomp$inline_4414$$=$G__45960$$}};
$cljs$pprint$iterate_list_of_sublists$$=function($params$jscomp$37$$,$clause$jscomp$4_navigator$jscomp$24$$){var $max_count$jscomp$5$$=$cljs$cst$1454$max_iterations$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$37$$),$navigator__$1$jscomp$16_navigator__$2$jscomp$1_param_clause$jscomp$1_vec__44776_vec__44779$$=$APP.$cljs$core$first$$($cljs$cst$1453$clauses$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$37$$));$navigator__$1$jscomp$16_navigator__$2$jscomp$1_param_clause$jscomp$1_vec__44776_vec__44779$$=
$APP.$cljs$core$empty_QMARK_$$($navigator__$1$jscomp$16_navigator__$2$jscomp$1_param_clause$jscomp$1_vec__44776_vec__44779$$)?$cljs$pprint$get_format_arg$$($clause$jscomp$4_navigator$jscomp$24$$):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$navigator__$1$jscomp$16_navigator__$2$jscomp$1_param_clause$jscomp$1_vec__44776_vec__44779$$,$clause$jscomp$4_navigator$jscomp$24$$],null);$clause$jscomp$4_navigator$jscomp$24$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$16_navigator__$2$jscomp$1_param_clause$jscomp$1_vec__44776_vec__44779$$,
0,null);$navigator__$1$jscomp$16_navigator__$2$jscomp$1_param_clause$jscomp$1_vec__44776_vec__44779$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$16_navigator__$2$jscomp$1_param_clause$jscomp$1_vec__44776_vec__44779$$,1,null);$navigator__$1$jscomp$16_navigator__$2$jscomp$1_param_clause$jscomp$1_vec__44776_vec__44779$$=$cljs$pprint$next_arg$$($navigator__$1$jscomp$16_navigator__$2$jscomp$1_param_clause$jscomp$1_vec__44776_vec__44779$$);var $G__45962_arg_list$jscomp$1_arg_list__$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$16_navigator__$2$jscomp$1_param_clause$jscomp$1_vec__44776_vec__44779$$,0,null);$navigator__$1$jscomp$16_navigator__$2$jscomp$1_param_clause$jscomp$1_vec__44776_vec__44779$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$16_navigator__$2$jscomp$1_param_clause$jscomp$1_vec__44776_vec__44779$$,1,null);for(var $G__45961_count$jscomp$59$$=0;;){var $iter_result$jscomp$1_or__5025__auto__$jscomp$inline_4416$$=
$APP.$cljs$core$empty_QMARK_$$($G__45962_arg_list$jscomp$1_arg_list__$1$$)&&($APP.$cljs$core$not$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1455$right_params$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$37$$)))||$G__45961_count$jscomp$59$$>0);if($APP.$cljs$core$truth_$$($iter_result$jscomp$1_or__5025__auto__$jscomp$inline_4416$$?$iter_result$jscomp$1_or__5025__auto__$jscomp$inline_4416$$:$APP.$cljs$core$truth_$$($max_count$jscomp$5$$)?$G__45961_count$jscomp$59$$>=
$max_count$jscomp$5$$:$max_count$jscomp$5$$))return $navigator__$1$jscomp$16_navigator__$2$jscomp$1_param_clause$jscomp$1_vec__44776_vec__44779$$;$iter_result$jscomp$1_or__5025__auto__$jscomp$inline_4416$$=$cljs$pprint$execute_sub_format$$($clause$jscomp$4_navigator$jscomp$24$$,$cljs$pprint$init_navigator$$($APP.$cljs$core$first$$($G__45962_arg_list$jscomp$1_arg_list__$1$$)),$cljs$pprint$init_navigator$$($APP.$cljs$core$next$$($G__45962_arg_list$jscomp$1_arg_list__$1$$)));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1444$colon_up_arrow$$,
$APP.$cljs$core$first$$($iter_result$jscomp$1_or__5025__auto__$jscomp$inline_4416$$)))return $navigator__$1$jscomp$16_navigator__$2$jscomp$1_param_clause$jscomp$1_vec__44776_vec__44779$$;$G__45961_count$jscomp$59$$+=1;$G__45962_arg_list$jscomp$1_arg_list__$1$$=$APP.$cljs$core$next$$($G__45962_arg_list$jscomp$1_arg_list__$1$$)}};
$cljs$pprint$iterate_main_list$$=function($params$jscomp$38$$,$clause$jscomp$5_navigator$jscomp$25$$){var $max_count$jscomp$6$$=$cljs$cst$1454$max_iterations$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$38$$),$G__45965_count$jscomp$60_param_clause$jscomp$2$$=$APP.$cljs$core$first$$($cljs$cst$1453$clauses$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$38$$)),$navigator__$2$jscomp$2_vec__44796$$=$APP.$cljs$core$empty_QMARK_$$($G__45965_count$jscomp$60_param_clause$jscomp$2$$)?$cljs$pprint$get_format_arg$$($clause$jscomp$5_navigator$jscomp$25$$):
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__45965_count$jscomp$60_param_clause$jscomp$2$$,$clause$jscomp$5_navigator$jscomp$25$$],null);$clause$jscomp$5_navigator$jscomp$25$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$2$jscomp$2_vec__44796$$,0,null);$G__45965_count$jscomp$60_param_clause$jscomp$2$$=0;$navigator__$2$jscomp$2_vec__44796$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$2$jscomp$2_vec__44796$$,
1,null);for(var $G__45966_iter_result$jscomp$2_last_pos$jscomp$1_or__5025__auto__$jscomp$inline_4418$$=-1;;){if($APP.$cljs$core$not$$($max_count$jscomp$6$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($navigator__$2$jscomp$2_vec__44796$$),$G__45966_iter_result$jscomp$2_last_pos$jscomp$1_or__5025__auto__$jscomp$inline_4418$$)&&$G__45965_count$jscomp$60_param_clause$jscomp$2$$>1)throw Error("%@{ construct not consuming any arguments: Infinite loop!");
$G__45966_iter_result$jscomp$2_last_pos$jscomp$1_or__5025__auto__$jscomp$inline_4418$$=$APP.$cljs$core$empty_QMARK_$$($cljs$cst$1426$rest$$.$cljs$core$IFn$_invoke$arity$1$($navigator__$2$jscomp$2_vec__44796$$))&&($APP.$cljs$core$not$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1455$right_params$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$38$$)))||$G__45965_count$jscomp$60_param_clause$jscomp$2$$>0);if($APP.$cljs$core$truth_$$($G__45966_iter_result$jscomp$2_last_pos$jscomp$1_or__5025__auto__$jscomp$inline_4418$$?
$G__45966_iter_result$jscomp$2_last_pos$jscomp$1_or__5025__auto__$jscomp$inline_4418$$:$APP.$cljs$core$truth_$$($max_count$jscomp$6$$)?$G__45965_count$jscomp$60_param_clause$jscomp$2$$>=$max_count$jscomp$6$$:$max_count$jscomp$6$$))return $navigator__$2$jscomp$2_vec__44796$$;$G__45966_iter_result$jscomp$2_last_pos$jscomp$1_or__5025__auto__$jscomp$inline_4418$$=$cljs$pprint$execute_sub_format$$($clause$jscomp$5_navigator$jscomp$25$$,$navigator__$2$jscomp$2_vec__44796$$,$cljs$cst$1445$base_args$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$38$$));
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1443$up_arrow$$,$APP.$cljs$core$first$$($G__45966_iter_result$jscomp$2_last_pos$jscomp$1_or__5025__auto__$jscomp$inline_4418$$)))return $APP.$cljs$core$second$$($G__45966_iter_result$jscomp$2_last_pos$jscomp$1_or__5025__auto__$jscomp$inline_4418$$);$G__45965_count$jscomp$60_param_clause$jscomp$2$$+=1;var $G__45967$$=$APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($navigator__$2$jscomp$2_vec__44796$$);$navigator__$2$jscomp$2_vec__44796$$=
$G__45966_iter_result$jscomp$2_last_pos$jscomp$1_or__5025__auto__$jscomp$inline_4418$$;$G__45966_iter_result$jscomp$2_last_pos$jscomp$1_or__5025__auto__$jscomp$inline_4418$$=$G__45967$$}};
$cljs$pprint$iterate_main_sublists$$=function($params$jscomp$39$$,$clause$jscomp$6_navigator$jscomp$26$$){var $max_count$jscomp$7$$=$cljs$cst$1454$max_iterations$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$39$$),$count$jscomp$61_param_clause$jscomp$3$$=$APP.$cljs$core$first$$($cljs$cst$1453$clauses$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$39$$)),$G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$=$APP.$cljs$core$empty_QMARK_$$($count$jscomp$61_param_clause$jscomp$3$$)?
$cljs$pprint$get_format_arg$$($clause$jscomp$6_navigator$jscomp$26$$):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$count$jscomp$61_param_clause$jscomp$3$$,$clause$jscomp$6_navigator$jscomp$26$$],null);$clause$jscomp$6_navigator$jscomp$26$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$,0,null);$count$jscomp$61_param_clause$jscomp$3$$=
0;for($G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$,1,null);;){var $navigator__$3_or__5025__auto__$jscomp$inline_4420_rst$jscomp$inline_11704_vec__44816$$=$APP.$cljs$core$empty_QMARK_$$($cljs$cst$1426$rest$$.$cljs$core$IFn$_invoke$arity$1$($G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$))&&
($APP.$cljs$core$not$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1455$right_params$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$39$$)))||$count$jscomp$61_param_clause$jscomp$3$$>0);if($APP.$cljs$core$truth_$$($navigator__$3_or__5025__auto__$jscomp$inline_4420_rst$jscomp$inline_11704_vec__44816$$?$navigator__$3_or__5025__auto__$jscomp$inline_4420_rst$jscomp$inline_11704_vec__44816$$:$APP.$cljs$core$truth_$$($max_count$jscomp$7$$)?$count$jscomp$61_param_clause$jscomp$3$$>=
$max_count$jscomp$7$$:$max_count$jscomp$7$$))return $G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$;$navigator__$3_or__5025__auto__$jscomp$inline_4420_rst$jscomp$inline_11704_vec__44816$$=$cljs$cst$1426$rest$$.$cljs$core$IFn$_invoke$arity$1$($G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$);$navigator__$3_or__5025__auto__$jscomp$inline_4420_rst$jscomp$inline_11704_vec__44816$$=$APP.$cljs$core$truth_$$($navigator__$3_or__5025__auto__$jscomp$inline_4420_rst$jscomp$inline_11704_vec__44816$$)?
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($navigator__$3_or__5025__auto__$jscomp$inline_4420_rst$jscomp$inline_11704_vec__44816$$),new $cljs$pprint$arg_navigator$$($cljs$cst$1425$seq$$.$cljs$core$IFn$_invoke$arity$1$($G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$),$APP.$cljs$core$next$$($navigator__$3_or__5025__auto__$jscomp$inline_4420_rst$jscomp$inline_11704_vec__44816$$),
$APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$)+1,null,null,null)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$],null);$G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$3_or__5025__auto__$jscomp$inline_4420_rst$jscomp$inline_11704_vec__44816$$,0,null);$navigator__$3_or__5025__auto__$jscomp$inline_4420_rst$jscomp$inline_11704_vec__44816$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$3_or__5025__auto__$jscomp$inline_4420_rst$jscomp$inline_11704_vec__44816$$,1,null);$G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$=$cljs$pprint$execute_sub_format$$($clause$jscomp$6_navigator$jscomp$26$$,
$cljs$pprint$init_navigator$$($G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$),$navigator__$3_or__5025__auto__$jscomp$inline_4420_rst$jscomp$inline_11704_vec__44816$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1444$colon_up_arrow$$,$APP.$cljs$core$first$$($G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$)))return $navigator__$3_or__5025__auto__$jscomp$inline_4420_rst$jscomp$inline_11704_vec__44816$$;
$G__45971_iter_result$jscomp$3_navigator$jscomp$inline_11703_navigator__$2$jscomp$3_sublist_vec__44810$$=$navigator__$3_or__5025__auto__$jscomp$inline_4420_rst$jscomp$inline_11704_vec__44816$$;$count$jscomp$61_param_clause$jscomp$3$$+=1}};
$cljs$pprint$logical_block_or_justify$$=function($JSCompiler_temp$jscomp$639_params$jscomp$40$$,$arg$jscomp$inline_4430_navigator$jscomp$27$$){if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1455$right_params$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$639_params$jscomp$40$$)))){var $clauses$jscomp$inline_4424_suffix$jscomp$inline_4428$$=$cljs$cst$1453$clauses$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$639_params$jscomp$40$$),
$clause_count$jscomp$inline_4425_navigator__$1$jscomp$inline_4431_vec__44929$jscomp$inline_4429$$=$APP.$cljs$core$count$$($clauses$jscomp$inline_4424_suffix$jscomp$inline_4428$$),$prefix$jscomp$inline_4426$$=$clause_count$jscomp$inline_4425_navigator__$1$jscomp$inline_4431_vec__44929$jscomp$inline_4429$$>1?$APP.$cljs$cst$198$string$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$first$$($clauses$jscomp$inline_4424_suffix$jscomp$inline_4428$$)))):
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$639_params$jscomp$40$$))?"(":null,$body$jscomp$inline_4427$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($clauses$jscomp$inline_4424_suffix$jscomp$inline_4428$$,$clause_count$jscomp$inline_4425_navigator__$1$jscomp$inline_4431_vec__44929$jscomp$inline_4429$$>1?1:0);$clauses$jscomp$inline_4424_suffix$jscomp$inline_4428$$=$clause_count$jscomp$inline_4425_navigator__$1$jscomp$inline_4431_vec__44929$jscomp$inline_4429$$>
2?$APP.$cljs$cst$198$string$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($clauses$jscomp$inline_4424_suffix$jscomp$inline_4428$$,2)))):$APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$639_params$jscomp$40$$))?")":null;$clause_count$jscomp$inline_4425_navigator__$1$jscomp$inline_4431_vec__44929$jscomp$inline_4429$$=
$cljs$pprint$next_arg$$($arg$jscomp$inline_4430_navigator$jscomp$27$$);$arg$jscomp$inline_4430_navigator$jscomp$27$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($clause_count$jscomp$inline_4425_navigator__$1$jscomp$inline_4431_vec__44929$jscomp$inline_4429$$,0,null);$clause_count$jscomp$inline_4425_navigator__$1$jscomp$inline_4431_vec__44929$jscomp$inline_4429$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($clause_count$jscomp$inline_4425_navigator__$1$jscomp$inline_4431_vec__44929$jscomp$inline_4429$$,
1,null);if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"#");else{var $_STAR_current_level_STAR__orig_val__44934_46019$jscomp$inline_4432$$=$cljs$pprint$_STAR_current_level_STAR_$$,$_STAR_current_length_STAR__orig_val__44935_46020$jscomp$inline_4433$$=$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$($prefix$jscomp$inline_4426$$,
$clauses$jscomp$inline_4424_suffix$jscomp$inline_4428$$),$cljs$pprint$execute_sub_format$$($body$jscomp$inline_4427$$,$cljs$pprint$init_navigator$$($arg$jscomp$inline_4430_navigator$jscomp$27$$),$cljs$cst$1445$base_args$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$639_params$jscomp$40$$)),$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=$_STAR_current_length_STAR__orig_val__44935_46020$jscomp$inline_4433$$,$cljs$pprint$_STAR_current_level_STAR_$$=$_STAR_current_level_STAR__orig_val__44934_46019$jscomp$inline_4432$$}}$JSCompiler_temp$jscomp$639_params$jscomp$40$$=
$clause_count$jscomp$inline_4425_navigator__$1$jscomp$inline_4431_vec__44929$jscomp$inline_4429$$}else $JSCompiler_temp$jscomp$639_params$jscomp$40$$=$cljs$pprint$justify_clauses$$($JSCompiler_temp$jscomp$639_params$jscomp$40$$,$arg$jscomp$inline_4430_navigator$jscomp$27$$);return $JSCompiler_temp$jscomp$639_params$jscomp$40$$};
$cljs$pprint$render_clauses$$=function($G__45972_clauses$jscomp$3_clauses__$1$$,$G__45974_iter_result$jscomp$4_navigator$jscomp$28_navigator__$1$jscomp$19$$,$base_navigator$$){for(var $G__45973_acc$jscomp$84$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){if($APP.$cljs$core$empty_QMARK_$$($G__45972_clauses$jscomp$3_clauses__$1$$))return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__45973_acc$jscomp$84$$,$G__45974_iter_result$jscomp$4_navigator$jscomp$28_navigator__$1$jscomp$19$$],
null);var $clause$jscomp$7_result_str$$=$APP.$cljs$core$first$$($G__45972_clauses$jscomp$3_clauses__$1$$);var $sb$jscomp$inline_4435$$=new $APP.$goog$string$StringBuffer$$,$_STAR_out_STAR__orig_val__44829$jscomp$inline_4436$$=$cljs$core$_STAR_out_STAR_$$;$cljs$core$_STAR_out_STAR_$$=new $cljs$core$StringBufferWriter$$($sb$jscomp$inline_4435$$);try{var $vec__44826$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$pprint$execute_sub_format$$($clause$jscomp$7_result_str$$,
$G__45974_iter_result$jscomp$4_navigator$jscomp$28_navigator__$1$jscomp$19$$,$base_navigator$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$inline_4435$$)],null)}finally{$cljs$core$_STAR_out_STAR_$$=$_STAR_out_STAR__orig_val__44829$jscomp$inline_4436$$}$G__45974_iter_result$jscomp$4_navigator$jscomp$28_navigator__$1$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__44826$$,0,null);$clause$jscomp$7_result_str$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__44826$$,
1,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1443$up_arrow$$,$APP.$cljs$core$first$$($G__45974_iter_result$jscomp$4_navigator$jscomp$28_navigator__$1$jscomp$19$$)))return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__45973_acc$jscomp$84$$,$APP.$cljs$core$second$$($G__45974_iter_result$jscomp$4_navigator$jscomp$28_navigator__$1$jscomp$19$$)],null);$G__45972_clauses$jscomp$3_clauses__$1$$=$APP.$cljs$core$next$$($G__45972_clauses$jscomp$3_clauses__$1$$);
$G__45973_acc$jscomp$84$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__45973_acc$jscomp$84$$,$clause$jscomp$7_result_str$$)}};
$cljs$pprint$justify_clauses$$=function($params$jscomp$41$$,$navigator$jscomp$29$$){var $G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$=function(){var $temp__5825__auto__$jscomp$94$$=$cljs$cst$225$else$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$94$$)?$cljs$pprint$render_clauses$$($temp__5825__auto__$jscomp$94$$,$navigator$jscomp$29$$,$cljs$cst$1445$base_args$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$)):
null}(),$G__45989_eol_str_vec__44835$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$,0,null);$G__45989_eol_str_vec__44835$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__45989_eol_str_vec__44835$$,0,null);$G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$,
1,null);var $navigator__$1$jscomp$20$$=$APP.$cljs$core$truth_$$($G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$)?$G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$:$navigator$jscomp$29$$;$G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$=function(){var $temp__5825__auto__$jscomp$95$$=$cljs$cst$1456$else_params$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$);
return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$95$$)?$cljs$pprint$realize_parameter_list$$($temp__5825__auto__$jscomp$95$$,$navigator__$1$jscomp$20$$):null}();var $else_params$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$,0,null);$G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$,
1,null);var $navigator__$2$jscomp$4_navigator__$3$jscomp$1_vec__44841$$=$APP.$cljs$core$truth_$$($G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$)?$G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$:$navigator__$1$jscomp$20$$;$G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$=function(){var $or__5025__auto__$jscomp$282$$=$APP.$cljs$core$first$$($cljs$cst$1457$min_remaining$$.$cljs$core$IFn$_invoke$arity$1$($else_params$$));
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$282$$)?$or__5025__auto__$jscomp$282$$:0}();var $max_columns$jscomp$6$$=function(){var $or__5025__auto__$jscomp$283$$=$APP.$cljs$core$first$$($cljs$cst$1458$max_columns$$.$cljs$core$IFn$_invoke$arity$1$($else_params$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$283$$)?$or__5025__auto__$jscomp$283$$:$cljs$pprint$get_max_column$$($cljs$core$_STAR_out_STAR_$$)}(),$chars$jscomp$3_clauses$jscomp$4_pad$jscomp$2_pad_str$$=$cljs$cst$1453$clauses$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$);
$navigator__$2$jscomp$4_navigator__$3$jscomp$1_vec__44841$$=$cljs$pprint$render_clauses$$($chars$jscomp$3_clauses$jscomp$4_pad$jscomp$2_pad_str$$,$navigator__$2$jscomp$4_navigator__$3$jscomp$1_vec__44841$$,$cljs$cst$1445$base_args$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$));var $strs$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$2$jscomp$4_navigator__$3$jscomp$1_vec__44841$$,0,null);$navigator__$2$jscomp$4_navigator__$3$jscomp$1_vec__44841$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$2$jscomp$4_navigator__$3$jscomp$1_vec__44841$$,
1,null);var $slots$$=function(){var $y__5111__auto__$jscomp$27$$=$APP.$cljs$core$count$$($strs$$)-1+($APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$))?1:0)+($APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$))?1:0);return 1>$y__5111__auto__$jscomp$27$$?1:$y__5111__auto__$jscomp$27$$}();$chars$jscomp$3_clauses$jscomp$4_pad$jscomp$2_pad_str$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_PLUS_$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$,$strs$$));var $mincol_result_columns$$=$cljs$cst$1437$mincol$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$),$minpad$$=$cljs$cst$1436$minpad$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$),$colinc$jscomp$1_extra_pad$$=$cljs$cst$1438$colinc$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$),$minout$$=$chars$jscomp$3_clauses$jscomp$4_pad$jscomp$2_pad_str$$+$slots$$*$minpad$$;$mincol_result_columns$$=$minout$$<=
$mincol_result_columns$$?$mincol_result_columns$$:$mincol_result_columns$$+$colinc$jscomp$1_extra_pad$$*(1+$APP.$cljs$core$quot$$($minout$$-$mincol_result_columns$$-1,$colinc$jscomp$1_extra_pad$$));var $total_pad$$=$mincol_result_columns$$-$chars$jscomp$3_clauses$jscomp$4_pad$jscomp$2_pad_str$$;$chars$jscomp$3_clauses$jscomp$4_pad$jscomp$2_pad_str$$=function(){var $y__5111__auto__$jscomp$28$$=$APP.$cljs$core$quot$$($total_pad$$,$slots$$);return $minpad$$>$y__5111__auto__$jscomp$28$$?$minpad$$:$y__5111__auto__$jscomp$28$$}();
$colinc$jscomp$1_extra_pad$$=$total_pad$$-$chars$jscomp$3_clauses$jscomp$4_pad$jscomp$2_pad_str$$*$slots$$;$chars$jscomp$3_clauses$jscomp$4_pad$jscomp$2_pad_str$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($chars$jscomp$3_clauses$jscomp$4_pad$jscomp$2_pad_str$$,$cljs$cst$1439$padchar$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$)));$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__45989_eol_str_vec__44835$$)?
$cljs$pprint$get_column$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($cljs$core$_STAR_out_STAR_$$))))+$G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$+$mincol_result_columns$$>$max_columns$jscomp$6$$:$G__45989_eol_str_vec__44835$$)&&$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__45989_eol_str_vec__44835$$]));
$G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$=$colinc$jscomp$1_extra_pad$$;for(var $strs_45984__$1$$=$strs$$,$pad_only_45985$$=function(){var $or__5025__auto__$jscomp$284$$=$APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$284$$)?$or__5025__auto__$jscomp$284$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($strs_45984__$1$$),
1)&&$APP.$cljs$core$not$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$))}();;)if($APP.$cljs$core$seq$$($strs_45984__$1$$))$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$not$$($pad_only_45985$$)?$APP.$cljs$core$first$$($strs_45984__$1$$):null),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$285_or__5025__auto____$1$jscomp$34$$=
$pad_only_45985$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$285_or__5025__auto____$1$jscomp$34$$)?$or__5025__auto__$jscomp$285_or__5025__auto____$1$jscomp$34$$:($or__5025__auto__$jscomp$285_or__5025__auto____$1$jscomp$34$$=$APP.$cljs$core$next$$($strs_45984__$1$$))?$or__5025__auto__$jscomp$285_or__5025__auto____$1$jscomp$34$$:$cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$)}())?$chars$jscomp$3_clauses$jscomp$4_pad$jscomp$2_pad_str$$:null),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$>
0?$cljs$cst$1439$padchar$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$41$$):null)].join("")])),--$G__45988_extra_pad_45983__$1_min_remaining_new_navigator$jscomp$2_new_navigator__$1_vec__44832_vec__44838$$,$strs_45984__$1$$=$G__45989_eol_str_vec__44835$$=$APP.$cljs$core$truth_$$($pad_only_45985$$)?$strs_45984__$1$$:$APP.$cljs$core$next$$($strs_45984__$1$$),$pad_only_45985$$=!1;else break;return $navigator__$2$jscomp$4_navigator__$3$jscomp$1_vec__44841$$};
$cljs$pprint$t_cljs$0pprint44851$$=function($writer$jscomp$150$$,$meta44852$$){this.$writer$=$writer$jscomp$150$$;this.$meta44852$=$meta44852$$;this.$cljs$lang$protocol_mask$partition0$$=1074135040;this.$cljs$lang$protocol_mask$partition1$$=0};$cljs$pprint$downcase_writer$$=function($writer$jscomp$152$$){return new $cljs$pprint$t_cljs$0pprint44851$$($writer$jscomp$152$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$pprint$t_cljs$0pprint44871$$=function($writer$jscomp$153$$,$meta44872$$){this.$writer$=$writer$jscomp$153$$;this.$meta44872$=$meta44872$$;this.$cljs$lang$protocol_mask$partition0$$=1074135040;this.$cljs$lang$protocol_mask$partition1$$=0};$cljs$pprint$upcase_writer$$=function($writer$jscomp$155$$){return new $cljs$pprint$t_cljs$0pprint44871$$($writer$jscomp$155$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$pprint$capitalize_string$$=function($s$jscomp$494_s__$1$jscomp$47$$,$first_QMARK_$$){var $f$jscomp$660$$=$APP.$cljs$core$first$$($s$jscomp$494_s__$1$jscomp$47$$);$s$jscomp$494_s__$1$jscomp$47$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($first_QMARK_$$)?$APP.$cljs$core$truth_$$($f$jscomp$660$$)?$goog$string$isUnicodeChar$$($f$jscomp$660$$):$f$jscomp$660$$:$first_QMARK_$$)?[$APP.$clojure$string$upper_case$$($f$jscomp$660$$),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$494_s__$1$jscomp$47$$,
1)].join(""):$s$jscomp$494_s__$1$jscomp$47$$;return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$first$$($cljs$pprint$consume$$(function($s__$2$$){if($APP.$cljs$core$empty_QMARK_$$($s__$2$$))return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,null],null);var $m$jscomp$178_offset$jscomp$47$$=RegExp("\\W\\w","g").exec($s__$2$$);$m$jscomp$178_offset$jscomp$47$$=$APP.$cljs$core$truth_$$($m$jscomp$178_offset$jscomp$47$$)?
$m$jscomp$178_offset$jscomp$47$$.index+1:$m$jscomp$178_offset$jscomp$47$$;return $APP.$cljs$core$truth_$$($m$jscomp$178_offset$jscomp$47$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s__$2$$,0,$m$jscomp$178_offset$jscomp$47$$),$APP.$clojure$string$upper_case$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($s__$2$$,$m$jscomp$178_offset$jscomp$47$$))].join(""),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($s__$2$$,
$m$jscomp$178_offset$jscomp$47$$+1)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$s__$2$$,null],null)},$s$jscomp$494_s__$1$jscomp$47$$)))};
$cljs$pprint$t_cljs$0pprint44886$$=function($writer$jscomp$156$$,$last_was_whitespace_QMARK_$$,$meta44887$$){this.$writer$=$writer$jscomp$156$$;this.$last_was_whitespace_QMARK_$=$last_was_whitespace_QMARK_$$;this.$meta44887$=$meta44887$$;this.$cljs$lang$protocol_mask$partition0$$=1074135040;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$pprint$capitalize_word_writer$$=function($writer$jscomp$158$$){return new $cljs$pprint$t_cljs$0pprint44886$$($writer$jscomp$158$$,$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$pprint$t_cljs$0pprint44899$$=function($writer$jscomp$159$$,$capped$$,$meta44900$$){this.$writer$=$writer$jscomp$159$$;this.$capped$=$capped$$;this.$meta44900$=$meta44900$$;this.$cljs$lang$protocol_mask$partition0$$=1074135040;this.$cljs$lang$protocol_mask$partition1$$=0};$cljs$pprint$init_cap_writer$$=function($writer$jscomp$161$$){return new $cljs$pprint$t_cljs$0pprint44899$$($writer$jscomp$161$$,$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$pprint$set_indent$$=function($params$jscomp$46$$,$navigator$jscomp$34$$){var $relative_to$jscomp$5$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$46$$))?$cljs$cst$1401$current$$:$APP.$cljs$cst$1400$block$$;$cljs$pprint$pprint_indent$$($relative_to$jscomp$5$$,$cljs$cst$1451$n$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$46$$));return $navigator$jscomp$34$$};
$cljs$pprint$conditional_newline$$=function($kind$jscomp$24_params$jscomp$47$$,$navigator$jscomp$35$$){$kind$jscomp$24_params$jscomp$47$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($kind$jscomp$24_params$jscomp$47$$))?$APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($kind$jscomp$24_params$jscomp$47$$))?$cljs$cst$1402$mandatory$$:$APP.$cljs$cst$1403$fill$$:$APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($kind$jscomp$24_params$jscomp$47$$))?
$cljs$cst$288$miser$$:$APP.$cljs$cst$287$linear$$;$cljs$pprint$pprint_newline$$($kind$jscomp$24_params$jscomp$47$$);return $navigator$jscomp$35$$};
$cljs$pprint$extract_param$$=function($m$jscomp$180_new_offset$jscomp$1_p__45076$$){var $remainder$jscomp$6_s$jscomp$497$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($m$jscomp$180_new_offset$jscomp$1_p__45076$$,0,null),$offset$jscomp$83$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($m$jscomp$180_new_offset$jscomp$1_p__45076$$,1,null),$saw_comma_token_str$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($m$jscomp$180_new_offset$jscomp$1_p__45076$$,2,null);$m$jscomp$180_new_offset$jscomp$1_p__45076$$=
new RegExp($cljs$pprint$param_pattern$$.source,"g");var $param$jscomp$10$$=$m$jscomp$180_new_offset$jscomp$1_p__45076$$.exec($remainder$jscomp$6_s$jscomp$497$$);return $APP.$cljs$core$truth_$$($param$jscomp$10$$)?($saw_comma_token_str$$=$APP.$cljs$core$first$$($param$jscomp$10$$),$remainder$jscomp$6_s$jscomp$497$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($remainder$jscomp$6_s$jscomp$497$$,$m$jscomp$180_new_offset$jscomp$1_p__45076$$.lastIndex),$m$jscomp$180_new_offset$jscomp$1_p__45076$$=
$offset$jscomp$83$$+$m$jscomp$180_new_offset$jscomp$1_p__45076$$.lastIndex,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(",",$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($remainder$jscomp$6_s$jscomp$497$$,0))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$saw_comma_token_str$$,$offset$jscomp$83$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($remainder$jscomp$6_s$jscomp$497$$,1),$m$jscomp$180_new_offset$jscomp$1_p__45076$$+1,!0],null)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$saw_comma_token_str$$,$offset$jscomp$83$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$remainder$jscomp$6_s$jscomp$497$$,$m$jscomp$180_new_offset$jscomp$1_p__45076$$,!1],null)],null)):$APP.$cljs$core$truth_$$($saw_comma_token_str$$)?$cljs$pprint$format_error$$("Badly formed parameters in format directive",$offset$jscomp$83$$):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$remainder$jscomp$6_s$jscomp$497$$,$offset$jscomp$83$$],null)],
null)};
$cljs$pprint$translate_param$$=function($offset$jscomp$85_p__45083$$){var $p$jscomp$131$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offset$jscomp$85_p__45083$$,0,null);$offset$jscomp$85_p__45083$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offset$jscomp$85_p__45083$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$131$$.length,0)?null:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$131$$.length,
1)&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["V",null,"v",null],null),null),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($p$jscomp$131$$,0))?$cljs$cst$1434$parameter_from_args$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$131$$.length,1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("#",$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($p$jscomp$131$$,0))?$cljs$cst$1435$remaining_arg_count$$:
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$131$$.length,2)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("'",$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($p$jscomp$131$$,0))?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($p$jscomp$131$$,1):parseInt($p$jscomp$131$$,10),$offset$jscomp$85_p__45083$$],null)};
$cljs$pprint$extract_flags$$=function($s$jscomp$499$$,$offset$jscomp$86$$){return $cljs$pprint$consume$$(function($flags$jscomp$10_p__45092$$){var $s__$1$jscomp$48$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flags$jscomp$10_p__45092$$,0,null),$offset__$1$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flags$jscomp$10_p__45092$$,1,null);$flags$jscomp$10_p__45092$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flags$jscomp$10_p__45092$$,2,null);if($APP.$cljs$core$empty_QMARK_$$($s__$1$jscomp$48$$))return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$s__$1$jscomp$48$$,$offset__$1$jscomp$1$$,$flags$jscomp$10_p__45092$$],null)],null);var $flag$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cljs$pprint$flag_defs$$,$APP.$cljs$core$first$$($s__$1$jscomp$48$$));return $APP.$cljs$core$truth_$$($flag$jscomp$3$$)?$APP.$cljs$core$contains_QMARK_$$($flags$jscomp$10_p__45092$$,$flag$jscomp$3$$)?
$cljs$pprint$format_error$$(['Flag "',$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($s__$1$jscomp$48$$)),'" appears more than once in a directive'].join(""),$offset__$1$jscomp$1$$):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[!0,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($s__$1$jscomp$48$$,1),$offset__$1$jscomp$1$$+
1,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($flags$jscomp$10_p__45092$$,$flag$jscomp$3$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[!0,$offset__$1$jscomp$1$$],null))],null)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$s__$1$jscomp$48$$,$offset__$1$jscomp$1$$,$flags$jscomp$10_p__45092$$],
null)],null)},new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$s$jscomp$499$$,$offset$jscomp$86$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null))};
$cljs$pprint$check_flags$$=function($def$jscomp$3$$,$flags$jscomp$11$$){var $allowed$$=$APP.$cljs$cst$1467$flags$$.$cljs$core$IFn$_invoke$arity$1$($def$jscomp$3$$);$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$196$$=$APP.$cljs$core$not$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($allowed$$));return $and__5023__auto__$jscomp$196$$?$cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($flags$jscomp$11$$):$and__5023__auto__$jscomp$196$$}())&&$cljs$pprint$format_error$$(['"@" is an illegal flag for format directive "',
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1466$directive$$.$cljs$core$IFn$_invoke$arity$1$($def$jscomp$3$$)),'"'].join(""),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($flags$jscomp$11$$),1));$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$197$$=$APP.$cljs$core$not$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($allowed$$));return $and__5023__auto__$jscomp$197$$?$APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($flags$jscomp$11$$):
$and__5023__auto__$jscomp$197$$}())&&$cljs$pprint$format_error$$(['":" is an illegal flag for format directive "',$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1466$directive$$.$cljs$core$IFn$_invoke$arity$1$($def$jscomp$3$$)),'"'].join(""),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($flags$jscomp$11$$),1));$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$198_and__5023__auto____$1$jscomp$36$$=
$APP.$cljs$core$not$$($cljs$cst$259$both$$.$cljs$core$IFn$_invoke$arity$1$($allowed$$));return $and__5023__auto__$jscomp$198_and__5023__auto____$1$jscomp$36$$?($and__5023__auto__$jscomp$198_and__5023__auto____$1$jscomp$36$$=$cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($flags$jscomp$11$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$198_and__5023__auto____$1$jscomp$36$$)?$APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($flags$jscomp$11$$):$and__5023__auto__$jscomp$198_and__5023__auto____$1$jscomp$36$$):
$and__5023__auto__$jscomp$198_and__5023__auto____$1$jscomp$36$$}())&&$cljs$pprint$format_error$$(['Cannot combine "@" and ":" flags for format directive "',$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1466$directive$$.$cljs$core$IFn$_invoke$arity$1$($def$jscomp$3$$)),'"'].join(""),function(){var $x__5113__auto__$jscomp$21$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($flags$jscomp$11$$),1),$y__5114__auto__$jscomp$21$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($flags$jscomp$11$$),1);return $x__5113__auto__$jscomp$21$$<$y__5114__auto__$jscomp$21$$?$x__5113__auto__$jscomp$21$$:$y__5114__auto__$jscomp$21$$}())};
$cljs$pprint$map_params$$=function($def$jscomp$4$$,$params$jscomp$82$$,$flags$jscomp$12$$,$offset$jscomp$87$$){$cljs$pprint$check_flags$$($def$jscomp$4$$,$flags$jscomp$12$$);$APP.$cljs$core$count$$($params$jscomp$82$$)>$APP.$cljs$core$count$$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($def$jscomp$4$$))&&$cljs$pprint$format_error$$($cljs$pprint$cl_format$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(null,'Too many parameters for directive "~C": ~D~:* ~[were~;was~:;were~] specified but only ~D~:* ~[are~;is~:;are~] allowed',
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$1466$directive$$.$cljs$core$IFn$_invoke$arity$1$($def$jscomp$4$$),$APP.$cljs$core$count$$($params$jscomp$82$$),$APP.$cljs$core$count$$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($def$jscomp$4$$))])),$APP.$cljs$core$second$$($APP.$cljs$core$first$$($params$jscomp$82$$)));$APP.$cljs$core$doall$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(function($p1__45100_SHARP_$$,
$p2__45101_SHARP_$$){var $val$jscomp$152$$=$APP.$cljs$core$first$$($p1__45100_SHARP_$$);return $val$jscomp$152$$==null||$APP.$cljs$core$contains_QMARK_$$($cljs$pprint$special_params$$,$val$jscomp$152$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$($APP.$cljs$core$second$$($p2__45101_SHARP_$$)),$APP.$cljs$core$type$$($val$jscomp$152$$))?null:$cljs$pprint$format_error$$(["Parameter ",$APP.$cljs$core$name$$($APP.$cljs$core$first$$($p2__45101_SHARP_$$)),' has bad type in directive "',
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1466$directive$$.$cljs$core$IFn$_invoke$arity$1$($def$jscomp$4$$)),'": ',$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$type$$($val$jscomp$152$$))].join(""),$APP.$cljs$core$second$$($p1__45100_SHARP_$$))},$params$jscomp$82$$,$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($def$jscomp$4$$)));return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$reverse$$(function(){return function $cljs$pprint$map_params_$_iter__45105$$($s__45106$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__45106__$2_temp__5825__auto__$jscomp$96$$=$APP.$cljs$core$seq$$($s__45106$$);if($s__45106__$2_temp__5825__auto__$jscomp$96$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__45106__$2_temp__5825__auto__$jscomp$96$$)){var $JSCompiler_inline_result$jscomp$641_c__5501__auto__$jscomp$9_default$$jscomp$47_vec__45115_vec__45118$$=$APP.$cljs$core$_chunked_first$$($s__45106__$2_temp__5825__auto__$jscomp$96$$),
$size__5502__auto__$jscomp$9$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$641_c__5501__auto__$jscomp$9_default$$jscomp$47_vec__45115_vec__45118$$),$b__45108_name$jscomp$153$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$9$$);a:{for(var $i__45107$jscomp$inline_4482$$=0;;)if($i__45107$jscomp$inline_4482$$<$size__5502__auto__$jscomp$9$$){var $default$$jscomp$inline_4486_vec__45109$jscomp$inline_4483_vec__45112$jscomp$inline_4485$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$641_c__5501__auto__$jscomp$9_default$$jscomp$47_vec__45115_vec__45118$$,
$i__45107$jscomp$inline_4482$$),$name$jscomp$inline_4484$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($default$$jscomp$inline_4486_vec__45109$jscomp$inline_4483_vec__45112$jscomp$inline_4485$$,0,null);$default$$jscomp$inline_4486_vec__45109$jscomp$inline_4483_vec__45112$jscomp$inline_4485$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($default$$jscomp$inline_4486_vec__45109$jscomp$inline_4483_vec__45112$jscomp$inline_4485$$,1,null);$default$$jscomp$inline_4486_vec__45109$jscomp$inline_4483_vec__45112$jscomp$inline_4485$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($default$$jscomp$inline_4486_vec__45109$jscomp$inline_4483_vec__45112$jscomp$inline_4485$$,0,null);$b__45108_name$jscomp$153$$.add(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$name$jscomp$inline_4484$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$default$$jscomp$inline_4486_vec__45109$jscomp$inline_4483_vec__45112$jscomp$inline_4485$$,$offset$jscomp$87$$],
null)],null));$i__45107$jscomp$inline_4482$$+=1}else{$JSCompiler_inline_result$jscomp$641_c__5501__auto__$jscomp$9_default$$jscomp$47_vec__45115_vec__45118$$=!0;break a}$JSCompiler_inline_result$jscomp$641_c__5501__auto__$jscomp$9_default$$jscomp$47_vec__45115_vec__45118$$=void 0}return $JSCompiler_inline_result$jscomp$641_c__5501__auto__$jscomp$9_default$$jscomp$47_vec__45115_vec__45118$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__45108_name$jscomp$153$$),$cljs$pprint$map_params_$_iter__45105$$($APP.$cljs$core$_chunked_rest$$($s__45106__$2_temp__5825__auto__$jscomp$96$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__45108_name$jscomp$153$$),null)}$JSCompiler_inline_result$jscomp$641_c__5501__auto__$jscomp$9_default$$jscomp$47_vec__45115_vec__45118$$=$APP.$cljs$core$first$$($s__45106__$2_temp__5825__auto__$jscomp$96$$);$b__45108_name$jscomp$153$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$641_c__5501__auto__$jscomp$9_default$$jscomp$47_vec__45115_vec__45118$$,0,null);$JSCompiler_inline_result$jscomp$641_c__5501__auto__$jscomp$9_default$$jscomp$47_vec__45115_vec__45118$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$641_c__5501__auto__$jscomp$9_default$$jscomp$47_vec__45115_vec__45118$$,1,null);$JSCompiler_inline_result$jscomp$641_c__5501__auto__$jscomp$9_default$$jscomp$47_vec__45115_vec__45118$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$641_c__5501__auto__$jscomp$9_default$$jscomp$47_vec__45115_vec__45118$$,0,null);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__45108_name$jscomp$153$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_inline_result$jscomp$641_c__5501__auto__$jscomp$9_default$$jscomp$47_vec__45115_vec__45118$$,$offset$jscomp$87$$],null)],null),$cljs$pprint$map_params_$_iter__45105$$($APP.$cljs$core$rest$$($s__45106__$2_temp__5825__auto__$jscomp$96$$)))}return null}},null,null)}($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($def$jscomp$4$$))}())),
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__45102_SHARP_$$,$p2__45103_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$,$p1__45102_SHARP_$$,$p2__45103_SHARP_$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__45104_SHARP_$$){return $APP.$cljs$core$first$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__45104_SHARP_$$,1))},$APP.$cljs$core$zipmap$$($APP.$cljs$core$keys$$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($def$jscomp$4$$)),
$params$jscomp$82$$))),$flags$jscomp$12$$]))};
$cljs$pprint$compile_directive$$=function($raw_params_s$jscomp$500$$,$flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$){$flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$=$cljs$pprint$consume$$($cljs$pprint$extract_param$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$raw_params_s$jscomp$500$$,$flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$,!1],null));
$raw_params_s$jscomp$500$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$,0,null);var $directive_offset__$1$jscomp$2_vec__45124$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$,1,null);$flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($directive_offset__$1$jscomp$2_vec__45124$$,
0,null);$directive_offset__$1$jscomp$2_vec__45124$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($directive_offset__$1$jscomp$2_vec__45124$$,1,null);$flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$=$cljs$pprint$extract_flags$$($flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$,$directive_offset__$1$jscomp$2_vec__45124$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$,
0,null);$flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$,1,null);var $rest__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$,0,null),$offset__$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$,
1,null);$flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$,2,null);$directive_offset__$1$jscomp$2_vec__45124$$=$APP.$cljs$core$first$$($rest__$1$$);var $def$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cljs$pprint$directive_table$$,$APP.$clojure$string$upper_case$$($directive_offset__$1$jscomp$2_vec__45124$$)),
$params$jscomp$83$$=$APP.$cljs$core$truth_$$($def$jscomp$5$$)?$cljs$pprint$map_params$$($def$jscomp$5$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$pprint$translate_param$$,$raw_params_s$jscomp$500$$),$flags$jscomp$13_offset$jscomp$88_rest$jscomp$18_vec__45121_vec__45127_vec__45130$$,$offset__$2$$):null;$APP.$cljs$core$not$$($directive_offset__$1$jscomp$2_vec__45124$$)&&$cljs$pprint$format_error$$("Format string ended in the middle of a directive",$offset__$2$$);$APP.$cljs$core$not$$($def$jscomp$5$$)&&
$cljs$pprint$format_error$$(['Directive "',$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($directive_offset__$1$jscomp$2_vec__45124$$),'" is undefined'].join(""),$offset__$2$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $cljs$pprint$compiled_directive$$(function(){var $fexpr__45134$$=$cljs$cst$1469$generator_fn$$.$cljs$core$IFn$_invoke$arity$1$($def$jscomp$5$$);return $fexpr__45134$$.$cljs$core$IFn$_invoke$arity$2$?$fexpr__45134$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$83$$,
$offset__$2$$):$fexpr__45134$$($params$jscomp$83$$,$offset__$2$$)}(),$def$jscomp$5$$,$params$jscomp$83$$,$offset__$2$$,null,null,null),function(){var $remainder$jscomp$7_remainder__$1$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($rest__$1$$,1),$offset__$3$$=$offset__$2$$+1;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("\n",$cljs$cst$1466$directive$$.$cljs$core$IFn$_invoke$arity$1$($def$jscomp$5$$))&&$APP.$cljs$core$not$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$83$$)))a:{var $JSCompiler_temp$jscomp$10724_test$jscomp$inline_11724_trim_count_val$jscomp$inline_11723$$=
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[" ","\t"],null);$JSCompiler_temp$jscomp$10724_test$jscomp$inline_11724_trim_count_val$jscomp$inline_11723$$=$APP.$cljs$core$coll_QMARK_$$($JSCompiler_temp$jscomp$10724_test$jscomp$inline_11724_trim_count_val$jscomp$inline_11723$$)?$APP.$cljs$core$set$$($JSCompiler_temp$jscomp$10724_test$jscomp$inline_11724_trim_count_val$jscomp$inline_11723$$):$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$JSCompiler_temp$jscomp$10724_test$jscomp$inline_11724_trim_count_val$jscomp$inline_11723$$]);
for(var $pos$jscomp$inline_11725$$=0;;){var $G__43146$jscomp$inline_11728_JSCompiler_inline_result$jscomp$inline_11727_JSCompiler_temp$jscomp$inline_11726$$;($G__43146$jscomp$inline_11728_JSCompiler_inline_result$jscomp$inline_11727_JSCompiler_temp$jscomp$inline_11726$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$inline_11725$$,$APP.$cljs$core$count$$($remainder$jscomp$7_remainder__$1$$)))||($G__43146$jscomp$inline_11728_JSCompiler_inline_result$jscomp$inline_11727_JSCompiler_temp$jscomp$inline_11726$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($remainder$jscomp$7_remainder__$1$$,$pos$jscomp$inline_11725$$),$G__43146$jscomp$inline_11728_JSCompiler_inline_result$jscomp$inline_11727_JSCompiler_temp$jscomp$inline_11726$$=$JSCompiler_temp$jscomp$10724_test$jscomp$inline_11724_trim_count_val$jscomp$inline_11723$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_temp$jscomp$10724_test$jscomp$inline_11724_trim_count_val$jscomp$inline_11723$$.$cljs$core$IFn$_invoke$arity$1$($G__43146$jscomp$inline_11728_JSCompiler_inline_result$jscomp$inline_11727_JSCompiler_temp$jscomp$inline_11726$$):
$JSCompiler_temp$jscomp$10724_test$jscomp$inline_11724_trim_count_val$jscomp$inline_11723$$($G__43146$jscomp$inline_11728_JSCompiler_inline_result$jscomp$inline_11727_JSCompiler_temp$jscomp$inline_11726$$),$G__43146$jscomp$inline_11728_JSCompiler_inline_result$jscomp$inline_11727_JSCompiler_temp$jscomp$inline_11726$$=$APP.$cljs$core$not$$($G__43146$jscomp$inline_11728_JSCompiler_inline_result$jscomp$inline_11727_JSCompiler_temp$jscomp$inline_11726$$));if($G__43146$jscomp$inline_11728_JSCompiler_inline_result$jscomp$inline_11727_JSCompiler_temp$jscomp$inline_11726$$){$JSCompiler_temp$jscomp$10724_test$jscomp$inline_11724_trim_count_val$jscomp$inline_11723$$=
$pos$jscomp$inline_11725$$;break a}$pos$jscomp$inline_11725$$+=1}$JSCompiler_temp$jscomp$10724_test$jscomp$inline_11724_trim_count_val$jscomp$inline_11723$$=void 0}else $JSCompiler_temp$jscomp$10724_test$jscomp$inline_11724_trim_count_val$jscomp$inline_11723$$=0;$remainder$jscomp$7_remainder__$1$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($remainder$jscomp$7_remainder__$1$$,$JSCompiler_temp$jscomp$10724_test$jscomp$inline_11724_trim_count_val$jscomp$inline_11723$$);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$remainder$jscomp$7_remainder__$1$$,$offset__$3$$+$JSCompiler_temp$jscomp$10724_test$jscomp$inline_11724_trim_count_val$jscomp$inline_11723$$],null)}()],null)};
$cljs$pprint$compile_raw_string$$=function($s$jscomp$501$$,$offset$jscomp$89$$){return new $cljs$pprint$compiled_directive$$(function($_$jscomp$1015$$,$a$jscomp$316$$){$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$s$jscomp$501$$]));return $a$jscomp$316$$},null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$198$string$$,$s$jscomp$501$$],null),$offset$jscomp$89$$,null,null,null)};
$cljs$pprint$process_bracket$$=function($this$$jscomp$560$$,$remainder$jscomp$8_subex$$){var $remainder__$1$jscomp$1_vec__45145$$=$cljs$pprint$collect_clauses$$($cljs$cst$1468$bracket_info$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1429$def$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$560$$)),$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$560$$),$remainder$jscomp$8_subex$$);$remainder$jscomp$8_subex$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($remainder__$1$jscomp$1_vec__45145$$,
0,null);$remainder__$1$jscomp$1_vec__45145$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($remainder__$1$jscomp$1_vec__45145$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $cljs$pprint$compiled_directive$$($cljs$cst$1428$func$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$560$$),$cljs$cst$1429$def$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$560$$),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$560$$),
$cljs$pprint$tuple_map$$($remainder$jscomp$8_subex$$,$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$560$$))])),$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$560$$),null,null,null),$remainder__$1$jscomp$1_vec__45145$$],null)};
$cljs$pprint$process_clause$$=function($bracket_info$$,$offset$jscomp$90$$,$remainder$jscomp$9$$){return $cljs$pprint$consume$$(function($remainder__$1$jscomp$2_remainder__$2$$){if($APP.$cljs$core$empty_QMARK_$$($remainder__$1$jscomp$2_remainder__$2$$))return $cljs$pprint$format_error$$("No closing bracket found.",$offset$jscomp$90$$);var $JSCompiler_temp$jscomp$642_JSCompiler_temp$jscomp$643_this$$jscomp$561$$=$APP.$cljs$core$first$$($remainder__$1$jscomp$2_remainder__$2$$);$remainder__$1$jscomp$2_remainder__$2$$=
$APP.$cljs$core$next$$($remainder__$1$jscomp$2_remainder__$2$$);if($APP.$cljs$core$truth_$$($APP.$cljs$cst$258$right$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1468$bracket_info$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1429$def$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$642_JSCompiler_temp$jscomp$643_this$$jscomp$561$$)))))$JSCompiler_temp$jscomp$642_JSCompiler_temp$jscomp$643_this$$jscomp$561$$=$cljs$pprint$process_bracket$$($JSCompiler_temp$jscomp$642_JSCompiler_temp$jscomp$643_this$$jscomp$561$$,
$remainder__$1$jscomp$2_remainder__$2$$);else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$258$right$$.$cljs$core$IFn$_invoke$arity$1$($bracket_info$$),$cljs$cst$1466$directive$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1429$def$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$642_JSCompiler_temp$jscomp$643_this$$jscomp$561$$))))$JSCompiler_temp$jscomp$642_JSCompiler_temp$jscomp$643_this$$jscomp$561$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[null,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1476$right_bracket$$,$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$642_JSCompiler_temp$jscomp$643_this$$jscomp$561$$),null,$remainder__$1$jscomp$2_remainder__$2$$],null)],null);else{var $JSCompiler_inline_result$jscomp$644_and__5023__auto__$jscomp$inline_4489$$=$APP.$cljs$cst$1472$separator$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1468$bracket_info$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1429$def$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$642_JSCompiler_temp$jscomp$643_this$$jscomp$561$$)));
$JSCompiler_inline_result$jscomp$644_and__5023__auto__$jscomp$inline_4489$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$644_and__5023__auto__$jscomp$inline_4489$$)?$APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$642_JSCompiler_temp$jscomp$643_this$$jscomp$561$$)):$JSCompiler_inline_result$jscomp$644_and__5023__auto__$jscomp$inline_4489$$;$JSCompiler_temp$jscomp$642_JSCompiler_temp$jscomp$643_this$$jscomp$561$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$644_and__5023__auto__$jscomp$inline_4489$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$225$else$$,null,$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$642_JSCompiler_temp$jscomp$643_this$$jscomp$561$$),$remainder__$1$jscomp$2_remainder__$2$$],null)],
null):$APP.$cljs$core$truth_$$($APP.$cljs$cst$1472$separator$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1468$bracket_info$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1429$def$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$642_JSCompiler_temp$jscomp$643_this$$jscomp$561$$))))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1472$separator$$,
null,null,$remainder__$1$jscomp$2_remainder__$2$$],null)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$642_JSCompiler_temp$jscomp$643_this$$jscomp$561$$,$remainder__$1$jscomp$2_remainder__$2$$],null)}return $JSCompiler_temp$jscomp$642_JSCompiler_temp$jscomp$643_this$$jscomp$561$$},$remainder$jscomp$9$$)};
$cljs$pprint$collect_clauses$$=function($bracket_info$jscomp$1$$,$offset$jscomp$91$$,$remainder$jscomp$10$$){return $APP.$cljs$core$second$$($cljs$pprint$consume$$(function($clause$jscomp$9_p__45178_remainder__$1$jscomp$3$$){var $clause_map$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($clause$jscomp$9_p__45178_remainder__$1$jscomp$3$$,0,null),$saw_else$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($clause$jscomp$9_p__45178_remainder__$1$jscomp$3$$,1,null);$clause$jscomp$9_p__45178_remainder__$1$jscomp$3$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($clause$jscomp$9_p__45178_remainder__$1$jscomp$3$$,2,null);var $type$jscomp$253_vec__45182$$=$cljs$pprint$process_clause$$($bracket_info$jscomp$1$$,$offset$jscomp$91$$,$clause$jscomp$9_p__45178_remainder__$1$jscomp$3$$);$clause$jscomp$9_p__45178_remainder__$1$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($type$jscomp$253_vec__45182$$,0,null);var $remainder__$2$jscomp$1_vec__45185$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($type$jscomp$253_vec__45182$$,
1,null);$type$jscomp$253_vec__45182$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($remainder__$2$jscomp$1_vec__45185$$,0,null);var $right_params$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($remainder__$2$jscomp$1_vec__45185$$,1,null),$else_params$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($remainder__$2$jscomp$1_vec__45185$$,2,null);$remainder__$2$jscomp$1_vec__45185$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($remainder__$2$jscomp$1_vec__45185$$,
3,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$253_vec__45182$$,$cljs$cst$1476$right_bracket$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$merge_with$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$concat$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$clause_map$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$APP.$cljs$core$truth_$$($saw_else$$)?
$cljs$cst$225$else$$:$cljs$cst$1453$clauses$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$clause$jscomp$9_p__45178_remainder__$1$jscomp$3$$],null),$cljs$cst$1455$right_params$$,$right_params$$])])),$remainder__$2$jscomp$1_vec__45185$$],null)],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$253_vec__45182$$,$cljs$cst$225$else$$)?$APP.$cljs$core$truth_$$($cljs$cst$225$else$$.$cljs$core$IFn$_invoke$arity$1$($clause_map$$))?
$cljs$pprint$format_error$$('Two else clauses ("~:;") inside bracket construction.',$offset$jscomp$91$$):$APP.$cljs$core$not$$($cljs$cst$225$else$$.$cljs$core$IFn$_invoke$arity$1$($bracket_info$jscomp$1$$))?$cljs$pprint$format_error$$('An else clause ("~:;") is in a bracket type that doesn\'t support it.',$offset$jscomp$91$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1320$first$$,$cljs$cst$225$else$$.$cljs$core$IFn$_invoke$arity$1$($bracket_info$jscomp$1$$))&&$APP.$cljs$core$seq$$($cljs$cst$1453$clauses$$.$cljs$core$IFn$_invoke$arity$1$($clause_map$$))?
$cljs$pprint$format_error$$('The else clause ("~:;") is only allowed in the first position for this directive.',$offset$jscomp$91$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1320$first$$,$cljs$cst$225$else$$.$cljs$core$IFn$_invoke$arity$1$($bracket_info$jscomp$1$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[!0,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$merge_with$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$concat$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$clause_map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$225$else$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$clause$jscomp$9_p__45178_remainder__$1$jscomp$3$$],null),$cljs$cst$1456$else_params$$,$else_params$jscomp$1$$],null)])),!1,$remainder__$2$jscomp$1_vec__45185$$],null)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[!0,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$merge_with$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$concat$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$clause_map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1453$clauses$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$clause$jscomp$9_p__45178_remainder__$1$jscomp$3$$],null)],null)])),
!0,$remainder__$2$jscomp$1_vec__45185$$],null)],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$253_vec__45182$$,$APP.$cljs$cst$1472$separator$$)?$APP.$cljs$core$truth_$$($saw_else$$)?$cljs$pprint$format_error$$('A plain clause (with "~;") follows an else clause ("~:;") inside bracket construction.',$offset$jscomp$91$$):$APP.$cljs$core$not$$($cljs$cst$1470$allows_separator$$.$cljs$core$IFn$_invoke$arity$1$($bracket_info$jscomp$1$$))?$cljs$pprint$format_error$$('A separator ("~;") is in a bracket type that doesn\'t support it.',
$offset$jscomp$91$$):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[!0,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$merge_with$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$concat$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$clause_map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1453$clauses$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$clause$jscomp$9_p__45178_remainder__$1$jscomp$3$$],null)],null)])),!1,$remainder__$2$jscomp$1_vec__45185$$],null)],null):null},new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1453$clauses$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),!1,$remainder$jscomp$10$$],null)))};
$cljs$pprint$process_nesting$$=function($format$jscomp$23$$){return $APP.$cljs$core$first$$($cljs$pprint$consume$$(function($remainder$jscomp$11_remainder__$1$jscomp$4$$){var $this$$jscomp$562$$=$APP.$cljs$core$first$$($remainder$jscomp$11_remainder__$1$jscomp$4$$);$remainder$jscomp$11_remainder__$1$jscomp$4$$=$APP.$cljs$core$next$$($remainder$jscomp$11_remainder__$1$jscomp$4$$);var $bracket$$=$cljs$cst$1468$bracket_info$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1429$def$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$562$$));
return $APP.$cljs$core$truth_$$($APP.$cljs$cst$258$right$$.$cljs$core$IFn$_invoke$arity$1$($bracket$$))?$cljs$pprint$process_bracket$$($this$$jscomp$562$$,$remainder$jscomp$11_remainder__$1$jscomp$4$$):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$this$$jscomp$562$$,$remainder$jscomp$11_remainder__$1$jscomp$4$$],null)},$format$jscomp$23$$))};
$cljs$pprint$compile_format$$=function($format_str$$){var $_STAR_format_str_STAR__orig_val__45190$$=$cljs$pprint$_STAR_format_str_STAR_$$;$cljs$pprint$_STAR_format_str_STAR_$$=$format_str$$;try{return $cljs$pprint$process_nesting$$($APP.$cljs$core$first$$($cljs$pprint$consume$$(function($offset$jscomp$92_p__45194$$){var $s$jscomp$502$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offset$jscomp$92_p__45194$$,0,null);$offset$jscomp$92_p__45194$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offset$jscomp$92_p__45194$$,
1,null);if($APP.$cljs$core$empty_QMARK_$$($s$jscomp$502$$))return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$s$jscomp$502$$],null);var $tilde$$=$s$jscomp$502$$.indexOf("~");return $tilde$$<0?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$pprint$compile_raw_string$$($s$jscomp$502$$,$offset$jscomp$92_p__45194$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["",$offset$jscomp$92_p__45194$$+$s$jscomp$502$$.length],null)],null):$tilde$$===0?$cljs$pprint$compile_directive$$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$502$$,1),$offset$jscomp$92_p__45194$$+1):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$pprint$compile_raw_string$$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$502$$,0,$tilde$$),$offset$jscomp$92_p__45194$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$502$$,$tilde$$),$tilde$$+$offset$jscomp$92_p__45194$$],null)],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$format_str$$,0],null))))}finally{$cljs$pprint$_STAR_format_str_STAR_$$=$_STAR_format_str_STAR__orig_val__45190$$}};
$cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$=function($format$jscomp$26$$,$args$jscomp$217$$){$cljs$pprint$map_passing_context$$(function($element$jscomp$40$$,$args__$1$jscomp$7_context$jscomp$17_vec__45206$$){if($cljs$pprint$abort_QMARK_$$($args__$1$jscomp$7_context$jscomp$17_vec__45206$$))return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$args__$1$jscomp$7_context$jscomp$17_vec__45206$$],null);$args__$1$jscomp$7_context$jscomp$17_vec__45206$$=
$cljs$pprint$realize_parameter_list$$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($element$jscomp$40$$),$args__$1$jscomp$7_context$jscomp$17_vec__45206$$);var $params$jscomp$84_params__$1$jscomp$17_params__$2$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($args__$1$jscomp$7_context$jscomp$17_vec__45206$$,0,null);$args__$1$jscomp$7_context$jscomp$17_vec__45206$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($args__$1$jscomp$7_context$jscomp$17_vec__45206$$,
1,null);var $offsets$jscomp$41_vec__45209$$=$cljs$pprint$unzip_map$$($params$jscomp$84_params__$1$jscomp$17_params__$2$jscomp$3$$);$params$jscomp$84_params__$1$jscomp$17_params__$2$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offsets$jscomp$41_vec__45209$$,0,null);$offsets$jscomp$41_vec__45209$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offsets$jscomp$41_vec__45209$$,1,null);$params$jscomp$84_params__$1$jscomp$17_params__$2$jscomp$3$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($params$jscomp$84_params__$1$jscomp$17_params__$2$jscomp$3$$,
$cljs$cst$1445$base_args$$,$args__$1$jscomp$7_context$jscomp$17_vec__45206$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1428$func$$.$cljs$core$IFn$_invoke$arity$1$($element$jscomp$40$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$params$jscomp$84_params__$1$jscomp$17_params__$2$jscomp$3$$,$args__$1$jscomp$7_context$jscomp$17_vec__45206$$,
$offsets$jscomp$41_vec__45209$$],null))],null)},$args$jscomp$217$$,$format$jscomp$26$$);return null};
$cljs$pprint$pprint_reader_macro$$=function($alis$$){var $G__45217$jscomp$inline_11730_macro_char$$=$APP.$cljs$core$first$$($alis$$);$G__45217$jscomp$inline_11730_macro_char$$=$cljs$pprint$reader_macros$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$pprint$reader_macros$$.$cljs$core$IFn$_invoke$arity$1$($G__45217$jscomp$inline_11730_macro_char$$):$cljs$pprint$reader_macros$$($G__45217$jscomp$inline_11730_macro_char$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__45217$jscomp$inline_11730_macro_char$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$APP.$cljs$core$count$$($alis$$)):$G__45217$jscomp$inline_11730_macro_char$$)?($APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,$G__45217$jscomp$inline_11730_macro_char$$),$cljs$pprint$write_out$$($APP.$cljs$core$second$$($alis$$)),!0):null};
$cljs$pprint$pprint_vector$$=function($G__46115_avec$$){if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"#");else{var $_STAR_current_level_STAR__orig_val__45227_46109$$=$cljs$pprint$_STAR_current_level_STAR_$$,$_STAR_current_length_STAR__orig_val__45228_46110$$=$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$("[","]");for(var $length_count45231_46113$$=
0,$aseq_46114$$=$APP.$cljs$core$seq$$($G__46115_avec$$);;){if($APP.$cljs$core$not$$($cljs$core$_STAR_print_length_STAR_$$)||$length_count45231_46113$$<$cljs$core$_STAR_print_length_STAR_$$){if($aseq_46114$$&&($cljs$pprint$write_out$$($APP.$cljs$core$first$$($aseq_46114$$)),$APP.$cljs$core$next$$($aseq_46114$$))){$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$," ");$cljs$pprint$pprint_newline$$($APP.$cljs$cst$287$linear$$);$G__46115_avec$$=$length_count45231_46113$$+1;var $G__46116$$=$APP.$cljs$core$next$$($aseq_46114$$);
$length_count45231_46113$$=$G__46115_avec$$;$aseq_46114$$=$G__46116$$;continue}}else $APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"...");break}$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=$_STAR_current_length_STAR__orig_val__45228_46110$$,$cljs$pprint$_STAR_current_level_STAR_$$=$_STAR_current_level_STAR__orig_val__45227_46109$$}}return null};
$cljs$pprint$pprint_map$$=function($amap$$){var $_STAR_current_length_STAR__orig_val__45246_46123_lift_map$jscomp$1_vec__45238$$=$APP.$cljs$core$record_QMARK_$$($amap$$)?null:function(){var $fexpr__45241$$=new $APP.$cljs$core$Var$$(function(){return $cljs$core$lift_ns$$},$cljs$cst$1477$cljs_DOT_core_SLASH_lift_ns$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1478$private$$,$APP.$cljs$cst$176$ns$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$218$end_column$$,
$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$209$line$$,$APP.$cljs$cst$217$end_line$$,$APP.$cljs$cst$1479$arglists$$,$APP.$cljs$cst$1480$doc$$,$APP.$cljs$cst$171$test$$],[!0,$cljs$cst$1481$cljs_DOT_core$$,$cljs$cst$1482$lift_ns$$,"cljs/core.cljs",15,1,10699,10699,$APP.$cljs$core$list$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$316$m$$],null)),"Returns [lifted-ns lifted-map] or nil if m can't be lifted.",$APP.$cljs$core$truth_$$($cljs$core$lift_ns$$)?
$cljs$core$lift_ns$$.$cljs$lang$test$:null]));return $fexpr__45241$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__45241$$.$cljs$core$IFn$_invoke$arity$1$($amap$$):$fexpr__45241$$($amap$$)}(),$_STAR_current_level_STAR__orig_val__45245_46122_ns$jscomp$29$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_STAR_current_length_STAR__orig_val__45246_46123_lift_map$jscomp$1_vec__45238$$,0,null);$_STAR_current_length_STAR__orig_val__45246_46123_lift_map$jscomp$1_vec__45238$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_STAR_current_length_STAR__orig_val__45246_46123_lift_map$jscomp$1_vec__45238$$,
1,null);var $G__46135__STAR_current_level_STAR__orig_val__45250_46130_amap__$1$$=$APP.$cljs$core$truth_$$($_STAR_current_length_STAR__orig_val__45246_46123_lift_map$jscomp$1_vec__45238$$)?$_STAR_current_length_STAR__orig_val__45246_46123_lift_map$jscomp$1_vec__45238$$:$amap$$,$length_count45249_46127_prefix$jscomp$30$$=$APP.$cljs$core$truth_$$($_STAR_current_level_STAR__orig_val__45245_46122_ns$jscomp$29$$)?["#:",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($_STAR_current_level_STAR__orig_val__45245_46122_ns$jscomp$29$$),
"{"].join(""):"{";if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"#");else{$_STAR_current_level_STAR__orig_val__45245_46122_ns$jscomp$29$$=$cljs$pprint$_STAR_current_level_STAR_$$;$_STAR_current_length_STAR__orig_val__45246_46123_lift_map$jscomp$1_vec__45238$$=$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$($length_count45249_46127_prefix$jscomp$30$$,
"}");$length_count45249_46127_prefix$jscomp$30$$=0;for(var $aseq_46128$$=$APP.$cljs$core$seq$$($G__46135__STAR_current_level_STAR__orig_val__45250_46130_amap__$1$$);;){if($APP.$cljs$core$not$$($cljs$core$_STAR_print_length_STAR_$$)||$length_count45249_46127_prefix$jscomp$30$$<$cljs$core$_STAR_print_length_STAR_$$){if($aseq_46128$$){if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"#");else{$G__46135__STAR_current_level_STAR__orig_val__45250_46130_amap__$1$$=
$cljs$pprint$_STAR_current_level_STAR_$$;var $_STAR_current_length_STAR__orig_val__45251_46131$$=$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$(null,null),$cljs$pprint$write_out$$($APP.$cljs$core$ffirst$$($aseq_46128$$)),$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$," "),$cljs$pprint$pprint_newline$$($APP.$cljs$cst$287$linear$$),$cljs$pprint$_STAR_current_length_STAR_$$=0,$cljs$pprint$write_out$$($APP.$cljs$core$fnext$$($APP.$cljs$core$first$$($aseq_46128$$))),
$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=$_STAR_current_length_STAR__orig_val__45251_46131$$,$cljs$pprint$_STAR_current_level_STAR_$$=$G__46135__STAR_current_level_STAR__orig_val__45250_46130_amap__$1$$}}if($APP.$cljs$core$next$$($aseq_46128$$)){$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,", ");$cljs$pprint$pprint_newline$$($APP.$cljs$cst$287$linear$$);$G__46135__STAR_current_level_STAR__orig_val__45250_46130_amap__$1$$=$length_count45249_46127_prefix$jscomp$30$$+
1;var $G__46136$$=$APP.$cljs$core$next$$($aseq_46128$$);$length_count45249_46127_prefix$jscomp$30$$=$G__46135__STAR_current_level_STAR__orig_val__45250_46130_amap__$1$$;$aseq_46128$$=$G__46136$$;continue}}}else $APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"...");break}$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=$_STAR_current_length_STAR__orig_val__45246_46123_lift_map$jscomp$1_vec__45238$$,$cljs$pprint$_STAR_current_level_STAR_$$=$_STAR_current_level_STAR__orig_val__45245_46122_ns$jscomp$29$$}}return null};
$cljs$pprint$pprint_simple_default$$=function($obj$jscomp$153$$){return $APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$obj$jscomp$153$$])))};
$cljs$pprint$type_dispatcher$$=function($obj$jscomp$154$$){return $obj$jscomp$154$$ instanceof $cljs$core$PersistentQueue$$?$APP.$cljs$cst$1484$queue$$:($obj$jscomp$154$$!=null?$obj$jscomp$154$$.$cljs$lang$protocol_mask$partition0$$&32768||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$obj$jscomp$154$$.$cljs$core$IDeref$$||($obj$jscomp$154$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IDeref$$,$obj$jscomp$154$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IDeref$$,
$obj$jscomp$154$$))?$cljs$cst$1485$deref$$:$obj$jscomp$154$$ instanceof $APP.$cljs$core$Symbol$$?$APP.$cljs$cst$219$symbol$$:$APP.$cljs$core$seq_QMARK_$$($obj$jscomp$154$$)?$APP.$cljs$cst$201$list$$:$APP.$cljs$core$map_QMARK_$$($obj$jscomp$154$$)?$APP.$cljs$cst$202$map$$:$APP.$cljs$core$vector_QMARK_$$($obj$jscomp$154$$)?$APP.$cljs$cst$200$vector$$:$APP.$cljs$core$set_QMARK_$$($obj$jscomp$154$$)?$APP.$cljs$cst$203$set$$:$obj$jscomp$154$$==null?null:$APP.$cljs$cst$205$default$$};
$cljs$pprint$brackets$$=function($form$jscomp$146$$){return $APP.$cljs$core$vector_QMARK_$$($form$jscomp$146$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["[","]"],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["(",")"],null)};
$cljs$pprint$pprint_ns_reference$$=function($reference$$){if($APP.$cljs$core$sequential_QMARK_$$($reference$$)){var $vec__45299$$=$cljs$pprint$brackets$$($reference$$),$start$jscomp$178$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__45299$$,0,null),$end$jscomp$45$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__45299$$,1,null),$seq__45303$$=$APP.$cljs$core$seq$$($reference$$),$first__45304$$=$APP.$cljs$core$first$$($seq__45303$$),$seq__45303__$1$$=$APP.$cljs$core$next$$($seq__45303$$);
if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"#");else{var $_STAR_current_level_STAR__orig_val__45312_46149$$=$cljs$pprint$_STAR_current_level_STAR_$$,$_STAR_current_length_STAR__orig_val__45313_46150$$=$cljs$pprint$_STAR_current_length_STAR_$$,$_STAR_current_level_STAR__temp_val__45314_46151$$=$cljs$pprint$_STAR_current_level_STAR_$$+1;$cljs$pprint$_STAR_current_level_STAR_$$=$_STAR_current_level_STAR__temp_val__45314_46151$$;
$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$($start$jscomp$178$$,$end$jscomp$45$$);(function(){var $cf__42926__auto__$jscomp$3$$=$cljs$pprint$cached_compile$$("~w~:i");return function(){function $G__46154$$($var_args$jscomp$752$$){var $G__46156__i_args__42927__auto__$jscomp$10$$=null;if(arguments.length>0){$G__46156__i_args__42927__auto__$jscomp$10$$=0;for(var $G__46156__a$$=Array(arguments.length-0);$G__46156__i_args__42927__auto__$jscomp$10$$<$G__46156__a$$.length;)$G__46156__a$$[$G__46156__i_args__42927__auto__$jscomp$10$$]=
arguments[$G__46156__i_args__42927__auto__$jscomp$10$$+0],++$G__46156__i_args__42927__auto__$jscomp$10$$;$G__46156__i_args__42927__auto__$jscomp$10$$=new $APP.$cljs$core$IndexedSeq$$($G__46156__a$$,0,null)}return $G__46154__delegate$$.call(this,$G__46156__i_args__42927__auto__$jscomp$10$$)}function $G__46154__delegate$$($args__42927__auto__$jscomp$9_navigator__42928__auto__$jscomp$3$$){$args__42927__auto__$jscomp$9_navigator__42928__auto__$jscomp$3$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$9_navigator__42928__auto__$jscomp$3$$);
return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$3$$,$args__42927__auto__$jscomp$9_navigator__42928__auto__$jscomp$3$$)}$G__46154$$.$cljs$lang$maxFixedArity$=0;$G__46154$$.$cljs$lang$applyTo$=function($arglist__46157_args__42927__auto__$jscomp$11$$){$arglist__46157_args__42927__auto__$jscomp$11$$=$APP.$cljs$core$seq$$($arglist__46157_args__42927__auto__$jscomp$11$$);return $G__46154__delegate$$($arglist__46157_args__42927__auto__$jscomp$11$$)};$G__46154$$.$cljs$core$IFn$_invoke$arity$variadic$=
$G__46154__delegate$$;return $G__46154$$}()})()($first__45304$$);for(var $args_46158__$1$$=$seq__45303__$1$$;;)if($APP.$cljs$core$seq$$($args_46158__$1$$)){(function(){var $cf__42926__auto__$jscomp$4$$=$cljs$pprint$cached_compile$$(" ");return function($args_46158__$1$jscomp$1$$,$format_in__42925__auto__$jscomp$5$$,$cf__42926__auto__$jscomp$5$$){return function(){function $G__46159$$($var_args$jscomp$753$$){var $G__46160__i_args__42927__auto__$jscomp$13$$=null;if(arguments.length>0){$G__46160__i_args__42927__auto__$jscomp$13$$=
0;for(var $G__46160__a$$=Array(arguments.length-0);$G__46160__i_args__42927__auto__$jscomp$13$$<$G__46160__a$$.length;)$G__46160__a$$[$G__46160__i_args__42927__auto__$jscomp$13$$]=arguments[$G__46160__i_args__42927__auto__$jscomp$13$$+0],++$G__46160__i_args__42927__auto__$jscomp$13$$;$G__46160__i_args__42927__auto__$jscomp$13$$=new $APP.$cljs$core$IndexedSeq$$($G__46160__a$$,0,null)}return $G__46159__delegate$$.call(this,$G__46160__i_args__42927__auto__$jscomp$13$$)}function $G__46159__delegate$$($args__42927__auto__$jscomp$12_navigator__42928__auto__$jscomp$4$$){$args__42927__auto__$jscomp$12_navigator__42928__auto__$jscomp$4$$=
$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$12_navigator__42928__auto__$jscomp$4$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$5$$,$args__42927__auto__$jscomp$12_navigator__42928__auto__$jscomp$4$$)}$G__46159$$.$cljs$lang$maxFixedArity$=0;$G__46159$$.$cljs$lang$applyTo$=function($arglist__46161_args__42927__auto__$jscomp$14$$){$arglist__46161_args__42927__auto__$jscomp$14$$=$APP.$cljs$core$seq$$($arglist__46161_args__42927__auto__$jscomp$14$$);
return $G__46159__delegate$$($arglist__46161_args__42927__auto__$jscomp$14$$)};$G__46159$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46159__delegate$$;return $G__46159$$}()}($args_46158__$1$$," ",$cf__42926__auto__$jscomp$4$$,$_STAR_current_level_STAR__orig_val__45312_46149$$,$_STAR_current_length_STAR__orig_val__45313_46150$$,$_STAR_current_level_STAR__temp_val__45314_46151$$,0,$vec__45299$$,$start$jscomp$178$$,$end$jscomp$45$$,$reference$$,$seq__45303$$,$first__45304$$,$seq__45303__$1$$,$first__45304$$,
$seq__45303__$1$$)})()();var $arg_46162$$=$APP.$cljs$core$first$$($args_46158__$1$$);if($APP.$cljs$core$sequential_QMARK_$$($arg_46162$$)){var $vec__45316_46163$$=$cljs$pprint$brackets$$($arg_46162$$),$start_46164__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__45316_46163$$,0,null),$end_46165__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__45316_46163$$,1,null);if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,
"#");else{var $_STAR_current_level_STAR__orig_val__45327_46168$$=$cljs$pprint$_STAR_current_level_STAR_$$,$_STAR_current_length_STAR__orig_val__45328_46169$$=$cljs$pprint$_STAR_current_length_STAR_$$,$_STAR_current_level_STAR__temp_val__45329_46170$$=$cljs$pprint$_STAR_current_level_STAR_$$+1;$cljs$pprint$_STAR_current_level_STAR_$$=$_STAR_current_level_STAR__temp_val__45329_46170$$;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$($start_46164__$1$$,$end_46165__$1$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($arg_46162$$),
3)&&$APP.$cljs$core$second$$($arg_46162$$)instanceof $APP.$cljs$core$Keyword$$){var $vec__45331_46172$$=$arg_46162$$,$ns_46173$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__45331_46172$$,0,null),$kw_46174$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__45331_46172$$,1,null),$lis_46175$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__45331_46172$$,2,null);(function(){var $cf__42926__auto__$jscomp$6$$=$cljs$pprint$cached_compile$$("~w ~w ");return function($args_46158__$1$jscomp$2$$,
$format_in__42925__auto__$jscomp$7$$,$cf__42926__auto__$jscomp$7$$){return function(){function $G__46176$$($var_args$jscomp$754$$){var $G__46177__i_args__42927__auto__$jscomp$16$$=null;if(arguments.length>0){$G__46177__i_args__42927__auto__$jscomp$16$$=0;for(var $G__46177__a$$=Array(arguments.length-0);$G__46177__i_args__42927__auto__$jscomp$16$$<$G__46177__a$$.length;)$G__46177__a$$[$G__46177__i_args__42927__auto__$jscomp$16$$]=arguments[$G__46177__i_args__42927__auto__$jscomp$16$$+0],++$G__46177__i_args__42927__auto__$jscomp$16$$;
$G__46177__i_args__42927__auto__$jscomp$16$$=new $APP.$cljs$core$IndexedSeq$$($G__46177__a$$,0,null)}return $G__46176__delegate$$.call(this,$G__46177__i_args__42927__auto__$jscomp$16$$)}function $G__46176__delegate$$($args__42927__auto__$jscomp$15_navigator__42928__auto__$jscomp$5$$){$args__42927__auto__$jscomp$15_navigator__42928__auto__$jscomp$5$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$15_navigator__42928__auto__$jscomp$5$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$7$$,
$args__42927__auto__$jscomp$15_navigator__42928__auto__$jscomp$5$$)}$G__46176$$.$cljs$lang$maxFixedArity$=0;$G__46176$$.$cljs$lang$applyTo$=function($arglist__46178_args__42927__auto__$jscomp$17$$){$arglist__46178_args__42927__auto__$jscomp$17$$=$APP.$cljs$core$seq$$($arglist__46178_args__42927__auto__$jscomp$17$$);return $G__46176__delegate$$($arglist__46178_args__42927__auto__$jscomp$17$$)};$G__46176$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46176__delegate$$;return $G__46176$$}()}($args_46158__$1$$,
"~w ~w ",$cf__42926__auto__$jscomp$6$$,$vec__45331_46172$$,$ns_46173$$,$kw_46174$$,$lis_46175$$,$_STAR_current_level_STAR__orig_val__45327_46168$$,$_STAR_current_length_STAR__orig_val__45328_46169$$,$_STAR_current_level_STAR__temp_val__45329_46170$$,0,$vec__45316_46163$$,$start_46164__$1$$,$end_46165__$1$$,$arg_46162$$,$_STAR_current_level_STAR__orig_val__45312_46149$$,$_STAR_current_length_STAR__orig_val__45313_46150$$,$_STAR_current_level_STAR__temp_val__45314_46151$$,0,$vec__45299$$,$start$jscomp$178$$,
$end$jscomp$45$$,$reference$$,$seq__45303$$,$first__45304$$,$seq__45303__$1$$,$first__45304$$,$seq__45303__$1$$)})()($ns_46173$$,$kw_46174$$);$APP.$cljs$core$sequential_QMARK_$$($lis_46175$$)?function(){var $format_in__42925__auto__$jscomp$8$$=$APP.$cljs$core$vector_QMARK_$$($lis_46175$$)?"~\x3c[~;~@{~w~^ ~:_~}~;]~:\x3e":"~\x3c(~;~@{~w~^ ~:_~}~;)~:\x3e",$cf__42926__auto__$jscomp$8$$=typeof $format_in__42925__auto__$jscomp$8$$==="string"?$cljs$pprint$cached_compile$$($format_in__42925__auto__$jscomp$8$$):
$format_in__42925__auto__$jscomp$8$$;return function($args_46158__$1$jscomp$3$$,$format_in__42925__auto__$jscomp$9$$,$cf__42926__auto__$jscomp$9$$){return function(){function $G__46180$$($var_args$jscomp$755$$){var $G__46181__i_args__42927__auto__$jscomp$19$$=null;if(arguments.length>0){$G__46181__i_args__42927__auto__$jscomp$19$$=0;for(var $G__46181__a$$=Array(arguments.length-0);$G__46181__i_args__42927__auto__$jscomp$19$$<$G__46181__a$$.length;)$G__46181__a$$[$G__46181__i_args__42927__auto__$jscomp$19$$]=
arguments[$G__46181__i_args__42927__auto__$jscomp$19$$+0],++$G__46181__i_args__42927__auto__$jscomp$19$$;$G__46181__i_args__42927__auto__$jscomp$19$$=new $APP.$cljs$core$IndexedSeq$$($G__46181__a$$,0,null)}return $G__46180__delegate$$.call(this,$G__46181__i_args__42927__auto__$jscomp$19$$)}function $G__46180__delegate$$($args__42927__auto__$jscomp$18_navigator__42928__auto__$jscomp$6$$){$args__42927__auto__$jscomp$18_navigator__42928__auto__$jscomp$6$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$18_navigator__42928__auto__$jscomp$6$$);
return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$9$$,$args__42927__auto__$jscomp$18_navigator__42928__auto__$jscomp$6$$)}$G__46180$$.$cljs$lang$maxFixedArity$=0;$G__46180$$.$cljs$lang$applyTo$=function($arglist__46182_args__42927__auto__$jscomp$20$$){$arglist__46182_args__42927__auto__$jscomp$20$$=$APP.$cljs$core$seq$$($arglist__46182_args__42927__auto__$jscomp$20$$);return $G__46180__delegate$$($arglist__46182_args__42927__auto__$jscomp$20$$)};$G__46180$$.$cljs$core$IFn$_invoke$arity$variadic$=
$G__46180__delegate$$;return $G__46180$$}()}($args_46158__$1$$,$format_in__42925__auto__$jscomp$8$$,$cf__42926__auto__$jscomp$8$$,$vec__45331_46172$$,$ns_46173$$,$kw_46174$$,$lis_46175$$,$_STAR_current_level_STAR__orig_val__45327_46168$$,$_STAR_current_length_STAR__orig_val__45328_46169$$,$_STAR_current_level_STAR__temp_val__45329_46170$$,0,$vec__45316_46163$$,$start_46164__$1$$,$end_46165__$1$$,$arg_46162$$,$_STAR_current_level_STAR__orig_val__45312_46149$$,$_STAR_current_length_STAR__orig_val__45313_46150$$,
$_STAR_current_level_STAR__temp_val__45314_46151$$,0,$vec__45299$$,$start$jscomp$178$$,$end$jscomp$45$$,$reference$$,$seq__45303$$,$first__45304$$,$seq__45303__$1$$,$first__45304$$,$seq__45303__$1$$)}()($lis_46175$$):$cljs$pprint$write_out$$($lis_46175$$)}else $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $cf__42926__auto__$jscomp$10$$=$cljs$pprint$cached_compile$$("~w ~:i~@{~w~^ ~:_~}");return function($args_46158__$1$jscomp$4$$,$format_in__42925__auto__$jscomp$11$$,$cf__42926__auto__$jscomp$11$$){return function(){function $G__46183$$($var_args$jscomp$756$$){var $G__46184__i_args__42927__auto__$jscomp$22$$=
null;if(arguments.length>0){$G__46184__i_args__42927__auto__$jscomp$22$$=0;for(var $G__46184__a$$=Array(arguments.length-0);$G__46184__i_args__42927__auto__$jscomp$22$$<$G__46184__a$$.length;)$G__46184__a$$[$G__46184__i_args__42927__auto__$jscomp$22$$]=arguments[$G__46184__i_args__42927__auto__$jscomp$22$$+0],++$G__46184__i_args__42927__auto__$jscomp$22$$;$G__46184__i_args__42927__auto__$jscomp$22$$=new $APP.$cljs$core$IndexedSeq$$($G__46184__a$$,0,null)}return $G__46183__delegate$$.call(this,$G__46184__i_args__42927__auto__$jscomp$22$$)}
function $G__46183__delegate$$($args__42927__auto__$jscomp$21_navigator__42928__auto__$jscomp$7$$){$args__42927__auto__$jscomp$21_navigator__42928__auto__$jscomp$7$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$21_navigator__42928__auto__$jscomp$7$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$11$$,$args__42927__auto__$jscomp$21_navigator__42928__auto__$jscomp$7$$)}$G__46183$$.$cljs$lang$maxFixedArity$=0;$G__46183$$.$cljs$lang$applyTo$=
function($arglist__46185_args__42927__auto__$jscomp$23$$){$arglist__46185_args__42927__auto__$jscomp$23$$=$APP.$cljs$core$seq$$($arglist__46185_args__42927__auto__$jscomp$23$$);return $G__46183__delegate$$($arglist__46185_args__42927__auto__$jscomp$23$$)};$G__46183$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46183__delegate$$;return $G__46183$$}()}($args_46158__$1$$,"~w ~:i~@{~w~^ ~:_~}",$cf__42926__auto__$jscomp$10$$,$_STAR_current_level_STAR__orig_val__45327_46168$$,$_STAR_current_length_STAR__orig_val__45328_46169$$,
$_STAR_current_level_STAR__temp_val__45329_46170$$,0,$vec__45316_46163$$,$start_46164__$1$$,$end_46165__$1$$,$arg_46162$$,$_STAR_current_level_STAR__orig_val__45312_46149$$,$_STAR_current_length_STAR__orig_val__45313_46150$$,$_STAR_current_level_STAR__temp_val__45314_46151$$,0,$vec__45299$$,$start$jscomp$178$$,$end$jscomp$45$$,$reference$$,$seq__45303$$,$first__45304$$,$seq__45303__$1$$,$first__45304$$,$seq__45303__$1$$)}(),$arg_46162$$);$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=
$_STAR_current_length_STAR__orig_val__45328_46169$$,$cljs$pprint$_STAR_current_level_STAR_$$=$_STAR_current_level_STAR__orig_val__45327_46168$$}}$APP.$cljs$core$next$$($args_46158__$1$$)&&function(){var $cf__42926__auto__$jscomp$12$$=$cljs$pprint$cached_compile$$("~_");return function($args_46158__$1$jscomp$5$$,$format_in__42925__auto__$jscomp$13$$,$cf__42926__auto__$jscomp$13$$){return function(){function $G__46187$$($var_args$jscomp$757$$){var $G__46188__i_args__42927__auto__$jscomp$25$$=null;if(arguments.length>
0){$G__46188__i_args__42927__auto__$jscomp$25$$=0;for(var $G__46188__a$$=Array(arguments.length-0);$G__46188__i_args__42927__auto__$jscomp$25$$<$G__46188__a$$.length;)$G__46188__a$$[$G__46188__i_args__42927__auto__$jscomp$25$$]=arguments[$G__46188__i_args__42927__auto__$jscomp$25$$+0],++$G__46188__i_args__42927__auto__$jscomp$25$$;$G__46188__i_args__42927__auto__$jscomp$25$$=new $APP.$cljs$core$IndexedSeq$$($G__46188__a$$,0,null)}return $G__46187__delegate$$.call(this,$G__46188__i_args__42927__auto__$jscomp$25$$)}
function $G__46187__delegate$$($args__42927__auto__$jscomp$24_navigator__42928__auto__$jscomp$8$$){$args__42927__auto__$jscomp$24_navigator__42928__auto__$jscomp$8$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$24_navigator__42928__auto__$jscomp$8$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$13$$,$args__42927__auto__$jscomp$24_navigator__42928__auto__$jscomp$8$$)}$G__46187$$.$cljs$lang$maxFixedArity$=0;$G__46187$$.$cljs$lang$applyTo$=
function($arglist__46190_args__42927__auto__$jscomp$26$$){$arglist__46190_args__42927__auto__$jscomp$26$$=$APP.$cljs$core$seq$$($arglist__46190_args__42927__auto__$jscomp$26$$);return $G__46187__delegate$$($arglist__46190_args__42927__auto__$jscomp$26$$)};$G__46187$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46187__delegate$$;return $G__46187$$}()}($args_46158__$1$$,"~_",$cf__42926__auto__$jscomp$12$$,$vec__45316_46163$$,$start_46164__$1$$,$end_46165__$1$$,$arg_46162$$,$_STAR_current_level_STAR__orig_val__45312_46149$$,
$_STAR_current_length_STAR__orig_val__45313_46150$$,$_STAR_current_level_STAR__temp_val__45314_46151$$,0,$vec__45299$$,$start$jscomp$178$$,$end$jscomp$45$$,$reference$$,$seq__45303$$,$first__45304$$,$seq__45303__$1$$,$first__45304$$,$seq__45303__$1$$)}()()}else $cljs$pprint$write_out$$($arg_46162$$),$APP.$cljs$core$next$$($args_46158__$1$$)&&function(){var $cf__42926__auto__$jscomp$14$$=$cljs$pprint$cached_compile$$("~:_");return function($args_46158__$1$jscomp$6$$,$format_in__42925__auto__$jscomp$15$$,
$cf__42926__auto__$jscomp$15$$){return function(){function $G__46192$$($var_args$jscomp$758$$){var $G__46193__i_args__42927__auto__$jscomp$28$$=null;if(arguments.length>0){$G__46193__i_args__42927__auto__$jscomp$28$$=0;for(var $G__46193__a$$=Array(arguments.length-0);$G__46193__i_args__42927__auto__$jscomp$28$$<$G__46193__a$$.length;)$G__46193__a$$[$G__46193__i_args__42927__auto__$jscomp$28$$]=arguments[$G__46193__i_args__42927__auto__$jscomp$28$$+0],++$G__46193__i_args__42927__auto__$jscomp$28$$;
$G__46193__i_args__42927__auto__$jscomp$28$$=new $APP.$cljs$core$IndexedSeq$$($G__46193__a$$,0,null)}return $G__46192__delegate$$.call(this,$G__46193__i_args__42927__auto__$jscomp$28$$)}function $G__46192__delegate$$($args__42927__auto__$jscomp$27_navigator__42928__auto__$jscomp$9$$){$args__42927__auto__$jscomp$27_navigator__42928__auto__$jscomp$9$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$27_navigator__42928__auto__$jscomp$9$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$15$$,
$args__42927__auto__$jscomp$27_navigator__42928__auto__$jscomp$9$$)}$G__46192$$.$cljs$lang$maxFixedArity$=0;$G__46192$$.$cljs$lang$applyTo$=function($arglist__46194_args__42927__auto__$jscomp$29$$){$arglist__46194_args__42927__auto__$jscomp$29$$=$APP.$cljs$core$seq$$($arglist__46194_args__42927__auto__$jscomp$29$$);return $G__46192__delegate$$($arglist__46194_args__42927__auto__$jscomp$29$$)};$G__46192$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46192__delegate$$;return $G__46192$$}()}($args_46158__$1$$,
"~:_",$cf__42926__auto__$jscomp$14$$,$arg_46162$$,$_STAR_current_level_STAR__orig_val__45312_46149$$,$_STAR_current_length_STAR__orig_val__45313_46150$$,$_STAR_current_level_STAR__temp_val__45314_46151$$,0,$vec__45299$$,$start$jscomp$178$$,$end$jscomp$45$$,$reference$$,$seq__45303$$,$first__45304$$,$seq__45303__$1$$,$first__45304$$,$seq__45303__$1$$)}()();$args_46158__$1$$=$APP.$cljs$core$next$$($args_46158__$1$$)}else break;$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=
$_STAR_current_length_STAR__orig_val__45313_46150$$,$cljs$pprint$_STAR_current_level_STAR_$$=$_STAR_current_level_STAR__orig_val__45312_46149$$}}}else $cljs$pprint$write_out$$($reference$$)};
$cljs$pprint$single_defn$$=function($alis$jscomp$4$$,$has_doc_str_QMARK_$$){$APP.$cljs$core$seq$$($alis$jscomp$4$$)&&($APP.$cljs$core$truth_$$($has_doc_str_QMARK_$$)?function(){var $cf__42926__auto__$jscomp$20$$=$cljs$pprint$cached_compile$$(" ~_");return function(){function $G__46220$$($var_args$jscomp$763$$){var $G__46221__i_args__42927__auto__$jscomp$43$$=null;if(arguments.length>0){$G__46221__i_args__42927__auto__$jscomp$43$$=0;for(var $G__46221__a$$=Array(arguments.length-0);$G__46221__i_args__42927__auto__$jscomp$43$$<
$G__46221__a$$.length;)$G__46221__a$$[$G__46221__i_args__42927__auto__$jscomp$43$$]=arguments[$G__46221__i_args__42927__auto__$jscomp$43$$+0],++$G__46221__i_args__42927__auto__$jscomp$43$$;$G__46221__i_args__42927__auto__$jscomp$43$$=new $APP.$cljs$core$IndexedSeq$$($G__46221__a$$,0,null)}return $G__46220__delegate$$.call(this,$G__46221__i_args__42927__auto__$jscomp$43$$)}function $G__46220__delegate$$($args__42927__auto__$jscomp$42_navigator__42928__auto__$jscomp$14$$){$args__42927__auto__$jscomp$42_navigator__42928__auto__$jscomp$14$$=
$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$42_navigator__42928__auto__$jscomp$14$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$20$$,$args__42927__auto__$jscomp$42_navigator__42928__auto__$jscomp$14$$)}$G__46220$$.$cljs$lang$maxFixedArity$=0;$G__46220$$.$cljs$lang$applyTo$=function($arglist__46222_args__42927__auto__$jscomp$44$$){$arglist__46222_args__42927__auto__$jscomp$44$$=$APP.$cljs$core$seq$$($arglist__46222_args__42927__auto__$jscomp$44$$);
return $G__46220__delegate$$($arglist__46222_args__42927__auto__$jscomp$44$$)};$G__46220$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46220__delegate$$;return $G__46220$$}()}()():function(){var $cf__42926__auto__$jscomp$21$$=$cljs$pprint$cached_compile$$(" ~@_");return function(){function $G__46223$$($var_args$jscomp$764$$){var $G__46224__i_args__42927__auto__$jscomp$46$$=null;if(arguments.length>0){$G__46224__i_args__42927__auto__$jscomp$46$$=0;for(var $G__46224__a$$=Array(arguments.length-0);$G__46224__i_args__42927__auto__$jscomp$46$$<
$G__46224__a$$.length;)$G__46224__a$$[$G__46224__i_args__42927__auto__$jscomp$46$$]=arguments[$G__46224__i_args__42927__auto__$jscomp$46$$+0],++$G__46224__i_args__42927__auto__$jscomp$46$$;$G__46224__i_args__42927__auto__$jscomp$46$$=new $APP.$cljs$core$IndexedSeq$$($G__46224__a$$,0,null)}return $G__46223__delegate$$.call(this,$G__46224__i_args__42927__auto__$jscomp$46$$)}function $G__46223__delegate$$($args__42927__auto__$jscomp$45_navigator__42928__auto__$jscomp$15$$){$args__42927__auto__$jscomp$45_navigator__42928__auto__$jscomp$15$$=
$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$45_navigator__42928__auto__$jscomp$15$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$21$$,$args__42927__auto__$jscomp$45_navigator__42928__auto__$jscomp$15$$)}$G__46223$$.$cljs$lang$maxFixedArity$=0;$G__46223$$.$cljs$lang$applyTo$=function($arglist__46225_args__42927__auto__$jscomp$47$$){$arglist__46225_args__42927__auto__$jscomp$47$$=$APP.$cljs$core$seq$$($arglist__46225_args__42927__auto__$jscomp$47$$);
return $G__46223__delegate$$($arglist__46225_args__42927__auto__$jscomp$47$$)};$G__46223$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46223__delegate$$;return $G__46223$$}()}()(),function(){var $cf__42926__auto__$jscomp$22$$=$cljs$pprint$cached_compile$$("~{~w~^ ~_~}");return function(){function $G__46227$$($var_args$jscomp$765$$){var $G__46228__i_args__42927__auto__$jscomp$49$$=null;if(arguments.length>0){$G__46228__i_args__42927__auto__$jscomp$49$$=0;for(var $G__46228__a$$=Array(arguments.length-
0);$G__46228__i_args__42927__auto__$jscomp$49$$<$G__46228__a$$.length;)$G__46228__a$$[$G__46228__i_args__42927__auto__$jscomp$49$$]=arguments[$G__46228__i_args__42927__auto__$jscomp$49$$+0],++$G__46228__i_args__42927__auto__$jscomp$49$$;$G__46228__i_args__42927__auto__$jscomp$49$$=new $APP.$cljs$core$IndexedSeq$$($G__46228__a$$,0,null)}return $G__46227__delegate$$.call(this,$G__46228__i_args__42927__auto__$jscomp$49$$)}function $G__46227__delegate$$($args__42927__auto__$jscomp$48_navigator__42928__auto__$jscomp$16$$){$args__42927__auto__$jscomp$48_navigator__42928__auto__$jscomp$16$$=
$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$48_navigator__42928__auto__$jscomp$16$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$22$$,$args__42927__auto__$jscomp$48_navigator__42928__auto__$jscomp$16$$)}$G__46227$$.$cljs$lang$maxFixedArity$=0;$G__46227$$.$cljs$lang$applyTo$=function($arglist__46230_args__42927__auto__$jscomp$50$$){$arglist__46230_args__42927__auto__$jscomp$50$$=$APP.$cljs$core$seq$$($arglist__46230_args__42927__auto__$jscomp$50$$);
return $G__46227__delegate$$($arglist__46230_args__42927__auto__$jscomp$50$$)};$G__46227$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46227__delegate$$;return $G__46227$$}()}()($alis$jscomp$4$$))};
$cljs$pprint$multi_defn$$=function($alis$jscomp$5$$){$APP.$cljs$core$seq$$($alis$jscomp$5$$)&&function(){var $cf__42926__auto__$jscomp$23$$=$cljs$pprint$cached_compile$$(" ~_~{~w~^ ~_~}");return function(){function $G__46232$$($var_args$jscomp$766$$){var $G__46234__i_args__42927__auto__$jscomp$52$$=null;if(arguments.length>0){$G__46234__i_args__42927__auto__$jscomp$52$$=0;for(var $G__46234__a$$=Array(arguments.length-0);$G__46234__i_args__42927__auto__$jscomp$52$$<$G__46234__a$$.length;)$G__46234__a$$[$G__46234__i_args__42927__auto__$jscomp$52$$]=
arguments[$G__46234__i_args__42927__auto__$jscomp$52$$+0],++$G__46234__i_args__42927__auto__$jscomp$52$$;$G__46234__i_args__42927__auto__$jscomp$52$$=new $APP.$cljs$core$IndexedSeq$$($G__46234__a$$,0,null)}return $G__46232__delegate$$.call(this,$G__46234__i_args__42927__auto__$jscomp$52$$)}function $G__46232__delegate$$($args__42927__auto__$jscomp$51_navigator__42928__auto__$jscomp$17$$){$args__42927__auto__$jscomp$51_navigator__42928__auto__$jscomp$17$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$51_navigator__42928__auto__$jscomp$17$$);
return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$23$$,$args__42927__auto__$jscomp$51_navigator__42928__auto__$jscomp$17$$)}$G__46232$$.$cljs$lang$maxFixedArity$=0;$G__46232$$.$cljs$lang$applyTo$=function($arglist__46235_args__42927__auto__$jscomp$53$$){$arglist__46235_args__42927__auto__$jscomp$53$$=$APP.$cljs$core$seq$$($arglist__46235_args__42927__auto__$jscomp$53$$);return $G__46232__delegate$$($arglist__46235_args__42927__auto__$jscomp$53$$)};$G__46232$$.$cljs$core$IFn$_invoke$arity$variadic$=
$G__46232__delegate$$;return $G__46232$$}()}()($alis$jscomp$5$$)};
$cljs$pprint$pprint_defn$$=function($alis$jscomp$6_first__45359$$){if($APP.$cljs$core$next$$($alis$jscomp$6_first__45359$$)){var $first__45359__$1_seq__45358$$=$APP.$cljs$core$seq$$($alis$jscomp$6_first__45359$$);$alis$jscomp$6_first__45359$$=$APP.$cljs$core$first$$($first__45359__$1_seq__45358$$);var $doc_str$jscomp$1_seq__45358__$1_seq__45358__$2$$=$APP.$cljs$core$next$$($first__45359__$1_seq__45358$$);$first__45359__$1_seq__45358$$=$APP.$cljs$core$first$$($doc_str$jscomp$1_seq__45358__$1_seq__45358__$2$$);
$doc_str$jscomp$1_seq__45358__$1_seq__45358__$2$$=$APP.$cljs$core$next$$($doc_str$jscomp$1_seq__45358__$1_seq__45358__$2$$);var $attr_map$jscomp$1_stuff__$1$jscomp$1_vec__45360$$=typeof $APP.$cljs$core$first$$($doc_str$jscomp$1_seq__45358__$1_seq__45358__$2$$)==="string"?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($doc_str$jscomp$1_seq__45358__$1_seq__45358__$2$$),$APP.$cljs$core$next$$($doc_str$jscomp$1_seq__45358__$1_seq__45358__$2$$)],
null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$doc_str$jscomp$1_seq__45358__$1_seq__45358__$2$$],null);$doc_str$jscomp$1_seq__45358__$1_seq__45358__$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_map$jscomp$1_stuff__$1$jscomp$1_vec__45360$$,0,null);$attr_map$jscomp$1_stuff__$1$jscomp$1_vec__45360$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_map$jscomp$1_stuff__$1$jscomp$1_vec__45360$$,1,null);var $stuff__$2_vec__45363$$=
$APP.$cljs$core$map_QMARK_$$($APP.$cljs$core$first$$($attr_map$jscomp$1_stuff__$1$jscomp$1_vec__45360$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($attr_map$jscomp$1_stuff__$1$jscomp$1_vec__45360$$),$APP.$cljs$core$next$$($attr_map$jscomp$1_stuff__$1$jscomp$1_vec__45360$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$attr_map$jscomp$1_stuff__$1$jscomp$1_vec__45360$$],
null);$attr_map$jscomp$1_stuff__$1$jscomp$1_vec__45360$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($stuff__$2_vec__45363$$,0,null);$stuff__$2_vec__45363$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($stuff__$2_vec__45363$$,1,null);if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"#");else{var $_STAR_current_level_STAR__orig_val__45366_46239$$=$cljs$pprint$_STAR_current_level_STAR_$$,$_STAR_current_length_STAR__orig_val__45367_46240$$=
$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$("(",")"),function(){var $cf__42926__auto__$jscomp$24$$=$cljs$pprint$cached_compile$$("~w ~1I~@_~w");return function(){function $G__46243$$($var_args$jscomp$767$$){var $G__46244__i_args__42927__auto__$jscomp$55$$=null;if(arguments.length>0){$G__46244__i_args__42927__auto__$jscomp$55$$=0;for(var $G__46244__a$$=Array(arguments.length-0);$G__46244__i_args__42927__auto__$jscomp$55$$<
$G__46244__a$$.length;)$G__46244__a$$[$G__46244__i_args__42927__auto__$jscomp$55$$]=arguments[$G__46244__i_args__42927__auto__$jscomp$55$$+0],++$G__46244__i_args__42927__auto__$jscomp$55$$;$G__46244__i_args__42927__auto__$jscomp$55$$=new $APP.$cljs$core$IndexedSeq$$($G__46244__a$$,0,null)}return $G__46243__delegate$$.call(this,$G__46244__i_args__42927__auto__$jscomp$55$$)}function $G__46243__delegate$$($args__42927__auto__$jscomp$54_navigator__42928__auto__$jscomp$18$$){$args__42927__auto__$jscomp$54_navigator__42928__auto__$jscomp$18$$=
$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$54_navigator__42928__auto__$jscomp$18$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$24$$,$args__42927__auto__$jscomp$54_navigator__42928__auto__$jscomp$18$$)}$G__46243$$.$cljs$lang$maxFixedArity$=0;$G__46243$$.$cljs$lang$applyTo$=function($arglist__46245_args__42927__auto__$jscomp$56$$){$arglist__46245_args__42927__auto__$jscomp$56$$=$APP.$cljs$core$seq$$($arglist__46245_args__42927__auto__$jscomp$56$$);
return $G__46243__delegate$$($arglist__46245_args__42927__auto__$jscomp$56$$)};$G__46243$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46243__delegate$$;return $G__46243$$}()}()($alis$jscomp$6_first__45359$$,$first__45359__$1_seq__45358$$),$APP.$cljs$core$truth_$$($doc_str$jscomp$1_seq__45358__$1_seq__45358__$2$$)&&function(){var $cf__42926__auto__$jscomp$25$$=$cljs$pprint$cached_compile$$(" ~_~w");return function(){function $G__46246$$($var_args$jscomp$768$$){var $G__46248__i_args__42927__auto__$jscomp$58$$=
null;if(arguments.length>0){$G__46248__i_args__42927__auto__$jscomp$58$$=0;for(var $G__46248__a$$=Array(arguments.length-0);$G__46248__i_args__42927__auto__$jscomp$58$$<$G__46248__a$$.length;)$G__46248__a$$[$G__46248__i_args__42927__auto__$jscomp$58$$]=arguments[$G__46248__i_args__42927__auto__$jscomp$58$$+0],++$G__46248__i_args__42927__auto__$jscomp$58$$;$G__46248__i_args__42927__auto__$jscomp$58$$=new $APP.$cljs$core$IndexedSeq$$($G__46248__a$$,0,null)}return $G__46246__delegate$$.call(this,$G__46248__i_args__42927__auto__$jscomp$58$$)}
function $G__46246__delegate$$($args__42927__auto__$jscomp$57_navigator__42928__auto__$jscomp$19$$){$args__42927__auto__$jscomp$57_navigator__42928__auto__$jscomp$19$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$57_navigator__42928__auto__$jscomp$19$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$25$$,$args__42927__auto__$jscomp$57_navigator__42928__auto__$jscomp$19$$)}$G__46246$$.$cljs$lang$maxFixedArity$=0;$G__46246$$.$cljs$lang$applyTo$=
function($arglist__46249_args__42927__auto__$jscomp$59$$){$arglist__46249_args__42927__auto__$jscomp$59$$=$APP.$cljs$core$seq$$($arglist__46249_args__42927__auto__$jscomp$59$$);return $G__46246__delegate$$($arglist__46249_args__42927__auto__$jscomp$59$$)};$G__46246$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46246__delegate$$;return $G__46246$$}()}()($doc_str$jscomp$1_seq__45358__$1_seq__45358__$2$$),$APP.$cljs$core$truth_$$($attr_map$jscomp$1_stuff__$1$jscomp$1_vec__45360$$)&&function(){var $cf__42926__auto__$jscomp$26$$=
$cljs$pprint$cached_compile$$(" ~_~w");return function(){function $G__46250$$($var_args$jscomp$769$$){var $G__46252__i_args__42927__auto__$jscomp$61$$=null;if(arguments.length>0){$G__46252__i_args__42927__auto__$jscomp$61$$=0;for(var $G__46252__a$$=Array(arguments.length-0);$G__46252__i_args__42927__auto__$jscomp$61$$<$G__46252__a$$.length;)$G__46252__a$$[$G__46252__i_args__42927__auto__$jscomp$61$$]=arguments[$G__46252__i_args__42927__auto__$jscomp$61$$+0],++$G__46252__i_args__42927__auto__$jscomp$61$$;
$G__46252__i_args__42927__auto__$jscomp$61$$=new $APP.$cljs$core$IndexedSeq$$($G__46252__a$$,0,null)}return $G__46250__delegate$$.call(this,$G__46252__i_args__42927__auto__$jscomp$61$$)}function $G__46250__delegate$$($args__42927__auto__$jscomp$60_navigator__42928__auto__$jscomp$20$$){$args__42927__auto__$jscomp$60_navigator__42928__auto__$jscomp$20$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$60_navigator__42928__auto__$jscomp$20$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$26$$,
$args__42927__auto__$jscomp$60_navigator__42928__auto__$jscomp$20$$)}$G__46250$$.$cljs$lang$maxFixedArity$=0;$G__46250$$.$cljs$lang$applyTo$=function($arglist__46253_args__42927__auto__$jscomp$62$$){$arglist__46253_args__42927__auto__$jscomp$62$$=$APP.$cljs$core$seq$$($arglist__46253_args__42927__auto__$jscomp$62$$);return $G__46250__delegate$$($arglist__46253_args__42927__auto__$jscomp$62$$)};$G__46250$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46250__delegate$$;return $G__46250$$}()}()($attr_map$jscomp$1_stuff__$1$jscomp$1_vec__45360$$),
$APP.$cljs$core$vector_QMARK_$$($APP.$cljs$core$first$$($stuff__$2_vec__45363$$))?$cljs$pprint$single_defn$$($stuff__$2_vec__45363$$,$APP.$cljs$core$truth_$$($doc_str$jscomp$1_seq__45358__$1_seq__45358__$2$$)?$doc_str$jscomp$1_seq__45358__$1_seq__45358__$2$$:$attr_map$jscomp$1_stuff__$1$jscomp$1_vec__45360$$):$cljs$pprint$multi_defn$$($stuff__$2_vec__45363$$),$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=$_STAR_current_length_STAR__orig_val__45367_46240$$,$cljs$pprint$_STAR_current_level_STAR_$$=
$_STAR_current_level_STAR__orig_val__45366_46239$$}}return null}return $cljs$pprint$pprint_simple_code_list$$($alis$jscomp$6_first__45359$$)};
$cljs$pprint$pprint_binding_form$$=function($binding_46259_binding_vec$$){if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"#");else{var $_STAR_current_level_STAR__orig_val__45370_46254$$=$cljs$pprint$_STAR_current_level_STAR_$$,$_STAR_current_length_STAR__orig_val__45371_46255$$=$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$("[",
"]");for(var $length_count45374_46258$$=0;;){if($APP.$cljs$core$not$$($cljs$core$_STAR_print_length_STAR_$$)||$length_count45374_46258$$<$cljs$core$_STAR_print_length_STAR_$$){if($APP.$cljs$core$seq$$($binding_46259_binding_vec$$)){if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"#");else{var $G__46264__STAR_current_level_STAR__orig_val__45375_46260$$=$cljs$pprint$_STAR_current_level_STAR_$$,$_STAR_current_length_STAR__orig_val__45376_46261$$=
$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$(null,null),$cljs$pprint$write_out$$($APP.$cljs$core$first$$($binding_46259_binding_vec$$)),$APP.$cljs$core$next$$($binding_46259_binding_vec$$)&&($APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$," "),$cljs$pprint$pprint_newline$$($cljs$cst$288$miser$$),$cljs$pprint$write_out$$($APP.$cljs$core$second$$($binding_46259_binding_vec$$))),
$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=$_STAR_current_length_STAR__orig_val__45376_46261$$,$cljs$pprint$_STAR_current_level_STAR_$$=$G__46264__STAR_current_level_STAR__orig_val__45375_46260$$}}if($APP.$cljs$core$next$$($APP.$cljs$core$rest$$($binding_46259_binding_vec$$))){$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$," ");$cljs$pprint$pprint_newline$$($APP.$cljs$cst$287$linear$$);$G__46264__STAR_current_level_STAR__orig_val__45375_46260$$=$length_count45374_46258$$+
1;var $G__46265$$=$APP.$cljs$core$next$$($APP.$cljs$core$rest$$($binding_46259_binding_vec$$));$length_count45374_46258$$=$G__46264__STAR_current_level_STAR__orig_val__45375_46260$$;$binding_46259_binding_vec$$=$G__46265$$;continue}}}else $APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"...");break}$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=$_STAR_current_length_STAR__orig_val__45371_46255$$,$cljs$pprint$_STAR_current_level_STAR_$$=$_STAR_current_level_STAR__orig_val__45370_46254$$}}};
$cljs$pprint$pprint_let$$=function($alis$jscomp$7$$){var $base_sym$$=$APP.$cljs$core$first$$($alis$jscomp$7$$);if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"#");else{var $_STAR_current_level_STAR__orig_val__45379_46266$$=$cljs$pprint$_STAR_current_level_STAR_$$,$_STAR_current_length_STAR__orig_val__45380_46267$$=$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=
0;try{$cljs$pprint$start_block$$("(",")"),$APP.$cljs$core$next$$($alis$jscomp$7$$)&&$APP.$cljs$core$vector_QMARK_$$($APP.$cljs$core$second$$($alis$jscomp$7$$))?(function(){var $cf__42926__auto__$jscomp$27$$=$cljs$pprint$cached_compile$$("~w ~1I~@_");return function(){function $G__46270$$($var_args$jscomp$770$$){var $G__46271__i_args__42927__auto__$jscomp$64$$=null;if(arguments.length>0){$G__46271__i_args__42927__auto__$jscomp$64$$=0;for(var $G__46271__a$$=Array(arguments.length-0);$G__46271__i_args__42927__auto__$jscomp$64$$<
$G__46271__a$$.length;)$G__46271__a$$[$G__46271__i_args__42927__auto__$jscomp$64$$]=arguments[$G__46271__i_args__42927__auto__$jscomp$64$$+0],++$G__46271__i_args__42927__auto__$jscomp$64$$;$G__46271__i_args__42927__auto__$jscomp$64$$=new $APP.$cljs$core$IndexedSeq$$($G__46271__a$$,0,null)}return $G__46270__delegate$$.call(this,$G__46271__i_args__42927__auto__$jscomp$64$$)}function $G__46270__delegate$$($args__42927__auto__$jscomp$63_navigator__42928__auto__$jscomp$21$$){$args__42927__auto__$jscomp$63_navigator__42928__auto__$jscomp$21$$=
$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$63_navigator__42928__auto__$jscomp$21$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$27$$,$args__42927__auto__$jscomp$63_navigator__42928__auto__$jscomp$21$$)}$G__46270$$.$cljs$lang$maxFixedArity$=0;$G__46270$$.$cljs$lang$applyTo$=function($arglist__46272_args__42927__auto__$jscomp$65$$){$arglist__46272_args__42927__auto__$jscomp$65$$=$APP.$cljs$core$seq$$($arglist__46272_args__42927__auto__$jscomp$65$$);
return $G__46270__delegate$$($arglist__46272_args__42927__auto__$jscomp$65$$)};$G__46270$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46270__delegate$$;return $G__46270$$}()}()($base_sym$$),$cljs$pprint$pprint_binding_form$$($APP.$cljs$core$second$$($alis$jscomp$7$$)),function(){var $cf__42926__auto__$jscomp$28$$=$cljs$pprint$cached_compile$$(" ~_~{~w~^ ~_~}");return function(){function $G__46273$$($var_args$jscomp$771$$){var $G__46274__i_args__42927__auto__$jscomp$67$$=null;if(arguments.length>0){$G__46274__i_args__42927__auto__$jscomp$67$$=
0;for(var $G__46274__a$$=Array(arguments.length-0);$G__46274__i_args__42927__auto__$jscomp$67$$<$G__46274__a$$.length;)$G__46274__a$$[$G__46274__i_args__42927__auto__$jscomp$67$$]=arguments[$G__46274__i_args__42927__auto__$jscomp$67$$+0],++$G__46274__i_args__42927__auto__$jscomp$67$$;$G__46274__i_args__42927__auto__$jscomp$67$$=new $APP.$cljs$core$IndexedSeq$$($G__46274__a$$,0,null)}return $G__46273__delegate$$.call(this,$G__46274__i_args__42927__auto__$jscomp$67$$)}function $G__46273__delegate$$($args__42927__auto__$jscomp$66_navigator__42928__auto__$jscomp$22$$){$args__42927__auto__$jscomp$66_navigator__42928__auto__$jscomp$22$$=
$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$66_navigator__42928__auto__$jscomp$22$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$28$$,$args__42927__auto__$jscomp$66_navigator__42928__auto__$jscomp$22$$)}$G__46273$$.$cljs$lang$maxFixedArity$=0;$G__46273$$.$cljs$lang$applyTo$=function($arglist__46275_args__42927__auto__$jscomp$68$$){$arglist__46275_args__42927__auto__$jscomp$68$$=$APP.$cljs$core$seq$$($arglist__46275_args__42927__auto__$jscomp$68$$);
return $G__46273__delegate$$($arglist__46275_args__42927__auto__$jscomp$68$$)};$G__46273$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46273__delegate$$;return $G__46273$$}()}()($APP.$cljs$core$next$$($APP.$cljs$core$rest$$($alis$jscomp$7$$)))):$cljs$pprint$pprint_simple_code_list$$($alis$jscomp$7$$),$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=$_STAR_current_length_STAR__orig_val__45380_46267$$,$cljs$pprint$_STAR_current_level_STAR_$$=$_STAR_current_level_STAR__orig_val__45379_46266$$}}return null};
$cljs$pprint$pprint_simple_code_list$$=function($G__46322_alis$jscomp$11$$){if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"#");else{var $_STAR_current_level_STAR__orig_val__45429_46314$$=$cljs$pprint$_STAR_current_level_STAR_$$,$_STAR_current_length_STAR__orig_val__45430_46315$$=$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$("(",
")");$cljs$pprint$pprint_indent$$($APP.$cljs$cst$1400$block$$,1);for(var $length_count45433_46319$$=0,$alis_46320__$1$$=$APP.$cljs$core$seq$$($G__46322_alis$jscomp$11$$);;){if($APP.$cljs$core$not$$($cljs$core$_STAR_print_length_STAR_$$)||$length_count45433_46319$$<$cljs$core$_STAR_print_length_STAR_$$){if($alis_46320__$1$$&&($cljs$pprint$write_out$$($APP.$cljs$core$first$$($alis_46320__$1$$)),$APP.$cljs$core$next$$($alis_46320__$1$$))){$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$," ");$cljs$pprint$pprint_newline$$($APP.$cljs$cst$287$linear$$);
$G__46322_alis$jscomp$11$$=$length_count45433_46319$$+1;var $G__46323$$=$APP.$cljs$core$next$$($alis_46320__$1$$);$length_count45433_46319$$=$G__46322_alis$jscomp$11$$;$alis_46320__$1$$=$G__46323$$;continue}}else $APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"...");break}$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=$_STAR_current_length_STAR__orig_val__45430_46315$$,$cljs$pprint$_STAR_current_level_STAR_$$=$_STAR_current_level_STAR__orig_val__45429_46314$$}}return null};
$app$common$geom$point$Point$$=function($x$jscomp$1037$$,$y$jscomp$303$$,$$meta$$,$$extmap$$,$$hash$$){this.x=$x$jscomp$1037$$;this.y=$y$jscomp$303$$;this.$$meta$=$$meta$$;this.$$extmap$=$$extmap$$;this.$$hash$=$$hash$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139280};$APP.$app$common$geom$point$pos__GT_Point$$=function($x$jscomp$1039$$,$y$jscomp$305$$){return new $app$common$geom$point$Point$$($x$jscomp$1039$$,$y$jscomp$305$$,null,null,null)};
$app$common$geom$point$map__GT_Point$$=function($param_45683$$){var $exclude__42719__auto__$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1510$x$$,null],null),null),$extmap__42720__auto__$$=$APP.$cljs$core$reduce_kv$$(function($acc__42721__auto__$$,$k__42722__auto__$$,$v__42723__auto__$$){return $APP.$cljs$core$contains_QMARK_$$($exclude__42719__auto__$$,$k__42722__auto__$$)?$acc__42721__auto__$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc__42721__auto__$$,
$k__42722__auto__$$,$v__42723__auto__$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$param_45683$$);return new $app$common$geom$point$Point$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45683$$,$APP.$cljs$cst$1510$x$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45683$$,$APP.$cljs$cst$1511$y$$),null,$APP.$cljs$core$not_empty$$($extmap__42720__auto__$$),null)};$app$common$geom$point$point_QMARK_$$=function($v$jscomp$467$$){return $v$jscomp$467$$ instanceof $app$common$geom$point$Point$$};
$app$common$geom$point$decode_point$$=function($p$jscomp$132_x$jscomp$1040$$){if($APP.$cljs$core$map_QMARK_$$($p$jscomp$132_x$jscomp$1040$$))return $app$common$geom$point$map__GT_Point$$($p$jscomp$132_x$jscomp$1040$$);if(typeof $p$jscomp$132_x$jscomp$1040$$==="string"){var $vec__45711_y$jscomp$306$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$parse_double$$,$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($p$jscomp$132_x$jscomp$1040$$,/,/));$p$jscomp$132_x$jscomp$1040$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__45711_y$jscomp$306$$,0,null);$vec__45711_y$jscomp$306$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__45711_y$jscomp$306$$,1,null);return $APP.$app$common$geom$point$pos__GT_Point$$($p$jscomp$132_x$jscomp$1040$$,$vec__45711_y$jscomp$306$$)}return $p$jscomp$132_x$jscomp$1040$$};
$app$common$geom$point$close_QMARK_$$=function($p1$jscomp$23$$,$p2$jscomp$16$$){var $and__5023__auto__$jscomp$204$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($p1$jscomp$23$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$23$$,$APP.$cljs$cst$1510$x$$),$p2$jscomp$16$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$16$$,$APP.$cljs$cst$1510$x$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$204$$)?$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($p1$jscomp$23$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$23$$,$APP.$cljs$cst$1511$y$$),$p2$jscomp$16$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$16$$,$APP.$cljs$cst$1511$y$$)):$and__5023__auto__$jscomp$204$$};
$APP.$app$common$geom$point$add$$=function($p1$jscomp$24$$,$p2$jscomp$17$$){return $APP.$app$common$geom$point$pos__GT_Point$$(($p1$jscomp$24$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$24$$,$APP.$cljs$cst$1510$x$$))+($p2$jscomp$17$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$17$$,$APP.$cljs$cst$1510$x$$)),($p1$jscomp$24$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$24$$,$APP.$cljs$cst$1511$y$$))+($p2$jscomp$17$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$17$$,
$APP.$cljs$cst$1511$y$$)))};
$APP.$app$common$geom$point$subtract$$=function($p1$jscomp$25$$,$p2$jscomp$18$$){return $APP.$app$common$geom$point$pos__GT_Point$$(($p1$jscomp$25$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$25$$,$APP.$cljs$cst$1510$x$$))-($p2$jscomp$18$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$18$$,$APP.$cljs$cst$1510$x$$)),($p1$jscomp$25$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$25$$,$APP.$cljs$cst$1511$y$$))-($p2$jscomp$18$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$18$$,$APP.$cljs$cst$1511$y$$)))};
$APP.$app$common$geom$point$multiply$$=function($p1$jscomp$26$$,$p2$jscomp$19$$){return $APP.$app$common$geom$point$pos__GT_Point$$(($p1$jscomp$26$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$26$$,$APP.$cljs$cst$1510$x$$))*($p2$jscomp$19$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$19$$,$APP.$cljs$cst$1510$x$$)),($p1$jscomp$26$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$26$$,$APP.$cljs$cst$1511$y$$))*($p2$jscomp$19$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$19$$,$APP.$cljs$cst$1511$y$$)))};
$APP.$app$common$geom$point$divide$$=function($p1$jscomp$27$$,$p2$jscomp$20$$){return $APP.$app$common$geom$point$pos__GT_Point$$(($p1$jscomp$27$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$27$$,$APP.$cljs$cst$1510$x$$))/($p2$jscomp$20$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$20$$,$APP.$cljs$cst$1510$x$$)),($p1$jscomp$27$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$27$$,$APP.$cljs$cst$1511$y$$))/($p2$jscomp$20$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$20$$,$APP.$cljs$cst$1511$y$$)))};$APP.$app$common$geom$point$negate$$=function($pt$jscomp$2$$){return $APP.$app$common$geom$point$pos__GT_Point$$(-($pt$jscomp$2$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$2$$,$APP.$cljs$cst$1510$x$$)),-($pt$jscomp$2$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$2$$,$APP.$cljs$cst$1511$y$$)))};
$APP.$app$common$geom$point$distance$$=function($dy$jscomp$7_p1$jscomp$32$$,$p2$jscomp$23$$){var $dx$jscomp$7$$=($dy$jscomp$7_p1$jscomp$32$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dy$jscomp$7_p1$jscomp$32$$,$APP.$cljs$cst$1510$x$$))-($p2$jscomp$23$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$23$$,$APP.$cljs$cst$1510$x$$));$dy$jscomp$7_p1$jscomp$32$$=($dy$jscomp$7_p1$jscomp$32$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dy$jscomp$7_p1$jscomp$32$$,
$APP.$cljs$cst$1511$y$$))-($p2$jscomp$23$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$23$$,$APP.$cljs$cst$1511$y$$));return $APP.$app$common$math$hypot$$($dx$jscomp$7$$,$dy$jscomp$7_p1$jscomp$32$$)};
$APP.$app$common$geom$point$length$$=function($pt$jscomp$3_y$jscomp$309$$){var $x$jscomp$1043$$=$pt$jscomp$3_y$jscomp$309$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$3_y$jscomp$309$$,$APP.$cljs$cst$1510$x$$);$pt$jscomp$3_y$jscomp$309$$=$pt$jscomp$3_y$jscomp$309$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$3_y$jscomp$309$$,$APP.$cljs$cst$1511$y$$);return $APP.$app$common$math$hypot$$($x$jscomp$1043$$,$pt$jscomp$3_y$jscomp$309$$)};
$APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$01$$=function($pt$jscomp$4_y$jscomp$310$$){var $x$jscomp$1044$$=$pt$jscomp$4_y$jscomp$310$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$4_y$jscomp$310$$,$APP.$cljs$cst$1510$x$$);$pt$jscomp$4_y$jscomp$310$$=$pt$jscomp$4_y$jscomp$310$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$4_y$jscomp$310$$,$APP.$cljs$cst$1511$y$$);return Math.atan2($pt$jscomp$4_y$jscomp$310$$,$x$jscomp$1044$$)*180/
Math.PI};
$APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$02$$=function($pt$jscomp$5_y$jscomp$311$$,$center$jscomp$1$$){var $x$jscomp$1045$$=($pt$jscomp$5_y$jscomp$311$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$5_y$jscomp$311$$,$APP.$cljs$cst$1510$x$$))-($center$jscomp$1$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$1$$,$APP.$cljs$cst$1510$x$$));$pt$jscomp$5_y$jscomp$311$$=($pt$jscomp$5_y$jscomp$311$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$5_y$jscomp$311$$,$APP.$cljs$cst$1511$y$$))-
($center$jscomp$1$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$1$$,$APP.$cljs$cst$1511$y$$));return Math.atan2($pt$jscomp$5_y$jscomp$311$$,$x$jscomp$1045$$)*180/Math.PI};
$APP.$app$common$geom$point$angle_with_other$$=function($a$jscomp$317_d$jscomp$197_p1$jscomp$34$$,$p2$jscomp$25$$){var $length_p1$$=$APP.$app$common$geom$point$length$$($a$jscomp$317_d$jscomp$197_p1$jscomp$34$$),$length_p2$$=$APP.$app$common$geom$point$length$$($p2$jscomp$25$$);if($APP.$app$common$math$almost_zero_QMARK_$$($length_p1$$)||$APP.$app$common$math$almost_zero_QMARK_$$($length_p2$$))return 0;$a$jscomp$317_d$jscomp$197_p1$jscomp$34$$=(($a$jscomp$317_d$jscomp$197_p1$jscomp$34$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$317_d$jscomp$197_p1$jscomp$34$$,
$APP.$cljs$cst$1510$x$$))*($p2$jscomp$25$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$25$$,$APP.$cljs$cst$1510$x$$))+($a$jscomp$317_d$jscomp$197_p1$jscomp$34$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$317_d$jscomp$197_p1$jscomp$34$$,$APP.$cljs$cst$1511$y$$))*($p2$jscomp$25$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$25$$,$APP.$cljs$cst$1511$y$$)))/($length_p1$$*$length_p2$$);$a$jscomp$317_d$jscomp$197_p1$jscomp$34$$=Math.acos($a$jscomp$317_d$jscomp$197_p1$jscomp$34$$<
-1?-1:$a$jscomp$317_d$jscomp$197_p1$jscomp$34$$>1?1:$a$jscomp$317_d$jscomp$197_p1$jscomp$34$$)*180/Math.PI;return $APP.$cljs$core$truth_$$(isNaN($a$jscomp$317_d$jscomp$197_p1$jscomp$34$$))?0:$a$jscomp$317_d$jscomp$197_p1$jscomp$34$$};
$APP.$app$common$geom$point$angle_sign$$=function($p1$jscomp$35$$,$p2$jscomp$26$$){return($p1$jscomp$35$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$35$$,$APP.$cljs$cst$1511$y$$))*($p2$jscomp$26$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$26$$,$APP.$cljs$cst$1510$x$$))>($p1$jscomp$35$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$35$$,$APP.$cljs$cst$1510$x$$))*($p2$jscomp$26$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$26$$,
$APP.$cljs$cst$1511$y$$))?-1:1};$app$common$geom$point$signed_angle_with_other$$=function($v1$jscomp$22$$){var $v2$jscomp$15$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,0);return $APP.$app$common$geom$point$angle_sign$$($v1$jscomp$22$$,$v2$jscomp$15$$)*$APP.$app$common$geom$point$angle_with_other$$($v1$jscomp$22$$,$v2$jscomp$15$$)};
$app$common$geom$point$round_step$$=function($pt$jscomp$7$$,$step$jscomp$28$$){return $APP.$app$common$geom$point$pos__GT_Point$$($APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$7$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$7$$,$APP.$cljs$cst$1510$x$$),$step$jscomp$28$$),$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$7$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$7$$,$APP.$cljs$cst$1511$y$$),$step$jscomp$28$$))};
$APP.$app$common$geom$point$transform$$=function($p$jscomp$137_y$jscomp$313$$,$f$jscomp$662_m$jscomp$181$$){if($app$common$geom$point$point_QMARK_$$($p$jscomp$137_y$jscomp$313$$)){if($f$jscomp$662_m$jscomp$181$$!=null){var $x$jscomp$1047$$=$p$jscomp$137_y$jscomp$313$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$137_y$jscomp$313$$,$APP.$cljs$cst$1510$x$$);$p$jscomp$137_y$jscomp$313$$=$p$jscomp$137_y$jscomp$313$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$137_y$jscomp$313$$,
$APP.$cljs$cst$1511$y$$);var $a$jscomp$318$$=$f$jscomp$662_m$jscomp$181$$?.a??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$662_m$jscomp$181$$,$APP.$cljs$cst$1519$a$$),$b$jscomp$244$$=$f$jscomp$662_m$jscomp$181$$?.b??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$662_m$jscomp$181$$,$APP.$cljs$cst$1520$b$$),$c$jscomp$244$$=$f$jscomp$662_m$jscomp$181$$?.c??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$662_m$jscomp$181$$,$cljs$cst$1521$c$$),$d$jscomp$198$$=
$f$jscomp$662_m$jscomp$181$$?.d??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$662_m$jscomp$181$$,$cljs$cst$1447$d$$),$e$jscomp$215$$=$f$jscomp$662_m$jscomp$181$$?.e??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$662_m$jscomp$181$$,$cljs$cst$1449$e$$);$f$jscomp$662_m$jscomp$181$$=$f$jscomp$662_m$jscomp$181$$?.f??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$662_m$jscomp$181$$,$cljs$cst$598$f$$);return $APP.$app$common$geom$point$pos__GT_Point$$($x$jscomp$1047$$*
$a$jscomp$318$$+$p$jscomp$137_y$jscomp$313$$*$c$jscomp$244$$+$e$jscomp$215$$,$x$jscomp$1047$$*$b$jscomp$244$$+$p$jscomp$137_y$jscomp$313$$*$d$jscomp$198$$+$f$jscomp$662_m$jscomp$181$$)}return $p$jscomp$137_y$jscomp$313$$}return null};
$app$common$geom$point$transform_BANG_$$=function($p$jscomp$138$$,$f$jscomp$663_m$jscomp$182$$){var $x$jscomp$1048$$=$p$jscomp$138$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$138$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$314$$=$p$jscomp$138$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$138$$,$APP.$cljs$cst$1511$y$$),$a$jscomp$319$$=$f$jscomp$663_m$jscomp$182$$?.a??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$663_m$jscomp$182$$,$APP.$cljs$cst$1519$a$$),
$b$jscomp$245$$=$f$jscomp$663_m$jscomp$182$$?.b??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$663_m$jscomp$182$$,$APP.$cljs$cst$1520$b$$),$c$jscomp$245$$=$f$jscomp$663_m$jscomp$182$$?.c??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$663_m$jscomp$182$$,$cljs$cst$1521$c$$),$d$jscomp$199$$=$f$jscomp$663_m$jscomp$182$$?.d??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$663_m$jscomp$182$$,$cljs$cst$1447$d$$),$e$jscomp$216$$=$f$jscomp$663_m$jscomp$182$$?.e??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$663_m$jscomp$182$$,$cljs$cst$1449$e$$);$f$jscomp$663_m$jscomp$182$$=$f$jscomp$663_m$jscomp$182$$?.f??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$663_m$jscomp$182$$,$cljs$cst$598$f$$);$p$jscomp$138$$.x=$x$jscomp$1048$$*$a$jscomp$319$$+$y$jscomp$314$$*$c$jscomp$245$$+$e$jscomp$216$$;$p$jscomp$138$$.y=$x$jscomp$1048$$*$b$jscomp$245$$+$y$jscomp$314$$*$d$jscomp$199$$+$f$jscomp$663_m$jscomp$182$$;return $p$jscomp$138$$};
$APP.$app$common$geom$point$to_vec$$=function($p1$jscomp$36$$,$p2$jscomp$27$$){return $APP.$app$common$geom$point$subtract$$($p2$jscomp$27$$,$p1$jscomp$36$$)};
$APP.$app$common$geom$point$scale$$=function($p$jscomp$139$$,$scalar$$){return $APP.$app$common$geom$point$pos__GT_Point$$(($p$jscomp$139$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$139$$,$APP.$cljs$cst$1510$x$$))*$scalar$$,($p$jscomp$139$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$139$$,$APP.$cljs$cst$1511$y$$))*$scalar$$)};
$APP.$app$common$geom$point$dot$$=function($p1$jscomp$37$$,$p2$jscomp$28$$){return($p1$jscomp$37$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$37$$,$APP.$cljs$cst$1510$x$$))*($p2$jscomp$28$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$28$$,$APP.$cljs$cst$1510$x$$))+($p1$jscomp$37$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$37$$,$APP.$cljs$cst$1511$y$$))*($p2$jscomp$28$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$28$$,
$APP.$cljs$cst$1511$y$$))};
$APP.$app$common$geom$point$unit$$=function($p1$jscomp$38$$){var $p_length$$=$APP.$app$common$geom$point$length$$($p1$jscomp$38$$);return $APP.$app$common$math$almost_zero_QMARK_$$($p_length$$)?$APP.$app$common$geom$point$pos__GT_Point$$(0,0):$APP.$app$common$geom$point$pos__GT_Point$$(($p1$jscomp$38$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$38$$,$APP.$cljs$cst$1510$x$$))/$p_length$$,($p1$jscomp$38$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$38$$,$APP.$cljs$cst$1511$y$$))/
$p_length$$)};$app$common$geom$point$perpendicular$$=function($pt$jscomp$8$$){return $APP.$app$common$geom$point$pos__GT_Point$$(-($pt$jscomp$8$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$8$$,$APP.$cljs$cst$1511$y$$)),$pt$jscomp$8$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$8$$,$APP.$cljs$cst$1510$x$$))};
$app$common$geom$point$project$$=function($scalar_proj_v1$jscomp$23$$,$v2$jscomp$16_v2_unit$$){$v2$jscomp$16_v2_unit$$=$APP.$app$common$geom$point$unit$$($v2$jscomp$16_v2_unit$$);$scalar_proj_v1$jscomp$23$$=$APP.$app$common$geom$point$dot$$($scalar_proj_v1$jscomp$23$$,$v2$jscomp$16_v2_unit$$);return $APP.$app$common$geom$point$scale$$($v2$jscomp$16_v2_unit$$,$scalar_proj_v1$jscomp$23$$)};
$app$common$geom$point$center_points$$=function($points$$){var $k$jscomp$568$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$count$$($points$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__45827_SHARP_$$,$p2__45828_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__45827_SHARP_$$,$APP.$app$common$geom$point$divide$$($p2__45828_SHARP_$$,$k$jscomp$568$$))},$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$0$(),
$points$$)};
$APP.$app$common$geom$point$normal_left$$=function($p__45830_x$jscomp$1049$$){var $map__45831__$1_y$jscomp$315$$=$APP.$cljs$core$__destructure_map$$($p__45830_x$jscomp$1049$$);$p__45830_x$jscomp$1049$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45831__$1_y$jscomp$315$$,$APP.$cljs$cst$1510$x$$);$map__45831__$1_y$jscomp$315$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45831__$1_y$jscomp$315$$,$APP.$cljs$cst$1511$y$$);return $APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-$map__45831__$1_y$jscomp$315$$,$p__45830_x$jscomp$1049$$))};
$app$common$geom$point$lerp$$=function($p1$jscomp$39_v0$jscomp$inline_4522$$,$p2$jscomp$29_v1$jscomp$inline_4523$$,$t$jscomp$59$$){var $v0$jscomp$inline_4518_x$jscomp$1052$$=$p1$jscomp$39_v0$jscomp$inline_4522$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$39_v0$jscomp$inline_4522$$,$APP.$cljs$cst$1510$x$$);var $v1$jscomp$inline_4519$$=$p2$jscomp$29_v1$jscomp$inline_4523$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$29_v1$jscomp$inline_4523$$,$APP.$cljs$cst$1510$x$$);
$v0$jscomp$inline_4518_x$jscomp$1052$$=(1-$t$jscomp$59$$)*$v0$jscomp$inline_4518_x$jscomp$1052$$+$t$jscomp$59$$*$v1$jscomp$inline_4519$$;$p1$jscomp$39_v0$jscomp$inline_4522$$=$p1$jscomp$39_v0$jscomp$inline_4522$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$39_v0$jscomp$inline_4522$$,$APP.$cljs$cst$1511$y$$);$p2$jscomp$29_v1$jscomp$inline_4523$$=$p2$jscomp$29_v1$jscomp$inline_4523$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$29_v1$jscomp$inline_4523$$,
$APP.$cljs$cst$1511$y$$);return $APP.$app$common$geom$point$pos__GT_Point$$($v0$jscomp$inline_4518_x$jscomp$1052$$,(1-$t$jscomp$59$$)*$p1$jscomp$39_v0$jscomp$inline_4522$$+$t$jscomp$59$$*$p2$jscomp$29_v1$jscomp$inline_4523$$)};
$APP.$app$common$geom$point$rotate$$=function($p$jscomp$142_py$$,$c$jscomp$246_cy$jscomp$1$$,$angle$jscomp$13_px$jscomp$1$$){var $angle__$1$jscomp$1_ca$jscomp$2$$=$APP.$goog$math$toRadians$$($angle$jscomp$13_px$jscomp$1$$);$angle$jscomp$13_px$jscomp$1$$=$p$jscomp$142_py$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$142_py$$,$APP.$cljs$cst$1510$x$$);$p$jscomp$142_py$$=$p$jscomp$142_py$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$142_py$$,$APP.$cljs$cst$1511$y$$);
var $cx$jscomp$1$$=$c$jscomp$246_cy$jscomp$1$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$246_cy$jscomp$1$$,$APP.$cljs$cst$1510$x$$);$c$jscomp$246_cy$jscomp$1$$=$c$jscomp$246_cy$jscomp$1$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$246_cy$jscomp$1$$,$APP.$cljs$cst$1511$y$$);var $sa$$=Math.sin($angle__$1$jscomp$1_ca$jscomp$2$$);$angle__$1$jscomp$1_ca$jscomp$2$$=Math.cos($angle__$1$jscomp$1_ca$jscomp$2$$);return $APP.$app$common$geom$point$pos__GT_Point$$($angle__$1$jscomp$1_ca$jscomp$2$$*
($angle$jscomp$13_px$jscomp$1$$-$cx$jscomp$1$$)+$sa$$*($p$jscomp$142_py$$-$c$jscomp$246_cy$jscomp$1$$)*-1+$cx$jscomp$1$$,$sa$$*($angle$jscomp$13_px$jscomp$1$$-$cx$jscomp$1$$)+$angle__$1$jscomp$1_ca$jscomp$2$$*($p$jscomp$142_py$$-$c$jscomp$246_cy$jscomp$1$$)+$c$jscomp$246_cy$jscomp$1$$)};
$app$common$geom$rect$Rect$$=function($x$jscomp$1055$$,$y$jscomp$321$$,$width$jscomp$36$$,$height$jscomp$27$$,$x1$jscomp$8$$,$y1$jscomp$8$$,$x2$jscomp$6$$,$y2$jscomp$6$$,$$meta$jscomp$2$$,$$extmap$jscomp$2$$,$$hash$jscomp$2$$){this.x=$x$jscomp$1055$$;this.y=$y$jscomp$321$$;this.width=$width$jscomp$36$$;this.height=$height$jscomp$27$$;this.x1=$x1$jscomp$8$$;this.y1=$y1$jscomp$8$$;this.x2=$x2$jscomp$6$$;this.y2=$y2$jscomp$6$$;this.$$meta$=$$meta$jscomp$2$$;this.$$extmap$=$$extmap$jscomp$2$$;this.$$hash$=
$$hash$jscomp$2$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139280};
$app$common$geom$rect$map__GT_Rect$$=function($param_45904$$){var $exclude__42719__auto__$jscomp$1$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1524$y1$$,null,$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1523$x1$$,null,$APP.$cljs$cst$1526$y2$$,null,$APP.$cljs$cst$1525$x2$$,null,$APP.$cljs$cst$1522$height$$,null],null),null),$extmap__42720__auto__$jscomp$1$$=$APP.$cljs$core$reduce_kv$$(function($acc__42721__auto__$jscomp$1$$,
$k__42722__auto__$jscomp$1$$,$v__42723__auto__$jscomp$1$$){return $APP.$cljs$core$contains_QMARK_$$($exclude__42719__auto__$jscomp$1$$,$k__42722__auto__$jscomp$1$$)?$acc__42721__auto__$jscomp$1$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc__42721__auto__$jscomp$1$$,$k__42722__auto__$jscomp$1$$,$v__42723__auto__$jscomp$1$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$param_45904$$);return new $app$common$geom$rect$Rect$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45904$$,
$APP.$cljs$cst$1510$x$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45904$$,$APP.$cljs$cst$1511$y$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45904$$,$APP.$cljs$cst$290$width$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45904$$,$APP.$cljs$cst$1522$height$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45904$$,$APP.$cljs$cst$1523$x1$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45904$$,$APP.$cljs$cst$1524$y1$$),
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45904$$,$APP.$cljs$cst$1525$x2$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45904$$,$APP.$cljs$cst$1526$y2$$),null,$APP.$cljs$core$not_empty$$($extmap__42720__auto__$jscomp$1$$),null)};$app$common$geom$rect$rect_QMARK_$$=function($o$jscomp$213$$){return $o$jscomp$213$$ instanceof $app$common$geom$rect$Rect$$};
$APP.$app$common$geom$rect$update_rect$$=function($rect$jscomp$1$$,$G__46040__$1_type$jscomp$254_x$jscomp$1060_x1$jscomp$12$$){$G__46040__$1_type$jscomp$254_x$jscomp$1060_x1$jscomp$12$$=$G__46040__$1_type$jscomp$254_x$jscomp$1060_x1$jscomp$12$$ instanceof $APP.$cljs$core$Keyword$$?$G__46040__$1_type$jscomp$254_x$jscomp$1060_x1$jscomp$12$$.$fqn$:null;switch($G__46040__$1_type$jscomp$254_x$jscomp$1060_x1$jscomp$12$$){case "size":case "position":$G__46040__$1_type$jscomp$254_x$jscomp$1060_x1$jscomp$12$$=
$rect$jscomp$1$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$326_y1$jscomp$12$$=$rect$jscomp$1$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$1$$,$APP.$cljs$cst$1511$y$$),$w$jscomp$21_x2$jscomp$10$$=$rect$jscomp$1$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$1$$,$APP.$cljs$cst$290$width$$),$h$jscomp$132_y2$jscomp$10$$=$rect$jscomp$1$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$1$$,
$APP.$cljs$cst$1522$height$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($rect$jscomp$1$$,$APP.$cljs$cst$1523$x1$$,$G__46040__$1_type$jscomp$254_x$jscomp$1060_x1$jscomp$12$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1524$y1$$,$y$jscomp$326_y1$jscomp$12$$,$APP.$cljs$cst$1525$x2$$,$G__46040__$1_type$jscomp$254_x$jscomp$1060_x1$jscomp$12$$+$w$jscomp$21_x2$jscomp$10$$,$APP.$cljs$cst$1526$y2$$,$y$jscomp$326_y1$jscomp$12$$+$h$jscomp$132_y2$jscomp$10$$]));
case "corners":return $G__46040__$1_type$jscomp$254_x$jscomp$1060_x1$jscomp$12$$=$rect$jscomp$1$$?.x1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$1$$,$APP.$cljs$cst$1523$x1$$),$y$jscomp$326_y1$jscomp$12$$=$rect$jscomp$1$$?.y1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$1$$,$APP.$cljs$cst$1524$y1$$),$w$jscomp$21_x2$jscomp$10$$=$rect$jscomp$1$$?.x2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$1$$,$APP.$cljs$cst$1525$x2$$),$h$jscomp$132_y2$jscomp$10$$=
$rect$jscomp$1$$?.y2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$1$$,$APP.$cljs$cst$1526$y2$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($rect$jscomp$1$$,$APP.$cljs$cst$1510$x$$,Math.min($G__46040__$1_type$jscomp$254_x$jscomp$1060_x1$jscomp$12$$,$w$jscomp$21_x2$jscomp$10$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1511$y$$,Math.min($y$jscomp$326_y1$jscomp$12$$,$h$jscomp$132_y2$jscomp$10$$),$APP.$cljs$cst$290$width$$,
$APP.$app$common$math$abs$$($w$jscomp$21_x2$jscomp$10$$-$G__46040__$1_type$jscomp$254_x$jscomp$1060_x1$jscomp$12$$),$APP.$cljs$cst$1522$height$$,$APP.$app$common$math$abs$$($h$jscomp$132_y2$jscomp$10$$-$y$jscomp$326_y1$jscomp$12$$)]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__46040__$1_type$jscomp$254_x$jscomp$1060_x1$jscomp$12$$)].join(""));}};
$app$common$geom$rect$close_rect_QMARK_$$=function($rect1$$,$rect2$$){return $APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($rect1$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect1$$,$APP.$cljs$cst$1510$x$$),$rect2$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect2$$,$APP.$cljs$cst$1510$x$$))&&$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($rect1$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect1$$,
$APP.$cljs$cst$1511$y$$),$rect2$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect2$$,$APP.$cljs$cst$1511$y$$))&&$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($rect1$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect1$$,$APP.$cljs$cst$290$width$$),$rect2$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect2$$,$APP.$cljs$cst$290$width$$))&&$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($rect1$$?.height??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect1$$,$APP.$cljs$cst$1522$height$$),$rect2$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect2$$,$APP.$cljs$cst$1522$height$$))};
$APP.$app$common$geom$rect$rect__GT_points$$=function($h$jscomp$134_h__$1_rect$jscomp$3$$){var $x$jscomp$1062$$=$h$jscomp$134_h__$1_rect$jscomp$3$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$134_h__$1_rect$jscomp$3$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$328$$=$h$jscomp$134_h__$1_rect$jscomp$3$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$134_h__$1_rect$jscomp$3$$,$APP.$cljs$cst$1511$y$$),$w$jscomp$23_w__$1$jscomp$1$$=$h$jscomp$134_h__$1_rect$jscomp$3$$?.width??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$134_h__$1_rect$jscomp$3$$,$APP.$cljs$cst$290$width$$);$h$jscomp$134_h__$1_rect$jscomp$3$$=$h$jscomp$134_h__$1_rect$jscomp$3$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$134_h__$1_rect$jscomp$3$$,$APP.$cljs$cst$1522$height$$);return $APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($x$jscomp$1062$$,$y$jscomp$328$$)?($w$jscomp$23_w__$1$jscomp$1$$=Math.max($w$jscomp$23_w__$1$jscomp$1$$,.01),
$h$jscomp$134_h__$1_rect$jscomp$3$$=Math.max($h$jscomp$134_h__$1_rect$jscomp$3$$,.01),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1062$$,$y$jscomp$328$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1062$$+$w$jscomp$23_w__$1$jscomp$1$$,$y$jscomp$328$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1062$$+$w$jscomp$23_w__$1$jscomp$1$$,
$y$jscomp$328$$+$h$jscomp$134_h__$1_rect$jscomp$3$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1062$$,$y$jscomp$328$$+$h$jscomp$134_h__$1_rect$jscomp$3$$)],null)):null};
$APP.$app$common$geom$rect$rect__GT_center$$=function($h$jscomp$135_rect$jscomp$5$$){var $x$jscomp$1063$$=$h$jscomp$135_rect$jscomp$5$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$135_rect$jscomp$5$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$329$$=$h$jscomp$135_rect$jscomp$5$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$135_rect$jscomp$5$$,$APP.$cljs$cst$1511$y$$),$w$jscomp$24$$=$h$jscomp$135_rect$jscomp$5$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$135_rect$jscomp$5$$,
$APP.$cljs$cst$290$width$$);$h$jscomp$135_rect$jscomp$5$$=$h$jscomp$135_rect$jscomp$5$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$135_rect$jscomp$5$$,$APP.$cljs$cst$1522$height$$);return $app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$04$$($x$jscomp$1063$$,$y$jscomp$329$$,$w$jscomp$24$$,$h$jscomp$135_rect$jscomp$5$$)?$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1063$$+$w$jscomp$24$$/2,$y$jscomp$329$$+$h$jscomp$135_rect$jscomp$5$$/
2):null};
$APP.$app$common$geom$rect$points__GT_rect$$=function($G__46405_minx_points$jscomp$1$$){var $G__46409_pts_temp__5825__auto__$jscomp$101$$=$APP.$cljs$core$seq$$($G__46405_minx_points$jscomp$1$$);if($G__46409_pts_temp__5825__auto__$jscomp$101$$)for(var $G__46406_miny$$=$G__46405_minx_points$jscomp$1$$=Infinity,$G__46407_maxx$$=-Infinity,$G__46408_maxy$$=-Infinity;;){var $temp__5823__auto__$jscomp$97_x$jscomp$1065$$=$APP.$cljs$core$first$$($G__46409_pts_temp__5825__auto__$jscomp$101$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$97_x$jscomp$1065$$)){var $pt$jscomp$9_y$jscomp$331$$=$temp__5823__auto__$jscomp$97_x$jscomp$1065$$;
$temp__5823__auto__$jscomp$97_x$jscomp$1065$$=$pt$jscomp$9_y$jscomp$331$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$9_y$jscomp$331$$,$APP.$cljs$cst$1510$x$$);$pt$jscomp$9_y$jscomp$331$$=$pt$jscomp$9_y$jscomp$331$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$9_y$jscomp$331$$,$APP.$cljs$cst$1511$y$$);$G__46405_minx_points$jscomp$1$$=Math.min($G__46405_minx_points$jscomp$1$$,$temp__5823__auto__$jscomp$97_x$jscomp$1065$$);$G__46406_miny$$=Math.min($G__46406_miny$$,
$pt$jscomp$9_y$jscomp$331$$);$G__46407_maxx$$=Math.max($G__46407_maxx$$,$temp__5823__auto__$jscomp$97_x$jscomp$1065$$);$G__46408_maxy$$=Math.max($G__46408_maxy$$,$pt$jscomp$9_y$jscomp$331$$);$G__46409_pts_temp__5825__auto__$jscomp$101$$=$APP.$cljs$core$rest$$($G__46409_pts_temp__5825__auto__$jscomp$101$$)}else return $app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$04$$($G__46405_minx_points$jscomp$1$$,$G__46406_miny$$,$G__46407_maxx$$,$G__46408_maxy$$)?$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($G__46405_minx_points$jscomp$1$$,
$G__46406_miny$$,$G__46407_maxx$$-$G__46405_minx_points$jscomp$1$$,$G__46408_maxy$$-$G__46406_miny$$):null}else return null};
$APP.$app$common$geom$rect$join_rects$$=function($maxy$jscomp$3_rects$$){if($APP.$cljs$core$seq$$($maxy$jscomp$3_rects$$)){var $minx$jscomp$3$$=$cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$04$$($app$common$geom$rect$xf_keep_x$$,$APP.$app$common$data$min$$,Infinity,$maxy$jscomp$3_rects$$),$miny$jscomp$3$$=$cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$04$$($app$common$geom$rect$xf_keep_y$$,$APP.$app$common$data$min$$,Infinity,$maxy$jscomp$3_rects$$),$maxx$jscomp$3$$=$cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$04$$($app$common$geom$rect$xf_keep_x2$$,
$APP.$app$common$data$max$$,-Infinity,$maxy$jscomp$3_rects$$);$maxy$jscomp$3_rects$$=$cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$04$$($app$common$geom$rect$xf_keep_y2$$,$APP.$app$common$data$max$$,-Infinity,$maxy$jscomp$3_rects$$);return $app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$04$$($minx$jscomp$3$$,$miny$jscomp$3$$,$maxx$jscomp$3$$,$maxy$jscomp$3_rects$$)?$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($minx$jscomp$3$$,$miny$jscomp$3$$,$maxx$jscomp$3$$-
$minx$jscomp$3$$,$maxy$jscomp$3_rects$$-$miny$jscomp$3$$):null}return null};
$APP.$app$common$geom$rect$center__GT_rect$cljs$0core$0IFn$0_invoke$0arity$03$$=function($point$jscomp$6_y$jscomp$332$$,$w$jscomp$26$$,$h$jscomp$137$$){if($point$jscomp$6_y$jscomp$332$$!=null){var $x$jscomp$1066$$=$point$jscomp$6_y$jscomp$332$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$6_y$jscomp$332$$,$APP.$cljs$cst$1510$x$$);$point$jscomp$6_y$jscomp$332$$=$point$jscomp$6_y$jscomp$332$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$6_y$jscomp$332$$,
$APP.$cljs$cst$1511$y$$);return $app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$04$$($x$jscomp$1066$$,$point$jscomp$6_y$jscomp$332$$,$w$jscomp$26$$,$h$jscomp$137$$)?$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($x$jscomp$1066$$-$w$jscomp$26$$/2,$point$jscomp$6_y$jscomp$332$$-$h$jscomp$137$$/2,$w$jscomp$26$$,$h$jscomp$137$$):null}return null};
$APP.$app$common$geom$rect$overlaps_rects_QMARK_$$=function($rect_a_y2a$$,$rect_b_y2b$$){var $x1a$$=$rect_a_y2a$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect_a_y2a$$,$APP.$cljs$cst$1510$x$$),$y1a$$=$rect_a_y2a$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect_a_y2a$$,$APP.$cljs$cst$1511$y$$),$x2a$$=$x1a$$+($rect_a_y2a$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect_a_y2a$$,$APP.$cljs$cst$290$width$$));$rect_a_y2a$$=$y1a$$+($rect_a_y2a$$?.height??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect_a_y2a$$,$APP.$cljs$cst$1522$height$$));var $x1b$$=$rect_b_y2b$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect_b_y2b$$,$APP.$cljs$cst$1510$x$$),$y1b$$=$rect_b_y2b$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect_b_y2b$$,$APP.$cljs$cst$1511$y$$),$x2b$$=$x1b$$+($rect_b_y2b$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect_b_y2b$$,$APP.$cljs$cst$290$width$$));$rect_b_y2b$$=$y1b$$+($rect_b_y2b$$?.height??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect_b_y2b$$,$APP.$cljs$cst$1522$height$$));return($x2a$$>$x1b$$||$APP.$app$common$math$almost_zero_QMARK_$$($x2a$$-$x1b$$))&&($x2b$$>=$x1a$$||$APP.$app$common$math$almost_zero_QMARK_$$($x2b$$-$x1a$$))&&($y1b$$<=$rect_a_y2a$$||$APP.$app$common$math$almost_zero_QMARK_$$($y1b$$-$rect_a_y2a$$))&&($y1a$$<=$rect_b_y2b$$||$APP.$app$common$math$almost_zero_QMARK_$$($y1a$$-$rect_b_y2b$$))};
$app$common$geom$rect$contains_point_QMARK_$$=function($rect$jscomp$7_y2$jscomp$12$$,$point$jscomp$7_py$jscomp$1$$){var $x1$jscomp$14$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$7_y2$jscomp$12$$),$y1$jscomp$14$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$7_y2$jscomp$12$$),$x2$jscomp$12$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$7_y2$jscomp$12$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$7_y2$jscomp$12$$);
$rect$jscomp$7_y2$jscomp$12$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$7_y2$jscomp$12$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$7_y2$jscomp$12$$);var $px$jscomp$2$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$7_py$jscomp$1$$);$point$jscomp$7_py$jscomp$1$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$7_py$jscomp$1$$);return($px$jscomp$2$$>$x1$jscomp$14$$||$APP.$app$common$math$almost_zero_QMARK_$$($px$jscomp$2$$-
$x1$jscomp$14$$))&&($px$jscomp$2$$<$x2$jscomp$12$$||$APP.$app$common$math$almost_zero_QMARK_$$($px$jscomp$2$$-$x2$jscomp$12$$))&&($point$jscomp$7_py$jscomp$1$$>$y1$jscomp$14$$||$APP.$app$common$math$almost_zero_QMARK_$$($point$jscomp$7_py$jscomp$1$$-$y1$jscomp$14$$))&&($point$jscomp$7_py$jscomp$1$$<$rect$jscomp$7_y2$jscomp$12$$||$APP.$app$common$math$almost_zero_QMARK_$$($point$jscomp$7_py$jscomp$1$$-$rect$jscomp$7_y2$jscomp$12$$))};
$app$common$geom$rect$corners__GT_rect$cljs$0core$0IFn$0_invoke$0arity$04$$=function($xp1$jscomp$1$$,$yp1$jscomp$1$$,$xp2$jscomp$1$$,$yp2$jscomp$1$$){return $APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$(Math.min($xp1$jscomp$1$$,$xp2$jscomp$1$$),Math.min($yp1$jscomp$1$$,$yp2$jscomp$1$$),$APP.$app$common$math$abs$$($xp1$jscomp$1$$-$xp2$jscomp$1$$),$APP.$app$common$math$abs$$($yp1$jscomp$1$$-$yp2$jscomp$1$$))};
$APP.$app$common$geom$rect$clip_rect$$=function($selrect_y2$jscomp$13$$,$bounds_by2$jscomp$1$$){if($app$common$geom$rect$rect_QMARK_$$($selrect_y2$jscomp$13$$)){var $x1$jscomp$15$$=$selrect_y2$jscomp$13$$?.x1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect_y2$jscomp$13$$,$APP.$cljs$cst$1523$x1$$),$y1$jscomp$15$$=$selrect_y2$jscomp$13$$?.y1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect_y2$jscomp$13$$,$APP.$cljs$cst$1524$y1$$),$x2$jscomp$13$$=$selrect_y2$jscomp$13$$?.x2??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect_y2$jscomp$13$$,$APP.$cljs$cst$1525$x2$$);$selrect_y2$jscomp$13$$=$selrect_y2$jscomp$13$$?.y2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect_y2$jscomp$13$$,$APP.$cljs$cst$1526$y2$$);var $bx1$jscomp$1$$=$bounds_by2$jscomp$1$$?.x1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds_by2$jscomp$1$$,$APP.$cljs$cst$1523$x1$$),$by1$jscomp$1$$=$bounds_by2$jscomp$1$$?.y1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds_by2$jscomp$1$$,
$APP.$cljs$cst$1524$y1$$),$bx2$jscomp$1$$=$bounds_by2$jscomp$1$$?.x2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds_by2$jscomp$1$$,$APP.$cljs$cst$1525$x2$$);$bounds_by2$jscomp$1$$=$bounds_by2$jscomp$1$$?.y2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds_by2$jscomp$1$$,$APP.$cljs$cst$1526$y2$$);return $app$common$geom$rect$corners__GT_rect$cljs$0core$0IFn$0_invoke$0arity$04$$(Math.max($bx1$jscomp$1$$,$x1$jscomp$15$$),Math.max($by1$jscomp$1$$,$y1$jscomp$15$$),Math.min($bx2$jscomp$1$$,
$x2$jscomp$13$$),Math.min($bounds_by2$jscomp$1$$,$selrect_y2$jscomp$13$$))}return null};
$app$common$geom$rect$fix_aspect_ratio$$=function($G__46291__$1_bounds$jscomp$1$$,$aspect_ratio_target_width$$){if($APP.$cljs$core$truth_$$($aspect_ratio_target_width$$)){var $width$jscomp$41$$=$G__46291__$1_bounds$jscomp$1$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__46291__$1_bounds$jscomp$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$32$$=$G__46291__$1_bounds$jscomp$1$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__46291__$1_bounds$jscomp$1$$,$APP.$cljs$cst$1522$height$$),
$target_height$$=$width$jscomp$41$$*$aspect_ratio_target_width$$;$aspect_ratio_target_width$$=1/$aspect_ratio_target_width$$*$height$jscomp$32$$;$G__46291__$1_bounds$jscomp$1$$=$target_height$$>$height$jscomp$32$$?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__46291__$1_bounds$jscomp$1$$,$APP.$cljs$cst$1522$height$$,$target_height$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_$$,($target_height$$-$height$jscomp$32$$)/2):$G__46291__$1_bounds$jscomp$1$$;
return $target_height$$<$height$jscomp$32$$?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__46291__$1_bounds$jscomp$1$$,$APP.$cljs$cst$290$width$$,$aspect_ratio_target_width$$),$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$_$$,($aspect_ratio_target_width$$-$width$jscomp$41$$)/2):$G__46291__$1_bounds$jscomp$1$$}return $G__46291__$1_bounds$jscomp$1$$};
$app$common$media$format__GT_mtype$$=function($format$jscomp$28$$){switch($format$jscomp$28$$ instanceof $APP.$cljs$core$Keyword$$?$format$jscomp$28$$.$fqn$:null){case "png":return"image/png";case "jpeg":return"image/jpeg";case "jpg":return"image/jpeg";case "webp":return"image/webp";case "gif":return"image/gif";case "svg":return"image/svg+xml";default:return"application/octet-stream"}};
$app$common$media$mtype__GT_extension$$=function($mtype$jscomp$1$$){switch($mtype$jscomp$1$$){case "image/apng":return".apng";case "image/avif":return".avif";case "image/gif":return".gif";case "image/jpeg":return".jpg";case "image/png":return".png";case "image/svg+xml":return".svg";case "image/webp":return".webp";case "application/zip":return".zip";case "application/penpot":return".penpot";case "application/pdf":return".pdf";case "text/plain":return".txt";case "font/woff":return".woff";case "font/woff2":return".woff2";
case "font/ttf":return".ttf";case "font/otf":return".otf";case "application/octet-stream":return".bin";default:return null}};
$app$common$media$font_weight__GT_name$$=function($G__42991_weight$jscomp$3$$){$G__42991_weight$jscomp$3$$=$APP.$cljs$core$fix$$($G__42991_weight$jscomp$3$$);switch($G__42991_weight$jscomp$3$$){case 100:return"Hairline";case 200:return"Extra Light";case 300:return"Light";case 400:return"Regular";case 500:return"Medium";case 600:return"Semi Bold";case 700:return"Bold";case 800:return"Extra Bold";case 900:return"Black";case 950:return"Extra Black";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__42991_weight$jscomp$3$$)].join(""));
}};
$APP.$app$common$media$font_display_variant$$=function($base$jscomp$23_variant_name$$,$weight$jscomp$4$$,$style$jscomp$8$$){return typeof $base$jscomp$23_variant_name$$!=="string"||$APP.$cuerdas$core$blank_QMARK_$$($base$jscomp$23_variant_name$$)?($base$jscomp$23_variant_name$$=$app$common$media$font_weight__GT_name$$($weight$jscomp$4$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("italic",$style$jscomp$8$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$23_variant_name$$)," Italic"].join(""):
$base$jscomp$23_variant_name$$):$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$23_variant_name$$)};
$promesa$core$create$cljs$0core$0IFn$0_invoke$0arity$01$$=function($f$jscomp$665$$){var $d$jscomp$200$$=new $APP.$$jscomp$scope$84173391$14$PromiseImpl$$;try{var $G__43613_44217$$=function($p1__43602_SHARP_$$){return $APP.$promesa$protocols$_resolve_BANG_$$($d$jscomp$200$$,$p1__43602_SHARP_$$)},$G__43614_44218$$=function($p1__43603_SHARP_$$){return $APP.$promesa$protocols$_reject_BANG_$$($d$jscomp$200$$,$p1__43603_SHARP_$$)};$f$jscomp$665$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$665$$.$cljs$core$IFn$_invoke$arity$2$($G__43613_44217$$,
$G__43614_44218$$):$f$jscomp$665$$($G__43613_44217$$,$G__43614_44218$$)}catch($e43610$$){$APP.$promesa$protocols$_reject_BANG_$$($d$jscomp$200$$,$e43610$$)}return $d$jscomp$200$$};$APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$675$$,$p$jscomp$158$$){return $APP.$promesa$protocols$_fmap$$($promesa$protocols$_promise$$($p$jscomp$158$$),$f$jscomp$675$$)};
$promesa$core$mcat$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$679$$,$p$jscomp$162$$){return $promesa$protocols$_mcat$$($promesa$protocols$_promise$$($p$jscomp$162$$),$f$jscomp$679$$)};$APP.$promesa$core$finally$0$cljs$0core$0IFn$0_invoke$0arity$02$$=function($p$jscomp$170$$,$f$jscomp$687$$){return $promesa$protocols$_fnly$$($promesa$protocols$_promise$$($p$jscomp$170$$),$f$jscomp$687$$)};
$promesa$core$fnly$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$693$$,$p$jscomp$176$$){return $promesa$protocols$_fnly$$($promesa$protocols$_promise$$($p$jscomp$176$$),$f$jscomp$693$$)};
$promesa$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$=function($p$jscomp$178$$,$f$jscomp$695$$){return $promesa$protocols$_merr$$($promesa$protocols$_promise$$($p$jscomp$178$$),function($p1__43720_SHARP_$$){return $promesa$protocols$_promise$$($f$jscomp$695$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$695$$.$cljs$core$IFn$_invoke$arity$1$($p1__43720_SHARP_$$):$f$jscomp$695$$($p1__43720_SHARP_$$))})};
$APP.$promesa$core$merr$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$697$$,$p$jscomp$180$$){return $promesa$protocols$_merr$$($p$jscomp$180$$,$f$jscomp$697$$)};
$APP.$app$util$webapi$file_reader$$=function($f$jscomp$709$$){return $APP.$beicon$v2$core$create$$(function($subs$jscomp$8$$){var $reader$jscomp$50$$=new FileReader;$APP.$app$util$object$set_BANG_$$($reader$jscomp$50$$,"onload",function(){var $duri$jscomp$inline_4526_result__$1$jscomp$7$$=$reader$jscomp$50$$.result;$duri$jscomp$inline_4526_result__$1$jscomp$7$$=typeof $duri$jscomp$inline_4526_result__$1$jscomp$7$$==="string"?$APP.$cuerdas$core$replace$$($duri$jscomp$inline_4526_result__$1$jscomp$7$$,
$app$util$webapi$webkit_datauri_fix_re$$,"$1$3"):$duri$jscomp$inline_4526_result__$1$jscomp$7$$;$subs$jscomp$8$$.next($duri$jscomp$inline_4526_result__$1$jscomp$7$$);return $subs$jscomp$8$$.complete()});$APP.$app$util$object$set_BANG_$$($reader$jscomp$50$$,"onerror",function($p1__44823_SHARP_$$){return $subs$jscomp$8$$.error($p1__44823_SHARP_$$)});$APP.$app$util$object$set_BANG_$$($reader$jscomp$50$$,"onabort",function(){return $subs$jscomp$8$$.error($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("operation aborted",
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1544$abort$$,$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$1545$operation_aborted$$,$APP.$cljs$cst$275$hint$$,"operation aborted"],null),null])),null))});$f$jscomp$709$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$709$$.$cljs$core$IFn$_invoke$arity$1$($reader$jscomp$50$$):$f$jscomp$709$$($reader$jscomp$50$$);
return function(){return $reader$jscomp$50$$.abort()}})};$APP.$app$util$webapi$read_file_as_array_buffer$$=function($file$jscomp$9$$){return $APP.$app$util$webapi$file_reader$$(function($p1__44844_SHARP_$$){return $p1__44844_SHARP_$$.readAsArrayBuffer($file$jscomp$9$$)})};$APP.$app$util$webapi$read_file_as_data_url$$=function($file$jscomp$10$$){return $APP.$app$util$webapi$file_reader$$(function($p1__44845_SHARP_$$){return $p1__44845_SHARP_$$.readAsDataURL($file$jscomp$10$$)})};
$APP.$app$util$webapi$create_blob$cljs$0core$0IFn$0_invoke$0arity$02$$=function($content$jscomp$13$$,$mtype$jscomp$2$$){return new Blob([$content$jscomp$13$$],{type:$mtype$jscomp$2$$})};$APP.$app$util$webapi$revoke_uri$$=function($url$jscomp$66$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($url$jscomp$66$$,"blob:")?URL.revokeObjectURL($url$jscomp$66$$):null};$APP.$app$util$webapi$create_uri$$=function($b$jscomp$247$$){return URL.createObjectURL($b$jscomp$247$$)};
$APP.$app$util$webapi$data_uri__GT_blob$$=function($data_uri$jscomp$1_mtype$jscomp$3_mtype_end_vec__44854$$){$data_uri$jscomp$1_mtype$jscomp$3_mtype_end_vec__44854$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$03$$($data_uri$jscomp$1_mtype$jscomp$3_mtype_end_vec__44854$$,",",2);var $meta$jscomp$80$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data_uri$jscomp$1_mtype$jscomp$3_mtype_end_vec__44854$$,0,null),$data$jscomp$118$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data_uri$jscomp$1_mtype$jscomp$3_mtype_end_vec__44854$$,
1,null);$data_uri$jscomp$1_mtype$jscomp$3_mtype_end_vec__44854$$=function(){var $or__5025__auto__$jscomp$298$$=$APP.$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($meta$jscomp$80$$,";");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$298$$)?$or__5025__auto__$jscomp$298$$:$APP.$cljs$core$count$$($meta$jscomp$80$$)}();$data_uri$jscomp$1_mtype$jscomp$3_mtype_end_vec__44854$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($meta$jscomp$80$$,$APP.$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($meta$jscomp$80$$,
":")+1,$data_uri$jscomp$1_mtype$jscomp$3_mtype_end_vec__44854$$);var $base64_QMARK__content$jscomp$14$$=$APP.$cuerdas$core$includes_QMARK_$$($meta$jscomp$80$$,";base64");$base64_QMARK__content$jscomp$14$$=$APP.$cljs$core$truth_$$($base64_QMARK__content$jscomp$14$$)?function(){for(var $decoded$$=globalThis.atob($data$jscomp$118$$),$size$jscomp$84$$=$decoded$$.length,$bytes$jscomp$9$$=new Uint8Array($size$jscomp$84$$),$i_44943$$=0;;)if($i_44943$$<$size$jscomp$84$$)$bytes$jscomp$9$$[$i_44943$$]=$decoded$$.charCodeAt($i_44943$$),
$i_44943$$+=1;else break;return $bytes$jscomp$9$$}():(new TextEncoder).encode(globalThis.decodeURIComponent($data$jscomp$118$$));return $APP.$app$util$webapi$create_blob$cljs$0core$0IFn$0_invoke$0arity$02$$($base64_QMARK__content$jscomp$14$$,$data_uri$jscomp$1_mtype$jscomp$3_mtype_end_vec__44854$$)};
$app$util$webapi$get_selection$$=function(){if($APP.$cljs$core$truth_$$($APP.$app$util$globals$document$$)){var $selection$jscomp$1$$=$APP.$app$util$globals$document$$.getSelection();return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selection$jscomp$1$$.type,"None")?$selection$jscomp$1$$:null}return null};
$app$util$webapi$set_cursor_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($node$jscomp$168_text_node$$,$offset$jscomp$93$$){if($APP.$cljs$core$truth_$$($node$jscomp$168_text_node$$)){var $child_nodes$$=$node$jscomp$168_text_node$$.childNodes,$sel$jscomp$3$$=$app$util$webapi$get_selection$$(),$r$jscomp$75$$=$APP.$app$util$globals$document$$.createRange();$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($child_nodes$$.length,0)?($r$jscomp$75$$.setStart($node$jscomp$168_text_node$$,$offset$jscomp$93$$),
$r$jscomp$75$$.setEnd($node$jscomp$168_text_node$$,$offset$jscomp$93$$)):($node$jscomp$168_text_node$$=$child_nodes$$[0],$r$jscomp$75$$.setStart($node$jscomp$168_text_node$$,$offset$jscomp$93$$),$r$jscomp$75$$.setEnd($node$jscomp$168_text_node$$,$offset$jscomp$93$$));$sel$jscomp$3$$.removeAllRanges();$sel$jscomp$3$$.addRange($r$jscomp$75$$);return $sel$jscomp$3$$}return null};
$app$util$webapi$set_cursor_after_BANG_$$=function($node$jscomp$170$$){var $first_child$$=$node$jscomp$170$$.childNodes[0];return $app$util$webapi$set_cursor_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($node$jscomp$170$$,$APP.$cljs$core$truth_$$($first_child$$)?$first_child$$.length:0)};$APP.$okulary$core$key$$=function($k$jscomp$570$$){return function($v$jscomp$488$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$488$$,$k$jscomp$570$$)}};
$APP.$okulary$core$in$0$$=function($kv$jscomp$3$$){return function($v$jscomp$489$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$489$$,$kv$jscomp$3$$)}};$okulary$core$Atom$$=function($state$jscomp$34$$){var $watches$jscomp$5$$=new Map;this.state=$state$jscomp$34$$;this.$watches$=$watches$jscomp$5$$;this.$cljs$lang$protocol_mask$partition1$$=114690;this.$cljs$lang$protocol_mask$partition0$$=6324224};$okulary$core$atom$$=function($x$jscomp$1070$$){return new $okulary$core$Atom$$($x$jscomp$1070$$)};
$okulary$core$DerivedAtom$$=function($selector$jscomp$3$$,$source$jscomp$36$$,$equals_QMARK_$$){var $watches$jscomp$7$$=new Map;this.id=Symbol("okulary");this.$selector$=$selector$jscomp$3$$;this.source=$source$jscomp$36$$;this.$equals_QMARK_$=$equals_QMARK_$$;this.$watches$=$watches$jscomp$7$$;this.cache=this.$srccache$=$okulary$core$EMPTY$$;this.$cljs$lang$protocol_mask$partition1$$=16386;this.$cljs$lang$protocol_mask$partition0$$=32768};
$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$=function($selector$jscomp$5$$,$source$jscomp$38$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$($selector$jscomp$5$$,$source$jscomp$38$$,$cljs$core$identical_QMARK_$$)};$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$=function($selector$jscomp$6$$,$source$jscomp$39$$,$equals_QMARK_$jscomp$2$$){return new $okulary$core$DerivedAtom$$($selector$jscomp$6$$,$source$jscomp$39$$,$equals_QMARK_$jscomp$2$$)};
$potok$v2$core$UpdateEvent$$=function(){};
$potok$v2$core$update$$=function($JSCompiler_temp$jscomp$656_event$jscomp$7$$,$state$jscomp$37$$){if($JSCompiler_temp$jscomp$656_event$jscomp$7$$!=null&&$JSCompiler_temp$jscomp$656_event$jscomp$7$$.$potok$v2$core$UpdateEvent$update$arity$2$!=null)$JSCompiler_temp$jscomp$656_event$jscomp$7$$=$JSCompiler_temp$jscomp$656_event$jscomp$7$$.$potok$v2$core$UpdateEvent$update$arity$2$($JSCompiler_temp$jscomp$656_event$jscomp$7$$,$state$jscomp$37$$);else{var $m__5372__auto__$jscomp$inline_4536_m__5374__auto__$jscomp$inline_4535$$=$potok$v2$core$update$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$656_event$jscomp$7$$==
null?null:$JSCompiler_temp$jscomp$656_event$jscomp$7$$)];if($m__5372__auto__$jscomp$inline_4536_m__5374__auto__$jscomp$inline_4535$$!=null)$JSCompiler_temp$jscomp$656_event$jscomp$7$$=$m__5372__auto__$jscomp$inline_4536_m__5374__auto__$jscomp$inline_4535$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_4536_m__5374__auto__$jscomp$inline_4535$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$656_event$jscomp$7$$,$state$jscomp$37$$):$m__5372__auto__$jscomp$inline_4536_m__5374__auto__$jscomp$inline_4535$$($JSCompiler_temp$jscomp$656_event$jscomp$7$$,
$state$jscomp$37$$);else if($m__5372__auto__$jscomp$inline_4536_m__5374__auto__$jscomp$inline_4535$$=$potok$v2$core$update$$._,$m__5372__auto__$jscomp$inline_4536_m__5374__auto__$jscomp$inline_4535$$!=null)$JSCompiler_temp$jscomp$656_event$jscomp$7$$=$m__5372__auto__$jscomp$inline_4536_m__5374__auto__$jscomp$inline_4535$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_4536_m__5374__auto__$jscomp$inline_4535$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$656_event$jscomp$7$$,
$state$jscomp$37$$):$m__5372__auto__$jscomp$inline_4536_m__5374__auto__$jscomp$inline_4535$$($JSCompiler_temp$jscomp$656_event$jscomp$7$$,$state$jscomp$37$$);else throw $APP.$cljs$core$missing_protocol$$("UpdateEvent.update",$JSCompiler_temp$jscomp$656_event$jscomp$7$$);}return $JSCompiler_temp$jscomp$656_event$jscomp$7$$};$potok$v2$core$WatchEvent$$=function(){};
$potok$v2$core$watch$$=function($JSCompiler_temp$jscomp$657_event$jscomp$9$$,$state$jscomp$39$$,$stream$jscomp$9$$){if($JSCompiler_temp$jscomp$657_event$jscomp$9$$!=null&&$JSCompiler_temp$jscomp$657_event$jscomp$9$$.$potok$v2$core$WatchEvent$watch$arity$3$!=null)$JSCompiler_temp$jscomp$657_event$jscomp$9$$=$JSCompiler_temp$jscomp$657_event$jscomp$9$$.$potok$v2$core$WatchEvent$watch$arity$3$($JSCompiler_temp$jscomp$657_event$jscomp$9$$,$state$jscomp$39$$,$stream$jscomp$9$$);else{var $m__5372__auto__$jscomp$inline_4542_m__5374__auto__$jscomp$inline_4541$$=
$potok$v2$core$watch$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$657_event$jscomp$9$$==null?null:$JSCompiler_temp$jscomp$657_event$jscomp$9$$)];if($m__5372__auto__$jscomp$inline_4542_m__5374__auto__$jscomp$inline_4541$$!=null)$JSCompiler_temp$jscomp$657_event$jscomp$9$$=$m__5372__auto__$jscomp$inline_4542_m__5374__auto__$jscomp$inline_4541$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_4542_m__5374__auto__$jscomp$inline_4541$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$657_event$jscomp$9$$,
$state$jscomp$39$$,$stream$jscomp$9$$):$m__5372__auto__$jscomp$inline_4542_m__5374__auto__$jscomp$inline_4541$$($JSCompiler_temp$jscomp$657_event$jscomp$9$$,$state$jscomp$39$$,$stream$jscomp$9$$);else if($m__5372__auto__$jscomp$inline_4542_m__5374__auto__$jscomp$inline_4541$$=$potok$v2$core$watch$$._,$m__5372__auto__$jscomp$inline_4542_m__5374__auto__$jscomp$inline_4541$$!=null)$JSCompiler_temp$jscomp$657_event$jscomp$9$$=$m__5372__auto__$jscomp$inline_4542_m__5374__auto__$jscomp$inline_4541$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_4542_m__5374__auto__$jscomp$inline_4541$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$657_event$jscomp$9$$,$state$jscomp$39$$,$stream$jscomp$9$$):$m__5372__auto__$jscomp$inline_4542_m__5374__auto__$jscomp$inline_4541$$($JSCompiler_temp$jscomp$657_event$jscomp$9$$,$state$jscomp$39$$,$stream$jscomp$9$$);else throw $APP.$cljs$core$missing_protocol$$("WatchEvent.watch",$JSCompiler_temp$jscomp$657_event$jscomp$9$$);}return $JSCompiler_temp$jscomp$657_event$jscomp$9$$};
$potok$v2$core$EffectEvent$$=function(){};
$potok$v2$core$effect$$=function($JSCompiler_temp$jscomp$658_event$jscomp$11$$,$state$jscomp$41$$,$stream$jscomp$11$$){if($JSCompiler_temp$jscomp$658_event$jscomp$11$$!=null&&$JSCompiler_temp$jscomp$658_event$jscomp$11$$.$potok$v2$core$EffectEvent$effect$arity$3$!=null)$JSCompiler_temp$jscomp$658_event$jscomp$11$$=$JSCompiler_temp$jscomp$658_event$jscomp$11$$.$potok$v2$core$EffectEvent$effect$arity$3$($JSCompiler_temp$jscomp$658_event$jscomp$11$$,$state$jscomp$41$$,$stream$jscomp$11$$);else{var $m__5372__auto__$jscomp$inline_4548_m__5374__auto__$jscomp$inline_4547$$=
$potok$v2$core$effect$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$658_event$jscomp$11$$==null?null:$JSCompiler_temp$jscomp$658_event$jscomp$11$$)];if($m__5372__auto__$jscomp$inline_4548_m__5374__auto__$jscomp$inline_4547$$!=null)$JSCompiler_temp$jscomp$658_event$jscomp$11$$=$m__5372__auto__$jscomp$inline_4548_m__5374__auto__$jscomp$inline_4547$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_4548_m__5374__auto__$jscomp$inline_4547$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$658_event$jscomp$11$$,
$state$jscomp$41$$,$stream$jscomp$11$$):$m__5372__auto__$jscomp$inline_4548_m__5374__auto__$jscomp$inline_4547$$($JSCompiler_temp$jscomp$658_event$jscomp$11$$,$state$jscomp$41$$,$stream$jscomp$11$$);else if($m__5372__auto__$jscomp$inline_4548_m__5374__auto__$jscomp$inline_4547$$=$potok$v2$core$effect$$._,$m__5372__auto__$jscomp$inline_4548_m__5374__auto__$jscomp$inline_4547$$!=null)$JSCompiler_temp$jscomp$658_event$jscomp$11$$=$m__5372__auto__$jscomp$inline_4548_m__5374__auto__$jscomp$inline_4547$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_4548_m__5374__auto__$jscomp$inline_4547$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$658_event$jscomp$11$$,$state$jscomp$41$$,$stream$jscomp$11$$):$m__5372__auto__$jscomp$inline_4548_m__5374__auto__$jscomp$inline_4547$$($JSCompiler_temp$jscomp$658_event$jscomp$11$$,$state$jscomp$41$$,$stream$jscomp$11$$);else throw $APP.$cljs$core$missing_protocol$$("EffectEvent.effect",$JSCompiler_temp$jscomp$658_event$jscomp$11$$);}return $JSCompiler_temp$jscomp$658_event$jscomp$11$$};
$potok$v2$core$Event$$=function(){};
$potok$v2$core$_type$$=function($JSCompiler_temp$jscomp$659__$jscomp$1030$$){if($JSCompiler_temp$jscomp$659__$jscomp$1030$$!=null&&$JSCompiler_temp$jscomp$659__$jscomp$1030$$.$potok$v2$core$Event$_type$arity$1$!=null)$JSCompiler_temp$jscomp$659__$jscomp$1030$$=$JSCompiler_temp$jscomp$659__$jscomp$1030$$.$potok$v2$core$Event$_type$arity$1$($JSCompiler_temp$jscomp$659__$jscomp$1030$$);else{var $m__5372__auto__$jscomp$inline_4552_m__5374__auto__$jscomp$inline_4551$$=$potok$v2$core$_type$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$659__$jscomp$1030$$==
null?null:$JSCompiler_temp$jscomp$659__$jscomp$1030$$)];if($m__5372__auto__$jscomp$inline_4552_m__5374__auto__$jscomp$inline_4551$$!=null)$JSCompiler_temp$jscomp$659__$jscomp$1030$$=$m__5372__auto__$jscomp$inline_4552_m__5374__auto__$jscomp$inline_4551$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_4552_m__5374__auto__$jscomp$inline_4551$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$659__$jscomp$1030$$):$m__5372__auto__$jscomp$inline_4552_m__5374__auto__$jscomp$inline_4551$$($JSCompiler_temp$jscomp$659__$jscomp$1030$$);
else if($m__5372__auto__$jscomp$inline_4552_m__5374__auto__$jscomp$inline_4551$$=$potok$v2$core$_type$$._,$m__5372__auto__$jscomp$inline_4552_m__5374__auto__$jscomp$inline_4551$$!=null)$JSCompiler_temp$jscomp$659__$jscomp$1030$$=$m__5372__auto__$jscomp$inline_4552_m__5374__auto__$jscomp$inline_4551$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_4552_m__5374__auto__$jscomp$inline_4551$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$659__$jscomp$1030$$):$m__5372__auto__$jscomp$inline_4552_m__5374__auto__$jscomp$inline_4551$$($JSCompiler_temp$jscomp$659__$jscomp$1030$$);
else throw $APP.$cljs$core$missing_protocol$$("Event.-type",$JSCompiler_temp$jscomp$659__$jscomp$1030$$);}return $JSCompiler_temp$jscomp$659__$jscomp$1030$$};
$potok$v2$core$update_QMARK_$$=function($e$jscomp$223$$){return $e$jscomp$223$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$e$jscomp$223$$.$potok$v2$core$UpdateEvent$$?!0:$e$jscomp$223$$.$cljs$lang$protocol_mask$partition$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($potok$v2$core$UpdateEvent$$,$e$jscomp$223$$):$APP.$cljs$core$native_satisfies_QMARK_$$($potok$v2$core$UpdateEvent$$,$e$jscomp$223$$)};
$potok$v2$core$watch_QMARK_$$=function($e$jscomp$224$$){return $e$jscomp$224$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$e$jscomp$224$$.$potok$v2$core$WatchEvent$$?!0:$e$jscomp$224$$.$cljs$lang$protocol_mask$partition$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($potok$v2$core$WatchEvent$$,$e$jscomp$224$$):$APP.$cljs$core$native_satisfies_QMARK_$$($potok$v2$core$WatchEvent$$,$e$jscomp$224$$)};
$potok$v2$core$effect_QMARK_$$=function($e$jscomp$225$$){return $e$jscomp$225$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$e$jscomp$225$$.$potok$v2$core$EffectEvent$$?!0:$e$jscomp$225$$.$cljs$lang$protocol_mask$partition$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($potok$v2$core$EffectEvent$$,$e$jscomp$225$$):$APP.$cljs$core$native_satisfies_QMARK_$$($potok$v2$core$EffectEvent$$,$e$jscomp$225$$)};
$potok$v2$core$event_QMARK_$$=function($v$jscomp$490$$){var $or__5025__auto__$jscomp$299$$=$v$jscomp$490$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$v$jscomp$490$$.$potok$v2$core$Event$$?!0:$v$jscomp$490$$.$cljs$lang$protocol_mask$partition$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($potok$v2$core$Event$$,$v$jscomp$490$$):$APP.$cljs$core$native_satisfies_QMARK_$$($potok$v2$core$Event$$,$v$jscomp$490$$);return $or__5025__auto__$jscomp$299$$?$or__5025__auto__$jscomp$299$$:$potok$v2$core$update_QMARK_$$($v$jscomp$490$$)||
$potok$v2$core$watch_QMARK_$$($v$jscomp$490$$)||$potok$v2$core$effect_QMARK_$$($v$jscomp$490$$)};
$potok$v2$core$promise_QMARK_$$=function($v$jscomp$491$$){var $and__5023__auto__$jscomp$207_or__5025__auto__$jscomp$300$$=$v$jscomp$491$$ instanceof Promise;if($and__5023__auto__$jscomp$207_or__5025__auto__$jscomp$300$$)return $and__5023__auto__$jscomp$207_or__5025__auto__$jscomp$300$$;$and__5023__auto__$jscomp$207_or__5025__auto__$jscomp$300$$=$goog$isObject$$($v$jscomp$491$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$207_or__5025__auto__$jscomp$300$$)?$APP.$cljs$core$fn_QMARK_$$($v$jscomp$491$$.then):
$and__5023__auto__$jscomp$207_or__5025__auto__$jscomp$300$$};$APP.$potok$v2$core$type$$=function($o$jscomp$220$$){return $o$jscomp$220$$!=null&&$APP.$cljs$core$PROTOCOL_SENTINEL$$===$o$jscomp$220$$.$potok$v2$core$Event$$?$o$jscomp$220$$.$potok$v2$core$Event$_type$arity$1$(null):$cljs$cst$1551$potok_DOT_v2_DOT_core_SLASH_undefined$$};
$APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($t$jscomp$66$$){return function($v$jscomp$492$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$potok$v2$core$type$$($v$jscomp$492$$),$t$jscomp$66$$)}};$APP.$potok$v2$core$DataEvent$$=function($t$jscomp$68$$,$o$jscomp$221$$){this.t=$t$jscomp$68$$;this.o=$o$jscomp$221$$;this.$cljs$lang$protocol_mask$partition0$$=32768;this.$cljs$lang$protocol_mask$partition1$$=0};
$potok$v2$core$event$cljs$0core$0IFn$0_invoke$0arity$02$$=function($type$jscomp$260$$,$params$jscomp$87$$){return $potok$v2$core$resolve$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$260$$,$params$jscomp$87$$)};
$potok$v2$core$repr_event$$=function($event$jscomp$12$$){return($event$jscomp$12$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$event$jscomp$12$$.$potok$v2$core$Event$$||($event$jscomp$12$$.$cljs$lang$protocol_mask$partition$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($potok$v2$core$Event$$,$event$jscomp$12$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($potok$v2$core$Event$$,$event$jscomp$12$$))?["typ:(",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$potok$v2$core$_type$$($event$jscomp$12$$)])),
")"].join(""):$APP.$cljs$core$fn_QMARK_$$($event$jscomp$12$$)&&$APP.$cljs$core$count$$($event$jscomp$12$$.name)>0?["fn:(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$core$demunge$$($event$jscomp$12$$.name)),")"].join(""):["unk:(",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$event$jscomp$12$$])),")"].join("")};
$module$contents$goog$dispose_dispose$$=function($obj$jscomp$159$$){$obj$jscomp$159$$&&typeof $obj$jscomp$159$$.dispose=="function"&&$obj$jscomp$159$$.dispose()};
$module$contents$goog$disposeAll_disposeAll$$=function($var_args$jscomp$825$$){for(let $i$jscomp$436$$=0,$len$jscomp$71$$=arguments.length;$i$jscomp$436$$<$len$jscomp$71$$;++$i$jscomp$436$$){const $disposable$jscomp$5$$=arguments[$i$jscomp$436$$];$goog$isArrayLike$$($disposable$jscomp$5$$)?$module$contents$goog$disposeAll_disposeAll$$.apply(null,$disposable$jscomp$5$$):$module$contents$goog$dispose_dispose$$($disposable$jscomp$5$$)}};
$goog$Disposable$$=function(){0!=$goog$Disposable$MonitoringMode$OFF$$&&($goog$Disposable$instances_$$[$goog$getUid$$(this)]=this);this.$disposed_$=this.$disposed_$;this.$onDisposeCallbacks_$=this.$onDisposeCallbacks_$};$goog$events$EventId$$=function($eventId$$){this.id=$eventId$$};
$APP.$goog$events$Event$$=function($type$jscomp$261$$,$opt_target$jscomp$2$$){this.type=$type$jscomp$261$$ instanceof $goog$events$EventId$$?String($type$jscomp$261$$):$type$jscomp$261$$;this.currentTarget=this.target=$opt_target$jscomp$2$$;this.defaultPrevented=this.$propagationStopped_$=!1};
$APP.$goog$events$BrowserEvent$$=function($opt_e$jscomp$2$$,$opt_currentTarget$$){$APP.$goog$events$Event$$.call(this,$opt_e$jscomp$2$$?$opt_e$jscomp$2$$.type:"");this.relatedTarget=this.currentTarget=this.target=null;this.button=this.screenY=this.screenX=this.clientY=this.clientX=this.offsetY=this.offsetX=0;this.key="";this.charCode=this.keyCode=0;this.metaKey=this.shiftKey=this.altKey=this.ctrlKey=!1;this.state=null;this.pointerId=0;this.pointerType="";this.$event_$=null;$opt_e$jscomp$2$$&&this.init($opt_e$jscomp$2$$,
$opt_currentTarget$$)};$APP.$app$util$dom$set_html_title$$=function($title$jscomp$13$$){return $APP.$app$util$globals$document$$.title=$title$jscomp$13$$};$APP.$app$util$dom$get_element$$=function($id$jscomp$45$$){return $APP.$goog$dom$getElement$$($id$jscomp$45$$)};$APP.$app$util$dom$stop_propagation$$=function($event$jscomp$20$$){return $event$jscomp$20$$!=null&&$APP.$cljs$core$fn_QMARK_$$($event$jscomp$20$$.stopPropagation)?$event$jscomp$20$$.stopPropagation():null};
$APP.$app$util$dom$prevent_default$$=function($event$jscomp$22$$){return $event$jscomp$22$$!=null&&$APP.$cljs$core$fn_QMARK_$$($event$jscomp$22$$.preventDefault)?$event$jscomp$22$$.preventDefault():null};$APP.$app$util$dom$get_target$$=function($event$jscomp$24$$){return $event$jscomp$24$$!=null?$event$jscomp$24$$.target:null};$APP.$app$util$dom$get_current_target$$=function($event$jscomp$27$$){return $event$jscomp$27$$!=null?$event$jscomp$27$$.currentTarget:null};
$APP.$app$util$dom$get_parent$$=function($node$jscomp$176$$){return $node$jscomp$176$$!=null?$node$jscomp$176$$.parentElement:null};
$app$util$dom$get_parent_at$$=function($current$jscomp$8_node$jscomp$177$$){if($current$jscomp$8_node$jscomp$177$$!=null)for(var $G__46858_current_count$$=2;;){if($current$jscomp$8_node$jscomp$177$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__46858_current_count$$,0))return $current$jscomp$8_node$jscomp$177$$;--$G__46858_current_count$$;$current$jscomp$8_node$jscomp$177$$=$current$jscomp$8_node$jscomp$177$$.parentElement}else return null};
$APP.$app$util$dom$get_parent_with_data$$=function($current$jscomp$9_node$jscomp$178$$,$name$jscomp$156_name__$1$jscomp$2$$){for($name$jscomp$156_name__$1$jscomp$2$$=$cuerdas$core$camel$$($name$jscomp$156_name__$1$jscomp$2$$);;){if($current$jscomp$9_node$jscomp$178$$==null)return null;if(!$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$9_node$jscomp$178$$.nodeType,Node.ELEMENT_NODE)&&$name$jscomp$156_name__$1$jscomp$2$$ in $current$jscomp$9_node$jscomp$178$$.dataset)return $current$jscomp$9_node$jscomp$178$$;
$current$jscomp$9_node$jscomp$178$$=$current$jscomp$9_node$jscomp$178$$.parentElement}};$APP.$app$util$dom$get_value$$=function($node$jscomp$180$$){return $node$jscomp$180$$!=null?$node$jscomp$180$$.value:null};
$APP.$app$util$dom$get_input_value$$=function($node$jscomp$181$$){return $node$jscomp$181$$!=null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$181$$.type,"checkbox")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$181$$.type,"radio")?$node$jscomp$181$$.checked:$node$jscomp$181$$.value:null};$APP.$app$util$dom$get_attribute$$=function($node$jscomp$182$$,$attr_name$$){return $node$jscomp$182$$!=null?$node$jscomp$182$$.getAttribute($attr_name$$):null};
$APP.$app$util$dom$get_files$$=function($node$jscomp$186$$){return $node$jscomp$186$$!=null?$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($node$jscomp$186$$.files):null};$APP.$app$util$dom$checked_QMARK_$$=function($node$jscomp$187$$){return $node$jscomp$187$$!=null?$node$jscomp$187$$.checked:null};$APP.$app$util$dom$select_text_BANG_$$=function($node$jscomp$192$$){return $node$jscomp$192$$!=null&&$node$jscomp$192$$.select!=null?$node$jscomp$192$$.select():null};
$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$=function($tag$jscomp$48$$){return $APP.$app$util$globals$document$$.createElement($tag$jscomp$48$$)};$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$02$$=function(){return $APP.$app$util$globals$document$$.createElementNS("http://www.w3.org/2000/svg","use")};
$app$util$dom$escape_html$$=function($text$jscomp$17$$){return $text$jscomp$17$$!=null?$APP.$cuerdas$core$replace$$($APP.$cuerdas$core$replace$$($APP.$cuerdas$core$replace$$($APP.$cuerdas$core$replace$$($APP.$cuerdas$core$replace$$($text$jscomp$17$$,"\x26","\x26amp;"),"\x3c","\x26lt;"),"\x3e","\x26gt;"),'"',"\x26quot;"),"'","\x26#39;"):null};$app$util$dom$set_html_BANG_$$=function($el$jscomp$6$$,$html$jscomp$17$$){$el$jscomp$6$$!=null&&($el$jscomp$6$$.innerHTML=$html$jscomp$17$$);return $el$jscomp$6$$};
$APP.$app$util$dom$append_child_BANG_$$=function($el$jscomp$7$$,$child$jscomp$50$$){$el$jscomp$7$$!=null&&$el$jscomp$7$$.appendChild($child$jscomp$50$$);return $el$jscomp$7$$};
$app$util$dom$insert_after_BANG_$$=function($el$jscomp$8$$,$ref$jscomp$9$$,$child$jscomp$51$$){if($el$jscomp$8$$!=null&&$ref$jscomp$9$$!=null){var $nodes_46885_temp__5823__auto___46888$$=$el$jscomp$8$$.childNodes,$idx_46886$$=$APP.$app$common$data$index_of_pred$$($nodes_46885_temp__5823__auto___46888$$,function($p1__46469_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ref$jscomp$9$$,$p1__46469_SHARP_$$)});$nodes_46885_temp__5823__auto___46888$$=$nodes_46885_temp__5823__auto___46888$$[$idx_46886$$+
1];$APP.$cljs$core$truth_$$($nodes_46885_temp__5823__auto___46888$$)?$el$jscomp$8$$.insertBefore($child$jscomp$51$$,$nodes_46885_temp__5823__auto___46888$$):$el$jscomp$8$$.appendChild($child$jscomp$51$$)}};$APP.$app$util$dom$get_tag_name$$=function($el$jscomp$12$$){return $el$jscomp$12$$!=null?$el$jscomp$12$$.tagName:null};
$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$=function($selector$jscomp$8$$){return $APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$document$$,$selector$jscomp$8$$)};$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$=function($el$jscomp$16$$,$selector$jscomp$9$$){return $el$jscomp$16$$!=null?$el$jscomp$16$$.querySelector($selector$jscomp$9$$):null};
$APP.$app$util$dom$query_all$cljs$0core$0IFn$0_invoke$0arity$02$$=function($el$jscomp$17$$,$selector$jscomp$11$$){return $el$jscomp$17$$!=null?$el$jscomp$17$$.querySelectorAll($selector$jscomp$11$$):null};$APP.$app$util$dom$get_client_position$$=function($event$jscomp$30$$){return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$30$$.clientX,$event$jscomp$30$$.clientY)};
$APP.$app$util$dom$get_offset_position$$=function($event$jscomp$31$$){return $event$jscomp$31$$!=null?$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$31$$.offsetX,$event$jscomp$31$$.offsetY):null};$APP.$app$util$dom$get_client_size$$=function($node$jscomp$196$$){return $node$jscomp$196$$!=null?$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$(0,0,$node$jscomp$196$$.clientWidth,$node$jscomp$196$$.clientHeight):null};
$APP.$app$util$dom$get_bounding_rect$$=function($node$jscomp$197_rect$jscomp$8$$){$node$jscomp$197_rect$jscomp$8$$=$node$jscomp$197_rect$jscomp$8$$.getBoundingClientRect();return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$257$left$$,$node$jscomp$197_rect$jscomp$8$$.left,$APP.$cljs$cst$1562$top$$,$node$jscomp$197_rect$jscomp$8$$.top,$APP.$cljs$cst$258$right$$,$node$jscomp$197_rect$jscomp$8$$.right,$APP.$cljs$cst$1563$bottom$$,$node$jscomp$197_rect$jscomp$8$$.bottom,$APP.$cljs$cst$290$width$$,
$node$jscomp$197_rect$jscomp$8$$.width,$APP.$cljs$cst$1522$height$$,$node$jscomp$197_rect$jscomp$8$$.height],null)};
$app$util$dom$is_bounding_rect_outside_QMARK_$$=function($left$jscomp$13_p__46512$$,$p__46513_width$jscomp$46$$){var $bottom$jscomp$1_map__46514__$1$$=$APP.$cljs$core$__destructure_map$$($left$jscomp$13_p__46512$$);$left$jscomp$13_p__46512$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$1_map__46514__$1$$,$APP.$cljs$cst$257$left$$);var $top$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$1_map__46514__$1$$,$APP.$cljs$cst$1562$top$$),$right$jscomp$13$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$1_map__46514__$1$$,$APP.$cljs$cst$258$right$$);$bottom$jscomp$1_map__46514__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$1_map__46514__$1$$,$APP.$cljs$cst$1563$bottom$$);var $height$jscomp$38_map__46515__$1$$=$APP.$cljs$core$__destructure_map$$($p__46513_width$jscomp$46$$);$p__46513_width$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$38_map__46515__$1$$,$APP.$cljs$cst$290$width$$);
$height$jscomp$38_map__46515__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$38_map__46515__$1$$,$APP.$cljs$cst$1522$height$$);return $left$jscomp$13_p__46512$$<0||$top$jscomp$4$$<0||$right$jscomp$13$$>$p__46513_width$jscomp$46$$||$bottom$jscomp$1_map__46514__$1$$>$height$jscomp$38_map__46515__$1$$};
$APP.$app$util$dom$is_element_outside_QMARK_$$=function($element$jscomp$41$$){return $app$util$dom$is_bounding_rect_outside_QMARK_$$($APP.$app$util$dom$get_bounding_rect$$($element$jscomp$41$$),$APP.$app$util$dom$get_window_size$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$app$util$dom$get_window_size$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$app$util$dom$get_window_size$$())};
$APP.$app$util$dom$get_window_size$$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,window.innerWidth,$APP.$cljs$cst$1522$height$$,window.innerHeight],null)};$APP.$app$util$dom$focus_BANG_$$=function($node$jscomp$199$$){return $node$jscomp$199$$!=null?$node$jscomp$199$$.focus():null};$APP.$app$util$dom$click$$=function($node$jscomp$200$$){return $node$jscomp$200$$!=null?$node$jscomp$200$$.click():null};
$APP.$app$util$dom$blur_BANG_$$=function($node$jscomp$202$$){return $node$jscomp$202$$!=null?$node$jscomp$202$$.blur():null};$APP.$app$util$dom$set_property_BANG_$$=function($node$jscomp$204$$,$property$jscomp$23$$,$value$jscomp$370$$){$node$jscomp$204$$!=null&&$node$jscomp$204$$.setAttribute($property$jscomp$23$$,$value$jscomp$370$$);return $node$jscomp$204$$};$APP.$app$util$dom$get_text$$=function($node$jscomp$205$$){return $node$jscomp$205$$!=null?$node$jscomp$205$$.textContent:null};
$APP.$app$util$dom$set_text_BANG_$$=function($node$jscomp$206$$,$text$jscomp$18$$){$node$jscomp$206$$!=null&&($node$jscomp$206$$.textContent=$text$jscomp$18$$);return $node$jscomp$206$$};$APP.$app$util$dom$set_css_property_BANG_$$=function($node$jscomp$207$$,$property$jscomp$24$$,$value$jscomp$371$$){$node$jscomp$207$$!=null&&$node$jscomp$207$$.style.setProperty($property$jscomp$24$$,$value$jscomp$371$$);return $node$jscomp$207$$};
$APP.$app$util$dom$capture_pointer$$=function($event$jscomp$33$$){return $event$jscomp$33$$!=null?$APP.$app$util$dom$get_target$$($event$jscomp$33$$).setPointerCapture($event$jscomp$33$$.pointerId):null};$APP.$app$util$dom$release_pointer$$=function($event$jscomp$34$$){var $and__5023__auto__$jscomp$inline_4558$$=$event$jscomp$34$$!=null;$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_4558$$?$event$jscomp$34$$.pointerId:$and__5023__auto__$jscomp$inline_4558$$)&&$APP.$app$util$dom$get_target$$($event$jscomp$34$$).releasePointerCapture($event$jscomp$34$$.pointerId)};
$APP.$app$util$dom$classnames$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($params$jscomp$89$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$85$$,$p__46557_v$jscomp$496$$){var $k$jscomp$574$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46557_v$jscomp$496$$,0,null);$p__46557_v$jscomp$496$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46557_v$jscomp$496$$,
1,null);return $APP.$cljs$core$boolean$0$$($p__46557_v$jscomp$496$$)===!0?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$85$$,$APP.$app$common$data$name$$($k$jscomp$574$$)):$acc$jscomp$85$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$partition$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$89$$)))};
$APP.$app$util$dom$class_QMARK_$$=function($node$jscomp$210$$,$class_name$$){return $node$jscomp$210$$!=null?$node$jscomp$210$$.classList.contains($class_name$$):null};$APP.$app$util$dom$add_class_BANG_$$=function($node$jscomp$211$$,$class_name$jscomp$1$$){$node$jscomp$211$$!=null&&$node$jscomp$211$$.classList.add($class_name$jscomp$1$$);return $node$jscomp$211$$};
$APP.$app$util$dom$child_QMARK_$$=function($node1$jscomp$2$$,$node2$jscomp$2$$){return $node1$jscomp$2$$!=null&&$node2$jscomp$2$$!=null?$node2$jscomp$2$$.contains($node1$jscomp$2$$):null};$APP.$app$util$dom$get_data$$=function($node$jscomp$214$$,$attr$jscomp$1$$){return $node$jscomp$214$$!=null?$node$jscomp$214$$.getAttribute("data-"+($attr$jscomp$1$$??"")):null};
$app$util$dom$get_boolean_data$$=function($G__46602_G__46602__$1_node$jscomp$215$$){$G__46602_G__46602__$1_node$jscomp$215$$=$G__46602_G__46602__$1_node$jscomp$215$$ instanceof Element?$G__46602_G__46602__$1_node$jscomp$215$$:$APP.$app$util$dom$get_current_target$$($G__46602_G__46602__$1_node$jscomp$215$$);$G__46602_G__46602__$1_node$jscomp$215$$=$G__46602_G__46602__$1_node$jscomp$215$$==null?null:$APP.$app$util$dom$get_data$$($G__46602_G__46602__$1_node$jscomp$215$$,"active");return $G__46602_G__46602__$1_node$jscomp$215$$==
null?null:$APP.$cljs$core$parse_boolean$$($G__46602_G__46602__$1_node$jscomp$215$$)};$APP.$app$util$dom$set_data_BANG_$$=function($node$jscomp$216$$,$attr$jscomp$3$$,$value$jscomp$372$$){$node$jscomp$216$$!=null&&$node$jscomp$216$$.setAttribute("data-"+($attr$jscomp$3$$??""),""+($value$jscomp$372$$??""));return $node$jscomp$216$$};
$APP.$app$util$dom$set_attribute_BANG_$$=function($node$jscomp$217$$,$attr$jscomp$4$$,$value$jscomp$373$$){return $node$jscomp$217$$!=null?$node$jscomp$217$$.setAttribute($attr$jscomp$4$$,$value$jscomp$373$$):null};$APP.$app$util$dom$remove_attribute_BANG_$$=function($node$jscomp$219$$,$attr$jscomp$5$$){return $node$jscomp$219$$!=null?$node$jscomp$219$$.removeAttribute($attr$jscomp$5$$):null};
$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($element$jscomp$52$$,$options$jscomp$420$$){return $element$jscomp$52$$!=null?$element$jscomp$52$$.scrollIntoViewIfNeeded($options$jscomp$420$$):null};
$APP.$app$util$dom$trigger_download_uri$$=function($filename$jscomp$3_filename__$1$$,$extension_mtype$jscomp$4$$,$uri$jscomp$55$$){var $link$jscomp$1$$=$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("a");$extension_mtype$jscomp$4$$=$app$common$media$mtype__GT_extension$$($extension_mtype$jscomp$4$$);$filename$jscomp$3_filename__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($extension_mtype$jscomp$4$$)?!$APP.$cuerdas$core$ends_with_QMARK_$$($filename$jscomp$3_filename__$1$$,
$extension_mtype$jscomp$4$$):$extension_mtype$jscomp$4$$)?""+($filename$jscomp$3_filename__$1$$??"")+($extension_mtype$jscomp$4$$??""):$filename$jscomp$3_filename__$1$$;$APP.$app$util$object$set_BANG_$$($link$jscomp$1$$,"href",$uri$jscomp$55$$);$APP.$app$util$object$set_BANG_$$($link$jscomp$1$$,"download",$filename$jscomp$3_filename__$1$$);$APP.$app$util$object$set_BANG_$$($link$jscomp$1$$.style,"display","none");document.body.appendChild($link$jscomp$1$$);$link$jscomp$1$$.click();return $link$jscomp$1$$.remove()};
$APP.$app$util$dom$trigger_download$$=function($filename$jscomp$4$$,$blob$jscomp$16$$){var $uri$jscomp$56$$=$APP.$app$util$webapi$create_uri$$($blob$jscomp$16$$);try{return $APP.$app$util$dom$trigger_download_uri$$($filename$jscomp$4$$,$blob$jscomp$16$$.type,$uri$jscomp$56$$)}finally{$APP.$app$util$webapi$revoke_uri$$($uri$jscomp$56$$)}};
$APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$=function($uri$jscomp$58$$){return $app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$03$$($uri$jscomp$58$$,"_blank","noopener,noreferrer")};
$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$03$$=function($temp__5825__auto__$jscomp$108_uri$jscomp$60$$,$name$jscomp$160_temp__5825__auto____$1$jscomp$3$$,$features__$1$$){$temp__5825__auto__$jscomp$108_uri$jscomp$60$$=window.open($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto__$jscomp$108_uri$jscomp$60$$),$name$jscomp$160_temp__5825__auto____$1$jscomp$3$$,$features__$1$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$108_uri$jscomp$60$$)&&
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$160_temp__5825__auto____$1$jscomp$3$$,"_blank")?($name$jscomp$160_temp__5825__auto____$1$jscomp$3$$=$temp__5825__auto__$jscomp$108_uri$jscomp$60$$.location,$APP.$cljs$core$truth_$$($name$jscomp$160_temp__5825__auto____$1$jscomp$3$$)?$name$jscomp$160_temp__5825__auto____$1$jscomp$3$$.reload():null):null};$app$util$dom$browser_back$$=function(){return window.history.back()};
$APP.$app$util$dom$is_child_QMARK_$$=function($node$jscomp$220$$,$candidate$jscomp$6$$){var $and__5023__auto__$jscomp$212_and__5023__auto____$1$jscomp$40$$=$node$jscomp$220$$!=null;return $and__5023__auto__$jscomp$212_and__5023__auto____$1$jscomp$40$$?($and__5023__auto__$jscomp$212_and__5023__auto____$1$jscomp$40$$=$candidate$jscomp$6$$!=null)?$node$jscomp$220$$.contains($candidate$jscomp$6$$):$and__5023__auto__$jscomp$212_and__5023__auto____$1$jscomp$40$$:$and__5023__auto__$jscomp$212_and__5023__auto____$1$jscomp$40$$};
$app$util$dom$seq_nodes$$=function($root_node$$){function $get_children$$($node$jscomp$222$$){return $APP.$cljs$core$seq$$($node$jscomp$222$$.children)}return $APP.$cljs$core$tree_seq$$(function($node$jscomp$221$$){return $APP.$app$common$data$not_empty_QMARK_$$($get_children$$($node$jscomp$221$$))},$get_children$$,$root_node$$)};
$app$util$cache$with_cache$$=function($map__43596__$1_max_age_p__43595$$,$observable$$){$map__43596__$1_max_age_p__43595$$=$APP.$cljs$core$__destructure_map$$($map__43596__$1_max_age_p__43595$$);var $key$jscomp$281$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__43596__$1_max_age_p__43595$$,$APP.$cljs$cst$302$key$$);$map__43596__$1_max_age_p__43595$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__43596__$1_max_age_p__43595$$,$cljs$cst$1568$max_age$$);var $entry$jscomp$32$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($app$util$cache$cache$$),$key$jscomp$281$$),$pending_entry$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($app$util$cache$pending$$),$key$jscomp$281$$),$age$$=$APP.$cljs$core$truth_$$($entry$jscomp$32$$)?$APP.$app$common$time$diff_ms$$($APP.$cljs$cst$1569$created_at$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$32$$)):null;if($entry$jscomp$32$$!=null&&$age$$<$map__43596__$1_max_age_p__43595$$)return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$32$$));
if($pending_entry$$!=null)return $pending_entry$$;var $subject$$=$APP.$beicon$v2$core$subject$$();$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$util$cache$pending$$,$APP.$cljs$core$assoc$$,$key$jscomp$281$$,$subject$$);$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$03$$($observable$$,function($data$jscomp$119$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$util$cache$cache$$,$APP.$cljs$core$assoc$$,$key$jscomp$281$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1569$created_at$$,$APP.$app$common$time$now$$(),$APP.$cljs$cst$142$data$$,$data$jscomp$119$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$util$cache$pending$$,$APP.$cljs$core$dissoc$$,$key$jscomp$281$$);$subject$$.next($data$jscomp$119$$);return $subject$$.complete()},function($p1__43594_SHARP_$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$util$cache$pending$$,$APP.$cljs$core$dissoc$$,$key$jscomp$281$$);return $subject$$.error($p1__43594_SHARP_$$)});
return $subject$$};$goog$module$BaseModule$$=function(){$goog$Disposable$$.call(this)};$goog$module$ModuleLoadCallback$$=function($fn$jscomp$28$$,$opt_handler$$){this.$fn_$=$fn$jscomp$28$$;this.$handler_$=$opt_handler$$};$goog$module$ModuleInfo$$=function($deps$jscomp$2$$,$id$jscomp$48$$){$goog$Disposable$$.call(this);this.$deps_$=$deps$jscomp$2$$;this.$id_$=$id$jscomp$48$$;this.$onloadCallbacks_$=[];this.$onErrorCallbacks_$=[];this.$earlyOnloadCallbacks_$=[]};
$JSCompiler_StaticMethods_registerErrback$$=function($JSCompiler_StaticMethods_registerErrback$self$$,$fn$jscomp$31$$){$JSCompiler_StaticMethods_registerErrback$self$$.$registerCallback_$($JSCompiler_StaticMethods_registerErrback$self$$.$onErrorCallbacks_$,$fn$jscomp$31$$)};
$JSCompiler_StaticMethods_callCallbacks_$$=function($callbacks$jscomp$2$$,$context$jscomp$21$$){for(var $errors$jscomp$13$$=[],$i$jscomp$437$$=0;$i$jscomp$437$$<$callbacks$jscomp$2$$.length;$i$jscomp$437$$++)try{$callbacks$jscomp$2$$[$i$jscomp$437$$].$execute$($context$jscomp$21$$)}catch($e$jscomp$248$$){$module$contents$goog$async$throwException_throwException$$($e$jscomp$248$$),$errors$jscomp$13$$.push($e$jscomp$248$$)}$callbacks$jscomp$2$$.length=0;return $errors$jscomp$13$$.length?$errors$jscomp$13$$:
null};$goog$loader$AbstractModuleManager$$=function(){this.$loader_$=this.$moduleContext_$=null};$JSCompiler_StaticMethods_getEffectiveLevel$$=function($JSCompiler_StaticMethods_getEffectiveLevel$self$$){return $JSCompiler_StaticMethods_getEffectiveLevel$self$$.level?$JSCompiler_StaticMethods_getEffectiveLevel$self$$.level:$JSCompiler_StaticMethods_getEffectiveLevel$self$$.parent?$JSCompiler_StaticMethods_getEffectiveLevel$$($JSCompiler_StaticMethods_getEffectiveLevel$self$$.parent):$goog$log$log$classdecl$var0$OFF$$};
$JSCompiler_StaticMethods_getLogRegistryEntry$$=function($JSCompiler_StaticMethods_getLogRegistryEntry$self$$,$name$jscomp$167$$){var $entry$jscomp$33_lastDotIndex_parentLogRegistryEntry$$=$JSCompiler_StaticMethods_getLogRegistryEntry$self$$.entries[$name$jscomp$167$$];if($entry$jscomp$33_lastDotIndex_parentLogRegistryEntry$$)return $entry$jscomp$33_lastDotIndex_parentLogRegistryEntry$$;$entry$jscomp$33_lastDotIndex_parentLogRegistryEntry$$=$name$jscomp$167$$.lastIndexOf(".");$entry$jscomp$33_lastDotIndex_parentLogRegistryEntry$$=
$JSCompiler_StaticMethods_getLogRegistryEntry$$($JSCompiler_StaticMethods_getLogRegistryEntry$self$$,$name$jscomp$167$$.slice(0,Math.max($entry$jscomp$33_lastDotIndex_parentLogRegistryEntry$$,0)));const $logRegistryEntry$$=new $goog$log$log$classdecl$var4$$($name$jscomp$167$$,$entry$jscomp$33_lastDotIndex_parentLogRegistryEntry$$);$JSCompiler_StaticMethods_getLogRegistryEntry$self$$.entries[$name$jscomp$167$$]=$logRegistryEntry$$;$entry$jscomp$33_lastDotIndex_parentLogRegistryEntry$$.children.push($logRegistryEntry$$);
return $logRegistryEntry$$};$goog$log$log$classdecl$var5$getInstance$$=function(){$goog$log$log$classdecl$var5$instance_$$||($goog$log$log$classdecl$var5$instance_$$=new $goog$log$log$classdecl$var5$$);return $goog$log$log$classdecl$var5$instance_$$};$goog$log$getLogger$$=function($name$jscomp$168$$){return $JSCompiler_StaticMethods_getLogRegistryEntry$$($goog$log$log$classdecl$var5$getInstance$$(),$name$jscomp$168$$).$logger$};
$goog$log$log$$=function($JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$,$level$jscomp$51_level$jscomp$inline_4562$$,$msg$jscomp$14_msg$jscomp$inline_4563$$){var $JSCompiler_temp$jscomp$10739_JSCompiler_temp$jscomp$10740_JSCompiler_temp_const$jscomp$10741_loggerEntry$jscomp$8$$;if($JSCompiler_temp$jscomp$10739_JSCompiler_temp$jscomp$10740_JSCompiler_temp_const$jscomp$10741_loggerEntry$jscomp$8$$=$JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$)if($JSCompiler_temp$jscomp$10739_JSCompiler_temp$jscomp$10740_JSCompiler_temp_const$jscomp$10741_loggerEntry$jscomp$8$$=
$JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$&&$level$jscomp$51_level$jscomp$inline_4562$$){$JSCompiler_temp$jscomp$10739_JSCompiler_temp$jscomp$10740_JSCompiler_temp_const$jscomp$10741_loggerEntry$jscomp$8$$=$level$jscomp$51_level$jscomp$inline_4562$$.value;var $JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$=$JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$?$JSCompiler_StaticMethods_getEffectiveLevel$$($JSCompiler_StaticMethods_getLogRegistryEntry$$($goog$log$log$classdecl$var5$getInstance$$(),
$JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$.$getName$())):$goog$log$log$classdecl$var0$OFF$$;$JSCompiler_temp$jscomp$10739_JSCompiler_temp$jscomp$10740_JSCompiler_temp_const$jscomp$10741_loggerEntry$jscomp$8$$=$JSCompiler_temp$jscomp$10739_JSCompiler_temp$jscomp$10740_JSCompiler_temp_const$jscomp$10741_loggerEntry$jscomp$8$$>=$JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$.value}if($JSCompiler_temp$jscomp$10739_JSCompiler_temp$jscomp$10740_JSCompiler_temp_const$jscomp$10741_loggerEntry$jscomp$8$$){$level$jscomp$51_level$jscomp$inline_4562$$=
$level$jscomp$51_level$jscomp$inline_4562$$||$goog$log$log$classdecl$var0$OFF$$;$JSCompiler_temp$jscomp$10739_JSCompiler_temp$jscomp$10740_JSCompiler_temp_const$jscomp$10741_loggerEntry$jscomp$8$$=$JSCompiler_StaticMethods_getLogRegistryEntry$$($goog$log$log$classdecl$var5$getInstance$$(),$JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$.$getName$());typeof $msg$jscomp$14_msg$jscomp$inline_4563$$==="function"&&($msg$jscomp$14_msg$jscomp$inline_4563$$=$msg$jscomp$14_msg$jscomp$inline_4563$$());
$goog$log$log$classdecl$var2$instance_$$||($goog$log$log$classdecl$var2$instance_$$=new $goog$log$log$classdecl$var2$$);$JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$=$goog$log$log$classdecl$var2$instance_$$;$JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$=$JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$.$getName$();if($JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$.$capacity_$>
0){var $curIndex$jscomp$inline_4565$$=($JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$.$curIndex_$+1)%$JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$.$capacity_$;$JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$.$curIndex_$=$curIndex$jscomp$inline_4565$$;$JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$.$isFull_$?
($JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$=$JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$.$buffer_$[$curIndex$jscomp$inline_4565$$],$JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$.reset($level$jscomp$51_level$jscomp$inline_4562$$,$msg$jscomp$14_msg$jscomp$inline_4563$$,$JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$),
$JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$=$JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$):($JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$.$isFull_$=$curIndex$jscomp$inline_4565$$==$JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$.$capacity_$-1,$JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$=
$JSCompiler_inline_result$jscomp$10742_JSCompiler_inline_result$jscomp$668_ret$jscomp$inline_4566$$.$buffer_$[$curIndex$jscomp$inline_4565$$]=new $goog$log$log$classdecl$var3$$($level$jscomp$51_level$jscomp$inline_4562$$,$msg$jscomp$14_msg$jscomp$inline_4563$$,$JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$))}else $JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$=new $goog$log$log$classdecl$var3$$($level$jscomp$51_level$jscomp$inline_4562$$,
$msg$jscomp$14_msg$jscomp$inline_4563$$,$JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$);$JSCompiler_temp$jscomp$10739_JSCompiler_temp$jscomp$10740_JSCompiler_temp_const$jscomp$10741_loggerEntry$jscomp$8$$.publish($JSCompiler_inline_result$jscomp$667_logger$jscomp$14_loggerName$jscomp$inline_4564$$)}};
$goog$log$error$$=function($logger$jscomp$15$$,$msg$jscomp$15$$){$logger$jscomp$15$$&&$goog$log$log$$($logger$jscomp$15$$,$goog$log$log$classdecl$var0$SEVERE$$,$msg$jscomp$15$$)};$goog$log$info$$=function($logger$jscomp$17$$,$msg$jscomp$17$$){$logger$jscomp$17$$&&$goog$log$log$$($logger$jscomp$17$$,$goog$log$log$classdecl$var0$INFO$$,$msg$jscomp$17$$)};
$goog$log$fine$$=function($logger$jscomp$18$$,$msg$jscomp$18$$){$logger$jscomp$18$$&&$goog$log$log$$($logger$jscomp$18$$,$goog$log$log$classdecl$var0$FINE$$,$msg$jscomp$18$$)};
$JSCompiler_StaticMethods_getReadableError_$$=function($JSCompiler_StaticMethods_getReadableError_$self$$){switch($JSCompiler_StaticMethods_getReadableError_$self$$.type){case $module$contents$goog$module$ModuleLoadFailure_ModuleLoadFailure$$.$Type$.$UNAUTHORIZED$:return"Unauthorized";case $module$contents$goog$module$ModuleLoadFailure_ModuleLoadFailure$$.$Type$.$CONSECUTIVE_FAILURES$:return"Consecutive load failures";case $module$contents$goog$module$ModuleLoadFailure_ModuleLoadFailure$$.$Type$.TIMEOUT:return"Timed out";
case $module$contents$goog$module$ModuleLoadFailure_ModuleLoadFailure$$.$Type$.$OLD_CODE_GONE$:return"Out of date module id";case $module$contents$goog$module$ModuleLoadFailure_ModuleLoadFailure$$.$Type$.$INIT_ERROR$:return"Init error";default:return`Unknown failure type ${$JSCompiler_StaticMethods_getReadableError_$self$$.type}`}};
$goog$module$ModuleManager$$=function(){$goog$loader$AbstractModuleManager$$.call(this);this.$moduleInfoMap$={};this.$loadingModuleIds_$=[];this.$requestedLoadingModuleIds_$=[];this.$requestedModuleIds_$=[];this.$requestedModuleIdsQueue_$=[];this.$userInitiatedLoadingModuleIds_$=[];this.$extraEdges_$={};this.$callbackMap_$={};this.$baseModuleInfo_$=new $goog$module$ModuleInfo$$([],"");this.$initialModulesLoaded_$=new $goog$async$Deferred$$;this.$logger_$=$goog$log$getLogger$$("goog.module.ModuleManager");
this.$concurrentLoadingEnabled_$=this.$batchModeEnabled_$=!1;this.$consecutiveFailures_$=0;this.$isDisposed_$=this.$userLastActive_$=this.$lastActive_$=!1};$goog$module$ModuleManager$ModuleFailureError$$=function($moduleID$$,$failureType$$){$module$contents$goog$debug$Error_DebugError$$.call(this,`Error loading ${$moduleID$$}: ${$failureType$$}`)};
$JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$$=function($JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$self$$){var $lastActive_userActive$$=$JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$self$$.$lastActive_$,$active$$=$JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$self$$.isActive();$active$$!=$lastActive_userActive$$&&($JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$self$$.$executeCallbacks_$($active$$?"active":"idle"),$JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$self$$.$lastActive_$=
$active$$);$lastActive_userActive$$=$JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$self$$.$isUserActive$();$lastActive_userActive$$!=$JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$self$$.$userLastActive_$&&($JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$self$$.$executeCallbacks_$($lastActive_userActive$$?"userActive":"userIdle"),$JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$self$$.$userLastActive_$=$lastActive_userActive$$)};
$JSCompiler_StaticMethods_registerModuleLoadCallbacks_$$=function($JSCompiler_StaticMethods_registerModuleLoadCallbacks_$self$$,$id$jscomp$64$$,$moduleInfo$jscomp$4$$,$userInitiated$$,$d$jscomp$206$$){$moduleInfo$jscomp$4$$.$registerCallback$($d$jscomp$206$$.callback,$d$jscomp$206$$);$JSCompiler_StaticMethods_registerErrback$$($moduleInfo$jscomp$4$$,function($err$jscomp$27$$){$d$jscomp$206$$.errback(new $goog$module$ModuleManager$ModuleFailureError$$($id$jscomp$64$$,$err$jscomp$27$$))});$JSCompiler_StaticMethods_isModuleLoading$$($JSCompiler_StaticMethods_registerModuleLoadCallbacks_$self$$,
$id$jscomp$64$$)?$userInitiated$$&&($goog$log$fine$$($JSCompiler_StaticMethods_registerModuleLoadCallbacks_$self$$.$logger_$,"User initiated module already loading: "+$id$jscomp$64$$),$JSCompiler_StaticMethods_addUserInitiatedLoadingModule_$$($JSCompiler_StaticMethods_registerModuleLoadCallbacks_$self$$,$id$jscomp$64$$),$JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$$($JSCompiler_StaticMethods_registerModuleLoadCallbacks_$self$$)):$userInitiated$$?($goog$log$fine$$($JSCompiler_StaticMethods_registerModuleLoadCallbacks_$self$$.$logger_$,
"User initiated module load: "+$id$jscomp$64$$),$JSCompiler_StaticMethods_addUserInitiatedLoadingModule_$$($JSCompiler_StaticMethods_registerModuleLoadCallbacks_$self$$,$id$jscomp$64$$)):$goog$log$fine$$($JSCompiler_StaticMethods_registerModuleLoadCallbacks_$self$$.$logger_$,"Initiating module load: "+$id$jscomp$64$$)};
$JSCompiler_StaticMethods_processModulesForLoad_$$=function($JSCompiler_StaticMethods_processModulesForLoad_$self$$,$ids$jscomp$4$$){$ids$jscomp$4$$=$ids$jscomp$4$$.filter($id$jscomp$65$$=>$JSCompiler_StaticMethods_processModulesForLoad_$self$$.$moduleInfoMap$[$id$jscomp$65$$].isLoaded()?($APP.$goog$global$$.setTimeout(()=>Error("Module already loaded: "+$id$jscomp$65$$),0),!1):!0);for(var $idsWithDeps$$=[],$i$jscomp$444_idToLoad$$=0;$i$jscomp$444_idToLoad$$<$ids$jscomp$4$$.length;$i$jscomp$444_idToLoad$$++)$idsWithDeps$$=
$idsWithDeps$$.concat($JSCompiler_StaticMethods_getNotYetLoadedTransitiveDepIds_$$($JSCompiler_StaticMethods_processModulesForLoad_$self$$,$ids$jscomp$4$$[$i$jscomp$444_idToLoad$$]));$module$contents$goog$array_removeDuplicates$$($idsWithDeps$$);return!$JSCompiler_StaticMethods_processModulesForLoad_$self$$.$batchModeEnabled_$&&$idsWithDeps$$.length>1?($i$jscomp$444_idToLoad$$=$idsWithDeps$$.shift(),$goog$log$fine$$($JSCompiler_StaticMethods_processModulesForLoad_$self$$.$logger_$,"Must load "+$i$jscomp$444_idToLoad$$+
" module before "+$ids$jscomp$4$$),$JSCompiler_StaticMethods_processModulesForLoad_$self$$.$requestedModuleIdsQueue_$=$idsWithDeps$$.map(function($id$jscomp$66$$){return[$id$jscomp$66$$]}).concat($JSCompiler_StaticMethods_processModulesForLoad_$self$$.$requestedModuleIdsQueue_$),[$i$jscomp$444_idToLoad$$]):$idsWithDeps$$};
$JSCompiler_StaticMethods_getNotYetLoadedTransitiveDepIds_$$=function($JSCompiler_StaticMethods_getNotYetLoadedTransitiveDepIds_$self$$,$depIdLookupList_id$jscomp$67$$){var $requestedModuleSet$$=$module$contents$goog$object_createSet$$($JSCompiler_StaticMethods_getNotYetLoadedTransitiveDepIds_$self$$.$requestedModuleIds_$),$ids$jscomp$5$$=[];$requestedModuleSet$$[$depIdLookupList_id$jscomp$67$$]||$ids$jscomp$5$$.push($depIdLookupList_id$jscomp$67$$);$depIdLookupList_id$jscomp$67$$=[$depIdLookupList_id$jscomp$67$$];
for(var $i$jscomp$445$$=0;$i$jscomp$445$$<$depIdLookupList_id$jscomp$67$$.length;$i$jscomp$445$$++)for(var $depIds$$=$JSCompiler_StaticMethods_getNotYetLoadedTransitiveDepIds_$self$$.$moduleInfoMap$[$depIdLookupList_id$jscomp$67$$[$i$jscomp$445$$]].$deps_$,$j$jscomp$110$$=$depIds$$.length-1;$j$jscomp$110$$>=0;$j$jscomp$110$$--){var $depId$$=$depIds$$[$j$jscomp$110$$];$JSCompiler_StaticMethods_getNotYetLoadedTransitiveDepIds_$self$$.$moduleInfoMap$[$depId$$].isLoaded()||$requestedModuleSet$$[$depId$$]||
($ids$jscomp$5$$.push($depId$$),$depIdLookupList_id$jscomp$67$$.push($depId$$))}$ids$jscomp$5$$.reverse();$module$contents$goog$array_removeDuplicates$$($ids$jscomp$5$$);return $ids$jscomp$5$$};
$JSCompiler_StaticMethods_isModuleLoading$$=function($JSCompiler_StaticMethods_isModuleLoading$self$$,$id$jscomp$69$$){if($module$contents$goog$array_indexOf$$($JSCompiler_StaticMethods_isModuleLoading$self$$.$loadingModuleIds_$,$id$jscomp$69$$)>=0)return!0;for(var $i$jscomp$446$$=0;$i$jscomp$446$$<$JSCompiler_StaticMethods_isModuleLoading$self$$.$requestedModuleIdsQueue_$.length;$i$jscomp$446$$++)if($module$contents$goog$array_indexOf$$($JSCompiler_StaticMethods_isModuleLoading$self$$.$requestedModuleIdsQueue_$[$i$jscomp$446$$],$id$jscomp$69$$)>=
0)return!0;return!1};$JSCompiler_StaticMethods_addUserInitiatedLoadingModule_$$=function($JSCompiler_StaticMethods_addUserInitiatedLoadingModule_$self$$,$id$jscomp$70$$){$module$contents$goog$array_indexOf$$($JSCompiler_StaticMethods_addUserInitiatedLoadingModule_$self$$.$userInitiatedLoadingModuleIds_$,$id$jscomp$70$$)>=0||$JSCompiler_StaticMethods_addUserInitiatedLoadingModule_$self$$.$userInitiatedLoadingModuleIds_$.push($id$jscomp$70$$)};
$JSCompiler_StaticMethods_requeueBatchOrDispatchFailure_$$=function($JSCompiler_StaticMethods_requeueBatchOrDispatchFailure_$self$$,$cause$jscomp$28$$){$JSCompiler_StaticMethods_requeueBatchOrDispatchFailure_$self$$.$requestedLoadingModuleIds_$.length>1?$JSCompiler_StaticMethods_requeueBatchOrDispatchFailure_$self$$.$requestedModuleIdsQueue_$=$JSCompiler_StaticMethods_requeueBatchOrDispatchFailure_$self$$.$requestedLoadingModuleIds_$.map(function($id$jscomp$72$$){return[$id$jscomp$72$$]}).concat($JSCompiler_StaticMethods_requeueBatchOrDispatchFailure_$self$$.$requestedModuleIdsQueue_$):
$JSCompiler_StaticMethods_dispatchModuleLoadFailed_$$($JSCompiler_StaticMethods_requeueBatchOrDispatchFailure_$self$$,$cause$jscomp$28$$)};
$JSCompiler_StaticMethods_dispatchModuleLoadFailed_$$=function($JSCompiler_StaticMethods_dispatchModuleLoadFailed_$self$$,$cause$jscomp$29$$){var $failedIds$$=$JSCompiler_StaticMethods_dispatchModuleLoadFailed_$self$$.$requestedLoadingModuleIds_$;$JSCompiler_StaticMethods_dispatchModuleLoadFailed_$self$$.$loadingModuleIds_$.length=0;for(var $idsToCancel$$=[],$i$jscomp$447$$=0;$i$jscomp$447$$<$JSCompiler_StaticMethods_dispatchModuleLoadFailed_$self$$.$requestedModuleIdsQueue_$.length;$i$jscomp$447$$++){var $dependentModules_j$jscomp$111$$=
$JSCompiler_StaticMethods_dispatchModuleLoadFailed_$self$$.$requestedModuleIdsQueue_$[$i$jscomp$447$$].filter(function($requestedId$$){var $requestedDeps$$=$JSCompiler_StaticMethods_getNotYetLoadedTransitiveDepIds_$$(this,$requestedId$$);return $module$contents$goog$array_some$$($failedIds$$,function($id$jscomp$73$$){return $module$contents$goog$array_indexOf$$($requestedDeps$$,$id$jscomp$73$$)>=0})},$JSCompiler_StaticMethods_dispatchModuleLoadFailed_$self$$);$module$contents$goog$array_extend$$($idsToCancel$$,
$dependentModules_j$jscomp$111$$)}for($i$jscomp$447$$=0;$i$jscomp$447$$<$failedIds$$.length;$i$jscomp$447$$++)$module$contents$goog$array_insert$$($idsToCancel$$,$failedIds$$[$i$jscomp$447$$]);for($i$jscomp$447$$=0;$i$jscomp$447$$<$idsToCancel$$.length;$i$jscomp$447$$++){for($dependentModules_j$jscomp$111$$=0;$dependentModules_j$jscomp$111$$<$JSCompiler_StaticMethods_dispatchModuleLoadFailed_$self$$.$requestedModuleIdsQueue_$.length;$dependentModules_j$jscomp$111$$++)$module$contents$goog$array_remove$$($JSCompiler_StaticMethods_dispatchModuleLoadFailed_$self$$.$requestedModuleIdsQueue_$[$dependentModules_j$jscomp$111$$],
$idsToCancel$$[$i$jscomp$447$$]);$module$contents$goog$array_remove$$($JSCompiler_StaticMethods_dispatchModuleLoadFailed_$self$$.$userInitiatedLoadingModuleIds_$,$idsToCancel$$[$i$jscomp$447$$])}var $errorCallbacks$$=$JSCompiler_StaticMethods_dispatchModuleLoadFailed_$self$$.$callbackMap_$.error;if($errorCallbacks$$)for($i$jscomp$447$$=0;$i$jscomp$447$$<$errorCallbacks$$.length;$i$jscomp$447$$++){var $callback$jscomp$80$$=$errorCallbacks$$[$i$jscomp$447$$];for($dependentModules_j$jscomp$111$$=0;$dependentModules_j$jscomp$111$$<
$idsToCancel$$.length;$dependentModules_j$jscomp$111$$++)$callback$jscomp$80$$("error",$idsToCancel$$[$dependentModules_j$jscomp$111$$],$cause$jscomp$29$$)}for($i$jscomp$447$$=0;$i$jscomp$447$$<$failedIds$$.length;$i$jscomp$447$$++)$JSCompiler_StaticMethods_dispatchModuleLoadFailed_$self$$.$moduleInfoMap$[$failedIds$$[$i$jscomp$447$$]]&&$JSCompiler_StaticMethods_dispatchModuleLoadFailed_$self$$.$moduleInfoMap$[$failedIds$$[$i$jscomp$447$$]].$onError$($cause$jscomp$29$$);$JSCompiler_StaticMethods_dispatchModuleLoadFailed_$self$$.$requestedLoadingModuleIds_$.length=
0;$JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$$($JSCompiler_StaticMethods_dispatchModuleLoadFailed_$self$$)};
$JSCompiler_StaticMethods_loadNextModules_$$=function($JSCompiler_StaticMethods_loadNextModules_$self$$){for(;$JSCompiler_StaticMethods_loadNextModules_$self$$.$requestedModuleIdsQueue_$.length;){var $nextIds$$=$JSCompiler_StaticMethods_loadNextModules_$self$$.$requestedModuleIdsQueue_$.shift().filter(function($id$jscomp$74$$){return!this.$moduleInfoMap$[$id$jscomp$74$$].isLoaded()},$JSCompiler_StaticMethods_loadNextModules_$self$$);if($nextIds$$.length>0){$JSCompiler_StaticMethods_loadNextModules_$self$$.$loadModules_$($nextIds$$);
return}}$JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$$($JSCompiler_StaticMethods_loadNextModules_$self$$)};$goog$events$Listenable$isImplementedBy$$=function($obj$jscomp$161$$){return!(!$obj$jscomp$161$$||!$obj$jscomp$161$$[$goog$events$Listenable$IMPLEMENTED_BY_PROP$$])};
$goog$events$Listener$$=function($listener$jscomp$74$$,$src$jscomp$14$$,$type$jscomp$275$$,$capture$jscomp$3$$,$opt_handler$jscomp$11$$){this.listener=$listener$jscomp$74$$;this.proxy=null;this.src=$src$jscomp$14$$;this.type=$type$jscomp$275$$;this.capture=!!$capture$jscomp$3$$;this.handler=$opt_handler$jscomp$11$$;this.key=++$goog$events$ListenableKey$counter_$$;this.$removed$=this.$callOnce$=!1};
$JSCompiler_StaticMethods_markAsRemoved$$=function($JSCompiler_StaticMethods_markAsRemoved$self$$){$JSCompiler_StaticMethods_markAsRemoved$self$$.$removed$=!0;$JSCompiler_StaticMethods_markAsRemoved$self$$.listener=null;$JSCompiler_StaticMethods_markAsRemoved$self$$.proxy=null;$JSCompiler_StaticMethods_markAsRemoved$self$$.src=null;$JSCompiler_StaticMethods_markAsRemoved$self$$.handler=null};
$goog$events$ListenerMap$$=function($src$jscomp$15$$){this.src=$src$jscomp$15$$;this.$listeners$={};this.$typeCount_$=0};
$JSCompiler_StaticMethods_removeByKey$$=function($JSCompiler_StaticMethods_removeByKey$self$$,$listener$jscomp$77$$){var $type$jscomp$279$$=$listener$jscomp$77$$.type;if(!($type$jscomp$279$$ in $JSCompiler_StaticMethods_removeByKey$self$$.$listeners$))return!1;var $removed$$=$module$contents$goog$array_remove$$($JSCompiler_StaticMethods_removeByKey$self$$.$listeners$[$type$jscomp$279$$],$listener$jscomp$77$$);$removed$$&&($JSCompiler_StaticMethods_markAsRemoved$$($listener$jscomp$77$$),$JSCompiler_StaticMethods_removeByKey$self$$.$listeners$[$type$jscomp$279$$].length==
0&&(delete $JSCompiler_StaticMethods_removeByKey$self$$.$listeners$[$type$jscomp$279$$],$JSCompiler_StaticMethods_removeByKey$self$$.$typeCount_$--));return $removed$$};
$goog$events$ListenerMap$findListenerIndex_$$=function($listenerArray$jscomp$6$$,$listener$jscomp$79$$,$opt_useCapture$jscomp$17$$,$opt_listenerScope$jscomp$7$$){for(var $i$jscomp$454$$=0;$i$jscomp$454$$<$listenerArray$jscomp$6$$.length;++$i$jscomp$454$$){var $listenerObj$jscomp$3$$=$listenerArray$jscomp$6$$[$i$jscomp$454$$];if(!$listenerObj$jscomp$3$$.$removed$&&$listenerObj$jscomp$3$$.listener==$listener$jscomp$79$$&&$listenerObj$jscomp$3$$.capture==!!$opt_useCapture$jscomp$17$$&&$listenerObj$jscomp$3$$.handler==
$opt_listenerScope$jscomp$7$$)return $i$jscomp$454$$}return-1};
$APP.$goog$events$listen$$=function($src$jscomp$16$$,$type$jscomp$284$$,$listener$jscomp$80$$,$opt_options$jscomp$94$$,$opt_handler$jscomp$12$$){if($opt_options$jscomp$94$$&&$opt_options$jscomp$94$$.once)return $goog$events$listenOnce$$($src$jscomp$16$$,$type$jscomp$284$$,$listener$jscomp$80$$,$opt_options$jscomp$94$$,$opt_handler$jscomp$12$$);if(Array.isArray($type$jscomp$284$$)){for(var $i$jscomp$455$$=0;$i$jscomp$455$$<$type$jscomp$284$$.length;$i$jscomp$455$$++)$APP.$goog$events$listen$$($src$jscomp$16$$,$type$jscomp$284$$[$i$jscomp$455$$],
$listener$jscomp$80$$,$opt_options$jscomp$94$$,$opt_handler$jscomp$12$$);return null}$listener$jscomp$80$$=$goog$events$wrapListener$$($listener$jscomp$80$$);return $goog$events$Listenable$isImplementedBy$$($src$jscomp$16$$)?$src$jscomp$16$$.$listen$($type$jscomp$284$$,$listener$jscomp$80$$,$goog$isObject$$($opt_options$jscomp$94$$)?!!$opt_options$jscomp$94$$.capture:!!$opt_options$jscomp$94$$,$opt_handler$jscomp$12$$):$goog$events$listen_$$($src$jscomp$16$$,$type$jscomp$284$$,$listener$jscomp$80$$,
!1,$opt_options$jscomp$94$$,$opt_handler$jscomp$12$$)};
$goog$events$listen_$$=function($src$jscomp$17$$,$type$jscomp$285$$,$listener$jscomp$81_listenerObj$jscomp$4$$,$callOnce$jscomp$1_proxy$jscomp$1$$,$opt_options$jscomp$95$$,$opt_handler$jscomp$13$$){if(!$type$jscomp$285$$)throw Error("Invalid event type");var $capture$jscomp$7$$=$goog$isObject$$($opt_options$jscomp$95$$)?!!$opt_options$jscomp$95$$.capture:!!$opt_options$jscomp$95$$,$listenerMap$$=$goog$events$getListenerMap_$$($src$jscomp$17$$);$listenerMap$$||($src$jscomp$17$$[$goog$events$LISTENER_MAP_PROP_$$]=
$listenerMap$$=new $goog$events$ListenerMap$$($src$jscomp$17$$));$listener$jscomp$81_listenerObj$jscomp$4$$=$listenerMap$$.add($type$jscomp$285$$,$listener$jscomp$81_listenerObj$jscomp$4$$,$callOnce$jscomp$1_proxy$jscomp$1$$,$capture$jscomp$7$$,$opt_handler$jscomp$13$$);if($listener$jscomp$81_listenerObj$jscomp$4$$.proxy)return $listener$jscomp$81_listenerObj$jscomp$4$$;$callOnce$jscomp$1_proxy$jscomp$1$$=$goog$events$getProxy$$();$listener$jscomp$81_listenerObj$jscomp$4$$.proxy=$callOnce$jscomp$1_proxy$jscomp$1$$;
$callOnce$jscomp$1_proxy$jscomp$1$$.src=$src$jscomp$17$$;$callOnce$jscomp$1_proxy$jscomp$1$$.listener=$listener$jscomp$81_listenerObj$jscomp$4$$;if($src$jscomp$17$$.addEventListener)$goog$events$BrowserFeature$PASSIVE_EVENTS$$||($opt_options$jscomp$95$$=$capture$jscomp$7$$),$opt_options$jscomp$95$$===void 0&&($opt_options$jscomp$95$$=!1),$src$jscomp$17$$.addEventListener($type$jscomp$285$$.toString(),$callOnce$jscomp$1_proxy$jscomp$1$$,$opt_options$jscomp$95$$);else if($src$jscomp$17$$.attachEvent)$src$jscomp$17$$.attachEvent($goog$events$getOnString_$$($type$jscomp$285$$.toString()),
$callOnce$jscomp$1_proxy$jscomp$1$$);else if($src$jscomp$17$$.addListener&&$src$jscomp$17$$.removeListener)$src$jscomp$17$$.addListener($callOnce$jscomp$1_proxy$jscomp$1$$);else throw Error("addEventListener and attachEvent are unavailable.");$goog$events$listenerCountEstimate_$$++;return $listener$jscomp$81_listenerObj$jscomp$4$$};
$goog$events$getProxy$$=function(){function $f$jscomp$717$$($eventObject$jscomp$1$$){return $proxyCallbackFunction$$.call($f$jscomp$717$$.src,$f$jscomp$717$$.listener,$eventObject$jscomp$1$$)}const $proxyCallbackFunction$$=$goog$events$handleBrowserEvent_$$;return $f$jscomp$717$$};
$goog$events$listenOnce$$=function($src$jscomp$18$$,$type$jscomp$286$$,$listener$jscomp$82$$,$opt_options$jscomp$96$$,$opt_handler$jscomp$14$$){if(Array.isArray($type$jscomp$286$$)){for(var $i$jscomp$456$$=0;$i$jscomp$456$$<$type$jscomp$286$$.length;$i$jscomp$456$$++)$goog$events$listenOnce$$($src$jscomp$18$$,$type$jscomp$286$$[$i$jscomp$456$$],$listener$jscomp$82$$,$opt_options$jscomp$96$$,$opt_handler$jscomp$14$$);return null}$listener$jscomp$82$$=$goog$events$wrapListener$$($listener$jscomp$82$$);
return $goog$events$Listenable$isImplementedBy$$($src$jscomp$18$$)?$src$jscomp$18$$.$listenOnce$($type$jscomp$286$$,$listener$jscomp$82$$,$goog$isObject$$($opt_options$jscomp$96$$)?!!$opt_options$jscomp$96$$.capture:!!$opt_options$jscomp$96$$,$opt_handler$jscomp$14$$):$goog$events$listen_$$($src$jscomp$18$$,$type$jscomp$286$$,$listener$jscomp$82$$,!0,$opt_options$jscomp$96$$,$opt_handler$jscomp$14$$)};
$APP.$goog$events$unlisten$$=function($listenerMap$jscomp$1_src$jscomp$20$$,$listenerObj$jscomp$5_type$jscomp$287$$,$listener$jscomp$84$$,$capture$jscomp$9_opt_options$jscomp$97$$,$opt_handler$jscomp$16$$){if(Array.isArray($listenerObj$jscomp$5_type$jscomp$287$$))for(var $i$jscomp$457$$=0;$i$jscomp$457$$<$listenerObj$jscomp$5_type$jscomp$287$$.length;$i$jscomp$457$$++)$APP.$goog$events$unlisten$$($listenerMap$jscomp$1_src$jscomp$20$$,$listenerObj$jscomp$5_type$jscomp$287$$[$i$jscomp$457$$],$listener$jscomp$84$$,
$capture$jscomp$9_opt_options$jscomp$97$$,$opt_handler$jscomp$16$$);else $capture$jscomp$9_opt_options$jscomp$97$$=$goog$isObject$$($capture$jscomp$9_opt_options$jscomp$97$$)?!!$capture$jscomp$9_opt_options$jscomp$97$$.capture:!!$capture$jscomp$9_opt_options$jscomp$97$$,$listener$jscomp$84$$=$goog$events$wrapListener$$($listener$jscomp$84$$),$goog$events$Listenable$isImplementedBy$$($listenerMap$jscomp$1_src$jscomp$20$$)?$listenerMap$jscomp$1_src$jscomp$20$$.$unlisten$($listenerObj$jscomp$5_type$jscomp$287$$,
$listener$jscomp$84$$,$capture$jscomp$9_opt_options$jscomp$97$$,$opt_handler$jscomp$16$$):$listenerMap$jscomp$1_src$jscomp$20$$&&($listenerMap$jscomp$1_src$jscomp$20$$=$goog$events$getListenerMap_$$($listenerMap$jscomp$1_src$jscomp$20$$))&&($listenerObj$jscomp$5_type$jscomp$287$$=$listenerMap$jscomp$1_src$jscomp$20$$.$getListener$($listenerObj$jscomp$5_type$jscomp$287$$,$listener$jscomp$84$$,$capture$jscomp$9_opt_options$jscomp$97$$,$opt_handler$jscomp$16$$))&&$APP.$goog$events$unlistenByKey$$($listenerObj$jscomp$5_type$jscomp$287$$)};
$APP.$goog$events$unlistenByKey$$=function($key$jscomp$283$$){if(typeof $key$jscomp$283$$==="number"||!$key$jscomp$283$$||$key$jscomp$283$$.$removed$)return!1;var $src$jscomp$21$$=$key$jscomp$283$$.src;if($goog$events$Listenable$isImplementedBy$$($src$jscomp$21$$))return $JSCompiler_StaticMethods_removeByKey$$($src$jscomp$21$$.$eventTargetListeners_$,$key$jscomp$283$$);var $listenerMap$jscomp$2_type$jscomp$288$$=$key$jscomp$283$$.type,$proxy$jscomp$2$$=$key$jscomp$283$$.proxy;$src$jscomp$21$$.removeEventListener?
$src$jscomp$21$$.removeEventListener($listenerMap$jscomp$2_type$jscomp$288$$,$proxy$jscomp$2$$,$key$jscomp$283$$.capture):$src$jscomp$21$$.detachEvent?$src$jscomp$21$$.detachEvent($goog$events$getOnString_$$($listenerMap$jscomp$2_type$jscomp$288$$),$proxy$jscomp$2$$):$src$jscomp$21$$.addListener&&$src$jscomp$21$$.removeListener&&$src$jscomp$21$$.removeListener($proxy$jscomp$2$$);$goog$events$listenerCountEstimate_$$--;($listenerMap$jscomp$2_type$jscomp$288$$=$goog$events$getListenerMap_$$($src$jscomp$21$$))?
($JSCompiler_StaticMethods_removeByKey$$($listenerMap$jscomp$2_type$jscomp$288$$,$key$jscomp$283$$),$listenerMap$jscomp$2_type$jscomp$288$$.$typeCount_$==0&&($listenerMap$jscomp$2_type$jscomp$288$$.src=null,$src$jscomp$21$$[$goog$events$LISTENER_MAP_PROP_$$]=null)):$JSCompiler_StaticMethods_markAsRemoved$$($key$jscomp$283$$);return!0};
$goog$events$getOnString_$$=function($type$jscomp$292$$){return $type$jscomp$292$$ in $goog$events$onStringMap_$$?$goog$events$onStringMap_$$[$type$jscomp$292$$]:$goog$events$onStringMap_$$[$type$jscomp$292$$]="on"+$type$jscomp$292$$};
$goog$events$handleBrowserEvent_$$=function($JSCompiler_temp$jscomp$672_listener$jscomp$90$$,$eventObject$jscomp$inline_4591_opt_evt$$){if($JSCompiler_temp$jscomp$672_listener$jscomp$90$$.$removed$)$JSCompiler_temp$jscomp$672_listener$jscomp$90$$=!0;else{$eventObject$jscomp$inline_4591_opt_evt$$=new $APP.$goog$events$BrowserEvent$$($eventObject$jscomp$inline_4591_opt_evt$$,this);var $listenerFn$jscomp$inline_4592$$=$JSCompiler_temp$jscomp$672_listener$jscomp$90$$.listener,$listenerHandler$jscomp$inline_4593$$=
$JSCompiler_temp$jscomp$672_listener$jscomp$90$$.handler||$JSCompiler_temp$jscomp$672_listener$jscomp$90$$.src;$JSCompiler_temp$jscomp$672_listener$jscomp$90$$.$callOnce$&&$APP.$goog$events$unlistenByKey$$($JSCompiler_temp$jscomp$672_listener$jscomp$90$$);$JSCompiler_temp$jscomp$672_listener$jscomp$90$$=$listenerFn$jscomp$inline_4592$$.call($listenerHandler$jscomp$inline_4593$$,$eventObject$jscomp$inline_4591_opt_evt$$)}return $JSCompiler_temp$jscomp$672_listener$jscomp$90$$};
$goog$events$getListenerMap_$$=function($listenerMap$jscomp$8_src$jscomp$25$$){$listenerMap$jscomp$8_src$jscomp$25$$=$listenerMap$jscomp$8_src$jscomp$25$$[$goog$events$LISTENER_MAP_PROP_$$];return $listenerMap$jscomp$8_src$jscomp$25$$ instanceof $goog$events$ListenerMap$$?$listenerMap$jscomp$8_src$jscomp$25$$:null};
$goog$events$wrapListener$$=function($listener$jscomp$91$$){if(typeof $listener$jscomp$91$$==="function")return $listener$jscomp$91$$;$listener$jscomp$91$$[$goog$events$LISTENER_WRAPPER_PROP_$$]||($listener$jscomp$91$$[$goog$events$LISTENER_WRAPPER_PROP_$$]=function($e$jscomp$254$$){return $listener$jscomp$91$$.handleEvent($e$jscomp$254$$)});return $listener$jscomp$91$$[$goog$events$LISTENER_WRAPPER_PROP_$$]};
$goog$events$EventHandler$$=function($opt_scope$jscomp$11$$){$goog$Disposable$$.call(this);this.$handler_$=$opt_scope$jscomp$11$$;this.$keys_$={}};
$JSCompiler_StaticMethods_listenOnce_$$=function($JSCompiler_StaticMethods_listenOnce_$self$$,$listenerObj$jscomp$7_src$jscomp$31$$,$type$jscomp$300$$,$opt_fn$jscomp$3$$,$opt_options$jscomp$101$$,$opt_scope$jscomp$13$$){if(Array.isArray($type$jscomp$300$$))for(var $i$jscomp$461$$=0;$i$jscomp$461$$<$type$jscomp$300$$.length;$i$jscomp$461$$++)$JSCompiler_StaticMethods_listenOnce_$$($JSCompiler_StaticMethods_listenOnce_$self$$,$listenerObj$jscomp$7_src$jscomp$31$$,$type$jscomp$300$$[$i$jscomp$461$$],
$opt_fn$jscomp$3$$,$opt_options$jscomp$101$$,$opt_scope$jscomp$13$$);else{$listenerObj$jscomp$7_src$jscomp$31$$=$goog$events$listenOnce$$($listenerObj$jscomp$7_src$jscomp$31$$,$type$jscomp$300$$,$opt_fn$jscomp$3$$||$JSCompiler_StaticMethods_listenOnce_$self$$.handleEvent,$opt_options$jscomp$101$$,$opt_scope$jscomp$13$$||$JSCompiler_StaticMethods_listenOnce_$self$$.$handler_$||$JSCompiler_StaticMethods_listenOnce_$self$$);if(!$listenerObj$jscomp$7_src$jscomp$31$$)return $JSCompiler_StaticMethods_listenOnce_$self$$;
$JSCompiler_StaticMethods_listenOnce_$self$$.$keys_$[$listenerObj$jscomp$7_src$jscomp$31$$.key]=$listenerObj$jscomp$7_src$jscomp$31$$}return $JSCompiler_StaticMethods_listenOnce_$self$$};$APP.$goog$events$EventTarget$$=function(){$goog$Disposable$$.call(this);this.$eventTargetListeners_$=new $goog$events$ListenerMap$$(this);this.$actualEventTarget_$=this;this.$parentEventTarget_$=null};
$JSCompiler_StaticMethods_fireListeners$$=function($JSCompiler_StaticMethods_fireListeners$self$$,$listenerArray$jscomp$8_type$jscomp$307$$,$capture$jscomp$17$$,$eventObject$jscomp$5$$){$listenerArray$jscomp$8_type$jscomp$307$$=$JSCompiler_StaticMethods_fireListeners$self$$.$eventTargetListeners_$.$listeners$[String($listenerArray$jscomp$8_type$jscomp$307$$)];if(!$listenerArray$jscomp$8_type$jscomp$307$$)return!0;$listenerArray$jscomp$8_type$jscomp$307$$=$listenerArray$jscomp$8_type$jscomp$307$$.concat();
for(var $rv$jscomp$19$$=!0,$i$jscomp$463$$=0;$i$jscomp$463$$<$listenerArray$jscomp$8_type$jscomp$307$$.length;++$i$jscomp$463$$){var $listener$jscomp$100$$=$listenerArray$jscomp$8_type$jscomp$307$$[$i$jscomp$463$$];if($listener$jscomp$100$$&&!$listener$jscomp$100$$.$removed$&&$listener$jscomp$100$$.capture==$capture$jscomp$17$$){var $listenerFn$jscomp$1$$=$listener$jscomp$100$$.listener,$listenerHandler$jscomp$1$$=$listener$jscomp$100$$.handler||$listener$jscomp$100$$.src;$listener$jscomp$100$$.$callOnce$&&
$JSCompiler_StaticMethods_removeByKey$$($JSCompiler_StaticMethods_fireListeners$self$$.$eventTargetListeners_$,$listener$jscomp$100$$);$rv$jscomp$19$$=$listenerFn$jscomp$1$$.call($listenerHandler$jscomp$1$$,$eventObject$jscomp$5$$)!==!1&&$rv$jscomp$19$$}}return $rv$jscomp$19$$&&!$eventObject$jscomp$5$$.defaultPrevented};$goog$net$BulkLoaderHelper$$=function($uris$jscomp$2$$){$goog$Disposable$$.call(this);this.$uris_$=$uris$jscomp$2$$;this.$responseTexts_$=[]};
$goog$Timer$callOnce$$=function($listener$jscomp$102$$,$opt_delay$jscomp$2$$,$opt_handler$jscomp$19$$){if(typeof $listener$jscomp$102$$==="function")$opt_handler$jscomp$19$$&&($listener$jscomp$102$$=$goog$bind$$($listener$jscomp$102$$,$opt_handler$jscomp$19$$));else if($listener$jscomp$102$$&&typeof $listener$jscomp$102$$.handleEvent=="function")$listener$jscomp$102$$=$goog$bind$$($listener$jscomp$102$$.handleEvent,$listener$jscomp$102$$);else throw Error("Invalid listener argument");return Number($opt_delay$jscomp$2$$)>
2147483647?-1:$APP.$goog$global$$.setTimeout($listener$jscomp$102$$,$opt_delay$jscomp$2$$||0)};$goog$net$XmlHttpFactory$$=function(){};
$JSCompiler_StaticMethods_getOptions$$=function($JSCompiler_StaticMethods_getOptions$self$$){var $JSCompiler_temp$jscomp$677_options$jscomp$inline_4627$$;($JSCompiler_temp$jscomp$677_options$jscomp$inline_4627$$=$JSCompiler_StaticMethods_getOptions$self$$.$cachedOptions_$)||($JSCompiler_temp$jscomp$677_options$jscomp$inline_4627$$={},$JSCompiler_StaticMethods_getProgId_$$($JSCompiler_StaticMethods_getOptions$self$$)&&($JSCompiler_temp$jscomp$677_options$jscomp$inline_4627$$[0]=!0,$JSCompiler_temp$jscomp$677_options$jscomp$inline_4627$$[1]=
!0),$JSCompiler_temp$jscomp$677_options$jscomp$inline_4627$$=$JSCompiler_StaticMethods_getOptions$self$$.$cachedOptions_$=$JSCompiler_temp$jscomp$677_options$jscomp$inline_4627$$);return $JSCompiler_temp$jscomp$677_options$jscomp$inline_4627$$};$goog$net$DefaultXmlHttpFactory$$=function(){};
$JSCompiler_StaticMethods_createInstance$$=function($JSCompiler_StaticMethods_createInstance$self_progId$jscomp$1$$){return($JSCompiler_StaticMethods_createInstance$self_progId$jscomp$1$$=$JSCompiler_StaticMethods_getProgId_$$($JSCompiler_StaticMethods_createInstance$self_progId$jscomp$1$$))?new ActiveXObject($JSCompiler_StaticMethods_createInstance$self_progId$jscomp$1$$):new XMLHttpRequest};
$JSCompiler_StaticMethods_getProgId_$$=function($JSCompiler_StaticMethods_getProgId_$self$$){if(!$JSCompiler_StaticMethods_getProgId_$self$$.$ieProgId_$&&typeof XMLHttpRequest=="undefined"&&typeof ActiveXObject!="undefined"){const $ACTIVE_X_IDENTS$$=["MSXML2.XMLHTTP.6.0","MSXML2.XMLHTTP.3.0","MSXML2.XMLHTTP","Microsoft.XMLHTTP"];for(let $i$jscomp$467$$=0;$i$jscomp$467$$<$ACTIVE_X_IDENTS$$.length;$i$jscomp$467$$++){const $candidate$jscomp$7$$=$ACTIVE_X_IDENTS$$[$i$jscomp$467$$];try{return new ActiveXObject($candidate$jscomp$7$$),
$JSCompiler_StaticMethods_getProgId_$self$$.$ieProgId_$=$candidate$jscomp$7$$}catch($e$jscomp$260$$){}}throw Error("Could not create ActiveXObject. ActiveX might be disabled, or MSXML might not be installed");}return $JSCompiler_StaticMethods_getProgId_$self$$.$ieProgId_$};
$goog$net$XhrIo$$=function($opt_xmlHttpFactory$$){$APP.$goog$events$EventTarget$$.call(this);this.headers=new Map;this.$xmlHttpFactory_$=$opt_xmlHttpFactory$$||null;this.$active_$=!1;this.$xhrOptions_$=this.$xhr_$=null;this.$lastError_$=this.$lastMethod_$=this.$lastUri_$="";this.$inAbort_$=this.$inOpen_$=this.$inSend_$=this.$errorDispatched_$=!1;this.$timeoutInterval_$=0;this.$timeoutId_$=null;this.$responseType_$=$goog$net$XhrIo$ResponseType$DEFAULT$$;this.$useXhr2Timeout_$=this.$progressEventsEnabled_$=
this.$withCredentials_$=!1;this.$trustToken_$=null};$goog$net$XhrIo$shouldUseXhr2Timeout_$$=function($xhr$jscomp$1$$){return $goog$userAgent$IE$$&&typeof $xhr$jscomp$1$$.timeout==="number"&&$xhr$jscomp$1$$.ontimeout!==void 0};
$JSCompiler_StaticMethods_dispatchErrors_$$=function($JSCompiler_StaticMethods_dispatchErrors_$self$$){$JSCompiler_StaticMethods_dispatchErrors_$self$$.$errorDispatched_$||($JSCompiler_StaticMethods_dispatchErrors_$self$$.$errorDispatched_$=!0,$JSCompiler_StaticMethods_dispatchErrors_$self$$.dispatchEvent("complete"),$JSCompiler_StaticMethods_dispatchErrors_$self$$.dispatchEvent("error"))};
$JSCompiler_StaticMethods_onReadyStateChangeHelper_$$=function($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$){if($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$.$active_$&&typeof $goog$$!="undefined")if($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$.$xhrOptions_$[1]&&$JSCompiler_StaticMethods_getReadyState$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$)==4&&$JSCompiler_StaticMethods_getStatus$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$)==
2)$goog$log$fine$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$.$logger_$,$JSCompiler_StaticMethods_formatMsg_$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$,"Local request error detected and ignored"));else if($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$.$inSend_$&&$JSCompiler_StaticMethods_getReadyState$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$)==4)$goog$Timer$callOnce$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$.$onReadyStateChange_$,
0,$JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$);else if($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$.dispatchEvent("readystatechange"),$JSCompiler_StaticMethods_getReadyState$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$)==4){$goog$log$fine$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$.$logger_$,$JSCompiler_StaticMethods_formatMsg_$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$,"Request complete"));$JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$.$active_$=
!1;try{if($JSCompiler_StaticMethods_isSuccess$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$))$JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$.dispatchEvent("complete"),$JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$.dispatchEvent("success");else{try{var $JSCompiler_inline_result$jscomp$684$$=$JSCompiler_StaticMethods_getReadyState$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$)>2?$JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$.$xhr_$.statusText:
""}catch($e$jscomp$inline_4635$$){$goog$log$fine$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$.$logger_$,"Can not get status: "+$e$jscomp$inline_4635$$.message),$JSCompiler_inline_result$jscomp$684$$=""}$JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$.$lastError_$=$JSCompiler_inline_result$jscomp$684$$+" ["+$JSCompiler_StaticMethods_getStatus$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$)+"]";$JSCompiler_StaticMethods_dispatchErrors_$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$)}}finally{$JSCompiler_StaticMethods_cleanUpXhr_$$($JSCompiler_StaticMethods_onReadyStateChangeHelper_$self$$)}}};
$goog$net$XhrIo$buildProgressEvent_$$=function($e$jscomp$263$$,$eventType$jscomp$3$$){return{type:$eventType$jscomp$3$$,lengthComputable:$e$jscomp$263$$.lengthComputable,loaded:$e$jscomp$263$$.loaded,total:$e$jscomp$263$$.total}};
$JSCompiler_StaticMethods_cleanUpXhr_$$=function($JSCompiler_StaticMethods_cleanUpXhr_$self$$,$opt_fromDispose$$){if($JSCompiler_StaticMethods_cleanUpXhr_$self$$.$xhr_$){$JSCompiler_StaticMethods_cleanUpTimeoutTimer_$$($JSCompiler_StaticMethods_cleanUpXhr_$self$$);const $xhr$jscomp$2$$=$JSCompiler_StaticMethods_cleanUpXhr_$self$$.$xhr_$,$clearedOnReadyStateChange$$=$JSCompiler_StaticMethods_cleanUpXhr_$self$$.$xhrOptions_$[0]?()=>{}:null;$JSCompiler_StaticMethods_cleanUpXhr_$self$$.$xhr_$=null;$JSCompiler_StaticMethods_cleanUpXhr_$self$$.$xhrOptions_$=
null;$opt_fromDispose$$||$JSCompiler_StaticMethods_cleanUpXhr_$self$$.dispatchEvent("ready");try{$xhr$jscomp$2$$.onreadystatechange=$clearedOnReadyStateChange$$}catch($e$jscomp$264$$){$goog$log$error$$($JSCompiler_StaticMethods_cleanUpXhr_$self$$.$logger_$,"Problem encountered resetting onreadystatechange: "+$e$jscomp$264$$.message)}}};
$JSCompiler_StaticMethods_cleanUpTimeoutTimer_$$=function($JSCompiler_StaticMethods_cleanUpTimeoutTimer_$self$$){$JSCompiler_StaticMethods_cleanUpTimeoutTimer_$self$$.$xhr_$&&$JSCompiler_StaticMethods_cleanUpTimeoutTimer_$self$$.$useXhr2Timeout_$&&($JSCompiler_StaticMethods_cleanUpTimeoutTimer_$self$$.$xhr_$.ontimeout=null);$JSCompiler_StaticMethods_cleanUpTimeoutTimer_$self$$.$timeoutId_$&&($APP.$goog$global$$.clearTimeout($JSCompiler_StaticMethods_cleanUpTimeoutTimer_$self$$.$timeoutId_$),$JSCompiler_StaticMethods_cleanUpTimeoutTimer_$self$$.$timeoutId_$=
null)};
$JSCompiler_StaticMethods_isSuccess$$=function($JSCompiler_StaticMethods_isSuccess$self_scheme$jscomp$inline_11829$$){var $JSCompiler_temp$jscomp$681_status$jscomp$5$$=$JSCompiler_StaticMethods_getStatus$$($JSCompiler_StaticMethods_isSuccess$self_scheme$jscomp$inline_11829$$);a:switch($JSCompiler_temp$jscomp$681_status$jscomp$5$$){case 200:case 201:case 202:case 204:case 206:case 304:case 1223:var $JSCompiler_inline_result$jscomp$676_JSCompiler_temp$jscomp$680$$=!0;break a;default:$JSCompiler_inline_result$jscomp$676_JSCompiler_temp$jscomp$680$$=!1}if(!$JSCompiler_inline_result$jscomp$676_JSCompiler_temp$jscomp$680$$){if($JSCompiler_temp$jscomp$681_status$jscomp$5$$=
$JSCompiler_temp$jscomp$681_status$jscomp$5$$===0)$JSCompiler_StaticMethods_isSuccess$self_scheme$jscomp$inline_11829$$=String($JSCompiler_StaticMethods_isSuccess$self_scheme$jscomp$inline_11829$$.$lastUri_$).match($goog$uri$utils$splitRe_$$)[1]||null,!$JSCompiler_StaticMethods_isSuccess$self_scheme$jscomp$inline_11829$$&&$APP.$goog$global$$.self&&$APP.$goog$global$$.self.location&&($JSCompiler_StaticMethods_isSuccess$self_scheme$jscomp$inline_11829$$=$APP.$goog$global$$.self.location.protocol.slice(0,
-1)),$JSCompiler_temp$jscomp$681_status$jscomp$5$$=!$goog$net$XhrIo$HTTP_SCHEME_PATTERN$$.test($JSCompiler_StaticMethods_isSuccess$self_scheme$jscomp$inline_11829$$?$JSCompiler_StaticMethods_isSuccess$self_scheme$jscomp$inline_11829$$.toLowerCase():"");$JSCompiler_inline_result$jscomp$676_JSCompiler_temp$jscomp$680$$=$JSCompiler_temp$jscomp$681_status$jscomp$5$$}return $JSCompiler_inline_result$jscomp$676_JSCompiler_temp$jscomp$680$$};
$JSCompiler_StaticMethods_getReadyState$$=function($JSCompiler_StaticMethods_getReadyState$self$$){return $JSCompiler_StaticMethods_getReadyState$self$$.$xhr_$?$JSCompiler_StaticMethods_getReadyState$self$$.$xhr_$.readyState:0};$JSCompiler_StaticMethods_getStatus$$=function($JSCompiler_StaticMethods_getStatus$self$$){try{return $JSCompiler_StaticMethods_getReadyState$$($JSCompiler_StaticMethods_getStatus$self$$)>2?$JSCompiler_StaticMethods_getStatus$self$$.$xhr_$.status:-1}catch($e$jscomp$265$$){return-1}};
$JSCompiler_StaticMethods_formatMsg_$$=function($JSCompiler_StaticMethods_formatMsg_$self$$,$msg$jscomp$20$$){return $msg$jscomp$20$$+" ["+$JSCompiler_StaticMethods_formatMsg_$self$$.$lastMethod_$+" "+$JSCompiler_StaticMethods_formatMsg_$self$$.$lastUri_$+" "+$JSCompiler_StaticMethods_getStatus$$($JSCompiler_StaticMethods_formatMsg_$self$$)+"]"};
$goog$net$BulkLoader$$=function($uris$jscomp$3$$){$APP.$goog$events$EventTarget$$.call(this);this.$helper_$=new $goog$net$BulkLoaderHelper$$($uris$jscomp$3$$);this.$eventHandler_$=new $goog$events$EventHandler$$(this)};$goog$net$BulkLoader$LoadErrorEvent$$=function($status$jscomp$6$$){$APP.$goog$events$Event$$.call(this,"error");this.status=$status$jscomp$6$$};
$goog$net$jsloader$safeLoadMany$$=function($trustedUris$$){if($trustedUris$$.length){var $isAnotherModuleLoading$$=$goog$net$jsloader$scriptsToLoad_$$.length;$module$contents$goog$array_extend$$($goog$net$jsloader$scriptsToLoad_$$,$trustedUris$$);if(!$isAnotherModuleLoading$$){$trustedUris$$=$goog$net$jsloader$scriptsToLoad_$$;var $popAndLoadNextScript$$=function(){var $deferred$jscomp$9_trustedUri$$=$trustedUris$$.shift();$deferred$jscomp$9_trustedUri$$=$goog$net$jsloader$safeLoad$$($deferred$jscomp$9_trustedUri$$);
$trustedUris$$.length&&$deferred$jscomp$9_trustedUri$$.addCallbacks($popAndLoadNextScript$$,$popAndLoadNextScript$$,void 0);return $deferred$jscomp$9_trustedUri$$};$popAndLoadNextScript$$()}}else(new $goog$async$Deferred$$).callback(null)};
$goog$net$jsloader$safeLoad$$=function($trustedUri$jscomp$1$$){const $options$jscomp$424$$={},$doc$jscomp$36$$=$options$jscomp$424$$.document||document,$uri$jscomp$61$$=$goog$html$TrustedResourceUrl$unwrap$$($trustedUri$jscomp$1$$),$script$jscomp$14$$=(new $goog$dom$DomHelper$$($doc$jscomp$36$$)).createElement("SCRIPT");var $properties$jscomp$88_request$jscomp$5$$={$script_$:$script$jscomp$14$$,$timeout_$:void 0};const $deferred$jscomp$10$$=new $goog$async$Deferred$$($goog$net$jsloader$cancel_$$,
$properties$jscomp$88_request$jscomp$5$$);let $timeout$jscomp$9$$=null;const $timeoutDuration$$=$options$jscomp$424$$.timeout!=null?$options$jscomp$424$$.timeout:5E3;$timeoutDuration$$>0&&($timeout$jscomp$9$$=window.setTimeout(function(){$goog$net$jsloader$cleanup_$$($script$jscomp$14$$,!0);$deferred$jscomp$10$$.errback(new $goog$net$jsloader$Error$$($goog$net$jsloader$ErrorCode$TIMEOUT$$,"Timeout reached for loading script "+$uri$jscomp$61$$))},$timeoutDuration$$),$properties$jscomp$88_request$jscomp$5$$.$timeout_$=
$timeout$jscomp$9$$);$script$jscomp$14$$.onload=$script$jscomp$14$$.onreadystatechange=function(){$script$jscomp$14$$.readyState&&$script$jscomp$14$$.readyState!="loaded"&&$script$jscomp$14$$.readyState!="complete"||($goog$net$jsloader$cleanup_$$($script$jscomp$14$$,$options$jscomp$424$$.$cleanupWhenDone$||!1,$timeout$jscomp$9$$),$deferred$jscomp$10$$.callback(null))};$script$jscomp$14$$.onerror=function(){$goog$net$jsloader$cleanup_$$($script$jscomp$14$$,!0,$timeout$jscomp$9$$);$deferred$jscomp$10$$.errback(new $goog$net$jsloader$Error$$($goog$net$jsloader$ErrorCode$LOAD_ERROR$$,
"Error while loading script "+$uri$jscomp$61$$))};$properties$jscomp$88_request$jscomp$5$$=$options$jscomp$424$$.attributes||{};$module$contents$goog$object_extend$$($properties$jscomp$88_request$jscomp$5$$,{type:"text/javascript",charset:"UTF-8"});$goog$dom$setProperties$$($script$jscomp$14$$,$properties$jscomp$88_request$jscomp$5$$);$goog$dom$safe$setScriptSrc$$($script$jscomp$14$$,$trustedUri$jscomp$1$$);$goog$net$jsloader$getScriptParentElement_$$($doc$jscomp$36$$).appendChild($script$jscomp$14$$);
return $deferred$jscomp$10$$};$goog$net$jsloader$getScriptParentElement_$$=function($doc$jscomp$37$$){var $JSCompiler_inline_result$jscomp$557$$;return($JSCompiler_inline_result$jscomp$557$$=($doc$jscomp$37$$||document).getElementsByTagName("HEAD"))&&$JSCompiler_inline_result$jscomp$557$$.length!==0?$JSCompiler_inline_result$jscomp$557$$[0]:$doc$jscomp$37$$.documentElement};
$goog$net$jsloader$cancel_$$=function(){if(this&&this.$script_$){const $scriptNode$$=this.$script_$;$scriptNode$$&&$scriptNode$$.tagName=="SCRIPT"&&$goog$net$jsloader$cleanup_$$($scriptNode$$,!0,this.$timeout_$)}};
$goog$net$jsloader$cleanup_$$=function($scriptNode$jscomp$1$$,$removeScriptNode$jscomp$1$$,$opt_timeout$jscomp$2$$){$opt_timeout$jscomp$2$$!=null&&$APP.$goog$global$$.clearTimeout($opt_timeout$jscomp$2$$);$scriptNode$jscomp$1$$.onload=()=>{};$scriptNode$jscomp$1$$.onerror=()=>{};$scriptNode$jscomp$1$$.onreadystatechange=()=>{};$removeScriptNode$jscomp$1$$&&window.setTimeout(function(){$goog$dom$removeNode$$($scriptNode$jscomp$1$$)},0)};
$goog$net$jsloader$Error$$=function($code$jscomp$17$$,$opt_message$jscomp$16$$){let $msg$jscomp$21$$="Jsloader error (code #"+$code$jscomp$17$$+")";$opt_message$jscomp$16$$&&($msg$jscomp$21$$+=": "+$opt_message$jscomp$16$$);$module$contents$goog$debug$Error_DebugError$$.call(this,$msg$jscomp$21$$);this.code=$code$jscomp$17$$};
$module$contents$goog$module$ModuleLoader_ModuleLoader$$=function(){$APP.$goog$events$EventTarget$$.call(this);this.$eventHandler_$=new $goog$events$EventHandler$$(this);var $callback$jscomp$inline_11832$$=$APP.$goog$partial$$($module$contents$goog$dispose_dispose$$,this.$eventHandler_$);this.$disposed_$?$callback$jscomp$inline_11832$$():(this.$onDisposeCallbacks_$||(this.$onDisposeCallbacks_$=[]),this.$onDisposeCallbacks_$.push($callback$jscomp$inline_11832$$));this.$loadingModulesStatus_$={};this.$hasPrefetched_$=
!1};$module$contents$goog$module$ModuleLoader_ModuleLoader$createScriptElement_$$=function($url$jscomp$73$$){const $script$jscomp$16$$=$goog$dom$createElement_$$(document,"SCRIPT");$goog$dom$safe$setScriptSrc$$($script$jscomp$16$$,$url$jscomp$73$$);$script$jscomp$16$$.async=!1;return $script$jscomp$16$$};
$JSCompiler_StaticMethods_evaluateCode_$$=function($JSCompiler_StaticMethods_evaluateCode_$self$$,$moduleIds$jscomp$3$$){$JSCompiler_StaticMethods_evaluateCode_$self$$.dispatchEvent(new $module$contents$goog$module$ModuleLoader_ModuleLoader$RequestSuccessEvent$$($moduleIds$jscomp$3$$));$goog$log$info$$($JSCompiler_StaticMethods_evaluateCode_$self$$.$logger$,"evaluateCode ids:"+$moduleIds$jscomp$3$$);const $loadStatus$jscomp$1$$=$JSCompiler_StaticMethods_evaluateCode_$self$$.$loadingModulesStatus_$[$moduleIds$jscomp$3$$];
var $logger$jscomp$inline_4670_uris$jscomp$5$$=$loadStatus$jscomp$1$$.$requestUris$;const $texts$$=$loadStatus$jscomp$1$$.$responseTexts$;let $error$jscomp$45$$=null;try{if($JSCompiler_StaticMethods_evaluateCode_$self$$.$sourceUrlInjection_$||$JSCompiler_StaticMethods_evaluateCode_$self$$.$debugMode_$&&($goog$userAgent$product$CHROME$$||$module$contents$goog$labs$userAgent$browser_matchFirefox$$()&&$goog$string$internal$compareVersions$$()>=0))for(var $i$jscomp$471_script$jscomp$18$$=0;$i$jscomp$471_script$jscomp$18$$<
$logger$jscomp$inline_4670_uris$jscomp$5$$.length;$i$jscomp$471_script$jscomp$18$$++){const $script$jscomp$17$$=$module$contents$goog$html$SafeScript_SafeScript$createSafeScriptSecurityPrivateDoNotAccessOrElse$$($texts$$[$i$jscomp$471_script$jscomp$18$$]+" //# sourceURL\x3d"+$logger$jscomp$inline_4670_uris$jscomp$5$$[$i$jscomp$471_script$jscomp$18$$]);$goog$globalEval$$($module$contents$goog$html$SafeScript_SafeScript$unwrapTrustedScript$$($script$jscomp$17$$))}else $i$jscomp$471_script$jscomp$18$$=
$module$contents$goog$html$SafeScript_SafeScript$createSafeScriptSecurityPrivateDoNotAccessOrElse$$($texts$$.join("\n")),$goog$globalEval$$($module$contents$goog$html$SafeScript_SafeScript$unwrapTrustedScript$$($i$jscomp$471_script$jscomp$18$$))}catch($e$jscomp$272$$){$error$jscomp$45$$=$e$jscomp$272$$,($logger$jscomp$inline_4670_uris$jscomp$5$$=$JSCompiler_StaticMethods_evaluateCode_$self$$.$logger$)&&$goog$log$log$$($logger$jscomp$inline_4670_uris$jscomp$5$$,$goog$log$log$classdecl$var0$WARNING$$,
"Loaded incomplete code for module(s): "+$moduleIds$jscomp$3$$)}$JSCompiler_StaticMethods_evaluateCode_$self$$.dispatchEvent(new $module$contents$goog$module$ModuleLoader_ModuleLoader$EvaluateCodeEvent$$($moduleIds$jscomp$3$$));$error$jscomp$45$$?$JSCompiler_StaticMethods_handleErrorHelper_$$($JSCompiler_StaticMethods_evaluateCode_$self$$,$moduleIds$jscomp$3$$,$loadStatus$jscomp$1$$.$errorFn$,null,$error$jscomp$45$$):$loadStatus$jscomp$1$$.$successFn$&&$loadStatus$jscomp$1$$.$successFn$();delete $JSCompiler_StaticMethods_evaluateCode_$self$$.$loadingModulesStatus_$[$moduleIds$jscomp$3$$]};
$JSCompiler_StaticMethods_downloadModules_$$=function($JSCompiler_StaticMethods_downloadModules_$self$$,$ids$jscomp$8$$){var $bulkLoader$jscomp$1_debugMode$jscomp$1$$=$JSCompiler_StaticMethods_downloadModules_$self$$.$debugMode_$,$eventHandler$jscomp$1_sourceUrlInjection$$=$JSCompiler_StaticMethods_downloadModules_$self$$.$sourceUrlInjection_$||$JSCompiler_StaticMethods_downloadModules_$self$$.$debugMode_$&&($goog$userAgent$product$CHROME$$||$module$contents$goog$labs$userAgent$browser_matchFirefox$$()&&
$goog$string$internal$compareVersions$$()>=0);const $useScriptTags$jscomp$1$$=$JSCompiler_StaticMethods_downloadModules_$self$$.$useScriptTags_$;if($bulkLoader$jscomp$1_debugMode$jscomp$1$$+$eventHandler$jscomp$1_sourceUrlInjection$$+$useScriptTags$jscomp$1$$>1){var $loadStatus$jscomp$4_logger$jscomp$inline_4674$$=$JSCompiler_StaticMethods_downloadModules_$self$$.$logger$;$loadStatus$jscomp$4_logger$jscomp$inline_4674$$&&$goog$log$log$$($loadStatus$jscomp$4_logger$jscomp$inline_4674$$,$goog$log$log$classdecl$var0$WARNING$$,
`More than one of debugMode (set to ${$bulkLoader$jscomp$1_debugMode$jscomp$1$$}), `+`useScriptTags (set to ${$useScriptTags$jscomp$1$$}), `+`and sourceUrlInjection (set to ${$eventHandler$jscomp$1_sourceUrlInjection$$}) `+"is enabled. Proceeding with download as if "+`${$useScriptTags$jscomp$1$$?"useScriptTags":$bulkLoader$jscomp$1_debugMode$jscomp$1$$&&!$eventHandler$jscomp$1_sourceUrlInjection$$?"debug":"sourceUrlInjection"} is set to true and the rest to false.`)}$loadStatus$jscomp$4_logger$jscomp$inline_4674$$=
$JSCompiler_StaticMethods_downloadModules_$self$$.$loadingModulesStatus_$[$ids$jscomp$8$$];$useScriptTags$jscomp$1$$?$JSCompiler_StaticMethods_loadWithNonAsyncScriptTag_$$($JSCompiler_StaticMethods_downloadModules_$self$$,$loadStatus$jscomp$4_logger$jscomp$inline_4674$$,$ids$jscomp$8$$):$bulkLoader$jscomp$1_debugMode$jscomp$1$$&&!$eventHandler$jscomp$1_sourceUrlInjection$$?$goog$net$jsloader$safeLoadMany$$($loadStatus$jscomp$4_logger$jscomp$inline_4674$$.$trustedRequestUris$):($goog$log$info$$($JSCompiler_StaticMethods_downloadModules_$self$$.$logger$,
"downloadModules ids:"+$ids$jscomp$8$$+" uris:"+$loadStatus$jscomp$4_logger$jscomp$inline_4674$$.$requestUris$),$bulkLoader$jscomp$1_debugMode$jscomp$1$$=new $goog$net$BulkLoader$$($loadStatus$jscomp$4_logger$jscomp$inline_4674$$.$requestUris$),$eventHandler$jscomp$1_sourceUrlInjection$$=$JSCompiler_StaticMethods_downloadModules_$self$$.$eventHandler_$,$eventHandler$jscomp$1_sourceUrlInjection$$.$listen$($bulkLoader$jscomp$1_debugMode$jscomp$1$$,"success",$goog$bind$$($JSCompiler_StaticMethods_downloadModules_$self$$.$handleSuccess_$,
$JSCompiler_StaticMethods_downloadModules_$self$$,$bulkLoader$jscomp$1_debugMode$jscomp$1$$,$ids$jscomp$8$$)),$eventHandler$jscomp$1_sourceUrlInjection$$.$listen$($bulkLoader$jscomp$1_debugMode$jscomp$1$$,"error",$goog$bind$$($JSCompiler_StaticMethods_downloadModules_$self$$.$handleError_$,$JSCompiler_StaticMethods_downloadModules_$self$$,$bulkLoader$jscomp$1_debugMode$jscomp$1$$,$ids$jscomp$8$$)),$bulkLoader$jscomp$1_debugMode$jscomp$1$$.load())};
$JSCompiler_StaticMethods_loadWithNonAsyncScriptTag_$$=function($JSCompiler_StaticMethods_loadWithNonAsyncScriptTag_$self$$,$loadStatus$jscomp$5$$,$ids$jscomp$9$$){$goog$log$info$$($JSCompiler_StaticMethods_loadWithNonAsyncScriptTag_$self$$.$logger$,`Loading initiated for: ${$ids$jscomp$9$$}`);if($loadStatus$jscomp$5$$.$trustedRequestUris$.length==0&&$loadStatus$jscomp$5$$.$successFn$)$loadStatus$jscomp$5$$.$successFn$();else{var $lastScript$$=null,$insertPos$jscomp$1$$=document.head||document.documentElement;
for(let $i$jscomp$474$$=0;$i$jscomp$474$$<$loadStatus$jscomp$5$$.$trustedRequestUris$.length;$i$jscomp$474$$++){const $scriptElement$$=$module$contents$goog$module$ModuleLoader_ModuleLoader$createScriptElement_$$($loadStatus$jscomp$5$$.$trustedRequestUris$[$i$jscomp$474$$]);$scriptElement$$.onload=()=>{$scriptElement$$.onload=null;$scriptElement$$.onerror=null;$goog$dom$removeNode$$($scriptElement$$);$scriptElement$$==$lastScript$$&&($goog$log$info$$($JSCompiler_StaticMethods_loadWithNonAsyncScriptTag_$self$$.$logger$,
`Loading complete for: ${$ids$jscomp$9$$}`),$lastScript$$=null,$loadStatus$jscomp$5$$.$successFn$&&$loadStatus$jscomp$5$$.$successFn$())};$scriptElement$$.onerror=()=>{$goog$log$error$$($JSCompiler_StaticMethods_loadWithNonAsyncScriptTag_$self$$.$logger$,`Network error when loading module(s): ${$ids$jscomp$9$$}`);$scriptElement$$.onload=null;$scriptElement$$.onerror=null;$goog$dom$removeNode$$($scriptElement$$);$JSCompiler_StaticMethods_handleErrorHelper_$$($JSCompiler_StaticMethods_loadWithNonAsyncScriptTag_$self$$,
$ids$jscomp$9$$,$loadStatus$jscomp$5$$.$errorFn$,-1);$lastScript$$==$scriptElement$$?$lastScript$$=null:$goog$log$error$$($JSCompiler_StaticMethods_loadWithNonAsyncScriptTag_$self$$.$logger$,"Dependent requests were made in parallel with failed request "+`for module(s) "${$ids$jscomp$9$$}". Non-recoverable out-of-order `+"execution may occur.")};$lastScript$$=$scriptElement$$;$insertPos$jscomp$1$$.insertBefore($scriptElement$$,$insertPos$jscomp$1$$.firstChild)}}};
$JSCompiler_StaticMethods_handleErrorHelper_$$=function($JSCompiler_StaticMethods_handleErrorHelper_$self_logger$jscomp$inline_4678$$,$moduleIds$jscomp$6$$,$errorFn$$,$status$jscomp$7$$,$opt_error$jscomp$3$$){$JSCompiler_StaticMethods_handleErrorHelper_$self_logger$jscomp$inline_4678$$.dispatchEvent(new $module$contents$goog$module$ModuleLoader_ModuleLoader$RequestErrorEvent$$($moduleIds$jscomp$6$$,$status$jscomp$7$$,$opt_error$jscomp$3$$));($JSCompiler_StaticMethods_handleErrorHelper_$self_logger$jscomp$inline_4678$$=
$JSCompiler_StaticMethods_handleErrorHelper_$self_logger$jscomp$inline_4678$$.$logger$)&&$goog$log$log$$($JSCompiler_StaticMethods_handleErrorHelper_$self_logger$jscomp$inline_4678$$,$goog$log$log$classdecl$var0$WARNING$$,"Request failed for module(s): "+$moduleIds$jscomp$6$$);$errorFn$$&&$errorFn$$($status$jscomp$7$$)};$module$contents$goog$module$ModuleLoader_ModuleLoader$EvaluateCodeEvent$$=function(){$APP.$goog$events$Event$$.call(this,$module$contents$goog$module$ModuleLoader_ModuleLoader$EventType$EVALUATE_CODE$$)};
$module$contents$goog$module$ModuleLoader_ModuleLoader$RequestSuccessEvent$$=function(){$APP.$goog$events$Event$$.call(this,$module$contents$goog$module$ModuleLoader_ModuleLoader$EventType$REQUEST_SUCCESS$$)};
$module$contents$goog$module$ModuleLoader_ModuleLoader$RequestErrorEvent$$=function($moduleIds$jscomp$9$$,$status$jscomp$8$$,$opt_error$jscomp$4$$){$APP.$goog$events$Event$$.call(this,$module$contents$goog$module$ModuleLoader_ModuleLoader$EventType$REQUEST_ERROR$$);this.status=$status$jscomp$8$$;this.error=$opt_error$jscomp$4$$||null};
$module$contents$goog$module$ModuleLoader_ModuleLoader$LoadStatus$$=function($trustedRequestUris$$){this.$requestUris$=$trustedRequestUris$$.map($goog$html$TrustedResourceUrl$unwrap$$);this.$trustedRequestUris$=$trustedRequestUris$$;this.$responseTexts$=null;this.$loadRequested$=!1;this.$errorFn$=this.$successFn$=null};$APP.$rumext$v2$ref_val$$=function($ref$jscomp$10$$){return $ref$jscomp$10$$.current};
$APP.$rumext$v2$set_ref_val_BANG_$$=function($ref$jscomp$11$$,$val$jscomp$153$$){return $ref$jscomp$11$$.current=$val$jscomp$153$$};$APP.$rumext$v2$provider$$=function($ctx$jscomp$1$$){return $ctx$jscomp$1$$.Provider};$APP.$rumext$v2$adapt$$=function($o$jscomp$232$$){if($o$jscomp$232$$!=null){var $adapt_fn$$=$o$jscomp$232$$[$rumext$v2$adapt_sym$$];return $adapt_fn$$?$adapt_fn$$($o$jscomp$232$$):$o$jscomp$232$$}return null};
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$=function($f$jscomp$722$$){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],$f$jscomp$722$$)};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$=function($deps$jscomp$5$$,$f$jscomp$723$$){(0,$APP.$rumext$v2$useEffect$$)(function(){var $r$jscomp$76$$=$f$jscomp$723$$();return $APP.$cljs$core$fn_QMARK_$$($r$jscomp$76$$)?$r$jscomp$76$$:$rumext$v2$noop$$},$deps$jscomp$5$$)};
$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$=function($deps$jscomp$7$$,$f$jscomp$727$$){$rumext$v2$useLayoutEffect$$(function(){var $r$jscomp$78$$=$f$jscomp$727$$();return $APP.$cljs$core$fn_QMARK_$$($r$jscomp$78$$)?$r$jscomp$78$$:$rumext$v2$noop$$},$deps$jscomp$7$$)};
$rumext$v2$use_ssr_effect$$=function($deps$jscomp$8_ret$jscomp$143$$,$effect_fn$$){$rumext$v2$browser_context_QMARK_$$?$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$($deps$jscomp$8_ret$jscomp$143$$,$effect_fn$$):($deps$jscomp$8_ret$jscomp$143$$=$effect_fn$$.$cljs$core$IFn$_invoke$arity$0$?$effect_fn$$.$cljs$core$IFn$_invoke$arity$0$():$effect_fn$$(),$APP.$cljs$core$fn_QMARK_$$($deps$jscomp$8_ret$jscomp$143$$)&&($deps$jscomp$8_ret$jscomp$143$$.$cljs$core$IFn$_invoke$arity$0$?$deps$jscomp$8_ret$jscomp$143$$.$cljs$core$IFn$_invoke$arity$0$():
$deps$jscomp$8_ret$jscomp$143$$()))};$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$=function($f$jscomp$728$$){return(0,$APP.$rumext$v2$useMemo$$)($f$jscomp$728$$,[])};$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$=function($deps$jscomp$9$$,$f$jscomp$729$$){return(0,$APP.$rumext$v2$useMemo$$)($f$jscomp$729$$,$deps$jscomp$9$$)};$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$=function($f$jscomp$730$$){return $rumext$v2$useCallback$$($f$jscomp$730$$,[])};
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$=function($deps$jscomp$10$$,$f$jscomp$731$$){return $rumext$v2$useCallback$$($f$jscomp$731$$,$deps$jscomp$10$$)};$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$=function($f$jscomp$732$$){return $rumext$v2$useCallback$$($f$jscomp$732$$,[])};$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$=function($deps$jscomp$11$$,$f$jscomp$733$$){return $rumext$v2$useCallback$$($f$jscomp$733$$,$deps$jscomp$11$$)};
$APP.$rumext$v2$deref$$=function($iref$jscomp$6$$){var $state$jscomp$44$$=(0,$APP.$rumext$v2$use_ref$$)($APP.$cljs$core$_deref$$($iref$jscomp$6$$)),$key$jscomp$298$$=(0,$APP.$rumext$v2$use_id$$)(),$get_state$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$state$jscomp$44$$],function(){return $state$jscomp$44$$.current}),$subscribe$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$iref$jscomp$6$$,$key$jscomp$298$$],function($listener_fn$$){$state$jscomp$44$$.current=$APP.$cljs$core$_deref$$($iref$jscomp$6$$);
$APP.$cljs$core$add_watch$$($iref$jscomp$6$$,$key$jscomp$298$$,function($_$jscomp$1045$$,$___$1$jscomp$670$$,$___$2$jscomp$78$$,$newv$$){$state$jscomp$44$$.current=$newv$$;return $listener_fn$$()});return function(){return $APP.$cljs$core$remove_watch$$($iref$jscomp$6$$,$key$jscomp$298$$)}}),$snapshot$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$iref$jscomp$6$$],function(){return $APP.$cljs$core$_deref$$($iref$jscomp$6$$)});return $shadow$js$shim$module$0react$$.useSyncExternalStore($subscribe$$,
$get_state$$,$snapshot$$)};$rumext$v2$State$$=function($update_fn$$,$value$jscomp$383$$){this.$update_fn$=$update_fn$$;this.value=$value$jscomp$383$$;this.$cljs$lang$protocol_mask$partition1$$=98304;this.$cljs$lang$protocol_mask$partition0$$=32768};
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$=function($initial$jscomp$4_tmp$jscomp$4$$){$initial$jscomp$4_tmp$jscomp$4$$=(0,$APP.$rumext$v2$useState$$)($initial$jscomp$4_tmp$jscomp$4$$);(0,$APP.$rumext$v2$useRef$$)(null);var $value$jscomp$385$$=$initial$jscomp$4_tmp$jscomp$4$$[0],$update_fn$jscomp$2$$=$initial$jscomp$4_tmp$jscomp$4$$[1];return $APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$385$$],function(){return new $rumext$v2$State$$($update_fn$jscomp$2$$,
$value$jscomp$385$$)})};
$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$=function($initial$jscomp$5$$){var $ref$jscomp$13$$=(0,$APP.$rumext$v2$useRef$$)(null);if($ref$jscomp$13$$.current==null){var $self_45062$$=function($value$jscomp$386$$){return $ref$jscomp$13$$.current.value=$value$jscomp$386$$};$self_45062$$.value=$initial$jscomp$5$$;$ref$jscomp$13$$.current=$self_45062$$;$self_45062$$.$cljs$core$IDeref$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$self_45062$$.$cljs$core$IDeref$_deref$arity$1$=function(){return this.value};
$self_45062$$.$cljs$core$IReset$_reset_BANG_$arity$2$=function($this$$jscomp$603$$,$v$jscomp$498$$){return this.value=$v$jscomp$498$$};$self_45062$$.$cljs$core$ISwap$_swap_BANG_$arity$2$=function($G__44922$jscomp$inline_4688_this$$jscomp$604$$,$f$jscomp$738$$){$G__44922$jscomp$inline_4688_this$$jscomp$604$$=this.value;return this.value=$f$jscomp$738$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$738$$.$cljs$core$IFn$_invoke$arity$1$($G__44922$jscomp$inline_4688_this$$jscomp$604$$):$f$jscomp$738$$($G__44922$jscomp$inline_4688_this$$jscomp$604$$)};
$self_45062$$.$cljs$core$ISwap$_swap_BANG_$arity$3$=function($G__44923$jscomp$inline_4690_this$$jscomp$605$$,$f$jscomp$739$$,$a$jscomp$330$$){$G__44923$jscomp$inline_4690_this$$jscomp$605$$=this.value;return this.value=$f$jscomp$739$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$739$$.$cljs$core$IFn$_invoke$arity$2$($G__44923$jscomp$inline_4690_this$$jscomp$605$$,$a$jscomp$330$$):$f$jscomp$739$$($G__44923$jscomp$inline_4690_this$$jscomp$605$$,$a$jscomp$330$$)};$self_45062$$.$cljs$core$ISwap$_swap_BANG_$arity$4$=
function($G__44925$jscomp$inline_4692_this$$jscomp$606$$,$f$jscomp$740$$,$a$jscomp$331$$,$b$jscomp$256$$){$G__44925$jscomp$inline_4692_this$$jscomp$606$$=this.value;return this.value=$f$jscomp$740$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$740$$.$cljs$core$IFn$_invoke$arity$3$($G__44925$jscomp$inline_4692_this$$jscomp$606$$,$a$jscomp$331$$,$b$jscomp$256$$):$f$jscomp$740$$($G__44925$jscomp$inline_4692_this$$jscomp$606$$,$a$jscomp$331$$,$b$jscomp$256$$)};$self_45062$$.$cljs$core$ISwap$_swap_BANG_$arity$5$=
function($this$$jscomp$607$$,$f$jscomp$741$$,$a$jscomp$332$$,$b$jscomp$257$$,$xs$jscomp$30$$){return this.value=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($f$jscomp$741$$,this.value,$a$jscomp$332$$,$b$jscomp$257$$,$xs$jscomp$30$$)}}return $ref$jscomp$13$$.current};
$rumext$v2$element$cljs$0core$0IFn$0_invoke$0arity$02$$=function($klass$jscomp$2$$,$JSCompiler_temp$jscomp$692_JSCompiler_temp$jscomp$693_props$jscomp$56$$){if(!$APP.$cljs$core$object_QMARK_$$($JSCompiler_temp$jscomp$692_JSCompiler_temp$jscomp$693_props$jscomp$56$$))if($APP.$cljs$core$map_QMARK_$$($JSCompiler_temp$jscomp$692_JSCompiler_temp$jscomp$693_props$jscomp$56$$))$JSCompiler_temp$jscomp$692_JSCompiler_temp$jscomp$693_props$jscomp$56$$=$APP.$rumext$v2$util$map__GT_obj$$($JSCompiler_temp$jscomp$692_JSCompiler_temp$jscomp$693_props$jscomp$56$$);
else throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Unexpected props",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$575$props$$,$JSCompiler_temp$jscomp$692_JSCompiler_temp$jscomp$693_props$jscomp$56$$],null));return(0,$APP.$rumext$v2$jsx$$)($klass$jscomp$2$$,$JSCompiler_temp$jscomp$692_JSCompiler_temp$jscomp$693_props$jscomp$56$$,void 0)};$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$=function($component$jscomp$2$$){return $shadow$js$shim$module$0react$$.memo($component$jscomp$2$$)};
$APP.$rumext$v2$deferred$cljs$0core$0IFn$0_invoke$0arity$02$$=function($component$jscomp$5$$,$sfn$$){return function($props_44984$$){var $tmp$jscomp$5$$=(0,$APP.$rumext$v2$useState$$)(!1),$render_QMARK_$$=$tmp$jscomp$5$$[0],$set_render$$=$tmp$jscomp$5$$[1];$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $sfn$$(function(){return $set_render$$(!0)})});return $render_QMARK_$$?(0,$APP.$rumext$v2$create_element$$)($component$jscomp$5$$,$props_44984$$):null}};
$app$util$perf$install_long_task_observer$$=function(){if(window.PerformanceObserver!=null&&$APP.$cljs$core$_deref$$($app$util$perf$longtask_observer_STAR_$$)==null){var $observer$jscomp$2$$=new PerformanceObserver(function($G__45162_entry$jscomp$34_list_temp__5825__auto__$jscomp$109$$){for(var $G__45161_seq__45096_seq__45096__$1$$=$APP.$cljs$core$seq$$($G__45162_entry$jscomp$34_list_temp__5825__auto__$jscomp$109$$.getEntries()),$c__5548__auto__$jscomp$14_chunk__45097_start_45166$$=null,$G__45163_attrib_45167_count__45098_first_attrib_45169$$=
0,$attrib_name_45170_i__45099$$=0;;)if($attrib_name_45170_i__45099$$<$G__45163_attrib_45167_count__45098_first_attrib_45169$$){$G__45162_entry$jscomp$34_list_temp__5825__auto__$jscomp$109$$=$c__5548__auto__$jscomp$14_chunk__45097_start_45166$$.$cljs$core$IIndexed$_nth$arity$2$(null,$attrib_name_45170_i__45099$$);var $attrib_ctype_45171_start_45149$$=$G__45162_entry$jscomp$34_list_temp__5825__auto__$jscomp$109$$.startTime,$attrib_45150_attrib_cid_45172_first_attrib_45152$$=$G__45162_entry$jscomp$34_list_temp__5825__auto__$jscomp$109$$.attribution,
$attrib_count_45151$$=$APP.$cljs$core$truth_$$($attrib_45150_attrib_cid_45172_first_attrib_45152$$)?$attrib_45150_attrib_cid_45172_first_attrib_45152$$.length:null;$attrib_45150_attrib_cid_45172_first_attrib_45152$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$214$$=$attrib_count_45151$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$214$$)?$attrib_count_45151$$>0:$and__5023__auto__$jscomp$214$$}())?$attrib_45150_attrib_cid_45172_first_attrib_45152$$[0]:null;var $attrib_csrc_45173_attrib_name_45153$$=
$APP.$cljs$core$truth_$$($attrib_45150_attrib_cid_45172_first_attrib_45152$$)?$attrib_45150_attrib_cid_45172_first_attrib_45152$$.name:null,$attrib_ctype_45154$$=$APP.$cljs$core$truth_$$($attrib_45150_attrib_cid_45172_first_attrib_45152$$)?$attrib_45150_attrib_cid_45172_first_attrib_45152$$.containerType:null,$attrib_cid_45155$$=$APP.$cljs$core$truth_$$($attrib_45150_attrib_cid_45172_first_attrib_45152$$)?$attrib_45150_attrib_cid_45172_first_attrib_45152$$.containerId:null,$attrib_csrc_45156$$=$APP.$cljs$core$truth_$$($attrib_45150_attrib_cid_45172_first_attrib_45152$$)?
$attrib_45150_attrib_cid_45172_first_attrib_45152$$.containerSrc:null;console.warn(["[perf] long task ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(Math.round($G__45162_entry$jscomp$34_list_temp__5825__auto__$jscomp$109$$.duration)),"ms at ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(Math.round($attrib_ctype_45171_start_45149$$)),"ms",$APP.$cljs$core$truth_$$($attrib_45150_attrib_cid_45172_first_attrib_45152$$)?[" attrib:name\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attrib_csrc_45173_attrib_name_45153$$),
" ctype\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attrib_ctype_45154$$)," cid\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attrib_cid_45155$$)," csrc\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attrib_csrc_45156$$)].join(""):null].join(""));$attrib_name_45170_i__45099$$+=1}else if($G__45162_entry$jscomp$34_list_temp__5825__auto__$jscomp$109$$=$APP.$cljs$core$seq$$($G__45161_seq__45096_seq__45096__$1$$)){$G__45161_seq__45096_seq__45096__$1$$=$G__45162_entry$jscomp$34_list_temp__5825__auto__$jscomp$109$$;
if($APP.$cljs$core$chunked_seq_QMARK_$$($G__45161_seq__45096_seq__45096__$1$$))$c__5548__auto__$jscomp$14_chunk__45097_start_45166$$=$APP.$cljs$core$_chunked_first$$($G__45161_seq__45096_seq__45096__$1$$),$G__45161_seq__45096_seq__45096__$1$$=$APP.$cljs$core$_chunked_rest$$($G__45161_seq__45096_seq__45096__$1$$),$G__45162_entry$jscomp$34_list_temp__5825__auto__$jscomp$109$$=$c__5548__auto__$jscomp$14_chunk__45097_start_45166$$,$G__45163_attrib_45167_count__45098_first_attrib_45169$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$14_chunk__45097_start_45166$$),
$c__5548__auto__$jscomp$14_chunk__45097_start_45166$$=$G__45162_entry$jscomp$34_list_temp__5825__auto__$jscomp$109$$;else{$G__45162_entry$jscomp$34_list_temp__5825__auto__$jscomp$109$$=$APP.$cljs$core$first$$($G__45161_seq__45096_seq__45096__$1$$);$c__5548__auto__$jscomp$14_chunk__45097_start_45166$$=$G__45162_entry$jscomp$34_list_temp__5825__auto__$jscomp$109$$.startTime;$G__45163_attrib_45167_count__45098_first_attrib_45169$$=$G__45162_entry$jscomp$34_list_temp__5825__auto__$jscomp$109$$.attribution;
var $attrib_count_45168$$=$APP.$cljs$core$truth_$$($G__45163_attrib_45167_count__45098_first_attrib_45169$$)?$G__45163_attrib_45167_count__45098_first_attrib_45169$$.length:null;$G__45163_attrib_45167_count__45098_first_attrib_45169$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$215$$=$attrib_count_45168$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$215$$)?$attrib_count_45168$$>0:$and__5023__auto__$jscomp$215$$}())?$G__45163_attrib_45167_count__45098_first_attrib_45169$$[0]:
null;$attrib_name_45170_i__45099$$=$APP.$cljs$core$truth_$$($G__45163_attrib_45167_count__45098_first_attrib_45169$$)?$G__45163_attrib_45167_count__45098_first_attrib_45169$$.name:null;$attrib_ctype_45171_start_45149$$=$APP.$cljs$core$truth_$$($G__45163_attrib_45167_count__45098_first_attrib_45169$$)?$G__45163_attrib_45167_count__45098_first_attrib_45169$$.containerType:null;$attrib_45150_attrib_cid_45172_first_attrib_45152$$=$APP.$cljs$core$truth_$$($G__45163_attrib_45167_count__45098_first_attrib_45169$$)?
$G__45163_attrib_45167_count__45098_first_attrib_45169$$.containerId:null;$attrib_csrc_45173_attrib_name_45153$$=$APP.$cljs$core$truth_$$($G__45163_attrib_45167_count__45098_first_attrib_45169$$)?$G__45163_attrib_45167_count__45098_first_attrib_45169$$.containerSrc:null;console.warn(["[perf] long task ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(Math.round($G__45162_entry$jscomp$34_list_temp__5825__auto__$jscomp$109$$.duration)),"ms at ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(Math.round($c__5548__auto__$jscomp$14_chunk__45097_start_45166$$)),
"ms",$APP.$cljs$core$truth_$$($G__45163_attrib_45167_count__45098_first_attrib_45169$$)?[" attrib:name\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attrib_name_45170_i__45099$$)," ctype\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attrib_ctype_45171_start_45149$$)," cid\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attrib_45150_attrib_cid_45172_first_attrib_45152$$)," csrc\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attrib_csrc_45173_attrib_name_45153$$)].join(""):
null].join(""));$G__45161_seq__45096_seq__45096__$1$$=$APP.$cljs$core$next$$($G__45161_seq__45096_seq__45096__$1$$);$c__5548__auto__$jscomp$14_chunk__45097_start_45166$$=null;$G__45163_attrib_45167_count__45098_first_attrib_45169$$=0}$attrib_name_45170_i__45099$$=0}else return null});$observer$jscomp$2$$.observe({entryTypes:["longtask"]});$APP.$cljs$core$reset_BANG_$$($app$util$perf$longtask_observer_STAR_$$,$observer$jscomp$2$$)}};
$app$util$perf$start_event_loop_stall_logger$$=function(){if($APP.$cljs$core$_deref$$($app$util$perf$stall_timer_STAR_$$)==null){var $last$jscomp$1$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(performance.now()),$id$jscomp$92$$=setInterval(function(){var $now$jscomp$4$$=performance.now(),$drift_expected$jscomp$2$$=$APP.$cljs$core$_deref$$($last$jscomp$1$$)+50;$drift_expected$jscomp$2$$=$now$jscomp$4$$-$drift_expected$jscomp$2$$;var $current_op$$=$APP.$cljs$core$_deref$$($app$util$perf$current_op_STAR_$$),
$meas_name_measures$jscomp$1$$=performance.getEntriesByType("measure"),$last_measure_meas_count_meas_detail_mlen$$=$meas_name_measures$jscomp$1$$.length;$last_measure_meas_count_meas_detail_mlen$$=$last_measure_meas_count_meas_detail_mlen$$>0?$meas_name_measures$jscomp$1$$[$last_measure_meas_count_meas_detail_mlen$$-1]:null;$meas_name_measures$jscomp$1$$=$APP.$cljs$core$truth_$$($last_measure_meas_count_meas_detail_mlen$$)?$last_measure_meas_count_meas_detail_mlen$$.name:null;$last_measure_meas_count_meas_detail_mlen$$=
$APP.$cljs$core$truth_$$($last_measure_meas_count_meas_detail_mlen$$)?$last_measure_meas_count_meas_detail_mlen$$.detail:null;$last_measure_meas_count_meas_detail_mlen$$=$APP.$cljs$core$truth_$$($last_measure_meas_count_meas_detail_mlen$$)?$last_measure_meas_count_meas_detail_mlen$$.count:null;$APP.$cljs$core$reset_BANG_$$($last$jscomp$1$$,$now$jscomp$4$$);return $drift_expected$jscomp$2$$>100?console.warn(["[perf] event loop stall: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(Math.round($drift_expected$jscomp$2$$)),
"ms",$APP.$cljs$core$truth_$$($current_op$$)?[" op\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($current_op$$)].join(""):null,$APP.$cljs$core$truth_$$($meas_name_measures$jscomp$1$$)?[" last\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($meas_name_measures$jscomp$1$$)].join(""):null,$APP.$cljs$core$truth_$$($last_measure_meas_count_meas_detail_mlen$$)?[" count\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($last_measure_meas_count_meas_detail_mlen$$)].join(""):
null].join("")):null},50);$APP.$cljs$core$reset_BANG_$$($app$util$perf$stall_timer_STAR_$$,$id$jscomp$92$$)}};$app$util$perf$setup$$=function(){$app$util$perf$install_long_task_observer$$();$app$util$perf$start_event_loop_stall_logger$$();return window.PenpotPerf={reset:function(){try{return performance.clearMarks(),performance.clearMeasures()}catch($e45133$$){return null}}}};
$app$util$http$_update_headers$$=function($JSCompiler_temp$jscomp$694__$jscomp$1051$$,$headers$jscomp$2$$){if($JSCompiler_temp$jscomp$694__$jscomp$1051$$!=null&&$JSCompiler_temp$jscomp$694__$jscomp$1051$$.$app$util$http$IBodyData$_update_headers$arity$2$!=null)$JSCompiler_temp$jscomp$694__$jscomp$1051$$=$JSCompiler_temp$jscomp$694__$jscomp$1051$$.$app$util$http$IBodyData$_update_headers$arity$2$($JSCompiler_temp$jscomp$694__$jscomp$1051$$,$headers$jscomp$2$$);else{var $m__5372__auto__$jscomp$inline_4709_m__5374__auto__$jscomp$inline_4708$$=
$app$util$http$_update_headers$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$694__$jscomp$1051$$==null?null:$JSCompiler_temp$jscomp$694__$jscomp$1051$$)];if($m__5372__auto__$jscomp$inline_4709_m__5374__auto__$jscomp$inline_4708$$!=null)$JSCompiler_temp$jscomp$694__$jscomp$1051$$=$m__5372__auto__$jscomp$inline_4709_m__5374__auto__$jscomp$inline_4708$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_4709_m__5374__auto__$jscomp$inline_4708$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$694__$jscomp$1051$$,
$headers$jscomp$2$$):$m__5372__auto__$jscomp$inline_4709_m__5374__auto__$jscomp$inline_4708$$($JSCompiler_temp$jscomp$694__$jscomp$1051$$,$headers$jscomp$2$$);else if($m__5372__auto__$jscomp$inline_4709_m__5374__auto__$jscomp$inline_4708$$=$app$util$http$_update_headers$$._,$m__5372__auto__$jscomp$inline_4709_m__5374__auto__$jscomp$inline_4708$$!=null)$JSCompiler_temp$jscomp$694__$jscomp$1051$$=$m__5372__auto__$jscomp$inline_4709_m__5374__auto__$jscomp$inline_4708$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_4709_m__5374__auto__$jscomp$inline_4708$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$694__$jscomp$1051$$,$headers$jscomp$2$$):$m__5372__auto__$jscomp$inline_4709_m__5374__auto__$jscomp$inline_4708$$($JSCompiler_temp$jscomp$694__$jscomp$1051$$,$headers$jscomp$2$$);else throw $APP.$cljs$core$missing_protocol$$("IBodyData.-update-headers",$JSCompiler_temp$jscomp$694__$jscomp$1051$$);}return $JSCompiler_temp$jscomp$694__$jscomp$1051$$};
$app$util$http$_get_body_data$$=function($JSCompiler_temp$jscomp$695__$jscomp$1053$$){if($JSCompiler_temp$jscomp$695__$jscomp$1053$$!=null&&$JSCompiler_temp$jscomp$695__$jscomp$1053$$.$app$util$http$IBodyData$_get_body_data$arity$1$!=null)$JSCompiler_temp$jscomp$695__$jscomp$1053$$=$JSCompiler_temp$jscomp$695__$jscomp$1053$$.$app$util$http$IBodyData$_get_body_data$arity$1$($JSCompiler_temp$jscomp$695__$jscomp$1053$$);else{var $m__5372__auto__$jscomp$inline_4713_m__5374__auto__$jscomp$inline_4712$$=
$app$util$http$_get_body_data$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$695__$jscomp$1053$$==null?null:$JSCompiler_temp$jscomp$695__$jscomp$1053$$)];if($m__5372__auto__$jscomp$inline_4713_m__5374__auto__$jscomp$inline_4712$$!=null)$JSCompiler_temp$jscomp$695__$jscomp$1053$$=$m__5372__auto__$jscomp$inline_4713_m__5374__auto__$jscomp$inline_4712$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_4713_m__5374__auto__$jscomp$inline_4712$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$695__$jscomp$1053$$):
$m__5372__auto__$jscomp$inline_4713_m__5374__auto__$jscomp$inline_4712$$($JSCompiler_temp$jscomp$695__$jscomp$1053$$);else if($m__5372__auto__$jscomp$inline_4713_m__5374__auto__$jscomp$inline_4712$$=$app$util$http$_get_body_data$$._,$m__5372__auto__$jscomp$inline_4713_m__5374__auto__$jscomp$inline_4712$$!=null)$JSCompiler_temp$jscomp$695__$jscomp$1053$$=$m__5372__auto__$jscomp$inline_4713_m__5374__auto__$jscomp$inline_4712$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_4713_m__5374__auto__$jscomp$inline_4712$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$695__$jscomp$1053$$):
$m__5372__auto__$jscomp$inline_4713_m__5374__auto__$jscomp$inline_4712$$($JSCompiler_temp$jscomp$695__$jscomp$1053$$);else throw $APP.$cljs$core$missing_protocol$$("IBodyData.-get-body-data",$JSCompiler_temp$jscomp$695__$jscomp$1053$$);}return $JSCompiler_temp$jscomp$695__$jscomp$1053$$};
$app$util$http$translate_method$$=function($G__45188__$1_method$jscomp$43$$){$G__45188__$1_method$jscomp$43$$=$G__45188__$1_method$jscomp$43$$ instanceof $APP.$cljs$core$Keyword$$?$G__45188__$1_method$jscomp$43$$.$fqn$:null;switch($G__45188__$1_method$jscomp$43$$){case "head":return"HEAD";case "options":return"OPTIONS";case "get":return"GET";case "post":return"POST";case "put":return"PUT";case "patch":return"PATCH";case "delete":return"DELETE";case "trace":return"TRACE";default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__45188__$1_method$jscomp$43$$)].join(""));}};
$APP.$app$util$http$fetch$$=function($map__45193__$1_p__45192$$){$map__45193__$1_p__45192$$=$APP.$cljs$core$__destructure_map$$($map__45193__$1_p__45192$$);var $method$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45193__$1_p__45192$$,$APP.$cljs$cst$1578$method$$),$uri$jscomp$63$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45193__$1_p__45192$$,$APP.$cljs$cst$1579$uri$$),$query$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45193__$1_p__45192$$,
$APP.$cljs$cst$747$query$$),$headers$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__45193__$1_p__45192$$,$cljs$cst$1580$headers$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),$body$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45193__$1_p__45192$$,$APP.$cljs$cst$1581$body$$),$mode$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__45193__$1_p__45192$$,$APP.$cljs$cst$320$mode$$,$APP.$cljs$cst$1190$cors$$),$omit_default_headers$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45193__$1_p__45192$$,$APP.$cljs$cst$1582$omit_default_headers$$),$credentials$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__45193__$1_p__45192$$,$APP.$cljs$cst$1583$credentials$$,"same-origin");return $APP.$beicon$v2$core$create$$(function($subscriber$$){var $controller$jscomp$4$$=new AbortController,$params$jscomp$90_signal$$=$controller$jscomp$4$$.signal,$unsubscribed_QMARK_$$=$APP.$cljs$core$volatile_BANG_$$(!1),$abortable_QMARK_$$=
$APP.$cljs$core$volatile_BANG_$$(!0),$query__$1$$=typeof $query$jscomp$22$$==="string"?$query$jscomp$22$$:$APP.$cljs$core$map_QMARK_$$($query$jscomp$22$$)?$APP.$app$common$uri$map__GT_query_string$cljs$0core$0IFn$0_invoke$0arity$02$$($query$jscomp$22$$):null,$uri__$1$$=function(){var $G__45198__$1$$=typeof $uri$jscomp$63$$==="string"?$APP.$app$common$uri$uri$$($uri$jscomp$63$$):$uri$jscomp$63$$;return $query__$1$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__45198__$1$$,$APP.$cljs$cst$747$query$$,
$query__$1$$):$G__45198__$1$$}(),$body__$1_headers__$1$$=$APP.$cljs$core$not$$($omit_default_headers$$)?$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$headers$jscomp$6$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["x-frontend-version",$APP.$cljs$cst$1273$full$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$),"x-client",["penpot-frontend/",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1273$full$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$))].join("")],
null)])):$headers$jscomp$6$$,$headers__$2$$=$app$util$http$_update_headers$$($body$jscomp$4$$,$body__$1_headers__$1$$);$body__$1_headers__$1$$=$app$util$http$_get_body_data$$($body$jscomp$4$$);$params$jscomp$90_signal$$={method:$app$util$http$translate_method$$($method$jscomp$44$$),headers:$APP.$cljs$core$clj__GT_js$$($headers__$2$$),body:$body__$1_headers__$1$$,mode:$APP.$app$common$data$name$$($mode$jscomp$21$$),redirect:"follow",credentials:$credentials$$,referrerPolicy:"no-referrer",signal:$params$jscomp$90_signal$$};
var $start$jscomp$187$$=performance.now();$APP.$promesa$core$finally$0$cljs$0core$0IFn$0_invoke$0arity$02$$($promesa$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$(fetch($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($uri__$1$$),$params$jscomp$90_signal$$),function($response$jscomp$3$$){$APP.$cljs$core$_vreset_BANG_$$($abortable_QMARK_$$,!1);$subscriber$$.next($response$jscomp$3$$);return $subscriber$$.complete()}),function($cause$jscomp$30$$){$APP.$cljs$core$_vreset_BANG_$$($abortable_QMARK_$$,
!1);var $JSCompiler_inline_result$jscomp$700_or__5025__auto__$jscomp$inline_4715$$=$APP.$cljs$core$_deref$$($unsubscribed_QMARK_$$);$JSCompiler_inline_result$jscomp$700_or__5025__auto__$jscomp$inline_4715$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$700_or__5025__auto__$jscomp$inline_4715$$)?$JSCompiler_inline_result$jscomp$700_or__5025__auto__$jscomp$inline_4715$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cause$jscomp$30$$.name,"AbortError");return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$700_or__5025__auto__$jscomp$inline_4715$$)?
null:$subscriber$$.error($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$ex_message$$($cause$jscomp$30$$),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$1584$network$$,$APP.$cljs$cst$275$hint$$,"unable to perform fetch operation",$APP.$cljs$cst$1579$uri$$,$uri__$1$$,$cljs$cst$1580$headers$$,$headers__$2$$],null),$cause$jscomp$30$$))}),function(){var $count$jscomp$67_count__$1_map__45201$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($app$util$http$network_averages$$),
$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($uri__$1$$)),$average_average__$1_map__45201__$1$$=$APP.$cljs$core$__destructure_map$$($count$jscomp$67_count__$1_map__45201$$);$count$jscomp$67_count__$1_map__45201$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($average_average__$1_map__45201__$1$$,$APP.$cljs$cst$1080$count$$,0);$average_average__$1_map__45201__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($average_average__$1_map__45201__$1$$,$cljs$cst$1585$average$$,
0);var $current_time$$=performance.now()-$start$jscomp$187$$;$average_average__$1_map__45201__$1$$=$count$jscomp$67_count__$1_map__45201$$/($count$jscomp$67_count__$1_map__45201$$+1)*$average_average__$1_map__45201__$1$$+$current_time$$/($count$jscomp$67_count__$1_map__45201$$+1);$count$jscomp$67_count__$1_map__45201$$+=1;return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$util$http$network_averages$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($uri__$1$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1080$count$$,$count$jscomp$67_count__$1_map__45201$$,$cljs$cst$1585$average$$,$average_average__$1_map__45201__$1$$],null))});return function(){$APP.$cljs$core$_vreset_BANG_$$($unsubscribed_QMARK_$$,!0);return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($abortable_QMARK_$$))?$controller$jscomp$4$$.abort():null}})};
$app$util$http$response__GT_map$$=function($response$jscomp$4$$){var $JSCompiler_temp_const$jscomp$698$$=$APP.$cljs$cst$109$status$$,$JSCompiler_temp_const$jscomp$697$$=$response$jscomp$4$$.status,$JSCompiler_temp_const$jscomp$696$$=$response$jscomp$4$$.url;var $JSCompiler_inline_result$jscomp$699_headers$jscomp$inline_4717$$=$response$jscomp$4$$.headers;$JSCompiler_inline_result$jscomp$699_headers$jscomp$inline_4717$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$vec$$),$APP.$cljs$core$seq$$($JSCompiler_inline_result$jscomp$699_headers$jscomp$inline_4717$$.entries()));return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$JSCompiler_temp_const$jscomp$698$$,$JSCompiler_temp_const$jscomp$697$$,$APP.$cljs$cst$1579$uri$$,$JSCompiler_temp_const$jscomp$696$$,$cljs$cst$1580$headers$$,$JSCompiler_inline_result$jscomp$699_headers$jscomp$inline_4717$$,$APP.$cljs$cst$1581$body$$,$response$jscomp$4$$.body,
$cljs$cst$1586$app_DOT_util_DOT_http_SLASH_response$$,$response$jscomp$4$$],null)};
$app$util$http$process_response_type$$=function($response_type$$,$response$jscomp$5$$){var $native_response$$=$cljs$cst$1586$app_DOT_util_DOT_http_SLASH_response$$.$cljs$core$IFn$_invoke$arity$1$($response$jscomp$5$$),$body$jscomp$5$$=function(){var $G__45205__$1$$=$response_type$$ instanceof $APP.$cljs$core$Keyword$$?$response_type$$.$fqn$:null;switch($G__45205__$1$$){case "buffer":return $native_response$$.arrayBuffer();case "json":return $native_response$$.json();case "text":return $native_response$$.text();
case "blob":return $native_response$$.blob();default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__45205__$1$$)].join(""));}}();return $APP.$beicon$v2$core$map$$(function($body__$1$jscomp$1$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($response$jscomp$5$$,$APP.$cljs$cst$1581$body$$,$body__$1$jscomp$1$$)},$APP.$beicon$v2$core$from$$($body$jscomp$5$$))};
$APP.$app$util$http$send_BANG_$$=function($map__45213__$1_p__45212$$){$map__45213__$1_p__45212$$=$APP.$cljs$core$__destructure_map$$($map__45213__$1_p__45212$$);var $response_type$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__45213__$1_p__45212$$,$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$1588$text$$);return $APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$util$http$process_response_type$$,$response_type$jscomp$1$$),$APP.$beicon$v2$core$map$$($app$util$http$response__GT_map$$,
$APP.$app$util$http$fetch$$($map__45213__$1_p__45212$$)))};
$app$util$http$form_data$$=function($data$jscomp$121$$){return $APP.$cljs$core$reduce_kv$$(function($form$jscomp$147$$,$k$jscomp$576$$,$v$jscomp$500$$){$APP.$cljs$core$list_QMARK_$$($v$jscomp$500$$)?$form$jscomp$147$$.append($APP.$cljs$core$name$$($k$jscomp$576$$),$APP.$cljs$core$first$$($v$jscomp$500$$),$APP.$cljs$core$second$$($v$jscomp$500$$)):$form$jscomp$147$$.append($APP.$cljs$core$name$$($k$jscomp$576$$),$v$jscomp$500$$);return $form$jscomp$147$$},new FormData,$data$jscomp$121$$)};
$APP.$app$util$http$t_app$0util$0http45214$$=function($data$jscomp$122$$,$meta45215$$){this.data=$data$jscomp$122$$;this.$meta45215$=$meta45215$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0};
$app$util$http$conditional_decode_transit$$=function($map__45224__$1_p__45223$$){$map__45224__$1_p__45223$$=$APP.$cljs$core$__destructure_map$$($map__45224__$1_p__45223$$);var $body$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45224__$1_p__45223$$,$APP.$cljs$cst$1581$body$$),$contenttype_headers$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45224__$1_p__45223$$,$cljs$cst$1580$headers$$);$contenttype_headers$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($contenttype_headers$jscomp$8$$,
"content-type");return $APP.$cuerdas$core$starts_with_QMARK_$$($contenttype_headers$jscomp$8$$,"application/transit+json")&&typeof $body$jscomp$6$$==="string"&&$APP.$cljs$core$count$$($body$jscomp$6$$)>0?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__45224__$1_p__45223$$,$APP.$cljs$cst$1581$body$$,$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($body$jscomp$6$$)):$map__45224__$1_p__45223$$};
$app$util$http$conditional_error_decode_transit$$=function($map__45226__$1_p__45225$$){$map__45226__$1_p__45225$$=$APP.$cljs$core$__destructure_map$$($map__45226__$1_p__45225$$);var $body$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45226__$1_p__45225$$,$APP.$cljs$cst$1581$body$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45226__$1_p__45225$$,$APP.$cljs$cst$109$status$$)>=400&&typeof $body$jscomp$7$$==="string"?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__45226__$1_p__45225$$,
$APP.$cljs$cst$1581$body$$,$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($body$jscomp$7$$)):$map__45226__$1_p__45225$$};
$app$common$geom$matrix$Matrix$$=function($a$jscomp$333$$,$b$jscomp$258$$,$c$jscomp$255$$,$d$jscomp$213$$,$e$jscomp$278$$,$f$jscomp$744$$,$$meta$jscomp$4$$,$$extmap$jscomp$4$$,$$hash$jscomp$4$$){this.a=$a$jscomp$333$$;this.b=$b$jscomp$258$$;this.c=$c$jscomp$255$$;this.d=$d$jscomp$213$$;this.e=$e$jscomp$278$$;this.f=$f$jscomp$744$$;this.$$meta$=$$meta$jscomp$4$$;this.$$extmap$=$$extmap$jscomp$4$$;this.$$hash$=$$hash$jscomp$4$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=
139280};$app$common$geom$matrix$pos__GT_Matrix$$=function($a$jscomp$335$$,$b$jscomp$260$$,$c$jscomp$257$$,$d$jscomp$215$$,$e$jscomp$280$$,$f$jscomp$746$$){return new $app$common$geom$matrix$Matrix$$($a$jscomp$335$$,$b$jscomp$260$$,$c$jscomp$257$$,$d$jscomp$215$$,$e$jscomp$280$$,$f$jscomp$746$$,null,null,null)};
$app$common$geom$matrix$map__GT_Matrix$$=function($param_45912$$){var $exclude__42719__auto__$jscomp$2$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$1449$e$$,null,$cljs$cst$1521$c$$,null,$APP.$cljs$cst$1520$b$$,null,$cljs$cst$1447$d$$,null,$cljs$cst$598$f$$,null,$APP.$cljs$cst$1519$a$$,null],null),null),$extmap__42720__auto__$jscomp$2$$=$APP.$cljs$core$reduce_kv$$(function($acc__42721__auto__$jscomp$2$$,$k__42722__auto__$jscomp$2$$,$v__42723__auto__$jscomp$2$$){return $APP.$cljs$core$contains_QMARK_$$($exclude__42719__auto__$jscomp$2$$,
$k__42722__auto__$jscomp$2$$)?$acc__42721__auto__$jscomp$2$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc__42721__auto__$jscomp$2$$,$k__42722__auto__$jscomp$2$$,$v__42723__auto__$jscomp$2$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$param_45912$$);return new $app$common$geom$matrix$Matrix$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45912$$,$APP.$cljs$cst$1519$a$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45912$$,$APP.$cljs$cst$1520$b$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45912$$,
$cljs$cst$1521$c$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45912$$,$cljs$cst$1447$d$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45912$$,$cljs$cst$1449$e$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_45912$$,$cljs$cst$598$f$$),null,$APP.$cljs$core$not_empty$$($extmap__42720__auto__$jscomp$2$$),null)};
$APP.$app$common$geom$matrix$format_precision$$=function($mtx$$,$precision$jscomp$3$$){return $APP.$cljs$core$truth_$$($mtx$$)?"matrix("+($mtx$$.a.toFixed($precision$jscomp$3$$)??"")+", "+($mtx$$.b.toFixed($precision$jscomp$3$$)??"")+", "+($mtx$$.c.toFixed($precision$jscomp$3$$)??"")+", "+($mtx$$.d.toFixed($precision$jscomp$3$$)??"")+", "+($mtx$$.e.toFixed($precision$jscomp$3$$)??"")+", "+($mtx$$.f.toFixed($precision$jscomp$3$$)??"")+")":null};
$app$common$geom$matrix$matrix_QMARK_$$=function($v$jscomp$503$$){return $v$jscomp$503$$ instanceof $app$common$geom$matrix$Matrix$$};
$app$common$geom$matrix$str__GT_matrix$$=function($matrix_str_params$jscomp$92$$){$matrix_str_params$jscomp$92$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$parse_double$$,$APP.$cljs$core$first$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__46035_SHARP_$$){return $APP.$cljs$core$seq$$($APP.$cljs$core$first$$($p1__46035_SHARP_$$))},$APP.$cljs$core$re_seq$$($app$common$geom$matrix$number_regex$$,
$matrix_str_params$jscomp$92$$)));return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$matrix$matrix$$,$matrix_str_params$jscomp$92$$)};$app$common$geom$matrix$decode_matrix$$=function($o$jscomp$235$$){return $APP.$cljs$core$map_QMARK_$$($o$jscomp$235$$)?$app$common$geom$matrix$map__GT_Matrix$$($o$jscomp$235$$):typeof $o$jscomp$235$$==="string"?$app$common$geom$matrix$str__GT_matrix$$($o$jscomp$235$$):$o$jscomp$235$$};
$app$common$geom$matrix$close_QMARK_$$=function($m1$jscomp$7$$,$m2$jscomp$5$$){return $APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($m1$jscomp$7$$.a,$m2$jscomp$5$$.a)&&$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($m1$jscomp$7$$.b,$m2$jscomp$5$$.b)&&$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($m1$jscomp$7$$.c,$m2$jscomp$5$$.c)&&$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($m1$jscomp$7$$.d,$m2$jscomp$5$$.d)&&
$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($m1$jscomp$7$$.e,$m2$jscomp$5$$.e)&&$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($m1$jscomp$7$$.f,$m2$jscomp$5$$.f)};
$app$common$geom$matrix$unit_QMARK_$$=function($m1$jscomp$8$$){return $m1$jscomp$8$$!=null&&$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($m1$jscomp$8$$.a,1)&&$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($m1$jscomp$8$$.b,0)&&$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($m1$jscomp$8$$.c,0)&&$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($m1$jscomp$8$$.d,1)&&$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($m1$jscomp$8$$.e,
0)&&$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($m1$jscomp$8$$.f,0)};
$app$common$geom$matrix$multiply_BANG_$$=function($m1$jscomp$9$$,$m2$jscomp$6_m2f$$){var $m1a$$=$m1$jscomp$9$$.a,$m1b$$=$m1$jscomp$9$$.b,$m1c$$=$m1$jscomp$9$$.c,$m1d$$=$m1$jscomp$9$$.d,$m1e$$=$m1$jscomp$9$$.e,$m1f$$=$m1$jscomp$9$$.f,$m2a$$=$m2$jscomp$6_m2f$$.a,$m2b$$=$m2$jscomp$6_m2f$$.b,$m2c$$=$m2$jscomp$6_m2f$$.c,$m2d$$=$m2$jscomp$6_m2f$$.d,$m2e$$=$m2$jscomp$6_m2f$$.e;$m2$jscomp$6_m2f$$=$m2$jscomp$6_m2f$$.f;$m1$jscomp$9$$.a=$m1a$$*$m2a$$+$m1c$$*$m2b$$;$m1$jscomp$9$$.b=$m1b$$*$m2a$$+$m1d$$*$m2b$$;
$m1$jscomp$9$$.c=$m1a$$*$m2c$$+$m1c$$*$m2d$$;$m1$jscomp$9$$.d=$m1b$$*$m2c$$+$m1d$$*$m2d$$;$m1$jscomp$9$$.e=$m1a$$*$m2e$$+$m1c$$*$m2$jscomp$6_m2f$$+$m1e$$;$m1$jscomp$9$$.f=$m1b$$*$m2e$$+$m1d$$*$m2$jscomp$6_m2f$$+$m1f$$;return $m1$jscomp$9$$};
$app$common$geom$matrix$translate_matrix_neg$cljs$0core$0IFn$0_invoke$0arity$01$$=function($pt$jscomp$11$$){return $app$common$geom$matrix$pos__GT_Matrix$$(1,0,0,1,-($pt$jscomp$11$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$11$$,$APP.$cljs$cst$1510$x$$)),-($pt$jscomp$11$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$11$$,$APP.$cljs$cst$1511$y$$)))};
$APP.$app$common$geom$matrix$rotate$cljs$0core$0IFn$0_invoke$0arity$02$$=function($m$jscomp$184$$,$angle$jscomp$16$$){return $APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$184$$,$APP.$app$common$geom$matrix$rotate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($angle$jscomp$16$$))};
$app$common$geom$matrix$scale$cljs$0core$0IFn$0_invoke$0arity$02$$=function($m$jscomp$186$$,$scale$jscomp$4$$){return $APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$186$$,$app$common$geom$matrix$scale_matrix$$.$cljs$core$IFn$_invoke$arity$1$($scale$jscomp$4$$))};$APP.$app$common$geom$matrix$translate$$=function($m$jscomp$190$$,$pt$jscomp$14$$){return $APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$190$$,$APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($pt$jscomp$14$$))};
$app$common$geom$matrix$translate_BANG_$$=function($m$jscomp$191$$,$pt$jscomp$15$$){return $app$common$geom$matrix$multiply_BANG_$$($m$jscomp$191$$,$APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($pt$jscomp$15$$))};
$APP.$app$common$geom$matrix$transform_in$$=function($pt$jscomp$16$$,$mtx$jscomp$1$$){return $pt$jscomp$16$$!=null&&$mtx$jscomp$1$$!=null?$APP.$app$common$geom$matrix$translate$$($APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$matrix$translate$$($APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$(),$pt$jscomp$16$$),$mtx$jscomp$1$$),$APP.$app$common$geom$point$negate$$($pt$jscomp$16$$)):$mtx$jscomp$1$$};
$app$common$geom$matrix$inverse$$=function($a$jscomp$341_p__46325$$){var $det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$=$APP.$cljs$core$__destructure_map$$($a$jscomp$341_p__46325$$);$a$jscomp$341_p__46325$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,$APP.$cljs$cst$1519$a$$);var $b$jscomp$264$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,$APP.$cljs$cst$1520$b$$),
$c$jscomp$261$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,$cljs$cst$1521$c$$),$d$jscomp$218$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,$cljs$cst$1447$d$$),$e$jscomp$282$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,$cljs$cst$1449$e$$),$f$jscomp$748$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,
$cljs$cst$598$f$$);$det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$=$APP.$cljs$core$__destructure_map$$($det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$);var $a$jscomp$inline_4721$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,$APP.$cljs$cst$1519$a$$),$b$jscomp$inline_4722$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,$APP.$cljs$cst$1520$b$$),$c$jscomp$inline_4723$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,$cljs$cst$1521$c$$),$d$jscomp$inline_4724$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,$cljs$cst$1447$d$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,$APP.$cljs$cst$1102$_$$);$det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$=$a$jscomp$inline_4721$$*$d$jscomp$inline_4724$$-
$c$jscomp$inline_4723$$*$b$jscomp$inline_4722$$;return $APP.$app$common$math$almost_zero_QMARK_$$($det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$)?null:$app$common$geom$matrix$pos__GT_Matrix$$($d$jscomp$218$$/$det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,-$b$jscomp$264$$/$det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,-$c$jscomp$261$$/$det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,$a$jscomp$341_p__46325$$/$det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,($c$jscomp$261$$*
$f$jscomp$748$$-$d$jscomp$218$$*$e$jscomp$282$$)/$det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$,($b$jscomp$264$$*$e$jscomp$282$$-$a$jscomp$341_p__46325$$*$f$jscomp$748$$)/$det_map__46321__$1$jscomp$inline_4720_map__46326__$1$$)};
$APP.$app$common$geom$matrix$transform_point_center$$=function($point$jscomp$10$$,$center$jscomp$7$$,$matrix$jscomp$4$$){return $point$jscomp$10$$!=null&&$matrix$jscomp$4$$!=null&&$center$jscomp$7$$!=null?$APP.$app$common$geom$point$transform$$($point$jscomp$10$$,$APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$7$$),$matrix$jscomp$4$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$point$negate$$($center$jscomp$7$$))]))):
$point$jscomp$10$$};$APP.$app$common$geom$shapes$common$shapes__GT_rect$$=function($shapes$$){return $APP.$app$common$geom$rect$join_rects$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($shape$$){return $APP.$app$common$geom$rect$points__GT_rect$$($shape$$?.points??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$$,$APP.$cljs$cst$1604$points$$))},$shapes$$))};
$APP.$app$common$geom$shapes$common$points__GT_center$$=function($minx$jscomp$4_points$jscomp$3$$){var $maxx$jscomp$4_ptx$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$common$geom$shapes$common$xf_keep_x$$,$minx$jscomp$4_points$jscomp$3$$),$maxy$jscomp$4_pty$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$common$geom$shapes$common$xf_keep_y$$,$minx$jscomp$4_points$jscomp$3$$);$minx$jscomp$4_points$jscomp$3$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$data$min$$,Infinity,$maxx$jscomp$4_ptx$$);var $miny$jscomp$4$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$data$min$$,Infinity,$maxy$jscomp$4_pty$$);$maxx$jscomp$4_ptx$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$data$max$$,-Infinity,$maxx$jscomp$4_ptx$$);$maxy$jscomp$4_pty$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$data$max$$,
-Infinity,$maxy$jscomp$4_pty$$);return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(($minx$jscomp$4_points$jscomp$3$$+$maxx$jscomp$4_ptx$$)/2,($miny$jscomp$4$$+$maxy$jscomp$4_pty$$)/2)};$APP.$app$common$geom$shapes$common$shape__GT_center$$=function($shape$jscomp$1$$){return $APP.$app$common$geom$rect$rect__GT_center$$($shape$jscomp$1$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1$$,$APP.$cljs$cst$1605$selrect$$))};
$APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$02$$=function($points$jscomp$4$$,$matrix$jscomp$5$$){return $APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$03$$($points$jscomp$4$$,null,$matrix$jscomp$5$$)};
$APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$03$$=function($points$jscomp$5$$,$center$jscomp$8_post$$,$matrix$jscomp$6$$){if($app$common$geom$matrix$matrix_QMARK_$$($matrix$jscomp$6$$)&&$APP.$cljs$core$seq$$($points$jscomp$5$$)){var $prev$jscomp$8$$=$center$jscomp$8_post$$!=null?$APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$8_post$$):$cljs$core$_clone$$($app$common$geom$matrix$base$$);$center$jscomp$8_post$$=
$center$jscomp$8_post$$!=null?$app$common$geom$matrix$translate_matrix_neg$cljs$0core$0IFn$0_invoke$0arity$01$$($center$jscomp$8_post$$):$app$common$geom$matrix$base$$;var $mtx$jscomp$4$$=$app$common$geom$matrix$multiply_BANG_$$($app$common$geom$matrix$multiply_BANG_$$($prev$jscomp$8$$,$matrix$jscomp$6$$),$center$jscomp$8_post$$);return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__46397_SHARP_$$){return $APP.$app$common$geom$point$transform$$($p1__46397_SHARP_$$,$mtx$jscomp$4$$)},
$points$jscomp$5$$)}return $points$jscomp$5$$};
$app$common$geom$shapes$common$invalid_geometry_QMARK_$$=function($p__46415_points$jscomp$6$$){var $map__46416__$1_selrect$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($p__46415_points$jscomp$6$$);$p__46415_points$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46416__$1_selrect$jscomp$2$$,$APP.$cljs$cst$1604$points$$);$map__46416__$1_selrect$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46416__$1_selrect$jscomp$2$$,$APP.$cljs$cst$1605$selrect$$);
return $app$common$math$nan_QMARK_$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($map__46416__$1_selrect$jscomp$2$$))||$app$common$math$nan_QMARK_$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($map__46416__$1_selrect$jscomp$2$$))||$app$common$math$nan_QMARK_$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($map__46416__$1_selrect$jscomp$2$$))||$app$common$math$nan_QMARK_$$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($map__46416__$1_selrect$jscomp$2$$))||
$APP.$cljs$core$some$$(function($p$jscomp$197$$){return $app$common$math$nan_QMARK_$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$197$$))||$app$common$math$nan_QMARK_$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$197$$))},$p__46415_points$jscomp$6$$)};
$app$common$geom$shapes$common$shape__GT_points$$=function($p0$jscomp$3_p__46419_transform$jscomp$25$$){var $map__46421__$1_p2$jscomp$33_points$jscomp$7$$=$APP.$cljs$core$__destructure_map$$($p0$jscomp$3_p__46419_transform$jscomp$25$$);$p0$jscomp$3_p__46419_transform$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46421__$1_p2$jscomp$33_points$jscomp$7$$,$APP.$cljs$cst$1289$transform$$);$map__46421__$1_p2$jscomp$33_points$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46421__$1_p2$jscomp$33_points$jscomp$7$$,
$APP.$cljs$cst$1604$points$$);if($app$common$geom$matrix$unit_QMARK_$$($p0$jscomp$3_p__46419_transform$jscomp$25$$)){$p0$jscomp$3_p__46419_transform$jscomp$25$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($map__46421__$1_p2$jscomp$33_points$jscomp$7$$,0);$map__46421__$1_p2$jscomp$33_points$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($map__46421__$1_p2$jscomp$33_points$jscomp$7$$,2);var $p1$jscomp$44$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($map__46421__$1_p2$jscomp$33_points$jscomp$7$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p0$jscomp$3_p__46419_transform$jscomp$25$$)),$p3$jscomp$4$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p0$jscomp$3_p__46419_transform$jscomp$25$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($map__46421__$1_p2$jscomp$33_points$jscomp$7$$));return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p0$jscomp$3_p__46419_transform$jscomp$25$$,
$p1$jscomp$44$$,$map__46421__$1_p2$jscomp$33_points$jscomp$7$$,$p3$jscomp$4$$],null)}return $map__46421__$1_p2$jscomp$33_points$jscomp$7$$};
$APP.$app$common$files$helpers$root_QMARK_$$=function($shape$jscomp$2$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$2$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$2$$,$APP.$cljs$cst$139$type$$),$APP.$cljs$cst$1606$frame$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$2$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$2$$,$APP.$cljs$cst$266$id$$),$APP.$app$common$uuid$zero$$)};
$APP.$app$common$files$helpers$is_direct_child_of_root_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($shape$jscomp$3$$){return $shape$jscomp$3$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$3$$?.$frame_id$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$3$$,$APP.$cljs$cst$1607$frame_id$$),$APP.$app$common$uuid$zero$$)};
$APP.$app$common$files$helpers$bool_shape_QMARK_$$=function($shape$jscomp$8$$){return $shape$jscomp$8$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1610$bool$$,$shape$jscomp$8$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$8$$,$APP.$cljs$cst$139$type$$))};
$APP.$app$common$files$helpers$circle_shape_QMARK_$$=function($map__46505__$1_p__46504_type$jscomp$312$$){$map__46505__$1_p__46504_type$jscomp$312$$=$APP.$cljs$core$__destructure_map$$($map__46505__$1_p__46504_type$jscomp$312$$);$map__46505__$1_p__46504_type$jscomp$312$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46505__$1_p__46504_type$jscomp$312$$,$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__46505__$1_p__46504_type$jscomp$312$$,
$APP.$cljs$cst$1417$circle$$)};$app$common$files$helpers$image_shape_QMARK_$$=function($shape$jscomp$11$$){return $shape$jscomp$11$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1612$image$$,$shape$jscomp$11$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$11$$,$APP.$cljs$cst$139$type$$))};
$app$common$files$helpers$has_layout_QMARK_$$=function($objects$jscomp$9_shape$jscomp$16$$,$id$jscomp$102$$){$objects$jscomp$9_shape$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$9_shape$jscomp$16$$,$id$jscomp$102$$);return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$truth_$$($objects$jscomp$9_shape$jscomp$16$$)?$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$9_shape$jscomp$16$$):$objects$jscomp$9_shape$jscomp$16$$)};
$APP.$app$common$files$helpers$group_like_shape_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($shape$jscomp$17$$){return $APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$17$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$17$$)||$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$17$$)&&$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$17$$))};
$app$common$files$helpers$get_selected_type$$=function($objects$jscomp$11_shape$jscomp$18$$,$selected$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($selected$$))?($objects$jscomp$11_shape$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$11_shape$jscomp$18$$,$APP.$cljs$core$first$$($selected$$)),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$11_shape$jscomp$18$$)):$APP.$cljs$cst$1616$multiple$$};
$app$common$files$helpers$get_shape_type$$=function($objects$jscomp$12_shape$jscomp$19$$,$id$jscomp$104$$){$objects$jscomp$12_shape$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$12_shape$jscomp$19$$,$id$jscomp$104$$);return $APP.$app$common$files$helpers$root_QMARK_$$($objects$jscomp$12_shape$jscomp$19$$)?$cljs$cst$1617$root$$:$objects$jscomp$12_shape$jscomp$19$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$12_shape$jscomp$19$$,$APP.$cljs$cst$139$type$$)};
$app$common$files$helpers$get_children_ids_with_self$$=function($objects$jscomp$15$$,$id$jscomp$107$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$107$$],null),$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$15$$,$id$jscomp$107$$))};
$app$common$files$helpers$get_children$$=function($objects$jscomp$16$$,$id$jscomp$108$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$16$$),$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$16$$,$id$jscomp$108$$))};
$APP.$app$common$files$helpers$get_children_with_self$$=function($objects$jscomp$17$$,$id$jscomp$109$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$17$$),$app$common$files$helpers$get_children_ids_with_self$$($objects$jscomp$17$$,$id$jscomp$109$$))};
$app$common$files$helpers$get_parent$$=function($objects$jscomp$19$$,$id$jscomp$111_temp__5825__auto__$jscomp$111$$){$id$jscomp$111_temp__5825__auto__$jscomp$111$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$19$$,$id$jscomp$111_temp__5825__auto__$jscomp$111$$);return $APP.$cljs$core$truth_$$($id$jscomp$111_temp__5825__auto__$jscomp$111$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$19$$,$id$jscomp$111_temp__5825__auto__$jscomp$111$$?.$parent_id$??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$111_temp__5825__auto__$jscomp$111$$,$APP.$cljs$cst$1619$parent_id$$)):null};
$APP.$app$common$files$helpers$get_parent_id$$=function($objects$jscomp$20_temp__5825__auto__$jscomp$112$$,$id$jscomp$112$$){$objects$jscomp$20_temp__5825__auto__$jscomp$112$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$20_temp__5825__auto__$jscomp$112$$,$id$jscomp$112$$);return $APP.$cljs$core$truth_$$($objects$jscomp$20_temp__5825__auto__$jscomp$112$$)?$objects$jscomp$20_temp__5825__auto__$jscomp$112$$?.$parent_id$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$20_temp__5825__auto__$jscomp$112$$,
$APP.$cljs$cst$1619$parent_id$$):null};
$APP.$app$common$files$helpers$get_parent_ids$$=function($objects$jscomp$21$$,$G__47135_parent_id_shape_id$$){for(var $G__47133_result$jscomp$151$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$id$jscomp$113$$=$G__47135_parent_id_shape_id$$;;)if($G__47135_parent_id_shape_id$$=$APP.$app$common$files$helpers$get_parent_id$$($objects$jscomp$21$$,$id$jscomp$113$$),$G__47135_parent_id_shape_id$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__47135_parent_id_shape_id$$,$id$jscomp$113$$))$G__47133_result$jscomp$151$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__47133_result$jscomp$151$$,$G__47135_parent_id_shape_id$$),$id$jscomp$113$$=$G__47135_parent_id_shape_id$$;else return $G__47133_result$jscomp$151$$};
$APP.$app$common$files$helpers$get_parents$$=function($objects$jscomp$24$$,$G__47138_parent_id$jscomp$2_shape_id$jscomp$3$$){for(var $G__47137_result$jscomp$152$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$id$jscomp$114$$=$G__47138_parent_id$jscomp$2_shape_id$jscomp$3$$;;)if($G__47138_parent_id$jscomp$2_shape_id$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$24$$,$id$jscomp$114$$),$APP.$cljs$cst$1619$parent_id$$),
$G__47138_parent_id$jscomp$2_shape_id$jscomp$3$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__47138_parent_id$jscomp$2_shape_id$jscomp$3$$,$id$jscomp$114$$))$G__47137_result$jscomp$152$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__47137_result$jscomp$152$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$24$$,$G__47138_parent_id$jscomp$2_shape_id$jscomp$3$$)),$id$jscomp$114$$=$G__47138_parent_id$jscomp$2_shape_id$jscomp$3$$;else return $G__47137_result$jscomp$152$$};
$app$common$files$helpers$get_parent_seq$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objects$jscomp$25$$,$shape_id$jscomp$4$$){return $app$common$files$helpers$get_parent_seq$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$25$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$25$$,$shape_id$jscomp$4$$),$shape_id$jscomp$4$$)};
$app$common$files$helpers$get_parent_seq$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$26$$,$shape$jscomp$23$$,$shape_id$jscomp$5$$){var $parent_id$jscomp$3$$=$shape$jscomp$23$$?.$parent_id$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$23$$,$APP.$cljs$cst$1619$parent_id$$),$parent$jscomp$129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$26$$,$parent_id$jscomp$3$$);return $parent$jscomp$129$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parent_id$jscomp$3$$,
$shape_id$jscomp$5$$)?new $APP.$cljs$core$LazySeq$$(null,function(){return $APP.$cljs$core$cons$$($parent$jscomp$129$$,$app$common$files$helpers$get_parent_seq$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$26$$,$parent$jscomp$129$$,$parent_id$jscomp$3$$))},null,null):null};
$app$common$files$helpers$get_parents_with_self$$=function($objects$jscomp$27$$,$id$jscomp$115$$){var $lookup$$=$APP.$app$common$data$getf$$($objects$jscomp$27$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$lookup$$($id$jscomp$115$$)],null),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($lookup$$),$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$27$$,$id$jscomp$115$$))};
$app$common$files$helpers$get_parent_ids_with_index$$=function($objects$jscomp$29$$,$G__47151_parent_id$jscomp$5_shape_id$jscomp$7$$){for(var $parent_list_parent_list__$1$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$G__47150_parent_indices$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$current$jscomp$11$$=$G__47151_parent_id$jscomp$5_shape_id$jscomp$7$$;;){$G__47151_parent_id$jscomp$5_shape_id$jscomp$7$$=$APP.$app$common$files$helpers$get_parent_id$$($objects$jscomp$29$$,$current$jscomp$11$$);var $parent$jscomp$130$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$29$$,$G__47151_parent_id$jscomp$5_shape_id$jscomp$7$$);if($parent$jscomp$130$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__47151_parent_id$jscomp$5_shape_id$jscomp$7$$,$current$jscomp$11$$))$parent_list_parent_list__$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($parent_list_parent_list__$1$$,$G__47151_parent_id$jscomp$5_shape_id$jscomp$7$$),$G__47150_parent_indices$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__47150_parent_indices$$,
$G__47151_parent_id$jscomp$5_shape_id$jscomp$7$$,$APP.$app$common$data$index_of$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$130$$),$current$jscomp$11$$)),$current$jscomp$11$$=$G__47151_parent_id$jscomp$5_shape_id$jscomp$7$$;else return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent_list_parent_list__$1$$,$G__47150_parent_indices$$],null)}};
$app$common$files$helpers$get_siblings_ids$$=function($objects$jscomp$30_parent$jscomp$131$$,$id$jscomp$116$$){$objects$jscomp$30_parent$jscomp$131$$=$app$common$files$helpers$get_parent$$($objects$jscomp$30_parent$jscomp$131$$,$id$jscomp$116$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__46761_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__46761_SHARP_$$,
$id$jscomp$116$$)}),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$30_parent$jscomp$131$$))};
$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objects$jscomp$32$$,$G__46782__$1_shape_or_id$$){if($APP.$cljs$core$map_QMARK_$$($G__46782__$1_shape_or_id$$))return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__46782__$1_shape_or_id$$)?$G__46782__$1_shape_or_id$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$32$$,$G__46782__$1_shape_or_id$$?.$frame_id$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__46782__$1_shape_or_id$$,
$APP.$cljs$cst$1607$frame_id$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$G__46782__$1_shape_or_id$$))return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$32$$,$APP.$app$common$uuid$zero$$);$G__46782__$1_shape_or_id$$=$G__46782__$1_shape_or_id$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$32$$,$G__46782__$1_shape_or_id$$);return $G__46782__$1_shape_or_id$$==null?null:$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$32$$,
$G__46782__$1_shape_or_id$$)};
$app$common$files$helpers$get_position_on_parent$$=function($objects$jscomp$36_prt$$,$id$jscomp$117$$){var $obj$jscomp$171_pid$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$36_prt$$,$id$jscomp$117$$);$obj$jscomp$171_pid$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$171_pid$$);$objects$jscomp$36_prt$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$36_prt$$,$obj$jscomp$171_pid$$);return $APP.$app$common$data$index_of$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$36_prt$$),$id$jscomp$117$$)};
$app$common$files$helpers$get_prev_sibling$$=function($objects$jscomp$37_prt$jscomp$1_shapes$jscomp$2$$,$id$jscomp$118_pos$jscomp$92$$){var $obj$jscomp$172_pid$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$37_prt$jscomp$1_shapes$jscomp$2$$,$id$jscomp$118_pos$jscomp$92$$);$obj$jscomp$172_pid$jscomp$1$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$172_pid$jscomp$1$$);$objects$jscomp$37_prt$jscomp$1_shapes$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$37_prt$jscomp$1_shapes$jscomp$2$$,
$obj$jscomp$172_pid$jscomp$1$$);$objects$jscomp$37_prt$jscomp$1_shapes$jscomp$2$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$37_prt$jscomp$1_shapes$jscomp$2$$);$id$jscomp$118_pos$jscomp$92$$=$APP.$app$common$data$index_of$$($objects$jscomp$37_prt$jscomp$1_shapes$jscomp$2$$,$id$jscomp$118_pos$jscomp$92$$);return $id$jscomp$118_pos$jscomp$92$$!=null&&$id$jscomp$118_pos$jscomp$92$$>0?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$37_prt$jscomp$1_shapes$jscomp$2$$,
$id$jscomp$118_pos$jscomp$92$$-1):null};$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objects$jscomp$39$$,$shape_id$jscomp$10$$){return $APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$39$$,$shape_id$jscomp$10$$,null)};
$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$40$$,$shape_id$jscomp$11$$,$map__46832__$1_p__46831$$){$map__46832__$1_p__46831$$=$APP.$cljs$core$__destructure_map$$($map__46832__$1_p__46831$$);var $remove_hidden$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__46832__$1_p__46831$$,$APP.$cljs$cst$1621$remove_hidden$$,!1),$remove_blocked$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__46832__$1_p__46831$$,
$cljs$cst$1622$remove_blocked$$,!1),$lookup$jscomp$1$$=$APP.$app$common$data$getf$$($objects$jscomp$40$$);return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($app$common$geom$shapes$common$invalid_geometry_QMARK_$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cid_temp__5825__auto__$jscomp$113$$){$cid_temp__5825__auto__$jscomp$113$$=$lookup$jscomp$1$$($cid_temp__5825__auto__$jscomp$113$$);return $APP.$cljs$core$truth_$$($cid_temp__5825__auto__$jscomp$113$$)?($APP.$cljs$core$not$$($remove_hidden$$)||
$APP.$cljs$core$not$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($cid_temp__5825__auto__$jscomp$113$$)))&&($APP.$cljs$core$not$$($remove_blocked$$)||$APP.$cljs$core$not$$($APP.$cljs$cst$1623$blocked$$.$cljs$core$IFn$_invoke$arity$1$($cid_temp__5825__auto__$jscomp$113$$)))?$cid_temp__5825__auto__$jscomp$113$$:null:null},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($lookup$jscomp$1$$($shape_id$jscomp$11$$))))};
$app$common$files$helpers$get_base_shape$$=function($objects$jscomp$41$$,$indexed_shapes_selected$jscomp$1_sorted_ids$$){$indexed_shapes_selected$jscomp$1_sorted_ids$$=$app$common$files$helpers$indexed_shapes$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$files$helpers$indexed_shapes$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$41$$,$indexed_shapes_selected$jscomp$1_sorted_ids$$):$app$common$files$helpers$indexed_shapes$$($objects$jscomp$41$$,$indexed_shapes_selected$jscomp$1_sorted_ids$$);$indexed_shapes_selected$jscomp$1_sorted_ids$$=
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$val$$,$indexed_shapes_selected$jscomp$1_sorted_ids$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$41$$,$APP.$cljs$core$first$$($indexed_shapes_selected$jscomp$1_sorted_ids$$))};$app$common$files$helpers$page_QMARK_$$=function($container$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($container$$),$APP.$cljs$cst$1624$page$$)};
$app$common$files$helpers$components_nesting_loop_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$44_parents$$,$children$jscomp$134_shape_id$jscomp$13$$,$parent_id$jscomp$7$$){$children$jscomp$134_shape_id$jscomp$13$$=$APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$44_parents$$,$children$jscomp$134_shape_id$jscomp$13$$);$objects$jscomp$44_parents$$=$app$common$files$helpers$get_parents_with_self$$($objects$jscomp$44_parents$$,$parent_id$jscomp$7$$);return $app$common$files$helpers$components_nesting_loop_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($children$jscomp$134_shape_id$jscomp$13$$,
$objects$jscomp$44_parents$$)};
$app$common$files$helpers$components_nesting_loop_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($child_components_children$jscomp$135$$,$parent_components_parents$jscomp$1$$){var $xf_get_component_id$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1627$component_id$$);$child_components_children$jscomp$135$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$xf_get_component_id$$,$child_components_children$jscomp$135$$);$parent_components_parents$jscomp$1$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$xf_get_component_id$$,$parent_components_parents$jscomp$1$$);return $APP.$cljs$core$seq$$($APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($child_components_children$jscomp$135$$,$parent_components_parents$jscomp$1$$))};
$APP.$app$common$files$helpers$get_used_names$$=function($elements$jscomp$5_elements__$1$$){$elements$jscomp$5_elements__$1$$=$APP.$cljs$core$map_QMARK_$$($elements$jscomp$5_elements__$1$$)?$APP.$cljs$core$vals$$($elements$jscomp$5_elements__$1$$):$elements$jscomp$5_elements__$1$$;return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$725$name$$),$elements$jscomp$5_elements__$1$$)};
$app$common$files$helpers$name_seq$$=function($base_name$$,$suffix_fn$$){return $APP.$cljs$core$cons$$($base_name$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__46895_SHARP_$$){return""+($base_name$$??"")+(($suffix_fn$$.$cljs$core$IFn$_invoke$arity$1$?$suffix_fn$$.$cljs$core$IFn$_invoke$arity$1$($p1__46895_SHARP_$$):$suffix_fn$$($p1__46895_SHARP_$$))??"")},$cljs$core$iterate$$($APP.$cljs$core$inc$$,1)))};
$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($base_name$jscomp$1$$,$existing_names$$,$map__46907__$1_names$jscomp$1_p__46906_suffix_fn__$1$$){$map__46907__$1_names$jscomp$1_p__46906_suffix_fn__$1$$=$APP.$cljs$core$__destructure_map$$($map__46907__$1_names$jscomp$1_p__46906_suffix_fn__$1$$);var $suffix_fn$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46907__$1_names$jscomp$1_p__46906_suffix_fn__$1$$,$APP.$cljs$cst$1628$suffix_fn$$),
$immediate_suffix_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46907__$1_names$jscomp$1_p__46906_suffix_fn__$1$$,$APP.$cljs$cst$1629$immediate_suffix_QMARK_$$),$suffix$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46907__$1_names$jscomp$1_p__46906_suffix_fn__$1$$,$APP.$cljs$cst$1371$suffix$$);$map__46907__$1_names$jscomp$1_p__46906_suffix_fn__$1$$=$APP.$cljs$core$truth_$$($suffix_fn$jscomp$1$$)?$suffix_fn$jscomp$1$$:$APP.$cljs$core$truth_$$($suffix$jscomp$15$$)?
function($copy_count$$){return"-"+($suffix$jscomp$15$$??"")+(($copy_count$$>1?["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($copy_count$$)].join(""):null)??"")}:function($copy_count$jscomp$1$$){return" "+($copy_count$jscomp$1$$??"")};var $existing_name_set$$=function(){var $G__46913$$=$APP.$cljs$core$set$$($existing_names$$);return $APP.$cljs$core$truth_$$($immediate_suffix_QMARK_$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__46913$$,$base_name$jscomp$1$$):$G__46913$$}();
$map__46907__$1_names$jscomp$1_p__46906_suffix_fn__$1$$=$app$common$files$helpers$name_seq$$($base_name$jscomp$1$$,$map__46907__$1_names$jscomp$1_p__46906_suffix_fn__$1$$);return $APP.$cljs$core$first$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__46900_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($existing_name_set$$,$p1__46900_SHARP_$$)},$map__46907__$1_names$jscomp$1_p__46906_suffix_fn__$1$$))};
$app$common$files$helpers$append_at_the_end$$=function($prev_ids$$,$ids$jscomp$12$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$86$$,$id$jscomp$119$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$119$$]),$acc$jscomp$86$$))?$acc$jscomp$86$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$86$$,$id$jscomp$119$$)},$APP.$cljs$core$vec$$($prev_ids$$),$ids$jscomp$12$$)};
$APP.$app$common$files$helpers$clean_loops$$=function($objects$jscomp$45$$,$ids$jscomp$13$$){function $parent_selected_QMARK_$$($id$jscomp$120_parents$jscomp$2$$){$id$jscomp$120_parents$jscomp$2$$=$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$45$$,$id$jscomp$120_parents$jscomp$2$$);return $APP.$cljs$core$some$$(function($p1__46927_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($ids_set$$,$p1__46927_SHARP_$$)},$id$jscomp$120_parents$jscomp$2$$)}if($APP.$cljs$core$count$$($ids$jscomp$13$$)<=
1)return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$ids$jscomp$13$$);var $ids_set$$=$APP.$cljs$core$set_QMARK_$$($ids$jscomp$13$$)?$ids$jscomp$13$$:$APP.$cljs$core$set$$($ids$jscomp$13$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$153$$,$id$jscomp$121$$){return $APP.$cljs$core$not$$($parent_selected_QMARK_$$($id$jscomp$121$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$153$$,
$id$jscomp$121$$):$result$jscomp$153$$},$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$ids$jscomp$13$$)};
$app$common$files$helpers$indexed_shapes$$=function($objects$jscomp$46$$,$selected$jscomp$2$$){var $G__47190_G__47196_index$jscomp$146$$=1,$G__47197_result$jscomp$154_temp__5823__auto__$jscomp$98$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$add_QMARK__pending__$1$$=!1,$G__47191_G__47199_pending$jscomp$3_result__$1$jscomp$9$$=$APP.$cljs$core$set$$($selected$jscomp$2$$);var $G__47194_G__47200_rev$jscomp$inline_11835_shapes$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$46$$,
$APP.$app$common$uuid$zero$$),$APP.$cljs$cst$1614$shapes$$);for($G__47194_G__47200_rev$jscomp$inline_11835_shapes$jscomp$3$$=$APP.$cljs$core$_rseq$$($G__47194_G__47200_rev$jscomp$inline_11835_shapes$jscomp$3$$);;){var $G__47193_shape_id$jscomp$14$$=$APP.$cljs$core$first$$($G__47194_G__47200_rev$jscomp$inline_11835_shapes$jscomp$3$$),$G__47192_G__47198_add_QMARK___$1_and__5023__auto__$jscomp$inline_4726$$=$APP.$app$common$data$not_empty_QMARK_$$($G__47191_G__47199_pending$jscomp$3_result__$1$jscomp$9$$);
if($APP.$cljs$core$truth_$$($G__47192_G__47198_add_QMARK___$1_and__5023__auto__$jscomp$inline_4726$$?$G__47193_shape_id$jscomp$14$$:$G__47192_G__47198_add_QMARK___$1_and__5023__auto__$jscomp$inline_4726$$)){var $shape$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$46$$,$G__47193_shape_id$jscomp$14$$);$G__47192_G__47198_add_QMARK___$1_and__5023__auto__$jscomp$inline_4726$$=$add_QMARK__pending__$1$$||$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$2$$,$G__47193_shape_id$jscomp$14$$);
$add_QMARK__pending__$1$$=$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($G__47191_G__47199_pending$jscomp$3_result__$1$jscomp$9$$,$G__47193_shape_id$jscomp$14$$);$G__47191_G__47199_pending$jscomp$3_result__$1$jscomp$9$$=$G__47192_G__47198_add_QMARK___$1_and__5023__auto__$jscomp$inline_4726$$?$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__47197_result$jscomp$154_temp__5823__auto__$jscomp$98$$,new $APP.$cljs$core$MapEntry$$($G__47190_G__47196_index$jscomp$146$$,$G__47193_shape_id$jscomp$14$$,
null)):$G__47197_result$jscomp$154_temp__5823__auto__$jscomp$98$$;$G__47197_result$jscomp$154_temp__5823__auto__$jscomp$98$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$25$$,$APP.$cljs$cst$1614$shapes$$);$APP.$cljs$core$truth_$$($G__47197_result$jscomp$154_temp__5823__auto__$jscomp$98$$)?($G__47190_G__47196_index$jscomp$146$$+=1,$G__47193_shape_id$jscomp$14$$=$add_QMARK__pending__$1$$,$G__47194_G__47200_rev$jscomp$inline_11835_shapes$jscomp$3$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_rseq$$($G__47197_result$jscomp$154_temp__5823__auto__$jscomp$98$$),
$APP.$cljs$core$rest$$($G__47194_G__47200_rev$jscomp$inline_11835_shapes$jscomp$3$$)),$G__47197_result$jscomp$154_temp__5823__auto__$jscomp$98$$=$G__47191_G__47199_pending$jscomp$3_result__$1$jscomp$9$$,$add_QMARK__pending__$1$$=$G__47192_G__47198_add_QMARK___$1_and__5023__auto__$jscomp$inline_4726$$,$G__47191_G__47199_pending$jscomp$3_result__$1$jscomp$9$$=$G__47193_shape_id$jscomp$14$$):($G__47190_G__47196_index$jscomp$146$$+=1,$G__47197_result$jscomp$154_temp__5823__auto__$jscomp$98$$=$G__47191_G__47199_pending$jscomp$3_result__$1$jscomp$9$$,
$G__47191_G__47199_pending$jscomp$3_result__$1$jscomp$9$$=$add_QMARK__pending__$1$$,$G__47194_G__47200_rev$jscomp$inline_11835_shapes$jscomp$3$$=$APP.$cljs$core$rest$$($G__47194_G__47200_rev$jscomp$inline_11835_shapes$jscomp$3$$),$add_QMARK__pending__$1$$=$G__47192_G__47198_add_QMARK___$1_and__5023__auto__$jscomp$inline_4726$$)}else return $APP.$cljs$core$_persistent_BANG_$$($G__47197_result$jscomp$154_temp__5823__auto__$jscomp$98$$)}};
$APP.$app$common$files$helpers$expand_region_selection$$=function($indexed_shapes$jscomp$1_objects$jscomp$47$$,$indexes_selection$jscomp$5_selection__$1_xform$jscomp$16$$){$indexes_selection$jscomp$5_selection__$1_xform$jscomp$16$$=$APP.$cljs$core$set_QMARK_$$($indexes_selection$jscomp$5_selection__$1_xform$jscomp$16$$)?$indexes_selection$jscomp$5_selection__$1_xform$jscomp$16$$:$APP.$cljs$core$set$$($indexes_selection$jscomp$5_selection__$1_xform$jscomp$16$$);$indexed_shapes$jscomp$1_objects$jscomp$47$$=
$app$common$files$helpers$indexed_shapes$$($indexed_shapes$jscomp$1_objects$jscomp$47$$,$indexes_selection$jscomp$5_selection__$1_xform$jscomp$16$$);$indexes_selection$jscomp$5_selection__$1_xform$jscomp$16$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$key$$,$indexed_shapes$jscomp$1_objects$jscomp$47$$);var $from$jscomp$8$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$min$$,$indexes_selection$jscomp$5_selection__$1_xform$jscomp$16$$),$to$jscomp$7$$=
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$max$$,$indexes_selection$jscomp$5_selection__$1_xform$jscomp$16$$);$indexes_selection$jscomp$5_selection__$1_xform$jscomp$16$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p__46955$$){var $idx$jscomp$68$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46955$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46955$$,1,
null);return $idx$jscomp$68$$>=$from$jscomp$8$$&&$idx$jscomp$68$$<=$to$jscomp$7$$}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$val$$));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$indexes_selection$jscomp$5_selection__$1_xform$jscomp$16$$,$indexed_shapes$jscomp$1_objects$jscomp$47$$)};
$app$common$files$helpers$order_by_indexed_shapes$$=function($objects$jscomp$48$$,$selected$jscomp$3$$){var $selected__$1$$=$APP.$cljs$core$set_QMARK_$$($selected$jscomp$3$$)?$selected$jscomp$3$$:$APP.$cljs$core$set$$($selected$jscomp$3$$);return $APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($o$jscomp$236$$){return $APP.$cljs$core$contains_QMARK_$$($selected__$1$$,
$APP.$cljs$core$_val$$($o$jscomp$236$$))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$val$$)),$app$common$files$helpers$indexed_shapes$$($objects$jscomp$48$$,$selected__$1$$))};
$app$common$files$helpers$collect_shape_media_refs$$=function($shape$jscomp$26$$){return $APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$266$id$$),$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$26$$),$cljs$cst$1633$metadata$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$26$$)],
null),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1632$fill_image$$,$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$26$$)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1635$stroke_image$$,$APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$26$$)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1632$fill_image$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$1634$fills$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$tree_seq$$($APP.$cljs$core$map_QMARK_$$,$APP.$cljs$cst$342$children$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$26$$))])))])))};
$APP.$app$common$files$helpers$selected_subtree$$=function($objects$jscomp$52$$,$selected$jscomp$4$$){var $selected_PLUS_parents$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($selected$jscomp$4$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__47010_SHARP_$$){return $APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$52$$,$p1__47010_SHARP_$$)}),$selected$jscomp$4$$);return $APP.$cljs$core$update_vals$$($APP.$cljs$core$select_keys$$($objects$jscomp$52$$,
$selected_PLUS_parents$$),function($shape$jscomp$28$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$28$$,$APP.$cljs$cst$1614$shapes$$,function($p1__47011_SHARP_$$){return $APP.$cljs$core$filterv$$($selected_PLUS_parents$$,$p1__47011_SHARP_$$)})})};
$APP.$app$common$files$helpers$is_child_QMARK_$$=function($objects$jscomp$53$$,$parent_id$jscomp$8$$,$candidate_child_id_cur_id_cur_parent_id$$){for(;;){$candidate_child_id_cur_id_cur_parent_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$53$$,$candidate_child_id_cur_id_cur_parent_id$$),$APP.$cljs$cst$1619$parent_id$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parent_id$jscomp$8$$,$candidate_child_id_cur_id_cur_parent_id$$))return!0;
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($candidate_child_id_cur_id_cur_parent_id$$,$APP.$app$common$uuid$zero$$)||$candidate_child_id_cur_id_cur_parent_id$$==null)return!1}};
$APP.$app$common$files$helpers$reduce_objects$cljs$0core$0IFn$0_invoke$0arity$04$$=function($objects$jscomp$55$$,$reducer_fn$jscomp$1$$){return $app$common$files$helpers$reduce_objects$cljs$0core$0IFn$0_invoke$0arity$05$$($objects$jscomp$55$$,$APP.$cljs$core$complement$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$),$APP.$app$common$uuid$zero$$,$reducer_fn$jscomp$1$$,$APP.$cljs$core$PersistentVector$EMPTY$$)};
$app$common$files$helpers$reduce_objects$cljs$0core$0IFn$0_invoke$0arity$05$$=function($objects$jscomp$56$$,$check_children_QMARK_$jscomp$1$$,$G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$,$reducer_fn$jscomp$2$$,$G__47233_G__47240_current_val_init_val$jscomp$2_next_val$$){$G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$56$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$,$APP.$cljs$cst$1614$shapes$$],null));if($APP.$cljs$core$empty_QMARK_$$($G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$))return $G__47233_G__47240_current_val_init_val$jscomp$2_next_val$$;var $G__47234_current_id$jscomp$1_processed__$1$$=$APP.$cljs$core$first$$($G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$);$G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$=$APP.$cljs$core$rest$$($G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$);
for(var $G__47236_G__47242_next_pending_ids_processed$jscomp$1$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$;;)if($APP.$cljs$core$contains_QMARK_$$($G__47236_G__47242_next_pending_ids_processed$jscomp$1$$,$G__47234_current_id$jscomp$1_processed__$1$$))$G__47234_current_id$jscomp$1_processed__$1$$=$APP.$cljs$core$first$$($G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$),$G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$=$APP.$cljs$core$rest$$($G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$);
else{var $current_shape$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$56$$,$G__47234_current_id$jscomp$1_processed__$1$$);$G__47234_current_id$jscomp$1_processed__$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__47236_G__47242_next_pending_ids_processed$jscomp$1$$,$G__47234_current_id$jscomp$1_processed__$1$$);$G__47233_G__47240_current_val_init_val$jscomp$2_next_val$$=$reducer_fn$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$reducer_fn$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($G__47233_G__47240_current_val_init_val$jscomp$2_next_val$$,
$current_shape$$):$reducer_fn$jscomp$2$$($G__47233_G__47240_current_val_init_val$jscomp$2_next_val$$,$current_shape$$);$G__47236_G__47242_next_pending_ids_processed$jscomp$1$$=$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$314$$=$check_children_QMARK_$jscomp$1$$==null;return $or__5025__auto__$jscomp$314$$?$or__5025__auto__$jscomp$314$$:$check_children_QMARK_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$check_children_QMARK_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$$):
$check_children_QMARK_$jscomp$1$$($current_shape$$)}())?$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $or__5025__auto__$jscomp$315$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$315$$)?$or__5025__auto__$jscomp$315$$:$APP.$cljs$core$PersistentVector$EMPTY$$}(),$G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$):$G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$;
if($APP.$cljs$core$empty_QMARK_$$($G__47236_G__47242_next_pending_ids_processed$jscomp$1$$))return $G__47233_G__47240_current_val_init_val$jscomp$2_next_val$$;$G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$=$APP.$cljs$core$first$$($G__47236_G__47242_next_pending_ids_processed$jscomp$1$$);$G__47236_G__47242_next_pending_ids_processed$jscomp$1$$=$APP.$cljs$core$rest$$($G__47236_G__47242_next_pending_ids_processed$jscomp$1$$);var $G__47243$$=$G__47234_current_id$jscomp$1_processed__$1$$;
$G__47234_current_id$jscomp$1_processed__$1$$=$G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$;$G__47235_G__47241_pending_ids_root_children_root_id$jscomp$1$$=$G__47236_G__47242_next_pending_ids_processed$jscomp$1$$;$G__47236_G__47242_next_pending_ids_processed$jscomp$1$$=$G__47243$$}};
$APP.$app$common$files$helpers$selected_with_children$$=function($objects$jscomp$57$$,$selected$jscomp$5$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($selected$jscomp$5$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__47045_SHARP_$$){return $APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$57$$,$p1__47045_SHARP_$$)}),$selected$jscomp$5$$)};
$APP.$app$common$files$helpers$get_shape_id_root_frame$$=function($objects$jscomp$58$$,$shape_id$jscomp$15$$){return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$helpers$root_frame_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$58$$),$APP.$cljs$core$cons$$($shape_id$jscomp$15$$,$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$58$$,
$shape_id$jscomp$15$$)))))};
$APP.$app$common$files$helpers$common_parent_frame$$=function($objects$jscomp$59$$,$G__47251_selected$jscomp$6_selected__$1$jscomp$1$$){var $G__47249_JSCompiler_temp$jscomp$713_frame_id$jscomp$4_frame_id__$1_frame_id__$1$jscomp$inline_4728$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$59$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($G__47251_selected$jscomp$6_selected__$1$jscomp$1$$),$APP.$cljs$cst$1607$frame_id$$],
null)),$G__47250_frame_parents_frame_parents__$1_vec__47061$$=$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$59$$,$G__47249_JSCompiler_temp$jscomp$713_frame_id$jscomp$4_frame_id__$1_frame_id__$1$jscomp$inline_4728$$);for($G__47251_selected$jscomp$6_selected__$1$jscomp$1$$=$APP.$cljs$core$rest$$($G__47251_selected$jscomp$6_selected__$1$jscomp$1$$);;){if($APP.$cljs$core$empty_QMARK_$$($G__47251_selected$jscomp$6_selected__$1$jscomp$1$$))return $G__47249_JSCompiler_temp$jscomp$713_frame_id$jscomp$4_frame_id__$1_frame_id__$1$jscomp$inline_4728$$;
var $current$jscomp$12_parent_QMARK_$$=$APP.$cljs$core$first$$($G__47251_selected$jscomp$6_selected__$1$jscomp$1$$);$current$jscomp$12_parent_QMARK_$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$59$$,$current$jscomp$12_parent_QMARK_$$));$APP.$cljs$core$truth_$$($current$jscomp$12_parent_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$current$jscomp$12_parent_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__47249_JSCompiler_temp$jscomp$713_frame_id$jscomp$4_frame_id__$1_frame_id__$1$jscomp$inline_4728$$):
$current$jscomp$12_parent_QMARK_$$($G__47249_JSCompiler_temp$jscomp$713_frame_id$jscomp$4_frame_id__$1_frame_id__$1$jscomp$inline_4728$$))?$G__47249_JSCompiler_temp$jscomp$713_frame_id$jscomp$4_frame_id__$1_frame_id__$1$jscomp$inline_4728$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__47249_JSCompiler_temp$jscomp$713_frame_id$jscomp$4_frame_id__$1_frame_id__$1$jscomp$inline_4728$$,$G__47250_frame_parents_frame_parents__$1_vec__47061$$],null):($G__47249_JSCompiler_temp$jscomp$713_frame_id$jscomp$4_frame_id__$1_frame_id__$1$jscomp$inline_4728$$=
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($current$jscomp$12_parent_QMARK_$$,$G__47250_frame_parents_frame_parents__$1_vec__47061$$),$G__47249_JSCompiler_temp$jscomp$713_frame_id$jscomp$4_frame_id__$1_frame_id__$1$jscomp$inline_4728$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__47249_JSCompiler_temp$jscomp$713_frame_id$jscomp$4_frame_id__$1_frame_id__$1$jscomp$inline_4728$$,$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$59$$,
$G__47249_JSCompiler_temp$jscomp$713_frame_id$jscomp$4_frame_id__$1_frame_id__$1$jscomp$inline_4728$$)],null));$G__47250_frame_parents_frame_parents__$1_vec__47061$$=$G__47249_JSCompiler_temp$jscomp$713_frame_id$jscomp$4_frame_id__$1_frame_id__$1$jscomp$inline_4728$$;$G__47249_JSCompiler_temp$jscomp$713_frame_id$jscomp$4_frame_id__$1_frame_id__$1$jscomp$inline_4728$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__47250_frame_parents_frame_parents__$1_vec__47061$$,0,null);$G__47250_frame_parents_frame_parents__$1_vec__47061$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__47250_frame_parents_frame_parents__$1_vec__47061$$,1,null);$G__47251_selected$jscomp$6_selected__$1$jscomp$1$$=$APP.$cljs$core$rest$$($G__47251_selected$jscomp$6_selected__$1$jscomp$1$$)}};
$app$common$files$helpers$fixed_scroll_QMARK_$$=function($shape$jscomp$29$$){var $and__5023__auto__$jscomp$219$$=$APP.$cljs$cst$1645$fixed_scroll$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$29$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$219$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$29$$),$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$29$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$29$$),
$APP.$app$common$uuid$zero$$):$and__5023__auto__$jscomp$219$$};
$app$common$files$helpers$fixed_QMARK_$$=function($objects$jscomp$60$$,$ids_to_check_shape_id$jscomp$16$$){$ids_to_check_shape_id$jscomp$16$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$ids_to_check_shape_id$jscomp$16$$],null),$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$60$$,$ids_to_check_shape_id$jscomp$16$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__47068_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__47068_SHARP_$$,
$APP.$app$common$uuid$zero$$)&&$APP.$cljs$core$not$$($APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$60$$,$p1__47068_SHARP_$$))},$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$60$$,$ids_to_check_shape_id$jscomp$16$$))]));return $APP.$cljs$core$boolean$0$$($APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($id$jscomp$123$$){return $app$common$files$helpers$fixed_scroll_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$60$$,
$id$jscomp$123$$))},$ids_to_check_shape_id$jscomp$16$$))};$app$common$geom$shapes$corners$zero_div$$=function($a$jscomp$342$$,$b$jscomp$265$$){return $APP.$app$common$math$almost_zero_QMARK_$$($b$jscomp$265$$)?Infinity:$a$jscomp$342$$/$b$jscomp$265$$};
$app$common$geom$shapes$corners$shape_corners_1$$=function($JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$){$JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$);var $width$jscomp$50_x__5113__auto__$jscomp$inline_14218_y__5114__auto__$jscomp$inline_14219$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$,
$APP.$cljs$cst$290$width$$),$f$jscomp$inline_14217_height$jscomp$42_y__5114__auto__$jscomp$inline_14220$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$,$APP.$cljs$cst$1522$height$$);$JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$,$APP.$cljs$cst$1646$r1$$);$JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$==
null||$APP.$app$common$math$almost_zero_QMARK_$$($JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$)?$JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$=0:($width$jscomp$50_x__5113__auto__$jscomp$inline_14218_y__5114__auto__$jscomp$inline_14219$$=$app$common$geom$shapes$corners$zero_div$$($width$jscomp$50_x__5113__auto__$jscomp$inline_14218_y__5114__auto__$jscomp$inline_14219$$,2*$JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$),$width$jscomp$50_x__5113__auto__$jscomp$inline_14218_y__5114__auto__$jscomp$inline_14219$$=
1<$width$jscomp$50_x__5113__auto__$jscomp$inline_14218_y__5114__auto__$jscomp$inline_14219$$?1:$width$jscomp$50_x__5113__auto__$jscomp$inline_14218_y__5114__auto__$jscomp$inline_14219$$,$f$jscomp$inline_14217_height$jscomp$42_y__5114__auto__$jscomp$inline_14220$$=$app$common$geom$shapes$corners$zero_div$$($f$jscomp$inline_14217_height$jscomp$42_y__5114__auto__$jscomp$inline_14220$$,2*$JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$),$f$jscomp$inline_14217_height$jscomp$42_y__5114__auto__$jscomp$inline_14220$$=
$width$jscomp$50_x__5113__auto__$jscomp$inline_14218_y__5114__auto__$jscomp$inline_14219$$<$f$jscomp$inline_14217_height$jscomp$42_y__5114__auto__$jscomp$inline_14220$$?$width$jscomp$50_x__5113__auto__$jscomp$inline_14218_y__5114__auto__$jscomp$inline_14219$$:$f$jscomp$inline_14217_height$jscomp$42_y__5114__auto__$jscomp$inline_14220$$,$JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$=$f$jscomp$inline_14217_height$jscomp$42_y__5114__auto__$jscomp$inline_14220$$<1?$JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$*
$f$jscomp$inline_14217_height$jscomp$42_y__5114__auto__$jscomp$inline_14220$$:$JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$);return $JSCompiler_temp$jscomp$14048_map__45001__$1_p__45000_r1$jscomp$10$$};
$app$common$geom$shapes$corners$shape_corners_4$$=function($JSCompiler_temp$jscomp$14821_p__45005_r1$jscomp$11$$){var $map__45006__$1_r4$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$14821_p__45005_r1$jscomp$11$$),$width$jscomp$51_x__5113__auto__$jscomp$inline_14829_y__5114__auto__$jscomp$inline_14834$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45006__$1_r4$jscomp$1$$,$APP.$cljs$cst$290$width$$),$f$jscomp$inline_14828_height$jscomp$43_y__5114__auto__$jscomp$inline_14835$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45006__$1_r4$jscomp$1$$,$APP.$cljs$cst$1522$height$$);$JSCompiler_temp$jscomp$14821_p__45005_r1$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45006__$1_r4$jscomp$1$$,$APP.$cljs$cst$1646$r1$$);var $r2$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45006__$1_r4$jscomp$1$$,$APP.$cljs$cst$1647$r2$$),$r3$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45006__$1_r4$jscomp$1$$,
$APP.$cljs$cst$1648$r3$$);$map__45006__$1_r4$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45006__$1_r4$jscomp$1$$,$APP.$cljs$cst$1649$r4$$);if($JSCompiler_temp$jscomp$14821_p__45005_r1$jscomp$11$$!=null&&$r2$jscomp$10$$!=null&&$r3$jscomp$1$$!=null&&$map__45006__$1_r4$jscomp$1$$!=null){var $x__5113__auto__$jscomp$inline_14830_x__5113__auto__$jscomp$inline_14831_y__5114__auto__$jscomp$inline_14832$$=$app$common$geom$shapes$corners$zero_div$$($width$jscomp$51_x__5113__auto__$jscomp$inline_14829_y__5114__auto__$jscomp$inline_14834$$,
$JSCompiler_temp$jscomp$14821_p__45005_r1$jscomp$11$$+$r2$jscomp$10$$);$x__5113__auto__$jscomp$inline_14830_x__5113__auto__$jscomp$inline_14831_y__5114__auto__$jscomp$inline_14832$$=1<$x__5113__auto__$jscomp$inline_14830_x__5113__auto__$jscomp$inline_14831_y__5114__auto__$jscomp$inline_14832$$?1:$x__5113__auto__$jscomp$inline_14830_x__5113__auto__$jscomp$inline_14831_y__5114__auto__$jscomp$inline_14832$$;var $y__5114__auto__$jscomp$inline_14833$$=$app$common$geom$shapes$corners$zero_div$$($f$jscomp$inline_14828_height$jscomp$43_y__5114__auto__$jscomp$inline_14835$$,
$r2$jscomp$10$$+$r3$jscomp$1$$);$x__5113__auto__$jscomp$inline_14830_x__5113__auto__$jscomp$inline_14831_y__5114__auto__$jscomp$inline_14832$$=$x__5113__auto__$jscomp$inline_14830_x__5113__auto__$jscomp$inline_14831_y__5114__auto__$jscomp$inline_14832$$<$y__5114__auto__$jscomp$inline_14833$$?$x__5113__auto__$jscomp$inline_14830_x__5113__auto__$jscomp$inline_14831_y__5114__auto__$jscomp$inline_14832$$:$y__5114__auto__$jscomp$inline_14833$$;$width$jscomp$51_x__5113__auto__$jscomp$inline_14829_y__5114__auto__$jscomp$inline_14834$$=
$app$common$geom$shapes$corners$zero_div$$($width$jscomp$51_x__5113__auto__$jscomp$inline_14829_y__5114__auto__$jscomp$inline_14834$$,$r3$jscomp$1$$+$map__45006__$1_r4$jscomp$1$$);$width$jscomp$51_x__5113__auto__$jscomp$inline_14829_y__5114__auto__$jscomp$inline_14834$$=$x__5113__auto__$jscomp$inline_14830_x__5113__auto__$jscomp$inline_14831_y__5114__auto__$jscomp$inline_14832$$<$width$jscomp$51_x__5113__auto__$jscomp$inline_14829_y__5114__auto__$jscomp$inline_14834$$?$x__5113__auto__$jscomp$inline_14830_x__5113__auto__$jscomp$inline_14831_y__5114__auto__$jscomp$inline_14832$$:
$width$jscomp$51_x__5113__auto__$jscomp$inline_14829_y__5114__auto__$jscomp$inline_14834$$;$f$jscomp$inline_14828_height$jscomp$43_y__5114__auto__$jscomp$inline_14835$$=$app$common$geom$shapes$corners$zero_div$$($f$jscomp$inline_14828_height$jscomp$43_y__5114__auto__$jscomp$inline_14835$$,$map__45006__$1_r4$jscomp$1$$+$JSCompiler_temp$jscomp$14821_p__45005_r1$jscomp$11$$);$f$jscomp$inline_14828_height$jscomp$43_y__5114__auto__$jscomp$inline_14835$$=$width$jscomp$51_x__5113__auto__$jscomp$inline_14829_y__5114__auto__$jscomp$inline_14834$$<
$f$jscomp$inline_14828_height$jscomp$43_y__5114__auto__$jscomp$inline_14835$$?$width$jscomp$51_x__5113__auto__$jscomp$inline_14829_y__5114__auto__$jscomp$inline_14834$$:$f$jscomp$inline_14828_height$jscomp$43_y__5114__auto__$jscomp$inline_14835$$;$JSCompiler_temp$jscomp$14821_p__45005_r1$jscomp$11$$=$f$jscomp$inline_14828_height$jscomp$43_y__5114__auto__$jscomp$inline_14835$$<1?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$14821_p__45005_r1$jscomp$11$$*
$f$jscomp$inline_14828_height$jscomp$43_y__5114__auto__$jscomp$inline_14835$$,$r2$jscomp$10$$*$f$jscomp$inline_14828_height$jscomp$43_y__5114__auto__$jscomp$inline_14835$$,$r3$jscomp$1$$*$f$jscomp$inline_14828_height$jscomp$43_y__5114__auto__$jscomp$inline_14835$$,$map__45006__$1_r4$jscomp$1$$*$f$jscomp$inline_14828_height$jscomp$43_y__5114__auto__$jscomp$inline_14835$$],null):new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$14821_p__45005_r1$jscomp$11$$,
$r2$jscomp$10$$,$r3$jscomp$1$$,$map__45006__$1_r4$jscomp$1$$],null)}else $JSCompiler_temp$jscomp$14821_p__45005_r1$jscomp$11$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$14821_p__45005_r1$jscomp$11$$,$r2$jscomp$10$$,$r3$jscomp$1$$,$map__45006__$1_r4$jscomp$1$$],null);return $JSCompiler_temp$jscomp$14821_p__45005_r1$jscomp$11$$};
$app$common$geom$shapes$effects$update_shadows_scale$$=function($shape$jscomp$32$$,$scale$jscomp$10$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$32$$,$APP.$cljs$cst$1654$shadow$$,function($shadow__$1$jscomp$1$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__45091_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__45091_SHARP_$$,
$APP.$cljs$cst$1650$offset_x$$,$cljs$core$_STAR_$$,$scale$jscomp$10$$),$APP.$cljs$cst$1651$offset_y$$,$cljs$core$_STAR_$$,$scale$jscomp$10$$),$APP.$cljs$cst$1652$spread$$,$cljs$core$_STAR_$$,$scale$jscomp$10$$),$APP.$cljs$cst$1653$blur$$,$cljs$core$_STAR_$$,$scale$jscomp$10$$)},$shadow__$1$jscomp$1$$)})};
$app$common$geom$shapes$strokes$update_strokes_width$$=function($shape$jscomp$34$$,$scale$jscomp$13$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$34$$,$APP.$cljs$cst$1636$strokes$$,function($strokes$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__45189_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__45189_SHARP_$$,$APP.$cljs$cst$1655$stroke_width$$,$cljs$core$_STAR_$$,$scale$jscomp$13$$)},$strokes$$)})};
$app$common$geom$shapes$grid_layout$areas$area__GT_cell_props$$=function($p__45254_row_span$$){var $column$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45254_row_span$$,0,null),$row$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45254_row_span$$,1,null),$column_span$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45254_row_span$$,2,null);$p__45254_row_span$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45254_row_span$$,
3,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1656$row$$,$row$jscomp$3$$,$APP.$cljs$cst$216$column$$,$column$jscomp$10$$,$APP.$cljs$cst$1657$row_span$$,$p__45254_row_span$$,$APP.$cljs$cst$1658$column_span$$,$column_span$$],null)};
$app$common$geom$shapes$grid_layout$areas$make_area$cljs$0core$0IFn$0_invoke$0arity$01$$=function($column$jscomp$11_p__45260$$){var $map__45261__$1_row_span$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($column$jscomp$11_p__45260$$);$column$jscomp$11_p__45260$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45261__$1_row_span$jscomp$1$$,$APP.$cljs$cst$216$column$$);var $row$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45261__$1_row_span$jscomp$1$$,$APP.$cljs$cst$1656$row$$),
$column_span$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45261__$1_row_span$jscomp$1$$,$APP.$cljs$cst$1658$column_span$$);$map__45261__$1_row_span$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45261__$1_row_span$jscomp$1$$,$APP.$cljs$cst$1657$row_span$$);return $app$common$geom$shapes$grid_layout$areas$make_area$cljs$0core$0IFn$0_invoke$0arity$04$$($column$jscomp$11_p__45260$$,$row$jscomp$4$$,$column_span$jscomp$1$$,$map__45261__$1_row_span$jscomp$1$$)};
$app$common$geom$shapes$grid_layout$areas$make_area$cljs$0core$0IFn$0_invoke$0arity$04$$=function($x$jscomp$1089$$,$y$jscomp$346$$,$width$jscomp$52$$,$height$jscomp$44$$){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$x$jscomp$1089$$,$y$jscomp$346$$,$width$jscomp$52$$,$height$jscomp$44$$],null)};
$app$common$geom$shapes$grid_layout$areas$contains_QMARK_$$=function($a_height_p__45270$$,$b_height_p__45271$$){var $a_x$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a_height_p__45270$$,0,null),$a_y$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a_height_p__45270$$,1,null),$a_width$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a_height_p__45270$$,2,null);$a_height_p__45270$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a_height_p__45270$$,3,null);
var $b_x$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height_p__45271$$,0,null),$b_y$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height_p__45271$$,1,null),$b_width$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height_p__45271$$,2,null);$b_height_p__45271$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height_p__45271$$,3,null);return $b_x$$>=$a_x$$&&$b_y$$>=$a_y$$&&$b_x$$+$b_width$$<=$a_x$$+$a_width$$&&$b_y$$+$b_height_p__45271$$<=$a_y$$+
$a_height_p__45270$$};
$app$common$geom$shapes$grid_layout$areas$intersects_QMARK_$$=function($a_height$jscomp$1_p__45279$$,$b_height$jscomp$1_p__45280$$){var $a_x$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a_height$jscomp$1_p__45279$$,0,null),$a_y$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a_height$jscomp$1_p__45279$$,1,null),$a_width$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a_height$jscomp$1_p__45279$$,2,null);$a_height$jscomp$1_p__45279$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a_height$jscomp$1_p__45279$$,
3,null);var $b_x$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$1_p__45280$$,0,null),$b_y$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$1_p__45280$$,1,null),$b_width$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$1_p__45280$$,2,null);$b_height$jscomp$1_p__45280$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$1_p__45280$$,3,null);return!($b_x$jscomp$1$$+$b_width$jscomp$1$$<=
$a_x$jscomp$1$$||$b_y$jscomp$1$$+$b_height$jscomp$1_p__45280$$<=$a_y$jscomp$1$$||$b_x$jscomp$1$$>=$a_x$jscomp$1$$+$a_width$jscomp$1$$||$b_y$jscomp$1$$>=$a_y$jscomp$1$$+$a_height$jscomp$1_p__45279$$)};
$app$common$geom$shapes$grid_layout$areas$top_rect$$=function($b_y$jscomp$2_p__45289$$,$height$jscomp$45_p__45290$$){var $a_x$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_y$jscomp$2_p__45289$$,0,null),$a_y$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_y$jscomp$2_p__45289$$,1,null),$a_width$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_y$jscomp$2_p__45289$$,2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_y$jscomp$2_p__45289$$,
3,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($height$jscomp$45_p__45290$$,0,null);$b_y$jscomp$2_p__45289$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($height$jscomp$45_p__45290$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($height$jscomp$45_p__45290$$,2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($height$jscomp$45_p__45290$$,3,null);$height$jscomp$45_p__45290$$=$b_y$jscomp$2_p__45289$$-$a_y$jscomp$2$$;return $height$jscomp$45_p__45290$$>
0?$app$common$geom$shapes$grid_layout$areas$make_area$cljs$0core$0IFn$0_invoke$0arity$04$$($a_x$jscomp$2$$,$a_y$jscomp$2$$,$a_width$jscomp$2$$,$height$jscomp$45_p__45290$$):null};
$app$common$geom$shapes$grid_layout$areas$bottom_rect$$=function($a_height$jscomp$2_p__45297$$,$b_height$jscomp$2_p__45298_y$jscomp$347$$){var $a_x$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a_height$jscomp$2_p__45297$$,0,null),$a_y$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a_height$jscomp$2_p__45297$$,1,null),$a_width$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a_height$jscomp$2_p__45297$$,2,null);$a_height$jscomp$2_p__45297$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a_height$jscomp$2_p__45297$$,3,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$2_p__45298_y$jscomp$347$$,0,null);var $b_y$jscomp$3_height$jscomp$46$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$2_p__45298_y$jscomp$347$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$2_p__45298_y$jscomp$347$$,2,null);$b_height$jscomp$2_p__45298_y$jscomp$347$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$2_p__45298_y$jscomp$347$$,
3,null);$b_height$jscomp$2_p__45298_y$jscomp$347$$=$b_y$jscomp$3_height$jscomp$46$$+$b_height$jscomp$2_p__45298_y$jscomp$347$$;$b_y$jscomp$3_height$jscomp$46$$=$a_height$jscomp$2_p__45297$$-($b_height$jscomp$2_p__45298_y$jscomp$347$$-$a_y$jscomp$3$$);return $b_y$jscomp$3_height$jscomp$46$$>0&&$b_height$jscomp$2_p__45298_y$jscomp$347$$<$a_y$jscomp$3$$+$a_height$jscomp$2_p__45297$$?$app$common$geom$shapes$grid_layout$areas$make_area$cljs$0core$0IFn$0_invoke$0arity$04$$($a_x$jscomp$3$$,$b_height$jscomp$2_p__45298_y$jscomp$347$$,
$a_width$jscomp$3$$,$b_y$jscomp$3_height$jscomp$46$$):null};
$app$common$geom$shapes$grid_layout$areas$left_rect$$=function($b_x$jscomp$2_p__45319_width$jscomp$53$$,$b_height$jscomp$3_p__45320_rb_y$$){var $a_x$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_x$jscomp$2_p__45319_width$jscomp$53$$,0,null),$a_y$jscomp$4_y1$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_x$jscomp$2_p__45319_width$jscomp$53$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_x$jscomp$2_p__45319_width$jscomp$53$$,2,
null);var $a_height$jscomp$3_ra_y$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_x$jscomp$2_p__45319_width$jscomp$53$$,3,null);$b_x$jscomp$2_p__45319_width$jscomp$53$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$3_p__45320_rb_y$$,0,null);var $b_y$jscomp$4_height$jscomp$47$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$3_p__45320_rb_y$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$3_p__45320_rb_y$$,
2,null);$b_height$jscomp$3_p__45320_rb_y$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$3_p__45320_rb_y$$,3,null);$b_height$jscomp$3_p__45320_rb_y$$=$b_y$jscomp$4_height$jscomp$47$$+$b_height$jscomp$3_p__45320_rb_y$$;$a_height$jscomp$3_ra_y$$=$a_y$jscomp$4_y1$jscomp$17$$+$a_height$jscomp$3_ra_y$$;$a_y$jscomp$4_y1$jscomp$17$$=$a_y$jscomp$4_y1$jscomp$17$$>$b_y$jscomp$4_height$jscomp$47$$?$a_y$jscomp$4_y1$jscomp$17$$:$b_y$jscomp$4_height$jscomp$47$$;$b_y$jscomp$4_height$jscomp$47$$=
($a_height$jscomp$3_ra_y$$<$b_height$jscomp$3_p__45320_rb_y$$?$a_height$jscomp$3_ra_y$$:$b_height$jscomp$3_p__45320_rb_y$$)-$a_y$jscomp$4_y1$jscomp$17$$;$b_x$jscomp$2_p__45319_width$jscomp$53$$-=$a_x$jscomp$4$$;return $b_x$jscomp$2_p__45319_width$jscomp$53$$>0&&$b_y$jscomp$4_height$jscomp$47$$>0?$app$common$geom$shapes$grid_layout$areas$make_area$cljs$0core$0IFn$0_invoke$0arity$04$$($a_x$jscomp$4$$,$a_y$jscomp$4_y1$jscomp$17$$,$b_x$jscomp$2_p__45319_width$jscomp$53$$,$b_y$jscomp$4_height$jscomp$47$$):
null};
$app$common$geom$shapes$grid_layout$areas$right_rect$$=function($b_x$jscomp$3_p__45334_rb_x$$,$b_height$jscomp$4_p__45335_rb_y$jscomp$1$$){var $a_x$jscomp$5_width$jscomp$54$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_x$jscomp$3_p__45334_rb_x$$,0,null),$a_y$jscomp$5_y1$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_x$jscomp$3_p__45334_rb_x$$,1,null),$a_width$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_x$jscomp$3_p__45334_rb_x$$,2,
null),$a_height$jscomp$4_ra_y$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_x$jscomp$3_p__45334_rb_x$$,3,null);$b_x$jscomp$3_p__45334_rb_x$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$4_p__45335_rb_y$jscomp$1$$,0,null);var $b_y$jscomp$5_height$jscomp$48$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$4_p__45335_rb_y$jscomp$1$$,1,null),$b_width$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$4_p__45335_rb_y$jscomp$1$$,
2,null);$b_height$jscomp$4_p__45335_rb_y$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b_height$jscomp$4_p__45335_rb_y$jscomp$1$$,3,null);$b_height$jscomp$4_p__45335_rb_y$jscomp$1$$=$b_y$jscomp$5_height$jscomp$48$$+$b_height$jscomp$4_p__45335_rb_y$jscomp$1$$;$a_height$jscomp$4_ra_y$jscomp$1$$=$a_y$jscomp$5_y1$jscomp$18$$+$a_height$jscomp$4_ra_y$jscomp$1$$;$a_y$jscomp$5_y1$jscomp$18$$=$a_y$jscomp$5_y1$jscomp$18$$>$b_y$jscomp$5_height$jscomp$48$$?$a_y$jscomp$5_y1$jscomp$18$$:
$b_y$jscomp$5_height$jscomp$48$$;$b_y$jscomp$5_height$jscomp$48$$=($a_height$jscomp$4_ra_y$jscomp$1$$<$b_height$jscomp$4_p__45335_rb_y$jscomp$1$$?$a_height$jscomp$4_ra_y$jscomp$1$$:$b_height$jscomp$4_p__45335_rb_y$jscomp$1$$)-$a_y$jscomp$5_y1$jscomp$18$$;$b_x$jscomp$3_p__45334_rb_x$$+=$b_width$jscomp$2$$;$a_x$jscomp$5_width$jscomp$54$$=$a_width$jscomp$4$$-($b_x$jscomp$3_p__45334_rb_x$$-$a_x$jscomp$5_width$jscomp$54$$);return $a_x$jscomp$5_width$jscomp$54$$>0&&$b_y$jscomp$5_height$jscomp$48$$>0?$app$common$geom$shapes$grid_layout$areas$make_area$cljs$0core$0IFn$0_invoke$0arity$04$$($b_x$jscomp$3_p__45334_rb_x$$,
$a_y$jscomp$5_y1$jscomp$18$$,$a_x$jscomp$5_width$jscomp$54$$,$b_y$jscomp$5_height$jscomp$48$$):null};
$app$common$geom$shapes$grid_layout$areas$difference$$=function($area_a$$,$area_b$$){return $area_b$$==null||!$app$common$geom$shapes$grid_layout$areas$intersects_QMARK_$$($area_a$$,$area_b$$)||$app$common$geom$shapes$grid_layout$areas$contains_QMARK_$$($area_b$$,$area_a$$)?$APP.$cljs$core$PersistentVector$EMPTY$$:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__45342_SHARP_$$){return $p1__45342_SHARP_$$.$cljs$core$IFn$_invoke$arity$2$?
$p1__45342_SHARP_$$.$cljs$core$IFn$_invoke$arity$2$($area_a$$,$area_b$$):$p1__45342_SHARP_$$($area_a$$,$area_b$$)}),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$geom$shapes$grid_layout$areas$top_rect$$,$app$common$geom$shapes$grid_layout$areas$left_rect$$,$app$common$geom$shapes$grid_layout$areas$right_rect$$,$app$common$geom$shapes$grid_layout$areas$bottom_rect$$],null))};
$APP.$app$common$types$shape$layout$flex_layout_immediate_child_QMARK_$$=function($objects$jscomp$64_parent$jscomp$132$$,$parent_id$jscomp$9_shape$jscomp$38$$){$parent_id$jscomp$9_shape$jscomp$38$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($parent_id$jscomp$9_shape$jscomp$38$$);$objects$jscomp$64_parent$jscomp$132$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$64_parent$jscomp$132$$,$parent_id$jscomp$9_shape$jscomp$38$$);return $APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$64_parent$jscomp$132$$)};
$APP.$app$common$types$shape$layout$grid_layout_immediate_child_QMARK_$$=function($objects$jscomp$65_parent$jscomp$133$$,$parent_id$jscomp$10_shape$jscomp$39$$){$parent_id$jscomp$10_shape$jscomp$39$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($parent_id$jscomp$10_shape$jscomp$39$$);$objects$jscomp$65_parent$jscomp$133$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$65_parent$jscomp$133$$,$parent_id$jscomp$10_shape$jscomp$39$$);return $APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$65_parent$jscomp$133$$)};
$APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$=function($objects$jscomp$66_parent$jscomp$134$$,$parent_id$jscomp$11_shape$jscomp$40$$){$parent_id$jscomp$11_shape$jscomp$40$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($parent_id$jscomp$11_shape$jscomp$40$$);$objects$jscomp$66_parent$jscomp$134$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$66_parent$jscomp$134$$,$parent_id$jscomp$11_shape$jscomp$40$$);return $APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$66_parent$jscomp$134$$)};
$APP.$app$common$types$shape$layout$any_layout_immediate_child_id_QMARK_$$=function($objects$jscomp$69_parent$jscomp$137$$,$id$jscomp$129_parent_id$jscomp$14$$){$id$jscomp$129_parent_id$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$69_parent$jscomp$137$$,$id$jscomp$129_parent_id$jscomp$14$$),$APP.$cljs$cst$1619$parent_id$$);$objects$jscomp$69_parent$jscomp$137$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$69_parent$jscomp$137$$,
$id$jscomp$129_parent_id$jscomp$14$$);return $APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$69_parent$jscomp$137$$)};
$app$common$types$shape$layout$wrap_QMARK_$$=function($layout_wrap_type_map__47819__$1_p__47818$$){$layout_wrap_type_map__47819__$1_p__47818$$=$APP.$cljs$core$__destructure_map$$($layout_wrap_type_map__47819__$1_p__47818$$);$layout_wrap_type_map__47819__$1_p__47818$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_wrap_type_map__47819__$1_p__47818$$,$APP.$cljs$cst$1684$layout_wrap_type$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_wrap_type_map__47819__$1_p__47818$$,
$APP.$cljs$cst$896$wrap$$)};$app$common$types$shape$layout$fill_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($shape$jscomp$45$$){return $APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$45$$)||$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$45$$)};
$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($child$jscomp$56$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$56$$))};
$APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($child$jscomp$57$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$57$$))};
$app$common$types$shape$layout$auto_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($shape$jscomp$46$$){return $APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$46$$)||$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$46$$)};
$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($layout_flex_dir$jscomp$1_map__47857__$1_p__47856$$){$layout_flex_dir$jscomp$1_map__47857__$1_p__47856$$=$APP.$cljs$core$__destructure_map$$($layout_flex_dir$jscomp$1_map__47857__$1_p__47856$$);$layout_flex_dir$jscomp$1_map__47857__$1_p__47856$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_flex_dir$jscomp$1_map__47857__$1_p__47856$$,$APP.$cljs$cst$1679$layout_flex_dir$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1656$row$$,
$layout_flex_dir$jscomp$1_map__47857__$1_p__47856$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1661$row_reverse$$,$layout_flex_dir$jscomp$1_map__47857__$1_p__47856$$)};
$APP.$app$common$types$shape$layout$gaps$$=function($layout_gap_row_map__47859__$1_p__47858$$){$layout_gap_row_map__47859__$1_p__47858$$=$APP.$cljs$core$__destructure_map$$($layout_gap_row_map__47859__$1_p__47858$$);var $layout_gap$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_gap_row_map__47859__$1_p__47858$$,$APP.$cljs$cst$1680$layout_gap$$);$layout_gap_row_map__47859__$1_p__47858$$=function(){var $or__5025__auto__$jscomp$316$$=$APP.$app$common$math$finite$$($APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($layout_gap$$),
0);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$316$$)?$or__5025__auto__$jscomp$316$$:0}();var $layout_gap_col$$=function(){var $or__5025__auto__$jscomp$317$$=$APP.$app$common$math$finite$$($APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($layout_gap$$),0);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$317$$)?$or__5025__auto__$jscomp$317$$:0}();return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$layout_gap_row_map__47859__$1_p__47858$$,
$layout_gap_col$$],null)};
$app$common$types$shape$layout$paddings$$=function($layout_padding_type_p__47860$$){var $map__47861__$1_map__47863_pad_top$$=$APP.$cljs$core$__destructure_map$$($layout_padding_type_p__47860$$);$layout_padding_type_p__47860$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47861__$1_map__47863_pad_top$$,$APP.$cljs$cst$1685$layout_padding_type$$);$map__47861__$1_map__47863_pad_top$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47861__$1_map__47863_pad_top$$,$APP.$cljs$cst$1686$layout_padding$$);
var $map__47863__$1_pad_left$$=$APP.$cljs$core$__destructure_map$$($map__47861__$1_map__47863_pad_top$$);$map__47861__$1_map__47863_pad_top$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47863__$1_pad_left$$,$APP.$cljs$cst$1093$p1$$);var $pad_right$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47863__$1_pad_left$$,$APP.$cljs$cst$1091$p2$$),$pad_bottom$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47863__$1_pad_left$$,$APP.$cljs$cst$1687$p3$$);$map__47863__$1_pad_left$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47863__$1_pad_left$$,$APP.$cljs$cst$1688$p4$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1663$simple$$,$layout_padding_type_p__47860$$)?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$map__47861__$1_map__47863_pad_top$$,$pad_right$$,$map__47861__$1_map__47863_pad_top$$,$pad_right$$],null):new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$map__47861__$1_map__47863_pad_top$$,$pad_right$$,$pad_bottom$$,$map__47863__$1_pad_left$$],null)};
$app$common$types$shape$layout$child_min_width$$=function($child$jscomp$58_y__5111__auto__$jscomp$34$$){return $APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$58_y__5111__auto__$jscomp$34$$)&&$APP.$cljs$cst$1707$layout_item_min_w$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$58_y__5111__auto__$jscomp$34$$)!=null?($child$jscomp$58_y__5111__auto__$jscomp$34$$=$APP.$cljs$cst$1707$layout_item_min_w$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$58_y__5111__auto__$jscomp$34$$),
.01>$child$jscomp$58_y__5111__auto__$jscomp$34$$?.01:$child$jscomp$58_y__5111__auto__$jscomp$34$$):.01};
$app$common$types$shape$layout$child_max_width$$=function($child$jscomp$59_y__5111__auto__$jscomp$35$$){return $APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$59_y__5111__auto__$jscomp$35$$)&&$APP.$cljs$cst$1706$layout_item_max_w$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$59_y__5111__auto__$jscomp$35$$)!=null?($child$jscomp$59_y__5111__auto__$jscomp$35$$=$APP.$cljs$cst$1706$layout_item_max_w$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$59_y__5111__auto__$jscomp$35$$),
.01>$child$jscomp$59_y__5111__auto__$jscomp$35$$?.01:$child$jscomp$59_y__5111__auto__$jscomp$35$$):Infinity};
$app$common$types$shape$layout$child_min_height$$=function($child$jscomp$60_y__5111__auto__$jscomp$36$$){return $APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$60_y__5111__auto__$jscomp$36$$)&&$APP.$cljs$cst$1705$layout_item_min_h$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$60_y__5111__auto__$jscomp$36$$)!=null?($child$jscomp$60_y__5111__auto__$jscomp$36$$=$APP.$cljs$cst$1705$layout_item_min_h$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$60_y__5111__auto__$jscomp$36$$),
.01>$child$jscomp$60_y__5111__auto__$jscomp$36$$?.01:$child$jscomp$60_y__5111__auto__$jscomp$36$$):.01};
$app$common$types$shape$layout$child_max_height$$=function($child$jscomp$61_y__5111__auto__$jscomp$37$$){return $APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$61_y__5111__auto__$jscomp$37$$)&&$APP.$cljs$cst$1704$layout_item_max_h$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$61_y__5111__auto__$jscomp$37$$)!=null?($child$jscomp$61_y__5111__auto__$jscomp$37$$=$APP.$cljs$cst$1704$layout_item_max_h$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$61_y__5111__auto__$jscomp$37$$),
.01>$child$jscomp$61_y__5111__auto__$jscomp$37$$?.01:$child$jscomp$61_y__5111__auto__$jscomp$37$$):Infinity};
$app$common$types$shape$layout$child_margins$$=function($m3_m3__$1_map__47872_p__47870$$){var $layout_item_margin_type_map__47871__$1$$=$APP.$cljs$core$__destructure_map$$($m3_m3__$1_map__47872_p__47870$$);$m3_m3__$1_map__47872_p__47870$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_margin_type_map__47871__$1$$,$APP.$cljs$cst$1699$layout_item_margin$$);var $m4_m4__$1_map__47872__$1$$=$APP.$cljs$core$__destructure_map$$($m3_m3__$1_map__47872_p__47870$$),$m1$jscomp$16_m1__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m4_m4__$1_map__47872__$1$$,$APP.$cljs$cst$1700$m1$$),$m2$jscomp$13_m2__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m4_m4__$1_map__47872__$1$$,$APP.$cljs$cst$1701$m2$$);$m3_m3__$1_map__47872_p__47870$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m4_m4__$1_map__47872__$1$$,$APP.$cljs$cst$1702$m3$$);$m4_m4__$1_map__47872__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m4_m4__$1_map__47872__$1$$,$APP.$cljs$cst$1703$m4$$);
$layout_item_margin_type_map__47871__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_margin_type_map__47871__$1$$,$APP.$cljs$cst$1698$layout_item_margin_type$$);$m1$jscomp$16_m1__$1$$=$APP.$cljs$core$truth_$$($m1$jscomp$16_m1__$1$$)?$m1$jscomp$16_m1__$1$$:0;$m2$jscomp$13_m2__$1$$=$APP.$cljs$core$truth_$$($m2$jscomp$13_m2__$1$$)?$m2$jscomp$13_m2__$1$$:0;$m3_m3__$1_map__47872_p__47870$$=$APP.$cljs$core$truth_$$($m3_m3__$1_map__47872_p__47870$$)?$m3_m3__$1_map__47872_p__47870$$:
0;$m4_m4__$1_map__47872__$1$$=$APP.$cljs$core$truth_$$($m4_m4__$1_map__47872__$1$$)?$m4_m4__$1_map__47872__$1$$:0;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_margin_type_map__47871__$1$$,$APP.$cljs$cst$1616$multiple$$)?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$m1$jscomp$16_m1__$1$$,$m2$jscomp$13_m2__$1$$,$m3_m3__$1_map__47872_p__47870$$,$m4_m4__$1_map__47872__$1$$],null):new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$m1$jscomp$16_m1__$1$$,$m2$jscomp$13_m2__$1$$,$m1$jscomp$16_m1__$1$$,$m2$jscomp$13_m2__$1$$],null)};
$app$common$types$shape$layout$child_height_margin$$=function($child$jscomp$62_vec__47873$$){$child$jscomp$62_vec__47873$$=$app$common$types$shape$layout$child_margins$$($child$jscomp$62_vec__47873$$);var $top$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$62_vec__47873$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$62_vec__47873$$,1,null);var $bottom$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$62_vec__47873$$,
2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$62_vec__47873$$,3,null);return $top$jscomp$5$$+$bottom$jscomp$2$$};
$app$common$types$shape$layout$child_width_margin$$=function($child$jscomp$63_right$jscomp$14$$){var $left$jscomp$14_vec__47876$$=$app$common$types$shape$layout$child_margins$$($child$jscomp$63_right$jscomp$14$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left$jscomp$14_vec__47876$$,0,null);$child$jscomp$63_right$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left$jscomp$14_vec__47876$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left$jscomp$14_vec__47876$$,
2,null);$left$jscomp$14_vec__47876$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left$jscomp$14_vec__47876$$,3,null);return $child$jscomp$63_right$jscomp$14$$+$left$jscomp$14_vec__47876$$};
$app$common$types$shape$layout$h_start_QMARK_$$=function($map__47880__$1_p__47879$$){$map__47880__$1_p__47879$$=$APP.$cljs$core$__destructure_map$$($map__47880__$1_p__47879$$);var $layout_align_items$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47880__$1_p__47879$$,$APP.$cljs$cst$1692$layout_align_items$$),$layout_justify_content$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47880__$1_p__47879$$,$APP.$cljs$cst$1689$layout_justify_content$$);return $APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__47880__$1_p__47879$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_items$$,$APP.$cljs$cst$1292$start$$)||$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($map__47880__$1_p__47879$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_justify_content$$,$APP.$cljs$cst$1292$start$$)};
$app$common$types$shape$layout$h_center_QMARK_$$=function($map__47882__$1_p__47881$$){$map__47882__$1_p__47881$$=$APP.$cljs$core$__destructure_map$$($map__47882__$1_p__47881$$);var $layout_align_items$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47882__$1_p__47881$$,$APP.$cljs$cst$1692$layout_align_items$$),$layout_justify_content$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47882__$1_p__47881$$,$APP.$cljs$cst$1689$layout_justify_content$$);return $APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__47882__$1_p__47881$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_items$jscomp$1$$,$APP.$cljs$cst$1667$center$$)||$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($map__47882__$1_p__47881$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_justify_content$jscomp$1$$,$APP.$cljs$cst$1667$center$$)};
$app$common$types$shape$layout$h_end_QMARK_$$=function($map__47884__$1_p__47883$$){$map__47884__$1_p__47883$$=$APP.$cljs$core$__destructure_map$$($map__47884__$1_p__47883$$);var $layout_align_items$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47884__$1_p__47883$$,$APP.$cljs$cst$1692$layout_align_items$$),$layout_justify_content$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47884__$1_p__47883$$,$APP.$cljs$cst$1689$layout_justify_content$$);return $APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__47884__$1_p__47883$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_items$jscomp$2$$,$APP.$cljs$cst$1293$end$$)||$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($map__47884__$1_p__47883$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_justify_content$jscomp$2$$,$APP.$cljs$cst$1293$end$$)};
$app$common$types$shape$layout$v_start_QMARK_$$=function($map__47886__$1_p__47885$$){$map__47886__$1_p__47885$$=$APP.$cljs$core$__destructure_map$$($map__47886__$1_p__47885$$);var $layout_align_items$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47886__$1_p__47885$$,$APP.$cljs$cst$1692$layout_align_items$$),$layout_justify_content$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47886__$1_p__47885$$,$APP.$cljs$cst$1689$layout_justify_content$$);return $APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($map__47886__$1_p__47885$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_items$jscomp$3$$,$APP.$cljs$cst$1292$start$$)||$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__47886__$1_p__47885$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_justify_content$jscomp$3$$,$APP.$cljs$cst$1292$start$$)};
$app$common$types$shape$layout$v_center_QMARK_$$=function($map__47888__$1_p__47887$$){$map__47888__$1_p__47887$$=$APP.$cljs$core$__destructure_map$$($map__47888__$1_p__47887$$);var $layout_align_items$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47888__$1_p__47887$$,$APP.$cljs$cst$1692$layout_align_items$$),$layout_justify_content$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47888__$1_p__47887$$,$APP.$cljs$cst$1689$layout_justify_content$$);return $APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($map__47888__$1_p__47887$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_items$jscomp$4$$,$APP.$cljs$cst$1667$center$$)||$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__47888__$1_p__47887$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_justify_content$jscomp$4$$,$APP.$cljs$cst$1667$center$$)};
$app$common$types$shape$layout$v_end_QMARK_$$=function($map__47890__$1_p__47889$$){$map__47890__$1_p__47889$$=$APP.$cljs$core$__destructure_map$$($map__47890__$1_p__47889$$);var $layout_align_items$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47890__$1_p__47889$$,$APP.$cljs$cst$1692$layout_align_items$$),$layout_justify_content$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47890__$1_p__47889$$,$APP.$cljs$cst$1689$layout_justify_content$$);return $APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($map__47890__$1_p__47889$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_items$jscomp$5$$,$APP.$cljs$cst$1293$end$$)||$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__47890__$1_p__47889$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_justify_content$jscomp$5$$,$APP.$cljs$cst$1293$end$$)};
$app$common$types$shape$layout$content_center_QMARK_$$=function($layout_align_content$jscomp$1_map__47894__$1_p__47893$$){$layout_align_content$jscomp$1_map__47894__$1_p__47893$$=$APP.$cljs$core$__destructure_map$$($layout_align_content$jscomp$1_map__47894__$1_p__47893$$);$layout_align_content$jscomp$1_map__47894__$1_p__47893$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$1_map__47894__$1_p__47893$$,$APP.$cljs$cst$1691$layout_align_content$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1667$center$$,
$layout_align_content$jscomp$1_map__47894__$1_p__47893$$)};
$app$common$types$shape$layout$content_end_QMARK_$$=function($layout_align_content$jscomp$2_map__47896__$1_p__47895$$){$layout_align_content$jscomp$2_map__47896__$1_p__47895$$=$APP.$cljs$core$__destructure_map$$($layout_align_content$jscomp$2_map__47896__$1_p__47895$$);$layout_align_content$jscomp$2_map__47896__$1_p__47895$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$2_map__47896__$1_p__47895$$,$APP.$cljs$cst$1691$layout_align_content$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1293$end$$,
$layout_align_content$jscomp$2_map__47896__$1_p__47895$$)};
$app$common$types$shape$layout$content_around_QMARK_$$=function($layout_align_content$jscomp$4_map__47900__$1_p__47899$$){$layout_align_content$jscomp$4_map__47900__$1_p__47899$$=$APP.$cljs$core$__destructure_map$$($layout_align_content$jscomp$4_map__47900__$1_p__47899$$);$layout_align_content$jscomp$4_map__47900__$1_p__47899$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$4_map__47900__$1_p__47899$$,$APP.$cljs$cst$1691$layout_align_content$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1665$space_around$$,
$layout_align_content$jscomp$4_map__47900__$1_p__47899$$)};
$app$common$types$shape$layout$content_evenly_QMARK_$$=function($layout_align_content$jscomp$5_map__47902__$1_p__47901$$){$layout_align_content$jscomp$5_map__47902__$1_p__47901$$=$APP.$cljs$core$__destructure_map$$($layout_align_content$jscomp$5_map__47902__$1_p__47901$$);$layout_align_content$jscomp$5_map__47902__$1_p__47901$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$5_map__47902__$1_p__47901$$,$APP.$cljs$cst$1691$layout_align_content$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1666$space_evenly$$,
$layout_align_content$jscomp$5_map__47902__$1_p__47901$$)};
$app$common$types$shape$layout$content_stretch_QMARK_$$=function($layout_align_content$jscomp$6_map__47904__$1_p__47903$$){$layout_align_content$jscomp$6_map__47904__$1_p__47903$$=$APP.$cljs$core$__destructure_map$$($layout_align_content$jscomp$6_map__47904__$1_p__47903$$);$layout_align_content$jscomp$6_map__47904__$1_p__47903$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$6_map__47904__$1_p__47903$$,$APP.$cljs$cst$1691$layout_align_content$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1669$stretch$$,
$layout_align_content$jscomp$6_map__47904__$1_p__47903$$)||$layout_align_content$jscomp$6_map__47904__$1_p__47903$$==null};
$app$common$types$shape$layout$align_items_center_QMARK_$$=function($layout_align_items$jscomp$6_map__47907__$1_p__47906$$){$layout_align_items$jscomp$6_map__47907__$1_p__47906$$=$APP.$cljs$core$__destructure_map$$($layout_align_items$jscomp$6_map__47907__$1_p__47906$$);$layout_align_items$jscomp$6_map__47907__$1_p__47906$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_items$jscomp$6_map__47907__$1_p__47906$$,$APP.$cljs$cst$1692$layout_align_items$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_items$jscomp$6_map__47907__$1_p__47906$$,
$APP.$cljs$cst$1667$center$$)};
$app$common$types$shape$layout$align_items_end_QMARK_$$=function($layout_align_items$jscomp$8_map__47915__$1_p__47914$$){$layout_align_items$jscomp$8_map__47915__$1_p__47914$$=$APP.$cljs$core$__destructure_map$$($layout_align_items$jscomp$8_map__47915__$1_p__47914$$);$layout_align_items$jscomp$8_map__47915__$1_p__47914$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_items$jscomp$8_map__47915__$1_p__47914$$,$APP.$cljs$cst$1692$layout_align_items$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_items$jscomp$8_map__47915__$1_p__47914$$,
$APP.$cljs$cst$1293$end$$)};
$APP.$app$common$types$shape$layout$reverse_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($layout_flex_dir$jscomp$2_map__47923__$1_p__47922$$){$layout_flex_dir$jscomp$2_map__47923__$1_p__47922$$=$APP.$cljs$core$__destructure_map$$($layout_flex_dir$jscomp$2_map__47923__$1_p__47922$$);$layout_flex_dir$jscomp$2_map__47923__$1_p__47922$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_flex_dir$jscomp$2_map__47923__$1_p__47922$$,$APP.$cljs$cst$1679$layout_flex_dir$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1661$row_reverse$$,
$layout_flex_dir$jscomp$2_map__47923__$1_p__47922$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1662$column_reverse$$,$layout_flex_dir$jscomp$2_map__47923__$1_p__47922$$)};
$app$common$types$shape$layout$space_between_QMARK_$$=function($layout_justify_content$jscomp$6_map__47925__$1_p__47924$$){$layout_justify_content$jscomp$6_map__47925__$1_p__47924$$=$APP.$cljs$core$__destructure_map$$($layout_justify_content$jscomp$6_map__47925__$1_p__47924$$);$layout_justify_content$jscomp$6_map__47925__$1_p__47924$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_justify_content$jscomp$6_map__47925__$1_p__47924$$,$APP.$cljs$cst$1689$layout_justify_content$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_justify_content$jscomp$6_map__47925__$1_p__47924$$,
$APP.$cljs$cst$1668$space_between$$)};
$app$common$types$shape$layout$space_around_QMARK_$$=function($layout_justify_content$jscomp$7_map__47928__$1_p__47926$$){$layout_justify_content$jscomp$7_map__47928__$1_p__47926$$=$APP.$cljs$core$__destructure_map$$($layout_justify_content$jscomp$7_map__47928__$1_p__47926$$);$layout_justify_content$jscomp$7_map__47928__$1_p__47926$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_justify_content$jscomp$7_map__47928__$1_p__47926$$,$APP.$cljs$cst$1689$layout_justify_content$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_justify_content$jscomp$7_map__47928__$1_p__47926$$,
$APP.$cljs$cst$1665$space_around$$)};
$app$common$types$shape$layout$space_evenly_QMARK_$$=function($layout_justify_content$jscomp$8_map__47930__$1_p__47929$$){$layout_justify_content$jscomp$8_map__47930__$1_p__47929$$=$APP.$cljs$core$__destructure_map$$($layout_justify_content$jscomp$8_map__47930__$1_p__47929$$);$layout_justify_content$jscomp$8_map__47930__$1_p__47929$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_justify_content$jscomp$8_map__47930__$1_p__47929$$,$APP.$cljs$cst$1689$layout_justify_content$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($layout_justify_content$jscomp$8_map__47930__$1_p__47929$$,
$APP.$cljs$cst$1666$space_evenly$$)};
$app$common$types$shape$layout$align_self_start_QMARK_$$=function($layout_item_align_self_map__47932__$1_p__47931$$){$layout_item_align_self_map__47932__$1_p__47931$$=$APP.$cljs$core$__destructure_map$$($layout_item_align_self_map__47932__$1_p__47931$$);$layout_item_align_self_map__47932__$1_p__47931$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_align_self_map__47932__$1_p__47931$$,$APP.$cljs$cst$1710$layout_item_align_self$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1292$start$$,$layout_item_align_self_map__47932__$1_p__47931$$)};
$app$common$types$shape$layout$align_self_end_QMARK_$$=function($layout_item_align_self$jscomp$1_map__47934__$1_p__47933$$){$layout_item_align_self$jscomp$1_map__47934__$1_p__47933$$=$APP.$cljs$core$__destructure_map$$($layout_item_align_self$jscomp$1_map__47934__$1_p__47933$$);$layout_item_align_self$jscomp$1_map__47934__$1_p__47933$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_align_self$jscomp$1_map__47934__$1_p__47933$$,$APP.$cljs$cst$1710$layout_item_align_self$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1293$end$$,
$layout_item_align_self$jscomp$1_map__47934__$1_p__47933$$)};
$app$common$types$shape$layout$align_self_center_QMARK_$$=function($layout_item_align_self$jscomp$2_map__47937__$1_p__47935$$){$layout_item_align_self$jscomp$2_map__47937__$1_p__47935$$=$APP.$cljs$core$__destructure_map$$($layout_item_align_self$jscomp$2_map__47937__$1_p__47935$$);$layout_item_align_self$jscomp$2_map__47937__$1_p__47935$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_align_self$jscomp$2_map__47937__$1_p__47935$$,$APP.$cljs$cst$1710$layout_item_align_self$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1667$center$$,
$layout_item_align_self$jscomp$2_map__47937__$1_p__47935$$)};$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($shape$jscomp$53$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$53$$,$APP.$cljs$cst$1711$layout_item_absolute$$)===!0};
$app$common$types$shape$layout$layout_z_index$cljs$0core$0IFn$0_invoke$0arity$01$$=function($or__5025__auto__$jscomp$323_shape$jscomp$55$$){$or__5025__auto__$jscomp$323_shape$jscomp$55$$=$APP.$cljs$cst$1712$layout_item_z_index$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$323_shape$jscomp$55$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$323_shape$jscomp$55$$)?$or__5025__auto__$jscomp$323_shape$jscomp$55$$:0};
$app$common$types$shape$layout$comparator_layout_z_index$$=function($reverse_QMARK_$$,$child_a_p__47949$$,$child_b_p__47950$$){var $idx_a$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_a_p__47949$$,0,null);$child_a_p__47949$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_a_p__47949$$,1,null);var $idx_b$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_b_p__47950$$,0,null);$child_b_p__47950$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_b_p__47950$$,
1,null);return $app$common$types$shape$layout$layout_z_index$cljs$0core$0IFn$0_invoke$0arity$01$$($child_a_p__47949$$)>$app$common$types$shape$layout$layout_z_index$cljs$0core$0IFn$0_invoke$0arity$01$$($child_b_p__47950$$)?1:$app$common$types$shape$layout$layout_z_index$cljs$0core$0IFn$0_invoke$0arity$01$$($child_a_p__47949$$)<$app$common$types$shape$layout$layout_z_index$cljs$0core$0IFn$0_invoke$0arity$01$$($child_b_p__47950$$)?-1:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$221$$=
$idx_a$$<$idx_b$$;return $and__5023__auto__$jscomp$221$$?$reverse_QMARK_$$:$and__5023__auto__$jscomp$221$$}())?-1:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$222$$=$idx_a$$>$idx_b$$;return $and__5023__auto__$jscomp$222$$?$reverse_QMARK_$$:$and__5023__auto__$jscomp$222$$}())?1:$idx_a$$<$idx_b$$?1:$idx_a$$>$idx_b$$?-1:0};
$app$common$types$shape$layout$change_h_sizing_QMARK_$$=function($and__5023__auto____$2$jscomp$14_frame_id$jscomp$8$$,$objects$jscomp$86$$,$children_ids$$){var $and__5023__auto__$jscomp$223_and__5023__auto____$1$jscomp$42_and__5023__auto____$2$jscomp$inline_4737_or__5025__auto__$jscomp$324$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$86$$,$and__5023__auto____$2$jscomp$14_frame_id$jscomp$8$$);if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$223_and__5023__auto____$1$jscomp$42_and__5023__auto____$2$jscomp$inline_4737_or__5025__auto__$jscomp$324$$)){if($and__5023__auto__$jscomp$223_and__5023__auto____$1$jscomp$42_and__5023__auto____$2$jscomp$inline_4737_or__5025__auto__$jscomp$324$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$86$$,$and__5023__auto____$2$jscomp$14_frame_id$jscomp$8$$),$APP.$cljs$cst$1708$layout_item_h_sizing$$))){$and__5023__auto__$jscomp$223_and__5023__auto____$1$jscomp$42_and__5023__auto____$2$jscomp$inline_4737_or__5025__auto__$jscomp$324$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$86$$,
$and__5023__auto____$2$jscomp$14_frame_id$jscomp$8$$);$and__5023__auto__$jscomp$223_and__5023__auto____$1$jscomp$42_and__5023__auto____$2$jscomp$inline_4737_or__5025__auto__$jscomp$324$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$223_and__5023__auto____$1$jscomp$42_and__5023__auto____$2$jscomp$inline_4737_or__5025__auto__$jscomp$324$$)?$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$fill_width_QMARK_$$,$objects$jscomp$86$$),
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$,$objects$jscomp$86$$),$children_ids$$)):$and__5023__auto__$jscomp$223_and__5023__auto____$1$jscomp$42_and__5023__auto____$2$jscomp$inline_4737_or__5025__auto__$jscomp$324$$;if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$223_and__5023__auto____$1$jscomp$42_and__5023__auto____$2$jscomp$inline_4737_or__5025__auto__$jscomp$324$$))return $and__5023__auto__$jscomp$223_and__5023__auto____$1$jscomp$42_and__5023__auto____$2$jscomp$inline_4737_or__5025__auto__$jscomp$324$$;
$and__5023__auto____$2$jscomp$14_frame_id$jscomp$8$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$86$$,$and__5023__auto____$2$jscomp$14_frame_id$jscomp$8$$));return $APP.$cljs$core$truth_$$($and__5023__auto____$2$jscomp$14_frame_id$jscomp$8$$)?$APP.$cljs$core$some$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$fill_width_QMARK_$$,$objects$jscomp$86$$),
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$,$objects$jscomp$86$$),$children_ids$$)):$and__5023__auto____$2$jscomp$14_frame_id$jscomp$8$$}return $and__5023__auto__$jscomp$223_and__5023__auto____$1$jscomp$42_and__5023__auto____$2$jscomp$inline_4737_or__5025__auto__$jscomp$324$$}return $and__5023__auto__$jscomp$223_and__5023__auto____$1$jscomp$42_and__5023__auto____$2$jscomp$inline_4737_or__5025__auto__$jscomp$324$$};
$app$common$types$shape$layout$change_v_sizing_QMARK_$$=function($and__5023__auto____$2$jscomp$16_frame_id$jscomp$9$$,$objects$jscomp$87$$,$children_ids$jscomp$1$$){var $and__5023__auto__$jscomp$224_and__5023__auto____$1$jscomp$43_and__5023__auto____$2$jscomp$inline_4739_or__5025__auto__$jscomp$325$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$87$$,$and__5023__auto____$2$jscomp$16_frame_id$jscomp$9$$);if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$224_and__5023__auto____$1$jscomp$43_and__5023__auto____$2$jscomp$inline_4739_or__5025__auto__$jscomp$325$$)){if($and__5023__auto__$jscomp$224_and__5023__auto____$1$jscomp$43_and__5023__auto____$2$jscomp$inline_4739_or__5025__auto__$jscomp$325$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$87$$,$and__5023__auto____$2$jscomp$16_frame_id$jscomp$9$$),$APP.$cljs$cst$1709$layout_item_v_sizing$$))){$and__5023__auto__$jscomp$224_and__5023__auto____$1$jscomp$43_and__5023__auto____$2$jscomp$inline_4739_or__5025__auto__$jscomp$325$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$87$$,
$and__5023__auto____$2$jscomp$16_frame_id$jscomp$9$$);$and__5023__auto__$jscomp$224_and__5023__auto____$1$jscomp$43_and__5023__auto____$2$jscomp$inline_4739_or__5025__auto__$jscomp$325$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$224_and__5023__auto____$1$jscomp$43_and__5023__auto____$2$jscomp$inline_4739_or__5025__auto__$jscomp$325$$)?$APP.$cljs$core$some$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$fill_height_QMARK_$$,$objects$jscomp$87$$),
$children_ids$jscomp$1$$):$and__5023__auto__$jscomp$224_and__5023__auto____$1$jscomp$43_and__5023__auto____$2$jscomp$inline_4739_or__5025__auto__$jscomp$325$$;if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$224_and__5023__auto____$1$jscomp$43_and__5023__auto____$2$jscomp$inline_4739_or__5025__auto__$jscomp$325$$))return $and__5023__auto__$jscomp$224_and__5023__auto____$1$jscomp$43_and__5023__auto____$2$jscomp$inline_4739_or__5025__auto__$jscomp$325$$;$and__5023__auto____$2$jscomp$16_frame_id$jscomp$9$$=
$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$87$$,$and__5023__auto____$2$jscomp$16_frame_id$jscomp$9$$));return $APP.$cljs$core$truth_$$($and__5023__auto____$2$jscomp$16_frame_id$jscomp$9$$)?$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$fill_height_QMARK_$$,$objects$jscomp$87$$),$children_ids$jscomp$1$$):$and__5023__auto____$2$jscomp$16_frame_id$jscomp$9$$}return $and__5023__auto__$jscomp$224_and__5023__auto____$1$jscomp$43_and__5023__auto____$2$jscomp$inline_4739_or__5025__auto__$jscomp$325$$}return $and__5023__auto__$jscomp$224_and__5023__auto____$1$jscomp$43_and__5023__auto____$2$jscomp$inline_4739_or__5025__auto__$jscomp$325$$};
$app$common$types$shape$layout$remove_layout_item_data$$=function($shape$jscomp$57$$){var $G__47963_G__47963__$1$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape$jscomp$57$$,$APP.$cljs$cst$1699$layout_item_margin$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1698$layout_item_margin_type$$,$APP.$cljs$cst$1704$layout_item_max_h$$,$APP.$cljs$cst$1705$layout_item_min_h$$,$APP.$cljs$cst$1706$layout_item_max_w$$,$APP.$cljs$cst$1707$layout_item_min_w$$,
$APP.$cljs$cst$1710$layout_item_align_self$$,$APP.$cljs$cst$1711$layout_item_absolute$$,$APP.$cljs$cst$1712$layout_item_z_index$$]));$G__47963_G__47963__$1$$=!$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$57$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$57$$))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__47963_G__47963__$1$$,
$APP.$cljs$cst$1708$layout_item_h_sizing$$):$G__47963_G__47963__$1$$;return!$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$57$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$57$$))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__47963_G__47963__$1$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$):$G__47963_G__47963__$1$$};
$app$common$types$shape$layout$update_grid_scale$$=function($shape$jscomp$59$$,$scale$jscomp$15$$){function $scale_track$$($track$jscomp$4$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$4$$),$APP.$cljs$cst$1671$fixed$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($track$jscomp$4$$,$APP.$cljs$cst$260$value$$,$cljs$core$_STAR_$$,$scale$jscomp$15$$):$track$jscomp$4$$}return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$59$$,
$APP.$cljs$cst$1695$layout_grid_columns$$,function($p1__47970_SHARP_$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($scale_track$$,$p1__47970_SHARP_$$)}),$APP.$cljs$cst$1694$layout_grid_rows$$,function($p1__47971_SHARP_$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($scale_track$$,$p1__47971_SHARP_$$)})};
$app$common$types$shape$layout$add_grid_track$cljs$0core$0IFn$0_invoke$0arity$04$$=function($tracks_prop_type$jscomp$315$$,$parent$jscomp$141$$,$value$jscomp$391$$,$index$jscomp$149_new_index$jscomp$1$$){var $layout_grid_cells_vec__48028$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($tracks_prop_type$jscomp$315$$,$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1695$layout_grid_columns$$,$APP.$cljs$cst$1694$layout_grid_rows$$,
$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$1658$column_span$$,$APP.$cljs$cst$1657$row_span$$],null):new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1694$layout_grid_rows$$,$APP.$cljs$cst$1695$layout_grid_columns$$,$APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1657$row_span$$,$APP.$cljs$cst$1658$column_span$$],null);$tracks_prop_type$jscomp$315$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_grid_cells_vec__48028$$,
0,null);var $layout_grid_cells__$1_tracks_prop_other$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_grid_cells_vec__48028$$,1,null),$prop$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_grid_cells_vec__48028$$,2,null),$prop_other$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_grid_cells_vec__48028$$,3,null),$prop_span$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_grid_cells_vec__48028$$,4,null),$prop_span_other$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_grid_cells_vec__48028$$,5,null);$index$jscomp$149_new_index$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$149_new_index$jscomp$1$$,$APP.$cljs$core$count$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$141$$,$tracks_prop_type$jscomp$315$$)));var $new_track_num$$=$index$jscomp$149_new_index$jscomp$1$$+1;$layout_grid_cells_vec__48028$$=$APP.$cljs$core$update_vals$$($APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$141$$),
function($cell$jscomp$2$$){var $G__48032__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$2$$,$prop$jscomp$14$$)>=$new_track_num$$?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($cell$jscomp$2$$,$prop$jscomp$14$$,$APP.$cljs$core$inc$$):$cell$jscomp$2$$;return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$2$$,$prop$jscomp$14$$)<$new_track_num$$&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$2$$,$prop_span$jscomp$2$$)>1&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$2$$,
$prop$jscomp$14$$)+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$2$$,$prop_span$jscomp$2$$)-1)>=$new_track_num$$?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__48032__$1$$,$prop_span$jscomp$2$$,$APP.$cljs$core$inc$$):$G__48032__$1$$});var $exist_cells_QMARK_$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($cell$jscomp$3$$){return $new_track_num$$>=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$3$$,$prop$jscomp$14$$)&&$new_track_num$$<$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$3$$,$prop$jscomp$14$$)+$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$3$$,$prop_span$jscomp$2$$)}),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__48021_SHARP_$$){return $APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__48021_SHARP_$$,
$prop_other$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__48021_SHARP_$$,$prop_other$$)+$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__48021_SHARP_$$,$prop_span_other$$))})),$APP.$cljs$core$vals$$($layout_grid_cells_vec__48028$$));$layout_grid_cells__$1_tracks_prop_other$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$155$$,$id$jscomp$142_p__48035$$){var $idx$jscomp$69$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$142_p__48035$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$142_p__48035$$,1,null);$id$jscomp$142_p__48035$$=$APP.$app$common$uuid$next$$();return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$155$$,$id$jscomp$142_p__48035$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$,$id$jscomp$142_p__48035$$,$prop_other$$,
$idx$jscomp$69$$+1,$prop$jscomp$14$$,$new_track_num$$]),$app$common$types$shape$layout$grid_cell_defaults$$])))},$layout_grid_cells_vec__48028$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($G__48045_p__48040$$){var $idx$jscomp$70$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__48045_p__48040$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__48045_p__48040$$,1,null);$G__48045_p__48040$$=$idx$jscomp$70$$+1;return $exist_cells_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?
$exist_cells_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__48045_p__48040$$):$exist_cells_QMARK_$$($G__48045_p__48040$$)},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$141$$,$layout_grid_cells__$1_tracks_prop_other$$))));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($parent$jscomp$141$$,$tracks_prop_type$jscomp$315$$,$app$common$data$add_at_index$$,
$index$jscomp$149_new_index$jscomp$1$$,$value$jscomp$391$$),$APP.$cljs$cst$1696$layout_grid_cells$$,$layout_grid_cells__$1_tracks_prop_other$$)};
$app$common$types$shape$layout$make_remove_cell$$=function($attr$jscomp$6$$,$span_attr$$,$track_num$$){return function($cell$jscomp$6_p__48121$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell$jscomp$6_p__48121$$,0,null);$cell$jscomp$6_p__48121$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell$jscomp$6_p__48121$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($track_num$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$6_p__48121$$,
$attr$jscomp$6$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$6_p__48121$$,$span_attr$$),1)}};
$app$common$types$shape$layout$make_decrease_track_num$$=function($attr$jscomp$7$$,$span_attr$jscomp$1$$,$track_num$jscomp$1$$){return function($cell__$1_displace_cell_QMARK__p__48125$$){var $id$jscomp$144$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell__$1_displace_cell_QMARK__p__48125$$,0,null),$G__48131__$1$jscomp$inline_4741_cell$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell__$1_displace_cell_QMARK__p__48125$$,1,null),$inner_track_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($track_num$jscomp$1$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48131__$1$jscomp$inline_4741_cell$jscomp$7$$,$attr$jscomp$7$$))||$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48131__$1$jscomp$inline_4741_cell$jscomp$7$$,$attr$jscomp$7$$)<$track_num$jscomp$1$$&&$track_num$jscomp$1$$<$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48131__$1$jscomp$inline_4741_cell$jscomp$7$$,$attr$jscomp$7$$)+$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48131__$1$jscomp$inline_4741_cell$jscomp$7$$,
$span_attr$jscomp$1$$);$cell__$1_displace_cell_QMARK__p__48125$$=!$inner_track_QMARK_$$&&$track_num$jscomp$1$$<$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48131__$1$jscomp$inline_4741_cell$jscomp$7$$,$attr$jscomp$7$$);$G__48131__$1$jscomp$inline_4741_cell$jscomp$7$$=$inner_track_QMARK_$$?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__48131__$1$jscomp$inline_4741_cell$jscomp$7$$,$span_attr$jscomp$1$$,$APP.$cljs$core$dec$$):$G__48131__$1$jscomp$inline_4741_cell$jscomp$7$$;
$cell__$1_displace_cell_QMARK__p__48125$$=$cell__$1_displace_cell_QMARK__p__48125$$?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__48131__$1$jscomp$inline_4741_cell$jscomp$7$$,$attr$jscomp$7$$,$APP.$cljs$core$dec$$):$G__48131__$1$jscomp$inline_4741_cell$jscomp$7$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$144$$,$cell__$1_displace_cell_QMARK__p__48125$$],null)}};
$app$common$types$shape$layout$remove_grid_column$$=function($G__48133_parent$jscomp$146$$,$index$jscomp$154$$,$objects$jscomp$92$$){var $track_num$jscomp$2$$=$index$jscomp$154$$+1,$decrease_track_num$$=$app$common$types$shape$layout$make_decrease_track_num$$($APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1658$column_span$$,$track_num$jscomp$2$$),$remove_track_QMARK_$$=$app$common$types$shape$layout$make_remove_cell$$($APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1658$column_span$$,$track_num$jscomp$2$$);
$G__48133_parent$jscomp$146$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48133_parent$jscomp$146$$,$APP.$cljs$cst$1695$layout_grid_columns$$,$APP.$app$common$data$remove_at_index$$,$index$jscomp$154$$),$APP.$cljs$cst$1696$layout_grid_cells$$,function($cells$jscomp$2$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($remove_track_QMARK_$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($decrease_track_num$$)),$cells$jscomp$2$$)});return $APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$($G__48133_parent$jscomp$146$$,$objects$jscomp$92$$):$APP.$app$common$types$shape$layout$assign_cells$$($G__48133_parent$jscomp$146$$,$objects$jscomp$92$$)};
$app$common$types$shape$layout$remove_grid_row$$=function($G__48139_parent$jscomp$147$$,$index$jscomp$155$$,$objects$jscomp$93$$){var $track_num$jscomp$3$$=$index$jscomp$155$$+1,$decrease_track_num$jscomp$1$$=$app$common$types$shape$layout$make_decrease_track_num$$($APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$1657$row_span$$,$track_num$jscomp$3$$),$remove_track_QMARK_$jscomp$1$$=$app$common$types$shape$layout$make_remove_cell$$($APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$1657$row_span$$,$track_num$jscomp$3$$);
$G__48139_parent$jscomp$147$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48139_parent$jscomp$147$$,$APP.$cljs$cst$1694$layout_grid_rows$$,$APP.$app$common$data$remove_at_index$$,$index$jscomp$155$$),$APP.$cljs$cst$1696$layout_grid_cells$$,function($cells$jscomp$3$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($remove_track_QMARK_$jscomp$1$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($decrease_track_num$jscomp$1$$)),$cells$jscomp$3$$)});return $APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$($G__48139_parent$jscomp$147$$,$objects$jscomp$93$$):$APP.$app$common$types$shape$layout$assign_cells$$($G__48139_parent$jscomp$147$$,$objects$jscomp$93$$)};
$app$common$types$shape$layout$cells_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($layout_grid_cells$jscomp$1_p__48158$$,$map__48161__$1_maybe_sort_QMARK__p__48159_sort_QMARK_$$){var $comp_fn$jscomp$1_layout_grid_dir_map__48160__$1$$=$APP.$cljs$core$__destructure_map$$($layout_grid_cells$jscomp$1_p__48158$$);$layout_grid_cells$jscomp$1_p__48158$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($comp_fn$jscomp$1_layout_grid_dir_map__48160__$1$$,$APP.$cljs$cst$1696$layout_grid_cells$$);
$comp_fn$jscomp$1_layout_grid_dir_map__48160__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($comp_fn$jscomp$1_layout_grid_dir_map__48160__$1$$,$APP.$cljs$cst$1693$layout_grid_dir$$);$map__48161__$1_maybe_sort_QMARK__p__48159_sort_QMARK_$$=$APP.$cljs$core$__destructure_map$$($map__48161__$1_maybe_sort_QMARK__p__48159_sort_QMARK_$$);$map__48161__$1_maybe_sort_QMARK__p__48159_sort_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__48161__$1_maybe_sort_QMARK__p__48159_sort_QMARK_$$,
$APP.$cljs$cst$1713$sort_QMARK_$$,!1);$comp_fn$jscomp$1_layout_grid_dir_map__48160__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($comp_fn$jscomp$1_layout_grid_dir_map__48160__$1$$,$APP.$cljs$cst$1656$row$$)?$APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$216$column$$):$APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1656$row$$);$map__48161__$1_maybe_sort_QMARK__p__48159_sort_QMARK_$$=
$APP.$cljs$core$truth_$$($map__48161__$1_maybe_sort_QMARK__p__48159_sort_QMARK_$$)?$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$sort_by$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($comp_fn$jscomp$1_layout_grid_dir_map__48160__$1$$,$APP.$cljs$core$second$$)):$APP.$cljs$core$identity$$;return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$map__48161__$1_maybe_sort_QMARK__p__48159_sort_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?
$map__48161__$1_maybe_sort_QMARK__p__48159_sort_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($layout_grid_cells$jscomp$1_p__48158$$):$map__48161__$1_maybe_sort_QMARK__p__48159_sort_QMARK_$$($layout_grid_cells$jscomp$1_p__48158$$))};
$app$common$types$shape$layout$get_free_cells$cljs$0core$0IFn$0_invoke$0arity$02$$=function($parent$jscomp$154$$,$map__48168__$1_p__48167_sort_QMARK_$jscomp$1$$){$map__48168__$1_p__48167_sort_QMARK_$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($map__48168__$1_p__48167_sort_QMARK_$jscomp$1$$);$map__48168__$1_p__48167_sort_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__48168__$1_p__48167_sort_QMARK_$jscomp$1$$,$APP.$cljs$cst$1713$sort_QMARK_$$,!1);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$empty_QMARK_$$,$APP.$cljs$cst$1614$shapes$$),$app$common$types$shape$layout$cells_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($parent$jscomp$154$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1713$sort_QMARK_$$,$map__48168__$1_p__48167_sort_QMARK_$jscomp$1$$]))))};
$APP.$app$common$types$shape$layout$get_cells$cljs$0core$0IFn$0_invoke$0arity$02$$=function($G__48180_parent$jscomp$156$$,$p__48178_sort_QMARK_$jscomp$2$$){var $map__48179__$1_maybe_remove_QMARK__remove_empty_QMARK_$$=$APP.$cljs$core$__destructure_map$$($p__48178_sort_QMARK_$jscomp$2$$);$p__48178_sort_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__48179__$1_maybe_remove_QMARK__remove_empty_QMARK_$$,$APP.$cljs$cst$1713$sort_QMARK_$$,!1);$map__48179__$1_maybe_remove_QMARK__remove_empty_QMARK_$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__48179__$1_maybe_remove_QMARK__remove_empty_QMARK_$$,$cljs$cst$1714$remove_empty_QMARK_$$,!1);$map__48179__$1_maybe_remove_QMARK__remove_empty_QMARK_$$=$APP.$cljs$core$truth_$$($map__48179__$1_maybe_remove_QMARK__remove_empty_QMARK_$$)?$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$remove$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$empty_QMARK_$$,$APP.$cljs$cst$1614$shapes$$)):$APP.$cljs$core$identity$$;
$G__48180_parent$jscomp$156$$=$app$common$types$shape$layout$cells_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__48180_parent$jscomp$156$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1713$sort_QMARK_$$,$p__48178_sort_QMARK_$jscomp$2$$]));return $map__48179__$1_maybe_remove_QMARK__remove_empty_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$map__48179__$1_maybe_remove_QMARK__remove_empty_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__48180_parent$jscomp$156$$):$map__48179__$1_maybe_remove_QMARK__remove_empty_QMARK_$$($G__48180_parent$jscomp$156$$)};
$app$common$types$shape$layout$check_deassigned_cells$$=function($parent$jscomp$157$$,$objects$jscomp$94$$){function $assigned_QMARK_$$($id$jscomp$145$$){return $APP.$cljs$core$contains_QMARK_$$($child_set$$,$id$jscomp$145$$)&&$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$94$$,$id$jscomp$145$$))}var $child_set$$=$APP.$cljs$core$set$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$157$$)),
$cells$jscomp$4$$=$APP.$cljs$core$update_vals$$($APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$157$$),function($cell$jscomp$9$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($cell$jscomp$9$$,$APP.$cljs$cst$1614$shapes$$,function($p1__48181_SHARP_$$){return $APP.$cljs$core$filterv$$($assigned_QMARK_$$,$p1__48181_SHARP_$$)})});return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parent$jscomp$157$$,$APP.$cljs$cst$1696$layout_grid_cells$$,
$cells$jscomp$4$$)};
$app$common$types$shape$layout$reassign_positions$$=function($parent$jscomp$160$$){return $APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($auto_QMARK__auto_QMARK___$1_p__48208_vec__48215$$,$cell$jscomp$11_cell__$1$jscomp$1$$){var $parent__$1$jscomp$42$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($auto_QMARK__auto_QMARK___$1_p__48208_vec__48215$$,0,null);$auto_QMARK__auto_QMARK___$1_p__48208_vec__48215$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($auto_QMARK__auto_QMARK___$1_p__48208_vec__48215$$,1,
null);$auto_QMARK__auto_QMARK___$1_p__48208_vec__48215$$=$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$11_cell__$1$jscomp$1$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1673$manual$$,$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$11_cell__$1$jscomp$1$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1657$row_span$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$11_cell__$1$jscomp$1$$),
1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1658$column_span$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$11_cell__$1$jscomp$1$$),1)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cell$jscomp$11_cell__$1$jscomp$1$$,!1],null):($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1657$row_span$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$11_cell__$1$jscomp$1$$),1)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1658$column_span$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$11_cell__$1$jscomp$1$$),
1))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$11_cell__$1$jscomp$1$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cell$jscomp$11_cell__$1$jscomp$1$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1673$manual$$),!1],null):$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$11_cell__$1$jscomp$1$$))?
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cell$jscomp$11_cell__$1$jscomp$1$$,!1],null):$APP.$cljs$core$not$$($auto_QMARK__auto_QMARK___$1_p__48208_vec__48215$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$11_cell__$1$jscomp$1$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cell$jscomp$11_cell__$1$jscomp$1$$,
$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1673$manual$$),!1],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1673$manual$$,$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$11_cell__$1$jscomp$1$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cell$jscomp$11_cell__$1$jscomp$1$$,!1],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cell$jscomp$11_cell__$1$jscomp$1$$,
$auto_QMARK__auto_QMARK___$1_p__48208_vec__48215$$],null);$cell$jscomp$11_cell__$1$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($auto_QMARK__auto_QMARK___$1_p__48208_vec__48215$$,0,null);$auto_QMARK__auto_QMARK___$1_p__48208_vec__48215$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($auto_QMARK__auto_QMARK___$1_p__48208_vec__48215$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc_in$$($parent__$1$jscomp$42$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$11_cell__$1$jscomp$1$$)],null),$cell$jscomp$11_cell__$1$jscomp$1$$),$auto_QMARK__auto_QMARK___$1_p__48208_vec__48215$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent$jscomp$160$$,!0],null),$app$common$types$shape$layout$cells_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($parent$jscomp$160$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1713$sort_QMARK_$$,!0]))))};
$app$common$types$shape$layout$position_auto_shapes$$=function($parent$jscomp$161$$){var $auto_cells$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48219_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($p1__48219_SHARP_$$),$APP.$cljs$cst$1672$auto$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1657$row_span$$.$cljs$core$IFn$_invoke$arity$1$($p1__48219_SHARP_$$),1)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1658$column_span$$.$cljs$core$IFn$_invoke$arity$1$($p1__48219_SHARP_$$),1)},$app$common$types$shape$layout$cells_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($parent$jscomp$161$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1713$sort_QMARK_$$,!0]))),$shapes$jscomp$5$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$auto_cells$$]));
return function(){for(var $G__48606_parent__$1$jscomp$44$$=$parent$jscomp$161$$,$G__48607_cells$jscomp$6$$=$APP.$cljs$core$seq$$($auto_cells$$),$G__48608_shapes__$1$$=$APP.$cljs$core$seq$$($shapes$jscomp$5$$);;){if($APP.$cljs$core$empty_QMARK_$$($G__48607_cells$jscomp$6$$))return $G__48606_parent__$1$jscomp$44$$;var $shape$jscomp$66$$=$APP.$cljs$core$first$$($G__48608_shapes__$1$$),$cell$jscomp$12$$=$APP.$cljs$core$first$$($G__48607_cells$jscomp$6$$);$G__48606_parent__$1$jscomp$44$$=$APP.$cljs$core$assoc_in$$($G__48606_parent__$1$jscomp$44$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$12$$),$APP.$cljs$cst$1614$shapes$$],null),$shape$jscomp$66$$!=null?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$66$$],null):$APP.$cljs$core$PersistentVector$EMPTY$$);$G__48607_cells$jscomp$6$$=$APP.$cljs$core$rest$$($G__48607_cells$jscomp$6$$);
$G__48608_shapes__$1$$=$APP.$cljs$core$rest$$($G__48608_shapes__$1$$)}}()};$app$common$types$shape$layout$assign_cell_positions$$=function($parent$jscomp$162$$,$objects$jscomp$95$$){return $app$common$types$shape$layout$position_auto_shapes$$($app$common$types$shape$layout$reassign_positions$$($app$common$types$shape$layout$check_deassigned_cells$$($parent$jscomp$162$$,$objects$jscomp$95$$)))};
$APP.$app$common$types$shape$layout$assign_cells$$=function($free_cells_parent$jscomp$163_shape_has_cell_QMARK__to_add_tracks$$,$cells$jscomp$7_objects$jscomp$96_parent__$2$jscomp$2$$){var $parent__$1$jscomp$45$$=$app$common$types$shape$layout$assign_cell_positions$$($free_cells_parent$jscomp$163_shape_has_cell_QMARK__to_add_tracks$$,$cells$jscomp$7_objects$jscomp$96_parent__$2$jscomp$2$$);$free_cells_parent$jscomp$163_shape_has_cell_QMARK__to_add_tracks$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$second$$)),$APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$45$$));var $no_cell_shapes$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$,$cells$jscomp$7_objects$jscomp$96_parent__$2$jscomp$2$$),
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($free_cells_parent$jscomp$163_shape_has_cell_QMARK__to_add_tracks$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$45$$)));if($APP.$cljs$core$empty_QMARK_$$($no_cell_shapes$$))return $parent__$1$jscomp$45$$;$cells$jscomp$7_objects$jscomp$96_parent__$2$jscomp$2$$=function(){var $G__48232__$1$$=$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1695$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$45$$))?
$APP.$app$common$types$shape$layout$add_grid_column$$.$cljs$core$IFn$_invoke$arity$2$($parent__$1$jscomp$45$$,$APP.$app$common$types$shape$layout$default_track_value$$):$parent__$1$jscomp$45$$;return $APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1694$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$45$$))?$APP.$app$common$types$shape$layout$add_grid_row$$.$cljs$core$IFn$_invoke$arity$2$($G__48232__$1$$,$APP.$app$common$types$shape$layout$default_track_value$$):$G__48232__$1$$}();
$free_cells_parent$jscomp$163_shape_has_cell_QMARK__to_add_tracks$$=$app$common$types$shape$layout$get_free_cells$cljs$0core$0IFn$0_invoke$0arity$02$$($cells$jscomp$7_objects$jscomp$96_parent__$2$jscomp$2$$,null);$free_cells_parent$jscomp$163_shape_has_cell_QMARK__to_add_tracks$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1693$layout_grid_dir$$.$cljs$core$IFn$_invoke$arity$1$($cells$jscomp$7_objects$jscomp$96_parent__$2$jscomp$2$$),$APP.$cljs$cst$1656$row$$)?$APP.$app$common$math$ceil$$(($APP.$cljs$core$count$$($no_cell_shapes$$)-
$APP.$cljs$core$count$$($free_cells_parent$jscomp$163_shape_has_cell_QMARK__to_add_tracks$$))/$APP.$cljs$core$count$$($APP.$cljs$cst$1694$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($cells$jscomp$7_objects$jscomp$96_parent__$2$jscomp$2$$))):$APP.$app$common$math$ceil$$(($APP.$cljs$core$count$$($no_cell_shapes$$)-$APP.$cljs$core$count$$($free_cells_parent$jscomp$163_shape_has_cell_QMARK__to_add_tracks$$))/$APP.$cljs$core$count$$($APP.$cljs$cst$1695$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($cells$jscomp$7_objects$jscomp$96_parent__$2$jscomp$2$$)));
var $add_track$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1693$layout_grid_dir$$.$cljs$core$IFn$_invoke$arity$1$($cells$jscomp$7_objects$jscomp$96_parent__$2$jscomp$2$$),$APP.$cljs$cst$1656$row$$)?$APP.$app$common$types$shape$layout$add_grid_column$$:$APP.$app$common$types$shape$layout$add_grid_row$$,$parent__$3$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($parent__$3$jscomp$1$$){return $add_track$$.$cljs$core$IFn$_invoke$arity$2$?$add_track$$.$cljs$core$IFn$_invoke$arity$2$($parent__$3$jscomp$1$$,
$APP.$app$common$types$shape$layout$default_track_value$$):$add_track$$($parent__$3$jscomp$1$$,$APP.$app$common$types$shape$layout$default_track_value$$)},$cells$jscomp$7_objects$jscomp$96_parent__$2$jscomp$2$$,$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($free_cells_parent$jscomp$163_shape_has_cell_QMARK__to_add_tracks$$));$cells$jscomp$7_objects$jscomp$96_parent__$2$jscomp$2$$=function(){for(var $G__48612_cells$jscomp$8$$=$APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($parent__$3$$),
$G__48613_free_cells__$1$$=$app$common$types$shape$layout$get_free_cells$cljs$0core$0IFn$0_invoke$0arity$02$$($parent__$3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1713$sort_QMARK_$$,!0],null)),$G__48614_pending$jscomp$4$$=$no_cell_shapes$$;;){if($APP.$cljs$core$empty_QMARK_$$($G__48613_free_cells__$1$$)||$APP.$cljs$core$empty_QMARK_$$($G__48614_pending$jscomp$4$$))return $G__48612_cells$jscomp$8$$;var $next_free$$=$APP.$cljs$core$first$$($G__48613_free_cells__$1$$),$current$jscomp$14$$=
$APP.$cljs$core$first$$($G__48614_pending$jscomp$4$$);$G__48612_cells$jscomp$8$$=$APP.$cljs$core$assoc_in$$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__48612_cells$jscomp$8$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$next_free$$,$APP.$cljs$cst$1614$shapes$$],null),$APP.$cljs$core$conj$$,$current$jscomp$14$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$next_free$$,$APP.$cljs$cst$1676$position$$],
null),$APP.$cljs$cst$1672$auto$$);$G__48613_free_cells__$1$$=$APP.$cljs$core$rest$$($G__48613_free_cells__$1$$);$G__48614_pending$jscomp$4$$=$APP.$cljs$core$rest$$($G__48614_pending$jscomp$4$$)}}();return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parent__$3$$,$APP.$cljs$cst$1696$layout_grid_cells$$,$cells$jscomp$7_objects$jscomp$96_parent__$2$jscomp$2$$)};
$app$common$types$shape$layout$free_cell_push$$=function($G__48617$jscomp$inline_4752_idx$jscomp$inline_4745_parent$jscomp$164_parent__$1$jscomp$46$$,$cells$jscomp$9$$,$index$jscomp$156$$){var $parent__$1$jscomp$inline_4743_parent__$2$jscomp$inline_4749_result_cells_start_cell_vec__48239$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$9$$,$index$jscomp$156$$);if($APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$inline_4743_parent__$2$jscomp$inline_4749_result_cells_start_cell_vec__48239$$)))return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__48617$jscomp$inline_4752_idx$jscomp$inline_4745_parent$jscomp$164_parent__$1$jscomp$46$$,$cells$jscomp$9$$],null);a:{$parent__$1$jscomp$inline_4743_parent__$2$jscomp$inline_4749_result_cells_start_cell_vec__48239$$=$G__48617$jscomp$inline_4752_idx$jscomp$inline_4745_parent$jscomp$164_parent__$1$jscomp$46$$;var $G__48616$jscomp$inline_4751_result_cells$jscomp$inline_4744_result_cells__$1$jscomp$inline_4750$$=$cells$jscomp$9$$;for($G__48617$jscomp$inline_4752_idx$jscomp$inline_4745_parent$jscomp$164_parent__$1$jscomp$46$$=
$index$jscomp$156$$;;){if($G__48617$jscomp$inline_4752_idx$jscomp$inline_4745_parent$jscomp$164_parent__$1$jscomp$46$$>$APP.$cljs$core$count$$($cells$jscomp$9$$)-2){$parent__$1$jscomp$inline_4743_parent__$2$jscomp$inline_4749_result_cells_start_cell_vec__48239$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent__$1$jscomp$inline_4743_parent__$2$jscomp$inline_4749_result_cells_start_cell_vec__48239$$,$G__48616$jscomp$inline_4751_result_cells$jscomp$inline_4744_result_cells__$1$jscomp$inline_4750$$],
null);break a}var $cell$jscomp$inline_4748_cell_from$jscomp$inline_4746$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$9$$,$G__48617$jscomp$inline_4752_idx$jscomp$inline_4745_parent$jscomp$164_parent__$1$jscomp$46$$),$cell_to$jscomp$inline_4747$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$9$$,$G__48617$jscomp$inline_4752_idx$jscomp$inline_4745_parent$jscomp$164_parent__$1$jscomp$46$$+1);$cell$jscomp$inline_4748_cell_from$jscomp$inline_4746$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($cell_to$jscomp$inline_4747$$,
$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_4748_cell_from$jscomp$inline_4746$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_4748_cell_from$jscomp$inline_4746$$)]));$parent__$1$jscomp$inline_4743_parent__$2$jscomp$inline_4749_result_cells_start_cell_vec__48239$$=$APP.$cljs$core$assoc_in$$($parent__$1$jscomp$inline_4743_parent__$2$jscomp$inline_4749_result_cells_start_cell_vec__48239$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_4748_cell_from$jscomp$inline_4746$$)],null),$cell$jscomp$inline_4748_cell_from$jscomp$inline_4746$$);$G__48616$jscomp$inline_4751_result_cells$jscomp$inline_4744_result_cells__$1$jscomp$inline_4750$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48616$jscomp$inline_4751_result_cells$jscomp$inline_4744_result_cells__$1$jscomp$inline_4750$$,
$G__48617$jscomp$inline_4752_idx$jscomp$inline_4745_parent$jscomp$164_parent__$1$jscomp$46$$+1,$cell$jscomp$inline_4748_cell_from$jscomp$inline_4746$$);if($APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell_to$jscomp$inline_4747$$))){$parent__$1$jscomp$inline_4743_parent__$2$jscomp$inline_4749_result_cells_start_cell_vec__48239$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent__$1$jscomp$inline_4743_parent__$2$jscomp$inline_4749_result_cells_start_cell_vec__48239$$,
$G__48616$jscomp$inline_4751_result_cells$jscomp$inline_4744_result_cells__$1$jscomp$inline_4750$$],null);break a}$G__48617$jscomp$inline_4752_idx$jscomp$inline_4745_parent$jscomp$164_parent__$1$jscomp$46$$+=1}$parent__$1$jscomp$inline_4743_parent__$2$jscomp$inline_4749_result_cells_start_cell_vec__48239$$=void 0}$G__48617$jscomp$inline_4752_idx$jscomp$inline_4745_parent$jscomp$164_parent__$1$jscomp$46$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($parent__$1$jscomp$inline_4743_parent__$2$jscomp$inline_4749_result_cells_start_cell_vec__48239$$,
0,null);$parent__$1$jscomp$inline_4743_parent__$2$jscomp$inline_4749_result_cells_start_cell_vec__48239$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($parent__$1$jscomp$inline_4743_parent__$2$jscomp$inline_4749_result_cells_start_cell_vec__48239$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc_in$$($G__48617$jscomp$inline_4752_idx$jscomp$inline_4745_parent$jscomp$164_parent__$1$jscomp$46$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$9$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$156$$,$APP.$cljs$cst$266$id$$],null)),$APP.$cljs$cst$1614$shapes$$],null),$APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($parent__$1$jscomp$inline_4743_parent__$2$jscomp$inline_4749_result_cells_start_cell_vec__48239$$,
$index$jscomp$156$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1672$auto$$]))],null)};
$app$common$types$shape$layout$in_cell_QMARK_$$=function($cell_row_p__48245$$,$row$jscomp$5$$,$column$jscomp$12$$){var $column_span$jscomp$2_map__48246__$1$$=$APP.$cljs$core$__destructure_map$$($cell_row_p__48245$$);$cell_row_p__48245$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$2_map__48246__$1$$,$APP.$cljs$cst$1656$row$$);var $cell_column$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$2_map__48246__$1$$,$APP.$cljs$cst$216$column$$),$row_span$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$2_map__48246__$1$$,$APP.$cljs$cst$1657$row_span$$);$column_span$jscomp$2_map__48246__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$2_map__48246__$1$$,$APP.$cljs$cst$1658$column_span$$);return $row$jscomp$5$$>=$cell_row_p__48245$$&&$column$jscomp$12$$>=$cell_column$$&&$row$jscomp$5$$<=$cell_row_p__48245$$+$row_span$jscomp$2$$+-1&&$column$jscomp$12$$<=$cell_column$$+$column_span$jscomp$2_map__48246__$1$$+
-1};$app$common$types$shape$layout$cell_by_row_column$$=function($parent$jscomp$165$$,$row$jscomp$6$$,$column$jscomp$13$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__48251_SHARP_$$){return $app$common$types$shape$layout$in_cell_QMARK_$$($p1__48251_SHARP_$$,$row$jscomp$6$$,$column$jscomp$13$$)},$APP.$cljs$core$vals$$($APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$165$$)))};
$app$common$types$shape$layout$seek_indexed_cell$$=function($cells$jscomp$10_cells_PLUS_index$$,$row$jscomp$7$$,$column$jscomp$14$$){$cells$jscomp$10_cells_PLUS_index$$=$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($cells$jscomp$10_cells_PLUS_index$$);return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__48253_SHARP_$$){return $app$common$types$shape$layout$in_cell_QMARK_$$($APP.$cljs$core$second$$($p1__48253_SHARP_$$),$row$jscomp$7$$,$column$jscomp$14$$)},
$cells$jscomp$10_cells_PLUS_index$$)};
$app$common$types$shape$layout$free_cell_shapes$$=function($parent$jscomp$166$$,$shape_ids$$){var $shape_ids__$1$$=$APP.$cljs$core$set$$($shape_ids$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($parent$jscomp$166$$,$APP.$cljs$cst$1696$layout_grid_cells$$,function($cells$jscomp$11$$){return $APP.$cljs$core$reduce_kv$$(function($m$jscomp$196$$,$k$jscomp$578$$,$v$jscomp$505$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($shape_ids__$1$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$505$$)))?
$APP.$cljs$core$assoc_in$$($m$jscomp$196$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$578$$,$APP.$cljs$cst$1614$shapes$$],null),$APP.$cljs$core$PersistentVector$EMPTY$$):$m$jscomp$196$$},$cells$jscomp$11$$,$cells$jscomp$11$$)})};
$app$common$types$shape$layout$push_into_cell$$=function($parent$jscomp$167_parent__$1$jscomp$48$$,$shape_ids$jscomp$1$$,$row$jscomp$8_to_index$jscomp$5_vec__48256$$,$column$jscomp$15$$){$parent$jscomp$167_parent__$1$jscomp$48$$=$app$common$types$shape$layout$free_cell_shapes$$($parent$jscomp$167_parent__$1$jscomp$48$$,$shape_ids$jscomp$1$$);var $cells$jscomp$12$$=$APP.$cljs$core$vec$$($APP.$app$common$types$shape$layout$get_cells$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$167_parent__$1$jscomp$48$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1713$sort_QMARK_$$,!0],null)));$row$jscomp$8_to_index$jscomp$5_vec__48256$$=$app$common$types$shape$layout$seek_indexed_cell$$($cells$jscomp$12$$,$row$jscomp$8_to_index$jscomp$5_vec__48256$$,$column$jscomp$15$$);var $start_index$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($row$jscomp$8_to_index$jscomp$5_vec__48256$$,0,null);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($row$jscomp$8_to_index$jscomp$5_vec__48256$$,
1,null)!=null?($row$jscomp$8_to_index$jscomp$5_vec__48256$$=function(){var $x__5113__auto__$jscomp$32$$=$start_index$$+$APP.$cljs$core$count$$($shape_ids$jscomp$1$$),$y__5114__auto__$jscomp$32$$=$APP.$cljs$core$count$$($cells$jscomp$12$$)-1;return $x__5113__auto__$jscomp$32$$<$y__5114__auto__$jscomp$32$$?$x__5113__auto__$jscomp$32$$:$y__5114__auto__$jscomp$32$$}(),$APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__48262_shape_id$jscomp$17$$,$idx$jscomp$72_p__48263$$){var $parent__$2$jscomp$4_parent__$3$jscomp$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48262_shape_id$jscomp$17$$,0,null),$cells__$1$jscomp$1_cells__$2_vec__48270$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48262_shape_id$jscomp$17$$,1,null);$p__48262_shape_id$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($idx$jscomp$72_p__48263$$,0,null);$idx$jscomp$72_p__48263$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($idx$jscomp$72_p__48263$$,1,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__48262_shape_id$jscomp$17$$,
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($parent__$2$jscomp$4_parent__$3$jscomp$2$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cells__$1$jscomp$1_cells__$2_vec__48270$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$idx$jscomp$72_p__48263$$,$APP.$cljs$cst$266$id$$],null)),$APP.$cljs$cst$1614$shapes$$,
0],null))))return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent__$2$jscomp$4_parent__$3$jscomp$2$$,$cells__$1$jscomp$1_cells__$2_vec__48270$$],null);$cells__$1$jscomp$1_cells__$2_vec__48270$$=$app$common$types$shape$layout$free_cell_push$$($parent__$2$jscomp$4_parent__$3$jscomp$2$$,$cells__$1$jscomp$1_cells__$2_vec__48270$$,$idx$jscomp$72_p__48263$$);$parent__$2$jscomp$4_parent__$3$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cells__$1$jscomp$1_cells__$2_vec__48270$$,
0,null);$cells__$1$jscomp$1_cells__$2_vec__48270$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cells__$1$jscomp$1_cells__$2_vec__48270$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$variadic$($parent__$2$jscomp$4_parent__$3$jscomp$2$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cells__$1$jscomp$1_cells__$2_vec__48270$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$idx$jscomp$72_p__48263$$,$APP.$cljs$cst$266$id$$],null))],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1673$manual$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$p__48262_shape_id$jscomp$17$$],null)])),$cells__$1$jscomp$1_cells__$2_vec__48270$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent$jscomp$167_parent__$1$jscomp$48$$,$cells$jscomp$12$$],null),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vector$$,$shape_ids$jscomp$1$$,$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($start_index$$,$row$jscomp$8_to_index$jscomp$5_vec__48256$$+1))))):$parent$jscomp$167_parent__$1$jscomp$48$$};
$app$common$types$shape$layout$create_cells$$=function($parent$jscomp$168$$,$p__48275$$){var $column$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48275$$,0,null),$row$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48275$$,1,null),$column_span$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48275$$,2,null),$row_span$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48275$$,3,null);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__48273_SHARP_$$,
$p2__48274_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__48273_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p2__48274_SHARP_$$)],null),$p2__48274_SHARP_$$)},$parent$jscomp$168$$,function(){return function $app$common$types$shape$layout$create_cells_$_iter__48279$$($s__48280$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__48280__$1$$=
$s__48280$$;;){var $fs__5500__auto__$jscomp$1_temp__5825__auto__$jscomp$114$$=$APP.$cljs$core$seq$$($s__48280__$1$$);if($fs__5500__auto__$jscomp$1_temp__5825__auto__$jscomp$114$$){var $xs__6385__auto__$jscomp$3$$=$fs__5500__auto__$jscomp$1_temp__5825__auto__$jscomp$114$$,$row__$1$$=$APP.$cljs$core$first$$($xs__6385__auto__$jscomp$3$$);if($fs__5500__auto__$jscomp$1_temp__5825__auto__$jscomp$114$$=$APP.$cljs$core$seq$$(function($s__48280__$1$jscomp$1$$,$row__$1$jscomp$1$$,$xs__6385__auto__$jscomp$4$$,
$temp__5825__auto__$jscomp$115$$,$vec__48276$jscomp$1$$,$column$jscomp$17$$,$row$jscomp$10$$,$column_span$jscomp$4$$,$row_span$jscomp$4$$){return function $app$common$types$shape$layout$create_cells_$_iter__48279_$_iter__48281$$($s__48282$$){return new $APP.$cljs$core$LazySeq$$(null,function($s__48280__$1$jscomp$2$$,$row__$1$jscomp$2$$){return function(){for(;;){var $s__48282__$2_temp__5825__auto____$1$jscomp$4$$=$APP.$cljs$core$seq$$($s__48282$$);if($s__48282__$2_temp__5825__auto____$1$jscomp$4$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__48282__$2_temp__5825__auto____$1$jscomp$4$$)){var $JSCompiler_inline_result$jscomp$717_c__5501__auto__$jscomp$12$$=
$APP.$cljs$core$_chunked_first$$($s__48282__$2_temp__5825__auto____$1$jscomp$4$$),$size__5502__auto__$jscomp$12$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$717_c__5501__auto__$jscomp$12$$),$b__48284_column__$1$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$12$$);a:{for(var $i__48283$jscomp$inline_4754$$=0;;)if($i__48283$jscomp$inline_4754$$<$size__5502__auto__$jscomp$12$$){var $column__$1$jscomp$inline_4755_x$jscomp$inline_11846$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$717_c__5501__auto__$jscomp$12$$,
$i__48283$jscomp$inline_4754$$),$b$jscomp$inline_11845$$=$b__48284_column__$1$$;$column__$1$jscomp$inline_4755_x$jscomp$inline_11846$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$types$shape$layout$grid_cell_defaults$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$1656$row$$,$row__$1$jscomp$2$$,$APP.$cljs$cst$216$column$$,$column__$1$jscomp$inline_4755_x$jscomp$inline_11846$$,
$APP.$cljs$cst$1657$row_span$$,1,$APP.$cljs$cst$1658$column_span$$,1],null)]));$b$jscomp$inline_11845$$.add($column__$1$jscomp$inline_4755_x$jscomp$inline_11846$$);$i__48283$jscomp$inline_4754$$+=1}else{$JSCompiler_inline_result$jscomp$717_c__5501__auto__$jscomp$12$$=!0;break a}$JSCompiler_inline_result$jscomp$717_c__5501__auto__$jscomp$12$$=void 0}return $JSCompiler_inline_result$jscomp$717_c__5501__auto__$jscomp$12$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__48284_column__$1$$),$app$common$types$shape$layout$create_cells_$_iter__48279_$_iter__48281$$($APP.$cljs$core$_chunked_rest$$($s__48282__$2_temp__5825__auto____$1$jscomp$4$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__48284_column__$1$$),null)}$b__48284_column__$1$$=$APP.$cljs$core$first$$($s__48282__$2_temp__5825__auto____$1$jscomp$4$$);return $APP.$cljs$core$cons$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$types$shape$layout$grid_cell_defaults$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$1656$row$$,
$row__$1$jscomp$2$$,$APP.$cljs$cst$216$column$$,$b__48284_column__$1$$,$APP.$cljs$cst$1657$row_span$$,1,$APP.$cljs$cst$1658$column_span$$,1],null)])),$app$common$types$shape$layout$create_cells_$_iter__48279_$_iter__48281$$($APP.$cljs$core$rest$$($s__48282__$2_temp__5825__auto____$1$jscomp$4$$)))}return null}}}($s__48280__$1$jscomp$1$$,$row__$1$jscomp$1$$,$xs__6385__auto__$jscomp$4$$,$temp__5825__auto__$jscomp$115$$,$vec__48276$jscomp$1$$,$column$jscomp$17$$,$row$jscomp$10$$,$column_span$jscomp$4$$,
$row_span$jscomp$4$$),null,null)}}($s__48280__$1$$,$row__$1$$,$xs__6385__auto__$jscomp$3$$,$fs__5500__auto__$jscomp$1_temp__5825__auto__$jscomp$114$$,$p__48275$$,$column$jscomp$16$$,$row$jscomp$9$$,$column_span$jscomp$3$$,$row_span$jscomp$3$$)($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($column$jscomp$16$$,$column$jscomp$16$$+$column_span$jscomp$3$$))))return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($fs__5500__auto__$jscomp$1_temp__5825__auto__$jscomp$114$$,$app$common$types$shape$layout$create_cells_$_iter__48279$$($APP.$cljs$core$rest$$($s__48280__$1$$)));
$s__48280__$1$$=$APP.$cljs$core$rest$$($s__48280__$1$$)}else return null}},null,null)}($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($row$jscomp$9$$,$row$jscomp$9$$+$row_span$jscomp$3$$))}())};
$APP.$app$common$types$shape$layout$resize_cell_area$$=function($cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$,$prev_area_row$jscomp$12$$,$column$jscomp$19_prev_cell$$,$new_row_parent__$2$jscomp$5_split_cells$$,$new_column$$,$new_row_span_parent__$3$jscomp$3_parent__$5_parent__$6_vec__48289$$,$new_column_span$$){if($new_row_parent__$2$jscomp$5_split_cells$$>=1&&$new_column$$>=1&&$new_row_span_parent__$3$jscomp$3_parent__$5_parent__$6_vec__48289$$>=1&&$new_column_span$$>=1){$column$jscomp$19_prev_cell$$=
$app$common$types$shape$layout$cell_by_row_column$$($cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$,$prev_area_row$jscomp$12$$,$column$jscomp$19_prev_cell$$);$prev_area_row$jscomp$12$$=$app$common$geom$shapes$grid_layout$areas$make_area$cljs$0core$0IFn$0_invoke$0arity$01$$($column$jscomp$19_prev_cell$$);var $target_cell$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($column$jscomp$19_prev_cell$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1673$manual$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1656$row$$,
$new_row_parent__$2$jscomp$5_split_cells$$,$APP.$cljs$cst$216$column$$,$new_column$$,$APP.$cljs$cst$1657$row_span$$,$new_row_span_parent__$3$jscomp$3_parent__$5_parent__$6_vec__48289$$,$APP.$cljs$cst$1658$column_span$$,$new_column_span$$])),$target_area$$=$app$common$geom$shapes$grid_layout$areas$make_area$cljs$0core$0IFn$0_invoke$0arity$01$$($target_cell$$);$cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($parent__$1$jscomp$50$$){return $APP.$app$common$types$shape$layout$add_grid_column$$.$cljs$core$IFn$_invoke$arity$2$($parent__$1$jscomp$50$$,
$APP.$app$common$types$shape$layout$default_track_value$$)},$cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$,$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$count$$($APP.$cljs$cst$1695$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$)),$new_column$$+$new_column_span$$+-1));$new_row_parent__$2$jscomp$5_split_cells$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($parent__$2$jscomp$6$$){return $APP.$app$common$types$shape$layout$add_grid_row$$.$cljs$core$IFn$_invoke$arity$2$($parent__$2$jscomp$6$$,
$APP.$app$common$types$shape$layout$default_track_value$$)},$cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$,$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$count$$($APP.$cljs$cst$1694$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$)),$new_row_parent__$2$jscomp$5_split_cells$$+$new_row_span_parent__$3$jscomp$3_parent__$5_parent__$6_vec__48289$$+-1));$new_row_span_parent__$3$jscomp$3_parent__$5_parent__$6_vec__48289$$=
$app$common$types$shape$layout$create_cells$$($new_row_parent__$2$jscomp$5_split_cells$$,$prev_area_row$jscomp$12$$);$cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$=$APP.$cljs$core$vec$$($APP.$app$common$types$shape$layout$get_cells$cljs$0core$0IFn$0_invoke$0arity$02$$($new_row_span_parent__$3$jscomp$3_parent__$5_parent__$6_vec__48289$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1713$sort_QMARK_$$,!0],null)));var $remove_cells$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48286_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__48286_SHARP_$$))&&$app$common$geom$shapes$grid_layout$areas$contains_QMARK_$$($target_area$$,$app$common$geom$shapes$grid_layout$areas$make_area$cljs$0core$0IFn$0_invoke$0arity$01$$($p1__48286_SHARP_$$))},$cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$));
$new_row_parent__$2$jscomp$5_split_cells$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48287_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__48287_SHARP_$$))&&!$APP.$cljs$core$contains_QMARK_$$($remove_cells$$,$p1__48287_SHARP_$$)&&$app$common$geom$shapes$grid_layout$areas$intersects_QMARK_$$($target_area$$,$app$common$geom$shapes$grid_layout$areas$make_area$cljs$0core$0IFn$0_invoke$0arity$01$$($p1__48287_SHARP_$$))},
$cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$);$new_row_span_parent__$3$jscomp$3_parent__$5_parent__$6_vec__48289$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($cells__$1$jscomp$2_cells__$2$jscomp$1_p__48294_vec__48302$$,$cur_cell_p__48295$$){var $parent__$4$jscomp$1_parent__$5$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cells__$1$jscomp$2_cells__$2$jscomp$1_p__48294_vec__48302$$,0,null);$cells__$1$jscomp$2_cells__$2$jscomp$1_p__48294_vec__48302$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cells__$1$jscomp$2_cells__$2$jscomp$1_p__48294_vec__48302$$,1,null);var $index$jscomp$157$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cur_cell_p__48295$$,0,null);$cur_cell_p__48295$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cur_cell_p__48295$$,1,null);return $APP.$cljs$core$contains_QMARK_$$($remove_cells$$,$cur_cell_p__48295$$)?($cells__$1$jscomp$2_cells__$2$jscomp$1_p__48294_vec__48302$$=$app$common$types$shape$layout$free_cell_push$$($parent__$4$jscomp$1_parent__$5$jscomp$1$$,
$cells__$1$jscomp$2_cells__$2$jscomp$1_p__48294_vec__48302$$,$index$jscomp$157$$),$parent__$4$jscomp$1_parent__$5$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cells__$1$jscomp$2_cells__$2$jscomp$1_p__48294_vec__48302$$,0,null),$cells__$1$jscomp$2_cells__$2$jscomp$1_p__48294_vec__48302$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cells__$1$jscomp$2_cells__$2$jscomp$1_p__48294_vec__48302$$,1,null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$parent__$4$jscomp$1_parent__$5$jscomp$1$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cells__$1$jscomp$2_cells__$2$jscomp$1_p__48294_vec__48302$$,$cur_cell_p__48295$$)],null)):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent__$4$jscomp$1_parent__$5$jscomp$1$$,$cells__$1$jscomp$2_cells__$2$jscomp$1_p__48294_vec__48302$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_row_span_parent__$3$jscomp$3_parent__$5_parent__$6_vec__48289$$,
$cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$],null),$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$));$cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_row_span_parent__$3$jscomp$3_parent__$5_parent__$6_vec__48289$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_row_span_parent__$3$jscomp$3_parent__$5_parent__$6_vec__48289$$,
1,null);$new_row_span_parent__$3$jscomp$3_parent__$5_parent__$6_vec__48289$$=$APP.$cljs$core$assoc_in$$($cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$$)],null),$target_cell$$);$new_row_span_parent__$3$jscomp$3_parent__$5_parent__$6_vec__48289$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($parent__$6$jscomp$1$$,
$cell$jscomp$14$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($parent__$6$jscomp$1$$,$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$14$$))},$new_row_span_parent__$3$jscomp$3_parent__$5_parent__$6_vec__48289$$,$remove_cells$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($$__$1$jscomp$3_parent__$7$jscomp$1$$,$cell$jscomp$15$$){var $new_areas$$=$app$common$geom$shapes$grid_layout$areas$difference$$($app$common$geom$shapes$grid_layout$areas$make_area$cljs$0core$0IFn$0_invoke$0arity$01$$($cell$jscomp$15$$),
$target_area$$);$$__$1$jscomp$3_parent__$7$jscomp$1$$=$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($$__$1$jscomp$3_parent__$7$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$15$$)],null),$APP.$cljs$core$merge$$,$app$common$geom$shapes$grid_layout$areas$area__GT_cell_props$$($APP.$cljs$core$first$$($new_areas$$)));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($parent__$8$$,
$area$jscomp$1_cell__$1$jscomp$2$$){$area$jscomp$1_cell__$1$jscomp$2$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$shape$layout$grid_cell_defaults$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$()),$app$common$geom$shapes$grid_layout$areas$area__GT_cell_props$$($area$jscomp$1_cell__$1$jscomp$2$$)]));return $APP.$cljs$core$assoc_in$$($parent__$8$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($area$jscomp$1_cell__$1$jscomp$2$$)],null),$area$jscomp$1_cell__$1$jscomp$2$$)},$$__$1$jscomp$3_parent__$7$jscomp$1$$,$new_areas$$)},$new_row_span_parent__$3$jscomp$3_parent__$5_parent__$6_vec__48289$$,$new_row_parent__$2$jscomp$5_split_cells$$)}return $cells$jscomp$13_parent$jscomp$169_parent__$1$jscomp$49_parent__$4$$};
$APP.$app$common$types$shape$layout$get_cell_by_position$$=function($parent$jscomp$170$$,$target_row$$,$target_column$$){return $APP.$cljs$core$second$$($APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($column$jscomp$20_map__48311_p__48307$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$20_map__48311_p__48307$$,0,null);$column$jscomp$20_map__48311_p__48307$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$20_map__48311_p__48307$$,
1,null);var $map__48311__$1_row_span$jscomp$6$$=$APP.$cljs$core$__destructure_map$$($column$jscomp$20_map__48311_p__48307$$);$column$jscomp$20_map__48311_p__48307$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48311__$1_row_span$jscomp$6$$,$APP.$cljs$cst$216$column$$);var $row$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48311__$1_row_span$jscomp$6$$,$APP.$cljs$cst$1656$row$$),$column_span$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48311__$1_row_span$jscomp$6$$,
$APP.$cljs$cst$1658$column_span$$);$map__48311__$1_row_span$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48311__$1_row_span$jscomp$6$$,$APP.$cljs$cst$1657$row_span$$);return $target_row$$>=$row$jscomp$13$$&&$target_column$$>=$column$jscomp$20_map__48311_p__48307$$&&$target_column$$<$column$jscomp$20_map__48311_p__48307$$+$column_span$jscomp$6$$&&$target_row$$<$row$jscomp$13$$+$map__48311__$1_row_span$jscomp$6$$},$APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$170$$)))};
$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$=function($parent$jscomp$171$$,$shape_id$jscomp$18$$){return $APP.$cljs$core$second$$($APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($map__48318_map__48318__$1_p__48314_shapes$jscomp$6$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__48318_map__48318__$1_p__48314_shapes$jscomp$6$$,0,null);$map__48318_map__48318__$1_p__48314_shapes$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__48318_map__48318__$1_p__48314_shapes$jscomp$6$$,
1,null);$map__48318_map__48318__$1_p__48314_shapes$jscomp$6$$=$APP.$cljs$core$__destructure_map$$($map__48318_map__48318__$1_p__48314_shapes$jscomp$6$$);$map__48318_map__48318__$1_p__48314_shapes$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48318_map__48318__$1_p__48314_shapes$jscomp$6$$,$APP.$cljs$cst$1614$shapes$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$set$$($map__48318_map__48318__$1_p__48314_shapes$jscomp$6$$),$shape_id$jscomp$18$$)},$APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$171$$)))};
$app$common$types$shape$layout$swap_shapes$$=function($parent$jscomp$172$$,$id_from$$,$id_to$$){var $cell_to$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$172$$,$APP.$cljs$cst$1696$layout_grid_cells$$),$id_to$$),$cell_from$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$172$$,$APP.$cljs$cst$1696$layout_grid_cells$$),$id_from$$);
return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$variadic$($parent$jscomp$172$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$id_from$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell_to$jscomp$1$$),$APP.$cljs$cst$1676$position$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell_to$jscomp$1$$)])),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$id_to$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell_from$jscomp$1$$),$APP.$cljs$cst$1676$position$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell_from$jscomp$1$$)]))};
$app$common$types$shape$layout$add_children_to_cell$$=function($frame$jscomp$8$$,$children$jscomp$138$$,$objects$jscomp$97$$,$p__48321$$){var $row$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48321$$,0,null),$column$jscomp$21$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48321$$,1,null),$frame__$1$$=$APP.$app$common$types$shape$layout$assign_cells$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($frame$jscomp$8$$,$APP.$cljs$cst$1614$shapes$$,
function($p1__48319_SHARP_$$){return $APP.$app$common$data$removev$$($children$jscomp$138$$,$p1__48319_SHARP_$$)}),$objects$jscomp$97$$),$children__$1$jscomp$20$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48320_SHARP_$$){return $APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$97$$,$p1__48320_SHARP_$$)},$children$jscomp$138$$);return $APP.$app$common$types$shape$layout$assign_cells$$(function(){var $G__48325$$=
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($frame__$1$$,$APP.$cljs$cst$1614$shapes$$,$APP.$app$common$data$concat_vec$$,$children__$1$jscomp$20$$);return $p__48321$$!=null?$app$common$types$shape$layout$push_into_cell$$($G__48325$$,$children__$1$jscomp$20$$,$row$jscomp$14$$,$column$jscomp$21$$):$G__48325$$}(),$objects$jscomp$97$$)};
$app$common$types$shape$layout$get_cell_by_index$$=function($cells$jscomp$14_parent$jscomp$173$$,$to_index$jscomp$6_to_index__$1$$){$cells$jscomp$14_parent$jscomp$173$$=$APP.$app$common$types$shape$layout$get_cells$cljs$0core$0IFn$0_invoke$0arity$02$$($cells$jscomp$14_parent$jscomp$173$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1713$sort_QMARK_$$,!0,$cljs$cst$1714$remove_empty_QMARK_$$,!0],null));$to_index$jscomp$6_to_index__$1$$=$APP.$cljs$core$count$$($cells$jscomp$14_parent$jscomp$173$$)-
$to_index$jscomp$6_to_index__$1$$-1;return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cells$jscomp$14_parent$jscomp$173$$,$to_index$jscomp$6_to_index__$1$$,null)};
$app$common$types$shape$layout$reorder_grid_children$$=function($parent$jscomp$175$$){var $cells$jscomp$15_new_shapes_new_shapes__$1$$=$APP.$app$common$types$shape$layout$get_cells$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$175$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1713$sort_QMARK_$$,!0],null)),$child_QMARK_$$=$APP.$cljs$core$set$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$175$$));$cells$jscomp$15_new_shapes_new_shapes__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$APP.$cljs$cst$1614$shapes$$)),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($child_QMARK_$$)),$cells$jscomp$15_new_shapes_new_shapes__$1$$);$cells$jscomp$15_new_shapes_new_shapes__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$15_new_shapes_new_shapes__$1$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$175$$));
return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parent$jscomp$175$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$reverse$$($cells$jscomp$15_new_shapes_new_shapes__$1$$)))};
$APP.$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$03$$=function($parent$jscomp$177$$,$index$jscomp$159$$,$check_span_QMARK_$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__48337_row$jscomp$15$$){var $map__48338__$1_row_span$jscomp$7$$=$APP.$cljs$core$__destructure_map$$($p__48337_row$jscomp$15$$);$p__48337_row$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48338__$1_row_span$jscomp$7$$,$APP.$cljs$cst$1656$row$$);
$map__48338__$1_row_span$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48338__$1_row_span$jscomp$7$$,$APP.$cljs$cst$1657$row_span$$);return $APP.$cljs$core$truth_$$($check_span_QMARK_$$)?$index$jscomp$159$$+1>=$p__48337_row$jscomp$15$$&&$index$jscomp$159$$+1<$p__48337_row$jscomp$15$$+$map__48338__$1_row_span$jscomp$7$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$159$$+1,$p__48337_row$jscomp$15$$)},$APP.$cljs$core$vals$$($APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$177$$)))};
$APP.$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$03$$=function($parent$jscomp$179$$,$index$jscomp$161$$,$check_span_QMARK_$jscomp$1$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($column$jscomp$22_p__48349$$){var $column_span$jscomp$7_map__48350__$1$$=$APP.$cljs$core$__destructure_map$$($column$jscomp$22_p__48349$$);$column$jscomp$22_p__48349$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$7_map__48350__$1$$,
$APP.$cljs$cst$216$column$$);$column_span$jscomp$7_map__48350__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$7_map__48350__$1$$,$APP.$cljs$cst$1658$column_span$$);return $APP.$cljs$core$truth_$$($check_span_QMARK_$jscomp$1$$)?$index$jscomp$161$$+1>=$column$jscomp$22_p__48349$$&&$index$jscomp$161$$+1<$column$jscomp$22_p__48349$$+$column_span$jscomp$7_map__48350__$1$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$161$$+1,$column$jscomp$22_p__48349$$)},
$APP.$cljs$core$vals$$($APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$179$$)))};
$APP.$app$common$types$shape$layout$cells_coordinates$$=function($G__48659_cells$jscomp$16$$){for(var $cells__$1$jscomp$3$$=$APP.$cljs$core$seq$$($G__48659_cells$jscomp$16$$),$result$jscomp$158$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1715$first_row$$,Infinity,$APP.$cljs$cst$1716$first_column$$,Infinity,$APP.$cljs$cst$1717$last_row$$,-Infinity,$APP.$cljs$cst$1718$last_column$$,-Infinity,$APP.$cljs$cst$1719$cell_coords$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$],null);;){if($APP.$cljs$core$empty_QMARK_$$($cells__$1$jscomp$3$$))return $result$jscomp$158$$;
var $map__48386$$=$result$jscomp$158$$,$map__48386__$1$$=$APP.$cljs$core$__destructure_map$$($map__48386$$),$first_row$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48386__$1$$,$APP.$cljs$cst$1715$first_row$$),$last_row$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48386__$1$$,$APP.$cljs$cst$1717$last_row$$),$first_column$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48386__$1$$,$APP.$cljs$cst$1716$first_column$$),$last_column$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48386__$1$$,$APP.$cljs$cst$1718$last_column$$),$cell_coords$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48386__$1$$,$APP.$cljs$cst$1719$cell_coords$$),$current$jscomp$15$$=$APP.$cljs$core$first$$($cells__$1$jscomp$3$$),$first_row__$1$$=$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$)<$first_row$jscomp$1$$?$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$):$first_row$jscomp$1$$,
$last_row__$1$$=$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$)+$APP.$cljs$cst$1657$row_span$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$)+-1>$last_row$jscomp$1$$?$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$)+$APP.$cljs$cst$1657$row_span$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$)+-1:$last_row$jscomp$1$$,$first_column__$1$$=$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$)<$first_column$jscomp$1$$?
$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$):$first_column$jscomp$1$$,$last_column__$1$$=$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$)+$APP.$cljs$cst$1658$column_span$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$)+-1>$last_column$jscomp$1$$?$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$)+$APP.$cljs$cst$1658$column_span$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$)+-1:$last_column$jscomp$1$$,
$G__48660_cell_coords__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($cell_coords$$,function(){return function($cells__$1$jscomp$4$$,$result$jscomp$159$$,$map__48386$jscomp$1$$,$map__48386__$1$jscomp$1$$,$first_row$jscomp$2$$,$last_row$jscomp$2$$,$first_column$jscomp$2$$,$last_column$jscomp$2$$,$cell_coords$jscomp$1$$,$current$jscomp$16$$,$first_row__$1$jscomp$1$$,$last_row__$1$jscomp$1$$,$first_column__$1$jscomp$1$$,$last_column__$1$jscomp$1$$){return function $app$common$types$shape$layout$cells_coordinates_$_iter__48387$$($s__48388$$){return new $APP.$cljs$core$LazySeq$$(null,
function($cells__$1$jscomp$5$$,$result$jscomp$160$$,$map__48386$jscomp$2$$,$map__48386__$1$jscomp$2$$,$first_row$jscomp$3$$,$last_row$jscomp$3$$,$first_column$jscomp$3$$,$last_column$jscomp$3$$,$cell_coords$jscomp$2$$,$current$jscomp$17$$,$first_row__$1$jscomp$2$$,$last_row__$1$jscomp$2$$,$first_column__$1$jscomp$2$$,$last_column__$1$jscomp$2$$){return function(){for(var $s__48388__$1$$=$s__48388$$;;){var $fs__5500__auto__$jscomp$2_temp__5825__auto__$jscomp$117$$=$APP.$cljs$core$seq$$($s__48388__$1$$);
if($fs__5500__auto__$jscomp$2_temp__5825__auto__$jscomp$117$$){var $xs__6385__auto__$jscomp$6$$=$fs__5500__auto__$jscomp$2_temp__5825__auto__$jscomp$117$$,$r$jscomp$80$$=$APP.$cljs$core$first$$($xs__6385__auto__$jscomp$6$$);if($fs__5500__auto__$jscomp$2_temp__5825__auto__$jscomp$117$$=$APP.$cljs$core$seq$$(function($s__48388__$1$jscomp$1$$,$cells__$1$jscomp$6$$,$result$jscomp$161$$,$r$jscomp$81$$,$xs__6385__auto__$jscomp$7$$,$temp__5825__auto__$jscomp$118$$,$map__48386$jscomp$3$$,$map__48386__$1$jscomp$3$$,
$first_row$jscomp$4$$,$last_row$jscomp$4$$,$first_column$jscomp$4$$,$last_column$jscomp$4$$,$cell_coords$jscomp$3$$,$current$jscomp$18$$,$first_row__$1$jscomp$3$$,$last_row__$1$jscomp$3$$,$first_column__$1$jscomp$3$$,$last_column__$1$jscomp$3$$){return function $app$common$types$shape$layout$cells_coordinates_$_iter__48387_$_iter__48389$$($s__48390$$){return new $APP.$cljs$core$LazySeq$$(null,function($s__48388__$1$jscomp$2$$,$cells__$1$jscomp$7$$,$result$jscomp$162$$,$r$jscomp$82$$){return function(){for(;;){var $s__48390__$2_temp__5825__auto____$1$jscomp$5$$=
$APP.$cljs$core$seq$$($s__48390$$);if($s__48390__$2_temp__5825__auto____$1$jscomp$5$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__48390__$2_temp__5825__auto____$1$jscomp$5$$)){var $JSCompiler_inline_result$jscomp$718_c__5501__auto__$jscomp$13$$=$APP.$cljs$core$_chunked_first$$($s__48390__$2_temp__5825__auto____$1$jscomp$5$$),$size__5502__auto__$jscomp$13$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$718_c__5501__auto__$jscomp$13$$),$b__48392_c$jscomp$262$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$13$$);
a:{for(var $i__48391$jscomp$inline_4757$$=0;;)if($i__48391$jscomp$inline_4757$$<$size__5502__auto__$jscomp$13$$){var $c$jscomp$inline_4758$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$718_c__5501__auto__$jscomp$13$$,$i__48391$jscomp$inline_4757$$);$b__48392_c$jscomp$262$$.add(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r$jscomp$82$$,$c$jscomp$inline_4758$$],null));$i__48391$jscomp$inline_4757$$+=1}else{$JSCompiler_inline_result$jscomp$718_c__5501__auto__$jscomp$13$$=
!0;break a}$JSCompiler_inline_result$jscomp$718_c__5501__auto__$jscomp$13$$=void 0}return $JSCompiler_inline_result$jscomp$718_c__5501__auto__$jscomp$13$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__48392_c$jscomp$262$$),$app$common$types$shape$layout$cells_coordinates_$_iter__48387_$_iter__48389$$($APP.$cljs$core$_chunked_rest$$($s__48390__$2_temp__5825__auto____$1$jscomp$5$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__48392_c$jscomp$262$$),null)}$b__48392_c$jscomp$262$$=
$APP.$cljs$core$first$$($s__48390__$2_temp__5825__auto____$1$jscomp$5$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r$jscomp$82$$,$b__48392_c$jscomp$262$$],null),$app$common$types$shape$layout$cells_coordinates_$_iter__48387_$_iter__48389$$($APP.$cljs$core$rest$$($s__48390__$2_temp__5825__auto____$1$jscomp$5$$)))}return null}}}($s__48388__$1$jscomp$1$$,$cells__$1$jscomp$6$$,$result$jscomp$161$$,$r$jscomp$81$$,$xs__6385__auto__$jscomp$7$$,
$temp__5825__auto__$jscomp$118$$,$map__48386$jscomp$3$$,$map__48386__$1$jscomp$3$$,$first_row$jscomp$4$$,$last_row$jscomp$4$$,$first_column$jscomp$4$$,$last_column$jscomp$4$$,$cell_coords$jscomp$3$$,$current$jscomp$18$$,$first_row__$1$jscomp$3$$,$last_row__$1$jscomp$3$$,$first_column__$1$jscomp$3$$,$last_column__$1$jscomp$3$$),null,null)}}($s__48388__$1$$,$cells__$1$jscomp$5$$,$result$jscomp$160$$,$r$jscomp$80$$,$xs__6385__auto__$jscomp$6$$,$fs__5500__auto__$jscomp$2_temp__5825__auto__$jscomp$117$$,
$map__48386$jscomp$2$$,$map__48386__$1$jscomp$2$$,$first_row$jscomp$3$$,$last_row$jscomp$3$$,$first_column$jscomp$3$$,$last_column$jscomp$3$$,$cell_coords$jscomp$2$$,$current$jscomp$17$$,$first_row__$1$jscomp$2$$,$last_row__$1$jscomp$2$$,$first_column__$1$jscomp$2$$,$last_column__$1$jscomp$2$$)($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$17$$),$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$17$$)+
$APP.$cljs$cst$1658$column_span$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$17$$)))))return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($fs__5500__auto__$jscomp$2_temp__5825__auto__$jscomp$117$$,$app$common$types$shape$layout$cells_coordinates_$_iter__48387$$($APP.$cljs$core$rest$$($s__48388__$1$$)));$s__48388__$1$$=$APP.$cljs$core$rest$$($s__48388__$1$$)}else return null}}}($cells__$1$jscomp$4$$,$result$jscomp$159$$,$map__48386$jscomp$1$$,$map__48386__$1$jscomp$1$$,$first_row$jscomp$2$$,
$last_row$jscomp$2$$,$first_column$jscomp$2$$,$last_column$jscomp$2$$,$cell_coords$jscomp$1$$,$current$jscomp$16$$,$first_row__$1$jscomp$1$$,$last_row__$1$jscomp$1$$,$first_column__$1$jscomp$1$$,$last_column__$1$jscomp$1$$),null,null)}}($cells__$1$jscomp$3$$,$result$jscomp$158$$,$map__48386$$,$map__48386__$1$$,$first_row$jscomp$1$$,$last_row$jscomp$1$$,$first_column$jscomp$1$$,$last_column$jscomp$1$$,$cell_coords$$,$current$jscomp$15$$,$first_row__$1$$,$last_row__$1$$,$first_column__$1$$,$last_column__$1$$)($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$),
$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$)+$APP.$cljs$cst$1657$row_span$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$15$$)))}());$G__48659_cells$jscomp$16$$=$APP.$cljs$core$rest$$($cells__$1$jscomp$3$$);$G__48660_cell_coords__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($result$jscomp$158$$,$APP.$cljs$cst$1715$first_row$$,$first_row__$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1717$last_row$$,$last_row__$1$$,
$APP.$cljs$cst$1716$first_column$$,$first_column__$1$$,$APP.$cljs$cst$1718$last_column$$,$last_column__$1$$,$APP.$cljs$cst$1719$cell_coords$$,$G__48660_cell_coords__$1$$]));$cells__$1$jscomp$3$$=$G__48659_cells$jscomp$16$$;$result$jscomp$158$$=$G__48660_cell_coords__$1$$}};
$APP.$app$common$types$shape$layout$remap_grid_cells$$=function($shape$jscomp$67$$,$ids_map$jscomp$5$$){function $remap_shape$$($id$jscomp$149$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($ids_map$jscomp$5$$,$id$jscomp$149$$,$id$jscomp$149$$)}return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$67$$,$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$core$update_vals$$,function($cell$jscomp$19$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($cell$jscomp$19$$,
$APP.$cljs$cst$1614$shapes$$,function($p1__48420_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($remap_shape$$),$p1__48420_SHARP_$$)})})};
$app$common$types$shape$layout$merge_cells$$=function($target_cells$$,$source_cells$$,$omit_touched_QMARK__touched_cells$$){if($APP.$cljs$core$truth_$$($omit_touched_QMARK__touched_cells$$)){var $merge_cells$$=function($source_cell$$,$target_cell$jscomp$2$$){return $APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($source_cell$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($target_cell$jscomp$2$$,$APP.$cljs$cst$1656$row$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$216$column$$,
$APP.$cljs$cst$1657$row_span$$,$APP.$cljs$cst$1658$column_span$$])))},$deleted_cells$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__48440_SHARP_$$){return!$APP.$cljs$core$contains_QMARK_$$($source_cells$$,$p1__48440_SHARP_$$)}),$APP.$cljs$core$keys$$($target_cells$$));$omit_touched_QMARK__touched_cells$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__48441_SHARP_$$){return!$APP.$cljs$core$contains_QMARK_$$($deleted_cells$$,$p1__48441_SHARP_$$)}),$APP.$cljs$core$keys$$($target_cells$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($cells$jscomp$18$$,$id$jscomp$150$$){return $APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cells$jscomp$18$$,$id$jscomp$150$$,$merge_cells$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($target_cells$$,
$id$jscomp$150$$)]))},$source_cells$$,$omit_touched_QMARK__touched_cells$$)}return $source_cells$$};
$app$common$types$shape$layout$toggle_fix_if_auto$$=function($shape$jscomp$68$$){var $G__48449__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$68$$),$APP.$cljs$cst$1403$fill$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$68$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$,$APP.$cljs$cst$1697$fix$$):$shape$jscomp$68$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$68$$),
$APP.$cljs$cst$1403$fill$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48449__$1$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1697$fix$$):$G__48449__$1$$};
$app$common$types$color$has_valid_color_attrs_QMARK_$$=function($attrs$jscomp$1_color$jscomp$4_result$jscomp$163$$){$attrs$jscomp$1_color$jscomp$4_result$jscomp$163$$=$APP.$cljs$core$set$$($APP.$cljs$core$keys$$($attrs$jscomp$1_color$jscomp$4_result$jscomp$163$$));$attrs$jscomp$1_color$jscomp$4_result$jscomp$163$$=$APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$1_color$jscomp$4_result$jscomp$163$$,$app$common$types$color$required_color_attrs$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$APP.$cljs$core$count$$($attrs$jscomp$1_color$jscomp$4_result$jscomp$163$$))};$app$common$types$color$hex_color_string_QMARK_$$=function($o$jscomp$237$$){return typeof $o$jscomp$237$$==="string"&&$APP.$cljs$core$re_matches$$($app$common$types$color$hex_color_rx$$,$o$jscomp$237$$)!=null};
$APP.$app$common$types$color$stroke__GT_color$$=function($stroke$jscomp$1$$){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1298$color$$,$APP.$cuerdas$core$lower$$($APP.$cljs$cst$1739$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$1$$)),$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1740$stroke_opacity$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$1$$),$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$cst$1741$stroke_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$1$$),
$APP.$cljs$cst$1612$image$$,$APP.$cljs$cst$1635$stroke_image$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$1$$),$APP.$cljs$cst$1735$ref_id$$,$APP.$cljs$cst$1742$stroke_color_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$1$$),$APP.$cljs$cst$1736$ref_file$$,$APP.$cljs$cst$1641$stroke_color_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$1$$)],null))};$app$common$types$color$shadow__GT_color$$=function($shadow__$1$jscomp$2$$){return $APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$2$$)};
$app$common$types$color$grid__GT_color$$=function($color$jscomp$5_grid$$){$color$jscomp$5_grid$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$5_grid$$));return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$5_grid$$),$APP.$cljs$cst$1734$opacity$$,
$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$5_grid$$),$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$5_grid$$),$APP.$cljs$cst$1735$ref_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$5_grid$$),$APP.$cljs$cst$1736$ref_file$$,$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$5_grid$$)],null))};
$APP.$app$common$types$color$valid_hex_color_QMARK_$$=function($color$jscomp$6$$){return typeof $color$jscomp$6$$==="string"&&$APP.$cljs$core$re_matches$$($app$common$types$color$hex_color_re$$,$color$jscomp$6$$)!=null};
$app$common$types$color$parse_rgb$$=function($color$jscomp$7_r$jscomp$87$$){var $b$jscomp$268_result$jscomp$164$$=$APP.$cljs$core$re_matches$$($app$common$types$color$rgb_color_re$$,$color$jscomp$7_r$jscomp$87$$);if($b$jscomp$268_result$jscomp$164$$!=null){$color$jscomp$7_r$jscomp$87$$=$APP.$cljs$core$parse_long$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($b$jscomp$268_result$jscomp$164$$,1));var $g$jscomp$124$$=$APP.$cljs$core$parse_long$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($b$jscomp$268_result$jscomp$164$$,
2));$b$jscomp$268_result$jscomp$164$$=$APP.$cljs$core$parse_long$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($b$jscomp$268_result$jscomp$164$$,3));return 0<=$color$jscomp$7_r$jscomp$87$$&&$color$jscomp$7_r$jscomp$87$$<=255&&0<=$g$jscomp$124$$&&$g$jscomp$124$$<=255&&0<=$b$jscomp$268_result$jscomp$164$$&&$b$jscomp$268_result$jscomp$164$$<=255?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$color$jscomp$7_r$jscomp$87$$,$g$jscomp$124$$,$b$jscomp$268_result$jscomp$164$$],
null):null}return null};$APP.$app$common$types$color$hex__GT_rgb$$=function($color$jscomp$10$$){try{var $rgb$$=parseInt($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$10$$,1),16);return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$rgb$$>>16,$rgb$$>>8&255,$rgb$$&255],null)}catch($e45414$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,0,0],null)}};
$APP.$app$common$types$color$rgb__GT_hex$$=function($b$jscomp$272_b__$1$jscomp$1_p__45425$$){var $r$jscomp$91_r__$1$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$272_b__$1$jscomp$1_p__45425$$,0,null),$g$jscomp$128_g__$1_rgb$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$272_b__$1$jscomp$1_p__45425$$,1,null);$b$jscomp$272_b__$1$jscomp$1_p__45425$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$272_b__$1$jscomp$1_p__45425$$,
2,null);$r$jscomp$91_r__$1$jscomp$1$$|=0;$g$jscomp$128_g__$1_rgb$jscomp$1$$|=0;$b$jscomp$272_b__$1$jscomp$1_p__45425$$|=0;if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($r$jscomp$91_r__$1$jscomp$1$$,$r$jscomp$91_r__$1$jscomp$1$$&255)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($g$jscomp$128_g__$1_rgb$jscomp$1$$,$g$jscomp$128_g__$1_rgb$jscomp$1$$&255)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$272_b__$1$jscomp$1_p__45425$$,$b$jscomp$272_b__$1$jscomp$1_p__45425$$&
255))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("not valid rgb",new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1743$r$$,$r$jscomp$91_r__$1$jscomp$1$$,$APP.$cljs$cst$1744$g$$,$g$jscomp$128_g__$1_rgb$jscomp$1$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$272_b__$1$jscomp$1_p__45425$$],null));$g$jscomp$128_g__$1_rgb$jscomp$1$$=$r$jscomp$91_r__$1$jscomp$1$$<<16|$g$jscomp$128_g__$1_rgb$jscomp$1$$<<8|$b$jscomp$272_b__$1$jscomp$1_p__45425$$;return $r$jscomp$91_r__$1$jscomp$1$$<
16?"#"+($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$((16777216|$g$jscomp$128_g__$1_rgb$jscomp$1$$).toString(16),1)??""):"#"+($g$jscomp$128_g__$1_rgb$jscomp$1$$.toString(16)??"")};
$APP.$app$common$types$color$rgb__GT_hsl$$=function($b$jscomp$273_max$jscomp$67_p__45434$$){var $h$jscomp$141_norm_r_r$jscomp$92$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$273_max$jscomp$67_p__45434$$,0,null),$g$jscomp$129_norm_g$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$273_max$jscomp$67_p__45434$$,1,null);$b$jscomp$273_max$jscomp$67_p__45434$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$273_max$jscomp$67_p__45434$$,2,null);
$h$jscomp$141_norm_r_r$jscomp$92$$/=255;$g$jscomp$129_norm_g$$/=255;var $norm_b$$=$b$jscomp$273_max$jscomp$67_p__45434$$/255;$b$jscomp$273_max$jscomp$67_p__45434$$=$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$3$($h$jscomp$141_norm_r_r$jscomp$92$$,$g$jscomp$129_norm_g$$,$norm_b$$);var $min$jscomp$67$$=$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$3$($h$jscomp$141_norm_r_r$jscomp$92$$,$g$jscomp$129_norm_g$$,$norm_b$$),$l$jscomp$94$$=($b$jscomp$273_max$jscomp$67_p__45434$$+$min$jscomp$67$$)/
2;$h$jscomp$141_norm_r_r$jscomp$92$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$273_max$jscomp$67_p__45434$$,$min$jscomp$67$$)?0:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$273_max$jscomp$67_p__45434$$,$h$jscomp$141_norm_r_r$jscomp$92$$)?($g$jscomp$129_norm_g$$-$norm_b$$)/($b$jscomp$273_max$jscomp$67_p__45434$$-$min$jscomp$67$$)*60:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$273_max$jscomp$67_p__45434$$,$g$jscomp$129_norm_g$$)?120+($norm_b$$-
$h$jscomp$141_norm_r_r$jscomp$92$$)/($b$jscomp$273_max$jscomp$67_p__45434$$-$min$jscomp$67$$)*60:240+($h$jscomp$141_norm_r_r$jscomp$92$$-$g$jscomp$129_norm_g$$)/($b$jscomp$273_max$jscomp$67_p__45434$$-$min$jscomp$67$$)*60;return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$mod$$($h$jscomp$141_norm_r_r$jscomp$92$$+360,360),$l$jscomp$94$$>0&&$l$jscomp$94$$<=.5?($b$jscomp$273_max$jscomp$67_p__45434$$-$min$jscomp$67$$)/(2*$l$jscomp$94$$):
($b$jscomp$273_max$jscomp$67_p__45434$$-$min$jscomp$67$$)/(2-2*$l$jscomp$94$$),$l$jscomp$94$$],null)};$app$common$types$color$hex__GT_rgba$$=function($data$jscomp$128$$,$opacity$jscomp$1$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$color$hex__GT_rgb$$($data$jscomp$128$$),$opacity$jscomp$1$$)};
$APP.$app$common$types$color$hex__GT_hsl$$=function($hex$jscomp$2$$){try{return $APP.$app$common$types$color$rgb__GT_hsl$$($APP.$app$common$types$color$hex__GT_rgb$$($hex$jscomp$2$$))}catch($e45442$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,0,0],null)}};
$app$common$types$color$format_hsla$$=function($a$jscomp$345_p__45443_rounded_a$$){var $h$jscomp$142_rounded_h$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$345_p__45443_rounded_a$$,0,null),$rounded_s_s$jscomp$514$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$345_p__45443_rounded_a$$,1,null),$l$jscomp$95_rounded_l$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$345_p__45443_rounded_a$$,2,null);$a$jscomp$345_p__45443_rounded_a$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$345_p__45443_rounded_a$$,
3,null);$h$jscomp$142_rounded_h$$|=0;$rounded_s_s$jscomp$514$$=$app$common$data$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$(100*$rounded_s_s$jscomp$514$$);$l$jscomp$95_rounded_l$$=$app$common$data$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$(100*$l$jscomp$95_rounded_l$$);$a$jscomp$345_p__45443_rounded_a$$=$app$common$data$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($a$jscomp$345_p__45443_rounded_a$$);return""+($h$jscomp$142_rounded_h$$??"")+", "+($rounded_s_s$jscomp$514$$??"")+
"%, "+($l$jscomp$95_rounded_l$$??"")+"%, "+($a$jscomp$345_p__45443_rounded_a$$??"")};
$app$common$types$color$format_rgba$$=function($a$jscomp$346_p__45448_rounded_a$jscomp$1$$){var $r$jscomp$93$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$346_p__45448_rounded_a$jscomp$1$$,0,null),$g$jscomp$130$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$346_p__45448_rounded_a$jscomp$1$$,1,null),$b$jscomp$274$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$346_p__45448_rounded_a$jscomp$1$$,2,null);$a$jscomp$346_p__45448_rounded_a$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$346_p__45448_rounded_a$jscomp$1$$,3,null);$a$jscomp$346_p__45448_rounded_a$jscomp$1$$=$app$common$data$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($a$jscomp$346_p__45448_rounded_a$jscomp$1$$);return""+($r$jscomp$93$$??"")+", "+($g$jscomp$130$$??"")+", "+($b$jscomp$274$$??"")+", "+($a$jscomp$346_p__45448_rounded_a$jscomp$1$$??"")};
$APP.$app$common$types$color$expand_hex$$=function($c$jscomp$266_v$jscomp$512$$){if($APP.$cljs$core$truth_$$($APP.$cljs$core$re_matches$$(/^[0-9A-Fa-f]$/,$c$jscomp$266_v$jscomp$512$$)))return""+($c$jscomp$266_v$jscomp$512$$??"")+($c$jscomp$266_v$jscomp$512$$??"")+($c$jscomp$266_v$jscomp$512$$??"")+($c$jscomp$266_v$jscomp$512$$??"")+($c$jscomp$266_v$jscomp$512$$??"")+($c$jscomp$266_v$jscomp$512$$??"");if($APP.$cljs$core$truth_$$($APP.$cljs$core$re_matches$$(/^[0-9A-Fa-f]{2}$/,$c$jscomp$266_v$jscomp$512$$)))return""+
($c$jscomp$266_v$jscomp$512$$??"")+($c$jscomp$266_v$jscomp$512$$??"")+($c$jscomp$266_v$jscomp$512$$??"");if($APP.$cljs$core$truth_$$($APP.$cljs$core$re_matches$$(/^[0-9A-Fa-f]{3}$/,$c$jscomp$266_v$jscomp$512$$))){var $a$jscomp$347$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($c$jscomp$266_v$jscomp$512$$,0),$b$jscomp$277$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($c$jscomp$266_v$jscomp$512$$,1);$c$jscomp$266_v$jscomp$512$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($c$jscomp$266_v$jscomp$512$$,
2);return""+($a$jscomp$347$$??"")+($a$jscomp$347$$??"")+($b$jscomp$277$$??"")+($b$jscomp$277$$??"")+($c$jscomp$266_v$jscomp$512$$??"")+($c$jscomp$266_v$jscomp$512$$??"")}return $c$jscomp$266_v$jscomp$512$$};$APP.$app$common$types$color$prepend_hash$$=function($color$jscomp$12$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("#",$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$12$$,0,1))?$color$jscomp$12$$:"#"+($color$jscomp$12$$??"")};
$APP.$app$common$types$color$color_string_QMARK_$$=function($color$jscomp$14$$){return typeof $color$jscomp$14$$==="string"&&($APP.$app$common$types$color$valid_hex_color_QMARK_$$($color$jscomp$14$$)||(typeof $color$jscomp$14$$==="string"?$app$common$types$color$parse_rgb$$($color$jscomp$14$$)!=null:!1)||$APP.$cljs$core$contains_QMARK_$$($app$common$types$color$names$$,$color$jscomp$14$$))};
$APP.$app$common$types$color$parse$$=function($color$jscomp$15$$){if(typeof $color$jscomp$15$$==="string"){if($APP.$app$common$types$color$valid_hex_color_QMARK_$$($color$jscomp$15$$)||$APP.$app$common$types$color$valid_hex_color_QMARK_$$("#"+($color$jscomp$15$$??"")))return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($color$jscomp$15$$),4)?$APP.$cuerdas$core$lower$$($APP.$cuerdas$core$replace$$($color$jscomp$15$$,/#(.)(.)(.)/,"#$1$1$2$2$3$3")):$APP.$cuerdas$core$lower$$($color$jscomp$15$$);
var $G__45502$jscomp$inline_4760_or__5025__auto__$jscomp$326$$=$app$common$types$color$parse_rgb$$($color$jscomp$15$$);$G__45502$jscomp$inline_4760_or__5025__auto__$jscomp$326$$=$G__45502$jscomp$inline_4760_or__5025__auto__$jscomp$326$$==null?null:$APP.$app$common$types$color$rgb__GT_hex$$($G__45502$jscomp$inline_4760_or__5025__auto__$jscomp$326$$);return $APP.$cljs$core$truth_$$($G__45502$jscomp$inline_4760_or__5025__auto__$jscomp$326$$)?$G__45502$jscomp$inline_4760_or__5025__auto__$jscomp$326$$:
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$color$names$$,$APP.$cuerdas$core$lower$$($color$jscomp$15$$))}return null};
$JSCompiler_StaticMethods__findEntry$$=function($JSCompiler_StaticMethods__findEntry$self$$,$bucket$jscomp$11$$,$key$jscomp$299$$){let $i$jscomp$477$$=0,$found$jscomp$16$$=null;for(;$i$jscomp$477$$<$bucket$jscomp$11$$.length;){const $e$jscomp$284$$=$bucket$jscomp$11$$[$i$jscomp$477$$],$k$jscomp$579$$=$e$jscomp$284$$.$keyRef$.deref();$k$jscomp$579$$===void 0?($bucket$jscomp$11$$[$i$jscomp$477$$]=$bucket$jscomp$11$$[$bucket$jscomp$11$$.length-1],$bucket$jscomp$11$$.pop()):($found$jscomp$16$$===null&&
$JSCompiler_StaticMethods__findEntry$self$$.$_equals$($k$jscomp$579$$,$key$jscomp$299$$)&&($found$jscomp$16$$=$e$jscomp$284$$),$i$jscomp$477$$++)}return $found$jscomp$16$$};
$app$common$weak$weak_key$$=function($o$jscomp$239$$){var $key$jscomp$308_key__$1$jscomp$2$$=$app$common$weak$state$$.get($o$jscomp$239$$);if($key$jscomp$308_key__$1$jscomp$2$$!=null)return $key$jscomp$308_key__$1$jscomp$2$$;$key$jscomp$308_key__$1$jscomp$2$$=["weak-key",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$common$weak$global_counter$$++)].join("");$app$common$weak$state$$.set($o$jscomp$239$$,$key$jscomp$308_key__$1$jscomp$2$$);return $key$jscomp$308_key__$1$jscomp$2$$};
$app$common$buffer$wrap$$=function(){return new DataView($APP.$app$render_wasm$mem$get_heap_u8$$().buffer)};
$app$common$buffer$equals_QMARK_$$=function($buffer_a_cb$jscomp$9$$,$buffer_b_ob$jscomp$82$$){var $i$jscomp$479_len_a$$=$buffer_a_cb$jscomp$9$$.byteLength,$len_b_sz$$=$buffer_b_ob$jscomp$82$$.byteLength;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$479_len_a$$,$len_b_sz$$))for($buffer_a_cb$jscomp$9$$=new Uint8Array($buffer_a_cb$jscomp$9$$.buffer,$buffer_a_cb$jscomp$9$$.byteOffset,$i$jscomp$479_len_a$$),$buffer_b_ob$jscomp$82$$=new Uint8Array($buffer_b_ob$jscomp$82$$.buffer,$buffer_b_ob$jscomp$82$$.byteOffset,
$len_b_sz$$),$len_b_sz$$=$buffer_a_cb$jscomp$9$$.length,$i$jscomp$479_len_a$$=0;;){if($i$jscomp$479_len_a$$<$len_b_sz$$)if($buffer_b_ob$jscomp$82$$[$i$jscomp$479_len_a$$]===$buffer_a_cb$jscomp$9$$[$i$jscomp$479_len_a$$]){$i$jscomp$479_len_a$$+=1;continue}else return!1;else return!0;break}else return!1};
$app$common$types$fills$impl$_write_to$$=function($_$jscomp$1079$$,$offset$jscomp$100$$){var $buffer$jscomp$36$$=$APP.$app$render_wasm$mem$get_heap_u32$$();if($_$jscomp$1079$$!=null&&$_$jscomp$1079$$.$app$common$types$fills$impl$IHeapWritable$_write_to$arity$3$!=null)$_$jscomp$1079$$.$app$common$types$fills$impl$IHeapWritable$_write_to$arity$3$($_$jscomp$1079$$,$buffer$jscomp$36$$,$offset$jscomp$100$$);else{var $m__5372__auto__$jscomp$inline_4770_m__5374__auto__$jscomp$inline_4769$$=$app$common$types$fills$impl$_write_to$$[$APP.$goog$typeOf$$($_$jscomp$1079$$==
null?null:$_$jscomp$1079$$)];if($m__5372__auto__$jscomp$inline_4770_m__5374__auto__$jscomp$inline_4769$$!=null)$m__5372__auto__$jscomp$inline_4770_m__5374__auto__$jscomp$inline_4769$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_4770_m__5374__auto__$jscomp$inline_4769$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$1079$$,$buffer$jscomp$36$$,$offset$jscomp$100$$):$m__5372__auto__$jscomp$inline_4770_m__5374__auto__$jscomp$inline_4769$$($_$jscomp$1079$$,$buffer$jscomp$36$$,$offset$jscomp$100$$);
else if($m__5372__auto__$jscomp$inline_4770_m__5374__auto__$jscomp$inline_4769$$=$app$common$types$fills$impl$_write_to$$._,$m__5372__auto__$jscomp$inline_4770_m__5374__auto__$jscomp$inline_4769$$!=null)$m__5372__auto__$jscomp$inline_4770_m__5374__auto__$jscomp$inline_4769$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_4770_m__5374__auto__$jscomp$inline_4769$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$1079$$,$buffer$jscomp$36$$,$offset$jscomp$100$$):$m__5372__auto__$jscomp$inline_4770_m__5374__auto__$jscomp$inline_4769$$($_$jscomp$1079$$,
$buffer$jscomp$36$$,$offset$jscomp$100$$);else throw $APP.$cljs$core$missing_protocol$$("IHeapWritable.-write-to",$_$jscomp$1079$$);}};
$app$common$types$fills$impl$_get_byte_size$$=function($JSCompiler_temp$jscomp$721__$jscomp$1081$$){if($JSCompiler_temp$jscomp$721__$jscomp$1081$$!=null&&$JSCompiler_temp$jscomp$721__$jscomp$1081$$.$app$common$types$fills$impl$IHeapWritable$_get_byte_size$arity$1$!=null)$JSCompiler_temp$jscomp$721__$jscomp$1081$$=$JSCompiler_temp$jscomp$721__$jscomp$1081$$.$app$common$types$fills$impl$IHeapWritable$_get_byte_size$arity$1$($JSCompiler_temp$jscomp$721__$jscomp$1081$$);else{var $m__5372__auto__$jscomp$inline_4774_m__5374__auto__$jscomp$inline_4773$$=
$app$common$types$fills$impl$_get_byte_size$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$721__$jscomp$1081$$==null?null:$JSCompiler_temp$jscomp$721__$jscomp$1081$$)];if($m__5372__auto__$jscomp$inline_4774_m__5374__auto__$jscomp$inline_4773$$!=null)$JSCompiler_temp$jscomp$721__$jscomp$1081$$=$m__5372__auto__$jscomp$inline_4774_m__5374__auto__$jscomp$inline_4773$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_4774_m__5374__auto__$jscomp$inline_4773$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$721__$jscomp$1081$$):
$m__5372__auto__$jscomp$inline_4774_m__5374__auto__$jscomp$inline_4773$$($JSCompiler_temp$jscomp$721__$jscomp$1081$$);else if($m__5372__auto__$jscomp$inline_4774_m__5374__auto__$jscomp$inline_4773$$=$app$common$types$fills$impl$_get_byte_size$$._,$m__5372__auto__$jscomp$inline_4774_m__5374__auto__$jscomp$inline_4773$$!=null)$JSCompiler_temp$jscomp$721__$jscomp$1081$$=$m__5372__auto__$jscomp$inline_4774_m__5374__auto__$jscomp$inline_4773$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_4774_m__5374__auto__$jscomp$inline_4773$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$721__$jscomp$1081$$):
$m__5372__auto__$jscomp$inline_4774_m__5374__auto__$jscomp$inline_4773$$($JSCompiler_temp$jscomp$721__$jscomp$1081$$);else throw $APP.$cljs$core$missing_protocol$$("IHeapWritable.-get-byte-size",$JSCompiler_temp$jscomp$721__$jscomp$1081$$);}return $JSCompiler_temp$jscomp$721__$jscomp$1081$$};
$app$common$types$fills$impl$_get_image_ids$$=function($JSCompiler_temp$jscomp$722__$jscomp$1083$$){if($JSCompiler_temp$jscomp$722__$jscomp$1083$$!=null&&$JSCompiler_temp$jscomp$722__$jscomp$1083$$.$app$common$types$fills$impl$IBinaryFills$_get_image_ids$arity$1$!=null)$JSCompiler_temp$jscomp$722__$jscomp$1083$$=$JSCompiler_temp$jscomp$722__$jscomp$1083$$.$image_ids$;else{var $m__5372__auto__$jscomp$inline_4778_m__5374__auto__$jscomp$inline_4777$$=$app$common$types$fills$impl$_get_image_ids$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$722__$jscomp$1083$$==
null?null:$JSCompiler_temp$jscomp$722__$jscomp$1083$$)];if($m__5372__auto__$jscomp$inline_4778_m__5374__auto__$jscomp$inline_4777$$!=null)$JSCompiler_temp$jscomp$722__$jscomp$1083$$=$m__5372__auto__$jscomp$inline_4778_m__5374__auto__$jscomp$inline_4777$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_4778_m__5374__auto__$jscomp$inline_4777$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$722__$jscomp$1083$$):$m__5372__auto__$jscomp$inline_4778_m__5374__auto__$jscomp$inline_4777$$($JSCompiler_temp$jscomp$722__$jscomp$1083$$);
else if($m__5372__auto__$jscomp$inline_4778_m__5374__auto__$jscomp$inline_4777$$=$app$common$types$fills$impl$_get_image_ids$$._,$m__5372__auto__$jscomp$inline_4778_m__5374__auto__$jscomp$inline_4777$$!=null)$JSCompiler_temp$jscomp$722__$jscomp$1083$$=$m__5372__auto__$jscomp$inline_4778_m__5374__auto__$jscomp$inline_4777$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_4778_m__5374__auto__$jscomp$inline_4777$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$722__$jscomp$1083$$):
$m__5372__auto__$jscomp$inline_4778_m__5374__auto__$jscomp$inline_4777$$($JSCompiler_temp$jscomp$722__$jscomp$1083$$);else throw $APP.$cljs$core$missing_protocol$$("IBinaryFills.-get-image-ids",$JSCompiler_temp$jscomp$722__$jscomp$1083$$);}return $JSCompiler_temp$jscomp$722__$jscomp$1083$$};
$app$common$types$fills$impl$hex__GT_rgb$$=function($hex$jscomp$3_hex__$1$$){$hex$jscomp$3_hex__$1$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($hex$jscomp$3_hex__$1$$,1);return parseInt($hex$jscomp$3_hex__$1$$,16)};
$app$common$types$fills$impl$write_solid_fill$$=function($offset$jscomp$101$$,$buffer$jscomp$37$$,$opacity$jscomp$3$$,$color$jscomp$16_n$jscomp$inline_4780$$){$buffer$jscomp$37$$.setInt8($offset$jscomp$101$$+0,0,!0);var $JSCompiler_temp_const$jscomp$723$$=$buffer$jscomp$37$$.setInt32;$color$jscomp$16_n$jscomp$inline_4780$$=$app$common$types$fills$impl$hex__GT_rgb$$($color$jscomp$16_n$jscomp$inline_4780$$);$JSCompiler_temp_const$jscomp$723$$.call($buffer$jscomp$37$$,$offset$jscomp$101$$+4,$APP.$cljs$core$fix$$($APP.$app$common$math$floor$$($opacity$jscomp$3$$*
255))<<24|$color$jscomp$16_n$jscomp$inline_4780$$,!0);return $offset$jscomp$101$$+160};
$app$common$types$fills$impl$write_gradient_fill$$=function($offset$jscomp$102$$,$buffer$jscomp$38$$,$alpha$jscomp$5_opacity$jscomp$4$$,$alpha$jscomp$inline_4784_gradient_type$jscomp$316$$){var $G__45820_start_x_stops__$1$$=$APP.$cljs$cst$1729$start_x$$.$cljs$core$IFn$_invoke$arity$1$($alpha$jscomp$inline_4784_gradient_type$jscomp$316$$),$G__45821_offset_SINGLEQUOTE__start_y$$=$APP.$cljs$cst$1730$start_y$$.$cljs$core$IFn$_invoke$arity$1$($alpha$jscomp$inline_4784_gradient_type$jscomp$316$$),$end_x_stop$jscomp$1_temp__5823__auto__$jscomp$100$$=
$APP.$cljs$cst$1731$end_x$$.$cljs$core$IFn$_invoke$arity$1$($alpha$jscomp$inline_4784_gradient_type$jscomp$316$$),$end_y_n$jscomp$inline_4783$$=$APP.$cljs$cst$1732$end_y$$.$cljs$core$IFn$_invoke$arity$1$($alpha$jscomp$inline_4784_gradient_type$jscomp$316$$);$alpha$jscomp$5_opacity$jscomp$4$$=$APP.$app$common$math$floor$$($alpha$jscomp$5_opacity$jscomp$4$$*255);var $width$jscomp$55$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$inline_4784_gradient_type$jscomp$316$$,0),
$stops$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$common$types$fills$impl$xf_COLON_take_stops$$,$APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($alpha$jscomp$inline_4784_gradient_type$jscomp$316$$));$alpha$jscomp$inline_4784_gradient_type$jscomp$316$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($alpha$jscomp$inline_4784_gradient_type$jscomp$316$$),$APP.$cljs$cst$287$linear$$)?
1:2;$buffer$jscomp$38$$.setInt8($offset$jscomp$102$$+0,$alpha$jscomp$inline_4784_gradient_type$jscomp$316$$,!0);$buffer$jscomp$38$$.setFloat32($offset$jscomp$102$$+4,$G__45820_start_x_stops__$1$$,!0);$buffer$jscomp$38$$.setFloat32($offset$jscomp$102$$+8,$G__45821_offset_SINGLEQUOTE__start_y$$,!0);$buffer$jscomp$38$$.setFloat32($offset$jscomp$102$$+12,$end_x_stop$jscomp$1_temp__5823__auto__$jscomp$100$$,!0);$buffer$jscomp$38$$.setFloat32($offset$jscomp$102$$+16,$end_y_n$jscomp$inline_4783$$,!0);$buffer$jscomp$38$$.setInt8($offset$jscomp$102$$+
20,$alpha$jscomp$5_opacity$jscomp$4$$,!0);$buffer$jscomp$38$$.setFloat32($offset$jscomp$102$$+24,$width$jscomp$55$$,!0);$buffer$jscomp$38$$.setInt8($offset$jscomp$102$$+28,$APP.$cljs$core$count$$($stops$jscomp$2$$),!0);$G__45820_start_x_stops__$1$$=$APP.$cljs$core$seq$$($stops$jscomp$2$$);for($G__45821_offset_SINGLEQUOTE__start_y$$=$offset$jscomp$102$$+32;;)if($end_x_stop$jscomp$1_temp__5823__auto__$jscomp$100$$=$APP.$cljs$core$first$$($G__45820_start_x_stops__$1$$),$APP.$cljs$core$truth_$$($end_x_stop$jscomp$1_temp__5823__auto__$jscomp$100$$))$end_y_n$jscomp$inline_4783$$=
$app$common$types$fills$impl$hex__GT_rgb$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($end_x_stop$jscomp$1_temp__5823__auto__$jscomp$100$$)),$alpha$jscomp$inline_4784_gradient_type$jscomp$316$$=$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$2$($end_x_stop$jscomp$1_temp__5823__auto__$jscomp$100$$,1),$buffer$jscomp$38$$.setInt32($G__45821_offset_SINGLEQUOTE__start_y$$+0,$APP.$cljs$core$fix$$($APP.$app$common$math$floor$$($alpha$jscomp$inline_4784_gradient_type$jscomp$316$$*
255))<<24|$end_y_n$jscomp$inline_4783$$,!0),$buffer$jscomp$38$$.setFloat32($G__45821_offset_SINGLEQUOTE__start_y$$+4,$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($end_x_stop$jscomp$1_temp__5823__auto__$jscomp$100$$),!0),$G__45820_start_x_stops__$1$$=$APP.$cljs$core$rest$$($G__45820_start_x_stops__$1$$),$G__45821_offset_SINGLEQUOTE__start_y$$+=8;else return $offset$jscomp$102$$+160};
$app$common$types$fills$impl$write_image_fill$$=function($offset$jscomp$103$$,$buffer$jscomp$39$$,$alpha$jscomp$6_opacity$jscomp$5$$,$flags$jscomp$14_image$jscomp$8$$){var $barray__45664__auto___45822_image_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($flags$jscomp$14_image$jscomp$8$$,$APP.$cljs$cst$266$id$$),$image_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($flags$jscomp$14_image$jscomp$8$$,$APP.$cljs$cst$290$width$$),$image_height$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($flags$jscomp$14_image$jscomp$8$$,
$APP.$cljs$cst$1522$height$$);$alpha$jscomp$6_opacity$jscomp$5$$=$APP.$app$common$math$floor$$($alpha$jscomp$6_opacity$jscomp$5$$*255);$flags$jscomp$14_image$jscomp$8$$=($APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($flags$jscomp$14_image$jscomp$8$$,$APP.$cljs$cst$1727$keep_aspect_ratio$$,!1))?1:0)|0;$buffer$jscomp$39$$.setInt8($offset$jscomp$103$$+0,3,!0);$barray__45664__auto___45822_image_id$$=$APP.$app$common$uuid$get_u32$$($barray__45664__auto___45822_image_id$$);
$buffer$jscomp$39$$.setUint32($offset$jscomp$103$$+4+0,$barray__45664__auto___45822_image_id$$[0],!0);$buffer$jscomp$39$$.setUint32($offset$jscomp$103$$+4+4,$barray__45664__auto___45822_image_id$$[1],!0);$buffer$jscomp$39$$.setUint32($offset$jscomp$103$$+4+8,$barray__45664__auto___45822_image_id$$[2],!0);$buffer$jscomp$39$$.setUint32($offset$jscomp$103$$+4+12,$barray__45664__auto___45822_image_id$$[3],!0);$buffer$jscomp$39$$.setInt8($offset$jscomp$103$$+20,$alpha$jscomp$6_opacity$jscomp$5$$,!0);$buffer$jscomp$39$$.setInt8($offset$jscomp$103$$+
21,$flags$jscomp$14_image$jscomp$8$$,!0);$buffer$jscomp$39$$.setInt16($offset$jscomp$103$$+22,0,!0);$buffer$jscomp$39$$.setInt32($offset$jscomp$103$$+24,$image_width$$,!0);$buffer$jscomp$39$$.setInt32($offset$jscomp$103$$+28,$image_height$$,!0);return $offset$jscomp$103$$+160};
$app$common$types$fills$impl$write_metadata$$=function($offset$jscomp$104$$,$buffer$jscomp$40$$,$fill$jscomp$3_val_45823$$){var $barray__45664__auto___ref_id$jscomp$1$$=$APP.$cljs$cst$1745$fill_color_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$3_val_45823$$),$barray__45664__auto___45825_ref_file$$=$APP.$cljs$cst$1640$fill_color_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$3_val_45823$$),$mtype$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill$jscomp$3_val_45823$$,
$APP.$cljs$cst$1632$fill_image$$),$APP.$cljs$cst$1726$mtype$$);$APP.$cljs$core$truth_$$($mtype$jscomp$6$$)&&($fill$jscomp$3_val_45823$$=function(){switch($mtype$jscomp$6$$){case "image/jpeg":return 1;case "image/png":return 2;case "image/gif":return 3;case "image/webp":return 4;case "image/svg+xml":return 5;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($mtype$jscomp$6$$)].join(""));}}(),$buffer$jscomp$40$$.setInt16($offset$jscomp$104$$+2,$fill$jscomp$3_val_45823$$,
!0));$barray__45664__auto___45825_ref_file$$!=null&&$barray__45664__auto___ref_id$jscomp$1$$!=null?($buffer$jscomp$40$$.setInt8($offset$jscomp$104$$+0,1,!0),$barray__45664__auto___45825_ref_file$$=$APP.$app$common$uuid$get_u32$$($barray__45664__auto___45825_ref_file$$),$buffer$jscomp$40$$.setUint32($offset$jscomp$104$$+4+0,$barray__45664__auto___45825_ref_file$$[0],!0),$buffer$jscomp$40$$.setUint32($offset$jscomp$104$$+4+4,$barray__45664__auto___45825_ref_file$$[1],!0),$buffer$jscomp$40$$.setUint32($offset$jscomp$104$$+
4+8,$barray__45664__auto___45825_ref_file$$[2],!0),$buffer$jscomp$40$$.setUint32($offset$jscomp$104$$+4+12,$barray__45664__auto___45825_ref_file$$[3],!0),$barray__45664__auto___ref_id$jscomp$1$$=$APP.$app$common$uuid$get_u32$$($barray__45664__auto___ref_id$jscomp$1$$),$buffer$jscomp$40$$.setUint32($offset$jscomp$104$$+20+0,$barray__45664__auto___ref_id$jscomp$1$$[0],!0),$buffer$jscomp$40$$.setUint32($offset$jscomp$104$$+20+4,$barray__45664__auto___ref_id$jscomp$1$$[1],!0),$buffer$jscomp$40$$.setUint32($offset$jscomp$104$$+
20+8,$barray__45664__auto___ref_id$jscomp$1$$[2],!0),$buffer$jscomp$40$$.setUint32($offset$jscomp$104$$+20+12,$barray__45664__auto___ref_id$jscomp$1$$[3],!0)):$buffer$jscomp$40$$.setInt8($offset$jscomp$104$$+0,0,!0)};
$app$common$types$fills$impl$read_fill$$=function($dbuffer$$,$mbuffer$$,$fill$jscomp$4_index$jscomp$166$$){var $doffset$$=4+$fill$jscomp$4_index$jscomp$166$$*160,$moffset$$=$fill$jscomp$4_index$jscomp$166$$*36,$type$jscomp$317$$=$dbuffer$$.getInt8($doffset$$,!0),$ref_file$jscomp$1_refs_QMARK_$$=1===$mbuffer$$.getInt8($moffset$$+0,!0);$fill$jscomp$4_index$jscomp$166$$=function(){switch($type$jscomp$317$$){case 0:var $flags$jscomp$15_rgba$jscomp$1_width$jscomp$56$$=$dbuffer$$.getInt32($doffset$$+4,
!0);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1746$fill_color$$,"#"+(($flags$jscomp$15_rgba$jscomp$1_width$jscomp$56$$&16777215).toString(16).padStart(6,"0")??""),$APP.$cljs$cst$1747$fill_opacity$$,$APP.$app$common$math$precision$$((($flags$jscomp$15_rgba$jscomp$1_width$jscomp$56$$&4278190080)>>>24)/255,2)],null);case 1:case 2:var $id$jscomp$151_start_x$jscomp$1$$=$dbuffer$$.getFloat32($doffset$$+4,!0),$ratio_start_y$jscomp$1$$=$dbuffer$$.getFloat32($doffset$$+8,!0),$end_x$jscomp$1_height$jscomp$49$$=
$dbuffer$$.getFloat32($doffset$$+12,!0),$end_y$jscomp$1_mtype__$1$$=$dbuffer$$.getFloat32($doffset$$+16,!0),$alpha$jscomp$7_opacity$jscomp$6$$=$dbuffer$$.getUint8($doffset$$+20,!0);$flags$jscomp$15_rgba$jscomp$1_width$jscomp$56$$=$dbuffer$$.getFloat32($doffset$$+24,!0);var $stops$jscomp$3$$=$dbuffer$$.getInt8($doffset$$+28,!0);$alpha$jscomp$7_opacity$jscomp$6$$=$APP.$app$common$math$precision$$($alpha$jscomp$7_opacity$jscomp$6$$/255,2);var $type__$1$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$317$$,
1)?$APP.$cljs$cst$287$linear$$:$APP.$cljs$cst$1728$radial$$,$stops__$1$jscomp$1$$=function(){for(var $JSCompiler_inline_result$jscomp$729_index__$1_rgba$jscomp$inline_4788$$=0,$JSCompiler_temp_const$jscomp$726_result$jscomp$167$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;)if($JSCompiler_inline_result$jscomp$729_index__$1_rgba$jscomp$inline_4788$$<$stops$jscomp$3$$){var $G__45833$$=$JSCompiler_inline_result$jscomp$729_index__$1_rgba$jscomp$inline_4788$$+1,$G__45834_JSCompiler_temp_const$jscomp$728$$=
$APP.$cljs$core$conj$$,$JSCompiler_temp_const$jscomp$727$$=$G__45834_JSCompiler_temp_const$jscomp$728$$.$cljs$core$IFn$_invoke$arity$2$,$buffer$jscomp$inline_4786_soff$jscomp$inline_4789$$=$dbuffer$$,$offset$jscomp$inline_4787$$=$doffset$$+32+8*$JSCompiler_inline_result$jscomp$729_index__$1_rgba$jscomp$inline_4788$$;$JSCompiler_inline_result$jscomp$729_index__$1_rgba$jscomp$inline_4788$$=$buffer$jscomp$inline_4786_soff$jscomp$inline_4789$$.getInt32($offset$jscomp$inline_4787$$+0,!0);$buffer$jscomp$inline_4786_soff$jscomp$inline_4789$$=
$buffer$jscomp$inline_4786_soff$jscomp$inline_4789$$.getFloat32($offset$jscomp$inline_4787$$+4,!0);$JSCompiler_inline_result$jscomp$729_index__$1_rgba$jscomp$inline_4788$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1298$color$$,"#"+(($JSCompiler_inline_result$jscomp$729_index__$1_rgba$jscomp$inline_4788$$&16777215).toString(16).padStart(6,"0")??""),$APP.$cljs$cst$1734$opacity$$,$APP.$app$common$math$precision$$((($JSCompiler_inline_result$jscomp$729_index__$1_rgba$jscomp$inline_4788$$&
4278190080)>>>24)/255,2),$APP.$cljs$cst$195$offset$$,$APP.$app$common$math$precision$$($buffer$jscomp$inline_4786_soff$jscomp$inline_4789$$,2)],null);$G__45834_JSCompiler_temp_const$jscomp$728$$=$JSCompiler_temp_const$jscomp$727$$.call($G__45834_JSCompiler_temp_const$jscomp$728$$,$JSCompiler_temp_const$jscomp$726_result$jscomp$167$$,$JSCompiler_inline_result$jscomp$729_index__$1_rgba$jscomp$inline_4788$$);$JSCompiler_inline_result$jscomp$729_index__$1_rgba$jscomp$inline_4788$$=$G__45833$$;$JSCompiler_temp_const$jscomp$726_result$jscomp$167$$=
$G__45834_JSCompiler_temp_const$jscomp$728$$}else return $JSCompiler_temp_const$jscomp$726_result$jscomp$167$$}();return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1747$fill_opacity$$,$alpha$jscomp$7_opacity$jscomp$6$$,$APP.$cljs$cst$1748$fill_color_gradient$$,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1729$start_x$$,$id$jscomp$151_start_x$jscomp$1$$,$APP.$cljs$cst$1730$start_y$$,$ratio_start_y$jscomp$1$$,$APP.$cljs$cst$1731$end_x$$,$end_x$jscomp$1_height$jscomp$49$$,
$APP.$cljs$cst$1732$end_y$$,$end_y$jscomp$1_mtype__$1$$,$APP.$cljs$cst$290$width$$,$flags$jscomp$15_rgba$jscomp$1_width$jscomp$56$$,$APP.$cljs$cst$1733$stops$$,$stops__$1$jscomp$1$$,$APP.$cljs$cst$139$type$$,$type__$1$jscomp$1$$],null)],null);case 3:$id$jscomp$151_start_x$jscomp$1$$=function(){var $a__45571__auto__$$=$dbuffer$$.getUint32($doffset$$+4+0,!0),$b__45572__auto__$$=$dbuffer$$.getUint32($doffset$$+4+4,!0),$c__45573__auto__$$=$dbuffer$$.getUint32($doffset$$+4+8,!0),$d__45574__auto__$$=$dbuffer$$.getUint32($doffset$$+
4+12,!0);return $app$common$uuid$uuid$$($app$common$uuid_impl$v8$$.$fromUnsignedParts$($a__45571__auto__$$,$b__45572__auto__$$,$c__45573__auto__$$,$d__45574__auto__$$))}();$alpha$jscomp$7_opacity$jscomp$6$$=$dbuffer$$.getUint8($doffset$$+20,!0);$alpha$jscomp$7_opacity$jscomp$6$$=$APP.$app$common$math$precision$$($alpha$jscomp$7_opacity$jscomp$6$$/255,2);$flags$jscomp$15_rgba$jscomp$1_width$jscomp$56$$=$dbuffer$$.getUint8($doffset$$+21,!0);$ratio_start_y$jscomp$1$$=$APP.$cljs$core$boolean$0$$($flags$jscomp$15_rgba$jscomp$1_width$jscomp$56$$&
1);$flags$jscomp$15_rgba$jscomp$1_width$jscomp$56$$=$dbuffer$$.getInt32($doffset$$+24,!0);$end_x$jscomp$1_height$jscomp$49$$=$dbuffer$$.getInt32($doffset$$+28,!0);var $mtype$jscomp$7$$=$mbuffer$$.getInt16($moffset$$+2,!0);$end_y$jscomp$1_mtype__$1$$=function(){switch($mtype$jscomp$7$$){case 1:return"image/jpeg";case 2:return"image/png";case 3:return"image/gif";case 4:return"image/webp";case 5:return"image/svg+xml";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($mtype$jscomp$7$$)].join(""));
}}();return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1747$fill_opacity$$,$alpha$jscomp$7_opacity$jscomp$6$$,$APP.$cljs$cst$1632$fill_image$$,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$266$id$$,$id$jscomp$151_start_x$jscomp$1$$,$APP.$cljs$cst$290$width$$,$flags$jscomp$15_rgba$jscomp$1_width$jscomp$56$$,$APP.$cljs$cst$1522$height$$,$end_x$jscomp$1_height$jscomp$49$$,$APP.$cljs$cst$1726$mtype$$,$end_y$jscomp$1_mtype__$1$$,$APP.$cljs$cst$1727$keep_aspect_ratio$$,
$ratio_start_y$jscomp$1$$,$APP.$cljs$cst$725$name$$,"sample"],null)],null);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$317$$)].join(""));}}();if($ref_file$jscomp$1_refs_QMARK_$$){$ref_file$jscomp$1_refs_QMARK_$$=function(){var $a__45571__auto__$jscomp$1$$=$mbuffer$$.getUint32($moffset$$+4+0,!0),$b__45572__auto__$jscomp$1$$=$mbuffer$$.getUint32($moffset$$+4+4,!0),$c__45573__auto__$jscomp$1$$=$mbuffer$$.getUint32($moffset$$+4+8,!0),
$d__45574__auto__$jscomp$1$$=$mbuffer$$.getUint32($moffset$$+4+12,!0);return $app$common$uuid$uuid$$($app$common$uuid_impl$v8$$.$fromUnsignedParts$($a__45571__auto__$jscomp$1$$,$b__45572__auto__$jscomp$1$$,$c__45573__auto__$jscomp$1$$,$d__45574__auto__$jscomp$1$$))}();var $ref_id$jscomp$2$$=function(){var $a__45571__auto__$jscomp$2$$=$mbuffer$$.getUint32($moffset$$+20+0,!0),$b__45572__auto__$jscomp$2$$=$mbuffer$$.getUint32($moffset$$+20+4,!0),$c__45573__auto__$jscomp$2$$=$mbuffer$$.getUint32($moffset$$+
20+8,!0),$d__45574__auto__$jscomp$2$$=$mbuffer$$.getUint32($moffset$$+20+12,!0);return $app$common$uuid$uuid$$($app$common$uuid_impl$v8$$.$fromUnsignedParts$($a__45571__auto__$jscomp$2$$,$b__45572__auto__$jscomp$2$$,$c__45573__auto__$jscomp$2$$,$d__45574__auto__$jscomp$2$$))}();return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($fill$jscomp$4_index$jscomp$166$$,$APP.$cljs$cst$1745$fill_color_ref_id$$,$ref_id$jscomp$2$$),$APP.$cljs$cst$1640$fill_color_ref_file$$,
$ref_file$jscomp$1_refs_QMARK_$$)}return $fill$jscomp$4_index$jscomp$166$$};
$app$common$types$fills$impl$Fills$$=function($size$jscomp$87$$,$dbuffer$jscomp$1$$,$mbuffer$jscomp$1$$,$image_ids$$,$cache$jscomp$98$$,$__hash$jscomp$71$$){this.size=$size$jscomp$87$$;this.$dbuffer$=$dbuffer$jscomp$1$$;this.$mbuffer$=$mbuffer$jscomp$1$$;this.$image_ids$=$image_ids$$;this.cache=$cache$jscomp$98$$;this.$__hash$=$__hash$jscomp$71$$;this.$cljs$lang$protocol_mask$partition0$$=2179465746;this.$cljs$lang$protocol_mask$partition1$$=0};
$APP.$app$common$types$fills$impl$from_plain$$=function($fills_fills__$1$$){$fills_fills__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$common$types$fills$impl$xf_COLON_take_fills$$,$fills_fills__$1$$);var $total$jscomp$3$$=$APP.$cljs$core$count$$($fills_fills__$1$$),$dbuffer$jscomp$3$$=new DataView(new ArrayBuffer(1284)),$mbuffer$jscomp$3$$=new DataView(new ArrayBuffer($total$jscomp$3$$*36));$dbuffer$jscomp$3$$.setInt8(0,$total$jscomp$3$$,
!0);for(var $G__45863_index$jscomp$169$$=0,$G__45860_G__45862_G__45864_image_ids$jscomp$2$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$;;){if($G__45863_index$jscomp$169$$<$total$jscomp$3$$){var $fill$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($fills_fills__$1$$,$G__45863_index$jscomp$169$$),$doffset$jscomp$1$$=4+$G__45863_index$jscomp$169$$*160,$moffset$jscomp$1$$=$G__45863_index$jscomp$169$$*36,$opacity$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($fill$jscomp$5$$,
$APP.$cljs$cst$1747$fill_opacity$$,1),$image$jscomp$9_temp__5823__auto__$jscomp$101_temp__5823__auto____$1$jscomp$9_temp__5823__auto____$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill$jscomp$5$$,$APP.$cljs$cst$1746$fill_color$$);if($APP.$cljs$core$truth_$$($image$jscomp$9_temp__5823__auto__$jscomp$101_temp__5823__auto____$1$jscomp$9_temp__5823__auto____$2$$)){$app$common$types$fills$impl$write_solid_fill$$($doffset$jscomp$1$$,$dbuffer$jscomp$3$$,$opacity$jscomp$7$$,$image$jscomp$9_temp__5823__auto__$jscomp$101_temp__5823__auto____$1$jscomp$9_temp__5823__auto____$2$$);
$app$common$types$fills$impl$write_metadata$$($moffset$jscomp$1$$,$mbuffer$jscomp$3$$,$fill$jscomp$5$$);$G__45863_index$jscomp$169$$+=1;continue}else if($image$jscomp$9_temp__5823__auto__$jscomp$101_temp__5823__auto____$1$jscomp$9_temp__5823__auto____$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill$jscomp$5$$,$APP.$cljs$cst$1748$fill_color_gradient$$),$APP.$cljs$core$truth_$$($image$jscomp$9_temp__5823__auto__$jscomp$101_temp__5823__auto____$1$jscomp$9_temp__5823__auto____$2$$)){$app$common$types$fills$impl$write_gradient_fill$$($doffset$jscomp$1$$,
$dbuffer$jscomp$3$$,$opacity$jscomp$7$$,$image$jscomp$9_temp__5823__auto__$jscomp$101_temp__5823__auto____$1$jscomp$9_temp__5823__auto____$2$$);$app$common$types$fills$impl$write_metadata$$($moffset$jscomp$1$$,$mbuffer$jscomp$3$$,$fill$jscomp$5$$);$G__45863_index$jscomp$169$$+=1;continue}else if($image$jscomp$9_temp__5823__auto__$jscomp$101_temp__5823__auto____$1$jscomp$9_temp__5823__auto____$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill$jscomp$5$$,$APP.$cljs$cst$1632$fill_image$$),
$APP.$cljs$core$truth_$$($image$jscomp$9_temp__5823__auto__$jscomp$101_temp__5823__auto____$1$jscomp$9_temp__5823__auto____$2$$)){$app$common$types$fills$impl$write_image_fill$$($doffset$jscomp$1$$,$dbuffer$jscomp$3$$,$opacity$jscomp$7$$,$image$jscomp$9_temp__5823__auto__$jscomp$101_temp__5823__auto____$1$jscomp$9_temp__5823__auto____$2$$);$app$common$types$fills$impl$write_metadata$$($moffset$jscomp$1$$,$mbuffer$jscomp$3$$,$fill$jscomp$5$$);$G__45863_index$jscomp$169$$+=1;$G__45860_G__45862_G__45864_image_ids$jscomp$2$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__45860_G__45862_G__45864_image_ids$jscomp$2$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($image$jscomp$9_temp__5823__auto__$jscomp$101_temp__5823__auto____$1$jscomp$9_temp__5823__auto____$2$$,$APP.$cljs$cst$266$id$$));continue}else throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("found invalid fill on encoding fills to binary format",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$cljs$cst$1752$internal$$,$APP.$cljs$cst$273$code$$,$cljs$cst$1753$invalid_fill$$,$APP.$cljs$cst$275$hint$$,"found invalid fill on encoding fills to binary format"],null),null])),null);}else return new $app$common$types$fills$impl$Fills$$($total$jscomp$3$$,$dbuffer$jscomp$3$$,$mbuffer$jscomp$3$$,$G__45860_G__45862_G__45864_image_ids$jscomp$2$$,new $module$app$common$weak$impl_weak_value_map$$.$WeakValueMap$,null);break}};
$app$common$types$fills$impl$fills_QMARK_$$=function($o$jscomp$242$$){return $o$jscomp$242$$ instanceof $app$common$types$fills$impl$Fills$$};
$app$common$types$fills$has_valid_fill_attrs_QMARK_$$=function($attrs$jscomp$2_color$jscomp$19_result$jscomp$170$$){$attrs$jscomp$2_color$jscomp$19_result$jscomp$170$$=$APP.$cljs$core$set$$($APP.$cljs$core$keys$$($attrs$jscomp$2_color$jscomp$19_result$jscomp$170$$));$attrs$jscomp$2_color$jscomp$19_result$jscomp$170$$=$APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$2_color$jscomp$19_result$jscomp$170$$,$app$common$types$fills$valid_fill_attrs$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$APP.$cljs$core$count$$($attrs$jscomp$2_color$jscomp$19_result$jscomp$170$$))};
$app$common$types$fills$coerce$$=function($o$jscomp$245$$){if($o$jscomp$245$$==null)return $APP.$app$common$types$fills$impl$from_plain$$($APP.$cljs$core$PersistentVector$EMPTY$$);if($app$common$types$fills$impl$fills_QMARK_$$($o$jscomp$245$$))return $o$jscomp$245$$;if($APP.$cljs$core$vector_QMARK_$$($o$jscomp$245$$))return $APP.$app$common$types$fills$impl$from_plain$$($o$jscomp$245$$);throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$(["cannot coerce ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$o$jscomp$245$$])),
" to fills"].join(""),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$1752$internal$$,$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$1754$invalid_type$$,$APP.$cljs$cst$275$hint$$,["cannot coerce ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$o$jscomp$245$$]))," to fills"].join("")],
null),null])),null);};$app$common$types$fills$get_image_ids$$=function($fills$jscomp$2$$){return $APP.$cljs$core$vector_QMARK_$$($fills$jscomp$2$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1632$fill_image$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$)),$fills$jscomp$2$$):$app$common$types$fills$impl$_get_image_ids$$($fills$jscomp$2$$)};
$app$common$types$fills$assoc$$=function($fills$jscomp$5$$,$position$jscomp$6$$,$fill$jscomp$6$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$flags$_STAR_current_STAR_$$,$APP.$cljs$cst$1755$frontend_binary_fills$$)?$fills$jscomp$5$$==null?$APP.$app$common$types$fills$impl$from_plain$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$fill$jscomp$6$$],null)):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$fills$coerce$$($fills$jscomp$5$$),
$position$jscomp$6$$,$fill$jscomp$6$$):$fills$jscomp$5$$==null?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$fill$jscomp$6$$],null):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($fills$jscomp$5$$,$position$jscomp$6$$,$fill$jscomp$6$$)};
$APP.$app$common$types$fills$create$$=function($var_args$jscomp$921$$){for(var $args__5755__auto__$jscomp$147$$=[],$len__5749__auto___45895$$=arguments.length,$i__5750__auto___45896$$=0;;)if($i__5750__auto___45896$$<$len__5749__auto___45895$$)$args__5755__auto__$jscomp$147$$.push(arguments[$i__5750__auto___45896$$]),$i__5750__auto___45896$$+=1;else break;return $APP.$app$common$types$fills$create$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$147$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$147$$.slice(0),
0,null):null)};$APP.$app$common$types$fills$create$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($elements$jscomp$6_fills$jscomp$7$$){$elements$jscomp$6_fills$jscomp$7$$=$APP.$cljs$core$vec$$($elements$jscomp$6_fills$jscomp$7$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$flags$_STAR_current_STAR_$$,$APP.$cljs$cst$1755$frontend_binary_fills$$)?$APP.$app$common$types$fills$impl$from_plain$$($elements$jscomp$6_fills$jscomp$7$$):$elements$jscomp$6_fills$jscomp$7$$};
$APP.$app$common$types$fills$fill__GT_color$$=function($fill$jscomp$8$$){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1746$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$8$$),$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1747$fill_opacity$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$8$$),$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$cst$1748$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$8$$),
$APP.$cljs$cst$1612$image$$,$APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$8$$),$APP.$cljs$cst$1735$ref_id$$,$APP.$cljs$cst$1745$fill_color_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$8$$),$APP.$cljs$cst$1736$ref_file$$,$APP.$cljs$cst$1640$fill_color_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$8$$)],null))};
$APP.$app$common$types$text$get_default_text_attrs$$=function(){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$types$text$default_text_attrs$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$contains_QMARK_$$($APP.$app$common$flags$_STAR_current_STAR_$$,$APP.$cljs$cst$1755$frontend_binary_fills$$)?$APP.$app$common$types$fills$impl$from_plain$$($app$common$types$text$default_text_fills$$):$app$common$types$text$default_text_fills$$)};
$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$01$$=function($root$jscomp$29$$){return $APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$identity$$,$root$jscomp$29$$)};
$APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$=function($match_QMARK_$$,$root$jscomp$30$$){return $APP.$cljs$core$seq$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($match_QMARK_$$,$APP.$cljs$core$tree_seq$$($APP.$cljs$core$map_QMARK_$$,$APP.$cljs$cst$342$children$$,$root$jscomp$30$$)))};
$APP.$app$common$types$text$is_text_node_QMARK_$$=function($node$jscomp$229$$){return $APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$229$$)==null&&typeof $APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$229$$)==="string"};$APP.$app$common$types$text$is_paragraph_node_QMARK_$$=function($node$jscomp$231$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("paragraph",$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$231$$))};
$APP.$app$common$types$text$is_root_node_QMARK_$$=function($node$jscomp$232$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("root",$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$232$$))};$APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$02$$=function($transform$jscomp$26$$,$root$jscomp$31$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$identity$$,$transform$jscomp$26$$,$root$jscomp$31$$)};
$APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$=function($pred$jscomp$81$$,$transform$jscomp$27$$,$root$jscomp$32$$){return $APP.$clojure$walk$postwalk$$(function($item$jscomp$39$$){var $JSCompiler_inline_result$jscomp$730_and__5023__auto__$jscomp$inline_4797$$=($JSCompiler_inline_result$jscomp$730_and__5023__auto__$jscomp$inline_4797$$=$APP.$app$common$types$text$is_text_node_QMARK_$$($item$jscomp$39$$)||$APP.$app$common$types$text$is_paragraph_node_QMARK_$$($item$jscomp$39$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("paragraph-set",$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$39$$))||$APP.$app$common$types$text$is_root_node_QMARK_$$($item$jscomp$39$$))?$pred$jscomp$81$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$81$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$39$$):$pred$jscomp$81$$($item$jscomp$39$$):$JSCompiler_inline_result$jscomp$730_and__5023__auto__$jscomp$inline_4797$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$730_and__5023__auto__$jscomp$inline_4797$$)?
$transform$jscomp$27$$.$cljs$core$IFn$_invoke$arity$1$?$transform$jscomp$27$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$39$$):$transform$jscomp$27$$($item$jscomp$39$$):$item$jscomp$39$$},$root$jscomp$32$$)};
$app$common$types$text$update_text_content$$=function($shape$jscomp$69$$,$pred_fn$$,$update_fn$jscomp$4$$,$attrs$jscomp$3$$){function $update_attrs_fn$$($p1__45968_SHARP_$$){return $update_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$update_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($p1__45968_SHARP_$$,$attrs$jscomp$3$$):$update_fn$jscomp$4$$($p1__45968_SHARP_$$,$attrs$jscomp$3$$)}return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$69$$,$APP.$cljs$cst$1637$content$$,
function($p1__45969_SHARP_$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$($pred_fn$$,$update_attrs_fn$$,$p1__45969_SHARP_$$)})};
$APP.$app$common$types$text$generate_shape_name$$=function($text$jscomp$20$$){var $JSCompiler_temp_const$jscomp$731$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$,$y__5114__auto__$jscomp$inline_4799$$=$APP.$cljs$core$count$$($text$jscomp$20$$);return $JSCompiler_temp_const$jscomp$731$$.call($APP.$cljs$core$subs$$,$text$jscomp$20$$,0,280<$y__5114__auto__$jscomp$inline_4799$$?280:$y__5114__auto__$jscomp$inline_4799$$)};
$app$common$types$text$equal_attrs_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($item$jscomp$41$$,$attrs$jscomp$5$$,$and__5023__auto__$jscomp$228_ignore_QMARK_$$){var $item_attrs$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($item$jscomp$41$$,$APP.$cljs$cst$1588$text$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$342$children$$]));$and__5023__auto__$jscomp$228_ignore_QMARK_$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$228_ignore_QMARK_$$)?
$and__5023__auto__$jscomp$228_ignore_QMARK_$$:$APP.$cljs$core$empty_QMARK_$$($item_attrs$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$5$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($item$jscomp$41$$,$APP.$cljs$cst$1588$text$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$342$children$$])));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$228_ignore_QMARK_$$)?
$APP.$cljs$core$every_QMARK_$$(function($p1__45991_SHARP_$$){return $app$common$types$text$equal_attrs_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__45991_SHARP_$$,$attrs$jscomp$5$$,!1)},$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$41$$)):$and__5023__auto__$jscomp$228_ignore_QMARK_$$};
$app$common$types$text$get_first_paragraph_text_attrs$$=function($content$jscomp$16$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$16$$,$APP.$cljs$cst$342$children$$),0),$APP.$cljs$cst$342$children$$),0),$APP.$cljs$cst$1588$text$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$342$children$$]))};
$app$common$types$text$get_diff_type$$=function($a$jscomp$351$$,$b$jscomp$283$$){return $app$common$types$text$compare_text_content$$($a$jscomp$351$$,$b$jscomp$283$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$1771$text_cb$$,function($acc$jscomp$88$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$88$$,$cljs$cst$1774$text_content_text$$)},$cljs$cst$1772$attribute_cb$$,function($acc$jscomp$89$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$89$$,$cljs$cst$1775$text_content_attribute$$)}],
null))};
$app$common$types$text$get_diff_attrs$$=function($a$jscomp$352$$,$b$jscomp$284$$){var $diff_attrs$$=$app$common$types$text$compare_text_content$$($a$jscomp$352$$,$b$jscomp$284$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$1771$text_cb$$,$APP.$cljs$core$identity$$,$cljs$cst$1772$attribute_cb$$,function($acc$jscomp$90$$,$attr$jscomp$8$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$90$$,$attr$jscomp$8$$)}],null));if($APP.$cljs$core$contains_QMARK_$$($diff_attrs$$,$cljs$cst$1773$text_content_structure$$)){var $attrs$jscomp$6$$=
$app$common$types$text$get_first_paragraph_text_attrs$$($a$jscomp$352$$);return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$229$$=$app$common$types$text$equal_attrs_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$352$$,$attrs$jscomp$6$$,!0);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$229$$)?$app$common$types$text$equal_attrs_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$284$$,$attrs$jscomp$6$$,!0):$and__5023__auto__$jscomp$229$$}())?$APP.$cljs$core$PersistentHashSet$EMPTY$$:
$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($diff_attrs$$,$cljs$cst$1773$text_content_structure$$)}return $diff_attrs$$};
$APP.$app$common$types$text$content__GT_text$$=function($content$jscomp$20$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__46052_SHARP_$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("",$p1__46052_SHARP_$$)},$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$91$$,$node$jscomp$236$$){if($APP.$app$common$types$text$is_paragraph_node_QMARK_$$($node$jscomp$236$$))return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$91$$,
$APP.$cljs$core$PersistentVector$EMPTY$$);if($APP.$app$common$types$text$is_text_node_QMARK_$$($node$jscomp$236$$)){var $i$jscomp$483$$=$APP.$cljs$core$count$$($acc$jscomp$91$$)-1;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($acc$jscomp$91$$,$i$jscomp$483$$,$APP.$cljs$core$conj$$,$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$236$$))}return $acc$jscomp$91$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$01$$($content$jscomp$20$$))))};
$APP.$app$common$types$text$content__GT_text_PLUS_styles$$=function($node$jscomp$237$$){return $APP.$cljs$core$reverse$$(function $app$common$types$text$content__GT_text_PLUS_styles_$_rec_style_text_map$$($acc$jscomp$92$$,$node__$1$jscomp$65$$,$head_style_style$jscomp$12$$){var $node_style$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$head_style_style$jscomp$12$$,$APP.$cljs$core$select_keys$$($node__$1$jscomp$65$$,
$APP.$app$common$types$text$text_all_attrs$$)])),$head_text_vec__46061$$=function(){var $or__5025__auto__$jscomp$328$$=$APP.$cljs$core$first$$($acc$jscomp$92$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$328$$)?$or__5025__auto__$jscomp$328$$:new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentArrayMap$EMPTY$$,""],null)}();$head_style_style$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($head_text_vec__46061$$,
0,null);$head_text_vec__46061$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($head_text_vec__46061$$,1,null);var $new_acc$$=$APP.$app$common$types$text$is_text_node_QMARK_$$($node__$1$jscomp$65$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($head_style_style$jscomp$12$$,$node_style$$)?$APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$node_style$$,$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$2$($node__$1$jscomp$65$$,
"")],null),$acc$jscomp$92$$):$APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$node_style$$,""+($head_text_vec__46061$$??"")+($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($node__$1$jscomp$65$$)??"")],null),$APP.$cljs$core$rest$$($acc$jscomp$92$$)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__46053_SHARP_$$,$p2__46054_SHARP_$$){return $app$common$types$text$content__GT_text_PLUS_styles_$_rec_style_text_map$$($p1__46053_SHARP_$$,
$p2__46054_SHARP_$$,$node_style$$)},$acc$jscomp$92$$,$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($node__$1$jscomp$65$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($node__$1$jscomp$65$$),"paragraph")?function(){var $ht$jscomp$3_vec__46064$$=$APP.$cljs$core$first$$($new_acc$$),$hs$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ht$jscomp$3_vec__46064$$,0,null);$ht$jscomp$3_vec__46064$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ht$jscomp$3_vec__46064$$,1,null);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hs$jscomp$1$$,""+($ht$jscomp$3_vec__46064$$??"")+"\n"],null),$APP.$cljs$core$rest$$($new_acc$$))}():$new_acc$$}($APP.$cljs$core$PersistentVector$EMPTY$$,$node$jscomp$237$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$))};
$app$common$types$modifiers$Modifiers$$=function($last_order$$,$geometry_parent$$,$geometry_child$$,$structure_parent$$,$structure_child$$,$__meta$jscomp$16$$,$__extmap$jscomp$16$$,$__hash$jscomp$73$$){this.$last_order$=$last_order$$;this.$geometry_parent$=$geometry_parent$$;this.$geometry_child$=$geometry_child$$;this.$structure_parent$=$structure_parent$$;this.$structure_child$=$structure_child$$;this.$__meta$=$__meta$jscomp$16$$;this.$__extmap$=$__extmap$jscomp$16$$;this.$__hash$=$__hash$jscomp$73$$;
this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$APP.$app$common$types$modifiers$GeometricOperation$$=function($order$jscomp$1$$,$type$jscomp$318$$,$vector$jscomp$1$$,$origin$jscomp$3$$,$transform$jscomp$29$$,$transform_inverse$$,$rotation$jscomp$3$$,$center$jscomp$9$$,$__meta$jscomp$17$$,$__extmap$jscomp$17$$,$__hash$jscomp$74$$){this.order=$order$jscomp$1$$;this.type=$type$jscomp$318$$;this.$vector$=$vector$jscomp$1$$;this.origin=$origin$jscomp$3$$;this.transform=$transform$jscomp$29$$;this.$transform_inverse$=$transform_inverse$$;this.rotation=
$rotation$jscomp$3$$;this.$center$=$center$jscomp$9$$;this.$__meta$=$__meta$jscomp$17$$;this.$__extmap$=$__extmap$jscomp$17$$;this.$__hash$=$__hash$jscomp$74$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$APP.$app$common$types$modifiers$StructureOperation$$=function($type$jscomp$320$$,$property$jscomp$26$$,$value$jscomp$404$$,$index$jscomp$170$$,$__meta$jscomp$18$$,$__extmap$jscomp$18$$,$__hash$jscomp$75$$){this.type=$type$jscomp$320$$;this.property=$property$jscomp$26$$;this.value=$value$jscomp$404$$;this.index=$index$jscomp$170$$;this.$__meta$=$__meta$jscomp$18$$;this.$__extmap$=$__extmap$jscomp$18$$;this.$__hash$=$__hash$jscomp$75$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=
139264};$APP.$app$common$types$modifiers$move_vec_QMARK_$$=function($vector$jscomp$6$$){return!$APP.$app$common$math$almost_zero_QMARK_$$($vector$jscomp$6$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($vector$jscomp$6$$,$APP.$cljs$cst$1510$x$$))||!$APP.$app$common$math$almost_zero_QMARK_$$($vector$jscomp$6$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($vector$jscomp$6$$,$APP.$cljs$cst$1511$y$$))};
$APP.$app$common$types$modifiers$resize_vec_QMARK_$$=function($vector$jscomp$7$$){return!$APP.$app$common$math$almost_zero_QMARK_$$(($vector$jscomp$7$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($vector$jscomp$7$$,$APP.$cljs$cst$1510$x$$))-1)||!$APP.$app$common$math$almost_zero_QMARK_$$(($vector$jscomp$7$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($vector$jscomp$7$$,$APP.$cljs$cst$1511$y$$))-1)};
$app$common$types$modifiers$safe_size_rect_QMARK_$$=function($h$jscomp$148_rect$jscomp$11$$){var $and__5023__auto__$jscomp$230_w$jscomp$27$$=$h$jscomp$148_rect$jscomp$11$$!=null;return $and__5023__auto__$jscomp$230_w$jscomp$27$$?($and__5023__auto__$jscomp$230_w$jscomp$27$$=$h$jscomp$148_rect$jscomp$11$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$148_rect$jscomp$11$$,$APP.$cljs$cst$290$width$$),$h$jscomp$148_rect$jscomp$11$$=$h$jscomp$148_rect$jscomp$11$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$148_rect$jscomp$11$$,
$APP.$cljs$cst$1522$height$$),$APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($and__5023__auto__$jscomp$230_w$jscomp$27$$,$h$jscomp$148_rect$jscomp$11$$)&&$and__5023__auto__$jscomp$230_w$jscomp$27$$>0&&$h$jscomp$148_rect$jscomp$11$$>0&&$and__5023__auto__$jscomp$230_w$jscomp$27$$<=2147483647&&$h$jscomp$148_rect$jscomp$11$$<=2147483647):$and__5023__auto__$jscomp$230_w$jscomp$27$$};
$app$common$types$modifiers$safe_size_rect$$=function($map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$){$map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$=$APP.$cljs$core$__destructure_map$$($map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$);var $selrect$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$,
$APP.$cljs$cst$1605$selrect$$),$points$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$,$APP.$cljs$cst$1604$points$$),$x$jscomp$1090$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$348$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$,
$APP.$cljs$cst$1511$y$$),$width$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$,$APP.$cljs$cst$290$width$$),$height$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$,$APP.$cljs$cst$1522$height$$);$map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$=
function(){var $and__5023__auto__$jscomp$231$$=$app$common$types$modifiers$safe_size_rect_QMARK_$$($selrect$jscomp$3$$);return $and__5023__auto__$jscomp$231$$?$selrect$jscomp$3$$:$and__5023__auto__$jscomp$231$$}();if($APP.$cljs$core$truth_$$($map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$))return $map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$;$map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$=
function(){var $from_points$$=$APP.$app$common$geom$rect$points__GT_rect$$($points$jscomp$8$$),$and__5023__auto__$jscomp$232$$=$app$common$types$modifiers$safe_size_rect_QMARK_$$($from_points$$);return $and__5023__auto__$jscomp$232$$?$from_points$$:$and__5023__auto__$jscomp$232$$}();if($APP.$cljs$core$truth_$$($map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$))return $map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$;
$map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$=function(){var $from_shape$$=$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($x$jscomp$1090$$,$y$jscomp$348$$,$width$jscomp$57$$,$height$jscomp$50$$),$and__5023__auto__$jscomp$233$$=$app$common$types$modifiers$safe_size_rect_QMARK_$$($from_shape$$);return $and__5023__auto__$jscomp$233$$?$from_shape$$:$and__5023__auto__$jscomp$233$$}();return $APP.$cljs$core$truth_$$($map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$)?
$map__48611__$1_or__5025__auto__$jscomp$329_or__5025__auto____$1$jscomp$41_or__5025__auto____$2$jscomp$10_p__48610$$:$app$common$geom$rect$empty_rect$$};
$APP.$app$common$types$modifiers$maybe_add_move$$=function($G__48624_operations$$,$op$jscomp$10_vector$jscomp$inline_4810_vector_op2$jscomp$inline_4809$$){if($APP.$cljs$core$empty_QMARK_$$($G__48624_operations$$))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$op$jscomp$10_vector$jscomp$inline_4810_vector_op2$jscomp$inline_4809$$],null);var $head$jscomp$9_item$jscomp$42$$=$APP.$cljs$core$peek$$($G__48624_operations$$),$type_op1$jscomp$inline_4803_vector_op1$jscomp$inline_4808$$=
$head$jscomp$9_item$jscomp$42$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($head$jscomp$9_item$jscomp$42$$,$APP.$cljs$cst$139$type$$),$type_op2$jscomp$inline_4804$$=$op$jscomp$10_vector$jscomp$inline_4810_vector_op2$jscomp$inline_4809$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($op$jscomp$10_vector$jscomp$inline_4810_vector_op2$jscomp$inline_4809$$,$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1798$move$$,
$type_op1$jscomp$inline_4803_vector_op1$jscomp$inline_4808$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1798$move$$,$type_op2$jscomp$inline_4804$$)?($type_op1$jscomp$inline_4803_vector_op1$jscomp$inline_4808$$=$head$jscomp$9_item$jscomp$42$$?.$vector$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($head$jscomp$9_item$jscomp$42$$,$APP.$cljs$cst$200$vector$$),$op$jscomp$10_vector$jscomp$inline_4810_vector_op2$jscomp$inline_4809$$=$op$jscomp$10_vector$jscomp$inline_4810_vector_op2$jscomp$inline_4809$$?.$vector$??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($op$jscomp$10_vector$jscomp$inline_4810_vector_op2$jscomp$inline_4809$$,$APP.$cljs$cst$200$vector$$),$op$jscomp$10_vector$jscomp$inline_4810_vector_op2$jscomp$inline_4809$$=$APP.$app$common$geom$point$add$$($type_op1$jscomp$inline_4803_vector_op1$jscomp$inline_4808$$,$op$jscomp$10_vector$jscomp$inline_4810_vector_op2$jscomp$inline_4809$$),$head$jscomp$9_item$jscomp$42$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($head$jscomp$9_item$jscomp$42$$,
$APP.$cljs$cst$200$vector$$,$op$jscomp$10_vector$jscomp$inline_4810_vector_op2$jscomp$inline_4809$$),$G__48624_operations$$=$APP.$cljs$core$pop$$($G__48624_operations$$),$APP.$app$common$types$modifiers$move_vec_QMARK_$$($head$jscomp$9_item$jscomp$42$$?.$vector$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($head$jscomp$9_item$jscomp$42$$,$APP.$cljs$cst$200$vector$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48624_operations$$,$head$jscomp$9_item$jscomp$42$$):$G__48624_operations$$):
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48624_operations$$,$op$jscomp$10_vector$jscomp$inline_4810_vector_op2$jscomp$inline_4809$$)};$APP.$app$common$types$modifiers$empty$$=function(){return new $app$common$types$modifiers$Modifiers$$(0,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$,null,null,null)};
$APP.$app$common$types$modifiers$move$cljs$0core$0IFn$0_invoke$0arity$02$$=function($modifiers$jscomp$5_order$jscomp$10$$,$vector$jscomp$14$$){var $G__48654_modifiers__$1$jscomp$3$$=$modifiers$jscomp$5_order$jscomp$10$$?$modifiers$jscomp$5_order$jscomp$10$$:$APP.$app$common$types$modifiers$empty$$();$modifiers$jscomp$5_order$jscomp$10$$=($G__48654_modifiers__$1$jscomp$3$$?.$last_order$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48654_modifiers__$1$jscomp$3$$,$APP.$cljs$cst$1776$last_order$$))+
1;$G__48654_modifiers__$1$jscomp$3$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48654_modifiers__$1$jscomp$3$$,$APP.$cljs$cst$1776$last_order$$,$modifiers$jscomp$5_order$jscomp$10$$);return $APP.$app$common$types$modifiers$move_vec_QMARK_$$($vector$jscomp$14$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48654_modifiers__$1$jscomp$3$$,$cljs$cst$1778$geometry_child$$,$APP.$app$common$types$modifiers$maybe_add_move$$,new $APP.$app$common$types$modifiers$GeometricOperation$$($modifiers$jscomp$5_order$jscomp$10$$,
$APP.$cljs$cst$1798$move$$,$vector$jscomp$14$$,null,null,null,null,null,null,null,null)):$G__48654_modifiers__$1$jscomp$3$$};
$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$03$$=function($vector$jscomp$15$$,$origin$jscomp$9$$){var $modifiers$jscomp$6_order$jscomp$11$$=$APP.$app$common$types$modifiers$empty$$(),$G__48661_modifiers__$1$jscomp$4$$=$modifiers$jscomp$6_order$jscomp$11$$?$modifiers$jscomp$6_order$jscomp$11$$:$APP.$app$common$types$modifiers$empty$$();$modifiers$jscomp$6_order$jscomp$11$$=($G__48661_modifiers__$1$jscomp$4$$?.$last_order$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48661_modifiers__$1$jscomp$4$$,
$APP.$cljs$cst$1776$last_order$$))+1;$G__48661_modifiers__$1$jscomp$4$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48661_modifiers__$1$jscomp$4$$,$APP.$cljs$cst$1776$last_order$$,$modifiers$jscomp$6_order$jscomp$11$$);return $APP.$app$common$types$modifiers$resize_vec_QMARK_$$($vector$jscomp$15$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48661_modifiers__$1$jscomp$4$$,$cljs$cst$1778$geometry_child$$,$APP.$app$common$types$modifiers$maybe_add_resize$$,new $APP.$app$common$types$modifiers$GeometricOperation$$($modifiers$jscomp$6_order$jscomp$11$$,
$APP.$cljs$cst$1799$resize$$,$vector$jscomp$15$$,$origin$jscomp$9$$,null,null,null,null,null,null,null)):$G__48661_modifiers__$1$jscomp$4$$};
$APP.$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$05$$=function($modifiers$jscomp$7$$,$vector$jscomp$16$$,$origin$jscomp$10$$,$transform$jscomp$33$$,$transform_inverse$jscomp$4$$){return $app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$06$$($modifiers$jscomp$7$$,$vector$jscomp$16$$,$origin$jscomp$10$$,$transform$jscomp$33$$,$transform_inverse$jscomp$4$$,null)};
$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$06$$=function($modifiers$jscomp$8_order$jscomp$12$$,$vector$jscomp$17$$,$origin$jscomp$11$$,$transform$jscomp$34$$,$transform_inverse$jscomp$5$$,$map__48664__$1_p__48663_precise_QMARK_$jscomp$1$$){$map__48664__$1_p__48663_precise_QMARK_$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($map__48664__$1_p__48663_precise_QMARK_$jscomp$1$$);$map__48664__$1_p__48663_precise_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48664__$1_p__48663_precise_QMARK_$jscomp$1$$,
$cljs$cst$1805$precise_QMARK_$$);var $G__48666_modifiers__$1$jscomp$5$$=$APP.$cljs$core$truth_$$($modifiers$jscomp$8_order$jscomp$12$$)?$modifiers$jscomp$8_order$jscomp$12$$:$APP.$app$common$types$modifiers$empty$$();$modifiers$jscomp$8_order$jscomp$12$$=($G__48666_modifiers__$1$jscomp$5$$?.$last_order$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48666_modifiers__$1$jscomp$5$$,$APP.$cljs$cst$1776$last_order$$))+1;$G__48666_modifiers__$1$jscomp$5$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48666_modifiers__$1$jscomp$5$$,
$APP.$cljs$cst$1776$last_order$$,$modifiers$jscomp$8_order$jscomp$12$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__48664__$1_p__48663_precise_QMARK_$jscomp$1$$)?$map__48664__$1_p__48663_precise_QMARK_$jscomp$1$$:$APP.$app$common$types$modifiers$resize_vec_QMARK_$$($vector$jscomp$17$$))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48666_modifiers__$1$jscomp$5$$,$cljs$cst$1778$geometry_child$$,$APP.$app$common$types$modifiers$maybe_add_resize$$,new $APP.$app$common$types$modifiers$GeometricOperation$$($modifiers$jscomp$8_order$jscomp$12$$,
$APP.$cljs$cst$1799$resize$$,$vector$jscomp$17$$,$origin$jscomp$11$$,$transform$jscomp$34$$,$transform_inverse$jscomp$5$$,null,null,null,null,null)):$G__48666_modifiers__$1$jscomp$5$$};
$app$common$types$modifiers$remove_children$$=function($G__48668_modifiers$jscomp$10$$,$shapes$jscomp$9$$){$G__48668_modifiers$jscomp$10$$=$APP.$cljs$core$truth_$$($G__48668_modifiers$jscomp$10$$)?$G__48668_modifiers$jscomp$10$$:$APP.$app$common$types$modifiers$empty$$();return $APP.$app$common$data$not_empty_QMARK_$$($shapes$jscomp$9$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48668_modifiers$jscomp$10$$,$cljs$cst$1779$structure_parent$$,$APP.$cljs$core$conj$$,new $APP.$app$common$types$modifiers$StructureOperation$$($cljs$cst$1800$remove_children$$,
null,$shapes$jscomp$9$$,null,null,null,null)):$G__48668_modifiers$jscomp$10$$};
$app$common$types$modifiers$add_children$$=function($G__48669_modifiers$jscomp$11$$,$shapes$jscomp$10$$,$index$jscomp$173$$){$G__48669_modifiers$jscomp$11$$=$APP.$cljs$core$truth_$$($G__48669_modifiers$jscomp$11$$)?$G__48669_modifiers$jscomp$11$$:$APP.$app$common$types$modifiers$empty$$();return $APP.$app$common$data$not_empty_QMARK_$$($shapes$jscomp$10$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48669_modifiers$jscomp$11$$,$cljs$cst$1779$structure_parent$$,$APP.$cljs$core$conj$$,
new $APP.$app$common$types$modifiers$StructureOperation$$($cljs$cst$1801$add_children$$,null,$shapes$jscomp$10$$,$index$jscomp$173$$,null,null,null)):$G__48669_modifiers$jscomp$11$$};
$APP.$app$common$types$modifiers$reflow$$=function(){var $modifiers$jscomp$12$$=$APP.$app$common$types$modifiers$empty$$();return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$truth_$$($modifiers$jscomp$12$$)?$modifiers$jscomp$12$$:$APP.$app$common$types$modifiers$empty$$(),$cljs$cst$1779$structure_parent$$,$APP.$cljs$core$conj$$,new $APP.$app$common$types$modifiers$StructureOperation$$($cljs$cst$1802$reflow$$,null,null,null,null,null,null))};
$APP.$app$common$types$modifiers$change_property$$=function($modifiers$jscomp$14$$,$property$jscomp$29$$,$value$jscomp$409$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$truth_$$($modifiers$jscomp$14$$)?$modifiers$jscomp$14$$:$APP.$app$common$types$modifiers$empty$$(),$cljs$cst$1779$structure_parent$$,$APP.$cljs$core$conj$$,new $APP.$app$common$types$modifiers$StructureOperation$$($cljs$cst$1804$change_property$$,$property$jscomp$29$$,$value$jscomp$409$$,null,null,
null,null))};
$app$common$types$modifiers$concat_geometry$$=function($G__48816_operations$jscomp$3_result$jscomp$172$$,$G__48817_operations__$1_other$jscomp$177$$,$merge_QMARK_$$){if($APP.$cljs$core$empty_QMARK_$$($G__48816_operations$jscomp$3_result$jscomp$172$$))return $G__48817_operations__$1_other$jscomp$177$$;if($APP.$cljs$core$empty_QMARK_$$($G__48817_operations__$1_other$jscomp$177$$))return $G__48816_operations$jscomp$3_result$jscomp$172$$;for($G__48817_operations__$1_other$jscomp$177$$=$APP.$cljs$core$seq$$($G__48817_operations__$1_other$jscomp$177$$);;){if($APP.$cljs$core$empty_QMARK_$$($G__48817_operations__$1_other$jscomp$177$$))return $G__48816_operations$jscomp$3_result$jscomp$172$$;var $current$jscomp$20$$=
$APP.$cljs$core$first$$($G__48817_operations__$1_other$jscomp$177$$);$G__48816_operations$jscomp$3_result$jscomp$172$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($merge_QMARK_$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1798$move$$,$current$jscomp$20$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$20$$,$APP.$cljs$cst$139$type$$)):$merge_QMARK_$$)?$APP.$app$common$types$modifiers$maybe_add_move$$($G__48816_operations$jscomp$3_result$jscomp$172$$,
$current$jscomp$20$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($merge_QMARK_$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1799$resize$$,$current$jscomp$20$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$20$$,$APP.$cljs$cst$139$type$$)):$merge_QMARK_$$)?$APP.$app$common$types$modifiers$maybe_add_resize$$.$cljs$core$IFn$_invoke$arity$2$($G__48816_operations$jscomp$3_result$jscomp$172$$,$current$jscomp$20$$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48816_operations$jscomp$3_result$jscomp$172$$,
$current$jscomp$20$$);$G__48817_operations__$1_other$jscomp$177$$=$APP.$cljs$core$rest$$($G__48817_operations__$1_other$jscomp$177$$)}};$app$common$types$modifiers$increase_order$$=function($operations$jscomp$4$$,$last_order$jscomp$2$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48674_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__48674_SHARP_$$,$cljs$cst$365$order$$,$APP.$cljs$core$_PLUS_$$,$last_order$jscomp$2$$)},$operations$jscomp$4$$)};
$app$common$types$modifiers$add_modifiers$$=function($modifiers$jscomp$15_modifiers__$1$jscomp$7$$,$last_order$jscomp$3_new_modifiers$$){$modifiers$jscomp$15_modifiers__$1$jscomp$7$$=$APP.$cljs$core$truth_$$($modifiers$jscomp$15_modifiers__$1$jscomp$7$$)?$modifiers$jscomp$15_modifiers__$1$jscomp$7$$:$APP.$app$common$types$modifiers$empty$$();var $new_modifiers__$1$$=$APP.$cljs$core$truth_$$($last_order$jscomp$3_new_modifiers$$)?$last_order$jscomp$3_new_modifiers$$:$APP.$app$common$types$modifiers$empty$$();
$last_order$jscomp$3_new_modifiers$$=$modifiers$jscomp$15_modifiers__$1$jscomp$7$$?.$last_order$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$15_modifiers__$1$jscomp$7$$,$APP.$cljs$cst$1776$last_order$$);var $new_last_order$$=$new_modifiers__$1$$?.$last_order$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_modifiers__$1$$,$APP.$cljs$cst$1776$last_order$$),$old_geom_child$$=$modifiers$jscomp$15_modifiers__$1$jscomp$7$$?.$geometry_child$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$15_modifiers__$1$jscomp$7$$,
$cljs$cst$1778$geometry_child$$),$new_geom_child$$=$app$common$types$modifiers$increase_order$$($new_modifiers__$1$$?.$geometry_child$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_modifiers__$1$$,$cljs$cst$1778$geometry_child$$),$last_order$jscomp$3_new_modifiers$$),$old_geom_parent$$=$modifiers$jscomp$15_modifiers__$1$jscomp$7$$?.$geometry_parent$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$15_modifiers__$1$jscomp$7$$,$APP.$cljs$cst$1777$geometry_parent$$),
$new_geom_parent$$=$app$common$types$modifiers$increase_order$$($new_modifiers__$1$$?.$geometry_parent$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_modifiers__$1$$,$APP.$cljs$cst$1777$geometry_parent$$),$last_order$jscomp$3_new_modifiers$$),$merge_child_QMARK_$$=$APP.$cljs$core$empty_QMARK_$$($new_geom_parent$$)&&$APP.$cljs$core$empty_QMARK_$$($old_geom_parent$$),$merge_parent_QMARK_$$=$APP.$cljs$core$empty_QMARK_$$($new_geom_child$$)&&$APP.$cljs$core$empty_QMARK_$$($old_geom_child$$);
return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($modifiers$jscomp$15_modifiers__$1$jscomp$7$$,$APP.$cljs$cst$1776$last_order$$,$last_order$jscomp$3_new_modifiers$$+$new_last_order$$),$cljs$cst$1778$geometry_child$$,function($p1__48675_SHARP_$$){return $app$common$types$modifiers$concat_geometry$$($p1__48675_SHARP_$$,
$new_geom_child$$,$merge_child_QMARK_$$)}),$APP.$cljs$cst$1777$geometry_parent$$,function($p1__48676_SHARP_$$){return $app$common$types$modifiers$concat_geometry$$($p1__48676_SHARP_$$,$new_geom_parent$$,$merge_parent_QMARK_$$)}),$cljs$cst$1779$structure_parent$$,function($p1__48677_SHARP_$$){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__48677_SHARP_$$,$new_modifiers__$1$$?.$structure_parent$??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_modifiers__$1$$,$cljs$cst$1779$structure_parent$$)]))}),$APP.$cljs$cst$1780$structure_child$$,function($p1__48678_SHARP_$$){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__48678_SHARP_$$,$new_modifiers__$1$$?.$structure_child$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_modifiers__$1$$,
$APP.$cljs$cst$1780$structure_child$$)]))})};$APP.$app$common$types$modifiers$move_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$=function($vector$jscomp$18$$){return $APP.$app$common$types$modifiers$move$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$modifiers$empty$$(),$vector$jscomp$18$$)};
$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$=function($vector$jscomp$19$$,$origin$jscomp$12$$){return $app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$03$$($vector$jscomp$19$$,$origin$jscomp$12$$)};
$APP.$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$=function($vector$jscomp$20$$,$origin$jscomp$13$$,$transform$jscomp$35$$,$transform_inverse$jscomp$6$$){return $APP.$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$app$common$types$modifiers$empty$$(),$vector$jscomp$20$$,$origin$jscomp$13$$,$transform$jscomp$35$$,$transform_inverse$jscomp$6$$)};
$APP.$app$common$types$modifiers$rotation_modifiers$$=function($shape$jscomp$70_shape_center$$,$JSCompiler_inline_result$jscomp$702_JSCompiler_inline_result$jscomp$703_center$jscomp$13_modifiers$jscomp$inline_11878_order$jscomp$inline_11880$$,$JSCompiler_inline_result$jscomp$10757_angle$jscomp$21$$){$shape$jscomp$70_shape_center$$=$APP.$app$common$geom$shapes$common$shape__GT_center$$($shape$jscomp$70_shape_center$$);var $JSCompiler_temp_const$jscomp$701_move_vec$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,
0),$G__48667$jscomp$inline_11881_m$jscomp$inline_4812_modifiers__$1$jscomp$inline_11879$$=$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$();$JSCompiler_inline_result$jscomp$702_JSCompiler_inline_result$jscomp$703_center$jscomp$13_modifiers$jscomp$inline_11878_order$jscomp$inline_11880$$=$APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($G__48667$jscomp$inline_11881_m$jscomp$inline_4812_modifiers__$1$jscomp$inline_11879$$,$APP.$app$common$geom$matrix$rotate_matrix$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10757_angle$jscomp$21$$,
$JSCompiler_inline_result$jscomp$702_JSCompiler_inline_result$jscomp$703_center$jscomp$13_modifiers$jscomp$inline_11878_order$jscomp$inline_11880$$));$JSCompiler_inline_result$jscomp$702_JSCompiler_inline_result$jscomp$703_center$jscomp$13_modifiers$jscomp$inline_11878_order$jscomp$inline_11880$$=$APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$702_JSCompiler_inline_result$jscomp$703_center$jscomp$13_modifiers$jscomp$inline_11878_order$jscomp$inline_11880$$,
$APP.$app$common$geom$matrix$rotate_matrix$$.$cljs$core$IFn$_invoke$arity$2$(-$JSCompiler_inline_result$jscomp$10757_angle$jscomp$21$$,$shape$jscomp$70_shape_center$$));$JSCompiler_temp_const$jscomp$701_move_vec$$=$APP.$app$common$geom$point$transform$$($JSCompiler_temp_const$jscomp$701_move_vec$$,$JSCompiler_inline_result$jscomp$702_JSCompiler_inline_result$jscomp$703_center$jscomp$13_modifiers$jscomp$inline_11878_order$jscomp$inline_11880$$);$JSCompiler_inline_result$jscomp$702_JSCompiler_inline_result$jscomp$703_center$jscomp$13_modifiers$jscomp$inline_11878_order$jscomp$inline_11880$$=
$APP.$app$common$types$modifiers$empty$$();$G__48667$jscomp$inline_11881_m$jscomp$inline_4812_modifiers__$1$jscomp$inline_11879$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$702_JSCompiler_inline_result$jscomp$703_center$jscomp$13_modifiers$jscomp$inline_11878_order$jscomp$inline_11880$$)?$JSCompiler_inline_result$jscomp$702_JSCompiler_inline_result$jscomp$703_center$jscomp$13_modifiers$jscomp$inline_11878_order$jscomp$inline_11880$$:$APP.$app$common$types$modifiers$empty$$();$JSCompiler_inline_result$jscomp$702_JSCompiler_inline_result$jscomp$703_center$jscomp$13_modifiers$jscomp$inline_11878_order$jscomp$inline_11880$$=
($G__48667$jscomp$inline_11881_m$jscomp$inline_4812_modifiers__$1$jscomp$inline_11879$$?.$last_order$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48667$jscomp$inline_11881_m$jscomp$inline_4812_modifiers__$1$jscomp$inline_11879$$,$APP.$cljs$cst$1776$last_order$$))+1;$G__48667$jscomp$inline_11881_m$jscomp$inline_4812_modifiers__$1$jscomp$inline_11879$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48667$jscomp$inline_11881_m$jscomp$inline_4812_modifiers__$1$jscomp$inline_11879$$,
$APP.$cljs$cst$1776$last_order$$,$JSCompiler_inline_result$jscomp$702_JSCompiler_inline_result$jscomp$703_center$jscomp$13_modifiers$jscomp$inline_11878_order$jscomp$inline_11880$$);$JSCompiler_inline_result$jscomp$10757_angle$jscomp$21$$=$APP.$cljs$core$not$$($APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$10757_angle$jscomp$21$$,0))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48667$jscomp$inline_11881_m$jscomp$inline_4812_modifiers__$1$jscomp$inline_11879$$,
$APP.$cljs$cst$1780$structure_child$$,$APP.$cljs$core$conj$$,new $APP.$app$common$types$modifiers$StructureOperation$$($APP.$cljs$cst$1788$rotation$$,null,$JSCompiler_inline_result$jscomp$10757_angle$jscomp$21$$,null,null,null,null)),$cljs$cst$1778$geometry_child$$,$APP.$cljs$core$conj$$,new $APP.$app$common$types$modifiers$GeometricOperation$$($JSCompiler_inline_result$jscomp$702_JSCompiler_inline_result$jscomp$703_center$jscomp$13_modifiers$jscomp$inline_11878_order$jscomp$inline_11880$$,$APP.$cljs$cst$1788$rotation$$,
null,null,null,null,$JSCompiler_inline_result$jscomp$10757_angle$jscomp$21$$,$shape$jscomp$70_shape_center$$,null,null,null)):$G__48667$jscomp$inline_11881_m$jscomp$inline_4812_modifiers__$1$jscomp$inline_11879$$;return $APP.$app$common$types$modifiers$move$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$10757_angle$jscomp$21$$,$JSCompiler_temp_const$jscomp$701_move_vec$$)};
$APP.$app$common$types$modifiers$change_size$$=function($p__48686_transform$jscomp$36$$,$width$jscomp$58_width__$1$$,$height$jscomp$51_height__$1$$){var $map__48687__$1_map__48688_sr_width$$=$APP.$cljs$core$__destructure_map$$($p__48686_transform$jscomp$36$$),$origin$jscomp$14_points$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48687__$1_map__48688_sr_width$$,$APP.$cljs$cst$1604$points$$);$p__48686_transform$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48687__$1_map__48688_sr_width$$,
$APP.$cljs$cst$1289$transform$$);var $transform_inverse$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48687__$1_map__48688_sr_width$$,$APP.$cljs$cst$1787$transform_inverse$$);$map__48687__$1_map__48688_sr_width$$=$app$common$types$modifiers$safe_size_rect$$($map__48687__$1_map__48688_sr_width$$);var $map__48688__$1_sr_height$$=$APP.$cljs$core$__destructure_map$$($map__48687__$1_map__48688_sr_width$$);$map__48687__$1_map__48688_sr_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48688__$1_sr_height$$,
$APP.$cljs$cst$290$width$$);$map__48688__$1_sr_height$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48688__$1_sr_height$$,$APP.$cljs$cst$1522$height$$);$width$jscomp$58_width__$1$$=$APP.$cljs$core$truth_$$($width$jscomp$58_width__$1$$)?$width$jscomp$58_width__$1$$:$map__48687__$1_map__48688_sr_width$$;$height$jscomp$51_height__$1$$=$APP.$cljs$core$truth_$$($height$jscomp$51_height__$1$$)?$height$jscomp$51_height__$1$$:$map__48688__$1_sr_height$$;$origin$jscomp$14_points$jscomp$9$$=
$APP.$cljs$core$first$$($origin$jscomp$14_points$jscomp$9$$);return $APP.$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($width$jscomp$58_width__$1$$/$map__48687__$1_map__48688_sr_width$$,$height$jscomp$51_height__$1$$/$map__48688__$1_sr_height$$),$origin$jscomp$14_points$jscomp$9$$,$p__48686_transform$jscomp$36$$,$transform_inverse$jscomp$7$$)};
$APP.$app$common$types$modifiers$change_dimensions_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$=function($shape$jscomp$73$$,$attr$jscomp$10_height$jscomp$52$$,$origin$jscomp$15_value$jscomp$411_value__$1$jscomp$4$$,$map__48695__$1_p__48694_proportion$$){$map__48695__$1_p__48694_proportion$$=$APP.$cljs$core$__destructure_map$$($map__48695__$1_p__48694_proportion$$);var $and__5023__auto__$jscomp$inline_4820_ignore_lock_QMARK__width$jscomp$59$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__48695__$1_p__48694_proportion$$,
$APP.$cljs$cst$1806$ignore_lock_QMARK_$$,!1);$origin$jscomp$15_value$jscomp$411_value__$1$jscomp$4$$=$APP.$app$common$math$abs$$($origin$jscomp$15_value$jscomp$411_value__$1$jscomp$4$$)<.01?.01:$origin$jscomp$15_value$jscomp$411_value__$1$jscomp$4$$;var $map__48697__$1_map__48698_sr_width$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$73$$);$map__48695__$1_p__48694_proportion$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48697__$1_map__48698_sr_width$jscomp$1$$,$APP.$cljs$cst$1807$proportion$$);
var $locked_QMARK__proportion_lock$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48697__$1_map__48698_sr_width$jscomp$1$$,$APP.$cljs$cst$1808$proportion_lock$$);$map__48697__$1_map__48698_sr_width$jscomp$1$$=$app$common$types$modifiers$safe_size_rect$$($shape$jscomp$73$$);var $map__48698__$1_sr_height$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($map__48697__$1_map__48698_sr_width$jscomp$1$$);$map__48697__$1_map__48698_sr_width$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48698__$1_sr_height$jscomp$1$$,
$APP.$cljs$cst$290$width$$);$map__48698__$1_sr_height$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48698__$1_sr_height$jscomp$1$$,$APP.$cljs$cst$1522$height$$);$locked_QMARK__proportion_lock$$=($and__5023__auto__$jscomp$inline_4820_ignore_lock_QMARK__width$jscomp$59$$=$APP.$cljs$core$not$$($and__5023__auto__$jscomp$inline_4820_ignore_lock_QMARK__width$jscomp$59$$))?$locked_QMARK__proportion_lock$$:$and__5023__auto__$jscomp$inline_4820_ignore_lock_QMARK__width$jscomp$59$$;
$and__5023__auto__$jscomp$inline_4820_ignore_lock_QMARK__width$jscomp$59$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$10_height$jscomp$52$$,$APP.$cljs$cst$290$width$$)?$origin$jscomp$15_value$jscomp$411_value__$1$jscomp$4$$:$APP.$cljs$core$truth_$$($locked_QMARK__proportion_lock$$)?$origin$jscomp$15_value$jscomp$411_value__$1$jscomp$4$$*$map__48695__$1_p__48694_proportion$$:$map__48697__$1_map__48698_sr_width$jscomp$1$$;$attr$jscomp$10_height$jscomp$52$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$10_height$jscomp$52$$,
$APP.$cljs$cst$1522$height$$)?$origin$jscomp$15_value$jscomp$411_value__$1$jscomp$4$$:$APP.$cljs$core$truth_$$($locked_QMARK__proportion_lock$$)?$origin$jscomp$15_value$jscomp$411_value__$1$jscomp$4$$/$map__48695__$1_p__48694_proportion$$:$map__48698__$1_sr_height$jscomp$1$$;$origin$jscomp$15_value$jscomp$411_value__$1$jscomp$4$$=$APP.$cljs$core$first$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$73$$));return $APP.$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$inline_4820_ignore_lock_QMARK__width$jscomp$59$$/
$map__48697__$1_map__48698_sr_width$jscomp$1$$,$attr$jscomp$10_height$jscomp$52$$/$map__48698__$1_sr_height$jscomp$1$$),$origin$jscomp$15_value$jscomp$411_value__$1$jscomp$4$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$73$$),$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$73$$))};
$app$common$types$modifiers$empty_QMARK_$$=function($modifiers$jscomp$16$$){return $APP.$cljs$core$empty_QMARK_$$($modifiers$jscomp$16$$?.$geometry_child$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$16$$,$cljs$cst$1778$geometry_child$$))&&$APP.$cljs$core$empty_QMARK_$$($modifiers$jscomp$16$$?.$geometry_parent$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$16$$,$APP.$cljs$cst$1777$geometry_parent$$))&&$APP.$cljs$core$empty_QMARK_$$($modifiers$jscomp$16$$?.$structure_parent$??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$16$$,$cljs$cst$1779$structure_parent$$))&&$APP.$cljs$core$empty_QMARK_$$($modifiers$jscomp$16$$?.$structure_child$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$16$$,$APP.$cljs$cst$1780$structure_child$$))};
$app$common$types$modifiers$child_modifiers_QMARK_$$=function($modifiers$jscomp$17$$){return $APP.$app$common$data$not_empty_QMARK_$$($modifiers$jscomp$17$$?.$geometry_child$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$17$$,$cljs$cst$1778$geometry_child$$))||$APP.$app$common$data$not_empty_QMARK_$$($modifiers$jscomp$17$$?.$structure_child$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$17$$,$APP.$cljs$cst$1780$structure_child$$))};
$app$common$types$modifiers$has_geometry_QMARK_$$=function($modifiers$jscomp$18$$){return $APP.$app$common$data$not_empty_QMARK_$$($modifiers$jscomp$18$$?.$geometry_parent$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$18$$,$APP.$cljs$cst$1777$geometry_parent$$))||$APP.$app$common$data$not_empty_QMARK_$$($modifiers$jscomp$18$$?.$geometry_child$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$18$$,$cljs$cst$1778$geometry_child$$))};
$app$common$types$modifiers$has_structure_QMARK_$$=function($p__48705_structure_parent$jscomp$2$$){var $map__48706__$1_structure_child$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($p__48705_structure_parent$jscomp$2$$);$p__48705_structure_parent$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48706__$1_structure_child$jscomp$2$$,$cljs$cst$1779$structure_parent$$);$map__48706__$1_structure_child$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48706__$1_structure_child$jscomp$2$$,
$APP.$cljs$cst$1780$structure_child$$);return $APP.$app$common$data$not_empty_QMARK_$$($p__48705_structure_parent$jscomp$2$$)||$APP.$app$common$data$not_empty_QMARK_$$($map__48706__$1_structure_child$jscomp$2$$)};
$app$common$types$modifiers$only_move_QMARK_$$=function($modifiers$jscomp$20$$){function $move_op_QMARK_$$($p1__48708_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1798$move$$,$p1__48708_SHARP_$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__48708_SHARP_$$,$APP.$cljs$cst$139$type$$))}return!$app$common$types$modifiers$has_structure_QMARK_$$($modifiers$jscomp$20$$)&&$APP.$cljs$core$every_QMARK_$$($move_op_QMARK_$$,$modifiers$jscomp$20$$?.$geometry_child$??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$20$$,$cljs$cst$1778$geometry_child$$))&&$APP.$cljs$core$every_QMARK_$$($move_op_QMARK_$$,$modifiers$jscomp$20$$?.$geometry_parent$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$20$$,$APP.$cljs$cst$1777$geometry_parent$$))};
$app$common$types$modifiers$select_child$$=function($modifiers$jscomp$21$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$truth_$$($modifiers$jscomp$21$$)?$modifiers$jscomp$21$$:$APP.$app$common$types$modifiers$empty$$(),$APP.$cljs$cst$1777$geometry_parent$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$1779$structure_parent$$,$APP.$cljs$core$PersistentVector$EMPTY$$]))};
$app$common$types$modifiers$select_structure$$=function($modifiers$jscomp$23$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$truth_$$($modifiers$jscomp$23$$)?$modifiers$jscomp$23$$:$APP.$app$common$types$modifiers$empty$$(),$cljs$cst$1778$geometry_child$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1777$geometry_parent$$,$APP.$cljs$core$PersistentVector$EMPTY$$]))};
$app$common$types$modifiers$select_geometry$$=function($modifiers$jscomp$24$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$truth_$$($modifiers$jscomp$24$$)?$modifiers$jscomp$24$$:$APP.$app$common$types$modifiers$empty$$(),$APP.$cljs$cst$1780$structure_child$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$1779$structure_parent$$,$APP.$cljs$core$PersistentVector$EMPTY$$]))};
$app$common$types$modifiers$added_children_frames$$=function($modif_tree_structure_changes$$){$modif_tree_structure_changes$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p__48710_val$jscomp$157$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48710_val$jscomp$157$$,0,null);$p__48710_val$jscomp$157$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48710_val$jscomp$157$$,
1,null);return $cljs$cst$1779$structure_parent$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($p__48710_val$jscomp$157$$))!=null}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p__48715_val$jscomp$158$$){var $key$jscomp$309$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48715_val$jscomp$158$$,0,null);$p__48715_val$jscomp$158$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48715_val$jscomp$158$$,1,null);
return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$key$jscomp$309$$,$cljs$cst$1779$structure_parent$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($p__48715_val$jscomp$158$$))],null)})),$modif_tree_structure_changes$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($changes$jscomp$2_p__48720$$){var $frame_id$jscomp$10$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$2_p__48720$$,0,null);$changes$jscomp$2_p__48720$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$2_p__48720$$,1,null);return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($map__48726__$1_p__48725_value$jscomp$412$$){$map__48726__$1_p__48725_value$jscomp$412$$=$APP.$cljs$core$__destructure_map$$($map__48726__$1_p__48725_value$jscomp$412$$);$map__48726__$1_p__48725_value$jscomp$412$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48726__$1_p__48725_value$jscomp$412$$,$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$152$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1606$frame$$,$frame_id$jscomp$10$$,$APP.$cljs$cst$1811$shape$$,$id$jscomp$152$$],null)},$map__48726__$1_p__48725_value$jscomp$412$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($map__48728__$1_p__48727_type$jscomp$322$$){$map__48728__$1_p__48727_type$jscomp$322$$=
$APP.$cljs$core$__destructure_map$$($map__48728__$1_p__48727_type$jscomp$322$$);$map__48728__$1_p__48727_type$jscomp$322$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48728__$1_p__48727_type$jscomp$322$$,$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__48728__$1_p__48727_type$jscomp$322$$,$cljs$cst$1801$add_children$$)},$changes$jscomp$2_p__48720$$)]))}),$modif_tree_structure_changes$$)};
$app$common$types$modifiers$transform_BANG_$$=function($matrix$jscomp$11$$,$modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$){var $G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$=$modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$,$APP.$cljs$cst$139$type$$);
$G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$=$G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$ instanceof $APP.$cljs$core$Keyword$$?$G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$.$fqn$:null;switch($G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$){case "move":return $app$common$geom$matrix$multiply_BANG_$$($APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$?.$vector$??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$,$APP.$cljs$cst$200$vector$$)),$matrix$jscomp$11$$);case "resize":var $JSCompiler_inline_result$jscomp$inline_14230_m$jscomp$inline_14753_tf$jscomp$inline_14224$$=$modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$?.transform??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$,
$APP.$cljs$cst$1289$transform$$);$G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$=$modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$?.$transform_inverse$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$,$APP.$cljs$cst$1787$transform_inverse$$);var $G__48729$jscomp$inline_14232_JSCompiler_inline_result$jscomp$14734_rotation$jscomp$inline_4830_vector$jscomp$inline_14226$$=
$modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$?.$vector$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$,$APP.$cljs$cst$200$vector$$);$modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$=$modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$?.origin??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$,
$APP.$cljs$cst$1786$origin$$);$modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$=$G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$!=null?$APP.$app$common$geom$point$transform$$($modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$,$G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$):$modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$;
var $G__48730$jscomp$inline_14231$$=$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$();$JSCompiler_inline_result$jscomp$inline_14230_m$jscomp$inline_14753_tf$jscomp$inline_14224$$=$JSCompiler_inline_result$jscomp$inline_14230_m$jscomp$inline_14753_tf$jscomp$inline_14224$$!=null?$app$common$geom$matrix$multiply_BANG_$$($G__48730$jscomp$inline_14231$$,$JSCompiler_inline_result$jscomp$inline_14230_m$jscomp$inline_14753_tf$jscomp$inline_14224$$):$G__48730$jscomp$inline_14231$$;$JSCompiler_inline_result$jscomp$inline_14230_m$jscomp$inline_14753_tf$jscomp$inline_14224$$=
$app$common$geom$matrix$translate_BANG_$$($JSCompiler_inline_result$jscomp$inline_14230_m$jscomp$inline_14753_tf$jscomp$inline_14224$$,$modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$);$G__48729$jscomp$inline_14232_JSCompiler_inline_result$jscomp$14734_rotation$jscomp$inline_4830_vector$jscomp$inline_14226$$=$app$common$geom$matrix$multiply_BANG_$$($JSCompiler_inline_result$jscomp$inline_14230_m$jscomp$inline_14753_tf$jscomp$inline_14224$$,$app$common$geom$matrix$scale_matrix$$.$cljs$core$IFn$_invoke$arity$1$($G__48729$jscomp$inline_14232_JSCompiler_inline_result$jscomp$14734_rotation$jscomp$inline_4830_vector$jscomp$inline_14226$$));
$G__48729$jscomp$inline_14232_JSCompiler_inline_result$jscomp$14734_rotation$jscomp$inline_4830_vector$jscomp$inline_14226$$=$app$common$geom$matrix$translate_BANG_$$($G__48729$jscomp$inline_14232_JSCompiler_inline_result$jscomp$14734_rotation$jscomp$inline_4830_vector$jscomp$inline_14226$$,$APP.$app$common$geom$point$negate$$($modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$));$G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$=
$G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$!=null?$app$common$geom$matrix$multiply_BANG_$$($G__48729$jscomp$inline_14232_JSCompiler_inline_result$jscomp$14734_rotation$jscomp$inline_4830_vector$jscomp$inline_14226$$,$G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$):$G__48729$jscomp$inline_14232_JSCompiler_inline_result$jscomp$14734_rotation$jscomp$inline_4830_vector$jscomp$inline_14226$$;
return $app$common$geom$matrix$multiply_BANG_$$($G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$,$matrix$jscomp$11$$);case "rotation":return $G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$=$modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$?.$center$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$,
$APP.$cljs$cst$1667$center$$),$G__48729$jscomp$inline_14232_JSCompiler_inline_result$jscomp$14734_rotation$jscomp$inline_4830_vector$jscomp$inline_14226$$=$modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$?.rotation??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifier$jscomp$3_origin$jscomp$inline_14227_origin__$1$jscomp$inline_14228$$,$APP.$cljs$cst$1788$rotation$$),$app$common$geom$matrix$multiply_BANG_$$($app$common$geom$matrix$translate_BANG_$$($app$common$geom$matrix$multiply_BANG_$$($app$common$geom$matrix$translate_BANG_$$($APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$(),
$G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$),$APP.$app$common$geom$matrix$rotate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($G__48729$jscomp$inline_14232_JSCompiler_inline_result$jscomp$14734_rotation$jscomp$inline_4830_vector$jscomp$inline_14226$$)),$APP.$app$common$geom$point$negate$$($G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$)),$matrix$jscomp$11$$);
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__48733_G__48733__$1_JSCompiler_inline_result$jscomp$inline_14229_center$jscomp$inline_4829_tfi$jscomp$inline_14225$$)].join(""));}};
$app$common$types$modifiers$modifiers__GT_transform1$$=function($modifiers$jscomp$26$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$modifiers$transform_BANG_$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$(),$modifiers$jscomp$26$$)};
$app$common$types$modifiers$modifiers__GT_transform$$=function($modifiers$jscomp$27_modifiers__$1$jscomp$8_modifiers__$2$jscomp$7$$){$modifiers$jscomp$27_modifiers__$1$jscomp$8_modifiers__$2$jscomp$7$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$27_modifiers__$1$jscomp$8_modifiers__$2$jscomp$7$$?.$geometry_parent$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$27_modifiers__$1$jscomp$8_modifiers__$2$jscomp$7$$,$APP.$cljs$cst$1777$geometry_parent$$),
$modifiers$jscomp$27_modifiers__$1$jscomp$8_modifiers__$2$jscomp$7$$?.$geometry_child$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$27_modifiers__$1$jscomp$8_modifiers__$2$jscomp$7$$,$cljs$cst$1778$geometry_child$$));$modifiers$jscomp$27_modifiers__$1$jscomp$8_modifiers__$2$jscomp$7$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48734_SHARP_$$){return $p1__48734_SHARP_$$?.order??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__48734_SHARP_$$,
$cljs$cst$365$order$$)},$modifiers$jscomp$27_modifiers__$1$jscomp$8_modifiers__$2$jscomp$7$$);return $app$common$types$modifiers$modifiers__GT_transform1$$($modifiers$jscomp$27_modifiers__$1$jscomp$8_modifiers__$2$jscomp$7$$)};
$app$common$types$modifiers$transform_text_node$$=function($letter_spacing_value$jscomp$413$$,$attrs$jscomp$8$$){var $font_size$jscomp$1$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$8$$,$APP.$cljs$cst$1760$font_size$$,14))*$letter_spacing_value$jscomp$413$$);$letter_spacing_value$jscomp$413$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$8$$,
$APP.$cljs$cst$1766$letter_spacing$$,0))*$letter_spacing_value$jscomp$413$$);return $APP.$app$common$data$txt_merge$$($attrs$jscomp$8$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1760$font_size$$,$font_size$jscomp$1$$,$APP.$cljs$cst$1766$letter_spacing$$,$letter_spacing_value$jscomp$413$$],null))};
$app$common$types$modifiers$transform_paragraph_node$$=function($font_size$jscomp$2_value$jscomp$414$$,$attrs$jscomp$9$$){$font_size$jscomp$2_value$jscomp$414$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$9$$,$APP.$cljs$cst$1760$font_size$$,14))*$font_size$jscomp$2_value$jscomp$414$$);return $APP.$app$common$data$txt_merge$$($attrs$jscomp$9$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1760$font_size$$,$font_size$jscomp$2_value$jscomp$414$$],null))};
$app$common$types$modifiers$scale_text_content$$=function($content$jscomp$22$$,$value$jscomp$416$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$text$is_paragraph_node_QMARK_$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$modifiers$transform_paragraph_node$$,$value$jscomp$416$$),$APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$text$is_text_node_QMARK_$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$modifiers$transform_text_node$$,
$value$jscomp$416$$),$content$jscomp$22$$))};
$app$common$types$modifiers$apply_scale_content$$=function($shape$jscomp$76_shape$jscomp$inline_4842$$,$value$jscomp$417_value__$1$jscomp$5$$){$value$jscomp$417_value__$1$jscomp$5$$=$APP.$app$common$math$abs$$($value$jscomp$417_value__$1$jscomp$5$$);var $G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$76_shape$jscomp$inline_4842$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$76_shape$jscomp$inline_4842$$,
$APP.$cljs$cst$1637$content$$,$app$common$types$modifiers$scale_text_content$$,$value$jscomp$417_value__$1$jscomp$5$$):$shape$jscomp$76_shape$jscomp$inline_4842$$;$G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$,
$APP.$cljs$cst$1646$r1$$,$cljs$core$_STAR_$$,$value$jscomp$417_value__$1$jscomp$5$$),$APP.$cljs$cst$1647$r2$$,$cljs$core$_STAR_$$,$value$jscomp$417_value__$1$jscomp$5$$),$APP.$cljs$cst$1648$r3$$,$cljs$core$_STAR_$$,$value$jscomp$417_value__$1$jscomp$5$$),$APP.$cljs$cst$1649$r4$$,$cljs$core$_STAR_$$,$value$jscomp$417_value__$1$jscomp$5$$);$G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$=$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$76_shape$jscomp$inline_4842$$))?
$app$common$geom$shapes$strokes$update_strokes_width$$($G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$,$value$jscomp$417_value__$1$jscomp$5$$):$G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$;$G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$=$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$76_shape$jscomp$inline_4842$$))?
$app$common$geom$shapes$effects$update_shadows_scale$$($G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$,$value$jscomp$417_value__$1$jscomp$5$$):$G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$;$G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$=$APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$76_shape$jscomp$inline_4842$$)!=null?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$260$value$$],null),$cljs$core$_STAR_$$,$value$jscomp$417_value__$1$jscomp$5$$):$G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$;$G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$76_shape$jscomp$inline_4842$$)?
$APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1680$layout_gap$$,$APP.$cljs$cst$1681$row_gap$$],null),$cljs$core$_STAR_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$417_value__$1$jscomp$5$$])),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1680$layout_gap$$,$APP.$cljs$cst$1682$column_gap$$],null),$cljs$core$_STAR_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$417_value__$1$jscomp$5$$])),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1686$layout_padding$$,$APP.$cljs$cst$1093$p1$$],null),$cljs$core$_STAR_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$417_value__$1$jscomp$5$$])),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1686$layout_padding$$,$APP.$cljs$cst$1091$p2$$],null),$cljs$core$_STAR_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$417_value__$1$jscomp$5$$])),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1686$layout_padding$$,$APP.$cljs$cst$1687$p3$$],null),$cljs$core$_STAR_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$417_value__$1$jscomp$5$$])),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1686$layout_padding$$,$APP.$cljs$cst$1688$p4$$],null),$cljs$core$_STAR_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$417_value__$1$jscomp$5$$])):
$G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$;$shape$jscomp$76_shape$jscomp$inline_4842$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$76_shape$jscomp$inline_4842$$)?$app$common$types$shape$layout$update_grid_scale$$($G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$,$value$jscomp$417_value__$1$jscomp$5$$):$G__48743__$2_G__48743__$3_G__48743__$4_G__48743__$5_G__48743__$6_JSCompiler_temp$jscomp$738$$;
return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape$jscomp$76_shape$jscomp$inline_4842$$,
$APP.$cljs$cst$1704$layout_item_max_h$$,$cljs$core$_STAR_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$417_value__$1$jscomp$5$$])),$APP.$cljs$cst$1705$layout_item_min_h$$,$cljs$core$_STAR_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$417_value__$1$jscomp$5$$])),$APP.$cljs$cst$1706$layout_item_max_w$$,$cljs$core$_STAR_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$417_value__$1$jscomp$5$$])),$APP.$cljs$cst$1707$layout_item_min_w$$,
$cljs$core$_STAR_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$417_value__$1$jscomp$5$$])),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1699$layout_item_margin$$,$APP.$cljs$cst$1700$m1$$],null),$cljs$core$_STAR_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$417_value__$1$jscomp$5$$])),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1699$layout_item_margin$$,$APP.$cljs$cst$1701$m2$$],null),$cljs$core$_STAR_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$417_value__$1$jscomp$5$$])),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1699$layout_item_margin$$,$APP.$cljs$cst$1702$m3$$],null),$cljs$core$_STAR_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$417_value__$1$jscomp$5$$])),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1699$layout_item_margin$$,$APP.$cljs$cst$1703$m4$$],null),$cljs$core$_STAR_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$417_value__$1$jscomp$5$$]))};
$app$common$types$modifiers$remove_children_set$$=function($shapes$jscomp$11$$,$children_to_remove_remove_QMARK_$$){$children_to_remove_remove_QMARK_$$=$APP.$cljs$core$set$$($children_to_remove_remove_QMARK_$$);return $APP.$app$common$data$removev$$($children_to_remove_remove_QMARK_$$,$shapes$jscomp$11$$)};
$app$common$types$modifiers$apply_modifier$$=function($shape$jscomp$77_shape__$1$jscomp$2$$,$operation$$){var $G__48747_property$jscomp$30$$=$operation$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($operation$$,$APP.$cljs$cst$139$type$$);switch($G__48747_property$jscomp$30$$ instanceof $APP.$cljs$core$Keyword$$?$G__48747_property$jscomp$30$$.$fqn$:null){case "rotation":var $rotation$jscomp$6$$=$operation$$?.value??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($operation$$,
$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$77_shape__$1$jscomp$2$$,$APP.$cljs$cst$1788$rotation$$,function($p1__48745_SHARP_$$){return $APP.$cljs$core$mod$$(($APP.$cljs$core$truth_$$($p1__48745_SHARP_$$)?$p1__48745_SHARP_$$:0)+$rotation$jscomp$6$$,360)});case "add-children":var $value$jscomp$418$$=$operation$$?.value??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($operation$$,$APP.$cljs$cst$260$value$$),$index$jscomp$174$$=$operation$$?.index??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($operation$$,$APP.$cljs$cst$1795$index$$);$shape$jscomp$77_shape__$1$jscomp$2$$=$index$jscomp$174$$!=null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$77_shape__$1$jscomp$2$$,$APP.$cljs$cst$1614$shapes$$,function($shapes$jscomp$12$$){return $APP.$cljs$core$vector_QMARK_$$($shapes$jscomp$12$$)?$APP.$app$common$data$insert_at_index$$($shapes$jscomp$12$$,$index$jscomp$174$$,$value$jscomp$418$$):$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($shapes$jscomp$12$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$418$$]))}):$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$77_shape__$1$jscomp$2$$,$APP.$cljs$cst$1614$shapes$$,$APP.$app$common$data$concat_vec$$,$value$jscomp$418$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$77_shape__$1$jscomp$2$$,$APP.$cljs$cst$1614$shapes$$,function($p1__48746_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$,$p1__48746_SHARP_$$))});case "remove-children":return $value$jscomp$418$$=$operation$$?.value??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($operation$$,$APP.$cljs$cst$260$value$$),$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$77_shape__$1$jscomp$2$$,$APP.$cljs$cst$1614$shapes$$,$app$common$types$modifiers$remove_children_set$$,$value$jscomp$418$$);case "scale-content":return $value$jscomp$418$$=
$operation$$?.value??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($operation$$,$APP.$cljs$cst$260$value$$),$app$common$types$modifiers$apply_scale_content$$($shape$jscomp$77_shape__$1$jscomp$2$$,$value$jscomp$418$$);case "change-property":return $G__48747_property$jscomp$30$$=$operation$$?.property??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($operation$$,$cljs$cst$827$property$$),$value$jscomp$418$$=$operation$$?.value??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($operation$$,
$APP.$cljs$cst$260$value$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$77_shape__$1$jscomp$2$$,$G__48747_property$jscomp$30$$,$value$jscomp$418$$);default:return $shape$jscomp$77_shape__$1$jscomp$2$$}};
$APP.$app$common$types$modifiers$apply_structure_modifiers$$=function($$__$1$jscomp$4_shape$jscomp$78$$,$modifiers$jscomp$28$$){$$__$1$jscomp$4_shape$jscomp$78$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$modifiers$apply_modifier$$,$$__$1$jscomp$4_shape$jscomp$78$$,$modifiers$jscomp$28$$?.$structure_parent$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$28$$,$cljs$cst$1779$structure_parent$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$modifiers$apply_modifier$$,
$$__$1$jscomp$4_shape$jscomp$78$$,$modifiers$jscomp$28$$?.$structure_child$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$28$$,$APP.$cljs$cst$1780$structure_child$$))};
$app$common$types$path$helpers$make_move_to$$=function($to$jscomp$11$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$11$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$11$$)],null)],null)};
$app$common$types$path$helpers$make_line_to$$=function($to$jscomp$12$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1814$line_to$$,$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$12$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$12$$)],null)],null)};
$app$common$types$path$helpers$make_curve_params$cljs$0core$0IFn$0_invoke$0arity$02$$=function($point$jscomp$12$$,$handler$jscomp$25$$){return $app$common$types$path$helpers$make_curve_params$cljs$0core$0IFn$0_invoke$0arity$03$$($point$jscomp$12$$,$handler$jscomp$25$$,$point$jscomp$12$$)};
$app$common$types$path$helpers$make_curve_params$cljs$0core$0IFn$0_invoke$0arity$03$$=function($point$jscomp$13$$,$h1$jscomp$6$$,$h2$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$13$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$13$$),$APP.$cljs$cst$1815$c1x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($h1$jscomp$6$$),$APP.$cljs$cst$1816$c1y$$,
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($h1$jscomp$6$$),$APP.$cljs$cst$1817$c2x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($h2$$),$APP.$cljs$cst$1818$c2y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($h2$$)],null)};
$app$common$types$path$helpers$update_curve_to$$=function($command$$,$h1$jscomp$7_params$jscomp$93$$,$h2$jscomp$1$$){$h1$jscomp$7_params$jscomp$93$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($command$$)),$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($command$$)),
$APP.$cljs$cst$1815$c1x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($h1$jscomp$7_params$jscomp$93$$),$APP.$cljs$cst$1816$c1y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($h1$jscomp$7_params$jscomp$93$$),$APP.$cljs$cst$1817$c2x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$1$$),$APP.$cljs$cst$1818$c2y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$1$$)],null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($command$$,
$APP.$cljs$cst$1812$command$$,$cljs$cst$1819$curve_to$$),$APP.$cljs$cst$1430$params$$,$h1$jscomp$7_params$jscomp$93$$)};$app$common$types$path$helpers$make_curve_to$$=function($to$jscomp$13$$,$h1$jscomp$8$$,$h2$jscomp$2$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,$cljs$cst$1819$curve_to$$,$APP.$cljs$cst$1430$params$$,$app$common$types$path$helpers$make_curve_params$cljs$0core$0IFn$0_invoke$0arity$03$$($to$jscomp$13$$,$h1$jscomp$8$$,$h2$jscomp$2$$)],null)};
$app$common$types$path$helpers$prefix__GT_coords$$=function($prefix$jscomp$33$$){switch($prefix$jscomp$33$$ instanceof $APP.$cljs$core$Keyword$$?$prefix$jscomp$33$$.$fqn$:null){case "c1":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1815$c1x$$,$APP.$cljs$cst$1816$c1y$$],null);case "c2":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1817$c2x$$,$APP.$cljs$cst$1818$c2y$$],
null);default:return null}};
$APP.$app$common$types$path$helpers$position_fixed_angle$$=function($distance$jscomp$2_point$jscomp$14$$,$from_point$$){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($from_point$$)?$distance$jscomp$2_point$jscomp$14$$:$from_point$$)){var $angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$=$APP.$cljs$core$mod$$(360+-$APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$02$$($distance$jscomp$2_point$jscomp$14$$,$from_point$$),360);$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$=$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$>
337.5||$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$<=22.5?0:$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$>22.5&&$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$<=67.5?45:$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$>67.5&&$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$<=112.5?90:$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$>112.5&&$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$<=157.5?135:$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$>157.5&&
$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$<=202.5?180:$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$>202.5&&$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$<=247.5?225:$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$>247.5&&$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$<=292.5?270:$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$>292.5&&$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$<=337.5?315:null;$distance$jscomp$2_point$jscomp$14$$=$APP.$app$common$geom$point$distance$$($distance$jscomp$2_point$jscomp$14$$,
$from_point$$);$angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$=$APP.$goog$math$toRadians$$($angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$);return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(($from_point$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($from_point$$,$APP.$cljs$cst$1510$x$$))+$distance$jscomp$2_point$jscomp$14$$*Math.cos($angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$),($from_point$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($from_point$$,
$APP.$cljs$cst$1511$y$$))-$distance$jscomp$2_point$jscomp$14$$*Math.sin($angle$jscomp$23_angle$jscomp$inline_11888_to_angle$$))}return $distance$jscomp$2_point$jscomp$14$$};
$app$common$types$path$helpers$command__GT_line$cljs$0core$0IFn$0_invoke$0arity$01$$=function($segment$jscomp$3$$){var $prev$jscomp$inline_4846$$=$cljs$cst$1820$prev$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$3$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prev$jscomp$inline_4846$$,$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$3$$)],null)};
$app$common$types$path$helpers$command__GT_bezier$cljs$0core$0IFn$0_invoke$0arity$01$$=function($segment$jscomp$5$$){var $prev$jscomp$inline_4849$$=$cljs$cst$1820$prev$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$5$$);return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prev$jscomp$inline_4849$$,$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$5$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1815$c1x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$5$$)),
$APP.$cljs$cst$1816$c1y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$5$$))),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1817$c2x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$5$$)),$APP.$cljs$cst$1818$c2y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$5$$)))],null)};
$app$common$types$path$helpers$line_values$$=function($p__46459_to_p$$,$move_v_t$jscomp$72$$){var $from_p$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46459_to_p$$,0,null);$p__46459_to_p$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46459_to_p$$,1,null);$move_v_t$jscomp$72$$=$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$subtract$$($p__46459_to_p$$,$from_p$$),$move_v_t$jscomp$72$$);return $APP.$app$common$geom$point$add$$($from_p$$,$move_v_t$jscomp$72$$)};
$app$common$types$path$helpers$curve_values$$=function($var_args$jscomp$940$$){switch(arguments.length){case 2:return $app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);case 5:return $APP.$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$05$$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};
$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$=function($h2$jscomp$3_p__46476$$,$t$jscomp$74$$){var $start$jscomp$190$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$3_p__46476$$,0,null),$end$jscomp$55$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$3_p__46476$$,1,null),$h1$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$3_p__46476$$,2,null);$h2$jscomp$3_p__46476$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$3_p__46476$$,3,
null);return $APP.$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$05$$($start$jscomp$190$$,$end$jscomp$55$$,$h1$jscomp$9$$,$h2$jscomp$3_p__46476$$,$t$jscomp$74$$)};
$APP.$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$05$$=function($start$jscomp$191$$,$end$jscomp$56$$,$h1$jscomp$10$$,$h2$jscomp$4$$,$t$jscomp$75$$){function $coord_v$$($coord$jscomp$1$$){return($coord$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$coord$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($start$jscomp$191$$):$coord$jscomp$1$$($start$jscomp$191$$))*$start_v$$+($coord$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$coord$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($h1$jscomp$10$$):
$coord$jscomp$1$$($h1$jscomp$10$$))*$h1_v$$+($coord$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$coord$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$4$$):$coord$jscomp$1$$($h2$jscomp$4$$))*$h2_v$$+($coord$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$coord$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$56$$):$coord$jscomp$1$$($end$jscomp$56$$))*$t3$$}var $t2$jscomp$2$$=$t$jscomp$75$$*$t$jscomp$75$$,$t3$$=$t2$jscomp$2$$*$t$jscomp$75$$,$start_v$$=-$t3$$+3*$t2$jscomp$2$$+-3*$t$jscomp$75$$+
1,$h1_v$$=3*$t3$$+-6*$t2$jscomp$2$$+3*$t$jscomp$75$$,$h2_v$$=-3*$t3$$+3*$t2$jscomp$2$$;return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($coord_v$$($APP.$cljs$cst$1510$x$$),$coord_v$$($APP.$cljs$cst$1511$y$$))};
$app$common$types$path$helpers$solve_roots_STAR_$$=function($result$jscomp$173$$,$conj$jscomp$1$$,$a$jscomp$355$$,$b$jscomp$287$$,$c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$,$d$jscomp$219_q2$$){var $sqrt_b2_4ac$$=Math.sqrt($b$jscomp$287$$*$b$jscomp$287$$-4*$a$jscomp$355$$*$c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$);if($APP.$app$common$math$almost_zero_QMARK_$$($d$jscomp$219_q2$$)&&$APP.$app$common$math$almost_zero_QMARK_$$($a$jscomp$355$$)&&$APP.$app$common$math$almost_zero_QMARK_$$($b$jscomp$287$$))return $result$jscomp$173$$;
if($APP.$app$common$math$almost_zero_QMARK_$$($d$jscomp$219_q2$$)&&$APP.$app$common$math$almost_zero_QMARK_$$($a$jscomp$355$$)){var $G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$=-$c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$/$b$jscomp$287$$;return $conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$173$$,$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$):$conj$jscomp$1$$($result$jscomp$173$$,
$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$)}if($APP.$app$common$math$almost_zero_QMARK_$$($d$jscomp$219_q2$$)){$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$=function(){var $G__46490$$=(-$b$jscomp$287$$+$sqrt_b2_4ac$$)/(2*$a$jscomp$355$$);return $conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$173$$,$G__46490$$):$conj$jscomp$1$$($result$jscomp$173$$,$G__46490$$)}();var $G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$=
(-$b$jscomp$287$$-$sqrt_b2_4ac$$)/(2*$a$jscomp$355$$);return $conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$,$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$):$conj$jscomp$1$$($G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$,$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$)}$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$=
$a$jscomp$355$$/$d$jscomp$219_q2$$;var $b__$1$jscomp$3_discriminant_p3$jscomp$5$$=$b$jscomp$287$$/$d$jscomp$219_q2$$;$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$=(3*$b__$1$jscomp$3_discriminant_p3$jscomp$5$$-$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$*$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$)/3;$c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$=(2*$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$*$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$*
$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$+-9*$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$*$b__$1$jscomp$3_discriminant_p3$jscomp$5$$+$c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$/$d$jscomp$219_q2$$*27)/27;$b__$1$jscomp$3_discriminant_p3$jscomp$5$$=$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$/3;$d$jscomp$219_q2$$=$c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$/2;$b__$1$jscomp$3_discriminant_p3$jscomp$5$$=$d$jscomp$219_q2$$*
$d$jscomp$219_q2$$+$b__$1$jscomp$3_discriminant_p3$jscomp$5$$*$b__$1$jscomp$3_discriminant_p3$jscomp$5$$*$b__$1$jscomp$3_discriminant_p3$jscomp$5$$;if($b__$1$jscomp$3_discriminant_p3$jscomp$5$$<0){$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$=-$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$/3;$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$=Math.sqrt($G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$*
$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$*$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$);$c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$=-$c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$/(2*$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$);$c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$=Math.acos($c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$<-1?-1:$c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$>
1?1:$c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$);$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$=2*$app$common$math$cubicroot$$($G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$);var $root1$$=$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$*Math.cos($c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$/3)-$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$/3,$root2$$=$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$*
Math.cos(($c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$+2*$APP.$app$common$math$PI$$)/3)-$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$/3;$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$=$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$*Math.cos(($c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$+4*$APP.$app$common$math$PI$$)/3)-$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$/3;$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$=
function(){var $G__46496$$=$conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$173$$,$root1$$):$conj$jscomp$1$$($result$jscomp$173$$,$root1$$),$G__46497$$=$root2$$;return $conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($G__46496$$,$G__46497$$):$conj$jscomp$1$$($G__46496$$,$G__46497$$)}();return $conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$,
$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$):$conj$jscomp$1$$($G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$,$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$)}if($APP.$app$common$math$almost_zero_QMARK_$$($b__$1$jscomp$3_discriminant_p3$jscomp$5$$))return $G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$=$d$jscomp$219_q2$$<0?$app$common$math$cubicroot$$(-$d$jscomp$219_q2$$):-$app$common$math$cubicroot$$($d$jscomp$219_q2$$),
$root1$$=2*$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$-$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$/3,$root2$$=-$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$-$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$/3,$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$=$conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$173$$,$root1$$):$conj$jscomp$1$$($result$jscomp$173$$,
$root1$$),$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$=$root2$$,$conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$,$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$):$conj$jscomp$1$$($G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$,$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$);$c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$=
Math.sqrt($b__$1$jscomp$3_discriminant_p3$jscomp$5$$);$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$=$app$common$math$cubicroot$$($c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$-$d$jscomp$219_q2$$);$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$=$G__46487_G__46494_G__46499_mp3_p$jscomp$199_r$jscomp$96_t1$jscomp$2_u1$$-$app$common$math$cubicroot$$($c$jscomp$267_phi_q$jscomp$36_sd$jscomp$1_t$jscomp$76$$+$d$jscomp$219_q2$$)-$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$/
3;return $conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$conj$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$173$$,$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$):$conj$jscomp$1$$($result$jscomp$173$$,$G__46485_G__46486_G__46498_a__$1$jscomp$7_root$jscomp$33_root3$$)};
$app$common$types$path$helpers$curve_extremities$$=function($var_args$jscomp$942$$){switch(arguments.length){case 1:return $app$common$types$path$helpers$curve_extremities$cljs$0core$0IFn$0_invoke$0arity$01$$(arguments[0]);case 4:return $app$common$types$path$helpers$curve_extremities$cljs$0core$0IFn$0_invoke$0arity$04$$(arguments[0],arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$common$types$path$helpers$curve_extremities$cljs$0core$0IFn$0_invoke$0arity$01$$=function($h2$jscomp$5_p__46532$$){var $start$jscomp$192$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$5_p__46532$$,0,null),$end$jscomp$57$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$5_p__46532$$,1,null),$h1$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$5_p__46532$$,2,null);$h2$jscomp$5_p__46532$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$5_p__46532$$,
3,null);return $app$common$types$path$helpers$curve_extremities$cljs$0core$0IFn$0_invoke$0arity$04$$($start$jscomp$192$$,$end$jscomp$57$$,$h1$jscomp$11$$,$h2$jscomp$5_p__46532$$)};
$app$common$types$path$helpers$curve_extremities$cljs$0core$0IFn$0_invoke$0arity$04$$=function($coords_start$jscomp$193$$,$end$jscomp$58$$,$h1$jscomp$12$$,$h2$jscomp$6$$){$coords_start$jscomp$193$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($coords_start$jscomp$193$$),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($h1$jscomp$12$$),
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$6$$),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$58$$)],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($coords_start$jscomp$193$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($h1$jscomp$12$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$6$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$58$$)],
null)],null);return $APP.$cljs$core$filterv$$(function($p1__46524_SHARP_$$){return $p1__46524_SHARP_$$>.01&&$p1__46524_SHARP_$$<.99},$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($c3$jscomp$5_p__46549$$){var $c0$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$5_p__46549$$,0,null),$c1$jscomp$23$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$5_p__46549$$,1,null),$c2$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$5_p__46549$$,
2,null);$c3$jscomp$5_p__46549$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$5_p__46549$$,3,null);return $app$common$types$path$helpers$solve_roots_STAR_$$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$conj$$,-3*$c0$jscomp$2$$+9*$c1$jscomp$23$$+-9*$c2$jscomp$14$$+3*$c3$jscomp$5_p__46549$$,6*$c0$jscomp$2$$+-12*$c1$jscomp$23$$+6*$c2$jscomp$14$$,3*$c1$jscomp$23$$+-3*$c0$jscomp$2$$,0)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$coords_start$jscomp$193$$])))};
$app$common$types$path$helpers$calculate_curve_extremities$$=function($start$jscomp$194$$,$end$jscomp$59$$,$h1$jscomp$13$$,$h2$jscomp$7$$){function $process_curve$$($result$jscomp$174$$,$c0$jscomp$3$$,$c1$jscomp$24$$,$c2$jscomp$15$$,$c3$jscomp$6$$){return $app$common$types$path$helpers$solve_roots_STAR_$$($result$jscomp$174$$,$conj_STAR_$$,-3*$c0$jscomp$3$$+9*$c1$jscomp$24$$+-9*$c2$jscomp$15$$+3*$c3$jscomp$6$$,6*$c0$jscomp$3$$+-12*$c1$jscomp$24$$+6*$c2$jscomp$15$$,3*$c1$jscomp$24$$+-3*$c0$jscomp$3$$,
0)}var $start_x$jscomp$2$$=$start$jscomp$194$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($start$jscomp$194$$,$APP.$cljs$cst$1510$x$$),$h1_x$$=$h1$jscomp$13$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h1$jscomp$13$$,$APP.$cljs$cst$1510$x$$),$h2_x$$=$h2$jscomp$7$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h2$jscomp$7$$,$APP.$cljs$cst$1510$x$$),$end_x$jscomp$2$$=$end$jscomp$59$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$59$$,
$APP.$cljs$cst$1510$x$$),$start_y$jscomp$2$$=$start$jscomp$194$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($start$jscomp$194$$,$APP.$cljs$cst$1511$y$$),$h1_y$$=$h1$jscomp$13$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h1$jscomp$13$$,$APP.$cljs$cst$1511$y$$),$h2_y$$=$h2$jscomp$7$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h2$jscomp$7$$,$APP.$cljs$cst$1511$y$$),$end_y$jscomp$2$$=$end$jscomp$59$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$59$$,
$APP.$cljs$cst$1511$y$$),$conj_STAR_$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__46553_SHARP_$$){return $p1__46553_SHARP_$$>.01&&$p1__46553_SHARP_$$<.99}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($h1_v$jscomp$1_t$jscomp$77$$){var $h2_v$jscomp$1_t2$jscomp$3$$=$h1_v$jscomp$1_t$jscomp$77$$*$h1_v$jscomp$1_t$jscomp$77$$,$t3$jscomp$1$$=$h2_v$jscomp$1_t2$jscomp$3$$*$h1_v$jscomp$1_t$jscomp$77$$,$start_v$jscomp$1$$=
-$t3$jscomp$1$$+3*$h2_v$jscomp$1_t2$jscomp$3$$+-3*$h1_v$jscomp$1_t$jscomp$77$$+1;$h1_v$jscomp$1_t$jscomp$77$$=3*$t3$jscomp$1$$+-6*$h2_v$jscomp$1_t2$jscomp$3$$+3*$h1_v$jscomp$1_t$jscomp$77$$;$h2_v$jscomp$1_t2$jscomp$3$$=-3*$t3$jscomp$1$$+3*$h2_v$jscomp$1_t2$jscomp$3$$;return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($start_x$jscomp$2$$*$start_v$jscomp$1$$+$h1_x$$*$h1_v$jscomp$1_t$jscomp$77$$+$h2_x$$*$h2_v$jscomp$1_t2$jscomp$3$$+$end_x$jscomp$2$$*$t3$jscomp$1$$,$start_y$jscomp$2$$*
$start_v$jscomp$1$$+$h1_y$$*$h1_v$jscomp$1_t$jscomp$77$$+$h2_y$$*$h2_v$jscomp$1_t2$jscomp$3$$+$end_y$jscomp$2$$*$t3$jscomp$1$$)}))($APP.$cljs$core$conj_BANG_$$);return $APP.$cljs$core$persistent_BANG_$$($process_curve$$($process_curve$$($APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$start_x$jscomp$2$$,$h1_x$$,$h2_x$$,$end_x$jscomp$2$$),$start_y$jscomp$2$$,$h1_y$$,$h2_y$$,$end_y$jscomp$2$$))};
$app$common$types$path$helpers$curve_tangent$$=function($h2$jscomp$8_p__46564$$,$t$jscomp$78$$){var $coords$jscomp$1_start$jscomp$195_x$jscomp$1095$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$8_p__46564$$,0,null),$end$jscomp$60_vec__46569_y$jscomp$353$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$8_p__46564$$,1,null),$d$jscomp$221_h1$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$8_p__46564$$,2,null);$h2$jscomp$8_p__46564$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$8_p__46564$$,3,null);$coords$jscomp$1_start$jscomp$195_x$jscomp$1095$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($coords$jscomp$1_start$jscomp$195_x$jscomp$1095$$),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($d$jscomp$221_h1$jscomp$14$$),
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$8_p__46564$$),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$60_vec__46569_y$jscomp$353$$)],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($coords$jscomp$1_start$jscomp$195_x$jscomp$1095$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($d$jscomp$221_h1$jscomp$14$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$8_p__46564$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$60_vec__46569_y$jscomp$353$$)],null)],null);$end$jscomp$60_vec__46569_y$jscomp$353$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($c3$jscomp$7_p__46586$$){var $c0$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$7_p__46586$$,0,null),$c1$jscomp$25$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$7_p__46586$$,1,null),$c2$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$7_p__46586$$,
2,null);$c3$jscomp$7_p__46586$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$7_p__46586$$,3,null);var $t2$jscomp$4$$=$t$jscomp$78$$*$t$jscomp$78$$;return $c0$jscomp$4$$*(-3*$t2$jscomp$4$$+6*$t$jscomp$78$$+-3)+$c1$jscomp$25$$*(9*$t2$jscomp$4$$+-12*$t$jscomp$78$$+3)+$c2$jscomp$16$$*(-9*$t2$jscomp$4$$+6*$t$jscomp$78$$)+3*$t2$jscomp$4$$*$c3$jscomp$7_p__46586$$},$coords$jscomp$1_start$jscomp$195_x$jscomp$1095$$);$coords$jscomp$1_start$jscomp$195_x$jscomp$1095$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$60_vec__46569_y$jscomp$353$$,
0,null);$end$jscomp$60_vec__46569_y$jscomp$353$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$60_vec__46569_y$jscomp$353$$,1,null);$d$jscomp$221_h1$jscomp$14$$=$APP.$app$common$math$hypot$$($coords$jscomp$1_start$jscomp$195_x$jscomp$1095$$,$end$jscomp$60_vec__46569_y$jscomp$353$$);return $APP.$app$common$math$almost_zero_QMARK_$$($d$jscomp$221_h1$jscomp$14$$)?$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0):$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($coords$jscomp$1_start$jscomp$195_x$jscomp$1095$$/
$d$jscomp$221_h1$jscomp$14$$,$end$jscomp$60_vec__46569_y$jscomp$353$$/$d$jscomp$221_h1$jscomp$14$$)};
$app$common$types$path$helpers$curve_split$cljs$0core$0IFn$0_invoke$0arity$05$$=function($start$jscomp$198$$,$end$jscomp$63$$,$h1$jscomp$17_p4$$,$h2$jscomp$11_p3$jscomp$6$$,$sp$jscomp$2_t$jscomp$82$$){var $p1$jscomp$45$$=$app$common$geom$point$lerp$$($start$jscomp$198$$,$h1$jscomp$17_p4$$,$sp$jscomp$2_t$jscomp$82$$),$p2$jscomp$34_p5$$=$app$common$geom$point$lerp$$($h1$jscomp$17_p4$$,$h2$jscomp$11_p3$jscomp$6$$,$sp$jscomp$2_t$jscomp$82$$);$h2$jscomp$11_p3$jscomp$6$$=$app$common$geom$point$lerp$$($h2$jscomp$11_p3$jscomp$6$$,
$end$jscomp$63$$,$sp$jscomp$2_t$jscomp$82$$);$h1$jscomp$17_p4$$=$app$common$geom$point$lerp$$($p1$jscomp$45$$,$p2$jscomp$34_p5$$,$sp$jscomp$2_t$jscomp$82$$);$p2$jscomp$34_p5$$=$app$common$geom$point$lerp$$($p2$jscomp$34_p5$$,$h2$jscomp$11_p3$jscomp$6$$,$sp$jscomp$2_t$jscomp$82$$);$sp$jscomp$2_t$jscomp$82$$=$app$common$geom$point$lerp$$($h1$jscomp$17_p4$$,$p2$jscomp$34_p5$$,$sp$jscomp$2_t$jscomp$82$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$start$jscomp$198$$,$sp$jscomp$2_t$jscomp$82$$,$p1$jscomp$45$$,$h1$jscomp$17_p4$$],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$sp$jscomp$2_t$jscomp$82$$,$end$jscomp$63$$,$p2$jscomp$34_p5$$,$h2$jscomp$11_p3$jscomp$6$$],null)],null)};
$app$common$types$path$helpers$subcurve_range$cljs$0core$0IFn$0_invoke$0arity$03$$=function($h2$jscomp$14_p__46712$$,$t1$jscomp$4$$,$t2$jscomp$6$$){var $start$jscomp$200$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$14_p__46712$$,0,null),$end$jscomp$66$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$14_p__46712$$,1,null),$h1$jscomp$20$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$14_p__46712$$,2,null);$h2$jscomp$14_p__46712$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$14_p__46712$$,
3,null);return $app$common$types$path$helpers$subcurve_range$cljs$0core$0IFn$0_invoke$0arity$06$$($start$jscomp$200$$,$end$jscomp$66$$,$h1$jscomp$20$$,$h2$jscomp$14_p__46712$$,$t1$jscomp$4$$,$t2$jscomp$6$$)};
$app$common$types$path$helpers$subcurve_range$cljs$0core$0IFn$0_invoke$0arity$06$$=function($start$jscomp$201_start$jscomp$inline_4853_vec__46723$$,$end$jscomp$67_end$jscomp$inline_4854$$,$h1$jscomp$21_h1$jscomp$inline_4855$$,$h2$jscomp$15_h2$jscomp$inline_4856_p__46661$jscomp$inline_4851$$,$JSCompiler_inline_result$jscomp$744_t1$jscomp$5_t2_SINGLEQUOTE__vec__46720$$,$t1__$1_t2$jscomp$7$$){$JSCompiler_inline_result$jscomp$744_t1$jscomp$5_t2_SINGLEQUOTE__vec__46720$$=$JSCompiler_inline_result$jscomp$744_t1$jscomp$5_t2_SINGLEQUOTE__vec__46720$$<
$t1__$1_t2$jscomp$7$$?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_inline_result$jscomp$744_t1$jscomp$5_t2_SINGLEQUOTE__vec__46720$$,$t1__$1_t2$jscomp$7$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$t1__$1_t2$jscomp$7$$,$JSCompiler_inline_result$jscomp$744_t1$jscomp$5_t2_SINGLEQUOTE__vec__46720$$],null);$t1__$1_t2$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$744_t1$jscomp$5_t2_SINGLEQUOTE__vec__46720$$,
0,null);$JSCompiler_inline_result$jscomp$744_t1$jscomp$5_t2_SINGLEQUOTE__vec__46720$$=($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$744_t1$jscomp$5_t2_SINGLEQUOTE__vec__46720$$,1,null)-$t1__$1_t2$jscomp$7$$)/(1-$t1__$1_t2$jscomp$7$$);$start$jscomp$201_start$jscomp$inline_4853_vec__46723$$=$app$common$types$path$helpers$curve_split$cljs$0core$0IFn$0_invoke$0arity$05$$($start$jscomp$201_start$jscomp$inline_4853_vec__46723$$,$end$jscomp$67_end$jscomp$inline_4854$$,
$h1$jscomp$21_h1$jscomp$inline_4855$$,$h2$jscomp$15_h2$jscomp$inline_4856_p__46661$jscomp$inline_4851$$,$t1__$1_t2$jscomp$7$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start$jscomp$201_start$jscomp$inline_4853_vec__46723$$,0,null);$h2$jscomp$15_h2$jscomp$inline_4856_p__46661$jscomp$inline_4851$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start$jscomp$201_start$jscomp$inline_4853_vec__46723$$,1,null);$start$jscomp$201_start$jscomp$inline_4853_vec__46723$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$15_h2$jscomp$inline_4856_p__46661$jscomp$inline_4851$$,
0,null);$end$jscomp$67_end$jscomp$inline_4854$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$15_h2$jscomp$inline_4856_p__46661$jscomp$inline_4851$$,1,null);$h1$jscomp$21_h1$jscomp$inline_4855$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$15_h2$jscomp$inline_4856_p__46661$jscomp$inline_4851$$,2,null);$h2$jscomp$15_h2$jscomp$inline_4856_p__46661$jscomp$inline_4851$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$15_h2$jscomp$inline_4856_p__46661$jscomp$inline_4851$$,
3,null);$JSCompiler_inline_result$jscomp$744_t1$jscomp$5_t2_SINGLEQUOTE__vec__46720$$=$app$common$types$path$helpers$curve_split$cljs$0core$0IFn$0_invoke$0arity$05$$($start$jscomp$201_start$jscomp$inline_4853_vec__46723$$,$end$jscomp$67_end$jscomp$inline_4854$$,$h1$jscomp$21_h1$jscomp$inline_4855$$,$h2$jscomp$15_h2$jscomp$inline_4856_p__46661$jscomp$inline_4851$$,$JSCompiler_inline_result$jscomp$744_t1$jscomp$5_t2_SINGLEQUOTE__vec__46720$$);return $APP.$cljs$core$first$$($JSCompiler_inline_result$jscomp$744_t1$jscomp$5_t2_SINGLEQUOTE__vec__46720$$)};
$app$common$types$path$helpers$split_line_to_ranges$$=function($from_p$jscomp$4$$,$segment$jscomp$9_values_set$$,$values$jscomp$33_values__$1$$){$values$jscomp$33_values__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__46727_SHARP_$$){return $p1__46727_SHARP_$$>0&&$p1__46727_SHARP_$$<1},$values$jscomp$33_values__$1$$);if($APP.$cljs$core$empty_QMARK_$$($values$jscomp$33_values__$1$$))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$segment$jscomp$9_values_set$$],null);var $to_p$jscomp$3$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$9_values_set$$);$segment$jscomp$9_values_set$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$sorted_set$$(),$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$33_values__$1$$,1));return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($val$jscomp$159$$){return $app$common$types$path$helpers$make_line_to$$($app$common$geom$point$lerp$$($from_p$jscomp$4$$,
$to_p$jscomp$3$$,$val$jscomp$159$$))},$segment$jscomp$9_values_set$$)};
$app$common$types$path$helpers$split_curve_to_ranges$$=function($from_p$jscomp$5$$,$params$jscomp$96_segment$jscomp$10_values_set$jscomp$1$$,$values$jscomp$34_values__$1$jscomp$1$$){$values$jscomp$34_values__$1$jscomp$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__46732_SHARP_$$){return $p1__46732_SHARP_$$>0&&$p1__46732_SHARP_$$<1},$values$jscomp$34_values__$1$jscomp$1$$);if($APP.$cljs$core$empty_QMARK_$$($values$jscomp$34_values__$1$jscomp$1$$))return new $APP.$cljs$core$PersistentVector$$(null,1,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$params$jscomp$96_segment$jscomp$10_values_set$jscomp$1$$],null);var $to_p$jscomp$4$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$96_segment$jscomp$10_values_set$jscomp$1$$);$params$jscomp$96_segment$jscomp$10_values_set$jscomp$1$$=$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$96_segment$jscomp$10_values_set$jscomp$1$$);var $h1$jscomp$22$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1815$c1x$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$96_segment$jscomp$10_values_set$jscomp$1$$),
$APP.$cljs$cst$1816$c1y$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$96_segment$jscomp$10_values_set$jscomp$1$$)),$h2$jscomp$16$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1817$c2x$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$96_segment$jscomp$10_values_set$jscomp$1$$),$APP.$cljs$cst$1818$c2y$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$96_segment$jscomp$10_values_set$jscomp$1$$));$params$jscomp$96_segment$jscomp$10_values_set$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$sorted_set$$(),
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($values$jscomp$34_values__$1$jscomp$1$$,0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([1])));return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($h1_SINGLEQUOTE__p__46737_t0$$){var $t1$jscomp$6_to_p__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h1_SINGLEQUOTE__p__46737_t0$$,0,null);$h1_SINGLEQUOTE__p__46737_t0$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h1_SINGLEQUOTE__p__46737_t0$$,
1,null);var $h2_SINGLEQUOTE__vec__46741$$=$app$common$types$path$helpers$subcurve_range$cljs$0core$0IFn$0_invoke$0arity$06$$($from_p$jscomp$5$$,$to_p$jscomp$4$$,$h1$jscomp$22$$,$h2$jscomp$16$$,$h1_SINGLEQUOTE__p__46737_t0$$,$t1$jscomp$6_to_p__$1$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2_SINGLEQUOTE__vec__46741$$,0,null);$t1$jscomp$6_to_p__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2_SINGLEQUOTE__vec__46741$$,1,null);$h1_SINGLEQUOTE__p__46737_t0$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2_SINGLEQUOTE__vec__46741$$,
2,null);$h2_SINGLEQUOTE__vec__46741$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2_SINGLEQUOTE__vec__46741$$,3,null);return $app$common$types$path$helpers$make_curve_to$$($t1$jscomp$6_to_p__$1$$,$h1_SINGLEQUOTE__p__46737_t0$$,$h2_SINGLEQUOTE__vec__46741$$)},$APP.$cljs$core$rest$$($APP.$app$common$data$with_prev$$($params$jscomp$96_segment$jscomp$10_values_set$jscomp$1$$)))};
$app$common$types$path$helpers$get_line_tval$$=function($map__46752_p__46746_x2$jscomp$15$$,$p__46747_x$jscomp$1096$$){var $map__46751_x1$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__46752_p__46746_x2$jscomp$15$$,0,null),$map__46751__$1_y1$jscomp$19$$=$APP.$cljs$core$__destructure_map$$($map__46751_x1$jscomp$17$$);$map__46751_x1$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46751__$1_y1$jscomp$19$$,$APP.$cljs$cst$1510$x$$);$map__46751__$1_y1$jscomp$19$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46751__$1_y1$jscomp$19$$,$APP.$cljs$cst$1511$y$$);$map__46752_p__46746_x2$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__46752_p__46746_x2$jscomp$15$$,1,null);var $map__46752__$1_y2$jscomp$17$$=$APP.$cljs$core$__destructure_map$$($map__46752_p__46746_x2$jscomp$15$$);$map__46752_p__46746_x2$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46752__$1_y2$jscomp$17$$,$APP.$cljs$cst$1510$x$$);
$map__46752__$1_y2$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46752__$1_y2$jscomp$17$$,$APP.$cljs$cst$1511$y$$);var $map__46753__$1_y$jscomp$354$$=$APP.$cljs$core$__destructure_map$$($p__46747_x$jscomp$1096$$);$p__46747_x$jscomp$1096$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46753__$1_y$jscomp$354$$,$APP.$cljs$cst$1510$x$$);$map__46753__$1_y$jscomp$354$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46753__$1_y$jscomp$354$$,$APP.$cljs$cst$1511$y$$);
return $APP.$app$common$math$almost_zero_QMARK_$$($map__46751_x1$jscomp$17$$-$map__46752_p__46746_x2$jscomp$15$$)&&$APP.$app$common$math$almost_zero_QMARK_$$($map__46751__$1_y1$jscomp$19$$-$map__46752__$1_y2$jscomp$17$$)?Infinity:$APP.$app$common$math$almost_zero_QMARK_$$($map__46751_x1$jscomp$17$$-$map__46752_p__46746_x2$jscomp$15$$)?($map__46753__$1_y$jscomp$354$$-$map__46751__$1_y1$jscomp$19$$)/($map__46752__$1_y2$jscomp$17$$-$map__46751__$1_y1$jscomp$19$$):($p__46747_x$jscomp$1096$$-$map__46751_x1$jscomp$17$$)/
($map__46752_p__46746_x2$jscomp$15$$-$map__46751_x1$jscomp$17$$)};
$app$common$types$path$helpers$curve_range__GT_rect$$=function($curve$jscomp$2_from_p$jscomp$6$$,$from_t_to_p$jscomp$5$$,$extremes_to_t$$){var $vec__46758$$=$app$common$types$path$helpers$subcurve_range$cljs$0core$0IFn$0_invoke$0arity$03$$($curve$jscomp$2_from_p$jscomp$6$$,$from_t_to_p$jscomp$5$$,$extremes_to_t$$);$curve$jscomp$2_from_p$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__46758$$,0,null);$from_t_to_p$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__46758$$,
1,null);$extremes_to_t$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__46756_SHARP_$$){return $app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$($vec__46758$$,$p1__46756_SHARP_$$)},$app$common$types$path$helpers$curve_extremities$cljs$0core$0IFn$0_invoke$0arity$01$$($vec__46758$$));return $APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$curve$jscomp$2_from_p$jscomp$6$$,$from_t_to_p$jscomp$5$$],null),$extremes_to_t$$))};
$app$common$types$path$helpers$line_has_point_QMARK_$$=function($point$jscomp$15_px$jscomp$3$$,$map__46768__$1_p__46763_vy_y1$jscomp$20$$){var $from_p$jscomp$7_x1$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__46768__$1_p__46763_vy_y1$jscomp$20$$,0,null),$to_p$jscomp$6_x2$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__46768__$1_p__46763_vy_y1$jscomp$20$$,1,null);$map__46768__$1_p__46763_vy_y1$jscomp$20$$=$APP.$cljs$core$__destructure_map$$($from_p$jscomp$7_x1$jscomp$18$$);
$from_p$jscomp$7_x1$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46768__$1_p__46763_vy_y1$jscomp$20$$,$APP.$cljs$cst$1510$x$$);$map__46768__$1_p__46763_vy_y1$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46768__$1_p__46763_vy_y1$jscomp$20$$,$APP.$cljs$cst$1511$y$$);var $m$jscomp$197_map__46769__$1_y2$jscomp$18$$=$APP.$cljs$core$__destructure_map$$($to_p$jscomp$6_x2$jscomp$16$$);$to_p$jscomp$6_x2$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$197_map__46769__$1_y2$jscomp$18$$,
$APP.$cljs$cst$1510$x$$);$m$jscomp$197_map__46769__$1_y2$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$197_map__46769__$1_y2$jscomp$18$$,$APP.$cljs$cst$1511$y$$);var $map__46770__$1_py$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($point$jscomp$15_px$jscomp$3$$);$point$jscomp$15_px$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46770__$1_py$jscomp$2$$,$APP.$cljs$cst$1510$x$$);$map__46770__$1_py$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46770__$1_py$jscomp$2$$,
$APP.$cljs$cst$1511$y$$);$m$jscomp$197_map__46769__$1_y2$jscomp$18$$=$APP.$app$common$math$almost_zero_QMARK_$$($from_p$jscomp$7_x1$jscomp$18$$-$to_p$jscomp$6_x2$jscomp$16$$)?null:($m$jscomp$197_map__46769__$1_y2$jscomp$18$$-$map__46768__$1_p__46763_vy_y1$jscomp$20$$)/($to_p$jscomp$6_x2$jscomp$16$$-$from_p$jscomp$7_x1$jscomp$18$$);$map__46768__$1_p__46763_vy_y1$jscomp$20$$=$m$jscomp$197_map__46769__$1_y2$jscomp$18$$!=null?$m$jscomp$197_map__46769__$1_y2$jscomp$18$$*$point$jscomp$15_px$jscomp$3$$+
-$m$jscomp$197_map__46769__$1_y2$jscomp$18$$*$from_p$jscomp$7_x1$jscomp$18$$+$map__46768__$1_p__46763_vy_y1$jscomp$20$$:null;return $APP.$app$common$math$almost_zero_QMARK_$$($from_p$jscomp$7_x1$jscomp$18$$-$to_p$jscomp$6_x2$jscomp$16$$)&&$APP.$app$common$math$almost_zero_QMARK_$$($point$jscomp$15_px$jscomp$3$$-$from_p$jscomp$7_x1$jscomp$18$$)||$map__46768__$1_p__46763_vy_y1$jscomp$20$$!=null&&$APP.$app$common$math$almost_zero_QMARK_$$($map__46770__$1_py$jscomp$2$$-$map__46768__$1_p__46763_vy_y1$jscomp$20$$)};
$app$common$types$path$helpers$curve_has_point_QMARK_$$=function($point$jscomp$17$$,$curve$jscomp$3$$){return function $app$common$types$path$helpers$curve_has_point_QMARK__$_check_range$$($from_t$jscomp$1_or__5025__auto__$jscomp$353$$,$to_t$jscomp$1$$){var $half_t_r$jscomp$97$$=$app$common$types$path$helpers$curve_range__GT_rect$$($curve$jscomp$3$$,$from_t$jscomp$1_or__5025__auto__$jscomp$353$$,$to_t$jscomp$1$$);if($app$common$geom$rect$contains_point_QMARK_$$($half_t_r$jscomp$97$$,$point$jscomp$17$$)){if($APP.$app$common$math$almost_zero_QMARK_$$($from_t$jscomp$1_or__5025__auto__$jscomp$353$$-
$to_t$jscomp$1$$))return $APP.$app$common$geom$point$distance$$($app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$($curve$jscomp$3$$,$from_t$jscomp$1_or__5025__auto__$jscomp$353$$),$point$jscomp$17$$)<.1;$half_t_r$jscomp$97$$=$from_t$jscomp$1_or__5025__auto__$jscomp$353$$+($to_t$jscomp$1$$-$from_t$jscomp$1_or__5025__auto__$jscomp$353$$)/2;$from_t$jscomp$1_or__5025__auto__$jscomp$353$$=$app$common$types$path$helpers$curve_has_point_QMARK__$_check_range$$($from_t$jscomp$1_or__5025__auto__$jscomp$353$$,
$half_t_r$jscomp$97$$);return $APP.$cljs$core$truth_$$($from_t$jscomp$1_or__5025__auto__$jscomp$353$$)?$from_t$jscomp$1_or__5025__auto__$jscomp$353$$:$app$common$types$path$helpers$curve_has_point_QMARK__$_check_range$$($half_t_r$jscomp$97$$,$to_t$jscomp$1$$)}return null}(0,1)};
$app$common$types$path$helpers$curve_roots$cljs$0core$0IFn$0_invoke$0arity$05$$=function($coords$jscomp$2_start$jscomp$203$$,$end$jscomp$69$$,$h1$jscomp$24$$,$h2$jscomp$18$$){$coords$jscomp$2_start$jscomp$203$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($coords$jscomp$2_start$jscomp$203$$,$APP.$cljs$cst$1511$y$$),
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h1$jscomp$24$$,$APP.$cljs$cst$1511$y$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h2$jscomp$18$$,$APP.$cljs$cst$1511$y$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$69$$,$APP.$cljs$cst$1511$y$$)],null)],null);return $APP.$cljs$core$filterv$$(function($p1__46785_SHARP_$$){return $p1__46785_SHARP_$$>=0&&$p1__46785_SHARP_$$<=1},$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p__46804_pd$jscomp$1$$){var $pa$jscomp$4$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46804_pd$jscomp$1$$,0,null),$pb$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46804_pd$jscomp$1$$,1,null),$pc$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46804_pd$jscomp$1$$,2,null);$p__46804_pd$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46804_pd$jscomp$1$$,3,null);return $app$common$types$path$helpers$solve_roots_STAR_$$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$conj$$,3*$pa$jscomp$4$$+-6*$pb$jscomp$2$$+3*$pc$jscomp$1$$,-3*$pa$jscomp$4$$+3*$pb$jscomp$2$$,$pa$jscomp$4$$,-$pa$jscomp$4$$+3*$pb$jscomp$2$$+-3*$pc$jscomp$1$$+$p__46804_pd$jscomp$1$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$coords$jscomp$2_start$jscomp$203$$])))};
$app$common$types$path$helpers$line_line_crossing$$=function($p__46810_t1$jscomp$7$$,$p__46811_t2$jscomp$8$$){var $cross_p_from_p1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46810_t1$jscomp$7$$,0,null),$to_p1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46810_t1$jscomp$7$$,1,null),$from_p2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46811_t2$jscomp$8$$,0,null),$to_p2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46811_t2$jscomp$8$$,
1,null),$map__46819__$1_y1$jscomp$21$$=$APP.$cljs$core$__destructure_map$$($cross_p_from_p1$$),$d$jscomp$223_x1$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46819__$1_y1$jscomp$21$$,$APP.$cljs$cst$1510$x$$);$map__46819__$1_y1$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46819__$1_y1$jscomp$21$$,$APP.$cljs$cst$1511$y$$);var $map__46820__$1_y2$jscomp$19$$=$APP.$cljs$core$__destructure_map$$($to_p1$$),$x2$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46820__$1_y2$jscomp$19$$,
$APP.$cljs$cst$1510$x$$);$map__46820__$1_y2$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46820__$1_y2$jscomp$19$$,$APP.$cljs$cst$1511$y$$);var $map__46821__$1_y3$$=$APP.$cljs$core$__destructure_map$$($from_p2$$),$x3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46821__$1_y3$$,$APP.$cljs$cst$1510$x$$);$map__46821__$1_y3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46821__$1_y3$$,$APP.$cljs$cst$1511$y$$);var $map__46822__$1_nx$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($to_p2$$),
$x4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46822__$1_nx$jscomp$1$$,$APP.$cljs$cst$1510$x$$),$y4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46822__$1_nx$jscomp$1$$,$APP.$cljs$cst$1511$y$$);$map__46822__$1_nx$jscomp$1$$=($x3$$-$x4$$)*($d$jscomp$223_x1$jscomp$19$$*$map__46820__$1_y2$jscomp$19$$-$map__46819__$1_y1$jscomp$21$$*$x2$jscomp$17$$)-($d$jscomp$223_x1$jscomp$19$$-$x2$jscomp$17$$)*($x3$$*$y4$$-$map__46821__$1_y3$$*$x4$$);var $ny$jscomp$1$$=($map__46821__$1_y3$$-
$y4$$)*($d$jscomp$223_x1$jscomp$19$$*$map__46820__$1_y2$jscomp$19$$-$map__46819__$1_y1$jscomp$21$$*$x2$jscomp$17$$)-($map__46819__$1_y1$jscomp$21$$-$map__46820__$1_y2$jscomp$19$$)*($x3$$*$y4$$-$map__46821__$1_y3$$*$x4$$);$d$jscomp$223_x1$jscomp$19$$=($d$jscomp$223_x1$jscomp$19$$-$x2$jscomp$17$$)*($map__46821__$1_y3$$-$y4$$)-($map__46819__$1_y1$jscomp$21$$-$map__46820__$1_y2$jscomp$19$$)*($x3$$-$x4$$);if($APP.$app$common$math$almost_zero_QMARK_$$($d$jscomp$223_x1$jscomp$19$$))return $app$common$types$path$helpers$line_has_point_QMARK_$$($from_p2$$,
$p__46810_t1$jscomp$7$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$types$path$helpers$get_line_tval$$($p__46810_t1$jscomp$7$$,$from_p2$$),0],null):$app$common$types$path$helpers$line_has_point_QMARK_$$($to_p2$$,$p__46810_t1$jscomp$7$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$types$path$helpers$get_line_tval$$($p__46810_t1$jscomp$7$$,$to_p2$$),1],null):$app$common$types$path$helpers$line_has_point_QMARK_$$($to_p1$$,
$p__46811_t2$jscomp$8$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,$app$common$types$path$helpers$get_line_tval$$($p__46811_t2$jscomp$8$$,$to_p1$$)],null):$app$common$types$path$helpers$line_has_point_QMARK_$$($cross_p_from_p1$$,$p__46811_t2$jscomp$8$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,$app$common$types$path$helpers$get_line_tval$$($p__46811_t2$jscomp$8$$,$cross_p_from_p1$$)],null):
null;$cross_p_from_p1$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($map__46822__$1_nx$jscomp$1$$/$d$jscomp$223_x1$jscomp$19$$,$ny$jscomp$1$$/$d$jscomp$223_x1$jscomp$19$$);$p__46810_t1$jscomp$7$$=$app$common$types$path$helpers$get_line_tval$$($p__46810_t1$jscomp$7$$,$cross_p_from_p1$$);$p__46811_t2$jscomp$8$$=$app$common$types$path$helpers$get_line_tval$$($p__46811_t2$jscomp$8$$,$cross_p_from_p1$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$p__46810_t1$jscomp$7$$,$p__46811_t2$jscomp$8$$],null)};
$app$common$types$path$helpers$line_curve_crossing$$=function($end$jscomp$inline_4866_from_p2$jscomp$1_p__46835$$,$h2_p2_p__46836$$){var $from_p1$jscomp$1_start$jscomp$inline_4865_transform$jscomp$37$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$inline_4866_from_p2$jscomp$1_p__46835$$,0,null),$theta_to_p1$jscomp$1_y$jscomp$inline_4859$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$inline_4866_from_p2$jscomp$1_p__46835$$,1,null);$end$jscomp$inline_4866_from_p2$jscomp$1_p__46835$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2_p2_p__46836$$,0,null);var $h1$jscomp$inline_4867_to_p2$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2_p2_p__46836$$,1,null),$h1_p2_h2$jscomp$inline_4868_p__46792$jscomp$inline_4863$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2_p2_p__46836$$,2,null);$h2_p2_p__46836$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2_p2_p__46836$$,3,null);var $x$jscomp$inline_4858$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($theta_to_p1$jscomp$1_y$jscomp$inline_4859$$)-
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($from_p1$jscomp$1_start$jscomp$inline_4865_transform$jscomp$37$$);$theta_to_p1$jscomp$1_y$jscomp$inline_4859$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($theta_to_p1$jscomp$1_y$jscomp$inline_4859$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($from_p1$jscomp$1_start$jscomp$inline_4865_transform$jscomp$37$$);$theta_to_p1$jscomp$1_y$jscomp$inline_4859$$=Math.atan2($x$jscomp$inline_4858$$,$theta_to_p1$jscomp$1_y$jscomp$inline_4859$$)*
180/Math.PI;$from_p1$jscomp$1_start$jscomp$inline_4865_transform$jscomp$37$$=$APP.$app$common$geom$matrix$translate$$($APP.$app$common$geom$matrix$rotate$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$(),-$theta_to_p1$jscomp$1_y$jscomp$inline_4859$$),$APP.$app$common$geom$point$negate$$($from_p1$jscomp$1_start$jscomp$inline_4865_transform$jscomp$37$$));$h1_p2_h2$jscomp$inline_4868_p__46792$jscomp$inline_4863$$=new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$transform$$($end$jscomp$inline_4866_from_p2$jscomp$1_p__46835$$,$from_p1$jscomp$1_start$jscomp$inline_4865_transform$jscomp$37$$),$APP.$app$common$geom$point$transform$$($h1$jscomp$inline_4867_to_p2$jscomp$1$$,$from_p1$jscomp$1_start$jscomp$inline_4865_transform$jscomp$37$$),$APP.$app$common$geom$point$transform$$($h1_p2_h2$jscomp$inline_4868_p__46792$jscomp$inline_4863$$,$from_p1$jscomp$1_start$jscomp$inline_4865_transform$jscomp$37$$),
$APP.$app$common$geom$point$transform$$($h2_p2_p__46836$$,$from_p1$jscomp$1_start$jscomp$inline_4865_transform$jscomp$37$$)],null);$from_p1$jscomp$1_start$jscomp$inline_4865_transform$jscomp$37$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h1_p2_h2$jscomp$inline_4868_p__46792$jscomp$inline_4863$$,0,null);$end$jscomp$inline_4866_from_p2$jscomp$1_p__46835$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h1_p2_h2$jscomp$inline_4868_p__46792$jscomp$inline_4863$$,1,null);$h1$jscomp$inline_4867_to_p2$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h1_p2_h2$jscomp$inline_4868_p__46792$jscomp$inline_4863$$,2,null);$h1_p2_h2$jscomp$inline_4868_p__46792$jscomp$inline_4863$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h1_p2_h2$jscomp$inline_4868_p__46792$jscomp$inline_4863$$,3,null);return $app$common$types$path$helpers$curve_roots$cljs$0core$0IFn$0_invoke$0arity$05$$($from_p1$jscomp$1_start$jscomp$inline_4865_transform$jscomp$37$$,$end$jscomp$inline_4866_from_p2$jscomp$1_p__46835$$,
$h1$jscomp$inline_4867_to_p2$jscomp$1$$,$h1_p2_h2$jscomp$inline_4868_p__46792$jscomp$inline_4863$$)};
$app$common$types$path$helpers$line_curve_intersect$$=function($l1$jscomp$2$$,$c2$jscomp$17$$){var $curve_ts$$=$APP.$cljs$core$filterv$$(function($curve_t_curve_t__$1$$){$curve_t_curve_t__$1$$=$APP.$app$common$math$almost_zero_QMARK_$$($curve_t_curve_t__$1$$)?0:$curve_t_curve_t__$1$$;var $curve_v_line_t$$=$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$($c2$jscomp$17$$,$curve_t_curve_t__$1$$);$curve_v_line_t$$=$app$common$types$path$helpers$get_line_tval$$($l1$jscomp$2$$,
$curve_v_line_t$$);return $curve_t_curve_t__$1$$>=0&&$curve_t_curve_t__$1$$<=1&&$curve_v_line_t$$>=0&&$curve_v_line_t$$<=1},$app$common$types$path$helpers$line_curve_crossing$$($l1$jscomp$2$$,$c2$jscomp$17$$)),$intersect_ps_line_ts$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__46848_SHARP_$$){return $app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$($c2$jscomp$17$$,$p1__46848_SHARP_$$)},$curve_ts$$);$intersect_ps_line_ts$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__46849_SHARP_$$){return $app$common$types$path$helpers$get_line_tval$$($l1$jscomp$2$$,
$p1__46849_SHARP_$$)},$intersect_ps_line_ts$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$intersect_ps_line_ts$$,$curve_ts$$],null)};
$app$common$types$path$helpers$ray_overlaps_QMARK_$$=function($ray_point$$,$map__46859__$1_p__46856_selrect$jscomp$4$$){$map__46859__$1_p__46856_selrect$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($map__46859__$1_p__46856_selrect$jscomp$4$$);$map__46859__$1_p__46856_selrect$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46859__$1_p__46856_selrect$jscomp$4$$,$APP.$cljs$cst$1605$selrect$$);return($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($ray_point$$)>$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($map__46859__$1_p__46856_selrect$jscomp$4$$)||
$APP.$app$common$math$almost_zero_QMARK_$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($ray_point$$)-$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($map__46859__$1_p__46856_selrect$jscomp$4$$)))&&($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($ray_point$$)<$APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($map__46859__$1_p__46856_selrect$jscomp$4$$)||$APP.$app$common$math$almost_zero_QMARK_$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($ray_point$$)-
$APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($map__46859__$1_p__46856_selrect$jscomp$4$$)))};
$app$common$types$path$helpers$ray_curve_intersect$$=function($ray_line$jscomp$1$$,$curve$jscomp$4$$){var $curve_ts$jscomp$1$$=$APP.$cljs$core$filterv$$(function($curve_tg_curve_tg_angle_p1__46879_SHARP_$$){var $curve_v$jscomp$1$$=$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$($curve$jscomp$4$$,$curve_tg_curve_tg_angle_p1__46879_SHARP_$$);$curve_tg_curve_tg_angle_p1__46879_SHARP_$$=$app$common$types$path$helpers$curve_tangent$$($curve$jscomp$4$$,$curve_tg_curve_tg_angle_p1__46879_SHARP_$$);
$curve_tg_curve_tg_angle_p1__46879_SHARP_$$=$APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$01$$($curve_tg_curve_tg_angle_p1__46879_SHARP_$$);return $app$common$types$path$helpers$get_line_tval$$($ray_line$jscomp$1$$,$curve_v$jscomp$1$$)>0&&$APP.$app$common$math$abs$$($curve_tg_curve_tg_angle_p1__46879_SHARP_$$-180)>.01&&$APP.$app$common$math$abs$$($curve_tg_curve_tg_angle_p1__46879_SHARP_$$-0)>.01},$app$common$types$path$helpers$line_curve_crossing$$($ray_line$jscomp$1$$,$curve$jscomp$4$$));
return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($JSCompiler_inline_result$jscomp$743_p1__46880_SHARP__tangent$jscomp$inline_4872$$){var $JSCompiler_temp_const$jscomp$742$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$JSCompiler_temp_const$jscomp$741$$=$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$($curve$jscomp$4$$,$JSCompiler_inline_result$jscomp$743_p1__46880_SHARP__tangent$jscomp$inline_4872$$);$JSCompiler_inline_result$jscomp$743_p1__46880_SHARP__tangent$jscomp$inline_4872$$=
$app$common$types$path$helpers$curve_tangent$$($curve$jscomp$4$$,$JSCompiler_inline_result$jscomp$743_p1__46880_SHARP__tangent$jscomp$inline_4872$$);$JSCompiler_inline_result$jscomp$743_p1__46880_SHARP__tangent$jscomp$inline_4872$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$743_p1__46880_SHARP__tangent$jscomp$inline_4872$$)>0?-1:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$743_p1__46880_SHARP__tangent$jscomp$inline_4872$$)<
0?1:0;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$742$$,[$JSCompiler_temp_const$jscomp$741$$,$JSCompiler_inline_result$jscomp$743_p1__46880_SHARP__tangent$jscomp$inline_4872$$],null)},$curve_ts$jscomp$1$$)};
$app$common$types$path$helpers$curve_curve_intersect$$=function($c1$jscomp$26$$,$c2$jscomp$18$$){function $remove_close_ts$$($map__46909__$1_p__46908$$){$map__46909__$1_p__46908$$=$APP.$cljs$core$__destructure_map$$($map__46909__$1_p__46908$$);var $cp1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46909__$1_p__46908$$,$APP.$cljs$cst$1093$p1$$),$cp2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46909__$1_p__46908$$,$APP.$cljs$cst$1091$p2$$);return function($p1$jscomp$47_p__46910$$){var $map__46911__$1_p2$jscomp$36$$=
$APP.$cljs$core$__destructure_map$$($p1$jscomp$47_p__46910$$);$p1$jscomp$47_p__46910$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46911__$1_p2$jscomp$36$$,$APP.$cljs$cst$1093$p1$$);$map__46911__$1_p2$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46911__$1_p2$jscomp$36$$,$APP.$cljs$cst$1091$p2$$);return $APP.$app$common$geom$point$distance$$($p1$jscomp$47_p__46910$$,$cp1$$)>=2&&$APP.$app$common$geom$point$distance$$($map__46911__$1_p2$jscomp$36$$,$cp2$$)>=
2}}return function($G__47106_pending$jscomp$5_pending__$1$jscomp$1_ts$jscomp$9$$){var $G__47105_current$jscomp$21$$=$APP.$cljs$core$first$$($G__47106_pending$jscomp$5_pending__$1$jscomp$1_ts$jscomp$9$$);$G__47106_pending$jscomp$5_pending__$1$jscomp$1_ts$jscomp$9$$=$APP.$cljs$core$rest$$($G__47106_pending$jscomp$5_pending__$1$jscomp$1_ts$jscomp$9$$);for(var $G__47107_c1_ts_c1_ts__$1$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$G__47108_c2_ts_c2_ts__$1$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){if($G__47105_current$jscomp$21$$==
null)return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__47107_c1_ts_c1_ts__$1$$,$G__47108_c2_ts_c2_ts__$1$$],null);$G__47106_pending$jscomp$5_pending__$1$jscomp$1_ts$jscomp$9$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($remove_close_ts$$($G__47105_current$jscomp$21$$),$G__47106_pending$jscomp$5_pending__$1$jscomp$1_ts$jscomp$9$$);$G__47107_c1_ts_c1_ts__$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__47107_c1_ts_c1_ts__$1$$,
$cljs$cst$1823$t1$$.$cljs$core$IFn$_invoke$arity$1$($G__47105_current$jscomp$21$$));$G__47108_c2_ts_c2_ts__$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__47108_c2_ts_c2_ts__$1$$,$cljs$cst$1824$t2$$.$cljs$core$IFn$_invoke$arity$1$($G__47105_current$jscomp$21$$));$G__47105_current$jscomp$21$$=$APP.$cljs$core$first$$($G__47106_pending$jscomp$5_pending__$1$jscomp$1_ts$jscomp$9$$);$G__47106_pending$jscomp$5_pending__$1$jscomp$1_ts$jscomp$9$$=$APP.$cljs$core$rest$$($G__47106_pending$jscomp$5_pending__$1$jscomp$1_ts$jscomp$9$$)}}($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1447$d$$,
function $app$common$types$path$helpers$curve_curve_intersect_$_check_range$$($c1_from_ts_2$$,$c1_to_ts_4$$,$c2_from_ts_3$$,$c2_to$$){var $p1$jscomp$46_r1$jscomp$13_ts_1$$=$app$common$types$path$helpers$curve_range__GT_rect$$($c1$jscomp$26$$,$c1_from_ts_2$$,$c1_to_ts_4$$),$c1_half_p2$jscomp$35_r2$jscomp$12$$=$app$common$types$path$helpers$curve_range__GT_rect$$($c2$jscomp$18$$,$c2_from_ts_3$$,$c2_to$$);if($APP.$app$common$geom$rect$overlaps_rects_QMARK_$$($p1$jscomp$46_r1$jscomp$13_ts_1$$,$c1_half_p2$jscomp$35_r2$jscomp$12$$)){$p1$jscomp$46_r1$jscomp$13_ts_1$$=
$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$($c1$jscomp$26$$,$c1_from_ts_2$$);$c1_half_p2$jscomp$35_r2$jscomp$12$$=$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$($c2$jscomp$18$$,$c2_from_ts_3$$);if($APP.$app$common$geom$point$distance$$($p1$jscomp$46_r1$jscomp$13_ts_1$$,$c1_half_p2$jscomp$35_r2$jscomp$12$$)<.1)return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$1093$p1$$,$p1$jscomp$46_r1$jscomp$13_ts_1$$,$APP.$cljs$cst$1091$p2$$,$c1_half_p2$jscomp$35_r2$jscomp$12$$,$cljs$cst$1447$d$$,$APP.$app$common$geom$point$distance$$($p1$jscomp$46_r1$jscomp$13_ts_1$$,$c1_half_p2$jscomp$35_r2$jscomp$12$$),$cljs$cst$1823$t1$$,$APP.$app$common$math$precision$$($c1_from_ts_2$$,4),$cljs$cst$1824$t2$$,$APP.$app$common$math$precision$$($c2_from_ts_3$$,4)],null)],null);$c1_half_p2$jscomp$35_r2$jscomp$12$$=$c1_from_ts_2$$+($c1_to_ts_4$$-$c1_from_ts_2$$)/2;
var $c2_half$$=$c2_from_ts_3$$+($c2_to$$-$c2_from_ts_3$$)/2;$p1$jscomp$46_r1$jscomp$13_ts_1$$=$app$common$types$path$helpers$curve_curve_intersect_$_check_range$$($c1_from_ts_2$$,$c1_half_p2$jscomp$35_r2$jscomp$12$$,$c2_from_ts_3$$,$c2_half$$);$c1_from_ts_2$$=$app$common$types$path$helpers$curve_curve_intersect_$_check_range$$($c1_from_ts_2$$,$c1_half_p2$jscomp$35_r2$jscomp$12$$,$c2_half$$,$c2_to$$);$c2_from_ts_3$$=$app$common$types$path$helpers$curve_curve_intersect_$_check_range$$($c1_half_p2$jscomp$35_r2$jscomp$12$$,
$c1_to_ts_4$$,$c2_from_ts_3$$,$c2_half$$);$c1_to_ts_4$$=$app$common$types$path$helpers$curve_curve_intersect_$_check_range$$($c1_half_p2$jscomp$35_r2$jscomp$12$$,$c1_to_ts_4$$,$c2_half$$,$c2_to$$);return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($p1$jscomp$46_r1$jscomp$13_ts_1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$c1_from_ts_2$$,$c2_from_ts_3$$,$c1_to_ts_4$$]))}return null}(0,1,0,1)))};
$app$common$types$path$helpers$is_point_in_geom_data_QMARK_$$=function($point$jscomp$19$$,$content_geom$$){var $ray_line$jscomp$2$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$point$jscomp$19$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$19$$)+1,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$19$$))],null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$){var $G__46920_JSCompiler_temp_const$jscomp$10764_ray_line$jscomp$inline_4878_ray_t$jscomp$inline_4882$$=$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$);
switch($G__46920_JSCompiler_temp_const$jscomp$10764_ray_line$jscomp$inline_4878_ray_t$jscomp$inline_4882$$ instanceof $APP.$cljs$core$Keyword$$?$G__46920_JSCompiler_temp_const$jscomp$10764_ray_line$jscomp$inline_4878_ray_t$jscomp$inline_4882$$.$fqn$:null){case "line-to":$JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$=$cljs$cst$1825$geom$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$);
var $JSCompiler_temp_const$jscomp$10762_a$jscomp$inline_4876_a__$1$jscomp$inline_4879$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$,0,null),$JSCompiler_temp_const$jscomp$10763_b$jscomp$inline_4877_b__$1$jscomp$inline_4880_vec__46872$jscomp$inline_4881$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$,
1,null);$G__46920_JSCompiler_temp_const$jscomp$10764_ray_line$jscomp$inline_4878_ray_t$jscomp$inline_4882$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$point$jscomp$19$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$19$$)+1,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$19$$))],null);var $JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$;
if($JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$=$JSCompiler_temp_const$jscomp$10762_a$jscomp$inline_4876_a__$1$jscomp$inline_4879$$!=null){$JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10762_a$jscomp$inline_4876_a__$1$jscomp$inline_4879$$);
var $ay$jscomp$inline_11903_b$jscomp$inline_11892_b$jscomp$inline_11895_to_p$jscomp$inline_11900$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$19$$);$JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$=$APP.$app$common$math$almost_zero_QMARK_$$($JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$-
$ay$jscomp$inline_11903_b$jscomp$inline_11892_b$jscomp$inline_11895_to_p$jscomp$inline_11900$$)}$JSCompiler_temp_const$jscomp$10762_a$jscomp$inline_4876_a__$1$jscomp$inline_4879$$=$JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp_const$jscomp$10762_a$jscomp$inline_4876_a__$1$jscomp$inline_4879$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_PLUS_$$,
10):$JSCompiler_temp_const$jscomp$10762_a$jscomp$inline_4876_a__$1$jscomp$inline_4879$$;if($JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$=$JSCompiler_temp_const$jscomp$10763_b$jscomp$inline_4877_b__$1$jscomp$inline_4880_vec__46872$jscomp$inline_4881$$!=null)$JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$=
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10763_b$jscomp$inline_4877_b__$1$jscomp$inline_4880_vec__46872$jscomp$inline_4881$$),$ay$jscomp$inline_11903_b$jscomp$inline_11892_b$jscomp$inline_11895_to_p$jscomp$inline_11900$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$19$$),$JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$=$APP.$app$common$math$almost_zero_QMARK_$$($JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$-
$ay$jscomp$inline_11903_b$jscomp$inline_11892_b$jscomp$inline_11895_to_p$jscomp$inline_11900$$);$JSCompiler_temp_const$jscomp$10763_b$jscomp$inline_4877_b__$1$jscomp$inline_4880_vec__46872$jscomp$inline_4881$$=$JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp_const$jscomp$10763_b$jscomp$inline_4877_b__$1$jscomp$inline_4880_vec__46872$jscomp$inline_4881$$,
$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_PLUS_$$,10):$JSCompiler_temp_const$jscomp$10763_b$jscomp$inline_4877_b__$1$jscomp$inline_4880_vec__46872$jscomp$inline_4881$$;$JSCompiler_temp_const$jscomp$10763_b$jscomp$inline_4877_b__$1$jscomp$inline_4880_vec__46872$jscomp$inline_4881$$=$app$common$types$path$helpers$line_line_crossing$$($G__46920_JSCompiler_temp_const$jscomp$10764_ray_line$jscomp$inline_4878_ray_t$jscomp$inline_4882$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$JSCompiler_temp_const$jscomp$10762_a$jscomp$inline_4876_a__$1$jscomp$inline_4879$$,$JSCompiler_temp_const$jscomp$10763_b$jscomp$inline_4877_b__$1$jscomp$inline_4880_vec__46872$jscomp$inline_4881$$],null));$G__46920_JSCompiler_temp_const$jscomp$10764_ray_line$jscomp$inline_4878_ray_t$jscomp$inline_4882$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$10763_b$jscomp$inline_4877_b__$1$jscomp$inline_4880_vec__46872$jscomp$inline_4881$$,0,null);var $line_t$jscomp$inline_4883$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$10763_b$jscomp$inline_4877_b__$1$jscomp$inline_4880_vec__46872$jscomp$inline_4881$$,1,null);$line_t$jscomp$inline_4883$$!=null&&$G__46920_JSCompiler_temp_const$jscomp$10764_ray_line$jscomp$inline_4878_ray_t$jscomp$inline_4882$$!=null&&$G__46920_JSCompiler_temp_const$jscomp$10764_ray_line$jscomp$inline_4878_ray_t$jscomp$inline_4882$$>0&&($line_t$jscomp$inline_4883$$>0||$APP.$app$common$math$almost_zero_QMARK_$$($line_t$jscomp$inline_4883$$-
0))&&($line_t$jscomp$inline_4883$$<1||$APP.$app$common$math$almost_zero_QMARK_$$($line_t$jscomp$inline_4883$$-1))?($JSCompiler_temp_const$jscomp$10763_b$jscomp$inline_4877_b__$1$jscomp$inline_4880_vec__46872$jscomp$inline_4881$$=$G__46920_JSCompiler_temp_const$jscomp$10764_ray_line$jscomp$inline_4878_ray_t$jscomp$inline_4882$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$JSCompiler_temp_const$jscomp$10762_a$jscomp$inline_4876_a__$1$jscomp$inline_4879$$=$app$common$types$path$helpers$line_values$$($JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$,
$line_t$jscomp$inline_4883$$),$JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$,0,null),$ay$jscomp$inline_11903_b$jscomp$inline_11892_b$jscomp$inline_11895_to_p$jscomp$inline_11900$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$,
1,null),$JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$=$app$common$types$path$helpers$line_values$$($JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$,$line_t$jscomp$inline_4883$$),$JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$),
$ay$jscomp$inline_11903_b$jscomp$inline_11892_b$jscomp$inline_11895_to_p$jscomp$inline_11900$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($ay$jscomp$inline_11903_b$jscomp$inline_11892_b$jscomp$inline_11895_to_p$jscomp$inline_11900$$),$JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$),
$JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$G__46920_JSCompiler_temp_const$jscomp$10764_ray_line$jscomp$inline_4878_ray_t$jscomp$inline_4882$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$10763_b$jscomp$inline_4877_b__$1$jscomp$inline_4880_vec__46872$jscomp$inline_4881$$,[$JSCompiler_temp_const$jscomp$10762_a$jscomp$inline_4876_a__$1$jscomp$inline_4879$$,
$JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$-$ay$jscomp$inline_11903_b$jscomp$inline_11892_b$jscomp$inline_11895_to_p$jscomp$inline_11900$$>0&&!$APP.$app$common$math$almost_zero_QMARK_$$($JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$-$ay$jscomp$inline_11903_b$jscomp$inline_11892_b$jscomp$inline_11895_to_p$jscomp$inline_11900$$)?1:$JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$-
$ay$jscomp$inline_11903_b$jscomp$inline_11892_b$jscomp$inline_11895_to_p$jscomp$inline_11900$$<0&&!$APP.$app$common$math$almost_zero_QMARK_$$($JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$-$ay$jscomp$inline_11903_b$jscomp$inline_11892_b$jscomp$inline_11895_to_p$jscomp$inline_11900$$)?-1:$JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$-$JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$<
0?1:$JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$-$JSCompiler_temp$jscomp$10759_JSCompiler_temp$jscomp$10760_a$jscomp$inline_11891_a$jscomp$inline_11894_by$jscomp$inline_11904_from_p$jscomp$inline_11899$$>0?-1:0],null)],null)):$JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$=null;return $JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$;
case "curve-to":return $app$common$types$path$helpers$ray_curve_intersect$$($ray_line$jscomp$2$$,$cljs$cst$1825$geom$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10761_cy$jscomp$inline_11902_data$jscomp$131_p$jscomp$inline_11901_p__46867$jscomp$inline_4875$$));default:return $APP.$cljs$core$PersistentVector$EMPTY$$}},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$path$helpers$ray_overlaps_QMARK_$$,
$point$jscomp$19$$),$content_geom$$)])))))};
$app$common$types$path$helpers$is_point_in_border_QMARK_$$=function($point$jscomp$20$$,$content$jscomp$23$$){return $APP.$cljs$core$some$$(function($JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$){var $G__46926_and__5023__auto__$jscomp$inline_4887$$=$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$);switch($G__46926_and__5023__auto__$jscomp$inline_4887$$ instanceof
$APP.$cljs$core$Keyword$$?$G__46926_and__5023__auto__$jscomp$inline_4887$$.$fqn$:null){case "line-to":return $JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$=$app$common$types$path$helpers$command__GT_line$cljs$0core$0IFn$0_invoke$0arity$01$$($JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$),($G__46926_and__5023__auto__$jscomp$inline_4887$$=$app$common$types$path$helpers$line_has_point_QMARK_$$($point$jscomp$20$$,
$JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$))?($JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$=$app$common$types$path$helpers$get_line_tval$$($JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$,$point$jscomp$20$$),$JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$=($JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$>
0||$APP.$app$common$math$almost_zero_QMARK_$$($JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$-0))&&($JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$<1||$APP.$app$common$math$almost_zero_QMARK_$$($JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$-1))):$JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$=
$G__46926_and__5023__auto__$jscomp$inline_4887$$,$JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$;case "curve-to":return $app$common$types$path$helpers$curve_has_point_QMARK_$$($point$jscomp$20$$,$app$common$types$path$helpers$command__GT_bezier$cljs$0core$0IFn$0_invoke$0arity$01$$($JSCompiler_inline_result$jscomp$749_line$jscomp$inline_4886_segment$jscomp$11_t$jscomp$inline_4888$$));default:return!1}},$content$jscomp$23$$)};
$app$common$schema$openapi$minmax_properties$$=function($m$jscomp$198$$,$schema$jscomp$210$$,$kmin$$,$kmax$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$m$jscomp$198$$,$APP.$clojure$set$rename_keys$$($APP.$cljs$core$select_keys$$($APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$210$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$338$min$$,
$APP.$cljs$cst$339$max$$],null)),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,$kmin$$,$APP.$cljs$cst$339$max$$,$kmax$$],null))]))};
$app$common$schema$openapi$unlift_keys$$=function($m$jscomp$199$$){return $APP.$cljs$core$reduce_kv$$(function($p1__46457_SHARP_$$,$p2__46456_SHARP_$$,$p3__46458_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$name$$($cljs$cst$1849$app_DOT_common_DOT_openapi$$),$APP.$cljs$core$namespace$$($p2__46456_SHARP_$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__46457_SHARP_$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($cuerdas$core$camel$$($APP.$cljs$core$name$$($p2__46456_SHARP_$$))),
$p3__46458_SHARP_$$):$p1__46457_SHARP_$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$m$jscomp$199$$)};
$app$common$schema$openapi$transform_STAR_$$=function($s$jscomp$521$$,$options$jscomp$438$$){return $malli$core$walk$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$521$$,function($schema$jscomp$228$$,$_$jscomp$1145_p$jscomp$200$$,$children$jscomp$160$$,$options__$1$jscomp$63$$){$_$jscomp$1145_p$jscomp$200$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$core$type_properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$228$$),$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$228$$)]));
return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$select_keys$$($_$jscomp$1145_p$jscomp$200$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$939$title$$,$APP.$cljs$cst$936$description$$,$APP.$cljs$cst$205$default$$],null)),$app$common$schema$openapi$visit$$.$cljs$core$IFn$_invoke$arity$4$($APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$228$$),
$schema$jscomp$228$$,$children$jscomp$160$$,$options__$1$jscomp$63$$),$app$common$schema$openapi$unlift_keys$$($_$jscomp$1145_p$jscomp$200$$)]))},$options$jscomp$438$$)};$validCommand$$module$app$common$svg$path$parser$$=function($c$jscomp$273$$){switch($c$jscomp$273$$){case "Z":case "M":case "L":case "C":case "Q":case "A":case "H":case "V":case "S":case "T":case "z":case "m":case "l":case "c":case "q":case "a":case "h":case "v":case "s":case "t":return!0;default:return!1}};
$JSCompiler_StaticMethods__skipOptionalSpaces$$=function($JSCompiler_StaticMethods__skipOptionalSpaces$self$$){for(;$JSCompiler_StaticMethods__skipOptionalSpaces$self$$.$_currentIndex$<$JSCompiler_StaticMethods__skipOptionalSpaces$self$$.$_endIndex$&&$JSCompiler_StaticMethods__isCurrentSpace$$($JSCompiler_StaticMethods__skipOptionalSpaces$self$$);)$JSCompiler_StaticMethods__skipOptionalSpaces$self$$.$_currentIndex$+=1;return $JSCompiler_StaticMethods__skipOptionalSpaces$self$$.$_currentIndex$<$JSCompiler_StaticMethods__skipOptionalSpaces$self$$.$_endIndex$};
$JSCompiler_StaticMethods__parseNumber$$=function($JSCompiler_StaticMethods__parseNumber$self$$){var $exponent$$=0,$integer$jscomp$1_number$jscomp$1$$=0,$frac$$=1,$decimal$$=0,$sign$jscomp$9$$=1,$expsign$$=1,$startIndex$jscomp$2$$=$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$;$JSCompiler_StaticMethods__skipOptionalSpaces$$($JSCompiler_StaticMethods__parseNumber$self$$);$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$<$JSCompiler_StaticMethods__parseNumber$self$$.$_endIndex$&&
$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]==="+"?$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$+=1:$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$<$JSCompiler_StaticMethods__parseNumber$self$$.$_endIndex$&&$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]==="-"&&($JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$+=
1,$sign$jscomp$9$$=-1);if($JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$===$JSCompiler_StaticMethods__parseNumber$self$$.$_endIndex$||($JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]<"0"||$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]>"9")&&$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]!==
".")return null;for(var $startIntPartIndex$$=$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$;$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$<$JSCompiler_StaticMethods__parseNumber$self$$.$_endIndex$&&$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]>="0"&&$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]<="9";)$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$+=
1;if($JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$!==$startIntPartIndex$$)for(var $scanIntPartIndex$$=$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$-1,$multiplier$$=1;$scanIntPartIndex$$>=$startIntPartIndex$$;)$integer$jscomp$1_number$jscomp$1$$+=$multiplier$$*($JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$scanIntPartIndex$$]-0),--$scanIntPartIndex$$,$multiplier$$*=10;if($JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$<$JSCompiler_StaticMethods__parseNumber$self$$.$_endIndex$&&
$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]==="."){$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$+=1;if($JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$>=$JSCompiler_StaticMethods__parseNumber$self$$.$_endIndex$||$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]<"0"||$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]>
"9")return null;for(;$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$<$JSCompiler_StaticMethods__parseNumber$self$$.$_endIndex$&&$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]>="0"&&$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]<="9";)$frac$$*=10,$decimal$$+=($JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]-
0)/$frac$$,$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$+=1}if($JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$!==$startIndex$jscomp$2$$&&$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$+1<$JSCompiler_StaticMethods__parseNumber$self$$.$_endIndex$&&($JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]==="e"||$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]===
"E")&&$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$+1]!=="x"&&$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$+1]!=="m"){$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$+=1;$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]==="+"?$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$+=
1:$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]==="-"&&($JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$+=1,$expsign$$=-1);if($JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$>=$JSCompiler_StaticMethods__parseNumber$self$$.$_endIndex$||$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]<"0"||$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]>
"9")return null;for(;$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$<$JSCompiler_StaticMethods__parseNumber$self$$.$_endIndex$&&$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]>="0"&&$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]<="9";)$exponent$$*=10,$exponent$$+=$JSCompiler_StaticMethods__parseNumber$self$$.$_string$[$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$]-
0,$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$+=1}$integer$jscomp$1_number$jscomp$1$$=($integer$jscomp$1_number$jscomp$1$$+$decimal$$)*$sign$jscomp$9$$;$exponent$$&&($integer$jscomp$1_number$jscomp$1$$*=Math.pow(10,$expsign$$*$exponent$$));if($startIndex$jscomp$2$$===$JSCompiler_StaticMethods__parseNumber$self$$.$_currentIndex$)return null;$JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$$($JSCompiler_StaticMethods__parseNumber$self$$);return $integer$jscomp$1_number$jscomp$1$$};
$JSCompiler_StaticMethods__parseArcFlag$$=function($JSCompiler_StaticMethods__parseArcFlag$self$$){if($JSCompiler_StaticMethods__parseArcFlag$self$$.$_currentIndex$>=$JSCompiler_StaticMethods__parseArcFlag$self$$.$_endIndex$)return null;var $flag$jscomp$4_flagChar$$=$JSCompiler_StaticMethods__parseArcFlag$self$$.$_string$[$JSCompiler_StaticMethods__parseArcFlag$self$$.$_currentIndex$];$JSCompiler_StaticMethods__parseArcFlag$self$$.$_currentIndex$+=1;if($flag$jscomp$4_flagChar$$==="0")$flag$jscomp$4_flagChar$$=
0;else if($flag$jscomp$4_flagChar$$==="1")$flag$jscomp$4_flagChar$$=1;else return null;$JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$$($JSCompiler_StaticMethods__parseArcFlag$self$$);return $flag$jscomp$4_flagChar$$};
$JSCompiler_StaticMethods__isCurrentSpace$$=function($JSCompiler_StaticMethods__isCurrentSpace$self_ch$jscomp$66$$){$JSCompiler_StaticMethods__isCurrentSpace$self_ch$jscomp$66$$=$JSCompiler_StaticMethods__isCurrentSpace$self_ch$jscomp$66$$.$_string$[$JSCompiler_StaticMethods__isCurrentSpace$self_ch$jscomp$66$$.$_currentIndex$];return $JSCompiler_StaticMethods__isCurrentSpace$self_ch$jscomp$66$$<=" "&&($JSCompiler_StaticMethods__isCurrentSpace$self_ch$jscomp$66$$===" "||$JSCompiler_StaticMethods__isCurrentSpace$self_ch$jscomp$66$$===
"\n"||$JSCompiler_StaticMethods__isCurrentSpace$self_ch$jscomp$66$$==="\t"||$JSCompiler_StaticMethods__isCurrentSpace$self_ch$jscomp$66$$==="\r"||$JSCompiler_StaticMethods__isCurrentSpace$self_ch$jscomp$66$$==="\f")};
$JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$$=function($JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$self$$){$JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$self$$.$_currentIndex$<$JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$self$$.$_endIndex$&&!$JSCompiler_StaticMethods__isCurrentSpace$$($JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$self$$)&&$JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$self$$.$_string$[$JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$self$$.$_currentIndex$]!==
","||!($JSCompiler_StaticMethods__skipOptionalSpaces$$($JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$self$$)&&$JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$self$$.$_currentIndex$<$JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$self$$.$_endIndex$)||$JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$self$$.$_string$[$JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$self$$.$_currentIndex$]!==","||($JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$self$$.$_currentIndex$+=
1,$JSCompiler_StaticMethods__skipOptionalSpaces$$($JSCompiler_StaticMethods__skipOptionalSpacesOrDelimiter$self$$))};$unitVectorAngle$$module$app$common$svg$path$parser$$=function($ux$$,$uy$$,$vx$$,$vy$jscomp$1$$){let $dot$$=$ux$$*$vx$$+$uy$$*$vy$jscomp$1$$;return($ux$$*$vy$jscomp$1$$-$uy$$*$vx$$<0?-1:1)*Math.acos($dot$$>1?1:$dot$$<-1?-1:$dot$$)};
$arcToBeziers$$module$app$common$svg$path$parser$$=function($cx$jscomp$7_x1$jscomp$24$$,$cy$jscomp$8_y1$jscomp$26$$,$theta1$jscomp$2_x2$jscomp$22$$,$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$,$cxp$jscomp$inline_4922_fa$jscomp$1_i$jscomp$485$$,$fs$jscomp$7_result$jscomp$177$$,$rx$jscomp$8$$,$ry$jscomp$2$$,$phi$jscomp$1_sinPhi$jscomp$2$$){var $segments$jscomp$3_tau$$=Math.PI*2,$cosPhi$jscomp$2_phiTau$$=$phi$jscomp$1_sinPhi$jscomp$2$$*$segments$jscomp$3_tau$$/360;$phi$jscomp$1_sinPhi$jscomp$2$$=
Math.sin($cosPhi$jscomp$2_phiTau$$);$cosPhi$jscomp$2_phiTau$$=Math.cos($cosPhi$jscomp$2_phiTau$$);var $alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$=$cosPhi$jscomp$2_phiTau$$*($cx$jscomp$7_x1$jscomp$24$$-$theta1$jscomp$2_x2$jscomp$22$$)/2+$phi$jscomp$1_sinPhi$jscomp$2$$*($cy$jscomp$8_y1$jscomp$26$$-$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$)/2,$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$=
-$phi$jscomp$1_sinPhi$jscomp$2$$*($cx$jscomp$7_x1$jscomp$24$$-$theta1$jscomp$2_x2$jscomp$22$$)/2+$cosPhi$jscomp$2_phiTau$$*($cy$jscomp$8_y1$jscomp$26$$-$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$)/2;if($alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$===0&&$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$===0||$rx$jscomp$8$$===0||$ry$jscomp$2$$===0)return[];$rx$jscomp$8$$=Math.abs($rx$jscomp$8$$);
$ry$jscomp$2$$=Math.abs($ry$jscomp$2$$);$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$=$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$*$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$/($rx$jscomp$8$$*$rx$jscomp$8$$)+$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$*$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$/
($ry$jscomp$2$$*$ry$jscomp$2$$);$rx$jscomp$8$$=$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$>1?$rx$jscomp$8$$*Math.sqrt($alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$):$rx$jscomp$8$$;$ry$jscomp$2$$=$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$>1?$ry$jscomp$2$$*Math.sqrt($alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$):
$ry$jscomp$2$$;$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$=($cx$jscomp$7_x1$jscomp$24$$-$theta1$jscomp$2_x2$jscomp$22$$)/2*$cosPhi$jscomp$2_phiTau$$+($cy$jscomp$8_y1$jscomp$26$$-$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$)/2*$phi$jscomp$1_sinPhi$jscomp$2$$;$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$=($cx$jscomp$7_x1$jscomp$24$$-$theta1$jscomp$2_x2$jscomp$22$$)/2*-$phi$jscomp$1_sinPhi$jscomp$2$$+
($cy$jscomp$8_y1$jscomp$26$$-$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$)/2*$cosPhi$jscomp$2_phiTau$$;var $rxSq$jscomp$inline_4917_theta1$jscomp$inline_4928_x1$jscomp$inline_4948_x2$jscomp$inline_4936$$=$rx$jscomp$8$$*$rx$jscomp$8$$,$rySq$jscomp$inline_4918_v1x$jscomp$inline_4926_y1$jscomp$inline_4949_y2$jscomp$inline_4937$$=$ry$jscomp$2$$*$ry$jscomp$2$$,$v1y$jscomp$inline_4927_x1pSq$jscomp$inline_4919_x2$jscomp$inline_4950$$=$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$*
$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$,$y1pSq$jscomp$inline_4920_y2$jscomp$inline_4951$$=$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$*$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$,$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$=$rxSq$jscomp$inline_4917_theta1$jscomp$inline_4928_x1$jscomp$inline_4948_x2$jscomp$inline_4936$$*
$rySq$jscomp$inline_4918_v1x$jscomp$inline_4926_y1$jscomp$inline_4949_y2$jscomp$inline_4937$$-$rxSq$jscomp$inline_4917_theta1$jscomp$inline_4928_x1$jscomp$inline_4948_x2$jscomp$inline_4936$$*$y1pSq$jscomp$inline_4920_y2$jscomp$inline_4951$$-$rySq$jscomp$inline_4918_v1x$jscomp$inline_4926_y1$jscomp$inline_4949_y2$jscomp$inline_4937$$*$v1y$jscomp$inline_4927_x1pSq$jscomp$inline_4919_x2$jscomp$inline_4950$$;$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$=
Math.sqrt(($cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$<0?0:$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$)/($rxSq$jscomp$inline_4917_theta1$jscomp$inline_4928_x1$jscomp$inline_4948_x2$jscomp$inline_4936$$*$y1pSq$jscomp$inline_4920_y2$jscomp$inline_4951$$+$rySq$jscomp$inline_4918_v1x$jscomp$inline_4926_y1$jscomp$inline_4949_y2$jscomp$inline_4937$$*$v1y$jscomp$inline_4927_x1pSq$jscomp$inline_4919_x2$jscomp$inline_4950$$))*
($cxp$jscomp$inline_4922_fa$jscomp$1_i$jscomp$485$$===$fs$jscomp$7_result$jscomp$177$$?-1:1);$cxp$jscomp$inline_4922_fa$jscomp$1_i$jscomp$485$$=$rx$jscomp$8$$/$ry$jscomp$2$$*$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$*$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$;$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$=-$ry$jscomp$2$$/$rx$jscomp$8$$*$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$*
$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$;$rySq$jscomp$inline_4918_v1x$jscomp$inline_4926_y1$jscomp$inline_4949_y2$jscomp$inline_4937$$=($alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$-$cxp$jscomp$inline_4922_fa$jscomp$1_i$jscomp$485$$)/$rx$jscomp$8$$;$v1y$jscomp$inline_4927_x1pSq$jscomp$inline_4919_x2$jscomp$inline_4950$$=($x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$-
$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$)/$ry$jscomp$2$$;$rxSq$jscomp$inline_4917_theta1$jscomp$inline_4928_x1$jscomp$inline_4948_x2$jscomp$inline_4936$$=$unitVectorAngle$$module$app$common$svg$path$parser$$(1,0,$rySq$jscomp$inline_4918_v1x$jscomp$inline_4926_y1$jscomp$inline_4949_y2$jscomp$inline_4937$$,$v1y$jscomp$inline_4927_x1pSq$jscomp$inline_4919_x2$jscomp$inline_4950$$);$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$=
$unitVectorAngle$$module$app$common$svg$path$parser$$($rySq$jscomp$inline_4918_v1x$jscomp$inline_4926_y1$jscomp$inline_4949_y2$jscomp$inline_4937$$,$v1y$jscomp$inline_4927_x1pSq$jscomp$inline_4919_x2$jscomp$inline_4950$$,(-$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$-$cxp$jscomp$inline_4922_fa$jscomp$1_i$jscomp$485$$)/$rx$jscomp$8$$,(-$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$-$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$)/
$ry$jscomp$2$$);$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$=$fs$jscomp$7_result$jscomp$177$$===0&&$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$>0?$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$-Math.PI*2:$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$;
$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$=$fs$jscomp$7_result$jscomp$177$$===1&&$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$<0?$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$+Math.PI*2:$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$;$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$=
[$cosPhi$jscomp$2_phiTau$$*$cxp$jscomp$inline_4922_fa$jscomp$1_i$jscomp$485$$-$phi$jscomp$1_sinPhi$jscomp$2$$*$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$+($cx$jscomp$7_x1$jscomp$24$$+$theta1$jscomp$2_x2$jscomp$22$$)/2,$phi$jscomp$1_sinPhi$jscomp$2$$*$cxp$jscomp$inline_4922_fa$jscomp$1_i$jscomp$485$$+$cosPhi$jscomp$2_phiTau$$*$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$+($cy$jscomp$8_y1$jscomp$26$$+
$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$)/2,$rxSq$jscomp$inline_4917_theta1$jscomp$inline_4928_x1$jscomp$inline_4948_x2$jscomp$inline_4936$$,$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$];$cx$jscomp$7_x1$jscomp$24$$=$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$[0];$cy$jscomp$8_y1$jscomp$26$$=$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$[1];$theta1$jscomp$2_x2$jscomp$22$$=
$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$[2];$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$=$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$[3];$segments$jscomp$3_tau$$=Math.max(Math.ceil(Math.abs($JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$)/($segments$jscomp$3_tau$$/4)),1);$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$/=$segments$jscomp$3_tau$$;$fs$jscomp$7_result$jscomp$177$$=[];for($cxp$jscomp$inline_4922_fa$jscomp$1_i$jscomp$485$$=
0;$cxp$jscomp$inline_4922_fa$jscomp$1_i$jscomp$485$$<$segments$jscomp$3_tau$$;$cxp$jscomp$inline_4922_fa$jscomp$1_i$jscomp$485$$++){$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$=4/3*Math.tan($JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$/4);$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$=Math.cos($theta1$jscomp$2_x2$jscomp$22$$);$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$=
Math.sin($theta1$jscomp$2_x2$jscomp$22$$);$rxSq$jscomp$inline_4917_theta1$jscomp$inline_4928_x1$jscomp$inline_4948_x2$jscomp$inline_4936$$=Math.cos($theta1$jscomp$2_x2$jscomp$22$$+$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$);$rySq$jscomp$inline_4918_v1x$jscomp$inline_4926_y1$jscomp$inline_4949_y2$jscomp$inline_4937$$=Math.sin($theta1$jscomp$2_x2$jscomp$22$$+$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$);$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$=
[$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$,$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$,$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$-$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$*$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$,$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$+
$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$*$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$,$rxSq$jscomp$inline_4917_theta1$jscomp$inline_4928_x1$jscomp$inline_4948_x2$jscomp$inline_4936$$+$rySq$jscomp$inline_4918_v1x$jscomp$inline_4926_y1$jscomp$inline_4949_y2$jscomp$inline_4937$$*$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$,$rySq$jscomp$inline_4918_v1x$jscomp$inline_4926_y1$jscomp$inline_4949_y2$jscomp$inline_4937$$-
$rxSq$jscomp$inline_4917_theta1$jscomp$inline_4928_x1$jscomp$inline_4948_x2$jscomp$inline_4936$$*$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$,$rxSq$jscomp$inline_4917_theta1$jscomp$inline_4928_x1$jscomp$inline_4948_x2$jscomp$inline_4936$$,$rySq$jscomp$inline_4918_v1x$jscomp$inline_4926_y1$jscomp$inline_4949_y2$jscomp$inline_4937$$];$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$=$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[0]*
$rx$jscomp$8$$;$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$=$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[1]*$ry$jscomp$2$$;$rxSq$jscomp$inline_4917_theta1$jscomp$inline_4928_x1$jscomp$inline_4948_x2$jscomp$inline_4936$$=$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[2]*$rx$jscomp$8$$;$rySq$jscomp$inline_4918_v1x$jscomp$inline_4926_y1$jscomp$inline_4949_y2$jscomp$inline_4937$$=
$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[3]*$ry$jscomp$2$$;$v1y$jscomp$inline_4927_x1pSq$jscomp$inline_4919_x2$jscomp$inline_4950$$=$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[4]*$rx$jscomp$8$$;$y1pSq$jscomp$inline_4920_y2$jscomp$inline_4951$$=$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[5]*$ry$jscomp$2$$;
const $x3$jscomp$inline_4952$$=$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[6]*$rx$jscomp$8$$,$y3$jscomp$inline_4953$$=$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[7]*$ry$jscomp$2$$;$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[0]=$cx$jscomp$7_x1$jscomp$24$$+($cosPhi$jscomp$2_phiTau$$*$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$-
$phi$jscomp$1_sinPhi$jscomp$2$$*$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$);$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[1]=$cy$jscomp$8_y1$jscomp$26$$+($phi$jscomp$1_sinPhi$jscomp$2$$*$x0$jscomp$inline_4946_x1$jscomp$inline_4934_y1p$jscomp$1_y1p$jscomp$inline_4916$$+$cosPhi$jscomp$2_phiTau$$*$cyp$jscomp$inline_4923_radicant$jscomp$inline_4921_y0$jscomp$inline_4947_y1$jscomp$inline_4935$$);
$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[2]=$cx$jscomp$7_x1$jscomp$24$$+($cosPhi$jscomp$2_phiTau$$*$rxSq$jscomp$inline_4917_theta1$jscomp$inline_4928_x1$jscomp$inline_4948_x2$jscomp$inline_4936$$-$phi$jscomp$1_sinPhi$jscomp$2$$*$rySq$jscomp$inline_4918_v1x$jscomp$inline_4926_y1$jscomp$inline_4949_y2$jscomp$inline_4937$$);$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[3]=
$cy$jscomp$8_y1$jscomp$26$$+($phi$jscomp$1_sinPhi$jscomp$2$$*$rxSq$jscomp$inline_4917_theta1$jscomp$inline_4928_x1$jscomp$inline_4948_x2$jscomp$inline_4936$$+$cosPhi$jscomp$2_phiTau$$*$rySq$jscomp$inline_4918_v1x$jscomp$inline_4926_y1$jscomp$inline_4949_y2$jscomp$inline_4937$$);$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[4]=$cx$jscomp$7_x1$jscomp$24$$+($cosPhi$jscomp$2_phiTau$$*$v1y$jscomp$inline_4927_x1pSq$jscomp$inline_4919_x2$jscomp$inline_4950$$-
$phi$jscomp$1_sinPhi$jscomp$2$$*$y1pSq$jscomp$inline_4920_y2$jscomp$inline_4951$$);$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[5]=$cy$jscomp$8_y1$jscomp$26$$+($phi$jscomp$1_sinPhi$jscomp$2$$*$v1y$jscomp$inline_4927_x1pSq$jscomp$inline_4919_x2$jscomp$inline_4950$$+$cosPhi$jscomp$2_phiTau$$*$y1pSq$jscomp$inline_4920_y2$jscomp$inline_4951$$);$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[6]=
$cx$jscomp$7_x1$jscomp$24$$+($cosPhi$jscomp$2_phiTau$$*$x3$jscomp$inline_4952$$-$phi$jscomp$1_sinPhi$jscomp$2$$*$y3$jscomp$inline_4953$$);$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$[7]=$cy$jscomp$8_y1$jscomp$26$$+($phi$jscomp$1_sinPhi$jscomp$2$$*$x3$jscomp$inline_4952$$+$cosPhi$jscomp$2_phiTau$$*$y3$jscomp$inline_4953$$);$fs$jscomp$7_result$jscomp$177$$.push(new $Segment$$module$app$common$svg$path$parser$$("C",$alpha$jscomp$inline_4933_curve$jscomp$6_dtheta$jscomp$inline_4929_lambda_x1p$jscomp$1_x1p$jscomp$inline_4915$$.slice(2)));
$theta1$jscomp$2_x2$jscomp$22$$+=$JSCompiler_inline_result$jscomp$763_dtheta$jscomp$2_y2$jscomp$24$$}return $fs$jscomp$7_result$jscomp$177$$};$APP.$app$common$svg$path$parse$$=function($path_str$$){return $APP.$cljs$core$empty_QMARK_$$($path_str$$)?$path_str$$:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($segment$jscomp$14$$){return $segment$jscomp$14$$.toPersistentMap()}),$module$app$common$svg$path$parser$$.parse($path_str$$))};
$app$common$types$path$impl$normalize_coord$$=function($v$jscomp$519$$){return $v$jscomp$519$$>2147483647?2147483647:$v$jscomp$519$$<-2147483648?-2147483648:$v$jscomp$519$$};
$app$common$types$path$impl$_write_to$$=function($_$jscomp$1147$$,$buffer$jscomp$44$$){if($_$jscomp$1147$$!=null&&$_$jscomp$1147$$.$app$common$types$path$impl$IPathData$_write_to$arity$3$!=null)$_$jscomp$1147$$.$app$common$types$path$impl$IPathData$_write_to$arity$3$($_$jscomp$1147$$,$buffer$jscomp$44$$,0);else{var $m__5372__auto__$jscomp$inline_5009_m__5374__auto__$jscomp$inline_5008$$=$app$common$types$path$impl$_write_to$$[$APP.$goog$typeOf$$($_$jscomp$1147$$==null?null:$_$jscomp$1147$$)];if($m__5372__auto__$jscomp$inline_5009_m__5374__auto__$jscomp$inline_5008$$!=
null)$m__5372__auto__$jscomp$inline_5009_m__5374__auto__$jscomp$inline_5008$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_5009_m__5374__auto__$jscomp$inline_5008$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$1147$$,$buffer$jscomp$44$$,0):$m__5372__auto__$jscomp$inline_5009_m__5374__auto__$jscomp$inline_5008$$($_$jscomp$1147$$,$buffer$jscomp$44$$,0);else if($m__5372__auto__$jscomp$inline_5009_m__5374__auto__$jscomp$inline_5008$$=$app$common$types$path$impl$_write_to$$._,$m__5372__auto__$jscomp$inline_5009_m__5374__auto__$jscomp$inline_5008$$!=
null)$m__5372__auto__$jscomp$inline_5009_m__5374__auto__$jscomp$inline_5008$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_5009_m__5374__auto__$jscomp$inline_5008$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$1147$$,$buffer$jscomp$44$$,0):$m__5372__auto__$jscomp$inline_5009_m__5374__auto__$jscomp$inline_5008$$($_$jscomp$1147$$,$buffer$jscomp$44$$,0);else throw $APP.$cljs$core$missing_protocol$$("IPathData.-write-to",$_$jscomp$1147$$);}};
$app$common$types$path$impl$_get_byte_size$$=function($JSCompiler_temp$jscomp$766__$jscomp$1149$$){if($JSCompiler_temp$jscomp$766__$jscomp$1149$$!=null&&$JSCompiler_temp$jscomp$766__$jscomp$1149$$.$app$common$types$path$impl$IPathData$_get_byte_size$arity$1$!=null)$JSCompiler_temp$jscomp$766__$jscomp$1149$$=$JSCompiler_temp$jscomp$766__$jscomp$1149$$.buffer.byteLength;else{var $m__5372__auto__$jscomp$inline_5013_m__5374__auto__$jscomp$inline_5012$$=$app$common$types$path$impl$_get_byte_size$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$766__$jscomp$1149$$==
null?null:$JSCompiler_temp$jscomp$766__$jscomp$1149$$)];if($m__5372__auto__$jscomp$inline_5013_m__5374__auto__$jscomp$inline_5012$$!=null)$JSCompiler_temp$jscomp$766__$jscomp$1149$$=$m__5372__auto__$jscomp$inline_5013_m__5374__auto__$jscomp$inline_5012$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5013_m__5374__auto__$jscomp$inline_5012$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$766__$jscomp$1149$$):$m__5372__auto__$jscomp$inline_5013_m__5374__auto__$jscomp$inline_5012$$($JSCompiler_temp$jscomp$766__$jscomp$1149$$);
else if($m__5372__auto__$jscomp$inline_5013_m__5374__auto__$jscomp$inline_5012$$=$app$common$types$path$impl$_get_byte_size$$._,$m__5372__auto__$jscomp$inline_5013_m__5374__auto__$jscomp$inline_5012$$!=null)$JSCompiler_temp$jscomp$766__$jscomp$1149$$=$m__5372__auto__$jscomp$inline_5013_m__5374__auto__$jscomp$inline_5012$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5013_m__5374__auto__$jscomp$inline_5012$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$766__$jscomp$1149$$):
$m__5372__auto__$jscomp$inline_5013_m__5374__auto__$jscomp$inline_5012$$($JSCompiler_temp$jscomp$766__$jscomp$1149$$);else throw $APP.$cljs$core$missing_protocol$$("IPathData.-get-byte-size",$JSCompiler_temp$jscomp$766__$jscomp$1149$$);}return $JSCompiler_temp$jscomp$766__$jscomp$1149$$};
$app$common$types$path$impl$_transform$$=function($JSCompiler_temp$jscomp$767__$jscomp$1151$$,$m$jscomp$201$$){if($JSCompiler_temp$jscomp$767__$jscomp$1151$$!=null&&$JSCompiler_temp$jscomp$767__$jscomp$1151$$.$app$common$types$path$impl$ITransformable$_transform$arity$2$!=null)$JSCompiler_temp$jscomp$767__$jscomp$1151$$=$JSCompiler_temp$jscomp$767__$jscomp$1151$$.$app$common$types$path$impl$ITransformable$_transform$arity$2$($JSCompiler_temp$jscomp$767__$jscomp$1151$$,$m$jscomp$201$$);else{var $m__5372__auto__$jscomp$inline_5018_m__5374__auto__$jscomp$inline_5017$$=
$app$common$types$path$impl$_transform$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$767__$jscomp$1151$$==null?null:$JSCompiler_temp$jscomp$767__$jscomp$1151$$)];if($m__5372__auto__$jscomp$inline_5018_m__5374__auto__$jscomp$inline_5017$$!=null)$JSCompiler_temp$jscomp$767__$jscomp$1151$$=$m__5372__auto__$jscomp$inline_5018_m__5374__auto__$jscomp$inline_5017$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5018_m__5374__auto__$jscomp$inline_5017$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$767__$jscomp$1151$$,
$m$jscomp$201$$):$m__5372__auto__$jscomp$inline_5018_m__5374__auto__$jscomp$inline_5017$$($JSCompiler_temp$jscomp$767__$jscomp$1151$$,$m$jscomp$201$$);else if($m__5372__auto__$jscomp$inline_5018_m__5374__auto__$jscomp$inline_5017$$=$app$common$types$path$impl$_transform$$._,$m__5372__auto__$jscomp$inline_5018_m__5374__auto__$jscomp$inline_5017$$!=null)$JSCompiler_temp$jscomp$767__$jscomp$1151$$=$m__5372__auto__$jscomp$inline_5018_m__5374__auto__$jscomp$inline_5017$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5018_m__5374__auto__$jscomp$inline_5017$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$767__$jscomp$1151$$,$m$jscomp$201$$):$m__5372__auto__$jscomp$inline_5018_m__5374__auto__$jscomp$inline_5017$$($JSCompiler_temp$jscomp$767__$jscomp$1151$$,$m$jscomp$201$$);else throw $APP.$cljs$core$missing_protocol$$("ITransformable.-transform",$JSCompiler_temp$jscomp$767__$jscomp$1151$$);}return $JSCompiler_temp$jscomp$767__$jscomp$1151$$};
$app$common$types$path$impl$_lookup$$=function($JSCompiler_temp$jscomp$768__$jscomp$1153$$,$index$jscomp$176$$,$f$jscomp$757$$){if($JSCompiler_temp$jscomp$768__$jscomp$1153$$!=null&&$JSCompiler_temp$jscomp$768__$jscomp$1153$$.$app$common$types$path$impl$ITransformable$_lookup$arity$3$!=null)$JSCompiler_temp$jscomp$768__$jscomp$1153$$=$JSCompiler_temp$jscomp$768__$jscomp$1153$$.$app$common$types$path$impl$ITransformable$_lookup$arity$3$($JSCompiler_temp$jscomp$768__$jscomp$1153$$,$index$jscomp$176$$,
$f$jscomp$757$$);else{var $m__5372__auto__$jscomp$inline_5024_m__5374__auto__$jscomp$inline_5023$$=$app$common$types$path$impl$_lookup$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$768__$jscomp$1153$$==null?null:$JSCompiler_temp$jscomp$768__$jscomp$1153$$)];if($m__5372__auto__$jscomp$inline_5024_m__5374__auto__$jscomp$inline_5023$$!=null)$JSCompiler_temp$jscomp$768__$jscomp$1153$$=$m__5372__auto__$jscomp$inline_5024_m__5374__auto__$jscomp$inline_5023$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_5024_m__5374__auto__$jscomp$inline_5023$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$768__$jscomp$1153$$,
$index$jscomp$176$$,$f$jscomp$757$$):$m__5372__auto__$jscomp$inline_5024_m__5374__auto__$jscomp$inline_5023$$($JSCompiler_temp$jscomp$768__$jscomp$1153$$,$index$jscomp$176$$,$f$jscomp$757$$);else if($m__5372__auto__$jscomp$inline_5024_m__5374__auto__$jscomp$inline_5023$$=$app$common$types$path$impl$_lookup$$._,$m__5372__auto__$jscomp$inline_5024_m__5374__auto__$jscomp$inline_5023$$!=null)$JSCompiler_temp$jscomp$768__$jscomp$1153$$=$m__5372__auto__$jscomp$inline_5024_m__5374__auto__$jscomp$inline_5023$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_5024_m__5374__auto__$jscomp$inline_5023$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$768__$jscomp$1153$$,$index$jscomp$176$$,$f$jscomp$757$$):$m__5372__auto__$jscomp$inline_5024_m__5374__auto__$jscomp$inline_5023$$($JSCompiler_temp$jscomp$768__$jscomp$1153$$,$index$jscomp$176$$,$f$jscomp$757$$);else throw $APP.$cljs$core$missing_protocol$$("ITransformable.-lookup",$JSCompiler_temp$jscomp$768__$jscomp$1153$$);}return $JSCompiler_temp$jscomp$768__$jscomp$1153$$};
$app$common$types$path$impl$_walk$$=function($JSCompiler_temp$jscomp$769__$jscomp$1155$$,$f$jscomp$759$$){var $initial$jscomp$7$$=$APP.$cljs$core$PersistentVector$EMPTY$$;if($JSCompiler_temp$jscomp$769__$jscomp$1155$$!=null&&$JSCompiler_temp$jscomp$769__$jscomp$1155$$.$app$common$types$path$impl$ITransformable$_walk$arity$3$!=null)$JSCompiler_temp$jscomp$769__$jscomp$1155$$=$JSCompiler_temp$jscomp$769__$jscomp$1155$$.$app$common$types$path$impl$ITransformable$_walk$arity$3$($JSCompiler_temp$jscomp$769__$jscomp$1155$$,
$f$jscomp$759$$,$initial$jscomp$7$$);else{var $m__5372__auto__$jscomp$inline_5030_m__5374__auto__$jscomp$inline_5029$$=$app$common$types$path$impl$_walk$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$769__$jscomp$1155$$==null?null:$JSCompiler_temp$jscomp$769__$jscomp$1155$$)];if($m__5372__auto__$jscomp$inline_5030_m__5374__auto__$jscomp$inline_5029$$!=null)$JSCompiler_temp$jscomp$769__$jscomp$1155$$=$m__5372__auto__$jscomp$inline_5030_m__5374__auto__$jscomp$inline_5029$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_5030_m__5374__auto__$jscomp$inline_5029$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$769__$jscomp$1155$$,$f$jscomp$759$$,$initial$jscomp$7$$):$m__5372__auto__$jscomp$inline_5030_m__5374__auto__$jscomp$inline_5029$$($JSCompiler_temp$jscomp$769__$jscomp$1155$$,$f$jscomp$759$$,$initial$jscomp$7$$);else if($m__5372__auto__$jscomp$inline_5030_m__5374__auto__$jscomp$inline_5029$$=$app$common$types$path$impl$_walk$$._,$m__5372__auto__$jscomp$inline_5030_m__5374__auto__$jscomp$inline_5029$$!=
null)$JSCompiler_temp$jscomp$769__$jscomp$1155$$=$m__5372__auto__$jscomp$inline_5030_m__5374__auto__$jscomp$inline_5029$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_5030_m__5374__auto__$jscomp$inline_5029$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$769__$jscomp$1155$$,$f$jscomp$759$$,$initial$jscomp$7$$):$m__5372__auto__$jscomp$inline_5030_m__5374__auto__$jscomp$inline_5029$$($JSCompiler_temp$jscomp$769__$jscomp$1155$$,$f$jscomp$759$$,$initial$jscomp$7$$);else throw $APP.$cljs$core$missing_protocol$$("ITransformable.-walk",
$JSCompiler_temp$jscomp$769__$jscomp$1155$$);}return $JSCompiler_temp$jscomp$769__$jscomp$1155$$};
$app$common$types$path$impl$_reduce$$=function($JSCompiler_temp$jscomp$770__$jscomp$1157$$,$f$jscomp$761$$){var $initial$jscomp$9$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;if($JSCompiler_temp$jscomp$770__$jscomp$1157$$!=null&&$JSCompiler_temp$jscomp$770__$jscomp$1157$$.$app$common$types$path$impl$ITransformable$_reduce$arity$3$!=null)$JSCompiler_temp$jscomp$770__$jscomp$1157$$=$JSCompiler_temp$jscomp$770__$jscomp$1157$$.$app$common$types$path$impl$ITransformable$_reduce$arity$3$($JSCompiler_temp$jscomp$770__$jscomp$1157$$,$f$jscomp$761$$,
$initial$jscomp$9$$);else{var $m__5372__auto__$jscomp$inline_5036_m__5374__auto__$jscomp$inline_5035$$=$app$common$types$path$impl$_reduce$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$770__$jscomp$1157$$==null?null:$JSCompiler_temp$jscomp$770__$jscomp$1157$$)];if($m__5372__auto__$jscomp$inline_5036_m__5374__auto__$jscomp$inline_5035$$!=null)$JSCompiler_temp$jscomp$770__$jscomp$1157$$=$m__5372__auto__$jscomp$inline_5036_m__5374__auto__$jscomp$inline_5035$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_5036_m__5374__auto__$jscomp$inline_5035$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$770__$jscomp$1157$$,
$f$jscomp$761$$,$initial$jscomp$9$$):$m__5372__auto__$jscomp$inline_5036_m__5374__auto__$jscomp$inline_5035$$($JSCompiler_temp$jscomp$770__$jscomp$1157$$,$f$jscomp$761$$,$initial$jscomp$9$$);else if($m__5372__auto__$jscomp$inline_5036_m__5374__auto__$jscomp$inline_5035$$=$app$common$types$path$impl$_reduce$$._,$m__5372__auto__$jscomp$inline_5036_m__5374__auto__$jscomp$inline_5035$$!=null)$JSCompiler_temp$jscomp$770__$jscomp$1157$$=$m__5372__auto__$jscomp$inline_5036_m__5374__auto__$jscomp$inline_5035$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_5036_m__5374__auto__$jscomp$inline_5035$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$770__$jscomp$1157$$,$f$jscomp$761$$,$initial$jscomp$9$$):$m__5372__auto__$jscomp$inline_5036_m__5374__auto__$jscomp$inline_5035$$($JSCompiler_temp$jscomp$770__$jscomp$1157$$,$f$jscomp$761$$,$initial$jscomp$9$$);else throw $APP.$cljs$core$missing_protocol$$("ITransformable.-reduce",$JSCompiler_temp$jscomp$770__$jscomp$1157$$);}return $JSCompiler_temp$jscomp$770__$jscomp$1157$$};
$app$common$types$path$impl$impl_walk$$=function($buffer$jscomp$47$$,$f$jscomp$764$$,$G__47977_initial$jscomp$10_result$jscomp$180$$,$size$jscomp$90$$){var $G__47976_index$jscomp$178$$=0;for($G__47977_initial$jscomp$10_result$jscomp$180$$=$APP.$cljs$core$_as_transient$$($G__47977_initial$jscomp$10_result$jscomp$180$$);;)if($G__47976_index$jscomp$178$$<$size$jscomp$90$$){var $offset$jscomp$113_y$jscomp$358$$=$G__47976_index$jscomp$178$$*28,$type$jscomp$326$$=$buffer$jscomp$47$$.getInt16($offset$jscomp$113_y$jscomp$358$$,
!0),$c1x$jscomp$1_res$jscomp$34$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$47$$.getFloat32($offset$jscomp$113_y$jscomp$358$$+4,!0)),$c1y$jscomp$1$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$47$$.getFloat32($offset$jscomp$113_y$jscomp$358$$+8,!0)),$c2x$jscomp$1$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$47$$.getFloat32($offset$jscomp$113_y$jscomp$358$$+12,!0)),$c2y$jscomp$1$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$47$$.getFloat32($offset$jscomp$113_y$jscomp$358$$+
16,!0)),$x$jscomp$1100$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$47$$.getFloat32($offset$jscomp$113_y$jscomp$358$$+20,!0));$offset$jscomp$113_y$jscomp$358$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$47$$.getFloat32($offset$jscomp$113_y$jscomp$358$$+24,!0));var $type__$1$jscomp$2$$=function(){switch($type$jscomp$326$$){case 1:return $APP.$cljs$cst$1813$move_to$$;case 2:return $APP.$cljs$cst$1814$line_to$$;case 3:return $cljs$cst$1819$curve_to$$;case 4:return $APP.$cljs$cst$1850$close_path$$;
default:return null}}();$c1x$jscomp$1_res$jscomp$34$$=$type__$1$jscomp$2$$!=null?$f$jscomp$764$$.$cljs$core$IFn$_invoke$arity$7$?$f$jscomp$764$$.$cljs$core$IFn$_invoke$arity$7$($type__$1$jscomp$2$$,$c1x$jscomp$1_res$jscomp$34$$,$c1y$jscomp$1$$,$c2x$jscomp$1$$,$c2y$jscomp$1$$,$x$jscomp$1100$$,$offset$jscomp$113_y$jscomp$358$$):$f$jscomp$764$$($type__$1$jscomp$2$$,$c1x$jscomp$1_res$jscomp$34$$,$c1y$jscomp$1$$,$c2x$jscomp$1$$,$c2y$jscomp$1$$,$x$jscomp$1100$$,$offset$jscomp$113_y$jscomp$358$$):null;$G__47976_index$jscomp$178$$+=
1;$G__47977_initial$jscomp$10_result$jscomp$180$$=$c1x$jscomp$1_res$jscomp$34$$!=null?$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__47977_initial$jscomp$10_result$jscomp$180$$,$c1x$jscomp$1_res$jscomp$34$$):$G__47977_initial$jscomp$10_result$jscomp$180$$}else return $APP.$cljs$core$_persistent_BANG_$$($G__47977_initial$jscomp$10_result$jscomp$180$$)};
$app$common$types$path$impl$impl_reduce$$=function($buffer$jscomp$48$$,$f$jscomp$765$$,$G__47984_initial$jscomp$11_result$jscomp$181_result__$1$jscomp$15$$,$size$jscomp$91$$){for(var $index$jscomp$179$$=0;;)if($index$jscomp$179$$<$size$jscomp$91$$){var $offset$jscomp$114_y$jscomp$359$$=$index$jscomp$179$$*28,$type$jscomp$327$$=$buffer$jscomp$48$$.getInt16($offset$jscomp$114_y$jscomp$359$$,!0),$c1x$jscomp$2$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$48$$.getFloat32($offset$jscomp$114_y$jscomp$359$$+
4,!0)),$c1y$jscomp$2$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$48$$.getFloat32($offset$jscomp$114_y$jscomp$359$$+8,!0)),$c2x$jscomp$2$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$48$$.getFloat32($offset$jscomp$114_y$jscomp$359$$+12,!0)),$c2y$jscomp$2$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$48$$.getFloat32($offset$jscomp$114_y$jscomp$359$$+16,!0)),$x$jscomp$1101$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$48$$.getFloat32($offset$jscomp$114_y$jscomp$359$$+
20,!0));$offset$jscomp$114_y$jscomp$359$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$48$$.getFloat32($offset$jscomp$114_y$jscomp$359$$+24,!0));var $type__$1$jscomp$3$$=function(){switch($type$jscomp$327$$){case 1:return $APP.$cljs$cst$1813$move_to$$;case 2:return $APP.$cljs$cst$1814$line_to$$;case 3:return $cljs$cst$1819$curve_to$$;case 4:return $APP.$cljs$cst$1850$close_path$$;default:return null}}();$G__47984_initial$jscomp$11_result$jscomp$181_result__$1$jscomp$15$$=$type__$1$jscomp$3$$!=
null?$f$jscomp$765$$.$cljs$core$IFn$_invoke$arity$9$?$f$jscomp$765$$.$cljs$core$IFn$_invoke$arity$9$($G__47984_initial$jscomp$11_result$jscomp$181_result__$1$jscomp$15$$,$index$jscomp$179$$,$type__$1$jscomp$3$$,$c1x$jscomp$2$$,$c1y$jscomp$2$$,$c2x$jscomp$2$$,$c2y$jscomp$2$$,$x$jscomp$1101$$,$offset$jscomp$114_y$jscomp$359$$):$f$jscomp$765$$($G__47984_initial$jscomp$11_result$jscomp$181_result__$1$jscomp$15$$,$index$jscomp$179$$,$type__$1$jscomp$3$$,$c1x$jscomp$2$$,$c1y$jscomp$2$$,$c2x$jscomp$2$$,
$c2y$jscomp$2$$,$x$jscomp$1101$$,$offset$jscomp$114_y$jscomp$359$$):$G__47984_initial$jscomp$11_result$jscomp$181_result__$1$jscomp$15$$;if($cljs$core$reduced_QMARK_$$($G__47984_initial$jscomp$11_result$jscomp$181_result__$1$jscomp$15$$))return $G__47984_initial$jscomp$11_result$jscomp$181_result__$1$jscomp$15$$;$index$jscomp$179$$+=1}else return $G__47984_initial$jscomp$11_result$jscomp$181_result__$1$jscomp$15$$};
$app$common$types$path$impl$impl_lookup$$=function($buffer$jscomp$49_y$jscomp$360$$,$c1x$jscomp$3_index$jscomp$180$$,$f$jscomp$766$$){var $offset$jscomp$115_type__$1$jscomp$4$$=$c1x$jscomp$3_index$jscomp$180$$*28,$type$jscomp$328$$=$buffer$jscomp$49_y$jscomp$360$$.getInt16($offset$jscomp$115_type__$1$jscomp$4$$,!0);$c1x$jscomp$3_index$jscomp$180$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$49_y$jscomp$360$$.getFloat32($offset$jscomp$115_type__$1$jscomp$4$$+4,!0));var $c1y$jscomp$3$$=
$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$49_y$jscomp$360$$.getFloat32($offset$jscomp$115_type__$1$jscomp$4$$+8,!0)),$c2x$jscomp$3$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$49_y$jscomp$360$$.getFloat32($offset$jscomp$115_type__$1$jscomp$4$$+12,!0)),$c2y$jscomp$3$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$49_y$jscomp$360$$.getFloat32($offset$jscomp$115_type__$1$jscomp$4$$+16,!0)),$x$jscomp$1102$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$49_y$jscomp$360$$.getFloat32($offset$jscomp$115_type__$1$jscomp$4$$+
20,!0));$buffer$jscomp$49_y$jscomp$360$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$49_y$jscomp$360$$.getFloat32($offset$jscomp$115_type__$1$jscomp$4$$+24,!0));$offset$jscomp$115_type__$1$jscomp$4$$=function(){switch($type$jscomp$328$$){case 1:return $APP.$cljs$cst$1813$move_to$$;case 2:return $APP.$cljs$cst$1814$line_to$$;case 3:return $cljs$cst$1819$curve_to$$;case 4:return $APP.$cljs$cst$1850$close_path$$;default:return null}}();return $offset$jscomp$115_type__$1$jscomp$4$$!=
null?$f$jscomp$766$$($offset$jscomp$115_type__$1$jscomp$4$$,$c1x$jscomp$3_index$jscomp$180$$,$c1y$jscomp$3$$,$c2x$jscomp$3$$,$c2y$jscomp$3$$,$x$jscomp$1102$$,$buffer$jscomp$49_y$jscomp$360$$):null};
$app$common$types$path$impl$read_segment$$=function($buffer$jscomp$52_y$jscomp$362$$,$index$jscomp$181_offset$jscomp$117$$){$index$jscomp$181_offset$jscomp$117$$*=28;var $type$jscomp$330_x$jscomp$1104$$=$buffer$jscomp$52_y$jscomp$362$$.getInt16($index$jscomp$181_offset$jscomp$117$$,!0);switch($APP.$cljs$core$fix$$($type$jscomp$330_x$jscomp$1104$$)){case 1:return $type$jscomp$330_x$jscomp$1104$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$52_y$jscomp$362$$.getFloat32($index$jscomp$181_offset$jscomp$117$$+
20,!0)),$buffer$jscomp$52_y$jscomp$362$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$52_y$jscomp$362$$.getFloat32($index$jscomp$181_offset$jscomp$117$$+24,!0)),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$type$jscomp$330_x$jscomp$1104$$,$APP.$cljs$cst$1511$y$$,$buffer$jscomp$52_y$jscomp$362$$],null)],null);case 2:return $type$jscomp$330_x$jscomp$1104$$=
$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$52_y$jscomp$362$$.getFloat32($index$jscomp$181_offset$jscomp$117$$+20,!0)),$buffer$jscomp$52_y$jscomp$362$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$52_y$jscomp$362$$.getFloat32($index$jscomp$181_offset$jscomp$117$$+24,!0)),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1814$line_to$$,$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,
$type$jscomp$330_x$jscomp$1104$$,$APP.$cljs$cst$1511$y$$,$buffer$jscomp$52_y$jscomp$362$$],null)],null);case 3:var $c1x$jscomp$5$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$52_y$jscomp$362$$.getFloat32($index$jscomp$181_offset$jscomp$117$$+4,!0)),$c1y$jscomp$5$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$52_y$jscomp$362$$.getFloat32($index$jscomp$181_offset$jscomp$117$$+8,!0)),$c2x$jscomp$5$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$52_y$jscomp$362$$.getFloat32($index$jscomp$181_offset$jscomp$117$$+
12,!0)),$c2y$jscomp$5$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$52_y$jscomp$362$$.getFloat32($index$jscomp$181_offset$jscomp$117$$+16,!0));$type$jscomp$330_x$jscomp$1104$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$52_y$jscomp$362$$.getFloat32($index$jscomp$181_offset$jscomp$117$$+20,!0));$buffer$jscomp$52_y$jscomp$362$$=$app$common$types$path$impl$normalize_coord$$($buffer$jscomp$52_y$jscomp$362$$.getFloat32($index$jscomp$181_offset$jscomp$117$$+24,!0));return new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1812$command$$,$cljs$cst$1819$curve_to$$,$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1510$x$$,$type$jscomp$330_x$jscomp$1104$$,$APP.$cljs$cst$1511$y$$,$buffer$jscomp$52_y$jscomp$362$$,$APP.$cljs$cst$1815$c1x$$,$c1x$jscomp$5$$,$APP.$cljs$cst$1816$c1y$$,$c1y$jscomp$5$$,$APP.$cljs$cst$1817$c2x$$,$c2x$jscomp$5$$,$APP.$cljs$cst$1818$c2y$$,$c2y$jscomp$5$$],null)],null);case 4:return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,
$APP.$cljs$cst$1850$close_path$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null);default:return null}};$app$common$types$path$impl$PathData$$=function($size$jscomp$93$$,$buffer$jscomp$53$$,$cache$jscomp$100$$,$__hash$jscomp$76$$){this.size=$size$jscomp$93$$;this.buffer=$buffer$jscomp$53$$;this.cache=$cache$jscomp$100$$;this.$__hash$=$__hash$jscomp$76$$;this.$cljs$lang$protocol_mask$partition0$$=2179465234;this.$cljs$lang$protocol_mask$partition1$$=0};
$app$common$types$path$impl$path_data_QMARK_$$=function($o$jscomp$246$$){return $o$jscomp$246$$ instanceof $app$common$types$path$impl$PathData$$};$app$common$types$path$impl$from_string$$=function($G__47927_s$jscomp$525$$){$G__47927_s$jscomp$525$$=$APP.$app$common$svg$path$parse$$($G__47927_s$jscomp$525$$);return $APP.$app$common$types$path$impl$from_plain$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$path$impl$from_plain$$.$cljs$core$IFn$_invoke$arity$1$($G__47927_s$jscomp$525$$):$APP.$app$common$types$path$impl$from_plain$$($G__47927_s$jscomp$525$$)};
$APP.$app$common$types$path$impl$from_plain$$=function($segments$jscomp$5$$){for(var $total$jscomp$4$$=$APP.$cljs$core$count$$($segments$jscomp$5$$),$buffer$jscomp$56$$=new DataView(new ArrayBuffer($total$jscomp$4$$*28)),$index_48049$$=0;;)if($index_48049$$<$total$jscomp$4$$){var $segment_48050_x_48057_x_48064_x_48067$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($segments$jscomp$5$$,$index_48049$$),$offset_48051$$=$index_48049$$*28,$G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($segment_48050_x_48057_x_48064_x_48067$$,$APP.$cljs$cst$1812$command$$);$G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$=$G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$ instanceof $APP.$cljs$core$Keyword$$?$G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$.$fqn$:null;switch($G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$){case "move-to":$G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($segment_48050_x_48057_x_48064_x_48067$$,$APP.$cljs$cst$1430$params$$);$segment_48050_x_48057_x_48064_x_48067$$=$app$common$types$path$impl$normalize_coord$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$,$APP.$cljs$cst$1510$x$$));$G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$=$app$common$types$path$impl$normalize_coord$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$,
$APP.$cljs$cst$1511$y$$));$buffer$jscomp$56$$.setInt16($offset_48051$$,1,!0);$buffer$jscomp$56$$.setFloat32($offset_48051$$+20,$segment_48050_x_48057_x_48064_x_48067$$,!0);$buffer$jscomp$56$$.setFloat32($offset_48051$$+24,$G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$,!0);break;case "line-to":$G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($segment_48050_x_48057_x_48064_x_48067$$,
$APP.$cljs$cst$1430$params$$);$segment_48050_x_48057_x_48064_x_48067$$=$app$common$types$path$impl$normalize_coord$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$,$APP.$cljs$cst$1510$x$$));$G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$=$app$common$types$path$impl$normalize_coord$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$,
$APP.$cljs$cst$1511$y$$));$buffer$jscomp$56$$.setInt16($offset_48051$$,2,!0);$buffer$jscomp$56$$.setFloat32($offset_48051$$+20,$segment_48050_x_48057_x_48064_x_48067$$,!0);$buffer$jscomp$56$$.setFloat32($offset_48051$$+24,$G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$,!0);break;case "curve-to":var $c2y_48072_params_48066$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($segment_48050_x_48057_x_48064_x_48067$$,$APP.$cljs$cst$1430$params$$);$segment_48050_x_48057_x_48064_x_48067$$=
$app$common$types$path$impl$normalize_coord$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c2y_48072_params_48066$$,$APP.$cljs$cst$1510$x$$));$G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$=$app$common$types$path$impl$normalize_coord$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c2y_48072_params_48066$$,$APP.$cljs$cst$1511$y$$));var $c1x_48069$$=$app$common$types$path$impl$normalize_coord$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($c2y_48072_params_48066$$,
$APP.$cljs$cst$1815$c1x$$,$segment_48050_x_48057_x_48064_x_48067$$)),$c1y_48070$$=$app$common$types$path$impl$normalize_coord$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($c2y_48072_params_48066$$,$APP.$cljs$cst$1816$c1y$$,$G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$)),$c2x_48071$$=$app$common$types$path$impl$normalize_coord$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($c2y_48072_params_48066$$,$APP.$cljs$cst$1817$c2x$$,$segment_48050_x_48057_x_48064_x_48067$$));
$c2y_48072_params_48066$$=$app$common$types$path$impl$normalize_coord$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($c2y_48072_params_48066$$,$APP.$cljs$cst$1818$c2y$$,$G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$));$buffer$jscomp$56$$.setInt16($offset_48051$$,3,!0);$buffer$jscomp$56$$.setFloat32($offset_48051$$+4,$c1x_48069$$,!0);$buffer$jscomp$56$$.setFloat32($offset_48051$$+8,$c1y_48070$$,!0);$buffer$jscomp$56$$.setFloat32($offset_48051$$+12,$c2x_48071$$,
!0);$buffer$jscomp$56$$.setFloat32($offset_48051$$+16,$c2y_48072_params_48066$$,!0);$buffer$jscomp$56$$.setFloat32($offset_48051$$+20,$segment_48050_x_48057_x_48064_x_48067$$,!0);$buffer$jscomp$56$$.setFloat32($offset_48051$$+24,$G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$,!0);break;case "close-path":$buffer$jscomp$56$$.setInt16($offset_48051$$,4,!0);break;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__47944_48052_G__47944_48053__$1_params_48055_params_48063_y_48058_y_48065_y_48068$$)].join(""));
}$index_48049$$+=1}else break;return $app$common$types$path$impl$from_bytes$$($buffer$jscomp$56$$)};
$APP.$app$common$types$path$impl$path_data$$=function($data$jscomp$133$$){if($app$common$types$path$impl$path_data_QMARK_$$($data$jscomp$133$$))return $data$jscomp$133$$;if($data$jscomp$133$$==null)return $APP.$app$common$types$path$impl$from_plain$$($APP.$cljs$core$PersistentVector$EMPTY$$);if($APP.$cljs$core$sequential_QMARK_$$($data$jscomp$133$$))return $APP.$app$common$types$path$impl$from_plain$$($data$jscomp$133$$);throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("unexpected data",
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$142$data$$,$data$jscomp$133$$],null));};
$app$common$types$path$segment$update_handler$$=function($command$jscomp$7$$,$cox_prefix$jscomp$35$$,$point$jscomp$21$$){var $coy_vec__47964$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cox_prefix$jscomp$35$$,$APP.$cljs$cst$1821$c1$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1815$c1x$$,$APP.$cljs$cst$1816$c1y$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1817$c2x$$,
$APP.$cljs$cst$1818$c2y$$],null);$cox_prefix$jscomp$35$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($coy_vec__47964$$,0,null);$coy_vec__47964$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($coy_vec__47964$$,1,null);return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($command$jscomp$7$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,$cox_prefix$jscomp$35$$],null),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$21$$)),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,$coy_vec__47964$$],null),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$21$$))};
$APP.$app$common$types$path$segment$get_handler$$=function($map__47969__$1_p__47968$$,$cy$jscomp$9_prefix$jscomp$36$$){$map__47969__$1_p__47968$$=$APP.$cljs$core$__destructure_map$$($map__47969__$1_p__47968$$);var $params$jscomp$100$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47969__$1_p__47968$$,$APP.$cljs$cst$1430$params$$),$cx$jscomp$8$$=$APP.$app$common$data$prefix_keyword$$($cy$jscomp$9_prefix$jscomp$36$$,$APP.$cljs$cst$1510$x$$);$cy$jscomp$9_prefix$jscomp$36$$=$APP.$app$common$data$prefix_keyword$$($cy$jscomp$9_prefix$jscomp$36$$,
$APP.$cljs$cst$1511$y$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__47969__$1_p__47968$$)?$APP.$cljs$core$contains_QMARK_$$($params$jscomp$100$$,$cx$jscomp$8$$)&&$APP.$cljs$core$contains_QMARK_$$($params$jscomp$100$$,$cy$jscomp$9_prefix$jscomp$36$$):$map__47969__$1_p__47968$$)?$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$100$$,$cx$jscomp$8$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$100$$,
$cy$jscomp$9_prefix$jscomp$36$$)):null};
$APP.$app$common$types$path$segment$get_handlers$$=function($content$jscomp$24$$){var $prev_point_STAR_$$=$APP.$cljs$core$volatile_BANG_$$(null),$vec_conj$$=$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$);return $app$common$types$path$impl$_reduce$$($content$jscomp$24$$,function($result$jscomp$184$$,$index$jscomp$185$$,$type$jscomp$331$$,$_$jscomp$1171_curr_point$$,$___$1$jscomp$744_prev_point$jscomp$1$$,$___$2$jscomp$112$$,
$___$3$jscomp$30$$,$x$jscomp$1105$$,$y$jscomp$363$$){$_$jscomp$1171_curr_point$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1105$$,$y$jscomp$363$$);$___$1$jscomp$744_prev_point$jscomp$1$$=$APP.$cljs$core$_deref$$($prev_point_STAR_$$);$APP.$cljs$core$_vreset_BANG_$$($prev_point_STAR_$$,$_$jscomp$1171_curr_point$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($___$1$jscomp$744_prev_point$jscomp$1$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,
$type$jscomp$331$$):$___$1$jscomp$744_prev_point$jscomp$1$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($result$jscomp$184$$,$___$1$jscomp$744_prev_point$jscomp$1$$,$vec_conj$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$185$$,$APP.$cljs$cst$1821$c1$$],null)),$_$jscomp$1171_curr_point$$,$vec_conj$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$185$$,$cljs$cst$1822$c2$$],null)):$result$jscomp$184$$})};
$app$common$types$path$segment$point_indices$$=function($content$jscomp$25$$,$point$jscomp$22$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__47979$$){var $index$jscomp$186$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__47979$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__47979$$,1,null);return $index$jscomp$186$$},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__47985_segment$jscomp$18$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__47985_segment$jscomp$18$$,0,
null);$p__47985_segment$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__47985_segment$jscomp$18$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$22$$,$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($p__47985_segment$jscomp$18$$))},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$25$$)))};
$app$common$types$path$segment$handler_indices$$=function($content$jscomp$26$$,$point$jscomp$23$$){return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($cur_pos_cur_segment_p__47995$$){var $index$jscomp$187$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cur_pos_cur_segment_p__47995$$,0,null),$G__48007__$1_pre_pos_pre_segment_vec__48002$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cur_pos_cur_segment_p__47995$$,1,null);$cur_pos_cur_segment_p__47995$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__48007__$1_pre_pos_pre_segment_vec__48002$$,0,null);$G__48007__$1_pre_pos_pre_segment_vec__48002$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__48007__$1_pre_pos_pre_segment_vec__48002$$,1,null);if($G__48007__$1_pre_pos_pre_segment_vec__48002$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($cur_pos_cur_segment_p__47995$$))){$cur_pos_cur_segment_p__47995$$=
$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($cur_pos_cur_segment_p__47995$$);$G__48007__$1_pre_pos_pre_segment_vec__48002$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($G__48007__$1_pre_pos_pre_segment_vec__48002$$);var $G__48007$$=$APP.$cljs$core$PersistentVector$EMPTY$$;$G__48007__$1_pre_pos_pre_segment_vec__48002$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__48007__$1_pre_pos_pre_segment_vec__48002$$,
$point$jscomp$23$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48007$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$187$$,$APP.$cljs$cst$1821$c1$$],null)):$G__48007$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cur_pos_cur_segment_p__47995$$,$point$jscomp$23$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48007__$1_pre_pos_pre_segment_vec__48002$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$187$$,$cljs$cst$1822$c2$$],null)):$G__48007__$1_pre_pos_pre_segment_vec__48002$$}return $APP.$cljs$core$PersistentVector$EMPTY$$},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$with_prev$$($content$jscomp$26$$))]))};
$app$common$types$path$segment$opposite_index$$=function($content$jscomp$27$$,$index$jscomp$188$$,$prefix$jscomp$37$$){var $handlers$jscomp$2_point$jscomp$24$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prefix$jscomp$37$$,$cljs$cst$1822$c2$$)?$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$27$$,$index$jscomp$188$$)):$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$27$$,
$index$jscomp$188$$-1)),$point__GT_handlers$$=$APP.$app$common$types$path$segment$get_handlers$$($content$jscomp$27$$);$handlers$jscomp$2_point$jscomp$24$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($cp$jscomp$1_p__48011$$){var $ci$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cp$jscomp$1_p__48011$$,0,null);$cp$jscomp$1_p__48011$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cp$jscomp$1_p__48011$$,1,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$188$$,
$ci$jscomp$4$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prefix$jscomp$37$$,$cp$jscomp$1_p__48011$$)},$point__GT_handlers$$.$cljs$core$IFn$_invoke$arity$1$?$point__GT_handlers$$.$cljs$core$IFn$_invoke$arity$1$($handlers$jscomp$2_point$jscomp$24$$):$point__GT_handlers$$($handlers$jscomp$2_point$jscomp$24$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($handlers$jscomp$2_point$jscomp$24$$),1)?$APP.$cljs$core$first$$($handlers$jscomp$2_point$jscomp$24$$):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1821$c1$$,$prefix$jscomp$37$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($content$jscomp$27$$),$index$jscomp$188$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$188$$-1,$cljs$cst$1822$c2$$],null):null};
$APP.$app$common$types$path$segment$get_handler_point$$=function($content$jscomp$28$$,$index$jscomp$189$$,$prefix$jscomp$38$$){return $index$jscomp$189$$!=null&&$content$jscomp$28$$!=null?$app$common$types$path$impl$_lookup$$($content$jscomp$28$$,$index$jscomp$189$$,function($G__48019_command$jscomp$9$$,$c1x$jscomp$6$$,$c1y$jscomp$6$$,$c2x$jscomp$6$$,$c2y$jscomp$6$$,$x$jscomp$1106$$,$y$jscomp$364$$){$G__48019_command$jscomp$9$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,
$G__48019_command$jscomp$9$$)?$prefix$jscomp$38$$:null;switch($G__48019_command$jscomp$9$$ instanceof $APP.$cljs$core$Keyword$$?$G__48019_command$jscomp$9$$.$fqn$:null){case "c1":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($c1x$jscomp$6$$,$c1y$jscomp$6$$);case "c2":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($c2x$jscomp$6$$,$c2y$jscomp$6$$);default:return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1106$$,
$y$jscomp$364$$)}}):null};
$app$common$types$path$segment$get_points$$=function($content$jscomp$30_result__$1$jscomp$18$$){var $cache$jscomp$102$$=$content$jscomp$30_result__$1$jscomp$18$$.cache;if($cache$jscomp$102$$!=null){var $result$jscomp$185$$=$cache$jscomp$102$$.get("get-points");if($APP.$cljs$core$truth_$$($result$jscomp$185$$))return $result$jscomp$185$$;$content$jscomp$30_result__$1$jscomp$18$$=$app$common$types$path$impl$_walk$$($content$jscomp$30_result__$1$jscomp$18$$,function($type$jscomp$332$$,$_$jscomp$1174$$,
$___$1$jscomp$745$$,$___$2$jscomp$113$$,$___$3$jscomp$31$$,$x$jscomp$1107$$,$y$jscomp$365$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$332$$,$APP.$cljs$cst$1850$close_path$$)?$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1107$$,$y$jscomp$365$$):null});$cache$jscomp$102$$.set("get-points",$content$jscomp$30_result__$1$jscomp$18$$);return $content$jscomp$30_result__$1$jscomp$18$$}return $app$common$types$path$impl$_walk$$($content$jscomp$30_result__$1$jscomp$18$$,
function($type$jscomp$333$$,$_$jscomp$1175$$,$___$1$jscomp$746$$,$___$2$jscomp$114$$,$___$3$jscomp$32$$,$x$jscomp$1108$$,$y$jscomp$366$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$333$$,$APP.$cljs$cst$1850$close_path$$)?$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1108$$,$y$jscomp$366$$):null})};
$app$common$types$path$segment$remove_line_curves$$=function($content$jscomp$32$$){var $with_prev$$=$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$with_prev$$($content$jscomp$32$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($content__$1$$,$p__48106_segment$jscomp$19$$){var $index$jscomp$191$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48106_segment$jscomp$19$$,0,null),$cur_point_vec__48110$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48106_segment$jscomp$19$$,
1,null);$p__48106_segment$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cur_point_vec__48110$$,0,null);var $pre_point_prev$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cur_point_vec__48110$$,1,null);$cur_point_vec__48110$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($p__48106_segment$jscomp$19$$);$pre_point_prev$jscomp$11$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($pre_point_prev$jscomp$11$$);
var $handler_c1$$=$APP.$app$common$types$path$segment$get_handler$$($p__48106_segment$jscomp$19$$,$APP.$cljs$cst$1821$c1$$),$handler_c2$$=$APP.$app$common$types$path$segment$get_handler$$($p__48106_segment$jscomp$19$$,$cljs$cst$1822$c2$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($p__48106_segment$jscomp$19$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cur_point_vec__48110$$,
$handler_c2$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($pre_point_prev$jscomp$11$$,$handler_c1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($content__$1$$,$index$jscomp$191$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1814$line_to$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cur_point_vec__48110$$)],null)):$content__$1$$},$content$jscomp$32$$,
$with_prev$$)};
$app$common$types$path$segment$make_corner_point$$=function($content$jscomp$33_content__$1$jscomp$1_content__$2$$,$point$jscomp$28$$){var $handlers$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$path$segment$get_handlers$$($content$jscomp$33_content__$1$jscomp$1_content__$2$$),$point$jscomp$28$$);$content$jscomp$33_content__$1$jscomp$1_content__$2$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($content__$1$jscomp$2$$,$cx$jscomp$9_p__48117$$){var $index$jscomp$192$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cx$jscomp$9_p__48117$$,0,null),$cy$jscomp$10_prefix$jscomp$40$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cx$jscomp$9_p__48117$$,1,null);$cx$jscomp$9_p__48117$$=$APP.$app$common$data$prefix_keyword$$($cy$jscomp$10_prefix$jscomp$40$$,$APP.$cljs$cst$1510$x$$);$cy$jscomp$10_prefix$jscomp$40$$=$APP.$app$common$data$prefix_keyword$$($cy$jscomp$10_prefix$jscomp$40$$,$APP.$cljs$cst$1511$y$$);return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($content__$1$jscomp$2$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$192$$,$APP.$cljs$cst$1430$params$$,$cx$jscomp$9_p__48117$$],null),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$28$$)),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$192$$,$APP.$cljs$cst$1430$params$$,$cy$jscomp$10_prefix$jscomp$40$$],null),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$28$$))},
$APP.$cljs$core$vec$$($content$jscomp$33_content__$1$jscomp$1_content__$2$$),$handlers$jscomp$3$$);$content$jscomp$33_content__$1$jscomp$1_content__$2$$=$app$common$types$path$segment$remove_line_curves$$($content$jscomp$33_content__$1$jscomp$1_content__$2$$);return $APP.$app$common$types$path$impl$from_plain$$($content$jscomp$33_content__$1$jscomp$1_content__$2$$)};
$app$common$types$path$segment$line__GT_curve$$=function($dv2_from_p$jscomp$10$$,$segment$jscomp$20$$){var $to_p$jscomp$9$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$20$$),$dv1_v$jscomp$520$$=$APP.$app$common$geom$point$subtract$$($to_p$jscomp$9$$,$dv2_from_p$jscomp$10$$),$d$jscomp$227$$=$APP.$app$common$geom$point$distance$$($dv2_from_p$jscomp$10$$,$to_p$jscomp$9$$);$dv1_v$jscomp$520$$=$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$normal_left$$($dv1_v$jscomp$520$$),
$d$jscomp$227$$/3);var $h1$jscomp$28$$=$APP.$app$common$geom$point$add$$($dv2_from_p$jscomp$10$$,$dv1_v$jscomp$520$$);$dv2_from_p$jscomp$10$$=$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($h1$jscomp$28$$,$to_p$jscomp$9$$)),$d$jscomp$227$$/3);var $h2$jscomp$22$$=$APP.$app$common$geom$point$add$$($to_p$jscomp$9$$,$dv2_from_p$jscomp$10$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($segment$jscomp$20$$,
$APP.$cljs$cst$1812$command$$,$cljs$cst$1819$curve_to$$),$APP.$cljs$cst$1430$params$$,function($params$jscomp$102$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$params$jscomp$102$$),$APP.$cljs$cst$1815$c1x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($h1$jscomp$28$$)),
$APP.$cljs$cst$1816$c1y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($h1$jscomp$28$$)),$APP.$cljs$cst$1817$c2x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$22$$)),$APP.$cljs$cst$1818$c2y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$22$$))})};
$app$common$types$path$segment$make_curve_point$$=function($content$jscomp$35_vectors$$,$point$jscomp$30$$){var $add_curve_indices_points$jscomp$11_v1$jscomp$27_vec__48141$$=$app$common$types$path$segment$point_indices$$($content$jscomp$35_vectors$$,$point$jscomp$30$$),$content__$1$jscomp$3$$=$APP.$cljs$core$vec$$($content$jscomp$35_vectors$$);$content$jscomp$35_vectors$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($index$jscomp$193$$){var $segment$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content__$1$jscomp$3$$,
$index$jscomp$193$$),$prev_i$$=$index$jscomp$193$$-1,$prev$jscomp$12$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$21$$))?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content__$1$jscomp$3$$,$prev_i$$),$next_i$$=$index$jscomp$193$$+1,$next$jscomp$8_next__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content__$1$jscomp$3$$,$next_i$$);$next$jscomp$8_next__$1$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($next$jscomp$8_next__$1$$))?null:$next$jscomp$8_next__$1$$;return new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1795$index$$,$index$jscomp$193$$,$cljs$cst$1857$prev_i$$,$prev$jscomp$12$$!=null?$prev_i$$:null,$cljs$cst$1858$prev_c$$,$prev$jscomp$12$$,$cljs$cst$1856$prev_p$$,$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($prev$jscomp$12$$),
$cljs$cst$1859$next_i$$,$next$jscomp$8_next__$1$$!=null?$next_i$$:null,$cljs$cst$1860$next_c$$,$next$jscomp$8_next__$1$$,$cljs$cst$1855$next_p$$,$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($next$jscomp$8_next__$1$$),$APP.$cljs$cst$1861$segment$$,$segment$jscomp$21$$],null)},$add_curve_indices_points$jscomp$11_v1$jscomp$27_vec__48141$$);$add_curve_indices_points$jscomp$11_v1$jscomp$27_vec__48141$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$app$common$types$path$segment$xf_COLON_mapcat_points$$,$content$jscomp$35_vectors$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($add_curve_indices_points$jscomp$11_v1$jscomp$27_vec__48141$$),2)){$add_curve_indices_points$jscomp$11_v1$jscomp$27_vec__48141$$=$APP.$cljs$core$vec$$($add_curve_indices_points$jscomp$11_v1$jscomp$27_vec__48141$$);var $fpoint_v2$jscomp$19_vp$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($add_curve_indices_points$jscomp$11_v1$jscomp$27_vec__48141$$,
0,null),$spoint$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($add_curve_indices_points$jscomp$11_v1$jscomp$27_vec__48141$$,1,null);$add_curve_indices_points$jscomp$11_v1$jscomp$27_vec__48141$$=$APP.$app$common$geom$point$subtract$$($point$jscomp$30$$,$fpoint_v2$jscomp$19_vp$$);$fpoint_v2$jscomp$19_vp$$=$APP.$app$common$geom$point$subtract$$($spoint$$,$fpoint_v2$jscomp$19_vp$$);$fpoint_v2$jscomp$19_vp$$=$app$common$geom$point$project$$($add_curve_indices_points$jscomp$11_v1$jscomp$27_vec__48141$$,
$fpoint_v2$jscomp$19_vp$$);var $vh$jscomp$3$$=$APP.$app$common$geom$point$subtract$$($add_curve_indices_points$jscomp$11_v1$jscomp$27_vec__48141$$,$fpoint_v2$jscomp$19_vp$$);$add_curve_indices_points$jscomp$11_v1$jscomp$27_vec__48141$$=function($G__48149__$1_G__48149__$2_content__$2$jscomp$1$$,$next_p_p__48147$$){var $map__48148__$1_next_i$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($next_p_p__48147$$),$G__48149__$3_index$jscomp$194$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48148__$1_next_i$jscomp$1$$,
$APP.$cljs$cst$1795$index$$),$prev_p$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48148__$1_next_i$jscomp$1$$,$cljs$cst$1856$prev_p$$);$next_p_p__48147$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48148__$1_next_i$jscomp$1$$,$cljs$cst$1855$next_p$$);$map__48148__$1_next_i$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48148__$1_next_i$jscomp$1$$,$cljs$cst$1859$next_i$$);var $curr_command_curr_segment$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48149__$1_G__48149__$2_content__$2$jscomp$1$$,
$G__48149__$3_index$jscomp$194$$);$curr_command_curr_segment$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($curr_command_curr_segment$$,$APP.$cljs$cst$1812$command$$);var $next_command_next_segment$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48149__$1_G__48149__$2_content__$2$jscomp$1$$,$map__48148__$1_next_i$jscomp$1$$);$next_command_next_segment$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($next_command_next_segment$$,$APP.$cljs$cst$1812$command$$);var $prev_h_prev_h__$1$$=
$prev_p$$!=null?$APP.$app$common$geom$point$add$$($prev_p$$,$vh$jscomp$3$$):null,$next_h_next_h__$1$$=$next_p_p__48147$$!=null?$APP.$app$common$geom$point$add$$($next_p_p__48147$$,$vh$jscomp$3$$):null,$prev_correction$$=$prev_h_prev_h__$1$$!=null?$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$subtract$$($point$jscomp$30$$,$prev_h_prev_h__$1$$),1/3):null,$next_correction$$=$next_h_next_h__$1$$!=null?$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$subtract$$($point$jscomp$30$$,
$next_h_next_h__$1$$),1/3):null;$prev_h_prev_h__$1$$=$prev_h_prev_h__$1$$!=null?$APP.$app$common$geom$point$add$$($prev_h_prev_h__$1$$,$prev_correction$$):null;$next_h_next_h__$1$$=$next_h_next_h__$1$$!=null?$APP.$app$common$geom$point$add$$($next_h_next_h__$1$$,$next_correction$$):null;$G__48149__$1_G__48149__$2_content__$2$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1814$line_to$$,$curr_command_curr_segment$$)&&$prev_p$$!=null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($G__48149__$1_G__48149__$2_content__$2$jscomp$1$$,
$G__48149__$3_index$jscomp$194$$,$app$common$types$path$helpers$update_curve_to$$,$prev_p$$,$prev_h_prev_h__$1$$):$G__48149__$1_G__48149__$2_content__$2$jscomp$1$$;$G__48149__$1_G__48149__$2_content__$2$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1814$line_to$$,$next_command_next_segment$$)&&$next_p_p__48147$$!=null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($G__48149__$1_G__48149__$2_content__$2$jscomp$1$$,$map__48148__$1_next_i$jscomp$1$$,$app$common$types$path$helpers$update_curve_to$$,
$next_h_next_h__$1$$,$next_p_p__48147$$):$G__48149__$1_G__48149__$2_content__$2$jscomp$1$$;$G__48149__$3_index$jscomp$194$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,$curr_command_curr_segment$$)&&$prev_p$$!=null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($G__48149__$1_G__48149__$2_content__$2$jscomp$1$$,$G__48149__$3_index$jscomp$194$$,$app$common$types$path$segment$update_handler$$,$cljs$cst$1822$c2$$,$prev_h_prev_h__$1$$):$G__48149__$1_G__48149__$2_content__$2$jscomp$1$$;
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,$next_command_next_segment$$)&&$next_p_p__48147$$!=null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($G__48149__$3_index$jscomp$194$$,$map__48148__$1_next_i$jscomp$1$$,$app$common$types$path$segment$update_handler$$,$APP.$cljs$cst$1821$c1$$,$next_h_next_h__$1$$):$G__48149__$3_index$jscomp$194$$}}else $add_curve_indices_points$jscomp$11_v1$jscomp$27_vec__48141$$=function($G__48154__$1_G__48154__$2_G__48154__$3_content__$2$jscomp$2$$,
$next_c_p__48152$$){var $map__48153__$1_next_i$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($next_c_p__48152$$),$index$jscomp$195$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48153__$1_next_i$jscomp$2$$,$APP.$cljs$cst$1795$index$$),$segment$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48153__$1_next_i$jscomp$2$$,$APP.$cljs$cst$1861$segment$$),$prev_p$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48153__$1_next_i$jscomp$2$$,$cljs$cst$1856$prev_p$$);
$next_c_p__48152$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48153__$1_next_i$jscomp$2$$,$cljs$cst$1860$next_c$$);$map__48153__$1_next_i$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48153__$1_next_i$jscomp$2$$,$cljs$cst$1859$next_i$$);$G__48154__$1_G__48154__$2_G__48154__$3_content__$2$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1814$line_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$22$$))?
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__48154__$1_G__48154__$2_G__48154__$3_content__$2$jscomp$2$$,$index$jscomp$195$$,function($p1__48135_SHARP_$$){return $app$common$types$path$segment$line__GT_curve$$($prev_p$jscomp$1$$,$p1__48135_SHARP_$$)}):$G__48154__$1_G__48154__$2_G__48154__$3_content__$2$jscomp$2$$;$G__48154__$1_G__48154__$2_G__48154__$3_content__$2$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$22$$))?
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__48154__$1_G__48154__$2_G__48154__$3_content__$2$jscomp$2$$,$index$jscomp$195$$,function($p1__48136_SHARP_$$){return $app$common$types$path$segment$line__GT_curve$$($prev_p$jscomp$1$$,$p1__48136_SHARP_$$)}):$G__48154__$1_G__48154__$2_G__48154__$3_content__$2$jscomp$2$$;$G__48154__$1_G__48154__$2_G__48154__$3_content__$2$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1814$line_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($next_c_p__48152$$))?
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__48154__$1_G__48154__$2_G__48154__$3_content__$2$jscomp$2$$,$map__48153__$1_next_i$jscomp$2$$,function($p1__48137_SHARP_$$){return $app$common$types$path$segment$line__GT_curve$$($point$jscomp$30$$,$p1__48137_SHARP_$$)}):$G__48154__$1_G__48154__$2_G__48154__$3_content__$2$jscomp$2$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($next_c_p__48152$$))?
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__48154__$1_G__48154__$2_G__48154__$3_content__$2$jscomp$2$$,$map__48153__$1_next_i$jscomp$2$$,function($p1__48138_SHARP_$$){return $app$common$types$path$segment$line__GT_curve$$($point$jscomp$30$$,$p1__48138_SHARP_$$)}):$G__48154__$1_G__48154__$2_G__48154__$3_content__$2$jscomp$2$$};return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($add_curve_indices_points$jscomp$11_v1$jscomp$27_vec__48141$$,$content__$1$jscomp$3$$,$content$jscomp$35_vectors$$)};
$APP.$app$common$types$path$segment$get_segments_with_points$$=function($G__48384_content$jscomp$36_content__$1$jscomp$4$$,$point_set_points$jscomp$12$$){$point_set_points$jscomp$12$$=$APP.$cljs$core$set$$($point_set_points$jscomp$12$$);var $G__48165$jscomp$inline_5063_G__48380_result$jscomp$187$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$G__48381_prev_point$jscomp$3_prev_point__$1$$=null,$G__48382_start_point_start_point__$1$$=null,$G__48383_index$jscomp$196$$=0;
for($G__48384_content$jscomp$36_content__$1$jscomp$4$$=$APP.$cljs$core$seq$$($G__48384_content$jscomp$36_content__$1$jscomp$4$$);;){var $segment$jscomp$23_temp__5823__auto__$jscomp$104$$=$APP.$cljs$core$first$$($G__48384_content$jscomp$36_content__$1$jscomp$4$$);if($APP.$cljs$core$truth_$$($segment$jscomp$23_temp__5823__auto__$jscomp$104$$)){var $close_path_QMARK__cur_point$jscomp$1_map__48163__$1$$=$APP.$cljs$core$__destructure_map$$($segment$jscomp$23_temp__5823__auto__$jscomp$104$$);$segment$jscomp$23_temp__5823__auto__$jscomp$104$$=
$close_path_QMARK__cur_point$jscomp$1_map__48163__$1$$;var $command$jscomp$11_move_to_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($close_path_QMARK__cur_point$jscomp$1_map__48163__$1$$,$APP.$cljs$cst$1812$command$$);$close_path_QMARK__cur_point$jscomp$1_map__48163__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($command$jscomp$11_move_to_QMARK_$$,$APP.$cljs$cst$1850$close_path$$);$command$jscomp$11_move_to_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($command$jscomp$11_move_to_QMARK_$$,
$APP.$cljs$cst$1813$move_to$$);$close_path_QMARK__cur_point$jscomp$1_map__48163__$1$$=$close_path_QMARK__cur_point$jscomp$1_map__48163__$1$$?$G__48382_start_point_start_point__$1$$:$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$23_temp__5823__auto__$jscomp$104$$);$G__48381_prev_point$jscomp$3_prev_point__$1$$=$command$jscomp$11_move_to_QMARK_$$?null:$G__48381_prev_point$jscomp$3_prev_point__$1$$;$G__48382_start_point_start_point__$1$$=$command$jscomp$11_move_to_QMARK_$$?
$close_path_QMARK__cur_point$jscomp$1_map__48163__$1$$:$G__48382_start_point_start_point__$1$$;$G__48165$jscomp$inline_5063_G__48380_result$jscomp$187$$=$G__48381_prev_point$jscomp$3_prev_point__$1$$!=null&&$APP.$cljs$core$contains_QMARK_$$($point_set_points$jscomp$12$$,$G__48381_prev_point$jscomp$3_prev_point__$1$$)&&$APP.$cljs$core$contains_QMARK_$$($point_set_points$jscomp$12$$,$close_path_QMARK__cur_point$jscomp$1_map__48163__$1$$)?$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__48165$jscomp$inline_5063_G__48380_result$jscomp$187$$,
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($segment$jscomp$23_temp__5823__auto__$jscomp$104$$,$APP.$cljs$cst$1292$start$$,$G__48381_prev_point$jscomp$3_prev_point__$1$$),$APP.$cljs$cst$1293$end$$,$close_path_QMARK__cur_point$jscomp$1_map__48163__$1$$),$APP.$cljs$cst$1795$index$$,$G__48383_index$jscomp$196$$)):$G__48165$jscomp$inline_5063_G__48380_result$jscomp$187$$;$G__48381_prev_point$jscomp$3_prev_point__$1$$=
$close_path_QMARK__cur_point$jscomp$1_map__48163__$1$$;$G__48383_index$jscomp$196$$+=1;$G__48384_content$jscomp$36_content__$1$jscomp$4$$=$APP.$cljs$core$rest$$($G__48384_content$jscomp$36_content__$1$jscomp$4$$)}else return $APP.$cljs$core$_persistent_BANG_$$($G__48165$jscomp$inline_5063_G__48380_result$jscomp$187$$)}};
$APP.$app$common$types$path$segment$split_segments$$=function($content$jscomp$37$$,$points$jscomp$13$$,$value$jscomp$423$$){var $segment_changes$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$197_p__48169$$){var $end$jscomp$inline_5075_h11$jscomp$inline_5081_map__48170__$1$$=$APP.$cljs$core$__destructure_map$$($index$jscomp$197_p__48169$$),$JSCompiler_temp_const$jscomp$745_JSCompiler_temp_const$jscomp$747_command$jscomp$12$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$inline_5075_h11$jscomp$inline_5081_map__48170__$1$$,$APP.$cljs$cst$1812$command$$),$JSCompiler_inline_result$jscomp$746_JSCompiler_inline_result$jscomp$748_sp$jscomp$inline_5069_start$jscomp$206_to1$jscomp$inline_5080$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$inline_5075_h11$jscomp$inline_5081_map__48170__$1$$,$APP.$cljs$cst$1292$start$$),$end$jscomp$71_h1$jscomp$inline_5076_h21$jscomp$inline_5082_to_p$jscomp$inline_5068_vec__46680$jscomp$inline_5079$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$inline_5075_h11$jscomp$inline_5081_map__48170__$1$$,$APP.$cljs$cst$1293$end$$);$index$jscomp$197_p__48169$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$inline_5075_h11$jscomp$inline_5081_map__48170__$1$$,$APP.$cljs$cst$1795$index$$);switch($JSCompiler_temp_const$jscomp$745_JSCompiler_temp_const$jscomp$747_command$jscomp$12$$ instanceof $APP.$cljs$core$Keyword$$?$JSCompiler_temp_const$jscomp$745_JSCompiler_temp_const$jscomp$747_command$jscomp$12$$.$fqn$:
null){case "line-to":return $JSCompiler_temp_const$jscomp$745_JSCompiler_temp_const$jscomp$747_command$jscomp$12$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$end$jscomp$71_h1$jscomp$inline_5076_h21$jscomp$inline_5082_to_p$jscomp$inline_5068_vec__46680$jscomp$inline_5079$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$inline_5075_h11$jscomp$inline_5081_map__48170__$1$$),$JSCompiler_inline_result$jscomp$746_JSCompiler_inline_result$jscomp$748_sp$jscomp$inline_5069_start$jscomp$206_to1$jscomp$inline_5080$$=
$app$common$geom$point$lerp$$($JSCompiler_inline_result$jscomp$746_JSCompiler_inline_result$jscomp$748_sp$jscomp$inline_5069_start$jscomp$206_to1$jscomp$inline_5080$$,$end$jscomp$71_h1$jscomp$inline_5076_h21$jscomp$inline_5082_to_p$jscomp$inline_5068_vec__46680$jscomp$inline_5079$$,$value$jscomp$423$$),$JSCompiler_inline_result$jscomp$746_JSCompiler_inline_result$jscomp$748_sp$jscomp$inline_5069_start$jscomp$206_to1$jscomp$inline_5080$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$app$common$types$path$helpers$make_line_to$$($JSCompiler_inline_result$jscomp$746_JSCompiler_inline_result$jscomp$748_sp$jscomp$inline_5069_start$jscomp$206_to1$jscomp$inline_5080$$),$end$jscomp$inline_5075_h11$jscomp$inline_5081_map__48170__$1$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$745_JSCompiler_temp_const$jscomp$747_command$jscomp$12$$,[$index$jscomp$197_p__48169$$,$JSCompiler_inline_result$jscomp$746_JSCompiler_inline_result$jscomp$748_sp$jscomp$inline_5069_start$jscomp$206_to1$jscomp$inline_5080$$],
null);case "curve-to":$JSCompiler_temp_const$jscomp$745_JSCompiler_temp_const$jscomp$747_command$jscomp$12$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;var $h2$jscomp$inline_5077_params$jscomp$inline_5074_to2$jscomp$inline_5084_vec__46677$jscomp$inline_5078$$=$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$inline_5075_h11$jscomp$inline_5081_map__48170__$1$$);$end$jscomp$inline_5075_h11$jscomp$inline_5081_map__48170__$1$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$inline_5077_params$jscomp$inline_5074_to2$jscomp$inline_5084_vec__46677$jscomp$inline_5078$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$inline_5077_params$jscomp$inline_5074_to2$jscomp$inline_5084_vec__46677$jscomp$inline_5078$$));$end$jscomp$71_h1$jscomp$inline_5076_h21$jscomp$inline_5082_to_p$jscomp$inline_5068_vec__46680$jscomp$inline_5079$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1815$c1x$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$inline_5077_params$jscomp$inline_5074_to2$jscomp$inline_5084_vec__46677$jscomp$inline_5078$$),
$APP.$cljs$cst$1816$c1y$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$inline_5077_params$jscomp$inline_5074_to2$jscomp$inline_5084_vec__46677$jscomp$inline_5078$$));$h2$jscomp$inline_5077_params$jscomp$inline_5074_to2$jscomp$inline_5084_vec__46677$jscomp$inline_5078$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1817$c2x$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$inline_5077_params$jscomp$inline_5074_to2$jscomp$inline_5084_vec__46677$jscomp$inline_5078$$),$APP.$cljs$cst$1818$c2y$$.$cljs$core$IFn$_invoke$arity$1$($h2$jscomp$inline_5077_params$jscomp$inline_5074_to2$jscomp$inline_5084_vec__46677$jscomp$inline_5078$$));
$h2$jscomp$inline_5077_params$jscomp$inline_5074_to2$jscomp$inline_5084_vec__46677$jscomp$inline_5078$$=$app$common$types$path$helpers$curve_split$cljs$0core$0IFn$0_invoke$0arity$05$$($JSCompiler_inline_result$jscomp$746_JSCompiler_inline_result$jscomp$748_sp$jscomp$inline_5069_start$jscomp$206_to1$jscomp$inline_5080$$,$end$jscomp$inline_5075_h11$jscomp$inline_5081_map__48170__$1$$,$end$jscomp$71_h1$jscomp$inline_5076_h21$jscomp$inline_5082_to_p$jscomp$inline_5068_vec__46680$jscomp$inline_5079$$,
$h2$jscomp$inline_5077_params$jscomp$inline_5074_to2$jscomp$inline_5084_vec__46677$jscomp$inline_5078$$,$value$jscomp$423$$);$end$jscomp$71_h1$jscomp$inline_5076_h21$jscomp$inline_5082_to_p$jscomp$inline_5068_vec__46680$jscomp$inline_5079$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$inline_5077_params$jscomp$inline_5074_to2$jscomp$inline_5084_vec__46677$jscomp$inline_5078$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$71_h1$jscomp$inline_5076_h21$jscomp$inline_5082_to_p$jscomp$inline_5068_vec__46680$jscomp$inline_5079$$,
0,null);$JSCompiler_inline_result$jscomp$746_JSCompiler_inline_result$jscomp$748_sp$jscomp$inline_5069_start$jscomp$206_to1$jscomp$inline_5080$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$71_h1$jscomp$inline_5076_h21$jscomp$inline_5082_to_p$jscomp$inline_5068_vec__46680$jscomp$inline_5079$$,1,null);$end$jscomp$inline_5075_h11$jscomp$inline_5081_map__48170__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$71_h1$jscomp$inline_5076_h21$jscomp$inline_5082_to_p$jscomp$inline_5068_vec__46680$jscomp$inline_5079$$,
2,null);$end$jscomp$71_h1$jscomp$inline_5076_h21$jscomp$inline_5082_to_p$jscomp$inline_5068_vec__46680$jscomp$inline_5079$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$71_h1$jscomp$inline_5076_h21$jscomp$inline_5082_to_p$jscomp$inline_5068_vec__46680$jscomp$inline_5079$$,3,null);var $h22$jscomp$inline_5086_vec__46683$jscomp$inline_5083$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h2$jscomp$inline_5077_params$jscomp$inline_5074_to2$jscomp$inline_5084_vec__46677$jscomp$inline_5078$$,
1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h22$jscomp$inline_5086_vec__46683$jscomp$inline_5083$$,0,null);$h2$jscomp$inline_5077_params$jscomp$inline_5074_to2$jscomp$inline_5084_vec__46677$jscomp$inline_5078$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h22$jscomp$inline_5086_vec__46683$jscomp$inline_5083$$,1,null);var $h12$jscomp$inline_5085$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h22$jscomp$inline_5086_vec__46683$jscomp$inline_5083$$,2,null);
$h22$jscomp$inline_5086_vec__46683$jscomp$inline_5083$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h22$jscomp$inline_5086_vec__46683$jscomp$inline_5083$$,3,null);$JSCompiler_inline_result$jscomp$746_JSCompiler_inline_result$jscomp$748_sp$jscomp$inline_5069_start$jscomp$206_to1$jscomp$inline_5080$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$types$path$helpers$make_curve_to$$($JSCompiler_inline_result$jscomp$746_JSCompiler_inline_result$jscomp$748_sp$jscomp$inline_5069_start$jscomp$206_to1$jscomp$inline_5080$$,
$end$jscomp$inline_5075_h11$jscomp$inline_5081_map__48170__$1$$,$end$jscomp$71_h1$jscomp$inline_5076_h21$jscomp$inline_5082_to_p$jscomp$inline_5068_vec__46680$jscomp$inline_5079$$),$app$common$types$path$helpers$make_curve_to$$($h2$jscomp$inline_5077_params$jscomp$inline_5074_to2$jscomp$inline_5084_vec__46677$jscomp$inline_5078$$,$h12$jscomp$inline_5085$$,$h22$jscomp$inline_5086_vec__46683$jscomp$inline_5083$$)],null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$745_JSCompiler_temp_const$jscomp$747_command$jscomp$12$$,
[$index$jscomp$197_p__48169$$,$JSCompiler_inline_result$jscomp$746_JSCompiler_inline_result$jscomp$748_sp$jscomp$inline_5069_start$jscomp$206_to1$jscomp$inline_5080$$],null);case "close-path":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$197_p__48169$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$types$path$helpers$make_line_to$$($app$common$geom$point$lerp$$($JSCompiler_inline_result$jscomp$746_JSCompiler_inline_result$jscomp$748_sp$jscomp$inline_5069_start$jscomp$206_to1$jscomp$inline_5080$$,
$end$jscomp$71_h1$jscomp$inline_5076_h21$jscomp$inline_5082_to_p$jscomp$inline_5068_vec__46680$jscomp$inline_5079$$,$value$jscomp$423$$)),$end$jscomp$inline_5075_h11$jscomp$inline_5081_map__48170__$1$$],null)],null);default:return null}}),$APP.$app$common$types$path$segment$get_segments_with_points$$($content$jscomp$37$$,$points$jscomp$13$$));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($command$jscomp$13_p__48174$$){var $index$jscomp$198$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($command$jscomp$13_p__48174$$,0,null);$command$jscomp$13_p__48174$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($command$jscomp$13_p__48174$$,1,null);return $APP.$cljs$core$contains_QMARK_$$($segment_changes$$,$index$jscomp$198$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($segment_changes$$,$index$jscomp$198$$):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$command$jscomp$13_p__48174$$],
null)}),$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$37$$))};
$app$common$types$path$segment$next_node$$=function($add_line_QMARK__content$jscomp$38$$,$position$jscomp$10_position__$1$$,$add_curve_QMARK__prev_point$jscomp$4$$,$prev_handler$$){$position$jscomp$10_position__$1$$=$APP.$cljs$core$select_keys$$($position$jscomp$10_position__$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1511$y$$],null));var $last_command$$=$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($add_line_QMARK__content$jscomp$38$$));
$add_line_QMARK__content$jscomp$38$$=$APP.$cljs$core$truth_$$($add_curve_QMARK__prev_point$jscomp$4$$)?$APP.$cljs$core$not$$($prev_handler$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($last_command$$,$APP.$cljs$cst$1850$close_path$$):$add_curve_QMARK__prev_point$jscomp$4$$;$add_curve_QMARK__prev_point$jscomp$4$$=$APP.$cljs$core$truth_$$($add_curve_QMARK__prev_point$jscomp$4$$)?$APP.$cljs$core$truth_$$($prev_handler$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($last_command$$,
$APP.$cljs$cst$1850$close_path$$):$prev_handler$$:$add_curve_QMARK__prev_point$jscomp$4$$;return $APP.$cljs$core$truth_$$($add_line_QMARK__content$jscomp$38$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1814$line_to$$,$APP.$cljs$cst$1430$params$$,$position$jscomp$10_position__$1$$],null):$APP.$cljs$core$truth_$$($add_curve_QMARK__prev_point$jscomp$4$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,$cljs$cst$1819$curve_to$$,
$APP.$cljs$cst$1430$params$$,$app$common$types$path$helpers$make_curve_params$cljs$0core$0IFn$0_invoke$0arity$02$$($position$jscomp$10_position__$1$$,$prev_handler$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1430$params$$,$position$jscomp$10_position__$1$$],null)};
$app$common$types$path$segment$remove_nodes$$=function($content$jscomp$39_content__$1$jscomp$5$$,$points$jscomp$14$$){if($APP.$cljs$core$empty_QMARK_$$($points$jscomp$14$$))return $content$jscomp$39_content__$1$jscomp$5$$;$content$jscomp$39_content__$1$jscomp$5$$=$APP.$app$common$data$with_prev$$($content$jscomp$39_content__$1$jscomp$5$$);for(var $result$jscomp$188$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$G__48191$$=$APP.$cljs$core$first$$($content$jscomp$39_content__$1$jscomp$5$$),$cur_segment$jscomp$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__48191$$,0,null),$prev_segment$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__48191$$,1,null),$content__$2$jscomp$3$$=$APP.$cljs$core$rest$$($content$jscomp$39_content__$1$jscomp$5$$),$G__48394_point$jscomp$31_result__$1$jscomp$21$$=$result$jscomp$188$$,$G__48395_cur_handler_last_handler__$1$$=null,$G__48191__$1_G__48396$$=$G__48191$$,$content__$3$$=$content__$2$jscomp$3$$;;){var $result__$2$jscomp$2$$=$G__48394_point$jscomp$31_result__$1$jscomp$21$$,
$last_handler__$2$$=$G__48395_cur_handler_last_handler__$1$$,$vec__48212$$=$G__48191__$1_G__48396$$,$cur_segment__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__48212$$,0,null),$prev_segment__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__48212$$,1,null),$G__48397_content__$4$$=$content__$3$$;if($cur_segment__$1$$==null)return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$flatten$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function(){return function($p1__48182_SHARP_$$){return $APP.$cljs$core$count$$($p1__48182_SHARP_$$)>
1}}($G__48394_point$jscomp$31_result__$1$jscomp$21$$,$G__48395_cur_handler_last_handler__$1$$,$G__48191__$1_G__48396$$,$content__$3$$,$result__$2$jscomp$2$$,$last_handler__$2$$,$vec__48212$$,$cur_segment__$1$$,$prev_segment__$1$$,$G__48397_content__$4$$,$result$jscomp$188$$,null,$G__48191$$,$G__48191$$,$cur_segment$jscomp$2$$,$prev_segment$jscomp$1$$,$content__$2$jscomp$3$$,$content$jscomp$39_content__$1$jscomp$5$$),$result__$2$jscomp$2$$)));var $move_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1813$move_to$$,
$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($cur_segment__$1$$)),$curve_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($cur_segment__$1$$)),$result__$3$jscomp$1$$=$move_QMARK_$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result__$2$jscomp$2$$,$APP.$cljs$core$PersistentVector$EMPTY$$):$result__$2$jscomp$2$$,$subpath$$=$APP.$cljs$core$peek$$($result__$3$jscomp$1$$);
$G__48394_point$jscomp$31_result__$1$jscomp$21$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($cur_segment__$1$$);var $old_prev_point$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($prev_segment__$1$$),$new_prev_point$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$peek$$($subpath$$)),$remove_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($points$jscomp$14$$,
$G__48394_point$jscomp$31_result__$1$jscomp$21$$);$G__48395_cur_handler_last_handler__$1$$=$APP.$cljs$core$not$$($last_handler__$2$$)&&$remove_QMARK_$jscomp$1$$&&$curve_QMARK_$$?$APP.$cljs$core$select_keys$$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($cur_segment__$1$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1815$c1x$$,$APP.$cljs$cst$1816$c1y$$],null)):$remove_QMARK_$jscomp$1$$?$last_handler__$2$$:null;var $cur_segment__$2$$=
function(){var $G__48218_G__48218__$1$$=$cur_segment__$1$$;$G__48218_G__48218__$1$$=!$move_QMARK_$$&&$APP.$cljs$core$empty_QMARK_$$($subpath$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__48218_G__48218__$1$$,$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1813$move_to$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$select_keys$$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($cur_segment__$1$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1511$y$$],null))])):$G__48218_G__48218__$1$$;return $curve_QMARK_$$&&$APP.$cljs$core$seq$$($subpath$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($old_prev_point$$,$new_prev_point$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48218_G__48218__$1$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$merge$$,$last_handler__$2$$):$G__48218_G__48218__$1$$}(),$head_idx$$=$APP.$cljs$core$count$$($result__$3$jscomp$1$$)-
1;$G__48394_point$jscomp$31_result__$1$jscomp$21$$=function(){var $G__48220$$=$result__$3$jscomp$1$$;return $remove_QMARK_$jscomp$1$$?$G__48220$$:$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48220$$,$head_idx$$,$APP.$cljs$core$conj$$,$cur_segment__$2$$)}();$G__48191__$1_G__48396$$=$APP.$cljs$core$first$$($G__48397_content__$4$$);$content__$3$$=$G__48397_content__$4$$=$APP.$cljs$core$rest$$($G__48397_content__$4$$)}};
$app$common$types$path$segment$join_nodes$$=function($content$jscomp$40_content__$1$jscomp$7$$,$new_content_points$jscomp$15$$){$content$jscomp$40_content__$1$jscomp$7$$=$APP.$cljs$core$vec$$($content$jscomp$40_content__$1$jscomp$7$$);var $segments_set$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1292$start$$,$APP.$cljs$cst$1293$end$$)),
$APP.$app$common$types$path$segment$get_segments_with_points$$($content$jscomp$40_content__$1$jscomp$7$$,$new_content_points$jscomp$15$$));$new_content_points$jscomp$15$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$flatten$$($APP.$app$common$data$map_perm$cljs$0core$0IFn$0_invoke$0arity$03$$(function($point$jscomp$32$$,$other$jscomp$179$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$app$common$types$path$helpers$make_move_to$$($point$jscomp$32$$),$app$common$types$path$helpers$make_line_to$$($other$jscomp$179$$)],null)},function($point$jscomp$33$$,$other$jscomp$180$$){return!$APP.$cljs$core$contains_QMARK_$$($segments_set$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$point$jscomp$33$$,$other$jscomp$180$$],null))&&!$APP.$cljs$core$contains_QMARK_$$($segments_set$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$other$jscomp$180$$,$point$jscomp$33$$],null))},$new_content_points$jscomp$15$$)));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$40_content__$1$jscomp$7$$,$new_content_points$jscomp$15$$)};
$app$common$types$path$segment$separate_nodes$$=function($content$jscomp$41_content__$1$jscomp$8$$,$points$jscomp$16$$){$content$jscomp$41_content__$1$jscomp$8$$=$APP.$app$common$data$with_prev$$($content$jscomp$41_content__$1$jscomp$8$$);for(var $result$jscomp$190$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$G__48225$$=$APP.$cljs$core$first$$($content$jscomp$41_content__$1$jscomp$8$$),$cur_segment$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__48225$$,0,null),$prev_segment$jscomp$3$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__48225$$,1,null),$content__$2$jscomp$5$$=$APP.$cljs$core$rest$$($content$jscomp$41_content__$1$jscomp$8$$),$G__48400_cur_segment__$2$jscomp$1_result__$1$jscomp$23$$=$result$jscomp$190$$,$G__48225__$1_G__48401_result__$3$jscomp$2$$=$G__48225$$,$content__$3$jscomp$2$$=$content__$2$jscomp$5$$;;){var $head_idx$jscomp$1_result__$2$jscomp$4$$=$G__48400_cur_segment__$2$jscomp$1_result__$1$jscomp$23$$,$vec__48234$$=$G__48225__$1_G__48401_result__$3$jscomp$2$$,
$cur_segment__$1$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__48234$$,0,null),$prev_segment__$1$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__48234$$,1,null),$G__48402_content__$4$jscomp$2$$=$content__$3$jscomp$2$$;if($cur_segment__$1$jscomp$2$$==null)return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$flatten$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function(){return function($p1__48221_SHARP_$$){return $APP.$cljs$core$count$$($p1__48221_SHARP_$$)>
1}}($G__48400_cur_segment__$2$jscomp$1_result__$1$jscomp$23$$,$G__48225__$1_G__48401_result__$3$jscomp$2$$,$content__$3$jscomp$2$$,$head_idx$jscomp$1_result__$2$jscomp$4$$,$vec__48234$$,$cur_segment__$1$jscomp$2$$,$prev_segment__$1$jscomp$2$$,$G__48402_content__$4$jscomp$2$$,$result$jscomp$190$$,$G__48225$$,$G__48225$$,$cur_segment$jscomp$4$$,$prev_segment$jscomp$3$$,$content__$2$jscomp$5$$,$content$jscomp$41_content__$1$jscomp$8$$),$head_idx$jscomp$1_result__$2$jscomp$4$$)));var $prev_point$jscomp$5$$=
$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($prev_segment__$1$jscomp$2$$),$cur_point$jscomp$2$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($cur_segment__$1$jscomp$2$$);$G__48400_cur_segment__$2$jscomp$1_result__$1$jscomp$23$$=function(){var $G__48237$$=$cur_segment__$1$jscomp$2$$;return $APP.$cljs$core$contains_QMARK_$$($points$jscomp$16$$,$prev_point$jscomp$5$$)&&$APP.$cljs$core$contains_QMARK_$$($points$jscomp$16$$,
$cur_point$jscomp$2$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__48237$$,$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1813$move_to$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$select_keys$$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($cur_segment__$1$jscomp$2$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1511$y$$],
null))])):$G__48237$$}();$G__48225__$1_G__48401_result__$3$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($G__48400_cur_segment__$2$jscomp$1_result__$1$jscomp$23$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($head_idx$jscomp$1_result__$2$jscomp$4$$,$APP.$cljs$core$PersistentVector$EMPTY$$):$head_idx$jscomp$1_result__$2$jscomp$4$$;$head_idx$jscomp$1_result__$2$jscomp$4$$=$APP.$cljs$core$count$$($G__48225__$1_G__48401_result__$3$jscomp$2$$)-
1;$G__48400_cur_segment__$2$jscomp$1_result__$1$jscomp$23$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48225__$1_G__48401_result__$3$jscomp$2$$,$head_idx$jscomp$1_result__$2$jscomp$4$$,$APP.$cljs$core$conj$$,$G__48400_cur_segment__$2$jscomp$1_result__$1$jscomp$23$$);$G__48225__$1_G__48401_result__$3$jscomp$2$$=$APP.$cljs$core$first$$($G__48402_content__$4$jscomp$2$$);$content__$3$jscomp$2$$=$G__48402_content__$4$jscomp$2$$=$APP.$cljs$core$rest$$($G__48402_content__$4$jscomp$2$$)}};
$app$common$types$path$segment$add_to_set$$=function($set_list$$,$target$jscomp$118$$,$value$jscomp$424$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($it$jscomp$137$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$137$$,$target$jscomp$118$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$137$$,$value$jscomp$424$$):$it$jscomp$137$$},$set_list$$)};
$app$common$types$path$segment$join_sets$$=function($set_list$jscomp$1$$,$target$jscomp$119$$,$other$jscomp$181$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filterv$$(function($p1__48242_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__48242_SHARP_$$,$target$jscomp$119$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__48242_SHARP_$$,$other$jscomp$181$$)},$set_list$jscomp$1$$),$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($target$jscomp$119$$,
$other$jscomp$181$$))};
$app$common$types$path$segment$group_segments$$=function($segments$jscomp$6_segments__$1$$){var $result$jscomp$192$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$G__48248$$=$APP.$cljs$core$first$$($segments$jscomp$6_segments__$1$$),$map__48249__$1$$=$APP.$cljs$core$__destructure_map$$($G__48248$$),$point_a$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48249__$1$$,$APP.$cljs$cst$1292$start$$),$point_b$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48249__$1$$,$APP.$cljs$cst$1293$end$$);
$segments$jscomp$6_segments__$1$$=$APP.$cljs$core$rest$$($segments$jscomp$6_segments__$1$$);for(var $G__48410_result__$1$jscomp$25$$=$result$jscomp$192$$,$G__48248__$1_G__48411$$=$G__48248$$,$segments__$2$$=$segments$jscomp$6_segments__$1$$;;){var $result__$2$jscomp$6$$=$G__48410_result__$1$jscomp$25$$,$map__48254$$=$G__48248__$1_G__48411$$,$map__48254__$1$$=$APP.$cljs$core$__destructure_map$$($map__48254$$),$segment__$1$$=$map__48254__$1$$,$point_a__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48254__$1$$,
$APP.$cljs$cst$1292$start$$),$point_b__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48254__$1$$,$APP.$cljs$cst$1293$end$$),$G__48412_segments__$3$$=$segments__$2$$;if($segment__$1$$==null)return $result__$2$jscomp$6$$;var $set_a$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($result__$1$jscomp$26$$,$G__48248__$1$jscomp$1$$,$segments__$2$jscomp$1$$,$result__$2$jscomp$7$$,$map__48254$jscomp$1$$,$map__48254__$1$jscomp$1$$,$segment__$1$jscomp$1$$,$point_a__$1$jscomp$1$$){return function($p1__48243_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($p1__48243_SHARP_$$,
$point_a__$1$jscomp$1$$)}}($G__48410_result__$1$jscomp$25$$,$G__48248__$1_G__48411$$,$segments__$2$$,$result__$2$jscomp$6$$,$map__48254$$,$map__48254__$1$$,$segment__$1$$,$point_a__$1$$,$point_b__$1$$,$G__48412_segments__$3$$,$result$jscomp$192$$,$G__48248$$,$G__48248$$,$map__48249__$1$$,$map__48249__$1$$,$point_a$$,$point_b$$,$segments$jscomp$6_segments__$1$$),$result__$2$jscomp$6$$),$set_b$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($result__$1$jscomp$27$$,$G__48248__$1$jscomp$2$$,
$segments__$2$jscomp$2$$,$set_a$jscomp$1$$,$result__$2$jscomp$8$$,$map__48254$jscomp$2$$,$map__48254__$1$jscomp$2$$,$segment__$1$jscomp$2$$,$point_a__$1$jscomp$2$$,$point_b__$1$jscomp$2$$){return function($p1__48244_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($p1__48244_SHARP_$$,$point_b__$1$jscomp$2$$)}}($G__48410_result__$1$jscomp$25$$,$G__48248__$1_G__48411$$,$segments__$2$$,$set_a$$,$result__$2$jscomp$6$$,$map__48254$$,$map__48254__$1$$,$segment__$1$$,$point_a__$1$$,$point_b__$1$$,$G__48412_segments__$3$$,
$result$jscomp$192$$,$G__48248$$,$G__48248$$,$map__48249__$1$$,$map__48249__$1$$,$point_a$$,$point_b$$,$segments$jscomp$6_segments__$1$$),$result__$2$jscomp$6$$);$G__48410_result__$1$jscomp$25$$=function(){var $G__48255_G__48255__$1_G__48255__$2_G__48255__$3$$=$result__$2$jscomp$6$$;$G__48255_G__48255__$1_G__48255__$2_G__48255__$3$$=$set_a$$==null&&$set_b$$==null?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48255_G__48255__$1_G__48255__$2_G__48255__$3$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$point_b__$1$$,
$point_a__$1$$])):$G__48255_G__48255__$1_G__48255__$2_G__48255__$3$$;$G__48255_G__48255__$1_G__48255__$2_G__48255__$3$$=$set_a$$!=null&&$set_b$$==null?$app$common$types$path$segment$add_to_set$$($G__48255_G__48255__$1_G__48255__$2_G__48255__$3$$,$set_a$$,$point_b__$1$$):$G__48255_G__48255__$1_G__48255__$2_G__48255__$3$$;$G__48255_G__48255__$1_G__48255__$2_G__48255__$3$$=$set_a$$==null&&$set_b$$!=null?$app$common$types$path$segment$add_to_set$$($G__48255_G__48255__$1_G__48255__$2_G__48255__$3$$,$set_b$$,
$point_a__$1$$):$G__48255_G__48255__$1_G__48255__$2_G__48255__$3$$;return $set_a$$!=null&&$set_b$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($set_a$$,$set_b$$)?$app$common$types$path$segment$join_sets$$($G__48255_G__48255__$1_G__48255__$2_G__48255__$3$$,$set_a$$,$set_b$$):$G__48255_G__48255__$1_G__48255__$2_G__48255__$3$$}();$G__48248__$1_G__48411$$=$APP.$cljs$core$first$$($G__48412_segments__$3$$);$segments__$2$$=$G__48412_segments__$3$$=$APP.$cljs$core$rest$$($G__48412_segments__$3$$)}};
$app$common$types$path$segment$calculate_merge_points$$=function($group_segments$$,$point__GT_group_points$jscomp$17$$){var $group__GT_merge_point$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($group$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$group$$,$app$common$geom$point$center_points$$($group$$)],null)}),$group_segments$$);
$point__GT_group_points$jscomp$17$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($point$jscomp$34$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$point$jscomp$34$$,$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__48259_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($p1__48259_SHARP_$$,$point$jscomp$34$$)},
$group_segments$$)],null)}),$point__GT_group_points$jscomp$17$$);return $APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__48261_SHARP_$$,$p2__48260_SHARP_$$){return $group__GT_merge_point$$.$cljs$core$IFn$_invoke$arity$1$?$group__GT_merge_point$$.$cljs$core$IFn$_invoke$arity$1$($p2__48260_SHARP_$$):$group__GT_merge_point$$($p2__48260_SHARP_$$)},$point__GT_group_points$jscomp$17$$)};
$app$common$types$path$segment$replace_points$$=function($content$jscomp$42$$,$point__GT_merge_point$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($segment$jscomp$28$$){var $merge_point_point$jscomp$35$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$28$$);return $APP.$cljs$core$contains_QMARK_$$($point__GT_merge_point$$,$merge_point_point$jscomp$35$$)?($merge_point_point$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point__GT_merge_point$$,
$merge_point_point$jscomp$35$$),$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($segment$jscomp$28$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($merge_point_point$jscomp$35$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($merge_point_point$jscomp$35$$)]))):$segment$jscomp$28$$},$content$jscomp$42$$)};
$app$common$types$path$segment$transform_content$$=function($content$jscomp$44$$,$transform$jscomp$38$$){return $transform$jscomp$38$$!=null?$app$common$types$path$impl$_transform$$($APP.$app$common$types$path$impl$path_data$$($content$jscomp$44$$),$transform$jscomp$38$$):$content$jscomp$44$$};
$app$common$types$path$segment$calculate_extremities$$=function($G__48428_G__48435_G__48439_G__48445_content$jscomp$46_move_p$$){var $points$jscomp$19$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$vec$$($G__48428_G__48435_G__48439_G__48445_content$jscomp$46_move_p$$)),$from_p$jscomp$11$$=null;for($G__48428_G__48435_G__48439_G__48445_content$jscomp$46_move_p$$=
null;;){if($APP.$cljs$core$truth_$$($G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$)){var $G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$=$APP.$cljs$core$peek$$($G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$);$G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$))?
$APP.$cljs$core$pop$$($G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$):$G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$;$G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$,0);var $to_p$jscomp$10$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$);
if($APP.$cljs$core$truth_$$($G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$)){var $G__48292_G__48292__$1_G__48431_G__48434_G__48438_G__48444$$=$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$);$G__48292_G__48292__$1_G__48431_G__48434_G__48438_G__48444$$=$G__48292_G__48292__$1_G__48431_G__48434_G__48438_G__48444$$ instanceof $APP.$cljs$core$Keyword$$?$G__48292_G__48292__$1_G__48431_G__48434_G__48438_G__48444$$.$fqn$:
null;switch($G__48292_G__48292__$1_G__48431_G__48434_G__48438_G__48444$$){case "move-to":$G__48428_G__48435_G__48439_G__48445_content$jscomp$46_move_p$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($points$jscomp$19$$,$to_p$jscomp$10$$);$G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$,
1));$G__48292_G__48292__$1_G__48431_G__48434_G__48438_G__48444$$=$G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$=$to_p$jscomp$10$$;$points$jscomp$19$$=$G__48428_G__48435_G__48439_G__48445_content$jscomp$46_move_p$$;$from_p$jscomp$11$$=$G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$;$G__48428_G__48435_G__48439_G__48445_content$jscomp$46_move_p$$=$G__48292_G__48292__$1_G__48431_G__48434_G__48438_G__48444$$;continue;case "close-path":$G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$=
$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($points$jscomp$19$$,$G__48428_G__48435_G__48439_G__48445_content$jscomp$46_move_p$$);$G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$,1));$G__48292_G__48292__$1_G__48431_G__48434_G__48438_G__48444$$=$G__48428_G__48435_G__48439_G__48445_content$jscomp$46_move_p$$;
$points$jscomp$19$$=$G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$;$from_p$jscomp$11$$=$G__48292_G__48292__$1_G__48431_G__48434_G__48438_G__48444$$;continue;case "line-to":$G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$=function(){var $G__48293$$=$points$jscomp$19$$,$and__5023__auto__$jscomp$inline_5088$$=$from_p$jscomp$11$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_5088$$)?$to_p$jscomp$10$$:$and__5023__auto__$jscomp$inline_5088$$)?
$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__48293$$,$from_p$jscomp$11$$),$to_p$jscomp$10$$):$G__48293$$}();$G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$,1));$G__48292_G__48292__$1_G__48431_G__48434_G__48438_G__48444$$=
$to_p$jscomp$10$$;$points$jscomp$19$$=$G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$;$from_p$jscomp$11$$=$G__48292_G__48292__$1_G__48431_G__48434_G__48438_G__48444$$;continue;case "curve-to":var $c1$jscomp$27$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$2$($G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$,$APP.$cljs$cst$1821$c1$$),$c2$jscomp$19$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$2$($G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$,
$cljs$cst$1822$c2$$);$G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$244_and__5023__auto____$1$jscomp$45_and__5023__auto____$2$jscomp$18$$=$from_p$jscomp$11$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$244_and__5023__auto____$1$jscomp$45_and__5023__auto____$2$jscomp$18$$)?($and__5023__auto__$jscomp$244_and__5023__auto____$1$jscomp$45_and__5023__auto____$2$jscomp$18$$=$to_p$jscomp$10$$,$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$244_and__5023__auto____$1$jscomp$45_and__5023__auto____$2$jscomp$18$$)?
($and__5023__auto__$jscomp$244_and__5023__auto____$1$jscomp$45_and__5023__auto____$2$jscomp$18$$=$c1$jscomp$27$$,$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$244_and__5023__auto____$1$jscomp$45_and__5023__auto____$2$jscomp$18$$)?$c2$jscomp$19$$:$and__5023__auto__$jscomp$244_and__5023__auto____$1$jscomp$45_and__5023__auto____$2$jscomp$18$$):$and__5023__auto__$jscomp$244_and__5023__auto____$1$jscomp$45_and__5023__auto____$2$jscomp$18$$):$and__5023__auto__$jscomp$244_and__5023__auto____$1$jscomp$45_and__5023__auto____$2$jscomp$18$$}())?
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj_BANG_$$,$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($points$jscomp$19$$,$from_p$jscomp$11$$),$to_p$jscomp$10$$),$app$common$types$path$helpers$calculate_curve_extremities$$($from_p$jscomp$11$$,$to_p$jscomp$10$$,$c1$jscomp$27$$,$c2$jscomp$19$$)):$points$jscomp$19$$;$G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$=
$APP.$cljs$core$not_empty$$($APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48429_G__48433_G__48437_G__48443_content__$1$jscomp$10_content__$2$jscomp$7$$,1));$G__48292_G__48292__$1_G__48431_G__48434_G__48438_G__48444$$=$to_p$jscomp$10$$;$points$jscomp$19$$=$G__48430_G__48432_G__48436_G__48442_last_p_segment$jscomp$29$$;$from_p$jscomp$11$$=$G__48292_G__48292__$1_G__48431_G__48434_G__48438_G__48444$$;continue;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__48292_G__48292__$1_G__48431_G__48434_G__48438_G__48444$$)].join(""));
}}else return $APP.$cljs$core$_persistent_BANG_$$($points$jscomp$19$$)}else return $APP.$cljs$core$_persistent_BANG_$$($points$jscomp$19$$);break}};
$app$common$types$path$segment$content__GT_selrect$$=function($content$jscomp$47_extremities__$1$$){var $extremities$$=$app$common$types$path$segment$calculate_extremities$$($content$jscomp$47_extremities__$1$$);$content$jscomp$47_extremities__$1$$=$APP.$cljs$core$empty_QMARK_$$($extremities$$)?$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$path$helpers$segment__GT_point$$,$content$jscomp$47_extremities__$1$$):$extremities$$;return $APP.$app$common$data$not_empty_QMARK_$$($content$jscomp$47_extremities__$1$$)?
$APP.$app$common$geom$rect$points__GT_rect$$($content$jscomp$47_extremities__$1$$):$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$0$()};
$app$common$types$path$segment$points__GT_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($G__48450_points$jscomp$20_points__$1$jscomp$1$$,$close_map__48313__$1_p__48312_result__$1$jscomp$28$$){function $point__GT_params$$($point$jscomp$37$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$point$jscomp$37$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$37$$,$APP.$cljs$cst$1510$x$$),$APP.$cljs$cst$1511$y$$,$point$jscomp$37$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$37$$,$APP.$cljs$cst$1511$y$$)],null)}$close_map__48313__$1_p__48312_result__$1$jscomp$28$$=$APP.$cljs$core$__destructure_map$$($close_map__48313__$1_p__48312_result__$1$jscomp$28$$);$close_map__48313__$1_p__48312_result__$1$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($close_map__48313__$1_p__48312_result__$1$jscomp$28$$,$cljs$cst$1862$close$$);var $G__48451_initial$jscomp$14_result$jscomp$195$$=$APP.$cljs$core$first$$($G__48450_points$jscomp$20_points__$1$jscomp$1$$);
$G__48450_points$jscomp$20_points__$1$jscomp$1$$=$APP.$cljs$core$rest$$($G__48450_points$jscomp$20_points__$1$jscomp$1$$);for($G__48451_initial$jscomp$14_result$jscomp$195$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1430$params$$,$point__GT_params$$($G__48451_initial$jscomp$14_result$jscomp$195$$)],null)],null);;){var $point$jscomp$36_temp__5823__auto__$jscomp$105$$=
$APP.$cljs$core$first$$($G__48450_points$jscomp$20_points__$1$jscomp$1$$);if($APP.$cljs$core$truth_$$($point$jscomp$36_temp__5823__auto__$jscomp$105$$))$G__48450_points$jscomp$20_points__$1$jscomp$1$$=$APP.$cljs$core$rest$$($G__48450_points$jscomp$20_points__$1$jscomp$1$$),$G__48451_initial$jscomp$14_result$jscomp$195$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48451_initial$jscomp$14_result$jscomp$195$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1812$command$$,
$APP.$cljs$cst$1814$line_to$$,$APP.$cljs$cst$1430$params$$,$point__GT_params$$($point$jscomp$36_temp__5823__auto__$jscomp$105$$)],null));else return $close_map__48313__$1_p__48312_result__$1$jscomp$28$$=$APP.$cljs$core$truth_$$($close_map__48313__$1_p__48312_result__$1$jscomp$28$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48451_initial$jscomp$14_result$jscomp$195$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1850$close_path$$],null)):
$G__48451_initial$jscomp$14_result$jscomp$195$$,$APP.$app$common$types$path$impl$from_plain$$($close_map__48313__$1_p__48312_result__$1$jscomp$28$$)}};$app$common$types$path$subpath$pt_EQ_$$=function($p1$jscomp$48$$,$p2$jscomp$37$$){return $APP.$app$common$geom$point$distance$$($p1$jscomp$48$$,$p2$jscomp$37$$)<.1};
$app$common$types$path$subpath$make_subpath$cljs$0core$0IFn$0_invoke$0arity$03$$=function($from$jscomp$13$$,$to$jscomp$15$$,$data$jscomp$134$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1863$from$$,$from$jscomp$13$$,$APP.$cljs$cst$1864$to$$,$to$jscomp$15$$,$APP.$cljs$cst$142$data$$,$data$jscomp$134$$],null)};
$app$common$types$path$subpath$add_subpath_command$$=function($subpath$jscomp$1$$,$command$jscomp$15_command__$1$jscomp$1$$){$command$jscomp$15_command__$1$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1850$close_path$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($command$jscomp$15_command__$1$jscomp$1$$))?$app$common$types$path$helpers$make_line_to$$($APP.$cljs$cst$1863$from$$.$cljs$core$IFn$_invoke$arity$1$($subpath$jscomp$1$$)):$command$jscomp$15_command__$1$jscomp$1$$;
var $p$jscomp$202$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($command$jscomp$15_command__$1$jscomp$1$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($subpath$jscomp$1$$,$APP.$cljs$cst$1864$to$$,$p$jscomp$202$$),$APP.$cljs$cst$142$data$$,$APP.$cljs$core$conj$$,$command$jscomp$15_command__$1$jscomp$1$$)};
$app$common$types$path$subpath$reverse_subpath$$=function($subpath$jscomp$2$$){var $new_data$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($JSCompiler_temp$jscomp$783_result$jscomp$196$$,$JSCompiler_temp_const$jscomp$784_p__47789$$){var $JSCompiler_inline_result$jscomp$786_command$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$784_p__47789$$,0,null),$G__47788$jscomp$inline_5102_map__47786$jscomp$inline_5092_prev$jscomp$14_x$jscomp$inline_5094$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$784_p__47789$$,1,null);if($G__47788$jscomp$inline_5102_map__47786$jscomp$inline_5092_prev$jscomp$14_x$jscomp$inline_5094$$!=null){$JSCompiler_temp_const$jscomp$784_p__47789$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$;$G__47788$jscomp$inline_5102_map__47786$jscomp$inline_5092_prev$jscomp$14_x$jscomp$inline_5094$$=$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($G__47788$jscomp$inline_5102_map__47786$jscomp$inline_5092_prev$jscomp$14_x$jscomp$inline_5094$$);
var $map__47786__$1$jscomp$inline_5093_y$jscomp$inline_5095$$=$APP.$cljs$core$__destructure_map$$($G__47788$jscomp$inline_5102_map__47786$jscomp$inline_5092_prev$jscomp$14_x$jscomp$inline_5094$$);$G__47788$jscomp$inline_5102_map__47786$jscomp$inline_5092_prev$jscomp$14_x$jscomp$inline_5094$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47786__$1$jscomp$inline_5093_y$jscomp$inline_5095$$,$APP.$cljs$cst$1510$x$$);$map__47786__$1$jscomp$inline_5093_y$jscomp$inline_5095$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47786__$1$jscomp$inline_5093_y$jscomp$inline_5095$$,
$APP.$cljs$cst$1511$y$$);var $c1x$jscomp$inline_5098_map__47787$jscomp$inline_5096$$=$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$786_command$jscomp$17$$),$c2y$jscomp$inline_5101_map__47787__$1$jscomp$inline_5097$$=$APP.$cljs$core$__destructure_map$$($c1x$jscomp$inline_5098_map__47787$jscomp$inline_5096$$);$c1x$jscomp$inline_5098_map__47787$jscomp$inline_5096$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c2y$jscomp$inline_5101_map__47787__$1$jscomp$inline_5097$$,
$APP.$cljs$cst$1815$c1x$$);var $c1y$jscomp$inline_5099$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c2y$jscomp$inline_5101_map__47787__$1$jscomp$inline_5097$$,$APP.$cljs$cst$1816$c1y$$),$c2x$jscomp$inline_5100$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c2y$jscomp$inline_5101_map__47787__$1$jscomp$inline_5097$$,$APP.$cljs$cst$1817$c2x$$);$c2y$jscomp$inline_5101_map__47787__$1$jscomp$inline_5097$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c2y$jscomp$inline_5101_map__47787__$1$jscomp$inline_5097$$,
$APP.$cljs$cst$1818$c2y$$);$G__47788$jscomp$inline_5102_map__47786$jscomp$inline_5092_prev$jscomp$14_x$jscomp$inline_5094$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_inline_result$jscomp$786_command$jscomp$17$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1510$x$$,$G__47788$jscomp$inline_5102_map__47786$jscomp$inline_5092_prev$jscomp$14_x$jscomp$inline_5094$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__47786__$1$jscomp$inline_5093_y$jscomp$inline_5095$$]));
$JSCompiler_inline_result$jscomp$786_command$jscomp$17$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$786_command$jscomp$17$$))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($G__47788$jscomp$inline_5102_map__47786$jscomp$inline_5092_prev$jscomp$14_x$jscomp$inline_5094$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1815$c1x$$,$c2x$jscomp$inline_5100$$,
$APP.$cljs$cst$1816$c1y$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$c2y$jscomp$inline_5101_map__47787__$1$jscomp$inline_5097$$,$APP.$cljs$cst$1817$c2x$$,$c1x$jscomp$inline_5098_map__47787$jscomp$inline_5096$$,$APP.$cljs$cst$1818$c2y$$,$c1y$jscomp$inline_5099$$])):$G__47788$jscomp$inline_5102_map__47786$jscomp$inline_5092_prev$jscomp$14_x$jscomp$inline_5094$$;$JSCompiler_temp$jscomp$783_result$jscomp$196$$=$JSCompiler_temp_const$jscomp$784_p__47789$$.call($APP.$cljs$core$conj$$,
$JSCompiler_temp$jscomp$783_result$jscomp$196$$,$JSCompiler_inline_result$jscomp$786_command$jscomp$17$$)}return $JSCompiler_temp$jscomp$783_result$jscomp$196$$},new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$types$path$helpers$make_move_to$$($APP.$cljs$cst$1864$to$$.$cljs$core$IFn$_invoke$arity$1$($subpath$jscomp$2$$))],null),$APP.$cljs$core$reverse$$($APP.$app$common$data$with_prev$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($subpath$jscomp$2$$))));
return $app$common$types$path$subpath$make_subpath$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$1864$to$$.$cljs$core$IFn$_invoke$arity$1$($subpath$jscomp$2$$),$APP.$cljs$cst$1863$from$$.$cljs$core$IFn$_invoke$arity$1$($subpath$jscomp$2$$),$new_data$$)};
$app$common$types$path$subpath$get_subpaths$$=function($content$jscomp$50$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($JSCompiler_temp$jscomp$779_subpaths$$,$current$jscomp$22$$){var $JSCompiler_temp_const$jscomp$780_is_move_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$22$$)),$last_idx_p$jscomp$inline_5105$$=$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$779_subpaths$$)-
1;$JSCompiler_temp_const$jscomp$780_is_move_QMARK_$$?($JSCompiler_temp_const$jscomp$780_is_move_QMARK_$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$,$last_idx_p$jscomp$inline_5105$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$22$$),$JSCompiler_temp$jscomp$779_subpaths$$=$JSCompiler_temp_const$jscomp$780_is_move_QMARK_$$.call($APP.$cljs$core$conj$$,$JSCompiler_temp$jscomp$779_subpaths$$,$app$common$types$path$subpath$make_subpath$cljs$0core$0IFn$0_invoke$0arity$03$$($last_idx_p$jscomp$inline_5105$$,
$last_idx_p$jscomp$inline_5105$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$current$jscomp$22$$],null)))):$JSCompiler_temp$jscomp$779_subpaths$$=$last_idx_p$jscomp$inline_5105$$>=0?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$779_subpaths$$,$last_idx_p$jscomp$inline_5105$$,$app$common$types$path$subpath$add_subpath_command$$,$current$jscomp$22$$):$JSCompiler_temp$jscomp$779_subpaths$$;return $JSCompiler_temp$jscomp$779_subpaths$$},
$APP.$cljs$core$PersistentVector$EMPTY$$,$content$jscomp$50$$)};$app$common$types$path$subpath$subpaths_join$$=function($subpath$jscomp$3$$,$other$jscomp$182$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($subpath$jscomp$3$$,$APP.$cljs$cst$142$data$$,$APP.$app$common$data$concat_vec$$,$APP.$cljs$core$rest$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$182$$))),$APP.$cljs$cst$1864$to$$,$APP.$cljs$cst$1864$to$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$182$$))};
$app$common$types$path$subpath$merge_paths$$=function($candidate$jscomp$8$$,$subpaths$jscomp$1$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__47797_result$jscomp$197$$,$current$jscomp$23$$){var $candidate__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__47797_result$jscomp$197$$,0,null);$p__47797_result$jscomp$197$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__47797_result$jscomp$197$$,1,null);return $app$common$types$path$subpath$pt_EQ_$$($APP.$cljs$cst$1864$to$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$23$$),
$APP.$cljs$cst$1863$from$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$23$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$candidate__$1$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p__47797_result$jscomp$197$$,$current$jscomp$23$$)],null):$app$common$types$path$subpath$pt_EQ_$$($APP.$cljs$cst$1864$to$$.$cljs$core$IFn$_invoke$arity$1$($candidate__$1$$),$APP.$cljs$cst$1863$from$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$23$$))?
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$types$path$subpath$subpaths_join$$($candidate__$1$$,$current$jscomp$23$$),$p__47797_result$jscomp$197$$],null):$app$common$types$path$subpath$pt_EQ_$$($APP.$cljs$cst$1863$from$$.$cljs$core$IFn$_invoke$arity$1$($candidate__$1$$),$APP.$cljs$cst$1864$to$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$23$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$app$common$types$path$subpath$subpaths_join$$($current$jscomp$23$$,$candidate__$1$$),$p__47797_result$jscomp$197$$],null):$app$common$types$path$subpath$pt_EQ_$$($APP.$cljs$cst$1864$to$$.$cljs$core$IFn$_invoke$arity$1$($candidate__$1$$),$APP.$cljs$cst$1864$to$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$23$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$types$path$subpath$subpaths_join$$($candidate__$1$$,$app$common$types$path$subpath$reverse_subpath$$($current$jscomp$23$$)),
$p__47797_result$jscomp$197$$],null):$app$common$types$path$subpath$pt_EQ_$$($APP.$cljs$cst$1863$from$$.$cljs$core$IFn$_invoke$arity$1$($candidate__$1$$),$APP.$cljs$cst$1863$from$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$23$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$types$path$subpath$subpaths_join$$($app$common$types$path$subpath$reverse_subpath$$($current$jscomp$23$$),$candidate__$1$$),$p__47797_result$jscomp$197$$],null):
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$candidate__$1$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p__47797_result$jscomp$197$$,$current$jscomp$23$$)],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$candidate$jscomp$8$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$subpaths$jscomp$1$$)};
$app$common$types$path$subpath$is_closed_QMARK_$$=function($subpath$jscomp$4$$){return $app$common$types$path$subpath$pt_EQ_$$($APP.$cljs$cst$1863$from$$.$cljs$core$IFn$_invoke$arity$1$($subpath$jscomp$4$$),$APP.$cljs$cst$1864$to$$.$cljs$core$IFn$_invoke$arity$1$($subpath$jscomp$4$$))};
$app$common$types$path$subpath$join_adjacent$$=function($acc$jscomp$94$$,$subpath$jscomp$5$$){var $temp__5823__auto__$jscomp$106$$=$APP.$cljs$core$peek$$($acc$jscomp$94$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$106$$)?$app$common$types$path$subpath$is_closed_QMARK_$$($temp__5823__auto__$jscomp$106$$)||$app$common$types$path$subpath$is_closed_QMARK_$$($subpath$jscomp$5$$)||!$app$common$types$path$subpath$pt_EQ_$$($APP.$cljs$cst$1864$to$$.$cljs$core$IFn$_invoke$arity$1$($temp__5823__auto__$jscomp$106$$),
$APP.$cljs$cst$1863$from$$.$cljs$core$IFn$_invoke$arity$1$($subpath$jscomp$5$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$94$$,$subpath$jscomp$5$$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pop$$($acc$jscomp$94$$),$app$common$types$path$subpath$subpaths_join$$($temp__5823__auto__$jscomp$106$$,$subpath$jscomp$5$$)):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$94$$,$subpath$jscomp$5$$)};
$app$common$types$path$subpath$close_subpaths$$=function($G__47827$jscomp$inline_5113_closed_subpaths_content$jscomp$52_result$jscomp$inline_5107$$){var $G__47829$jscomp$inline_5115_new_current$jscomp$inline_5111_subpaths$jscomp$3_subpaths__$1$jscomp$inline_5109$$=$app$common$types$path$subpath$get_subpaths$$($G__47827$jscomp$inline_5113_closed_subpaths_content$jscomp$52_result$jscomp$inline_5107$$);a:{$G__47827$jscomp$inline_5113_closed_subpaths_content$jscomp$52_result$jscomp$inline_5107$$=$APP.$cljs$core$PersistentVector$EMPTY$$;
var $G__47828$jscomp$inline_5114_current$jscomp$inline_5108$$=$APP.$cljs$core$first$$($G__47829$jscomp$inline_5115_new_current$jscomp$inline_5111_subpaths$jscomp$3_subpaths__$1$jscomp$inline_5109$$);for($G__47829$jscomp$inline_5115_new_current$jscomp$inline_5111_subpaths$jscomp$3_subpaths__$1$jscomp$inline_5109$$=$APP.$cljs$core$rest$$($G__47829$jscomp$inline_5115_new_current$jscomp$inline_5111_subpaths$jscomp$3_subpaths__$1$jscomp$inline_5109$$);;)if($G__47828$jscomp$inline_5114_current$jscomp$inline_5108$$!=
null){var $G__47832$jscomp$inline_5116_new_subpaths$jscomp$inline_5112_vec__47809$jscomp$inline_5110$$=$app$common$types$path$subpath$is_closed_QMARK_$$($G__47828$jscomp$inline_5114_current$jscomp$inline_5108$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__47828$jscomp$inline_5114_current$jscomp$inline_5108$$,$G__47829$jscomp$inline_5115_new_current$jscomp$inline_5111_subpaths$jscomp$3_subpaths__$1$jscomp$inline_5109$$],null):$app$common$types$path$subpath$merge_paths$$($G__47828$jscomp$inline_5114_current$jscomp$inline_5108$$,
$G__47829$jscomp$inline_5115_new_current$jscomp$inline_5111_subpaths$jscomp$3_subpaths__$1$jscomp$inline_5109$$);$G__47829$jscomp$inline_5115_new_current$jscomp$inline_5111_subpaths$jscomp$3_subpaths__$1$jscomp$inline_5109$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__47832$jscomp$inline_5116_new_subpaths$jscomp$inline_5112_vec__47809$jscomp$inline_5110$$,0,null);$G__47832$jscomp$inline_5116_new_subpaths$jscomp$inline_5112_vec__47809$jscomp$inline_5110$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__47832$jscomp$inline_5116_new_subpaths$jscomp$inline_5112_vec__47809$jscomp$inline_5110$$,
1,null);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__47828$jscomp$inline_5114_current$jscomp$inline_5108$$,$G__47829$jscomp$inline_5115_new_current$jscomp$inline_5111_subpaths$jscomp$3_subpaths__$1$jscomp$inline_5109$$)?($G__47827$jscomp$inline_5113_closed_subpaths_content$jscomp$52_result$jscomp$inline_5107$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__47827$jscomp$inline_5113_closed_subpaths_content$jscomp$52_result$jscomp$inline_5107$$,$G__47829$jscomp$inline_5115_new_current$jscomp$inline_5111_subpaths$jscomp$3_subpaths__$1$jscomp$inline_5109$$),
$G__47828$jscomp$inline_5114_current$jscomp$inline_5108$$=$APP.$cljs$core$first$$($G__47832$jscomp$inline_5116_new_subpaths$jscomp$inline_5112_vec__47809$jscomp$inline_5110$$),$G__47829$jscomp$inline_5115_new_current$jscomp$inline_5111_subpaths$jscomp$3_subpaths__$1$jscomp$inline_5109$$=$APP.$cljs$core$rest$$($G__47832$jscomp$inline_5116_new_subpaths$jscomp$inline_5112_vec__47809$jscomp$inline_5110$$)):($G__47828$jscomp$inline_5114_current$jscomp$inline_5108$$=$G__47829$jscomp$inline_5115_new_current$jscomp$inline_5111_subpaths$jscomp$3_subpaths__$1$jscomp$inline_5109$$,
$G__47829$jscomp$inline_5115_new_current$jscomp$inline_5111_subpaths$jscomp$3_subpaths__$1$jscomp$inline_5109$$=$G__47832$jscomp$inline_5116_new_subpaths$jscomp$inline_5112_vec__47809$jscomp$inline_5110$$)}else break a;$G__47827$jscomp$inline_5113_closed_subpaths_content$jscomp$52_result$jscomp$inline_5107$$=void 0}return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$common$types$path$subpath$xf_mapcat_data$$,$G__47827$jscomp$inline_5113_closed_subpaths_content$jscomp$52_result$jscomp$inline_5107$$)};
$app$common$types$path$subpath$clockwise_QMARK_$$=function($G__47835_content$jscomp$54_subpath$jscomp$6_subpath__$1$$){$G__47835_content$jscomp$54_subpath$jscomp$6_subpath__$1$$=$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($app$common$types$path$subpath$get_subpaths$$($G__47835_content$jscomp$54_subpath$jscomp$6_subpath__$1$$)));var $current$jscomp$25_map__47815_signed_area__$1_x1$jscomp$27$$=$APP.$cljs$core$first$$($G__47835_content$jscomp$54_subpath$jscomp$6_subpath__$1$$);
$G__47835_content$jscomp$54_subpath$jscomp$6_subpath__$1$$=$APP.$cljs$core$rest$$($G__47835_content$jscomp$54_subpath$jscomp$6_subpath__$1$$);for(var $G__47836_first_point_first_point__$1$$=null,$G__47834_signed_area$$=0;;){if($current$jscomp$25_map__47815_signed_area__$1_x1$jscomp$27$$==null)return $G__47834_signed_area$$>0;$current$jscomp$25_map__47815_signed_area__$1_x1$jscomp$27$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$25_map__47815_signed_area__$1_x1$jscomp$27$$);
var $G__47837_map__47815__$1_y1$jscomp$29$$=$APP.$cljs$core$__destructure_map$$($current$jscomp$25_map__47815_signed_area__$1_x1$jscomp$27$$),$map__47816_p$jscomp$203_x2$jscomp$25$$=$G__47837_map__47815__$1_y1$jscomp$29$$;$current$jscomp$25_map__47815_signed_area__$1_x1$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__47837_map__47815__$1_y1$jscomp$29$$,$APP.$cljs$cst$1510$x$$);$G__47837_map__47815__$1_y1$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__47837_map__47815__$1_y1$jscomp$29$$,
$APP.$cljs$cst$1511$y$$);var $last_QMARK__map__47816__$1_y2$jscomp$27$$=$APP.$cljs$core$first$$($G__47835_content$jscomp$54_subpath$jscomp$6_subpath__$1$$)==null;$G__47836_first_point_first_point__$1$$=$G__47836_first_point_first_point__$1$$==null?$map__47816_p$jscomp$203_x2$jscomp$25$$:$G__47836_first_point_first_point__$1$$;$map__47816_p$jscomp$203_x2$jscomp$25$$=$last_QMARK__map__47816__$1_y2$jscomp$27$$?$G__47836_first_point_first_point__$1$$:$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($G__47835_content$jscomp$54_subpath$jscomp$6_subpath__$1$$));
$last_QMARK__map__47816__$1_y2$jscomp$27$$=$APP.$cljs$core$__destructure_map$$($map__47816_p$jscomp$203_x2$jscomp$25$$);$map__47816_p$jscomp$203_x2$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_QMARK__map__47816__$1_y2$jscomp$27$$,$APP.$cljs$cst$1510$x$$);$last_QMARK__map__47816__$1_y2$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_QMARK__map__47816__$1_y2$jscomp$27$$,$APP.$cljs$cst$1511$y$$);$current$jscomp$25_map__47815_signed_area__$1_x1$jscomp$27$$=
$G__47834_signed_area$$+($current$jscomp$25_map__47815_signed_area__$1_x1$jscomp$27$$*$last_QMARK__map__47816__$1_y2$jscomp$27$$-$map__47816_p$jscomp$203_x2$jscomp$25$$*$G__47837_map__47815__$1_y1$jscomp$29$$);$G__47834_signed_area$$=$APP.$cljs$core$first$$($G__47835_content$jscomp$54_subpath$jscomp$6_subpath__$1$$);$G__47835_content$jscomp$54_subpath$jscomp$6_subpath__$1$$=$APP.$cljs$core$rest$$($G__47835_content$jscomp$54_subpath$jscomp$6_subpath__$1$$);$G__47837_map__47815__$1_y1$jscomp$29$$=$current$jscomp$25_map__47815_signed_area__$1_x1$jscomp$27$$;
$current$jscomp$25_map__47815_signed_area__$1_x1$jscomp$27$$=$G__47834_signed_area$$;$G__47834_signed_area$$=$G__47837_map__47815__$1_y1$jscomp$29$$}};
$APP.$app$common$types$path$bool$get_default_fills$$=function(){var $fills$jscomp$9$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1746$fill_color$$,"#000000"],null)],null);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$flags$_STAR_current_STAR_$$,$APP.$cljs$cst$1755$frontend_binary_fills$$)?$APP.$app$common$types$fills$impl$from_plain$$($fills$jscomp$9$$):$fills$jscomp$9$$};
$app$common$types$path$bool$add_previous$cljs$0core$0IFn$0_invoke$0arity$01$$=function($content$jscomp$55$$){return $app$common$types$path$bool$add_previous$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$55$$,null)};
$app$common$types$path$bool$add_previous$cljs$0core$0IFn$0_invoke$0arity$02$$=function($content$jscomp$56$$,$first$jscomp$12$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__48329_prev$jscomp$16$$){var $G__48333__$1_cmd$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48329_prev$jscomp$16$$,0,null);$p__48329_prev$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48329_prev$jscomp$16$$,1,null);$G__48333__$1_cmd$jscomp$1$$=$p__48329_prev$jscomp$16$$==
null&&$first$jscomp$12$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48333__$1_cmd$jscomp$1$$,$cljs$cst$1820$prev$$,$first$jscomp$12$$):$G__48333__$1_cmd$jscomp$1$$;return $p__48329_prev$jscomp$16$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48333__$1_cmd$jscomp$1$$,$cljs$cst$1820$prev$$,$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($p__48329_prev$jscomp$16$$)):$G__48333__$1_cmd$jscomp$1$$},$APP.$app$common$data$with_prev$$($content$jscomp$56$$))};
$app$common$types$path$bool$close_paths$$=function($G__48524_content$jscomp$57_last_move$$){for(var $G__48522_segments$jscomp$8$$=$APP.$cljs$core$seq$$($G__48524_content$jscomp$57_last_move$$),$G__48348$jscomp$inline_5118_G__48523_result$jscomp$199$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$last_point_segment__$1$jscomp$3$$=$G__48524_content$jscomp$57_last_move$$=null;;){var $G__48525_point$jscomp$38_temp__5823__auto__$jscomp$107$$=$APP.$cljs$core$first$$($G__48522_segments$jscomp$8$$);if($APP.$cljs$core$truth_$$($G__48525_point$jscomp$38_temp__5823__auto__$jscomp$107$$)){var $segment$jscomp$31$$=
$G__48525_point$jscomp$38_temp__5823__auto__$jscomp$107$$;$G__48525_point$jscomp$38_temp__5823__auto__$jscomp$107$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$31$$);$last_point_segment__$1$jscomp$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1850$close_path$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$31$$))&&($last_point_segment__$1$jscomp$3$$==null||$APP.$app$common$geom$point$distance$$($last_point_segment__$1$jscomp$3$$,
$G__48524_content$jscomp$57_last_move$$)<.01)?null:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1850$close_path$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$31$$))?$app$common$types$path$helpers$make_line_to$$($G__48524_content$jscomp$57_last_move$$):$segment$jscomp$31$$;$G__48522_segments$jscomp$8$$=$APP.$cljs$core$rest$$($G__48522_segments$jscomp$8$$);$G__48348$jscomp$inline_5118_G__48523_result$jscomp$199$$=$last_point_segment__$1$jscomp$3$$!=
null?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48348$jscomp$inline_5118_G__48523_result$jscomp$199$$,$last_point_segment__$1$jscomp$3$$):$G__48348$jscomp$inline_5118_G__48523_result$jscomp$199$$;$G__48524_content$jscomp$57_last_move$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($last_point_segment__$1$jscomp$3$$))?$G__48525_point$jscomp$38_temp__5823__auto__$jscomp$107$$:$G__48524_content$jscomp$57_last_move$$;
$last_point_segment__$1$jscomp$3$$=$G__48525_point$jscomp$38_temp__5823__auto__$jscomp$107$$}else return $G__48348$jscomp$inline_5118_G__48523_result$jscomp$199$$}};
$app$common$types$path$bool$split_ts$$=function($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$,$l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$){var $cmd_1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$,$APP.$cljs$cst$1812$command$$),$cmd_2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$,
$APP.$cljs$cst$1812$command$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1814$line_to$$,$cmd_1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1814$line_to$$,$cmd_2$$)?($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$=$app$common$types$path$helpers$command__GT_line$cljs$0core$0IFn$0_invoke$0arity$01$$($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$),
$l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$=$app$common$types$path$helpers$command__GT_line$cljs$0core$0IFn$0_invoke$0arity$01$$($l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$),$l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$=$app$common$types$path$helpers$line_line_crossing$$($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$,
$l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$),$l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$,0,null),$l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$,
1,null),$l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$!=null&&$l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$!=null&&($l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$>0||$APP.$app$common$math$almost_zero_QMARK_$$($l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$-0))&&($l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$<1||$APP.$app$common$math$almost_zero_QMARK_$$($l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$-
1))&&($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$>0||$APP.$app$common$math$almost_zero_QMARK_$$($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$-0))&&($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$<1||$APP.$app$common$math$almost_zero_QMARK_$$($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$-
1))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$],null),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$],null)],null):null):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1814$line_to$$,$cmd_1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,$cmd_2$$)?$app$common$types$path$helpers$line_curve_intersect$$($app$common$types$path$helpers$command__GT_line$cljs$0core$0IFn$0_invoke$0arity$01$$($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$),$app$common$types$path$helpers$command__GT_bezier$cljs$0core$0IFn$0_invoke$0arity$01$$($l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$)):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,$cmd_1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1814$line_to$$,$cmd_2$$)?($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$=$app$common$types$path$helpers$line_curve_intersect$$($app$common$types$path$helpers$command__GT_line$cljs$0core$0IFn$0_invoke$0arity$01$$($l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$),
$app$common$types$path$helpers$command__GT_bezier$cljs$0core$0IFn$0_invoke$0arity$01$$($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$)),$l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$,0,null),$l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$,1,null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$,$l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$],null)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,
$cmd_1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,$cmd_2$$)?$app$common$types$path$helpers$curve_curve_intersect$$($app$common$types$path$helpers$command__GT_bezier$cljs$0core$0IFn$0_invoke$0arity$01$$($l1$jscomp$inline_5120_l2_t$jscomp$inline_5124_seg_1_seg_1_SINGLEQUOTE__vec__46827$jscomp$inline_5122_vec__48357$$),$app$common$types$path$helpers$command__GT_bezier$cljs$0core$0IFn$0_invoke$0arity$01$$($l1_t$jscomp$inline_5123_l2$jscomp$inline_5121_seg_2_seg_2_SINGLEQUOTE_$$)):
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null)};
$app$common$types$path$bool$content_intersect_split$$=function($content_a$$,$content_b$$,$sr_a$$,$sr_b$$){function $split_content$$($content_a__$1$$,$content_b__$1$$,$sr_b__$1$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__48362_SHARP_$$){return $split_segment_on_content$$($p1__48362_SHARP_$$,$content_b__$1$$,$sr_b__$1$$)}),$content_a__$1$$)}function $split_segment_on_content$$($segment$jscomp$33$$,
$content$jscomp$58$$,$content_sr$$){return $APP.$cljs$core$truth_$$($overlap_segment_selrect_QMARK_$$($segment$jscomp$33$$,$content_sr$$))?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$200$$,$current$jscomp$26$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($JSCompiler_inline_result$jscomp$787_p1__48361_SHARP_$$){if($APP.$cljs$core$not$$($overlap_segments_QMARK_$$($JSCompiler_inline_result$jscomp$787_p1__48361_SHARP_$$,
$current$jscomp$26$$)))$JSCompiler_inline_result$jscomp$787_p1__48361_SHARP_$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_inline_result$jscomp$787_p1__48361_SHARP_$$],null);else{var $JSCompiler_temp_const$jscomp$10766_vec__48377$jscomp$inline_5128$$=$app$common$types$path$bool$split_ts$$($JSCompiler_inline_result$jscomp$787_p1__48361_SHARP_$$,$current$jscomp$26$$),$JSCompiler_inline_result$jscomp$10767_ts_seg_1$jscomp$inline_5129$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$10766_vec__48377$jscomp$inline_5128$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$10766_vec__48377$jscomp$inline_5128$$,1,null);$JSCompiler_temp_const$jscomp$10766_vec__48377$jscomp$inline_5128$$=$app$common$types$path$bool$add_previous$cljs$0core$0IFn$0_invoke$0arity$02$$;b:{var $G__48351$jscomp$inline_11939$$=$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$787_p1__48361_SHARP_$$);switch($G__48351$jscomp$inline_11939$$ instanceof $APP.$cljs$core$Keyword$$?
$G__48351$jscomp$inline_11939$$.$fqn$:null){case "line-to":$JSCompiler_inline_result$jscomp$10767_ts_seg_1$jscomp$inline_5129$$=$app$common$types$path$helpers$split_line_to_ranges$$($cljs$cst$1820$prev$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$787_p1__48361_SHARP_$$),$JSCompiler_inline_result$jscomp$787_p1__48361_SHARP_$$,$JSCompiler_inline_result$jscomp$10767_ts_seg_1$jscomp$inline_5129$$);break b;case "curve-to":$JSCompiler_inline_result$jscomp$10767_ts_seg_1$jscomp$inline_5129$$=
$app$common$types$path$helpers$split_curve_to_ranges$$($cljs$cst$1820$prev$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$787_p1__48361_SHARP_$$),$JSCompiler_inline_result$jscomp$787_p1__48361_SHARP_$$,$JSCompiler_inline_result$jscomp$10767_ts_seg_1$jscomp$inline_5129$$);break b;default:$JSCompiler_inline_result$jscomp$10767_ts_seg_1$jscomp$inline_5129$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_inline_result$jscomp$787_p1__48361_SHARP_$$],
null)}}$JSCompiler_inline_result$jscomp$787_p1__48361_SHARP_$$=$JSCompiler_temp_const$jscomp$10766_vec__48377$jscomp$inline_5128$$($JSCompiler_inline_result$jscomp$10767_ts_seg_1$jscomp$inline_5129$$,$cljs$cst$1820$prev$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$787_p1__48361_SHARP_$$))}return $JSCompiler_inline_result$jscomp$787_p1__48361_SHARP_$$}),$result$jscomp$200$$)},new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$segment$jscomp$33$$],
null),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48360_SHARP_$$){return $overlap_segments_QMARK_$$($segment$jscomp$33$$,$p1__48360_SHARP_$$)},$content$jscomp$58$$)):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$segment$jscomp$33$$],null)}function $overlap_segments_QMARK_$$($r1$jscomp$15_seg_1$jscomp$1$$,$r2$jscomp$13_seg_2$jscomp$1$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1813$move_to$$,
$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($r1$jscomp$15_seg_1$jscomp$1$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($r2$jscomp$13_seg_2$jscomp$1$$)))return!1;$r1$jscomp$15_seg_1$jscomp$1$$=$command__GT_selrect$$($r1$jscomp$15_seg_1$jscomp$1$$);$r2$jscomp$13_seg_2$jscomp$1$$=$command__GT_selrect$$($r2$jscomp$13_seg_2$jscomp$1$$);return $APP.$app$common$geom$rect$overlaps_rects_QMARK_$$($r1$jscomp$15_seg_1$jscomp$1$$,
$r2$jscomp$13_seg_2$jscomp$1$$)}function $overlap_segment_selrect_QMARK_$$($r1$jscomp$14_segment$jscomp$32$$,$selrect$jscomp$5$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1813$move_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($r1$jscomp$14_segment$jscomp$32$$)))return!1;$r1$jscomp$14_segment$jscomp$32$$=$command__GT_selrect$$($r1$jscomp$14_segment$jscomp$32$$);return $APP.$app$common$geom$rect$overlaps_rects_QMARK_$$($r1$jscomp$14_segment$jscomp$32$$,
$selrect$jscomp$5$$)}var $command__GT_selrect$$=$APP.$cljs$core$memoize$$($app$common$types$path$helpers$command__GT_selrect$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$split_content$$($content_a$$,$content_b$$,$sr_b$$),$split_content$$($content_b$$,$content_a$$,$sr_a$$)],null)};
$app$common$types$path$bool$is_segment_QMARK_$$=function($cmd$jscomp$3$$){return $APP.$cljs$core$contains_QMARK_$$($cmd$jscomp$3$$,$cljs$cst$1820$prev$$)&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1814$line_to$$,null,$cljs$cst$1819$curve_to$$,null],null),null),$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($cmd$jscomp$3$$))};
$app$common$types$path$bool$contains_segment_QMARK_$$=function($point$jscomp$39_segment$jscomp$34$$,$content$jscomp$59$$,$and__5023__auto__$jscomp$245_content_sr$jscomp$1$$,$content_geom$jscomp$1_or__5025__auto__$jscomp$355$$){a:{var $G__48393$jscomp$inline_5131_G__48393__$1$jscomp$inline_5132$$=$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$39_segment$jscomp$34$$);$G__48393$jscomp$inline_5131_G__48393__$1$jscomp$inline_5132$$=$G__48393$jscomp$inline_5131_G__48393__$1$jscomp$inline_5132$$ instanceof
$APP.$cljs$core$Keyword$$?$G__48393$jscomp$inline_5131_G__48393__$1$jscomp$inline_5132$$.$fqn$:null;switch($G__48393$jscomp$inline_5131_G__48393__$1$jscomp$inline_5132$$){case "line-to":$point$jscomp$39_segment$jscomp$34$$=$app$common$types$path$helpers$line_values$$($app$common$types$path$helpers$command__GT_line$cljs$0core$0IFn$0_invoke$0arity$01$$($point$jscomp$39_segment$jscomp$34$$),.5);break a;case "curve-to":$point$jscomp$39_segment$jscomp$34$$=$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$path$helpers$command__GT_bezier$cljs$0core$0IFn$0_invoke$0arity$01$$($point$jscomp$39_segment$jscomp$34$$),
.5);break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__48393$jscomp$inline_5131_G__48393__$1$jscomp$inline_5132$$)].join(""));}}return($and__5023__auto__$jscomp$245_content_sr$jscomp$1$$=$app$common$geom$rect$contains_point_QMARK_$$($and__5023__auto__$jscomp$245_content_sr$jscomp$1$$,$point$jscomp$39_segment$jscomp$34$$))?($content_geom$jscomp$1_or__5025__auto__$jscomp$355$$=$app$common$types$path$helpers$is_point_in_geom_data_QMARK_$$($point$jscomp$39_segment$jscomp$34$$,
$content_geom$jscomp$1_or__5025__auto__$jscomp$355$$))?$content_geom$jscomp$1_or__5025__auto__$jscomp$355$$:$app$common$types$path$helpers$is_point_in_border_QMARK_$$($point$jscomp$39_segment$jscomp$34$$,$content$jscomp$59$$):$and__5023__auto__$jscomp$245_content_sr$jscomp$1$$};
$app$common$types$path$bool$overlap_segment_QMARK_$$=function($segment$jscomp$36$$,$content$jscomp$60$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($other$jscomp$183$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$36$$),$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$183$$))&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1814$line_to$$,null,$cljs$cst$1819$curve_to$$,null],null),null),$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$36$$))){var $G__48413_G__48413__$1_p1$jscomp$49$$=$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$36$$);$G__48413_G__48413__$1_p1$jscomp$49$$=$G__48413_G__48413__$1_p1$jscomp$49$$ instanceof $APP.$cljs$core$Keyword$$?$G__48413_G__48413__$1_p1$jscomp$49$$.$fqn$:null;
switch($G__48413_G__48413__$1_p1$jscomp$49$$){case "line-to":var $q1_vec__48414$$=$app$common$types$path$helpers$command__GT_line$cljs$0core$0IFn$0_invoke$0arity$01$$($segment$jscomp$36$$);$G__48413_G__48413__$1_p1$jscomp$49$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($q1_vec__48414$$,0,null);$q1_vec__48414$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($q1_vec__48414$$,1,null);var $h11$jscomp$1_vec__48417$$=$app$common$types$path$helpers$command__GT_line$cljs$0core$0IFn$0_invoke$0arity$01$$($other$jscomp$183$$),
$p2$jscomp$38_vec__48421$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h11$jscomp$1_vec__48417$$,0,null),$q2$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h11$jscomp$1_vec__48417$$,1,null);return $APP.$app$common$geom$point$distance$$($G__48413_G__48413__$1_p1$jscomp$49$$,$p2$jscomp$38_vec__48421$$)<.1&&$APP.$app$common$geom$point$distance$$($q1_vec__48414$$,$q2$jscomp$1$$)<.1||$APP.$app$common$geom$point$distance$$($G__48413_G__48413__$1_p1$jscomp$49$$,$q2$jscomp$1$$)<
.1&&$APP.$app$common$geom$point$distance$$($q1_vec__48414$$,$p2$jscomp$38_vec__48421$$)<.1?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$segment$jscomp$36$$,$other$jscomp$183$$],null):null;case "curve-to":$p2$jscomp$38_vec__48421$$=$app$common$types$path$helpers$command__GT_bezier$cljs$0core$0IFn$0_invoke$0arity$01$$($segment$jscomp$36$$);$G__48413_G__48413__$1_p1$jscomp$49$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2$jscomp$38_vec__48421$$,
0,null);$q1_vec__48414$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2$jscomp$38_vec__48421$$,1,null);$h11$jscomp$1_vec__48417$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2$jscomp$38_vec__48421$$,2,null);var $h21$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2$jscomp$38_vec__48421$$,3,null),$h22$jscomp$1_vec__48424$$=$app$common$types$path$helpers$command__GT_bezier$cljs$0core$0IFn$0_invoke$0arity$01$$($other$jscomp$183$$);$p2$jscomp$38_vec__48421$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h22$jscomp$1_vec__48424$$,0,null);$q2$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h22$jscomp$1_vec__48424$$,1,null);var $h12$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h22$jscomp$1_vec__48424$$,2,null);$h22$jscomp$1_vec__48424$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h22$jscomp$1_vec__48424$$,3,null);return $APP.$app$common$geom$point$distance$$($G__48413_G__48413__$1_p1$jscomp$49$$,
$p2$jscomp$38_vec__48421$$)<.1&&$APP.$app$common$geom$point$distance$$($q1_vec__48414$$,$q2$jscomp$1$$)<.1&&$APP.$app$common$geom$point$distance$$($h11$jscomp$1_vec__48417$$,$h12$jscomp$1$$)<.1&&$APP.$app$common$geom$point$distance$$($h21$jscomp$1$$,$h22$jscomp$1_vec__48424$$)<.1||$APP.$app$common$geom$point$distance$$($G__48413_G__48413__$1_p1$jscomp$49$$,$q2$jscomp$1$$)<.1&&$APP.$app$common$geom$point$distance$$($q1_vec__48414$$,$p2$jscomp$38_vec__48421$$)<.1&&$APP.$app$common$geom$point$distance$$($h11$jscomp$1_vec__48417$$,
$h22$jscomp$1_vec__48424$$)<.1&&$APP.$app$common$geom$point$distance$$($h21$jscomp$1$$,$h12$jscomp$1$$)<.1?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$segment$jscomp$36$$,$other$jscomp$183$$],null):null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__48413_G__48413__$1_p1$jscomp$49$$)].join(""));}}else return null},$content$jscomp$60$$)!=null};
$app$common$types$path$bool$fix_move_to$$=function($G__48542_content$jscomp$61_content__$1$jscomp$12$$){var $current$jscomp$27$$=$APP.$cljs$core$first$$($G__48542_content$jscomp$61_content__$1$jscomp$12$$);$G__48542_content$jscomp$61_content__$1$jscomp$12$$=$APP.$cljs$core$rest$$($G__48542_content$jscomp$61_content__$1$jscomp$12$$);for(var $G__48541_prev$jscomp$17$$=null,$G__48543_result$jscomp$201$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){if($current$jscomp$27$$==null)return $G__48543_result$jscomp$201$$;
var $G__48544_result__$1$jscomp$29$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1820$prev$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$27$$),$G__48541_prev$jscomp$17$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48543_result$jscomp$201$$,$app$common$types$path$helpers$make_move_to$$($cljs$cst$1820$prev$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$27$$))):$G__48543_result$jscomp$201$$;$G__48541_prev$jscomp$17$$=$APP.$cljs$core$first$$($G__48542_content$jscomp$61_content__$1$jscomp$12$$);
$G__48542_content$jscomp$61_content__$1$jscomp$12$$=$APP.$cljs$core$rest$$($G__48542_content$jscomp$61_content__$1$jscomp$12$$);$G__48543_result$jscomp$201$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$27$$);$G__48544_result__$1$jscomp$29$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48544_result__$1$jscomp$29$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$27$$,$cljs$cst$1820$prev$$));$current$jscomp$27$$=
$G__48541_prev$jscomp$17$$;$G__48541_prev$jscomp$17$$=$G__48543_result$jscomp$201$$;$G__48543_result$jscomp$201$$=$G__48544_result__$1$jscomp$29$$}};
$app$common$types$path$bool$remove_duplicated_segments$$=function($G__48546_content$jscomp$62$$){for(var $current$jscomp$28$$=$APP.$cljs$core$first$$($G__48546_content$jscomp$62$$),$G__48547_content__$1$jscomp$13$$=$APP.$cljs$core$rest$$($G__48546_content$jscomp$62$$),$segments$jscomp$9$$=$cljs$core$sorted_set_by$$(function($p__48465$$,$p__48466$$){var $fx1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48465$$,0,null),$fy1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48465$$,
1,null),$tx1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48465$$,2,null),$ty1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48465$$,3,null),$fx2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48466$$,0,null),$fy2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48466$$,1,null),$tx2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48466$$,2,null),$ty2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48466$$,
3,null);return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$246_and__5023__auto____$1$jscomp$46_and__5023__auto____$2$jscomp$19$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($tx1$$,$tx2$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$246_and__5023__auto____$1$jscomp$46_and__5023__auto____$2$jscomp$19$$)?($and__5023__auto__$jscomp$246_and__5023__auto____$1$jscomp$46_and__5023__auto____$2$jscomp$19$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($ty1$$,
$ty2$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$246_and__5023__auto____$1$jscomp$46_and__5023__auto____$2$jscomp$19$$)?($and__5023__auto__$jscomp$246_and__5023__auto____$1$jscomp$46_and__5023__auto____$2$jscomp$19$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($fx1$$,$fx2$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$246_and__5023__auto____$1$jscomp$46_and__5023__auto____$2$jscomp$19$$)?$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($fy1$$,
$fy2$$):$and__5023__auto__$jscomp$246_and__5023__auto____$1$jscomp$46_and__5023__auto____$2$jscomp$19$$):$and__5023__auto__$jscomp$246_and__5023__auto____$1$jscomp$46_and__5023__auto____$2$jscomp$19$$):$and__5023__auto__$jscomp$246_and__5023__auto____$1$jscomp$46_and__5023__auto____$2$jscomp$19$$}())?0:$APP.$cljs$core$compare$$($p__48465$$,$p__48466$$)}),$result$jscomp$202$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){if($current$jscomp$28$$==null)return $result$jscomp$202$$;var $fx$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1820$prev$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$28$$)),
$fy$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1820$prev$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$28$$)),$tx$jscomp$5$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$28$$)),$ty$jscomp$6$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$28$$)),$G__48549_result__$1$jscomp$30$$=function(){var $G__48476$$=
$result$jscomp$202$$;return $APP.$cljs$core$contains_QMARK_$$($segments$jscomp$9$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$fx$$,$fy$$,$tx$jscomp$5$$,$ty$jscomp$6$$],null))||$APP.$cljs$core$contains_QMARK_$$($segments$jscomp$9$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$tx$jscomp$5$$,$ty$jscomp$6$$,$fx$$,$fy$$],null))?$G__48476$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48476$$,
$current$jscomp$28$$)}(),$G__48548_segments__$1$jscomp$3$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($segments$jscomp$9$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$fx$$,$fy$$,$tx$jscomp$5$$,$ty$jscomp$6$$],null));$G__48546_content$jscomp$62$$=$APP.$cljs$core$first$$($G__48547_content__$1$jscomp$13$$);$G__48547_content__$1$jscomp$13$$=$APP.$cljs$core$rest$$($G__48547_content__$1$jscomp$13$$);$current$jscomp$28$$=$G__48546_content$jscomp$62$$;
$segments$jscomp$9$$=$G__48548_segments__$1$jscomp$3$$;$result$jscomp$202$$=$G__48549_result__$1$jscomp$30$$}};$app$common$types$path$bool$close_content$$=function($content$jscomp$63$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$142$data$$),$app$common$types$path$subpath$get_subpaths$$($app$common$types$path$subpath$close_subpaths$$($content$jscomp$63$$)))};
$app$common$types$path$bool$content__GT_geom_data$$=function($content$jscomp$64$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($segment$jscomp$37$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$37$$),$APP.$cljs$cst$1861$segment$$,$segment$jscomp$37$$,$cljs$cst$1825$geom$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1814$line_to$$,
$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$37$$))?$app$common$types$path$helpers$command__GT_line$cljs$0core$0IFn$0_invoke$0arity$01$$($segment$jscomp$37$$):$app$common$types$path$helpers$command__GT_bezier$cljs$0core$0IFn$0_invoke$0arity$01$$($segment$jscomp$37$$),$APP.$cljs$cst$1605$selrect$$,$app$common$types$path$helpers$command__GT_selrect$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$37$$)],null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48482_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1814$line_to$$,
$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($p1__48482_SHARP_$$)),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1819$curve_to$$,$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($p1__48482_SHARP_$$)))},$app$common$types$path$bool$close_content$$($content$jscomp$64$$)))};
$app$common$types$path$bool$create_union$$=function($content_a$jscomp$1$$,$content_a_split$$,$content_b$jscomp$1$$,$border_content_content_b_split$$,$sr_a$jscomp$1$$,$sr_b$jscomp$1$$){var $content_a_geom$$=$app$common$types$path$bool$content__GT_geom_data$$($content_a$jscomp$1$$),$content_b_geom$$=$app$common$types$path$bool$content__GT_geom_data$$($content_b$jscomp$1$$),$content$jscomp$65$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48484_SHARP_$$){return $APP.$cljs$core$not$$($app$common$types$path$bool$contains_segment_QMARK_$$($p1__48484_SHARP_$$,
$content_b$jscomp$1$$,$sr_b$jscomp$1$$,$content_b_geom$$))},$content_a_split$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48485_SHARP_$$){return $APP.$cljs$core$not$$($app$common$types$path$bool$contains_segment_QMARK_$$($p1__48485_SHARP_$$,$content_a$jscomp$1$$,$sr_a$jscomp$1$$,$content_a_geom$$))},$border_content_content_b_split$$)),$content_geom$jscomp$3$$=$app$common$types$path$bool$content__GT_geom_data$$($content$jscomp$65$$),$content_sr$jscomp$3$$=$app$common$types$path$segment$content__GT_selrect$$($app$common$types$path$bool$fix_move_to$$($content$jscomp$65$$));
$border_content_content_b_split$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($JSCompiler_temp$jscomp$10768_p1__48486_SHARP__point$jscomp$inline_11944$$){var $G__48398$jscomp$inline_11945_G__48398__$1$jscomp$inline_11946_JSCompiler_temp$jscomp$10769_and__5023__auto__$jscomp$247$$=$app$common$types$path$bool$contains_segment_QMARK_$$($JSCompiler_temp$jscomp$10768_p1__48486_SHARP__point$jscomp$inline_11944$$,$content_a$jscomp$1$$,$sr_a$jscomp$1$$,$content_a_geom$$);if($APP.$cljs$core$truth_$$($G__48398$jscomp$inline_11945_G__48398__$1$jscomp$inline_11946_JSCompiler_temp$jscomp$10769_and__5023__auto__$jscomp$247$$)){if($G__48398$jscomp$inline_11945_G__48398__$1$jscomp$inline_11946_JSCompiler_temp$jscomp$10769_and__5023__auto__$jscomp$247$$=
$app$common$types$path$bool$overlap_segment_QMARK_$$($JSCompiler_temp$jscomp$10768_p1__48486_SHARP__point$jscomp$inline_11944$$,$content_a_split$$)){a:switch($G__48398$jscomp$inline_11945_G__48398__$1$jscomp$inline_11946_JSCompiler_temp$jscomp$10769_and__5023__auto__$jscomp$247$$=$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10768_p1__48486_SHARP__point$jscomp$inline_11944$$),$G__48398$jscomp$inline_11945_G__48398__$1$jscomp$inline_11946_JSCompiler_temp$jscomp$10769_and__5023__auto__$jscomp$247$$=
$G__48398$jscomp$inline_11945_G__48398__$1$jscomp$inline_11946_JSCompiler_temp$jscomp$10769_and__5023__auto__$jscomp$247$$ instanceof $APP.$cljs$core$Keyword$$?$G__48398$jscomp$inline_11945_G__48398__$1$jscomp$inline_11946_JSCompiler_temp$jscomp$10769_and__5023__auto__$jscomp$247$$.$fqn$:null,$G__48398$jscomp$inline_11945_G__48398__$1$jscomp$inline_11946_JSCompiler_temp$jscomp$10769_and__5023__auto__$jscomp$247$$){case "line-to":$JSCompiler_temp$jscomp$10768_p1__48486_SHARP__point$jscomp$inline_11944$$=
$app$common$types$path$helpers$line_values$$($app$common$types$path$helpers$command__GT_line$cljs$0core$0IFn$0_invoke$0arity$01$$($JSCompiler_temp$jscomp$10768_p1__48486_SHARP__point$jscomp$inline_11944$$),.5);break a;case "curve-to":$JSCompiler_temp$jscomp$10768_p1__48486_SHARP__point$jscomp$inline_11944$$=$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$path$helpers$command__GT_bezier$cljs$0core$0IFn$0_invoke$0arity$01$$($JSCompiler_temp$jscomp$10768_p1__48486_SHARP__point$jscomp$inline_11944$$),
.5);break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__48398$jscomp$inline_11945_G__48398__$1$jscomp$inline_11946_JSCompiler_temp$jscomp$10769_and__5023__auto__$jscomp$247$$)].join(""));}$G__48398$jscomp$inline_11945_G__48398__$1$jscomp$inline_11946_JSCompiler_temp$jscomp$10769_and__5023__auto__$jscomp$247$$=!($app$common$geom$rect$contains_point_QMARK_$$($content_sr$jscomp$3$$,$JSCompiler_temp$jscomp$10768_p1__48486_SHARP__point$jscomp$inline_11944$$)&&
$app$common$types$path$helpers$is_point_in_geom_data_QMARK_$$($JSCompiler_temp$jscomp$10768_p1__48486_SHARP__point$jscomp$inline_11944$$,$content_geom$jscomp$3$$))}$JSCompiler_temp$jscomp$10768_p1__48486_SHARP__point$jscomp$inline_11944$$=$G__48398$jscomp$inline_11945_G__48398__$1$jscomp$inline_11946_JSCompiler_temp$jscomp$10769_and__5023__auto__$jscomp$247$$}else $JSCompiler_temp$jscomp$10768_p1__48486_SHARP__point$jscomp$inline_11944$$=$G__48398$jscomp$inline_11945_G__48398__$1$jscomp$inline_11946_JSCompiler_temp$jscomp$10769_and__5023__auto__$jscomp$247$$;
return $JSCompiler_temp$jscomp$10768_p1__48486_SHARP__point$jscomp$inline_11944$$},$border_content_content_b_split$$);return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($content$jscomp$65$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$border_content_content_b_split$$]))};
$app$common$types$path$bool$create_difference$$=function($content_a$jscomp$2$$,$content_a_split$jscomp$1$$,$content_b$jscomp$2$$,$content_b_split$jscomp$1$$,$sr_a$jscomp$2$$,$sr_b$jscomp$2$$){var $content_a_geom$jscomp$1$$=$app$common$types$path$bool$content__GT_geom_data$$($content_a$jscomp$2$$),$content_b_geom$jscomp$1$$=$app$common$types$path$bool$content__GT_geom_data$$($content_b$jscomp$2$$);return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48491_SHARP_$$){return $APP.$cljs$core$not$$($app$common$types$path$bool$contains_segment_QMARK_$$($p1__48491_SHARP_$$,
$content_b$jscomp$2$$,$sr_b$jscomp$2$$,$content_b_geom$jscomp$1$$))},$content_a_split$jscomp$1$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48492_SHARP_$$){var $and__5023__auto__$jscomp$248$$=$app$common$types$path$bool$contains_segment_QMARK_$$($p1__48492_SHARP_$$,$content_a$jscomp$2$$,$sr_a$jscomp$2$$,$content_a_geom$jscomp$1$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$248$$)?!$app$common$types$path$bool$overlap_segment_QMARK_$$($p1__48492_SHARP_$$,
$content_a_split$jscomp$1$$):$and__5023__auto__$jscomp$248$$},$content_b_split$jscomp$1$$)]))};
$app$common$types$path$bool$create_intersection$$=function($content_a$jscomp$3$$,$content_a_split$jscomp$2$$,$content_b$jscomp$3$$,$content_b_split$jscomp$2$$,$sr_a$jscomp$3$$,$sr_b$jscomp$3$$){var $content_a_geom$jscomp$2$$=$app$common$types$path$bool$content__GT_geom_data$$($content_a$jscomp$3$$),$content_b_geom$jscomp$2$$=$app$common$types$path$bool$content__GT_geom_data$$($content_b$jscomp$3$$);return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48497_SHARP_$$){return $app$common$types$path$bool$contains_segment_QMARK_$$($p1__48497_SHARP_$$,$content_b$jscomp$3$$,
$sr_b$jscomp$3$$,$content_b_geom$jscomp$2$$)},$content_a_split$jscomp$2$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48498_SHARP_$$){return $app$common$types$path$bool$contains_segment_QMARK_$$($p1__48498_SHARP_$$,$content_a$jscomp$3$$,$sr_a$jscomp$3$$,$content_a_geom$jscomp$2$$)},$content_b_split$jscomp$2$$)]))};
$app$common$types$path$bool$content_bool_pair$$=function($bool_type$$,$content$jscomp$66_content_a$jscomp$5_content_a_split$jscomp$3$$,$content_b$jscomp$5$$){var $should_reverse_QMARK_$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$736$union$$,$bool_type$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$path$subpath$clockwise_QMARK_$$($content_b$jscomp$5$$),$app$common$types$path$subpath$clockwise_QMARK_$$($content$jscomp$66_content_a$jscomp$5_content_a_split$jscomp$3$$)),
$content_a__$1$jscomp$1$$=$app$common$types$path$bool$add_previous$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$path$bool$close_paths$$($content$jscomp$66_content_a$jscomp$5_content_a_split$jscomp$3$$)),$content_b__$1$jscomp$1$$=$app$common$types$path$bool$add_previous$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $G__48507$$=$app$common$types$path$bool$close_paths$$($content_b$jscomp$5$$);return $should_reverse_QMARK_$$?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$app$common$types$path$subpath$xf_mapcat_data$$,$APP.$cljs$core$reverse$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$path$subpath$reverse_subpath$$,$app$common$types$path$subpath$get_subpaths$$($G__48507$$)))):$G__48507$$}()),$sr_a$jscomp$4$$=$app$common$types$path$segment$content__GT_selrect$$($content_a__$1$jscomp$1$$),$sr_b$jscomp$4$$=$app$common$types$path$segment$content__GT_selrect$$($content_b__$1$jscomp$1$$),$content_b_split$jscomp$3_vec__48504$$=$app$common$types$path$bool$content_intersect_split$$($content_a__$1$jscomp$1$$,
$content_b__$1$jscomp$1$$,$sr_a$jscomp$4$$,$sr_b$jscomp$4$$);$content$jscomp$66_content_a$jscomp$5_content_a_split$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content_b_split$jscomp$3_vec__48504$$,0,null);$content_b_split$jscomp$3_vec__48504$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content_b_split$jscomp$3_vec__48504$$,1,null);var $content_a_split__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$path$bool$is_segment_QMARK_$$,
$app$common$types$path$bool$add_previous$cljs$0core$0IFn$0_invoke$0arity$01$$($content$jscomp$66_content_a$jscomp$5_content_a_split$jscomp$3$$)),$content_b_split__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$path$bool$is_segment_QMARK_$$,$app$common$types$path$bool$add_previous$cljs$0core$0IFn$0_invoke$0arity$01$$($content_b_split$jscomp$3_vec__48504$$));$content$jscomp$66_content_a$jscomp$5_content_a_split$jscomp$3$$=function(){var $G__48509__$1$$=$bool_type$$ instanceof
$APP.$cljs$core$Keyword$$?$bool_type$$.$fqn$:null;switch($G__48509__$1$$){case "union":return $app$common$types$path$bool$create_union$$($content_a__$1$jscomp$1$$,$content_a_split__$1$$,$content_b__$1$jscomp$1$$,$content_b_split__$1$$,$sr_a$jscomp$4$$,$sr_b$jscomp$4$$);case "difference":return $app$common$types$path$bool$create_difference$$($content_a__$1$jscomp$1$$,$content_a_split__$1$$,$content_b__$1$jscomp$1$$,$content_b_split__$1$$,$sr_a$jscomp$4$$,$sr_b$jscomp$4$$);case "intersection":return $app$common$types$path$bool$create_intersection$$($content_a__$1$jscomp$1$$,
$content_a_split__$1$$,$content_b__$1$jscomp$1$$,$content_b_split__$1$$,$sr_a$jscomp$4$$,$sr_b$jscomp$4$$);case "exclude":return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($content_a_split__$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$content_b_split__$1$$]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__48509__$1$$)].join(""));}}();return $app$common$types$path$subpath$close_subpaths$$($app$common$types$path$bool$fix_move_to$$($app$common$types$path$bool$remove_duplicated_segments$$($content$jscomp$66_content_a$jscomp$5_content_a_split$jscomp$3$$)))};
$app$common$types$path$bool$calculate_content$$=function($bool_type$jscomp$1$$,$contents$jscomp$12$$){return $APP.$cljs$core$seq$$($contents$jscomp$12$$)?$APP.$cljs$core$vec$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$path$bool$content_bool_pair$$,$bool_type$jscomp$1$$),$contents$jscomp$12$$)):$APP.$cljs$core$PersistentVector$EMPTY$$};
$app$common$types$shape$radius$can_get_border_radius_QMARK_$$=function($shape$jscomp$80$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1606$frame$$,null,$APP.$cljs$cst$1611$rect$$,null],null),null),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$80$$))};
$app$common$types$shape$radius$all_equal_QMARK_$$=function($shape$jscomp$82$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$1646$r1$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$82$$),$APP.$cljs$cst$1647$r2$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$82$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1648$r3$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$82$$),$APP.$cljs$cst$1649$r4$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$82$$)]))};
$APP.$app$common$types$shape$radius$set_radius_to_all_corners$$=function($shape$jscomp$84$$,$value$jscomp$425$$){return $app$common$types$shape$radius$can_get_border_radius_QMARK_$$($shape$jscomp$84$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape$jscomp$84$$,$APP.$cljs$cst$1646$r1$$,$value$jscomp$425$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1647$r2$$,$value$jscomp$425$$,$APP.$cljs$cst$1648$r3$$,$value$jscomp$425$$,$APP.$cljs$cst$1649$r4$$,
$value$jscomp$425$$])):$shape$jscomp$84$$};
$APP.$app$common$types$shape$radius$set_radius_to_single_corner$$=function($shape$jscomp$85$$,$G__47804__$1$jscomp$inline_5137_attr$jscomp$11_attr__$1$$,$value$jscomp$426$$){$G__47804__$1$jscomp$inline_5137_attr$jscomp$11_attr__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$85$$))?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1647$r2$$,
$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1648$r3$$],null),$G__47804__$1$jscomp$inline_5137_attr$jscomp$11_attr__$1$$):$G__47804__$1$jscomp$inline_5137_attr$jscomp$11_attr__$1$$;$G__47804__$1$jscomp$inline_5137_attr$jscomp$11_attr__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$85$$))?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1646$r1$$],null),$G__47804__$1$jscomp$inline_5137_attr$jscomp$11_attr__$1$$):$G__47804__$1$jscomp$inline_5137_attr$jscomp$11_attr__$1$$;return $app$common$types$shape$radius$can_get_border_radius_QMARK_$$($shape$jscomp$85$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$85$$,$G__47804__$1$jscomp$inline_5137_attr$jscomp$11_attr__$1$$,
$value$jscomp$426$$):$shape$jscomp$85$$};$app$common$types$shape$radius$set_radius_for_corners$$=function($shape$jscomp$86$$,$attrs$jscomp$10$$,$value$jscomp$427$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($shape_SINGLEQUOTE_$$,$attr$jscomp$12$$){return $APP.$app$common$types$shape$radius$set_radius_to_single_corner$$($shape_SINGLEQUOTE_$$,$attr$jscomp$12$$,$value$jscomp$427$$)},$shape$jscomp$86$$,$attrs$jscomp$10$$)};
$app$common$types$path$shape_to_path$make_corner_arc$$=function($from$jscomp$14$$,$to$jscomp$16$$,$corner$$,$radius$jscomp$8$$){var $h1$jscomp$29_x$jscomp$1110$$=function(){var $G__48533__$1$$=$corner$$ instanceof $APP.$cljs$core$Keyword$$?$corner$$.$fqn$:null;switch($G__48533__$1$$){case "top-left":return $APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$14$$);case "top-right":return $APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$14$$)-$radius$jscomp$8$$;
case "bottom-right":return $APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$16$$)-$radius$jscomp$8$$;case "bottom-left":return $APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$16$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__48533__$1$$)].join(""));}}(),$h2$jscomp$23_y$jscomp$368$$=function(){var $G__48538__$1$$=$corner$$ instanceof $APP.$cljs$core$Keyword$$?$corner$$.$fqn$:null;switch($G__48538__$1$$){case "top-left":return $APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$14$$)-
$radius$jscomp$8$$;case "top-right":return $APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$14$$);case "bottom-right":return $APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$16$$)-2*$radius$jscomp$8$$;case "bottom-left":return $APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$16$$)-$radius$jscomp$8$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__48538__$1$$)].join(""));}}(),$width$jscomp$61$$=
$radius$jscomp$8$$*2,$height$jscomp$54$$=$radius$jscomp$8$$*2,$c1x$jscomp$8$$=$h1$jscomp$29_x$jscomp$1110$$+$width$jscomp$61$$/2*.448084975506,$c2x$jscomp$8$$=$h1$jscomp$29_x$jscomp$1110$$+$width$jscomp$61$$/2*1.5519150244939999,$c1y$jscomp$8$$=$h2$jscomp$23_y$jscomp$368$$+$height$jscomp$54$$/2*.448084975506,$c2y$jscomp$8$$=$h2$jscomp$23_y$jscomp$368$$+$height$jscomp$54$$/2*1.5519150244939999;$h1$jscomp$29_x$jscomp$1110$$=function(){var $G__48539__$1$$=$corner$$ instanceof $APP.$cljs$core$Keyword$$?
$corner$$.$fqn$:null;switch($G__48539__$1$$){case "top-left":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($from$jscomp$14$$,$APP.$cljs$cst$1511$y$$,$c1y$jscomp$8$$);case "top-right":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($from$jscomp$14$$,$APP.$cljs$cst$1510$x$$,$c2x$jscomp$8$$);case "bottom-right":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($from$jscomp$14$$,$APP.$cljs$cst$1511$y$$,$c2y$jscomp$8$$);case "bottom-left":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($from$jscomp$14$$,
$APP.$cljs$cst$1510$x$$,$c1x$jscomp$8$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__48539__$1$$)].join(""));}}();$h2$jscomp$23_y$jscomp$368$$=function(){var $G__48540__$1$$=$corner$$ instanceof $APP.$cljs$core$Keyword$$?$corner$$.$fqn$:null;switch($G__48540__$1$$){case "top-left":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($to$jscomp$16$$,$APP.$cljs$cst$1510$x$$,$c1x$jscomp$8$$);case "top-right":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($to$jscomp$16$$,
$APP.$cljs$cst$1511$y$$,$c1y$jscomp$8$$);case "bottom-right":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($to$jscomp$16$$,$APP.$cljs$cst$1510$x$$,$c2x$jscomp$8$$);case "bottom-left":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($to$jscomp$16$$,$APP.$cljs$cst$1511$y$$,$c2y$jscomp$8$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__48540__$1$$)].join(""));}}();return $app$common$types$path$helpers$make_curve_to$$($to$jscomp$16$$,
$h1$jscomp$29_x$jscomp$1110$$,$h2$jscomp$23_y$jscomp$368$$)};
$app$common$types$path$shape_to_path$circle__GT_path$$=function($c2y$jscomp$9_p__48545_y$jscomp$369$$){var $map__48550__$1_p1$jscomp$50$$=$APP.$cljs$core$__destructure_map$$($c2y$jscomp$9_p__48545_y$jscomp$369$$),$c2x$jscomp$9_x$jscomp$1111$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48550__$1_p1$jscomp$50$$,$APP.$cljs$cst$1510$x$$);$c2y$jscomp$9_p__48545_y$jscomp$369$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48550__$1_p1$jscomp$50$$,$APP.$cljs$cst$1511$y$$);
var $c1y$jscomp$9_width$jscomp$62$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48550__$1_p1$jscomp$50$$,$APP.$cljs$cst$290$width$$),$height$jscomp$55$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48550__$1_p1$jscomp$50$$,$APP.$cljs$cst$1522$height$$),$mx_p3$jscomp$7$$=$c2x$jscomp$9_x$jscomp$1111$$+$c1y$jscomp$9_width$jscomp$62$$/2,$my_p4$jscomp$1$$=$c2y$jscomp$9_p__48545_y$jscomp$369$$+$height$jscomp$55$$/2,$ex$jscomp$15_p2$jscomp$39$$=$c2x$jscomp$9_x$jscomp$1111$$+
$c1y$jscomp$9_width$jscomp$62$$,$c1x$jscomp$9_ey$$=$c2y$jscomp$9_p__48545_y$jscomp$369$$+$height$jscomp$55$$;$map__48550__$1_p1$jscomp$50$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($mx_p3$jscomp$7$$,$c2y$jscomp$9_p__48545_y$jscomp$369$$);$ex$jscomp$15_p2$jscomp$39$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($ex$jscomp$15_p2$jscomp$39$$,$my_p4$jscomp$1$$);$mx_p3$jscomp$7$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($mx_p3$jscomp$7$$,
$c1x$jscomp$9_ey$$);$my_p4$jscomp$1$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($c2x$jscomp$9_x$jscomp$1111$$,$my_p4$jscomp$1$$);$c1x$jscomp$9_ey$$=$c2x$jscomp$9_x$jscomp$1111$$+$c1y$jscomp$9_width$jscomp$62$$/2*.448084975506;$c2x$jscomp$9_x$jscomp$1111$$+=$c1y$jscomp$9_width$jscomp$62$$/2*1.5519150244939999;$c1y$jscomp$9_width$jscomp$62$$=$c2y$jscomp$9_p__48545_y$jscomp$369$$+$height$jscomp$55$$/2*.448084975506;$c2y$jscomp$9_p__48545_y$jscomp$369$$+=$height$jscomp$55$$/
2*1.5519150244939999;return new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$types$path$helpers$make_move_to$$($map__48550__$1_p1$jscomp$50$$),$app$common$types$path$helpers$make_curve_to$$($ex$jscomp$15_p2$jscomp$39$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__48550__$1_p1$jscomp$50$$,$APP.$cljs$cst$1510$x$$,$c2x$jscomp$9_x$jscomp$1111$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($ex$jscomp$15_p2$jscomp$39$$,
$APP.$cljs$cst$1511$y$$,$c1y$jscomp$9_width$jscomp$62$$)),$app$common$types$path$helpers$make_curve_to$$($mx_p3$jscomp$7$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($ex$jscomp$15_p2$jscomp$39$$,$APP.$cljs$cst$1511$y$$,$c2y$jscomp$9_p__48545_y$jscomp$369$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($mx_p3$jscomp$7$$,$APP.$cljs$cst$1510$x$$,$c2x$jscomp$9_x$jscomp$1111$$)),$app$common$types$path$helpers$make_curve_to$$($my_p4$jscomp$1$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($mx_p3$jscomp$7$$,
$APP.$cljs$cst$1510$x$$,$c1x$jscomp$9_ey$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($my_p4$jscomp$1$$,$APP.$cljs$cst$1511$y$$,$c2y$jscomp$9_p__48545_y$jscomp$369$$)),$app$common$types$path$helpers$make_curve_to$$($map__48550__$1_p1$jscomp$50$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($my_p4$jscomp$1$$,$APP.$cljs$cst$1511$y$$,$c1y$jscomp$9_width$jscomp$62$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__48550__$1_p1$jscomp$50$$,$APP.$cljs$cst$1510$x$$,
$c1x$jscomp$9_ey$$))],null)};
$app$common$types$path$shape_to_path$draw_rounded_rect_path$cljs$0core$0IFn$0_invoke$0arity$08$$=function($JSCompiler_temp_const$jscomp$14735_x$jscomp$1113$$,$p8_y$jscomp$371$$,$p7_width$jscomp$64$$,$JSCompiler_temp_const$jscomp$inline_14756_height$jscomp$57$$,$G__48568$jscomp$inline_14763_JSCompiler_inline_result$jscomp$inline_14761_r1$jscomp$16$$,$G__48567$jscomp$inline_14764_JSCompiler_inline_result$jscomp$inline_14759_r2$jscomp$14$$,$G__48566$jscomp$inline_14765_JSCompiler_inline_result$jscomp$inline_14757_r3$jscomp$2$$,$JSCompiler_inline_result$jscomp$14737_r4$jscomp$2$$){var $p1$jscomp$51$$=
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$14735_x$jscomp$1113$$,$p8_y$jscomp$371$$+$G__48568$jscomp$inline_14763_JSCompiler_inline_result$jscomp$inline_14761_r1$jscomp$16$$),$p2$jscomp$40$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$14735_x$jscomp$1113$$+$G__48568$jscomp$inline_14763_JSCompiler_inline_result$jscomp$inline_14761_r1$jscomp$16$$,$p8_y$jscomp$371$$),$p3$jscomp$8$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($p7_width$jscomp$64$$+
$JSCompiler_temp_const$jscomp$14735_x$jscomp$1113$$+-$G__48567$jscomp$inline_14764_JSCompiler_inline_result$jscomp$inline_14759_r2$jscomp$14$$,$p8_y$jscomp$371$$),$p4$jscomp$2$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($p7_width$jscomp$64$$+$JSCompiler_temp_const$jscomp$14735_x$jscomp$1113$$,$p8_y$jscomp$371$$+$G__48567$jscomp$inline_14764_JSCompiler_inline_result$jscomp$inline_14759_r2$jscomp$14$$),$p5$jscomp$1$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($p7_width$jscomp$64$$+
$JSCompiler_temp_const$jscomp$14735_x$jscomp$1113$$,$JSCompiler_temp_const$jscomp$inline_14756_height$jscomp$57$$+$p8_y$jscomp$371$$+-$G__48566$jscomp$inline_14765_JSCompiler_inline_result$jscomp$inline_14757_r3$jscomp$2$$),$p6$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($p7_width$jscomp$64$$+$JSCompiler_temp_const$jscomp$14735_x$jscomp$1113$$+-$G__48566$jscomp$inline_14765_JSCompiler_inline_result$jscomp$inline_14757_r3$jscomp$2$$,$JSCompiler_temp_const$jscomp$inline_14756_height$jscomp$57$$+
$p8_y$jscomp$371$$);$p7_width$jscomp$64$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$14735_x$jscomp$1113$$+$JSCompiler_inline_result$jscomp$14737_r4$jscomp$2$$,$JSCompiler_temp_const$jscomp$inline_14756_height$jscomp$57$$+$p8_y$jscomp$371$$);$p8_y$jscomp$371$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$14735_x$jscomp$1113$$,$JSCompiler_temp_const$jscomp$inline_14756_height$jscomp$57$$+$p8_y$jscomp$371$$+
-$JSCompiler_inline_result$jscomp$14737_r4$jscomp$2$$);var $JSCompiler_temp_const$jscomp$inline_14758$$=$JSCompiler_temp_const$jscomp$inline_14756_height$jscomp$57$$=$JSCompiler_temp_const$jscomp$14735_x$jscomp$1113$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$,$JSCompiler_temp_const$jscomp$inline_14760$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$,$G__48569$jscomp$inline_14762$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,
$app$common$types$path$helpers$make_move_to$$($p1$jscomp$51$$));$G__48568$jscomp$inline_14763_JSCompiler_inline_result$jscomp$inline_14761_r1$jscomp$16$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$51$$,$p2$jscomp$40$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48569$jscomp$inline_14762$$,$app$common$types$path$shape_to_path$make_corner_arc$$($p1$jscomp$51$$,$p2$jscomp$40$$,$APP.$cljs$cst$1883$top_left$$,$G__48568$jscomp$inline_14763_JSCompiler_inline_result$jscomp$inline_14761_r1$jscomp$16$$)):
$G__48569$jscomp$inline_14762$$;$G__48568$jscomp$inline_14763_JSCompiler_inline_result$jscomp$inline_14761_r1$jscomp$16$$=$JSCompiler_temp_const$jscomp$inline_14760$$.call($APP.$cljs$core$conj$$,$G__48568$jscomp$inline_14763_JSCompiler_inline_result$jscomp$inline_14761_r1$jscomp$16$$,$app$common$types$path$helpers$make_line_to$$($p3$jscomp$8$$));$G__48567$jscomp$inline_14764_JSCompiler_inline_result$jscomp$inline_14759_r2$jscomp$14$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p3$jscomp$8$$,
$p4$jscomp$2$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48568$jscomp$inline_14763_JSCompiler_inline_result$jscomp$inline_14761_r1$jscomp$16$$,$app$common$types$path$shape_to_path$make_corner_arc$$($p3$jscomp$8$$,$p4$jscomp$2$$,$APP.$cljs$cst$1884$top_right$$,$G__48567$jscomp$inline_14764_JSCompiler_inline_result$jscomp$inline_14759_r2$jscomp$14$$)):$G__48568$jscomp$inline_14763_JSCompiler_inline_result$jscomp$inline_14761_r1$jscomp$16$$;$G__48567$jscomp$inline_14764_JSCompiler_inline_result$jscomp$inline_14759_r2$jscomp$14$$=
$JSCompiler_temp_const$jscomp$inline_14758$$.call($APP.$cljs$core$conj$$,$G__48567$jscomp$inline_14764_JSCompiler_inline_result$jscomp$inline_14759_r2$jscomp$14$$,$app$common$types$path$helpers$make_line_to$$($p5$jscomp$1$$));$G__48566$jscomp$inline_14765_JSCompiler_inline_result$jscomp$inline_14757_r3$jscomp$2$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p5$jscomp$1$$,$p6$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48567$jscomp$inline_14764_JSCompiler_inline_result$jscomp$inline_14759_r2$jscomp$14$$,
$app$common$types$path$shape_to_path$make_corner_arc$$($p5$jscomp$1$$,$p6$$,$APP.$cljs$cst$1885$bottom_right$$,$G__48566$jscomp$inline_14765_JSCompiler_inline_result$jscomp$inline_14757_r3$jscomp$2$$)):$G__48567$jscomp$inline_14764_JSCompiler_inline_result$jscomp$inline_14759_r2$jscomp$14$$;$G__48566$jscomp$inline_14765_JSCompiler_inline_result$jscomp$inline_14757_r3$jscomp$2$$=$JSCompiler_temp_const$jscomp$inline_14756_height$jscomp$57$$.call($APP.$cljs$core$conj$$,$G__48566$jscomp$inline_14765_JSCompiler_inline_result$jscomp$inline_14757_r3$jscomp$2$$,
$app$common$types$path$helpers$make_line_to$$($p7_width$jscomp$64$$));$JSCompiler_inline_result$jscomp$14737_r4$jscomp$2$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p7_width$jscomp$64$$,$p8_y$jscomp$371$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48566$jscomp$inline_14765_JSCompiler_inline_result$jscomp$inline_14757_r3$jscomp$2$$,$app$common$types$path$shape_to_path$make_corner_arc$$($p7_width$jscomp$64$$,$p8_y$jscomp$371$$,$APP.$cljs$cst$1886$bottom_left$$,$JSCompiler_inline_result$jscomp$14737_r4$jscomp$2$$)):
$G__48566$jscomp$inline_14765_JSCompiler_inline_result$jscomp$inline_14757_r3$jscomp$2$$;return $JSCompiler_temp_const$jscomp$14735_x$jscomp$1113$$.call($APP.$cljs$core$conj$$,$JSCompiler_inline_result$jscomp$14737_r4$jscomp$2$$,$app$common$types$path$helpers$make_line_to$$($p1$jscomp$51$$))};
$app$common$types$path$shape_to_path$rect__GT_path$$=function($p__48572_x$jscomp$1114$$){var $map__48573__$1_r1$jscomp$17_radius$jscomp$9$$=$APP.$cljs$core$__destructure_map$$($p__48572_x$jscomp$1114$$);$p__48572_x$jscomp$1114$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48573__$1_r1$jscomp$17_radius$jscomp$9$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$372$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48573__$1_r1$jscomp$17_radius$jscomp$9$$,$APP.$cljs$cst$1511$y$$),
$width$jscomp$65$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48573__$1_r1$jscomp$17_radius$jscomp$9$$,$APP.$cljs$cst$290$width$$),$height$jscomp$58$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48573__$1_r1$jscomp$17_radius$jscomp$9$$,$APP.$cljs$cst$1522$height$$),$G__48574_r2$jscomp$15$$=$app$common$types$shape$radius$all_equal_QMARK_$$($map__48573__$1_r1$jscomp$17_radius$jscomp$9$$)?$cljs$cst$1877$radius_1$$:$cljs$cst$1878$radius_4$$;switch($G__48574_r2$jscomp$15$$ instanceof
$APP.$cljs$core$Keyword$$?$G__48574_r2$jscomp$15$$.$fqn$:null){case "radius-1":return $map__48573__$1_r1$jscomp$17_radius$jscomp$9$$=$app$common$geom$shapes$corners$shape_corners_1$$($map__48573__$1_r1$jscomp$17_radius$jscomp$9$$),$app$common$types$path$shape_to_path$draw_rounded_rect_path$cljs$0core$0IFn$0_invoke$0arity$08$$($p__48572_x$jscomp$1114$$,$y$jscomp$372$$,$width$jscomp$65$$,$height$jscomp$58$$,$map__48573__$1_r1$jscomp$17_radius$jscomp$9$$,$map__48573__$1_r1$jscomp$17_radius$jscomp$9$$,
$map__48573__$1_r1$jscomp$17_radius$jscomp$9$$,$map__48573__$1_r1$jscomp$17_radius$jscomp$9$$);case "radius-4":var $r4$jscomp$3_vec__48575$$=$app$common$geom$shapes$corners$shape_corners_4$$($map__48573__$1_r1$jscomp$17_radius$jscomp$9$$);$map__48573__$1_r1$jscomp$17_radius$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r4$jscomp$3_vec__48575$$,0,null);$G__48574_r2$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r4$jscomp$3_vec__48575$$,1,null);var $r3$jscomp$3$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r4$jscomp$3_vec__48575$$,2,null);$r4$jscomp$3_vec__48575$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r4$jscomp$3_vec__48575$$,3,null);return $app$common$types$path$shape_to_path$draw_rounded_rect_path$cljs$0core$0IFn$0_invoke$0arity$08$$($p__48572_x$jscomp$1114$$,$y$jscomp$372$$,$width$jscomp$65$$,$height$jscomp$58$$,$map__48573__$1_r1$jscomp$17_radius$jscomp$9$$,$G__48574_r2$jscomp$15$$,$r3$jscomp$3$$,$r4$jscomp$3_vec__48575$$);
default:return $APP.$cljs$core$PersistentVector$EMPTY$$}};
$app$common$types$path$shape_to_path$fix_first_relative$$=function($content$jscomp$67$$){var $head$jscomp$11$$=$APP.$cljs$core$first$$($content$jscomp$67$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($head$jscomp$11$$)?$cljs$cst$1887$relative$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$11$$):$head$jscomp$11$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($content$jscomp$67$$,0,$APP.$cljs$core$assoc$$,$cljs$cst$1887$relative$$,!1):$content$jscomp$67$$};
$app$common$types$path$shape_to_path$group_to_path$$=function($group$jscomp$1$$,$objects$jscomp$99$$){var $child_as_paths_content$jscomp$68_xform$jscomp$18$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$getf$$($objects$jscomp$99$$)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__48582_SHARP_$$){return $app$common$types$path$shape_to_path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$types$path$shape_to_path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$2$($p1__48582_SHARP_$$,
$objects$jscomp$99$$):$app$common$types$path$shape_to_path$convert_to_path$$($p1__48582_SHARP_$$,$objects$jscomp$99$$)}));$child_as_paths_content$jscomp$68_xform$jscomp$18$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$child_as_paths_content$jscomp$68_xform$jscomp$18$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$1$$));var $head$jscomp$12_head_data$$=$APP.$cljs$core$peek$$($child_as_paths_content$jscomp$68_xform$jscomp$18$$);
$head$jscomp$12_head_data$$=$APP.$cljs$core$select_keys$$($head$jscomp$12_head_data$$,$APP.$app$common$types$path$bool$style_properties$$);$child_as_paths_content$jscomp$68_xform$jscomp$18$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$path_shape_QMARK_$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1637$content$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$vec$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$path$shape_to_path$fix_first_relative$$)])),$child_as_paths_content$jscomp$68_xform$jscomp$18$$);return $APP.$app$common$data$without_keys$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($group$jscomp$1$$,
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$296$path$$),$APP.$cljs$cst$1637$content$$,$APP.$app$common$types$path$impl$path_data$$($child_as_paths_content$jscomp$68_xform$jscomp$18$$)),$head$jscomp$12_head_data$$])),$app$common$types$path$shape_to_path$dissoc_attrs$$)};
$app$common$types$path$shape_to_path$bool_to_path$$=function($shape$jscomp$89$$,$objects$jscomp$100$$){var $children$jscomp$161_content$jscomp$69$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48587_SHARP_$$){return $app$common$types$path$shape_to_path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$types$path$shape_to_path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$2$($p1__48587_SHARP_$$,$objects$jscomp$100$$):$app$common$types$path$shape_to_path$convert_to_path$$($p1__48587_SHARP_$$,
$objects$jscomp$100$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$100$$),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$89$$))),$bool_type$jscomp$2$$=$APP.$cljs$cst$1888$bool_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$89$$);$children$jscomp$161_content$jscomp$69$$=$APP.$app$common$types$path$impl$path_data$$($app$common$types$path$bool$calculate_content$$($bool_type$jscomp$2$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1637$content$$,
$children$jscomp$161_content$jscomp$69$$)));return $APP.$app$common$data$without_keys$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$89$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$296$path$$),$APP.$cljs$cst$1637$content$$,$children$jscomp$161_content$jscomp$69$$),$APP.$cljs$cst$1888$bool_type$$),$app$common$types$path$shape_to_path$dissoc_attrs$$)};
$app$common$types$path$shape_to_path$convert_to_path$$=function($shape$jscomp$90$$,$content$jscomp$70_content__$1$jscomp$14_objects$jscomp$101$$){var $type$jscomp$334$$=$shape$jscomp$90$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$90$$,$APP.$cljs$cst$139$type$$);switch($type$jscomp$334$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$334$$.$fqn$:null){case "group":case "frame":return $app$common$types$path$shape_to_path$group_to_path$$($shape$jscomp$90$$,$content$jscomp$70_content__$1$jscomp$14_objects$jscomp$101$$);
case "bool":return $app$common$types$path$shape_to_path$bool_to_path$$($shape$jscomp$90$$,$content$jscomp$70_content__$1$jscomp$14_objects$jscomp$101$$);case "rect":case "circle":case "image":case "text":$content$jscomp$70_content__$1$jscomp$14_objects$jscomp$101$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$334$$,$APP.$cljs$cst$1417$circle$$)?$app$common$types$path$shape_to_path$circle__GT_path$$($shape$jscomp$90$$):$app$common$types$path$shape_to_path$rect__GT_path$$($shape$jscomp$90$$);
$content$jscomp$70_content__$1$jscomp$14_objects$jscomp$101$$=$APP.$app$common$types$path$impl$from_plain$$($content$jscomp$70_content__$1$jscomp$14_objects$jscomp$101$$);var $transform$jscomp$40$$=function(){var $G__48590_G__48590__$1$$=$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$90$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$());$G__48590_G__48590__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$90$$))?
$app$common$geom$matrix$scale$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48590_G__48590__$1$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,1)):$G__48590_G__48590__$1$$;return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$90$$))?$app$common$geom$matrix$scale$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48590_G__48590__$1$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,-1)):$G__48590_G__48590__$1$$}(),
$content__$2$jscomp$8$$=$transform$jscomp$40$$!=null?$app$common$types$path$segment$transform_content$$($content$jscomp$70_content__$1$jscomp$14_objects$jscomp$101$$,$APP.$app$common$geom$matrix$transform_in$$($APP.$app$common$geom$shapes$common$shape__GT_center$$($shape$jscomp$90$$),$transform$jscomp$40$$)):$content$jscomp$70_content__$1$jscomp$14_objects$jscomp$101$$;return $APP.$app$common$data$without_keys$$(function(){var $G__48592$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$90$$,
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$296$path$$),$APP.$cljs$cst$1637$content$$,$content__$2$jscomp$8$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1612$image$$,$type$jscomp$334$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48592$$,$APP.$cljs$cst$1632$fill_image$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$90$$,$cljs$cst$1633$metadata$$)):$G__48592$$}(),$app$common$types$path$shape_to_path$dissoc_attrs$$);default:return $shape$jscomp$90$$}};
$app$common$types$path$close_subpaths$$=function($content$jscomp$74$$){return $APP.$app$common$types$path$impl$from_plain$$($app$common$types$path$subpath$close_subpaths$$($content$jscomp$74$$))};
$APP.$app$common$types$path$apply_content_modifiers$$=function($content$jscomp$76$$,$modifiers$jscomp$29$$){function $apply_to_index$$($content__$1$jscomp$15$$,$G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$){var $index$jscomp$199$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$,0,null),$params$jscomp$103$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$,
1,null);return $APP.$cljs$core$contains_QMARK_$$($content__$1$jscomp$15$$,$index$jscomp$199$$)?($G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$250$$=function(){var $or__5025__auto__$jscomp$356_or__5025__auto____$1$jscomp$42_or__5025__auto____$2$jscomp$11$$=$APP.$cljs$cst$1815$c1x$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$356_or__5025__auto____$1$jscomp$42_or__5025__auto____$2$jscomp$11$$))return $or__5025__auto__$jscomp$356_or__5025__auto____$1$jscomp$42_or__5025__auto____$2$jscomp$11$$;
$or__5025__auto__$jscomp$356_or__5025__auto____$1$jscomp$42_or__5025__auto____$2$jscomp$11$$=$APP.$cljs$cst$1816$c1y$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$356_or__5025__auto____$1$jscomp$42_or__5025__auto____$2$jscomp$11$$))return $or__5025__auto__$jscomp$356_or__5025__auto____$1$jscomp$42_or__5025__auto____$2$jscomp$11$$;$or__5025__auto__$jscomp$356_or__5025__auto____$1$jscomp$42_or__5025__auto____$2$jscomp$11$$=$APP.$cljs$cst$1817$c2x$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$356_or__5025__auto____$1$jscomp$42_or__5025__auto____$2$jscomp$11$$)?$or__5025__auto__$jscomp$356_or__5025__auto____$1$jscomp$42_or__5025__auto____$2$jscomp$11$$:$APP.$cljs$cst$1818$c2y$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$)}();return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$250$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1814$line_to$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($content__$1$jscomp$15$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$199$$,$APP.$cljs$cst$1812$command$$],null))):$and__5023__auto__$jscomp$250$$}())?$APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($content__$1$jscomp$15$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$199$$,$APP.$cljs$cst$1812$command$$],null),$cljs$cst$1819$curve_to$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$199$$,$APP.$cljs$cst$1430$params$$],null),$app$common$types$path$helpers$make_curve_params$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($content__$1$jscomp$15$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$199$$,$APP.$cljs$cst$1430$params$$],null)),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($content__$1$jscomp$15$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$199$$-1,$APP.$cljs$cst$1430$params$$],null)))):$content__$1$jscomp$15$$,$G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$))?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$199$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1510$x$$],null),$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$)):$G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$,$G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$))?
$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$199$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1511$y$$],null),$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$)):$G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$,
$G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1815$c1x$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$))?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$199$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1815$c1x$$],
null),$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1815$c1x$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$)):$G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$,$G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1816$c1y$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$))?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$199$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1816$c1y$$],null),$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1816$c1y$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$)):$G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$,$G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1817$c2x$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$))?
$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$199$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1817$c2x$$],null),$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1817$c2x$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$)):$G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$,
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1818$c2y$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$))?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$199$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1818$c2y$$],null),$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1818$c2y$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$103$$)):
$G__48634__$1_G__48634__$2_G__48634__$3_G__48634__$4_G__48634__$5_G__48634__$6_p__48628$$):$content__$1$jscomp$15$$}return $modifiers$jscomp$29$$!=null?$APP.$app$common$types$path$impl$path_data$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($apply_to_index$$,$APP.$cljs$core$vec$$($content$jscomp$76$$),$modifiers$jscomp$29$$)):$content$jscomp$76$$};
$app$common$types$path$transform_content$$=function($content$jscomp$77$$,$transform$jscomp$41$$){return $app$common$types$path$segment$transform_content$$($content$jscomp$77$$,$transform$jscomp$41$$)};
$app$common$types$path$move_content$$=function($JSCompiler_temp$jscomp$776_content$jscomp$78$$,$move_vec$jscomp$2_transform$jscomp$inline_5147$$){var $x$jscomp$inline_5142$$=$move_vec$jscomp$2_transform$jscomp$inline_5147$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($move_vec$jscomp$2_transform$jscomp$inline_5147$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$inline_5143$$=$move_vec$jscomp$2_transform$jscomp$inline_5147$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($move_vec$jscomp$2_transform$jscomp$inline_5147$$,
$APP.$cljs$cst$1511$y$$);if(0!==$x$jscomp$inline_5142$$||0!==$y$jscomp$inline_5143$$)$move_vec$jscomp$2_transform$jscomp$inline_5147$$=$APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($move_vec$jscomp$2_transform$jscomp$inline_5147$$),$JSCompiler_temp$jscomp$776_content$jscomp$78$$=$app$common$types$path$segment$transform_content$$($JSCompiler_temp$jscomp$776_content$jscomp$78$$,$move_vec$jscomp$2_transform$jscomp$inline_5147$$);return $JSCompiler_temp$jscomp$776_content$jscomp$78$$};
$APP.$app$common$types$path$get_points$$=function($content$jscomp$81_content__$1$jscomp$16$$){$content$jscomp$81_content__$1$jscomp$16$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$81_content__$1$jscomp$16$$);return $app$common$types$path$segment$get_points$$($content$jscomp$81_content__$1$jscomp$16$$)};
$APP.$app$common$types$path$calc_selrect$$=function($content$jscomp$82_content__$1$jscomp$17$$){$content$jscomp$82_content__$1$jscomp$17$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$82_content__$1$jscomp$17$$);return $app$common$types$path$segment$content__GT_selrect$$($content$jscomp$82_content__$1$jscomp$17$$)};
$APP.$app$common$types$path$get_handler_point$$=function($content$jscomp$84_content__$1$jscomp$19$$,$index$jscomp$200$$,$prefix$jscomp$41$$){$content$jscomp$84_content__$1$jscomp$19$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$84_content__$1$jscomp$19$$);return $APP.$app$common$types$path$segment$get_handler_point$$($content$jscomp$84_content__$1$jscomp$19$$,$index$jscomp$200$$,$prefix$jscomp$41$$)};
$APP.$app$common$types$path$opposite_index$$=function($content$jscomp$86_content__$1$jscomp$21$$,$index$jscomp$202$$,$prefix$jscomp$44$$){$content$jscomp$86_content__$1$jscomp$21$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$86_content__$1$jscomp$21$$);return $app$common$types$path$segment$opposite_index$$($content$jscomp$86_content__$1$jscomp$21$$,$index$jscomp$202$$,$prefix$jscomp$44$$)};
$app$common$types$path$point_indices$$=function($content$jscomp$87_content__$1$jscomp$22$$,$point$jscomp$41$$){$content$jscomp$87_content__$1$jscomp$22$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$87_content__$1$jscomp$22$$);return $app$common$types$path$segment$point_indices$$($content$jscomp$87_content__$1$jscomp$22$$,$point$jscomp$41$$)};
$app$common$types$path$handler_indices$$=function($content$jscomp$88_content__$1$jscomp$23$$,$point$jscomp$42$$){$content$jscomp$88_content__$1$jscomp$23$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$88_content__$1$jscomp$23$$);return $app$common$types$path$segment$handler_indices$$($content$jscomp$88_content__$1$jscomp$23$$,$point$jscomp$42$$)};
$app$common$types$path$append_segment$$=function($content$jscomp$90_content$jscomp$inline_5155_content__$1$jscomp$inline_5157$$,$segment$jscomp$38$$){$content$jscomp$90_content$jscomp$inline_5155_content__$1$jscomp$inline_5157$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$90_content$jscomp$inline_5155_content__$1$jscomp$inline_5157$$);$content$jscomp$90_content$jscomp$inline_5155_content__$1$jscomp$inline_5157$$=$app$common$types$path$impl$path_data_QMARK_$$($content$jscomp$90_content$jscomp$inline_5155_content__$1$jscomp$inline_5157$$)?
$APP.$cljs$core$vec$$($content$jscomp$90_content$jscomp$inline_5155_content__$1$jscomp$inline_5157$$):$content$jscomp$90_content$jscomp$inline_5155_content__$1$jscomp$inline_5157$$==null?$APP.$cljs$core$PersistentVector$EMPTY$$:$content$jscomp$90_content$jscomp$inline_5155_content__$1$jscomp$inline_5157$$;return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$90_content$jscomp$inline_5155_content__$1$jscomp$inline_5157$$,$app$common$types$path$impl$check_segment$$($segment$jscomp$38$$))};
$app$common$types$path$points__GT_content$$=function($var_args$jscomp$952$$){for(var $args__5755__auto__$jscomp$150_close$jscomp$inline_5162_map__48673__$1$jscomp$inline_5161$$=[],$len__5749__auto___48699_points$jscomp$inline_5159$$=arguments.length,$i__5750__auto___48700$$=0;;)if($i__5750__auto___48700$$<$len__5749__auto___48699_points$jscomp$inline_5159$$)$args__5755__auto__$jscomp$150_close$jscomp$inline_5162_map__48673__$1$jscomp$inline_5161$$.push(arguments[$i__5750__auto___48700$$]),$i__5750__auto___48700$$+=
1;else break;$len__5749__auto___48699_points$jscomp$inline_5159$$=arguments[0];$args__5755__auto__$jscomp$150_close$jscomp$inline_5162_map__48673__$1$jscomp$inline_5161$$=$APP.$cljs$core$__destructure_map$$(1<$args__5755__auto__$jscomp$150_close$jscomp$inline_5162_map__48673__$1$jscomp$inline_5161$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$150_close$jscomp$inline_5162_map__48673__$1$jscomp$inline_5161$$.slice(1),0,null):null);$args__5755__auto__$jscomp$150_close$jscomp$inline_5162_map__48673__$1$jscomp$inline_5161$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($args__5755__auto__$jscomp$150_close$jscomp$inline_5162_map__48673__$1$jscomp$inline_5161$$,$cljs$cst$1862$close$$);return $app$common$types$path$segment$points__GT_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($len__5749__auto___48699_points$jscomp$inline_5159$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$1862$close$$,$args__5755__auto__$jscomp$150_close$jscomp$inline_5162_map__48673__$1$jscomp$inline_5161$$]))};
$app$common$types$path$make_corner_point$$=function($content$jscomp$92_content__$1$jscomp$27$$,$point$jscomp$43$$){$content$jscomp$92_content__$1$jscomp$27$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$92_content__$1$jscomp$27$$);return $app$common$types$path$segment$make_corner_point$$($content$jscomp$92_content__$1$jscomp$27$$,$point$jscomp$43$$)};
$app$common$types$path$make_curve_point$$=function($content$jscomp$93_content__$1$jscomp$28$$,$point$jscomp$44$$){$content$jscomp$93_content__$1$jscomp$28$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$93_content__$1$jscomp$28$$);return $app$common$types$path$segment$make_curve_point$$($content$jscomp$93_content__$1$jscomp$28$$,$point$jscomp$44$$)};
$APP.$app$common$types$path$remove_nodes$$=function($content$jscomp$95_content__$1$jscomp$30$$,$points$jscomp$24$$){$content$jscomp$95_content__$1$jscomp$30$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$95_content__$1$jscomp$30$$);return $app$common$types$path$segment$remove_nodes$$($content$jscomp$95_content__$1$jscomp$30$$,$points$jscomp$24$$)};
$APP.$app$common$types$path$merge_nodes$$=function($content$jscomp$96_content$jscomp$inline_5164$$,$JSCompiler_inline_result$jscomp$775_points$jscomp$25$$){$content$jscomp$96_content$jscomp$inline_5164$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$96_content$jscomp$inline_5164$$);var $point__GT_merge_point$jscomp$inline_5167_segments$jscomp$inline_5166$$=$APP.$app$common$types$path$segment$get_segments_with_points$$($content$jscomp$96_content$jscomp$inline_5164$$,$JSCompiler_inline_result$jscomp$775_points$jscomp$25$$);
$APP.$cljs$core$seq$$($point__GT_merge_point$jscomp$inline_5167_segments$jscomp$inline_5166$$)?($point__GT_merge_point$jscomp$inline_5167_segments$jscomp$inline_5166$$=$app$common$types$path$segment$calculate_merge_points$$($app$common$types$path$segment$group_segments$$($point__GT_merge_point$jscomp$inline_5167_segments$jscomp$inline_5166$$),$JSCompiler_inline_result$jscomp$775_points$jscomp$25$$),$JSCompiler_inline_result$jscomp$775_points$jscomp$25$$=$app$common$types$path$segment$replace_points$$($app$common$types$path$segment$separate_nodes$$($content$jscomp$96_content$jscomp$inline_5164$$,
$JSCompiler_inline_result$jscomp$775_points$jscomp$25$$),$point__GT_merge_point$jscomp$inline_5167_segments$jscomp$inline_5166$$)):$JSCompiler_inline_result$jscomp$775_points$jscomp$25$$=$content$jscomp$96_content$jscomp$inline_5164$$;return $JSCompiler_inline_result$jscomp$775_points$jscomp$25$$};
$APP.$app$common$types$path$join_nodes$$=function($content$jscomp$97_content__$1$jscomp$32$$,$points$jscomp$26$$){$content$jscomp$97_content__$1$jscomp$32$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$97_content__$1$jscomp$32$$);return $app$common$types$path$segment$join_nodes$$($content$jscomp$97_content__$1$jscomp$32$$,$points$jscomp$26$$)};
$APP.$app$common$types$path$separate_nodes$$=function($content$jscomp$98_content__$1$jscomp$33$$,$points$jscomp$27$$){$content$jscomp$98_content__$1$jscomp$33$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$98_content__$1$jscomp$33$$);return $app$common$types$path$segment$separate_nodes$$($content$jscomp$98_content__$1$jscomp$33$$,$points$jscomp$27$$)};
$app$common$types$path$calc_bool_content_STAR_$$=function($shape$jscomp$93$$,$objects$jscomp$102$$){var $extract_content_xf$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$getf$$($objects$jscomp$102$$)),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1620$hidden$$),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__48681_SHARP_$$){return $app$common$types$path$shape_to_path$convert_to_path$$($p1__48681_SHARP_$$,
$objects$jscomp$102$$)}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1637$content$$)])),$contents$jscomp$13$$=$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($extract_content_xf$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$93$$));try{return $app$common$types$path$bool$calculate_content$$($APP.$cljs$cst$1888$bool_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$93$$),$contents$jscomp$13$$)}catch($e48685$$){return function($cause$jscomp$32$$){throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$(["unable to calculate bool content for shape ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$93$$))].join(""),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1888$bool_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$93$$),$APP.$cljs$cst$273$code$$,$cljs$cst$1889$invalid_path_content$$,$APP.$cljs$cst$275$hint$$,
["unable to calculate bool content for shape ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$93$$))].join(""),$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$93$$),$APP.$cljs$cst$1637$content$$,$APP.$cljs$core$vec$$($contents$jscomp$13$$)],null),null])),$cause$jscomp$32$$);}($e48685$$)}};
$app$common$types$path$calc_bool_content$$=function($content$jscomp$99_shape$jscomp$94$$,$objects$jscomp$103$$){$content$jscomp$99_shape$jscomp$94$$=$app$common$types$path$calc_bool_content_STAR_$$($content$jscomp$99_shape$jscomp$94$$,$objects$jscomp$103$$);return $APP.$app$common$types$path$impl$path_data$$($content$jscomp$99_shape$jscomp$94$$)};
$APP.$app$common$types$path$update_bool_shape$$=function($shape$jscomp$95_shape__$1$jscomp$3$$,$content$jscomp$100_objects$jscomp$104$$){$content$jscomp$100_objects$jscomp$104$$=$APP.$cljs$core$fn_QMARK_$$($app$common$types$path$wasm_COLON_calc_bool_content$$)?$app$common$types$path$wasm_COLON_calc_bool_content$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$types$path$wasm_COLON_calc_bool_content$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$95_shape__$1$jscomp$3$$,$content$jscomp$100_objects$jscomp$104$$):
$app$common$types$path$wasm_COLON_calc_bool_content$$($shape$jscomp$95_shape__$1$jscomp$3$$,$content$jscomp$100_objects$jscomp$104$$):$app$common$types$path$calc_bool_content$$($shape$jscomp$95_shape__$1$jscomp$3$$,$content$jscomp$100_objects$jscomp$104$$);$shape$jscomp$95_shape__$1$jscomp$3$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$95_shape__$1$jscomp$3$$,$APP.$cljs$cst$1637$content$$,$content$jscomp$100_objects$jscomp$104$$);return $app$common$types$path$update_geometry$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$95_shape__$1$jscomp$3$$)};
$APP.$app$common$types$path$shape_with_open_path_QMARK_$$=function($G__48689$jscomp$inline_5169_shape$jscomp$96$$){var $JSCompiler_inline_result$jscomp$796_maybe_close$$=$APP.$cljs$core$contains_QMARK_$$($G__48689$jscomp$inline_5169_shape$jscomp$96$$,$APP.$cljs$cst$1890$svg_attrs$$)?$APP.$cljs$core$identity$$:$app$common$types$path$subpath$close_subpaths$$,$JSCompiler_temp$jscomp$795$$;if($JSCompiler_temp$jscomp$795$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__48689$jscomp$inline_5169_shape$jscomp$96$$)))$G__48689$jscomp$inline_5169_shape$jscomp$96$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($G__48689$jscomp$inline_5169_shape$jscomp$96$$),$JSCompiler_inline_result$jscomp$796_maybe_close$$=$JSCompiler_inline_result$jscomp$796_maybe_close$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$796_maybe_close$$.$cljs$core$IFn$_invoke$arity$1$($G__48689$jscomp$inline_5169_shape$jscomp$96$$):
$JSCompiler_inline_result$jscomp$796_maybe_close$$($G__48689$jscomp$inline_5169_shape$jscomp$96$$),$JSCompiler_temp$jscomp$795$$=!$APP.$cljs$core$every_QMARK_$$($app$common$types$path$subpath$is_closed_QMARK_$$,$app$common$types$path$subpath$get_subpaths$$($JSCompiler_inline_result$jscomp$796_maybe_close$$));return $JSCompiler_temp$jscomp$795$$};
$app$common$geom$shapes$transforms$valid_point_QMARK_$$=function($o$jscomp$248$$){return $app$common$geom$point$point_QMARK_$$($o$jscomp$248$$)&&$APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($o$jscomp$248$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$248$$,$APP.$cljs$cst$1510$x$$),$o$jscomp$248$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$248$$,$APP.$cljs$cst$1511$y$$))};
$app$common$geom$shapes$transforms$move_selrect$$=function($h$jscomp$149_selrect$jscomp$7$$,$dy$jscomp$10_pt$jscomp$18$$){if($h$jscomp$149_selrect$jscomp$7$$!=null&&$app$common$geom$shapes$transforms$valid_point_QMARK_$$($dy$jscomp$10_pt$jscomp$18$$)){var $x$jscomp$1115$$=$h$jscomp$149_selrect$jscomp$7$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$149_selrect$jscomp$7$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$373$$=$h$jscomp$149_selrect$jscomp$7$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$149_selrect$jscomp$7$$,
$APP.$cljs$cst$1511$y$$),$w$jscomp$28$$=$h$jscomp$149_selrect$jscomp$7$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$149_selrect$jscomp$7$$,$APP.$cljs$cst$290$width$$);$h$jscomp$149_selrect$jscomp$7$$=$h$jscomp$149_selrect$jscomp$7$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$149_selrect$jscomp$7$$,$APP.$cljs$cst$1522$height$$);var $dx$jscomp$10$$=$dy$jscomp$10_pt$jscomp$18$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dy$jscomp$10_pt$jscomp$18$$,
$APP.$cljs$cst$1510$x$$);$dy$jscomp$10_pt$jscomp$18$$=$dy$jscomp$10_pt$jscomp$18$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dy$jscomp$10_pt$jscomp$18$$,$APP.$cljs$cst$1511$y$$);return $APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$common$math$finite_QMARK_$$($x$jscomp$1115$$)?$dx$jscomp$10$$+$x$jscomp$1115$$:$x$jscomp$1115$$,$APP.$app$common$math$finite_QMARK_$$($y$jscomp$373$$)?$dy$jscomp$10_pt$jscomp$18$$+$y$jscomp$373$$:$y$jscomp$373$$,$w$jscomp$28$$,
$h$jscomp$149_selrect$jscomp$7$$)}return $h$jscomp$149_selrect$jscomp$7$$};$app$common$geom$shapes$transforms$move_points$$=function($points$jscomp$28$$,$move_vec$jscomp$3$$){return $app$common$geom$shapes$transforms$valid_point_QMARK_$$($move_vec$jscomp$3$$)?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48764_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__48764_SHARP_$$,$move_vec$jscomp$3$$)},$points$jscomp$28$$):$points$jscomp$28$$};
$app$common$geom$shapes$transforms$move_position_data$$=function($position_data$$,$delta$jscomp$8$$){if($position_data$$!=null){var $dx$jscomp$11$$=$delta$jscomp$8$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($delta$jscomp$8$$,$APP.$cljs$cst$1510$x$$),$dy$jscomp$11$$=$delta$jscomp$8$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($delta$jscomp$8$$,$APP.$cljs$cst$1511$y$$);return $APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($dx$jscomp$11$$,$dy$jscomp$11$$)?
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48765_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__48765_SHARP_$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$_PLUS_$$,$dx$jscomp$11$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_PLUS_$$,$dy$jscomp$11$$)},$position_data$$):$position_data$$}return null};
$app$common$geom$shapes$transforms$transform_position_data$$=function($position_data$jscomp$1$$,$transform$jscomp$43$$){if($position_data$jscomp$1$$!=null){var $dx$jscomp$12$$=$transform$jscomp$43$$?.e??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$43$$,$cljs$cst$1449$e$$),$dy$jscomp$12$$=$transform$jscomp$43$$?.f??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$43$$,$cljs$cst$598$f$$);return $APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($dx$jscomp$12$$,
$dy$jscomp$12$$)?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48766_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__48766_SHARP_$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$_PLUS_$$,$dx$jscomp$12$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_PLUS_$$,$dy$jscomp$12$$)},$position_data$jscomp$1$$):$position_data$jscomp$1$$}return null};
$app$common$geom$shapes$transforms$move$$=function($G__48769_shape$jscomp$99$$,$dy$jscomp$13_mvec_point$jscomp$45$$){var $type$jscomp$335$$=$G__48769_shape$jscomp$99$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48769_shape$jscomp$99$$,$APP.$cljs$cst$139$type$$),$dx$jscomp$13_dx__$1$$=$dy$jscomp$13_mvec_point$jscomp$45$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dy$jscomp$13_mvec_point$jscomp$45$$,$APP.$cljs$cst$1510$x$$);$dy$jscomp$13_mvec_point$jscomp$45$$=
$dy$jscomp$13_mvec_point$jscomp$45$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dy$jscomp$13_mvec_point$jscomp$45$$,$APP.$cljs$cst$1511$y$$);$dx$jscomp$13_dx__$1$$=$APP.$app$common$math$finite$$($dx$jscomp$13_dx__$1$$,0);var $dy__$1$$=$APP.$app$common$math$finite$$($dy$jscomp$13_mvec_point$jscomp$45$$,0);$dy$jscomp$13_mvec_point$jscomp$45$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($dx$jscomp$13_dx__$1$$,$dy__$1$$);$G__48769_shape$jscomp$99$$=$APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48769_shape$jscomp$99$$,
$APP.$cljs$cst$1605$selrect$$,$app$common$geom$shapes$transforms$move_selrect$$,$dy$jscomp$13_mvec_point$jscomp$45$$),$APP.$cljs$cst$1604$points$$,$app$common$geom$shapes$transforms$move_points$$,$dy$jscomp$13_mvec_point$jscomp$45$$),$APP.$cljs$cst$1510$x$$,$app$common$data$safe_PLUS_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$dx$jscomp$13_dx__$1$$])),$APP.$cljs$cst$1511$y$$,$app$common$data$safe_PLUS_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$dy__$1$$])),
$APP.$cljs$cst$1891$position_data$$,$app$common$geom$shapes$transforms$move_position_data$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$dy$jscomp$13_mvec_point$jscomp$45$$]));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1610$bool$$,$type$jscomp$335$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,$type$jscomp$335$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48769_shape$jscomp$99$$,$APP.$cljs$cst$1637$content$$,
$app$common$types$path$move_content$$,$dy$jscomp$13_mvec_point$jscomp$45$$):$G__48769_shape$jscomp$99$$};
$app$common$geom$shapes$transforms$absolute_move$$=function($shape$jscomp$100$$,$pos$jscomp$93_y$jscomp$374$$){if($APP.$cljs$core$truth_$$($shape$jscomp$100$$)){var $x$jscomp$1116$$=$pos$jscomp$93_y$jscomp$374$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$93_y$jscomp$374$$,$APP.$cljs$cst$1510$x$$);$pos$jscomp$93_y$jscomp$374$$=$pos$jscomp$93_y$jscomp$374$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$93_y$jscomp$374$$,$APP.$cljs$cst$1511$y$$);var $py$jscomp$3_sr$$=
$shape$jscomp$100$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$100$$,$APP.$cljs$cst$1605$selrect$$),$px$jscomp$4$$=$py$jscomp$3_sr$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($py$jscomp$3_sr$$,$APP.$cljs$cst$1510$x$$);$py$jscomp$3_sr$$=$py$jscomp$3_sr$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($py$jscomp$3_sr$$,$APP.$cljs$cst$1511$y$$);return $app$common$geom$shapes$transforms$move$$($shape$jscomp$100$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$math$finite$$($x$jscomp$1116$$,
0)-$px$jscomp$4$$,$APP.$app$common$math$finite$$($pos$jscomp$93_y$jscomp$374$$,0)-$py$jscomp$3_sr$$))}return null};
$APP.$app$common$geom$shapes$transforms$transform_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$=function($shape$jscomp$102$$,$params$jscomp$104$$){var $JSCompiler_temp_const$jscomp$797$$=$app$common$geom$shapes$transforms$transform_matrix$cljs$0core$0IFn$0_invoke$0arity$03$$;var $JSCompiler_inline_result$jscomp$798_or__5025__auto__$jscomp$inline_5171$$=$APP.$app$common$geom$shapes$common$shape__GT_center$$($shape$jscomp$102$$);$JSCompiler_inline_result$jscomp$798_or__5025__auto__$jscomp$inline_5171$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$798_or__5025__auto__$jscomp$inline_5171$$)?$JSCompiler_inline_result$jscomp$798_or__5025__auto__$jscomp$inline_5171$$:$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0);return $JSCompiler_temp_const$jscomp$797$$($shape$jscomp$102$$,$params$jscomp$104$$,$JSCompiler_inline_result$jscomp$798_or__5025__auto__$jscomp$inline_5171$$)};
$app$common$geom$shapes$transforms$transform_matrix$cljs$0core$0IFn$0_invoke$0arity$03$$=function($JSCompiler_inline_result$jscomp$14738_flip_y$jscomp$1_p__48779$$,$map__48782__$1_no_flip_p__48780$$,$shape_center$jscomp$2$$){var $G__48785$jscomp$inline_14768_map__48781__$1_transform$jscomp$44$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$14738_flip_y$jscomp$1_p__48779$$),$G__48784$jscomp$inline_14767_flip_x$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48785$jscomp$inline_14768_map__48781__$1_transform$jscomp$44$$,
$APP.$cljs$cst$1879$flip_x$$);$JSCompiler_inline_result$jscomp$14738_flip_y$jscomp$1_p__48779$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48785$jscomp$inline_14768_map__48781__$1_transform$jscomp$44$$,$APP.$cljs$cst$1880$flip_y$$);$G__48785$jscomp$inline_14768_map__48781__$1_transform$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48785$jscomp$inline_14768_map__48781__$1_transform$jscomp$44$$,$APP.$cljs$cst$1289$transform$$);$map__48782__$1_no_flip_p__48780$$=
$APP.$cljs$core$__destructure_map$$($map__48782__$1_no_flip_p__48780$$);$map__48782__$1_no_flip_p__48780$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48782__$1_no_flip_p__48780$$,$cljs$cst$1892$no_flip$$);var $G__48786$jscomp$inline_14769$$=$APP.$app$common$geom$matrix$translate$$($APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$(),$shape_center$jscomp$2$$);$G__48785$jscomp$inline_14768_map__48781__$1_transform$jscomp$44$$=$G__48785$jscomp$inline_14768_map__48781__$1_transform$jscomp$44$$!=
null?$APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($G__48786$jscomp$inline_14769$$,$G__48785$jscomp$inline_14768_map__48781__$1_transform$jscomp$44$$):$G__48786$jscomp$inline_14769$$;$G__48784$jscomp$inline_14767_flip_x$jscomp$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__48784$jscomp$inline_14767_flip_x$jscomp$1$$)?$map__48782__$1_no_flip_p__48780$$:$G__48784$jscomp$inline_14767_flip_x$jscomp$1$$)?$app$common$geom$matrix$scale$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48785$jscomp$inline_14768_map__48781__$1_transform$jscomp$44$$,
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,1)):$G__48785$jscomp$inline_14768_map__48781__$1_transform$jscomp$44$$;$JSCompiler_inline_result$jscomp$14738_flip_y$jscomp$1_p__48779$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$14738_flip_y$jscomp$1_p__48779$$)?$map__48782__$1_no_flip_p__48780$$:$JSCompiler_inline_result$jscomp$14738_flip_y$jscomp$1_p__48779$$)?$app$common$geom$matrix$scale$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48784$jscomp$inline_14767_flip_x$jscomp$1$$,
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,-1)):$G__48784$jscomp$inline_14767_flip_x$jscomp$1$$;return $APP.$app$common$geom$matrix$translate$$($JSCompiler_inline_result$jscomp$14738_flip_y$jscomp$1_p__48779$$,$APP.$app$common$geom$point$negate$$($shape_center$jscomp$2$$))};
$app$common$geom$shapes$transforms$inverse_transform_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$=function($shape$jscomp$105$$,$params$jscomp$105$$){var $JSCompiler_temp_const$jscomp$799$$=$app$common$geom$shapes$transforms$inverse_transform_matrix$cljs$0core$0IFn$0_invoke$0arity$03$$;var $JSCompiler_inline_result$jscomp$800_or__5025__auto__$jscomp$inline_5173$$=$APP.$app$common$geom$shapes$common$shape__GT_center$$($shape$jscomp$105$$);$JSCompiler_inline_result$jscomp$800_or__5025__auto__$jscomp$inline_5173$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$800_or__5025__auto__$jscomp$inline_5173$$)?$JSCompiler_inline_result$jscomp$800_or__5025__auto__$jscomp$inline_5173$$:$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0);return $JSCompiler_temp_const$jscomp$799$$($shape$jscomp$105$$,$params$jscomp$105$$,$JSCompiler_inline_result$jscomp$800_or__5025__auto__$jscomp$inline_5173$$)};
$app$common$geom$shapes$transforms$inverse_transform_matrix$cljs$0core$0IFn$0_invoke$0arity$03$$=function($G__48796$jscomp$inline_14771_JSCompiler_inline_result$jscomp$14739_flip_y$jscomp$2_p__48792$$,$map__48795__$1_no_flip$jscomp$1_p__48793$$,$shape_center$jscomp$3$$){var $map__48794__$1_transform_inverse$jscomp$9$$=$APP.$cljs$core$__destructure_map$$($G__48796$jscomp$inline_14771_JSCompiler_inline_result$jscomp$14739_flip_y$jscomp$2_p__48792$$),$G__48797$jscomp$inline_14772_flip_x$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48794__$1_transform_inverse$jscomp$9$$,
$APP.$cljs$cst$1879$flip_x$$);$G__48796$jscomp$inline_14771_JSCompiler_inline_result$jscomp$14739_flip_y$jscomp$2_p__48792$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48794__$1_transform_inverse$jscomp$9$$,$APP.$cljs$cst$1880$flip_y$$);$map__48794__$1_transform_inverse$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48794__$1_transform_inverse$jscomp$9$$,$APP.$cljs$cst$1787$transform_inverse$$);$map__48795__$1_no_flip$jscomp$1_p__48793$$=$APP.$cljs$core$__destructure_map$$($map__48795__$1_no_flip$jscomp$1_p__48793$$);
$map__48795__$1_no_flip$jscomp$1_p__48793$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48795__$1_no_flip$jscomp$1_p__48793$$,$cljs$cst$1892$no_flip$$);var $G__48798$jscomp$inline_14773$$=$APP.$app$common$geom$matrix$translate$$($APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$(),$shape_center$jscomp$3$$);$G__48797$jscomp$inline_14772_flip_x$jscomp$2$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__48797$jscomp$inline_14772_flip_x$jscomp$2$$)?$map__48795__$1_no_flip$jscomp$1_p__48793$$:
$G__48797$jscomp$inline_14772_flip_x$jscomp$2$$)?$app$common$geom$matrix$scale$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48798$jscomp$inline_14773$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,1)):$G__48798$jscomp$inline_14773$$;$G__48796$jscomp$inline_14771_JSCompiler_inline_result$jscomp$14739_flip_y$jscomp$2_p__48792$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__48796$jscomp$inline_14771_JSCompiler_inline_result$jscomp$14739_flip_y$jscomp$2_p__48792$$)?$map__48795__$1_no_flip$jscomp$1_p__48793$$:
$G__48796$jscomp$inline_14771_JSCompiler_inline_result$jscomp$14739_flip_y$jscomp$2_p__48792$$)?$app$common$geom$matrix$scale$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48797$jscomp$inline_14772_flip_x$jscomp$2$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,-1)):$G__48797$jscomp$inline_14772_flip_x$jscomp$2$$;$G__48796$jscomp$inline_14771_JSCompiler_inline_result$jscomp$14739_flip_y$jscomp$2_p__48792$$=$map__48794__$1_transform_inverse$jscomp$9$$!=null?$APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($G__48796$jscomp$inline_14771_JSCompiler_inline_result$jscomp$14739_flip_y$jscomp$2_p__48792$$,
$map__48794__$1_transform_inverse$jscomp$9$$):$G__48796$jscomp$inline_14771_JSCompiler_inline_result$jscomp$14739_flip_y$jscomp$2_p__48792$$;return $APP.$app$common$geom$matrix$translate$$($G__48796$jscomp$inline_14771_JSCompiler_inline_result$jscomp$14739_flip_y$jscomp$2_p__48792$$,$APP.$app$common$geom$point$negate$$($shape_center$jscomp$3$$))};
$app$common$geom$shapes$transforms$transform_str$cljs$0core$0IFn$0_invoke$0arity$02$$=function($map__48806__$1_p__48803$$,$p__48804$$){var $map__48805__$1$$=$APP.$cljs$core$__destructure_map$$($map__48806__$1_p__48803$$),$transform$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48805__$1$$,$APP.$cljs$cst$1289$transform$$),$flip_x$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48805__$1$$,$APP.$cljs$cst$1879$flip_x$$),$flip_y$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48805__$1$$,
$APP.$cljs$cst$1880$flip_y$$);$map__48806__$1_p__48803$$=$APP.$cljs$core$__destructure_map$$($p__48804$$);var $no_flip$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48806__$1_p__48803$$,$cljs$cst$1892$no_flip$$);return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$255_or__5025__auto__$jscomp$360_or__5025__auto____$1$jscomp$43$$=$map__48805__$1$$!=null;if($and__5023__auto__$jscomp$255_or__5025__auto__$jscomp$360_or__5025__auto____$1$jscomp$43$$){if($and__5023__auto__$jscomp$255_or__5025__auto__$jscomp$360_or__5025__auto____$1$jscomp$43$$=
$transform$jscomp$45$$!=null)return $and__5023__auto__$jscomp$255_or__5025__auto__$jscomp$360_or__5025__auto____$1$jscomp$43$$;$and__5023__auto__$jscomp$255_or__5025__auto__$jscomp$360_or__5025__auto____$1$jscomp$43$$=$APP.$cljs$core$truth_$$($no_flip$jscomp$2$$)?$flip_x$jscomp$3$$:$no_flip$jscomp$2$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$255_or__5025__auto__$jscomp$360_or__5025__auto____$1$jscomp$43$$)?$and__5023__auto__$jscomp$255_or__5025__auto__$jscomp$360_or__5025__auto____$1$jscomp$43$$:
$APP.$cljs$core$truth_$$($no_flip$jscomp$2$$)?$flip_y$jscomp$3$$:$no_flip$jscomp$2$$}return $and__5023__auto__$jscomp$255_or__5025__auto__$jscomp$360_or__5025__auto____$1$jscomp$43$$}())?""+($APP.$app$common$geom$shapes$transforms$transform_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$($map__48805__$1$$,$map__48806__$1_p__48803$$)??""):""};
$app$common$geom$shapes$transforms$transform_rect$$=function($points$jscomp$29_rect$jscomp$12$$,$matrix$jscomp$12$$){$points$jscomp$29_rect$jscomp$12$$=$APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$rect$rect__GT_points$$($points$jscomp$29_rect$jscomp$12$$),$matrix$jscomp$12$$);return $APP.$app$common$geom$rect$points__GT_rect$$($points$jscomp$29_rect$jscomp$12$$)};
$app$common$geom$shapes$transforms$calculate_selrect$$=function($p4$jscomp$3_points$jscomp$30$$,$center$jscomp$16$$){var $height$jscomp$59_p1$jscomp$52$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($p4$jscomp$3_points$jscomp$30$$,0),$p2$jscomp$41_width$jscomp$66$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($p4$jscomp$3_points$jscomp$30$$,1);$p4$jscomp$3_points$jscomp$30$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($p4$jscomp$3_points$jscomp$30$$,3);$p2$jscomp$41_width$jscomp$66$$=
$APP.$app$common$math$hypot$$(($p2$jscomp$41_width$jscomp$66$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$41_width$jscomp$66$$,$APP.$cljs$cst$1510$x$$))-($height$jscomp$59_p1$jscomp$52$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$59_p1$jscomp$52$$,$APP.$cljs$cst$1510$x$$)),($p2$jscomp$41_width$jscomp$66$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$41_width$jscomp$66$$,$APP.$cljs$cst$1511$y$$))-($height$jscomp$59_p1$jscomp$52$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$59_p1$jscomp$52$$,$APP.$cljs$cst$1511$y$$)));$height$jscomp$59_p1$jscomp$52$$=$APP.$app$common$math$hypot$$(($height$jscomp$59_p1$jscomp$52$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$59_p1$jscomp$52$$,$APP.$cljs$cst$1510$x$$))-($p4$jscomp$3_points$jscomp$30$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p4$jscomp$3_points$jscomp$30$$,$APP.$cljs$cst$1510$x$$)),($height$jscomp$59_p1$jscomp$52$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$59_p1$jscomp$52$$,$APP.$cljs$cst$1511$y$$))-($p4$jscomp$3_points$jscomp$30$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p4$jscomp$3_points$jscomp$30$$,$APP.$cljs$cst$1511$y$$)));return $APP.$app$common$geom$rect$center__GT_rect$cljs$0core$0IFn$0_invoke$0arity$03$$($center$jscomp$16$$,$p2$jscomp$41_width$jscomp$66$$,$height$jscomp$59_p1$jscomp$52$$)};
$app$common$geom$shapes$transforms$calculate_transform$$=function($mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$,$center$jscomp$17_transform__$1$$,$ma0$jscomp$inline_5185_selrect$jscomp$9$$){var $d1$jscomp$inline_5177_ma3$jscomp$inline_5188$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$,0,null),$d2$jscomp$inline_5178_ma4$jscomp$inline_5189$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$,
1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$,2,null);var $d4$jscomp$inline_5179_ma5$jscomp$inline_5190$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$,3,null);$mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$=$app$common$math$round_to_zero$$($ma0$jscomp$inline_5185_selrect$jscomp$9$$?.x1??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ma0$jscomp$inline_5185_selrect$jscomp$9$$,$APP.$cljs$cst$1523$x1$$));var $y1$jscomp$inline_5181$$=$app$common$math$round_to_zero$$($ma0$jscomp$inline_5185_selrect$jscomp$9$$?.y1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ma0$jscomp$inline_5185_selrect$jscomp$9$$,$APP.$cljs$cst$1524$y1$$)),$x2$jscomp$inline_5182$$=$app$common$math$round_to_zero$$($ma0$jscomp$inline_5185_selrect$jscomp$9$$?.x2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ma0$jscomp$inline_5185_selrect$jscomp$9$$,
$APP.$cljs$cst$1525$x2$$)),$mb5$jscomp$inline_5196_y2$jscomp$inline_5183$$=$app$common$math$round_to_zero$$($ma0$jscomp$inline_5185_selrect$jscomp$9$$?.y2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ma0$jscomp$inline_5185_selrect$jscomp$9$$,$APP.$cljs$cst$1526$y2$$)),$det$jscomp$inline_5184$$=($y1$jscomp$inline_5181$$-$mb5$jscomp$inline_5196_y2$jscomp$inline_5183$$)*$mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$-($y1$jscomp$inline_5181$$-$mb5$jscomp$inline_5196_y2$jscomp$inline_5183$$)*
$x2$jscomp$inline_5182$$+($y1$jscomp$inline_5181$$-$y1$jscomp$inline_5181$$)*$mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$;if($det$jscomp$inline_5184$$===0)$mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$=null;else{$ma0$jscomp$inline_5185_selrect$jscomp$9$$=$app$common$math$round_to_zero$$($d1$jscomp$inline_5177_ma3$jscomp$inline_5188$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($d1$jscomp$inline_5177_ma3$jscomp$inline_5188$$,
$APP.$cljs$cst$1510$x$$));var $ma1$jscomp$inline_5186$$=$app$common$math$round_to_zero$$($d2$jscomp$inline_5178_ma4$jscomp$inline_5189$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($d2$jscomp$inline_5178_ma4$jscomp$inline_5189$$,$APP.$cljs$cst$1510$x$$)),$ma2$jscomp$inline_5187$$=$app$common$math$round_to_zero$$($d4$jscomp$inline_5179_ma5$jscomp$inline_5190$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($d4$jscomp$inline_5179_ma5$jscomp$inline_5190$$,$APP.$cljs$cst$1510$x$$));
$d1$jscomp$inline_5177_ma3$jscomp$inline_5188$$=$app$common$math$round_to_zero$$($d1$jscomp$inline_5177_ma3$jscomp$inline_5188$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($d1$jscomp$inline_5177_ma3$jscomp$inline_5188$$,$APP.$cljs$cst$1511$y$$));$d2$jscomp$inline_5178_ma4$jscomp$inline_5189$$=$app$common$math$round_to_zero$$($d2$jscomp$inline_5178_ma4$jscomp$inline_5189$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($d2$jscomp$inline_5178_ma4$jscomp$inline_5189$$,$APP.$cljs$cst$1511$y$$));
$d4$jscomp$inline_5179_ma5$jscomp$inline_5190$$=$app$common$math$round_to_zero$$($d4$jscomp$inline_5179_ma5$jscomp$inline_5190$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($d4$jscomp$inline_5179_ma5$jscomp$inline_5190$$,$APP.$cljs$cst$1511$y$$));var $mb0$jscomp$inline_5191$$=($y1$jscomp$inline_5181$$-$mb5$jscomp$inline_5196_y2$jscomp$inline_5183$$)/$det$jscomp$inline_5184$$,$mb1$jscomp$inline_5192$$=($mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$-
$x2$jscomp$inline_5182$$)/$det$jscomp$inline_5184$$,$mb2$jscomp$inline_5193$$=($x2$jscomp$inline_5182$$*$mb5$jscomp$inline_5196_y2$jscomp$inline_5183$$-$mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$*$y1$jscomp$inline_5181$$)/$det$jscomp$inline_5184$$,$mb3$jscomp$inline_5194$$=($mb5$jscomp$inline_5196_y2$jscomp$inline_5183$$-$y1$jscomp$inline_5181$$)/$det$jscomp$inline_5184$$,$mb4$jscomp$inline_5195$$=($mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$-
$mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$)/$det$jscomp$inline_5184$$;$mb5$jscomp$inline_5196_y2$jscomp$inline_5183$$=($mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$*$y1$jscomp$inline_5181$$-$mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$*$mb5$jscomp$inline_5196_y2$jscomp$inline_5183$$)/$det$jscomp$inline_5184$$;var $mb6$jscomp$inline_5197$$=($y1$jscomp$inline_5181$$-$y1$jscomp$inline_5181$$)/
$det$jscomp$inline_5184$$,$mb7$jscomp$inline_5198$$=($x2$jscomp$inline_5182$$-$mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$)/$det$jscomp$inline_5184$$;$mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$=($mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$*$y1$jscomp$inline_5181$$-$x2$jscomp$inline_5182$$*$y1$jscomp$inline_5181$$)/$det$jscomp$inline_5184$$;$mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$=
$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$6$($ma0$jscomp$inline_5185_selrect$jscomp$9$$*$mb0$jscomp$inline_5191$$+$ma1$jscomp$inline_5186$$*$mb3$jscomp$inline_5194$$+$ma2$jscomp$inline_5187$$*$mb6$jscomp$inline_5197$$,$d1$jscomp$inline_5177_ma3$jscomp$inline_5188$$*$mb0$jscomp$inline_5191$$+$d2$jscomp$inline_5178_ma4$jscomp$inline_5189$$*$mb3$jscomp$inline_5194$$+$d4$jscomp$inline_5179_ma5$jscomp$inline_5190$$*$mb6$jscomp$inline_5197$$,$ma0$jscomp$inline_5185_selrect$jscomp$9$$*
$mb1$jscomp$inline_5192$$+$ma1$jscomp$inline_5186$$*$mb4$jscomp$inline_5195$$+$ma2$jscomp$inline_5187$$*$mb7$jscomp$inline_5198$$,$d1$jscomp$inline_5177_ma3$jscomp$inline_5188$$*$mb1$jscomp$inline_5192$$+$d2$jscomp$inline_5178_ma4$jscomp$inline_5189$$*$mb4$jscomp$inline_5195$$+$d4$jscomp$inline_5179_ma5$jscomp$inline_5190$$*$mb7$jscomp$inline_5198$$,$ma0$jscomp$inline_5185_selrect$jscomp$9$$*$mb2$jscomp$inline_5193$$+$ma1$jscomp$inline_5186$$*$mb5$jscomp$inline_5196_y2$jscomp$inline_5183$$+$ma2$jscomp$inline_5187$$*
$mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$,$d1$jscomp$inline_5177_ma3$jscomp$inline_5188$$*$mb2$jscomp$inline_5193$$+$d2$jscomp$inline_5178_ma4$jscomp$inline_5189$$*$mb5$jscomp$inline_5196_y2$jscomp$inline_5183$$+$d4$jscomp$inline_5179_ma5$jscomp$inline_5190$$*$mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$)}$center$jscomp$17_transform__$1$$=$mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$!=
null?$app$common$geom$matrix$multiply_BANG_$$($app$common$geom$matrix$multiply_BANG_$$($app$common$geom$matrix$translate_matrix_neg$cljs$0core$0IFn$0_invoke$0arity$01$$($center$jscomp$17_transform__$1$$),$mb8$jscomp$inline_5199_points$jscomp$31_transform$jscomp$46_x1$jscomp$inline_5180$$),$APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$17_transform__$1$$)):null;return $app$common$geom$matrix$matrix_QMARK_$$($center$jscomp$17_transform__$1$$)?$app$common$geom$matrix$unit_QMARK_$$($center$jscomp$17_transform__$1$$)?
$app$common$geom$matrix$base$$:$center$jscomp$17_transform__$1$$:null};
$app$common$geom$shapes$transforms$calculate_geometry$$=function($points$jscomp$32_transform$jscomp$47$$){var $center$jscomp$18$$=$APP.$app$common$geom$shapes$common$points__GT_center$$($points$jscomp$32_transform$jscomp$47$$),$selrect$jscomp$10$$=$app$common$geom$shapes$transforms$calculate_selrect$$($points$jscomp$32_transform$jscomp$47$$,$center$jscomp$18$$);$points$jscomp$32_transform$jscomp$47$$=$app$common$geom$shapes$transforms$calculate_transform$$($points$jscomp$32_transform$jscomp$47$$,$center$jscomp$18$$,
$selrect$jscomp$10$$);return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$selrect$jscomp$10$$,$points$jscomp$32_transform$jscomp$47$$,$points$jscomp$32_transform$jscomp$47$$!=null?$app$common$geom$matrix$inverse$$($points$jscomp$32_transform$jscomp$47$$):null],null)};
$APP.$app$common$geom$shapes$transforms$apply_transform$$=function($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,$JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$){if($JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$==null)$JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$=
$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$;else if($APP.$app$common$math$almost_zero_QMARK_$$(($JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$?.a??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$,
$APP.$cljs$cst$1519$a$$))-1)&&$APP.$app$common$math$almost_zero_QMARK_$$($JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$?.b??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$,$APP.$cljs$cst$1520$b$$))&&$APP.$app$common$math$almost_zero_QMARK_$$($JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$?.c??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$,$cljs$cst$1521$c$$))&&$APP.$app$common$math$almost_zero_QMARK_$$(($JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$?.d??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$,
$cljs$cst$1447$d$$))-1)){var $dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$=$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,$APP.$cljs$cst$139$type$$),
$points$jscomp$inline_11971_points$jscomp$inline_5209$$=$APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$?.points??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,$APP.$cljs$cst$1604$points$$),
$JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$),$selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$=$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,
$APP.$cljs$cst$1605$selrect$$),$c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$=$selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$?.x1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$,
$APP.$cljs$cst$1523$x1$$),$p0_SINGLEQUOTE_$jscomp$inline_14254_rotation$jscomp$inline_11981_y1$jscomp$inline_11961$$=$selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$?.y1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$,$APP.$cljs$cst$1524$y1$$);var $c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$=
$selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$?.x2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$,$APP.$cljs$cst$1525$x2$$);$selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$=$selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$?.y2??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$,$APP.$cljs$cst$1526$y2$$);$c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$,
$p0_SINGLEQUOTE_$jscomp$inline_14254_rotation$jscomp$inline_11981_y1$jscomp$inline_11961$$);$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$,
$selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$);$c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$=$app$common$geom$point$transform_BANG_$$($c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$,
$JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$);$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$=$app$common$geom$point$transform_BANG_$$($c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$,
$JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$);$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$=$app$common$geom$rect$corners__GT_rect$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$));$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$,
$APP.$cljs$cst$1588$text$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,$APP.$cljs$cst$1891$position_data$$,$app$common$geom$shapes$transforms$transform_position_data$$,$JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$):$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$;
$JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$,$APP.$cljs$cst$296$path$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$,$APP.$cljs$cst$1610$bool$$)?
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,$APP.$cljs$cst$1637$content$$,$app$common$types$path$transform_content$$,$JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,
$APP.$cljs$cst$1510$x$$,$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$,
$APP.$cljs$cst$1510$x$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1511$y$$,$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$,
$APP.$cljs$cst$1511$y$$),$APP.$cljs$cst$290$width$$,$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$,
$APP.$cljs$cst$290$width$$),$APP.$cljs$cst$1522$height$$,$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$,
$APP.$cljs$cst$1522$height$$)]));$JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$,$APP.$cljs$cst$1605$selrect$$,$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$),
$APP.$cljs$cst$1604$points$$,$points$jscomp$inline_11971_points$jscomp$inline_5209$$)}else $points$jscomp$inline_11971_points$jscomp$inline_5209$$=$APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$?.points??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,
$APP.$cljs$cst$1604$points$$),$JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$),$c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$=$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$?.points??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,$APP.$cljs$cst$1604$points$$),$p0_SINGLEQUOTE_$jscomp$inline_14254_rotation$jscomp$inline_11981_y1$jscomp$inline_11961$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$,
0),$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($points$jscomp$inline_11971_points$jscomp$inline_5209$$,0),$dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$=$APP.$app$common$geom$point$to_vec$$($p0_SINGLEQUOTE_$jscomp$inline_14254_rotation$jscomp$inline_11981_y1$jscomp$inline_11961$$,
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$,1)),$selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$=$APP.$app$common$geom$point$to_vec$$($c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$,
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($points$jscomp$inline_11971_points$jscomp$inline_5209$$,1)),$dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$=$APP.$app$common$geom$point$dot$$($dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$,$selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$),$c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$=
$APP.$app$common$geom$point$to_vec$$($p0_SINGLEQUOTE_$jscomp$inline_14254_rotation$jscomp$inline_11981_y1$jscomp$inline_11961$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$,3)),$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$=
$APP.$app$common$geom$point$to_vec$$($c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($points$jscomp$inline_11971_points$jscomp$inline_5209$$,3)),$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$=
$APP.$app$common$geom$point$dot$$($c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$,$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$),
$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$=$dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$<0?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,$APP.$cljs$cst$1879$flip_x$$,$APP.$cljs$core$not$$):
$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$=$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$<
0?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,$APP.$cljs$cst$1880$flip_y$$,$APP.$cljs$core$not$$):$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,$dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$=
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$<0,$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$<0)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,
$APP.$cljs$cst$1788$rotation$$,$APP.$cljs$core$_$$):$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$=$APP.$app$common$geom$shapes$common$points__GT_center$$($points$jscomp$inline_11971_points$jscomp$inline_5209$$),
$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$=$app$common$geom$shapes$transforms$calculate_selrect$$($points$jscomp$inline_11971_points$jscomp$inline_5209$$,$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$),
$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$=$app$common$geom$shapes$transforms$calculate_transform$$($points$jscomp$inline_11971_points$jscomp$inline_5209$$,$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$,
$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$),$c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$=$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$!=
null?$app$common$geom$matrix$inverse$$($c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$):null,$c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$=
$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$!=null&&$c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$!=null?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$,$c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$],
null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$2$($dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()),$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$2$($dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$,
$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$())],null),$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$,
0,null),$c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$,
1,null),$selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$=$dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$,$APP.$cljs$cst$139$type$$),$p0_SINGLEQUOTE_$jscomp$inline_14254_rotation$jscomp$inline_11981_y1$jscomp$inline_11961$$=
$APP.$cljs$core$mod$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$),0)+$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$,
$APP.$cljs$cst$1810$modifiers$$),$APP.$cljs$cst$1788$rotation$$),0),360),$JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$,$APP.$cljs$cst$296$path$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$inline_11958_type$jscomp$inline_11980_xv2$jscomp$inline_14257_y2$jscomp$inline_11963$$,
$APP.$cljs$cst$1610$bool$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$,$APP.$cljs$cst$1637$content$$,$app$common$types$path$transform_content$$,$JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($dot_x$jscomp$inline_14258_shape__$1$jscomp$inline_11972_type$jscomp$inline_5208_xv1$jscomp$inline_14256$$,
$APP.$cljs$cst$1510$x$$,$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,$APP.$cljs$cst$1510$x$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1511$y$$,$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,$APP.$cljs$cst$1511$y$$),$APP.$cljs$cst$290$width$$,$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,
$APP.$cljs$cst$290$width$$),$APP.$cljs$cst$1522$height$$,$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$,$APP.$cljs$cst$1522$height$$)])),$JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$,$APP.$cljs$cst$1289$transform$$,$c2$jscomp$inline_11967_center$jscomp$inline_11973_dot_y$jscomp$inline_14261_p0$jscomp$inline_14255_p2$jscomp$inline_11965_selrect$jscomp$inline_5210_transform$jscomp$inline_11976_transform$jscomp$inline_11978_x2$jscomp$inline_11962_yv2$jscomp$inline_14260$$),
$APP.$cljs$cst$1787$transform_inverse$$,$c1$jscomp$inline_11966_inverse$jscomp$inline_11977_inverse$jscomp$inline_11979_p1$jscomp$inline_11964_points_SINGLEQUOTE_$jscomp$inline_14253_vec__48822$jscomp$inline_11975_x1$jscomp$inline_11960_yv1$jscomp$inline_14259$$),$APP.$cljs$cst$1605$selrect$$,$G__48820__$1$jscomp$inline_14262_G__48820__$2$jscomp$inline_14263_selrect$jscomp$inline_11974_shape$jscomp$112_shape__$1$jscomp$inline_5211$$),$APP.$cljs$cst$1604$points$$,$points$jscomp$inline_11971_points$jscomp$inline_5209$$),
$APP.$cljs$cst$1788$rotation$$,$p0_SINGLEQUOTE_$jscomp$inline_14254_rotation$jscomp$inline_11981_y1$jscomp$inline_11961$$);return $JSCompiler_temp$jscomp$704_JSCompiler_temp$jscomp$801_shape__$2$jscomp$inline_11982_shape__$2$jscomp$inline_5212_transform_mtx$jscomp$2$$};
$app$common$geom$shapes$transforms$update_group_viewbox$$=function($map__48827__$1_p__48826$$,$new_selrect$$){$map__48827__$1_p__48826$$=$APP.$cljs$core$__destructure_map$$($map__48827__$1_p__48826$$);var $selrect$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48827__$1_p__48826$$,$APP.$cljs$cst$1605$selrect$$),$svg_viewbox$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48827__$1_p__48826$$,$cljs$cst$1893$svg_viewbox$$),$deltas$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$2$($new_selrect$$,0)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$13$$,0),$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$2$($new_selrect$$,0)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$13$$,0),$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$2$($new_selrect$$,1)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$13$$,
1),$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$2$($new_selrect$$,1)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$13$$,1)],null);return $svg_viewbox$$!=null&&$selrect$jscomp$13$$!=null&&$new_selrect$$!=null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($map__48827__$1_p__48826$$,$cljs$cst$1893$svg_viewbox$$,function($p1__48825_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__48825_SHARP_$$,
$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($deltas$$)),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($deltas$$)),$APP.$cljs$cst$290$width$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($deltas$$)),$APP.$cljs$cst$1522$height$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($deltas$$))}):$map__48827__$1_p__48826$$};
$APP.$app$common$geom$shapes$transforms$update_group_selrect$$=function($group$jscomp$3$$,$children$jscomp$162_new_points_shape_center$jscomp$4$$){var $base_points_new_selrect$jscomp$1_points$jscomp$36_points__$1$jscomp$2_sr_transform$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$1604$points$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$children$jscomp$162_new_points_shape_center$jscomp$4$$]));$children$jscomp$162_new_points_shape_center$jscomp$4$$=
$APP.$app$common$geom$shapes$common$points__GT_center$$($base_points_new_selrect$jscomp$1_points$jscomp$36_points__$1$jscomp$2_sr_transform$$);$base_points_new_selrect$jscomp$1_points$jscomp$36_points__$1$jscomp$2_sr_transform$$=$APP.$cljs$core$empty_QMARK_$$($base_points_new_selrect$jscomp$1_points$jscomp$36_points__$1$jscomp$2_sr_transform$$)?$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$3$$):$base_points_new_selrect$jscomp$1_points$jscomp$36_points__$1$jscomp$2_sr_transform$$;
$base_points_new_selrect$jscomp$1_points$jscomp$36_points__$1$jscomp$2_sr_transform$$=$APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$03$$($base_points_new_selrect$jscomp$1_points$jscomp$36_points__$1$jscomp$2_sr_transform$$,$children$jscomp$162_new_points_shape_center$jscomp$4$$,$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$2$($group$jscomp$3$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()));$children$jscomp$162_new_points_shape_center$jscomp$4$$=
$APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$geom$rect$rect__GT_points$$($APP.$app$common$geom$rect$points__GT_rect$$($base_points_new_selrect$jscomp$1_points$jscomp$36_points__$1$jscomp$2_sr_transform$$)),$children$jscomp$162_new_points_shape_center$jscomp$4$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$2$($group$jscomp$3$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()));$base_points_new_selrect$jscomp$1_points$jscomp$36_points__$1$jscomp$2_sr_transform$$=
$APP.$app$common$geom$matrix$transform_in$$($APP.$app$common$geom$shapes$common$points__GT_center$$($children$jscomp$162_new_points_shape_center$jscomp$4$$),$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$2$($group$jscomp$3$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()));$base_points_new_selrect$jscomp$1_points$jscomp$36_points__$1$jscomp$2_sr_transform$$=$APP.$app$common$geom$rect$points__GT_rect$$($APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$02$$($children$jscomp$162_new_points_shape_center$jscomp$4$$,
$base_points_new_selrect$jscomp$1_points$jscomp$36_points__$1$jscomp$2_sr_transform$$));return $APP.$app$common$geom$shapes$transforms$apply_transform$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$common$geom$shapes$transforms$update_group_viewbox$$($group$jscomp$3$$,$base_points_new_selrect$jscomp$1_points$jscomp$36_points__$1$jscomp$2_sr_transform$$),
$APP.$cljs$cst$1605$selrect$$,$base_points_new_selrect$jscomp$1_points$jscomp$36_points__$1$jscomp$2_sr_transform$$),$APP.$cljs$cst$1604$points$$,$children$jscomp$162_new_points_shape_center$jscomp$4$$),$APP.$cljs$cst$1879$flip_x$$,!1),$APP.$cljs$cst$1880$flip_y$$,!1),$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$())};
$APP.$app$common$geom$shapes$transforms$update_mask_selrect$$=function($masked_group$$,$children$jscomp$163_mask$jscomp$11$$){$children$jscomp$163_mask$jscomp$11$$=$APP.$cljs$core$first$$($children$jscomp$163_mask$jscomp$11$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($masked_group$$,
$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$163_mask$jscomp$11$$)),$APP.$cljs$cst$1604$points$$,$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$163_mask$jscomp$11$$)),$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$163_mask$jscomp$11$$))),$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$163_mask$jscomp$11$$))),
$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$163_mask$jscomp$11$$))),$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$163_mask$jscomp$11$$))),$APP.$cljs$cst$1879$flip_x$$,$APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$163_mask$jscomp$11$$)),
$APP.$cljs$cst$1880$flip_y$$,$APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$163_mask$jscomp$11$$))};
$app$common$geom$shapes$transforms$apply_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$=function($G__48879_objects$jscomp$108_objects__$1$jscomp$2$$,$modifiers$jscomp$33$$,$G__48880_ids$jscomp$18_ids__$1$$){for($G__48880_ids$jscomp$18_ids__$1$$=$APP.$cljs$core$seq$$($G__48880_ids$jscomp$18_ids__$1$$);;){if($APP.$cljs$core$empty_QMARK_$$($G__48880_ids$jscomp$18_ids__$1$$))return $G__48879_objects$jscomp$108_objects__$1$jscomp$2$$;var $id$jscomp$154$$=$APP.$cljs$core$first$$($G__48880_ids$jscomp$18_ids__$1$$),
$modifier$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$33$$,$id$jscomp$154$$),$APP.$cljs$cst$1810$modifiers$$);$G__48879_objects$jscomp$108_objects__$1$jscomp$2$$=$APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__48879_objects$jscomp$108_objects__$1$jscomp$2$$,$id$jscomp$154$$,$app$common$geom$shapes$transforms$transform_shape$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$modifier$jscomp$4$$]));
$G__48880_ids$jscomp$18_ids__$1$$=$APP.$cljs$core$rest$$($G__48880_ids$jscomp$18_ids__$1$$)}};$app$common$geom$shapes$transforms$transform_bounds$cljs$0core$0IFn$0_invoke$0arity$02$$=function($points$jscomp$37$$,$modifiers$jscomp$34$$){return $app$common$geom$shapes$transforms$transform_bounds$cljs$0core$0IFn$0_invoke$0arity$03$$($points$jscomp$37$$,$modifiers$jscomp$34$$)};
$app$common$geom$shapes$transforms$transform_bounds$cljs$0core$0IFn$0_invoke$0arity$03$$=function($points$jscomp$38$$,$modifiers$jscomp$35_transform$jscomp$51$$){$modifiers$jscomp$35_transform$jscomp$51$$=$app$common$types$modifiers$modifiers__GT_transform$$($modifiers$jscomp$35_transform$jscomp$51$$);return $modifiers$jscomp$35_transform$jscomp$51$$!=null?$APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$03$$($points$jscomp$38$$,null,$modifiers$jscomp$35_transform$jscomp$51$$):
$points$jscomp$38$$};
$APP.$app$common$geom$shapes$text$position_data__GT_rect$$=function($p__48854_x$jscomp$1117$$){var $height$jscomp$60_map__48855__$1$$=$APP.$cljs$core$__destructure_map$$($p__48854_x$jscomp$1117$$);$p__48854_x$jscomp$1117$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$60_map__48855__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$375$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$60_map__48855__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$67$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$60_map__48855__$1$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$60_map__48855__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$60_map__48855__$1$$,$APP.$cljs$cst$1522$height$$);return $APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($p__48854_x$jscomp$1117$$,$y$jscomp$375$$-$height$jscomp$60_map__48855__$1$$,$width$jscomp$67$$,$height$jscomp$60_map__48855__$1$$)};
$APP.$app$common$geom$shapes$text$shape__GT_rect$$=function($shape$jscomp$116$$){var $points$jscomp$39$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$rect$rect__GT_points$$,$APP.$app$common$geom$shapes$text$position_data__GT_rect$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$116$$)]));return $APP.$cljs$core$seq$$($points$jscomp$39$$)?
$APP.$app$common$geom$rect$points__GT_rect$$($points$jscomp$39$$):$shape$jscomp$116$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$116$$,$APP.$cljs$cst$1605$selrect$$)};
$APP.$app$common$geom$shapes$intersect$points__GT_lines$cljs$0core$0IFn$0_invoke$0arity$02$$=function($points$jscomp$43$$){var $JSCompiler_temp_const$jscomp$802$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$;var $G__48885$jscomp$inline_5214_JSCompiler_inline_result$jscomp$804$$=$APP.$cljs$core$rest$$($points$jscomp$43$$);$G__48885$jscomp$inline_5214_JSCompiler_inline_result$jscomp$804$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($G__48885$jscomp$inline_5214_JSCompiler_inline_result$jscomp$804$$,
new $APP.$cljs$core$List$$(null,$APP.$cljs$core$first$$($points$jscomp$43$$),null,1,null));return $JSCompiler_temp_const$jscomp$802$$.call($APP.$cljs$core$map$$,$APP.$cljs$core$vector$$,$points$jscomp$43$$,$G__48885$jscomp$inline_5214_JSCompiler_inline_result$jscomp$804$$)};
$APP.$app$common$geom$shapes$intersect$is_point_inside_evenodd_QMARK_$$=function($p$jscomp$204$$,$lines$jscomp$1$$){return $APP.$cljs$core$odd_QMARK_$$($APP.$cljs$core$count$$($APP.$cljs$core$filterv$$(function($map__48894$jscomp$inline_5225_p1__48895_SHARP__x2$jscomp$inline_5227$$){var $map__48889__$1$jscomp$inline_5218_py$jscomp$inline_5220$$=$APP.$cljs$core$__destructure_map$$($p$jscomp$204$$),$px$jscomp$inline_5219$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48889__$1$jscomp$inline_5218_py$jscomp$inline_5220$$,
$APP.$cljs$cst$1510$x$$);$map__48889__$1$jscomp$inline_5218_py$jscomp$inline_5220$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48889__$1$jscomp$inline_5218_py$jscomp$inline_5220$$,$APP.$cljs$cst$1511$y$$);var $map__48893$jscomp$inline_5221_x1$jscomp$inline_5223$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__48894$jscomp$inline_5225_p1__48895_SHARP__x2$jscomp$inline_5227$$,0,null),$map__48893__$1$jscomp$inline_5222_y1$jscomp$inline_5224$$=$APP.$cljs$core$__destructure_map$$($map__48893$jscomp$inline_5221_x1$jscomp$inline_5223$$);
$map__48893$jscomp$inline_5221_x1$jscomp$inline_5223$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48893__$1$jscomp$inline_5222_y1$jscomp$inline_5224$$,$APP.$cljs$cst$1510$x$$);$map__48893__$1$jscomp$inline_5222_y1$jscomp$inline_5224$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48893__$1$jscomp$inline_5222_y1$jscomp$inline_5224$$,$APP.$cljs$cst$1511$y$$);$map__48894$jscomp$inline_5225_p1__48895_SHARP__x2$jscomp$inline_5227$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__48894$jscomp$inline_5225_p1__48895_SHARP__x2$jscomp$inline_5227$$,
1,null);var $map__48894__$1$jscomp$inline_5226_y2$jscomp$inline_5228$$=$APP.$cljs$core$__destructure_map$$($map__48894$jscomp$inline_5225_p1__48895_SHARP__x2$jscomp$inline_5227$$);$map__48894$jscomp$inline_5225_p1__48895_SHARP__x2$jscomp$inline_5227$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48894__$1$jscomp$inline_5226_y2$jscomp$inline_5228$$,$APP.$cljs$cst$1510$x$$);$map__48894__$1$jscomp$inline_5226_y2$jscomp$inline_5228$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48894__$1$jscomp$inline_5226_y2$jscomp$inline_5228$$,
$APP.$cljs$cst$1511$y$$);return $map__48893__$1$jscomp$inline_5222_y1$jscomp$inline_5224$$<=$map__48889__$1$jscomp$inline_5218_py$jscomp$inline_5220$$&&$map__48894__$1$jscomp$inline_5226_y2$jscomp$inline_5228$$>$map__48889__$1$jscomp$inline_5218_py$jscomp$inline_5220$$||$map__48893__$1$jscomp$inline_5222_y1$jscomp$inline_5224$$>$map__48889__$1$jscomp$inline_5218_py$jscomp$inline_5220$$&&$map__48894__$1$jscomp$inline_5226_y2$jscomp$inline_5228$$<=$map__48889__$1$jscomp$inline_5218_py$jscomp$inline_5220$$?
$px$jscomp$inline_5219$$<$map__48893$jscomp$inline_5221_x1$jscomp$inline_5223$$+($map__48889__$1$jscomp$inline_5218_py$jscomp$inline_5220$$-$map__48893__$1$jscomp$inline_5222_y1$jscomp$inline_5224$$)/($map__48894__$1$jscomp$inline_5226_y2$jscomp$inline_5228$$-$map__48893__$1$jscomp$inline_5222_y1$jscomp$inline_5224$$)*($map__48894$jscomp$inline_5225_p1__48895_SHARP__x2$jscomp$inline_5227$$-$map__48893$jscomp$inline_5221_x1$jscomp$inline_5223$$):!1},$lines$jscomp$1$$)))};
$APP.$app$common$geom$shapes$intersect$has_point_QMARK_$$=function($shape$jscomp$124_y2$jscomp$inline_11993$$,$JSCompiler_temp$jscomp$10775_point$jscomp$50_py$jscomp$inline_11995$$){if($APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$124_y2$jscomp$inline_11993$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$124_y2$jscomp$inline_11993$$)||$APP.$app$common$files$helpers$circle_shape_QMARK_$$($shape$jscomp$124_y2$jscomp$inline_11993$$)){var $lines$jscomp$inline_11986_points$jscomp$inline_14265_x1$jscomp$inline_11990$$=
$shape$jscomp$124_y2$jscomp$inline_11993$$?.points??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$124_y2$jscomp$inline_11993$$,$APP.$cljs$cst$1604$points$$);$lines$jscomp$inline_11986_points$jscomp$inline_14265_x1$jscomp$inline_11990$$=$APP.$app$common$geom$shapes$intersect$points__GT_lines$cljs$0core$0IFn$0_invoke$0arity$02$$($lines$jscomp$inline_11986_points$jscomp$inline_14265_x1$jscomp$inline_11990$$);$JSCompiler_temp$jscomp$10775_point$jscomp$50_py$jscomp$inline_11995$$=
$APP.$app$common$geom$shapes$intersect$is_point_inside_evenodd_QMARK_$$($JSCompiler_temp$jscomp$10775_point$jscomp$50_py$jscomp$inline_11995$$,$lines$jscomp$inline_11986_points$jscomp$inline_14265_x1$jscomp$inline_11990$$)}else{$lines$jscomp$inline_11986_points$jscomp$inline_14265_x1$jscomp$inline_11990$$=$shape$jscomp$124_y2$jscomp$inline_11993$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$124_y2$jscomp$inline_11993$$,$APP.$cljs$cst$1510$x$$);var $y1$jscomp$inline_11991$$=
$shape$jscomp$124_y2$jscomp$inline_11993$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$124_y2$jscomp$inline_11993$$,$APP.$cljs$cst$1511$y$$),$x2$jscomp$inline_11992$$=$lines$jscomp$inline_11986_points$jscomp$inline_14265_x1$jscomp$inline_11990$$+($shape$jscomp$124_y2$jscomp$inline_11993$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$124_y2$jscomp$inline_11993$$,$APP.$cljs$cst$290$width$$));$shape$jscomp$124_y2$jscomp$inline_11993$$=$y1$jscomp$inline_11991$$+
($shape$jscomp$124_y2$jscomp$inline_11993$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$124_y2$jscomp$inline_11993$$,$APP.$cljs$cst$1522$height$$));var $px$jscomp$inline_11994$$=$JSCompiler_temp$jscomp$10775_point$jscomp$50_py$jscomp$inline_11995$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10775_point$jscomp$50_py$jscomp$inline_11995$$,$APP.$cljs$cst$1510$x$$);$JSCompiler_temp$jscomp$10775_point$jscomp$50_py$jscomp$inline_11995$$=
$JSCompiler_temp$jscomp$10775_point$jscomp$50_py$jscomp$inline_11995$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10775_point$jscomp$50_py$jscomp$inline_11995$$,$APP.$cljs$cst$1511$y$$);$JSCompiler_temp$jscomp$10775_point$jscomp$50_py$jscomp$inline_11995$$=$px$jscomp$inline_11994$$>=$lines$jscomp$inline_11986_points$jscomp$inline_14265_x1$jscomp$inline_11990$$&&$px$jscomp$inline_11994$$<=$x2$jscomp$inline_11992$$&&$JSCompiler_temp$jscomp$10775_point$jscomp$50_py$jscomp$inline_11995$$>=
$y1$jscomp$inline_11991$$&&$JSCompiler_temp$jscomp$10775_point$jscomp$50_py$jscomp$inline_11995$$<=$shape$jscomp$124_y2$jscomp$inline_11993$$}return $JSCompiler_temp$jscomp$10775_point$jscomp$50_py$jscomp$inline_11995$$};
$app$common$geom$shapes$intersect$line_line_intersect$$=function($a$jscomp$365_c1$jscomp$28$$,$b$jscomp$297_b1$jscomp$3$$,$c$jscomp$279_c2$jscomp$20$$,$b2$jscomp$1_d$jscomp$228$$){var $a1$jscomp$7$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$297_b1$jscomp$3$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$365_c1$jscomp$28$$);$b$jscomp$297_b1$jscomp$3$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$365_c1$jscomp$28$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$297_b1$jscomp$3$$);
$a$jscomp$365_c1$jscomp$28$$=$a1$jscomp$7$$*$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$365_c1$jscomp$28$$)+$b$jscomp$297_b1$jscomp$3$$*$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$365_c1$jscomp$28$$);var $a2$jscomp$3$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($b2$jscomp$1_d$jscomp$228$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$279_c2$jscomp$20$$);$b2$jscomp$1_d$jscomp$228$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$279_c2$jscomp$20$$)-
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($b2$jscomp$1_d$jscomp$228$$);$c$jscomp$279_c2$jscomp$20$$=$a2$jscomp$3$$*$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$279_c2$jscomp$20$$)+$b2$jscomp$1_d$jscomp$228$$*$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$279_c2$jscomp$20$$);var $det$jscomp$2_det__$1$$=$a1$jscomp$7$$*$b2$jscomp$1_d$jscomp$228$$-$a2$jscomp$3$$*$b$jscomp$297_b1$jscomp$3$$;$det$jscomp$2_det__$1$$=$APP.$app$common$math$almost_zero_QMARK_$$($det$jscomp$2_det__$1$$)?
.001:$det$jscomp$2_det__$1$$;return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(($b2$jscomp$1_d$jscomp$228$$*$a$jscomp$365_c1$jscomp$28$$-$b$jscomp$297_b1$jscomp$3$$*$c$jscomp$279_c2$jscomp$20$$)/$det$jscomp$2_det__$1$$,($c$jscomp$279_c2$jscomp$20$$*$a1$jscomp$7$$-$a$jscomp$365_c1$jscomp$28$$*$a2$jscomp$3$$)/$det$jscomp$2_det__$1$$)};
$APP.$app$common$geom$shapes$points$origin$$=function($points$jscomp$45$$){return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($points$jscomp$45$$,0)};
$APP.$app$common$geom$shapes$points$start_hv$$=function($p__48949$$,$val$jscomp$160$$){var $p0$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48949$$,0,null),$p1$jscomp$57$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48949$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48949$$,2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48949$$,3,null);return $APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($p1$jscomp$57$$,
$p0$jscomp$7$$)),$val$jscomp$160$$)};
$APP.$app$common$geom$shapes$points$start_vv$$=function($p3$jscomp$11_p__48957$$,$val$jscomp$162$$){var $p0$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$11_p__48957$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$11_p__48957$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$11_p__48957$$,2,null);$p3$jscomp$11_p__48957$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$11_p__48957$$,3,null);
return $APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($p3$jscomp$11_p__48957$$,$p0$jscomp$9$$)),$val$jscomp$162$$)};
$APP.$app$common$geom$shapes$points$width_points$$=function($p__48965_y__5111__auto__$jscomp$40$$){var $p0$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48965_y__5111__auto__$jscomp$40$$,0,null),$p1$jscomp$59$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48965_y__5111__auto__$jscomp$40$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48965_y__5111__auto__$jscomp$40$$,2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48965_y__5111__auto__$jscomp$40$$,
3,null);return $p0$jscomp$11$$!=null&&$p1$jscomp$59$$!=null?($p__48965_y__5111__auto__$jscomp$40$$=$APP.$app$common$geom$point$length$$($APP.$app$common$geom$point$subtract$$($p1$jscomp$59$$,$p0$jscomp$11$$)),.01>$p__48965_y__5111__auto__$jscomp$40$$?.01:$p__48965_y__5111__auto__$jscomp$40$$):null};
$APP.$app$common$geom$shapes$points$height_points$$=function($p3$jscomp$13_p__48969$$){var $p0$jscomp$12_y__5111__auto__$jscomp$41$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$13_p__48969$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$13_p__48969$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$13_p__48969$$,2,null);$p3$jscomp$13_p__48969$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$13_p__48969$$,
3,null);return $p0$jscomp$12_y__5111__auto__$jscomp$41$$!=null&&$p3$jscomp$13_p__48969$$!=null?($p0$jscomp$12_y__5111__auto__$jscomp$41$$=$APP.$app$common$geom$point$length$$($APP.$app$common$geom$point$subtract$$($p3$jscomp$13_p__48969$$,$p0$jscomp$12_y__5111__auto__$jscomp$41$$)),.01>$p0$jscomp$12_y__5111__auto__$jscomp$41$$?.01:$p0$jscomp$12_y__5111__auto__$jscomp$41$$):null};
$app$common$geom$shapes$points$pad_points$$=function($left_v_p__48973$$,$pad_top$jscomp$2_top_v$$,$pad_right$jscomp$2_right_v$$,$bottom_v_pad_bottom$jscomp$2$$,$pad_left$jscomp$2$$){var $p0$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_v_p__48973$$,0,null),$p1$jscomp$60$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_v_p__48973$$,1,null),$p2$jscomp$45$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_v_p__48973$$,2,null),$p3$jscomp$14$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_v_p__48973$$,3,null);if($left_v_p__48973$$!=null){$pad_top$jscomp$2_top_v$$=$APP.$app$common$geom$shapes$points$start_vv$$($left_v_p__48973$$,$pad_top$jscomp$2_top_v$$);var $p0$jscomp$inline_5232_p0$jscomp$inline_5237$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_v_p__48973$$,0,null),$p1$jscomp$inline_5233_p3$jscomp$inline_5238$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_v_p__48973$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_v_p__48973$$,
2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_v_p__48973$$,3,null);$pad_right$jscomp$2_right_v$$=$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($p0$jscomp$inline_5232_p0$jscomp$inline_5237$$,$p1$jscomp$inline_5233_p3$jscomp$inline_5238$$)),$pad_right$jscomp$2_right_v$$);$p0$jscomp$inline_5232_p0$jscomp$inline_5237$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_v_p__48973$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_v_p__48973$$,
1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_v_p__48973$$,2,null);$p1$jscomp$inline_5233_p3$jscomp$inline_5238$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_v_p__48973$$,3,null);$bottom_v_pad_bottom$jscomp$2$$=$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($p0$jscomp$inline_5232_p0$jscomp$inline_5237$$,$p1$jscomp$inline_5233_p3$jscomp$inline_5238$$)),$bottom_v_pad_bottom$jscomp$2$$);$left_v_p__48973$$=
$APP.$app$common$geom$shapes$points$start_hv$$($left_v_p__48973$$,$pad_left$jscomp$2$$);return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$add$$($p0$jscomp$13$$,$left_v_p__48973$$),$pad_top$jscomp$2_top_v$$),$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$add$$($p1$jscomp$60$$,$pad_right$jscomp$2_right_v$$),$pad_top$jscomp$2_top_v$$),$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$add$$($p2$jscomp$45$$,
$pad_right$jscomp$2_right_v$$),$bottom_v_pad_bottom$jscomp$2$$),$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$add$$($p3$jscomp$14$$,$left_v_p__48973$$),$bottom_v_pad_bottom$jscomp$2$$)],null)}return null};
$APP.$app$common$geom$shapes$points$project_t$$=function($point$jscomp$51_pr_point$$,$line_vec_p__48977$$,$other_axis_vec$$){var $start$jscomp$207$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($line_vec_p__48977$$,0,null),$end$jscomp$72$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($line_vec_p__48977$$,1,null);$line_vec_p__48977$$=$APP.$app$common$geom$point$subtract$$($end$jscomp$72$$,$start$jscomp$207$$);$point$jscomp$51_pr_point$$=$app$common$geom$shapes$intersect$line_line_intersect$$($point$jscomp$51_pr_point$$,
$APP.$app$common$geom$point$add$$($point$jscomp$51_pr_point$$,$other_axis_vec$$),$start$jscomp$207$$,$end$jscomp$72$$);return $APP.$app$common$math$almost_zero_QMARK_$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($line_vec_p__48977$$))?$APP.$app$common$math$almost_zero_QMARK_$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($line_vec_p__48977$$))?0:($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$51_pr_point$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($start$jscomp$207$$))/
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($line_vec_p__48977$$):($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$51_pr_point$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($start$jscomp$207$$))/$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($line_vec_p__48977$$)};
$APP.$app$common$geom$shapes$points$project_point$$=function($p3$jscomp$15_p__48981$$,$axis_other_vec$$,$point$jscomp$52$$){var $p0$jscomp$14_start$jscomp$208$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$15_p__48981$$,0,null),$end$jscomp$73_p1$jscomp$61_vec__48985$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$15_p__48981$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$15_p__48981$$,2,null);$p3$jscomp$15_p__48981$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$15_p__48981$$,
3,null);$end$jscomp$73_p1$jscomp$61_vec__48985$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis_other_vec$$,$APP.$cljs$cst$1899$h$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$subtract$$($p3$jscomp$15_p__48981$$,$p0$jscomp$14_start$jscomp$208$$),$p0$jscomp$14_start$jscomp$208$$,$end$jscomp$73_p1$jscomp$61_vec__48985$$],null):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$app$common$geom$point$subtract$$($end$jscomp$73_p1$jscomp$61_vec__48985$$,$p0$jscomp$14_start$jscomp$208$$),$p0$jscomp$14_start$jscomp$208$$,$p3$jscomp$15_p__48981$$],null);$axis_other_vec$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$73_p1$jscomp$61_vec__48985$$,0,null);$p0$jscomp$14_start$jscomp$208$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$73_p1$jscomp$61_vec__48985$$,1,null);$end$jscomp$73_p1$jscomp$61_vec__48985$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$73_p1$jscomp$61_vec__48985$$,
2,null);return $app$common$geom$shapes$intersect$line_line_intersect$$($point$jscomp$52$$,$APP.$app$common$geom$point$add$$($point$jscomp$52$$,$axis_other_vec$$),$p0$jscomp$14_start$jscomp$208$$,$end$jscomp$73_p1$jscomp$61_vec__48985$$)};
$app$common$geom$shapes$points$axis_aligned_QMARK_$$=function($and__5023__auto__$jscomp$257_p__48988$$){var $p1$jscomp$62_vv$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($and__5023__auto__$jscomp$257_p__48988$$,0,null),$hv_p2$jscomp$46$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($and__5023__auto__$jscomp$257_p__48988$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($and__5023__auto__$jscomp$257_p__48988$$,2,null);var $p4$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($and__5023__auto__$jscomp$257_p__48988$$,
3,null);return($and__5023__auto__$jscomp$257_p__48988$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($and__5023__auto__$jscomp$257_p__48988$$),4))?($hv_p2$jscomp$46$$=$APP.$app$common$geom$point$subtract$$($hv_p2$jscomp$46$$,$p1$jscomp$62_vv$$),$p1$jscomp$62_vv$$=$APP.$app$common$geom$point$subtract$$($p4$jscomp$4$$,$p1$jscomp$62_vv$$),$APP.$app$common$math$almost_zero_QMARK_$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($hv_p2$jscomp$46$$))&&$APP.$app$common$math$almost_zero_QMARK_$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p1$jscomp$62_vv$$))&&
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($hv_p2$jscomp$46$$)>0&&$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p1$jscomp$62_vv$$)>0):$and__5023__auto__$jscomp$257_p__48988$$};
$APP.$app$common$geom$shapes$points$parent_coords_bounds$$=function($child_bounds_i4_minh_start_th_min$$,$minh_end_p__48995_tv_min$$){var $i1$jscomp$2_p1$jscomp$63$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($minh_end_p__48995_tv_min$$,0,null),$i2$jscomp$2_minv_start_p2$jscomp$47_vec__48999$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($minh_end_p__48995_tv_min$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($minh_end_p__48995_tv_min$$,2,null);var $i3_minv_end_p4$jscomp$5$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($minh_end_p__48995_tv_min$$,3,null);if($APP.$cljs$core$empty_QMARK_$$($child_bounds_i4_minh_start_th_min$$))return $minh_end_p__48995_tv_min$$;if($app$common$geom$shapes$points$axis_aligned_QMARK_$$($child_bounds_i4_minh_start_th_min$$)&&$app$common$geom$shapes$points$axis_aligned_QMARK_$$($minh_end_p__48995_tv_min$$))return $child_bounds_i4_minh_start_th_min$$;var $rh$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$i1$jscomp$2_p1$jscomp$63$$,$i2$jscomp$2_minv_start_p2$jscomp$47_vec__48999$$],null),$rv$jscomp$22$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$i1$jscomp$2_p1$jscomp$63$$,$i3_minv_end_p4$jscomp$5$$],null),$hv$jscomp$1$$=$APP.$app$common$geom$point$subtract$$($i2$jscomp$2_minv_start_p2$jscomp$47_vec__48999$$,$i1$jscomp$2_p1$jscomp$63$$),$vv$jscomp$1$$=$APP.$app$common$geom$point$subtract$$($i3_minv_end_p4$jscomp$5$$,$i1$jscomp$2_p1$jscomp$63$$);
$i2$jscomp$2_minv_start_p2$jscomp$47_vec__48999$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__49002_tv_max$jscomp$1$$,$ctv_current_point$$){var $th_min$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49002_tv_max$jscomp$1$$,0,null),$th_max$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49002_tv_max$jscomp$1$$,1,null),$tv_min$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49002_tv_max$jscomp$1$$,
2,null);$p__49002_tv_max$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49002_tv_max$jscomp$1$$,3,null);var $cth$$=$APP.$app$common$geom$shapes$points$project_t$$($ctv_current_point$$,$rh$$,$vv$jscomp$1$$);$ctv_current_point$$=$APP.$app$common$geom$shapes$points$project_t$$($ctv_current_point$$,$rv$jscomp$22$$,$hv$jscomp$1$$);return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[Math.min($th_min$jscomp$1$$,$cth$$),Math.max($th_max$jscomp$1$$,
$cth$$),Math.min($tv_min$jscomp$1$$,$ctv_current_point$$),Math.max($p__49002_tv_max$jscomp$1$$,$ctv_current_point$$)],null)},new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[Infinity,-Infinity,Infinity,-Infinity],null),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48994_SHARP_$$){var $and__5023__auto__$jscomp$258$$=$APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__48994_SHARP_$$));
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$258$$)?$APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__48994_SHARP_$$)):$and__5023__auto__$jscomp$258$$},$child_bounds_i4_minh_start_th_min$$));$child_bounds_i4_minh_start_th_min$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i2$jscomp$2_minv_start_p2$jscomp$47_vec__48999$$,0,null);var $maxh_start_th_max$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i2$jscomp$2_minv_start_p2$jscomp$47_vec__48999$$,
1,null);$minh_end_p__48995_tv_min$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i2$jscomp$2_minv_start_p2$jscomp$47_vec__48999$$,2,null);var $maxv_start_tv_max$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i2$jscomp$2_minv_start_p2$jscomp$47_vec__48999$$,3,null);$i2$jscomp$2_minv_start_p2$jscomp$47_vec__48999$$=$APP.$app$common$geom$point$add$$($i1$jscomp$2_p1$jscomp$63$$,$APP.$app$common$geom$point$scale$$($vv$jscomp$1$$,$minh_end_p__48995_tv_min$$));$i3_minv_end_p4$jscomp$5$$=
$APP.$app$common$geom$point$add$$($i2$jscomp$2_minv_start_p2$jscomp$47_vec__48999$$,$hv$jscomp$1$$);$child_bounds_i4_minh_start_th_min$$=$APP.$app$common$geom$point$add$$($i1$jscomp$2_p1$jscomp$63$$,$APP.$app$common$geom$point$scale$$($hv$jscomp$1$$,$child_bounds_i4_minh_start_th_min$$));$minh_end_p__48995_tv_min$$=$APP.$app$common$geom$point$add$$($child_bounds_i4_minh_start_th_min$$,$vv$jscomp$1$$);$maxv_start_tv_max$$=$APP.$app$common$geom$point$add$$($i1$jscomp$2_p1$jscomp$63$$,$APP.$app$common$geom$point$scale$$($vv$jscomp$1$$,
$maxv_start_tv_max$$));var $maxv_end$$=$APP.$app$common$geom$point$add$$($maxv_start_tv_max$$,$hv$jscomp$1$$);$maxh_start_th_max$$=$APP.$app$common$geom$point$add$$($i1$jscomp$2_p1$jscomp$63$$,$APP.$app$common$geom$point$scale$$($hv$jscomp$1$$,$maxh_start_th_max$$));var $maxh_end$$=$APP.$app$common$geom$point$add$$($maxh_start_th_max$$,$vv$jscomp$1$$);$i1$jscomp$2_p1$jscomp$63$$=$app$common$geom$shapes$intersect$line_line_intersect$$($i2$jscomp$2_minv_start_p2$jscomp$47_vec__48999$$,$i3_minv_end_p4$jscomp$5$$,
$child_bounds_i4_minh_start_th_min$$,$minh_end_p__48995_tv_min$$);$i2$jscomp$2_minv_start_p2$jscomp$47_vec__48999$$=$app$common$geom$shapes$intersect$line_line_intersect$$($i2$jscomp$2_minv_start_p2$jscomp$47_vec__48999$$,$i3_minv_end_p4$jscomp$5$$,$maxh_start_th_max$$,$maxh_end$$);$i3_minv_end_p4$jscomp$5$$=$app$common$geom$shapes$intersect$line_line_intersect$$($maxv_start_tv_max$$,$maxv_end$$,$maxh_start_th_max$$,$maxh_end$$);$child_bounds_i4_minh_start_th_min$$=$app$common$geom$shapes$intersect$line_line_intersect$$($maxv_start_tv_max$$,
$maxv_end$$,$child_bounds_i4_minh_start_th_min$$,$minh_end_p__48995_tv_min$$);return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$i1$jscomp$2_p1$jscomp$63$$,$i2$jscomp$2_minv_start_p2$jscomp$47_vec__48999$$,$i3_minv_end_p4$jscomp$5$$,$child_bounds_i4_minh_start_th_min$$],null)};
$app$common$geom$shapes$points$merge_parent_coords_bounds$$=function($bounds$jscomp$3$$,$parent_bounds$jscomp$1$$){return $APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$core$flatten$$($bounds$jscomp$3$$),$parent_bounds$jscomp$1$$)};
$app$common$geom$shapes$points$center$$=function($bounds$jscomp$5$$){var $half_h_width$jscomp$69$$=$APP.$app$common$geom$shapes$points$width_points$$($bounds$jscomp$5$$),$half_v_height$jscomp$62$$=$APP.$app$common$geom$shapes$points$height_points$$($bounds$jscomp$5$$);$half_h_width$jscomp$69$$=$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$5$$,$half_h_width$jscomp$69$$/2);$half_v_height$jscomp$62$$=$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$5$$,$half_v_height$jscomp$62$$/
2);return $APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$add$$($APP.$app$common$geom$shapes$points$origin$$($bounds$jscomp$5$$),$half_h_width$jscomp$69$$),$half_v_height$jscomp$62$$)};
$app$common$geom$shapes$constraints$right_vector$$=function($child_points_dir_v$$,$c1$jscomp$29_parent_points$$){var $p0$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1$jscomp$29_parent_points$$,0,null),$cp$jscomp$2_p1$jscomp$64$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1$jscomp$29_parent_points$$,1,null),$p2$jscomp$48$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1$jscomp$29_parent_points$$,2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1$jscomp$29_parent_points$$,
3,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points_dir_v$$,0,null);$c1$jscomp$29_parent_points$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points_dir_v$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points_dir_v$$,2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points_dir_v$$,3,null);$child_points_dir_v$$=$APP.$app$common$geom$point$subtract$$($cp$jscomp$2_p1$jscomp$64$$,$p0$jscomp$15$$);$cp$jscomp$2_p1$jscomp$64$$=
$app$common$geom$shapes$intersect$line_line_intersect$$($c1$jscomp$29_parent_points$$,$APP.$app$common$geom$point$add$$($c1$jscomp$29_parent_points$$,$child_points_dir_v$$),$cp$jscomp$2_p1$jscomp$64$$,$p2$jscomp$48$$);return $APP.$app$common$geom$point$subtract$$($cp$jscomp$2_p1$jscomp$64$$,$c1$jscomp$29_parent_points$$)};
$app$common$geom$shapes$constraints$left_vector$$=function($c3$jscomp$8_child_points$jscomp$1$$,$p3$jscomp$16_parent_points$jscomp$1$$){var $cp$jscomp$3_p0$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$16_parent_points$jscomp$1$$,0,null),$dir_v$jscomp$1_p1$jscomp$65$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$16_parent_points$jscomp$1$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$16_parent_points$jscomp$1$$,
2,null);$p3$jscomp$16_parent_points$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$16_parent_points$jscomp$1$$,3,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$8_child_points$jscomp$1$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$8_child_points$jscomp$1$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$8_child_points$jscomp$1$$,2,null);$c3$jscomp$8_child_points$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$8_child_points$jscomp$1$$,
3,null);$dir_v$jscomp$1_p1$jscomp$65$$=$APP.$app$common$geom$point$subtract$$($dir_v$jscomp$1_p1$jscomp$65$$,$cp$jscomp$3_p0$jscomp$16$$);$cp$jscomp$3_p0$jscomp$16$$=$app$common$geom$shapes$intersect$line_line_intersect$$($c3$jscomp$8_child_points$jscomp$1$$,$APP.$app$common$geom$point$add$$($c3$jscomp$8_child_points$jscomp$1$$,$dir_v$jscomp$1_p1$jscomp$65$$),$cp$jscomp$3_p0$jscomp$16$$,$p3$jscomp$16_parent_points$jscomp$1$$);return $APP.$app$common$geom$point$subtract$$($cp$jscomp$3_p0$jscomp$16$$,
$c3$jscomp$8_child_points$jscomp$1$$)};
$app$common$geom$shapes$constraints$top_vector$$=function($child_points$jscomp$2_dir_v$jscomp$2$$,$c0$jscomp$5_parent_points$jscomp$2$$){var $cp$jscomp$4_p0$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c0$jscomp$5_parent_points$jscomp$2$$,0,null),$p1$jscomp$66$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c0$jscomp$5_parent_points$jscomp$2$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c0$jscomp$5_parent_points$jscomp$2$$,2,null);var $p3$jscomp$17$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c0$jscomp$5_parent_points$jscomp$2$$,3,null);$c0$jscomp$5_parent_points$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$2_dir_v$jscomp$2$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$2_dir_v$jscomp$2$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$2_dir_v$jscomp$2$$,2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$2_dir_v$jscomp$2$$,
3,null);$child_points$jscomp$2_dir_v$jscomp$2$$=$APP.$app$common$geom$point$subtract$$($p3$jscomp$17$$,$cp$jscomp$4_p0$jscomp$17$$);$cp$jscomp$4_p0$jscomp$17$$=$app$common$geom$shapes$intersect$line_line_intersect$$($c0$jscomp$5_parent_points$jscomp$2$$,$APP.$app$common$geom$point$add$$($c0$jscomp$5_parent_points$jscomp$2$$,$child_points$jscomp$2_dir_v$jscomp$2$$),$cp$jscomp$4_p0$jscomp$17$$,$p1$jscomp$66$$);return $APP.$app$common$geom$point$subtract$$($cp$jscomp$4_p0$jscomp$17$$,$c0$jscomp$5_parent_points$jscomp$2$$)};
$app$common$geom$shapes$constraints$bottom_vector$$=function($child_points$jscomp$3_dir_v$jscomp$3$$,$c2$jscomp$21_parent_points$jscomp$3$$){var $p0$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c2$jscomp$21_parent_points$jscomp$3$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c2$jscomp$21_parent_points$jscomp$3$$,1,null);var $cp$jscomp$5_p2$jscomp$49$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c2$jscomp$21_parent_points$jscomp$3$$,2,null),
$p3$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c2$jscomp$21_parent_points$jscomp$3$$,3,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$3_dir_v$jscomp$3$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$3_dir_v$jscomp$3$$,1,null);$c2$jscomp$21_parent_points$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$3_dir_v$jscomp$3$$,2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$3_dir_v$jscomp$3$$,
3,null);$child_points$jscomp$3_dir_v$jscomp$3$$=$APP.$app$common$geom$point$subtract$$($p3$jscomp$18$$,$p0$jscomp$18$$);$cp$jscomp$5_p2$jscomp$49$$=$app$common$geom$shapes$intersect$line_line_intersect$$($c2$jscomp$21_parent_points$jscomp$3$$,$APP.$app$common$geom$point$add$$($c2$jscomp$21_parent_points$jscomp$3$$,$child_points$jscomp$3_dir_v$jscomp$3$$),$cp$jscomp$5_p2$jscomp$49$$,$p3$jscomp$18$$);return $APP.$app$common$geom$point$subtract$$($cp$jscomp$5_p2$jscomp$49$$,$c2$jscomp$21_parent_points$jscomp$3$$)};
$app$common$geom$shapes$constraints$center_horizontal_vector$$=function($child_points$jscomp$4_dir_v$jscomp$4$$,$c1$jscomp$30_parent_points$jscomp$4$$){var $cp$jscomp$6_p0$jscomp$19_p1c$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1$jscomp$30_parent_points$jscomp$4$$,0,null),$p1$jscomp$67$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1$jscomp$30_parent_points$jscomp$4$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1$jscomp$30_parent_points$jscomp$4$$,
2,null);var $p2c_p3$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1$jscomp$30_parent_points$jscomp$4$$,3,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$4_dir_v$jscomp$4$$,0,null);$c1$jscomp$30_parent_points$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$4_dir_v$jscomp$4$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$4_dir_v$jscomp$4$$,2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$4_dir_v$jscomp$4$$,
3,null);$child_points$jscomp$4_dir_v$jscomp$4$$=$APP.$app$common$geom$point$subtract$$($p1$jscomp$67$$,$cp$jscomp$6_p0$jscomp$19_p1c$$);$cp$jscomp$6_p0$jscomp$19_p1c$$=$APP.$app$common$geom$point$add$$($cp$jscomp$6_p0$jscomp$19_p1c$$,$APP.$app$common$geom$point$scale$$($child_points$jscomp$4_dir_v$jscomp$4$$,.5));$p2c_p3$jscomp$19$$=$APP.$app$common$geom$point$add$$($p2c_p3$jscomp$19$$,$APP.$app$common$geom$point$scale$$($child_points$jscomp$4_dir_v$jscomp$4$$,.5));$cp$jscomp$6_p0$jscomp$19_p1c$$=
$app$common$geom$shapes$intersect$line_line_intersect$$($c1$jscomp$30_parent_points$jscomp$4$$,$APP.$app$common$geom$point$add$$($c1$jscomp$30_parent_points$jscomp$4$$,$child_points$jscomp$4_dir_v$jscomp$4$$),$cp$jscomp$6_p0$jscomp$19_p1c$$,$p2c_p3$jscomp$19$$);return $APP.$app$common$geom$point$subtract$$($cp$jscomp$6_p0$jscomp$19_p1c$$,$c1$jscomp$30_parent_points$jscomp$4$$)};
$app$common$geom$shapes$constraints$center_vertical_vector$$=function($child_points$jscomp$5_dir_v$jscomp$5$$,$c1$jscomp$31_parent_points$jscomp$5$$){var $p0$jscomp$20_p3c$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1$jscomp$31_parent_points$jscomp$5$$,0,null),$cp$jscomp$7_p1$jscomp$68_p2c$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1$jscomp$31_parent_points$jscomp$5$$,1,null),$p2$jscomp$50$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1$jscomp$31_parent_points$jscomp$5$$,
2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1$jscomp$31_parent_points$jscomp$5$$,3,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$5_dir_v$jscomp$5$$,0,null);$c1$jscomp$31_parent_points$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$5_dir_v$jscomp$5$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$5_dir_v$jscomp$5$$,2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points$jscomp$5_dir_v$jscomp$5$$,
3,null);$child_points$jscomp$5_dir_v$jscomp$5$$=$APP.$app$common$geom$point$subtract$$($p2$jscomp$50$$,$cp$jscomp$7_p1$jscomp$68_p2c$jscomp$1$$);$p0$jscomp$20_p3c$$=$APP.$app$common$geom$point$add$$($p0$jscomp$20_p3c$$,$APP.$app$common$geom$point$scale$$($child_points$jscomp$5_dir_v$jscomp$5$$,.5));$cp$jscomp$7_p1$jscomp$68_p2c$jscomp$1$$=$APP.$app$common$geom$point$add$$($cp$jscomp$7_p1$jscomp$68_p2c$jscomp$1$$,$APP.$app$common$geom$point$scale$$($child_points$jscomp$5_dir_v$jscomp$5$$,.5));$cp$jscomp$7_p1$jscomp$68_p2c$jscomp$1$$=
$app$common$geom$shapes$intersect$line_line_intersect$$($c1$jscomp$31_parent_points$jscomp$5$$,$APP.$app$common$geom$point$add$$($c1$jscomp$31_parent_points$jscomp$5$$,$child_points$jscomp$5_dir_v$jscomp$5$$),$p0$jscomp$20_p3c$$,$cp$jscomp$7_p1$jscomp$68_p2c$jscomp$1$$);return $APP.$app$common$geom$point$subtract$$($cp$jscomp$7_p1$jscomp$68_p2c$jscomp$1$$,$c1$jscomp$31_parent_points$jscomp$5$$)};
$app$common$geom$shapes$constraints$start_vector$$=function($axis$jscomp$11_pos_vector$$,$child_points$jscomp$6$$,$parent_points$jscomp$6$$){$axis$jscomp$11_pos_vector$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$axis$jscomp$11_pos_vector$$)?$app$common$geom$shapes$constraints$left_vector$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1511$y$$,$axis$jscomp$11_pos_vector$$)?$app$common$geom$shapes$constraints$top_vector$$:null;return $axis$jscomp$11_pos_vector$$.$cljs$core$IFn$_invoke$arity$2$?
$axis$jscomp$11_pos_vector$$.$cljs$core$IFn$_invoke$arity$2$($child_points$jscomp$6$$,$parent_points$jscomp$6$$):$axis$jscomp$11_pos_vector$$($child_points$jscomp$6$$,$parent_points$jscomp$6$$)};
$app$common$geom$shapes$constraints$end_vector$$=function($axis$jscomp$12_pos_vector$jscomp$1$$,$child_points$jscomp$7$$,$parent_points$jscomp$7$$){$axis$jscomp$12_pos_vector$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$axis$jscomp$12_pos_vector$jscomp$1$$)?$app$common$geom$shapes$constraints$right_vector$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1511$y$$,$axis$jscomp$12_pos_vector$jscomp$1$$)?$app$common$geom$shapes$constraints$bottom_vector$$:
null;return $axis$jscomp$12_pos_vector$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$axis$jscomp$12_pos_vector$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($child_points$jscomp$7$$,$parent_points$jscomp$7$$):$axis$jscomp$12_pos_vector$jscomp$1$$($child_points$jscomp$7$$,$parent_points$jscomp$7$$)};
$app$common$geom$shapes$constraints$center_vector$$=function($axis$jscomp$13_fexpr__49077$$,$child_points$jscomp$8$$,$parent_points$jscomp$8$$){$axis$jscomp$13_fexpr__49077$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$axis$jscomp$13_fexpr__49077$$)?$app$common$geom$shapes$constraints$center_horizontal_vector$$:$app$common$geom$shapes$constraints$center_vertical_vector$$;return $axis$jscomp$13_fexpr__49077$$.$cljs$core$IFn$_invoke$arity$2$?$axis$jscomp$13_fexpr__49077$$.$cljs$core$IFn$_invoke$arity$2$($child_points$jscomp$8$$,
$parent_points$jscomp$8$$):$axis$jscomp$13_fexpr__49077$$($child_points$jscomp$8$$,$parent_points$jscomp$8$$)};
$app$common$geom$shapes$constraints$displacement$$=function($before_v_length$jscomp$38$$,$after_v$$,$before_angl_before_parent_side_v$$,$after_angl_after_parent_side_v$$){$before_angl_before_parent_side_v$$=$APP.$app$common$geom$point$angle_with_other$$($before_v_length$jscomp$38$$,$before_angl_before_parent_side_v$$);$after_angl_after_parent_side_v$$=$APP.$app$common$geom$point$angle_with_other$$($after_v$$,$after_angl_after_parent_side_v$$);$before_v_length$jscomp$38$$=($APP.$cljs$core$truth_$$($APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($before_angl_before_parent_side_v$$,
$after_angl_after_parent_side_v$$))?1:-1)*$APP.$app$common$geom$point$length$$($before_v_length$jscomp$38$$);return $APP.$app$common$math$almost_zero_QMARK_$$($before_v_length$jscomp$38$$)?$after_v$$:$APP.$app$common$geom$point$subtract$$($after_v$$,$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$unit$$($after_v$$),$before_v_length$jscomp$38$$))};
$app$common$geom$shapes$constraints$side_vector$$=function($axis$jscomp$14$$,$c3$jscomp$9_p__49080$$){var $c0$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$9_p__49080$$,0,null),$c1$jscomp$32$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$9_p__49080$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$9_p__49080$$,2,null);$c3$jscomp$9_p__49080$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c3$jscomp$9_p__49080$$,
3,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$14$$,$APP.$cljs$cst$1510$x$$)?$APP.$app$common$geom$point$subtract$$($c1$jscomp$32$$,$c0$jscomp$6$$):$APP.$app$common$geom$point$subtract$$($c3$jscomp$9_p__49080$$,$c0$jscomp$6$$)};
$APP.$app$common$geom$shapes$constraints$default_constraints_h$$=function($shape$jscomp$126$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$126$$),$APP.$app$common$uuid$zero$$)?null:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$126$$),$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$126$$))?
$APP.$cljs$cst$257$left$$:$APP.$cljs$cst$1902$scale$$};
$APP.$app$common$geom$shapes$constraints$default_constraints_v$$=function($shape$jscomp$127$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$127$$),$APP.$app$common$uuid$zero$$)?null:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$127$$),$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$127$$))?$APP.$cljs$cst$1562$top$$:
$APP.$cljs$cst$1902$scale$$};
$app$common$geom$shapes$constraints$normalize_modifiers$$=function($constraints_h_resize_origin$jscomp$1_scale_x$$,$constraints_v_resize_vector$jscomp$1_scale_y$$,$modifiers$jscomp$39$$,$child_bb_before_child_bounds$jscomp$1$$,$center$jscomp$27_transform$jscomp$55_transformed_child_bounds$$,$parent_bounds$jscomp$2$$,$selrect$jscomp$17_transform_inverse$jscomp$11_transformed_parent_bounds$$){$child_bb_before_child_bounds$jscomp$1$$=$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($child_bb_before_child_bounds$jscomp$1$$,$parent_bounds$jscomp$2$$);
var $child_bb_after$$=$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($center$jscomp$27_transform$jscomp$55_transformed_child_bounds$$,$selrect$jscomp$17_transform_inverse$jscomp$11_transformed_parent_bounds$$);$constraints_h_resize_origin$jscomp$1_scale_x$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1902$scale$$,$constraints_h_resize_origin$jscomp$1_scale_x$$)?1:$APP.$app$common$geom$shapes$points$width_points$$($child_bb_before_child_bounds$jscomp$1$$)/function(){var $y__5111__auto__$jscomp$42$$=
$APP.$app$common$geom$shapes$points$width_points$$($child_bb_after$$);return.01>$y__5111__auto__$jscomp$42$$?.01:$y__5111__auto__$jscomp$42$$}();$constraints_v_resize_vector$jscomp$1_scale_y$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1902$scale$$,$constraints_v_resize_vector$jscomp$1_scale_y$$)?1:$APP.$app$common$geom$shapes$points$height_points$$($child_bb_before_child_bounds$jscomp$1$$)/function(){var $y__5111__auto__$jscomp$43$$=$APP.$app$common$geom$shapes$points$height_points$$($child_bb_after$$);
return.01>$y__5111__auto__$jscomp$43$$?.01:$y__5111__auto__$jscomp$43$$}();$constraints_v_resize_vector$jscomp$1_scale_y$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h_resize_origin$jscomp$1_scale_x$$,$constraints_v_resize_vector$jscomp$1_scale_y$$);$constraints_h_resize_origin$jscomp$1_scale_x$$=$APP.$app$common$geom$shapes$points$origin$$($child_bb_after$$);$center$jscomp$27_transform$jscomp$55_transformed_child_bounds$$=$APP.$app$common$geom$shapes$common$points__GT_center$$($child_bb_after$$);
$selrect$jscomp$17_transform_inverse$jscomp$11_transformed_parent_bounds$$=$app$common$geom$shapes$transforms$calculate_selrect$$($child_bb_after$$,$center$jscomp$27_transform$jscomp$55_transformed_child_bounds$$);$center$jscomp$27_transform$jscomp$55_transformed_child_bounds$$=$app$common$geom$shapes$transforms$calculate_transform$$($child_bb_after$$,$center$jscomp$27_transform$jscomp$55_transformed_child_bounds$$,$selrect$jscomp$17_transform_inverse$jscomp$11_transformed_parent_bounds$$);$selrect$jscomp$17_transform_inverse$jscomp$11_transformed_parent_bounds$$=
$center$jscomp$27_transform$jscomp$55_transformed_child_bounds$$!=null?$app$common$geom$matrix$inverse$$($center$jscomp$27_transform$jscomp$55_transformed_child_bounds$$):null;return $APP.$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$05$$($modifiers$jscomp$39$$,$constraints_v_resize_vector$jscomp$1_scale_y$$,$constraints_h_resize_origin$jscomp$1_scale_x$$,$center$jscomp$27_transform$jscomp$55_transformed_child_bounds$$,$selrect$jscomp$17_transform_inverse$jscomp$11_transformed_parent_bounds$$)};
$app$common$geom$shapes$bounds$shape_stroke_margin$$=function($shape$jscomp$128$$,$stroke_width$$){return $APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$128$$)?$stroke_width$$+Math.sqrt(2*$stroke_width$$*$stroke_width$$):Math.sqrt(2*$stroke_width$$*$stroke_width$$)};
$app$common$geom$shapes$bounds$apply_filters$$=function($attr$jscomp$13$$,$type$jscomp$341$$,$filters$$){return $APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1620$hidden$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__48707_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$13$$.$cljs$core$IFn$_invoke$arity$1$?
$attr$jscomp$13$$.$cljs$core$IFn$_invoke$arity$1$($p1__48707_SHARP_$$):$attr$jscomp$13$$($p1__48707_SHARP_$$),$type$jscomp$341$$)}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($item$jscomp$44$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,"filter_"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$44$$)??""),$APP.$cljs$cst$139$type$$,$type$jscomp$341$$,$APP.$cljs$cst$1430$params$$,$item$jscomp$44$$],null)})),$filters$$)};
$app$common$geom$shapes$bounds$shape__GT_filters$$=function($shape$jscomp$129$$){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,"BackgroundImageFix",$APP.$cljs$cst$139$type$$,$cljs$cst$1903$image_fix$$],null)],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$geom$shapes$bounds$apply_filters$$($APP.$cljs$cst$1904$style$$,
$APP.$cljs$cst$1905$drop_shadow$$,$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$129$$)),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,"shape",$APP.$cljs$cst$139$type$$,$cljs$cst$1906$blend_filters$$],null)],null),$app$common$geom$shapes$bounds$apply_filters$$($APP.$cljs$cst$1904$style$$,$cljs$cst$1907$inner_shadow$$,$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$129$$)),
$app$common$geom$shapes$bounds$apply_filters$$($APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1908$layer_blur$$,new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$129$$),null,1,null))]))};
$app$common$geom$shapes$bounds$calculate_filter_bounds$$=function($h$jscomp$150_selrect$jscomp$18$$,$filter_entry_map__48709_offset_x$$){var $x$jscomp$1120$$=$h$jscomp$150_selrect$jscomp$18$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$150_selrect$jscomp$18$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$378$$=$h$jscomp$150_selrect$jscomp$18$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$150_selrect$jscomp$18$$,$APP.$cljs$cst$1511$y$$),$w$jscomp$29$$=$h$jscomp$150_selrect$jscomp$18$$?.width??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$150_selrect$jscomp$18$$,$APP.$cljs$cst$290$width$$);$h$jscomp$150_selrect$jscomp$18$$=$h$jscomp$150_selrect$jscomp$18$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$150_selrect$jscomp$18$$,$APP.$cljs$cst$1522$height$$);$filter_entry_map__48709_offset_x$$=$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($filter_entry_map__48709_offset_x$$);var $map__48709__$1_spread$$=$APP.$cljs$core$__destructure_map$$($filter_entry_map__48709_offset_x$$);
$filter_entry_map__48709_offset_x$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__48709__$1_spread$$,$APP.$cljs$cst$1650$offset_x$$,0);var $offset_y$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__48709__$1_spread$$,$APP.$cljs$cst$1651$offset_y$$,0),$blur$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__48709__$1_spread$$,$APP.$cljs$cst$1653$blur$$,0);$map__48709__$1_spread$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__48709__$1_spread$$,$APP.$cljs$cst$1652$spread$$,
0);return $APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$(Math.min($x$jscomp$1120$$,$x$jscomp$1120$$+$filter_entry_map__48709_offset_x$$+-$map__48709__$1_spread$$+-$blur$$+-5),Math.min($y$jscomp$378$$,$y$jscomp$378$$+$offset_y$$+-$map__48709__$1_spread$$+-$blur$$+-5),$w$jscomp$29$$+$APP.$app$common$math$abs$$($filter_entry_map__48709_offset_x$$)+$map__48709__$1_spread$$*2+$blur$$*2+10,$h$jscomp$150_selrect$jscomp$18$$+$APP.$app$common$math$abs$$($offset_y$$)+$map__48709__$1_spread$$*
2+$blur$$*2+10)};$app$common$geom$shapes$bounds$get_rect_filter_bounds$cljs$0core$0IFn$0_invoke$0arity$03$$=function($selrect$jscomp$19$$,$filters$jscomp$1$$,$blur_value$$){return $app$common$geom$shapes$bounds$get_rect_filter_bounds$cljs$0core$0IFn$0_invoke$0arity$04$$($selrect$jscomp$19$$,$filters$jscomp$1$$,$blur_value$$,!1)};
$app$common$geom$shapes$bounds$get_rect_filter_bounds$cljs$0core$0IFn$0_invoke$0arity$04$$=function($selrect$jscomp$20$$,$filters$jscomp$2$$,$blur_value$jscomp$1_delta_blur$$,$ignore_shadow_margin_QMARK_$$){var $bounds_xf$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__48714_SHARP_$$){return $APP.$cljs$core$not$$($ignore_shadow_margin_QMARK_$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1905$drop_shadow$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__48714_SHARP_$$))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$geom$shapes$bounds$calculate_filter_bounds$$,$selrect$jscomp$20$$)));$blur_value$jscomp$1_delta_blur$$*=2;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$common$geom$rect$join_rects$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$selrect$jscomp$20$$],null),$bounds_xf$$,$filters$jscomp$2$$)),$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$_$$,$blur_value$jscomp$1_delta_blur$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_$$,$blur_value$jscomp$1_delta_blur$$),$APP.$cljs$cst$1523$x1$$,$APP.$cljs$core$_$$,$blur_value$jscomp$1_delta_blur$$),$APP.$cljs$cst$1524$y1$$,$APP.$cljs$core$_$$,$blur_value$jscomp$1_delta_blur$$),$APP.$cljs$cst$1525$x2$$,$APP.$cljs$core$_PLUS_$$,$blur_value$jscomp$1_delta_blur$$),
$APP.$cljs$cst$1526$y2$$,$APP.$cljs$core$_PLUS_$$,$blur_value$jscomp$1_delta_blur$$),$APP.$cljs$cst$290$width$$,$APP.$cljs$core$_PLUS_$$,$blur_value$jscomp$1_delta_blur$$*2),$APP.$cljs$cst$1522$height$$,$APP.$cljs$core$_PLUS_$$,$blur_value$jscomp$1_delta_blur$$*2)};
$app$common$geom$shapes$bounds$get_shape_filter_bounds$cljs$0core$0IFn$0_invoke$0arity$02$$=function($shape$jscomp$131$$,$ignore_shadow_margin_QMARK_$jscomp$1$$){if($APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$131$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1538$svg$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$131$$,$APP.$cljs$cst$1637$content$$),
$APP.$cljs$cst$78$tag$$))||$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$131$$))&&($APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$131$$)==null||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1908$layer_blur$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$131$$)))||function(){var $or__5025__auto____$3$jscomp$5$$=
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$131$$));return $APP.$cljs$core$truth_$$($or__5025__auto____$3$jscomp$5$$)?$or__5025__auto____$3$jscomp$5$$:0}()===0))return $shape$jscomp$131$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$131$$,$APP.$cljs$cst$1605$selrect$$);var $filters$jscomp$3$$=$app$common$geom$shapes$bounds$shape__GT_filters$$($shape$jscomp$131$$),$blur_value$jscomp$2$$=
function(){var $G__48735_or__5025__auto__$jscomp$365$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$131$$));switch($G__48735_or__5025__auto__$jscomp$365$$ instanceof $APP.$cljs$core$Keyword$$?$G__48735_or__5025__auto__$jscomp$365$$.$fqn$:null){case "layer-blur":return $G__48735_or__5025__auto__$jscomp$365$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$131$$)),
$APP.$cljs$core$truth_$$($G__48735_or__5025__auto__$jscomp$365$$)?$G__48735_or__5025__auto__$jscomp$365$$:0;case "background-blur":return 0;default:return 0}}(),$srect$$=$APP.$app$common$geom$rect$points__GT_rect$$($shape$jscomp$131$$?.points??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$131$$,$APP.$cljs$cst$1604$points$$));return $app$common$geom$shapes$bounds$get_rect_filter_bounds$cljs$0core$0IFn$0_invoke$0arity$04$$($srect$$,$filters$jscomp$3$$,$blur_value$jscomp$2$$,$ignore_shadow_margin_QMARK_$jscomp$1$$)};
$app$common$geom$shapes$bounds$calculate_padding$cljs$0core$0IFn$0_invoke$0arity$03$$=function($shadow_height_shape$jscomp$133$$,$ignore_margin_QMARK__stroke_margin$$,$ignore_shadow_margin_QMARK_$jscomp$2$$){var $shadow_width_stroke_width$jscomp$1_strokes$jscomp$1$$=$APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shadow_height_shape$jscomp$133$$),$open_path_QMARK_$$=$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shadow_height_shape$jscomp$133$$)&&
$APP.$app$common$types$path$shape_with_open_path_QMARK_$$($shadow_height_shape$jscomp$133$$);$shadow_width_stroke_width$jscomp$1_strokes$jscomp$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$data$max$$,0,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48736_SHARP_$$){var $G__48741$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($p1__48736_SHARP_$$,$APP.$cljs$cst$1868$stroke_alignment$$,$APP.$cljs$cst$1667$center$$);switch($G__48741$$ instanceof
$APP.$cljs$core$Keyword$$?$G__48741$$.$fqn$:null){case "center":return $APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$2$($p1__48736_SHARP_$$,0)/2;case "outer":return $APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$2$($p1__48736_SHARP_$$,0);default:return $open_path_QMARK_$$?$APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$2$($p1__48736_SHARP_$$,0):0}},$shadow_width_stroke_width$jscomp$1_strokes$jscomp$1$$));$ignore_margin_QMARK__stroke_margin$$=$APP.$cljs$core$truth_$$($ignore_margin_QMARK__stroke_margin$$)?
0:$app$common$geom$shapes$bounds$shape_stroke_margin$$($shadow_height_shape$jscomp$133$$,$shadow_width_stroke_width$jscomp$1_strokes$jscomp$1$$);$shadow_width_stroke_width$jscomp$1_strokes$jscomp$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$data$max$$,0,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48737_SHARP_$$){var $G__48742$$=$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$2$($p1__48737_SHARP_$$,$APP.$cljs$cst$1905$drop_shadow$$);
switch($G__48742$$ instanceof $APP.$cljs$core$Keyword$$?$G__48742$$.$fqn$:null){case "drop-shadow":return $APP.$app$common$math$abs$$($APP.$cljs$cst$1650$offset_x$$.$cljs$core$IFn$_invoke$arity$1$($p1__48737_SHARP_$$))+$APP.$cljs$cst$1652$spread$$.$cljs$core$IFn$_invoke$arity$1$($p1__48737_SHARP_$$)*2+$APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($p1__48737_SHARP_$$)*2+10;default:return 0}},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shadow_height_shape$jscomp$133$$))));
$shadow_height_shape$jscomp$133$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$data$max$$,0,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48738_SHARP_$$){var $G__48744$$=$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$2$($p1__48738_SHARP_$$,$APP.$cljs$cst$1905$drop_shadow$$);switch($G__48744$$ instanceof $APP.$cljs$core$Keyword$$?$G__48744$$.$fqn$:null){case "drop-shadow":return $APP.$app$common$math$abs$$($APP.$cljs$cst$1651$offset_y$$.$cljs$core$IFn$_invoke$arity$1$($p1__48738_SHARP_$$))+
$APP.$cljs$cst$1652$spread$$.$cljs$core$IFn$_invoke$arity$1$($p1__48738_SHARP_$$)*2+$APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($p1__48738_SHARP_$$)*2+10;default:return 0}},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shadow_height_shape$jscomp$133$$))));return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1909$horizontal$$,$APP.$app$common$math$ceil$$($ignore_margin_QMARK__stroke_margin$$+
($APP.$cljs$core$truth_$$($ignore_shadow_margin_QMARK_$jscomp$2$$)?0:$shadow_width_stroke_width$jscomp$1_strokes$jscomp$1$$)),$APP.$cljs$cst$1910$vertical$$,$APP.$app$common$math$ceil$$($ignore_margin_QMARK__stroke_margin$$+($APP.$cljs$core$truth_$$($ignore_shadow_margin_QMARK_$jscomp$2$$)?0:$shadow_height_shape$jscomp$133$$))],null)};
$app$common$geom$shapes$bounds$calculate_base_bounds$cljs$0core$0IFn$0_invoke$0arity$03$$=function($h_padding$jscomp$inline_5255_shape$jscomp$135$$,$ignore_margin_QMARK_$jscomp$1_padding$jscomp$inline_5254_v_padding$jscomp$inline_5256$$,$ignore_shadow_margin_QMARK_$jscomp$3$$){var $bounds$jscomp$inline_5253$$=$app$common$geom$shapes$bounds$get_shape_filter_bounds$cljs$0core$0IFn$0_invoke$0arity$02$$($h_padding$jscomp$inline_5255_shape$jscomp$135$$,$ignore_shadow_margin_QMARK_$jscomp$3$$);$ignore_margin_QMARK_$jscomp$1_padding$jscomp$inline_5254_v_padding$jscomp$inline_5256$$=
$app$common$geom$shapes$bounds$calculate_padding$cljs$0core$0IFn$0_invoke$0arity$03$$($h_padding$jscomp$inline_5255_shape$jscomp$135$$,$ignore_margin_QMARK_$jscomp$1_padding$jscomp$inline_5254_v_padding$jscomp$inline_5256$$,$ignore_shadow_margin_QMARK_$jscomp$3$$);$h_padding$jscomp$inline_5255_shape$jscomp$135$$=$APP.$cljs$cst$1909$horizontal$$.$cljs$core$IFn$_invoke$arity$1$($ignore_margin_QMARK_$jscomp$1_padding$jscomp$inline_5254_v_padding$jscomp$inline_5256$$);$ignore_margin_QMARK_$jscomp$1_padding$jscomp$inline_5254_v_padding$jscomp$inline_5256$$=
$APP.$cljs$cst$1910$vertical$$.$cljs$core$IFn$_invoke$arity$1$($ignore_margin_QMARK_$jscomp$1_padding$jscomp$inline_5254_v_padding$jscomp$inline_5256$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($bounds$jscomp$inline_5253$$,
$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$_$$,$h_padding$jscomp$inline_5255_shape$jscomp$135$$),$APP.$cljs$cst$1523$x1$$,$APP.$cljs$core$_$$,$h_padding$jscomp$inline_5255_shape$jscomp$135$$),$APP.$cljs$cst$1525$x2$$,$APP.$cljs$core$_PLUS_$$,$h_padding$jscomp$inline_5255_shape$jscomp$135$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_$$,$ignore_margin_QMARK_$jscomp$1_padding$jscomp$inline_5254_v_padding$jscomp$inline_5256$$),$APP.$cljs$cst$1524$y1$$,$APP.$cljs$core$_$$,$ignore_margin_QMARK_$jscomp$1_padding$jscomp$inline_5254_v_padding$jscomp$inline_5256$$),
$APP.$cljs$cst$1526$y2$$,$APP.$cljs$core$_PLUS_$$,$ignore_margin_QMARK_$jscomp$1_padding$jscomp$inline_5254_v_padding$jscomp$inline_5256$$),$APP.$cljs$cst$290$width$$,$APP.$cljs$core$_PLUS_$$,2*$h_padding$jscomp$inline_5255_shape$jscomp$135$$),$APP.$cljs$cst$1522$height$$,$APP.$cljs$core$_PLUS_$$,2*$ignore_margin_QMARK_$jscomp$1_padding$jscomp$inline_5254_v_padding$jscomp$inline_5256$$)};
$APP.$app$common$geom$shapes$translate_to_frame$$=function($shape$jscomp$140$$,$frame$jscomp$10$$){return $app$common$geom$shapes$transforms$move$$($shape$jscomp$140$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-($frame$jscomp$10$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$10$$,$APP.$cljs$cst$1510$x$$)),-($frame$jscomp$10$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$10$$,$APP.$cljs$cst$1511$y$$))))};
$app$common$geom$shapes$left_bound$$=function($shape$jscomp$144$$){var $or__5025__auto__$jscomp$370$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$144$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$370$$)?$or__5025__auto__$jscomp$370$$:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$144$$))};
$app$common$geom$shapes$top_bound$$=function($shape$jscomp$145$$){var $or__5025__auto__$jscomp$371$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$145$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$371$$)?$or__5025__auto__$jscomp$371$$:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$145$$))};
$app$common$geom$shapes$fully_contained_QMARK_$$=function($rect$jscomp$25$$,$other$jscomp$184$$){return $APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$25$$)<=$APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$184$$)&&$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$25$$)>=$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$184$$)&&$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$25$$)<=$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$184$$)&&
$APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$25$$)>=$APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$184$$)};
$APP.$app$common$geom$shapes$get_areas$$=function($bound_y2_bounds$jscomp$9$$,$selrect$jscomp$24_sr_y2$$){var $bound_x1$$=$bound_y2_bounds$jscomp$9$$?.x1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bound_y2_bounds$jscomp$9$$,$APP.$cljs$cst$1523$x1$$),$bound_x2$$=$bound_y2_bounds$jscomp$9$$?.x2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bound_y2_bounds$jscomp$9$$,$APP.$cljs$cst$1525$x2$$),$bound_y1$$=$bound_y2_bounds$jscomp$9$$?.y1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bound_y2_bounds$jscomp$9$$,
$APP.$cljs$cst$1524$y1$$);$bound_y2_bounds$jscomp$9$$=$bound_y2_bounds$jscomp$9$$?.y2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bound_y2_bounds$jscomp$9$$,$APP.$cljs$cst$1526$y2$$);var $sr_x1$$=$selrect$jscomp$24_sr_y2$$?.x1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$24_sr_y2$$,$APP.$cljs$cst$1523$x1$$),$sr_x2$$=$selrect$jscomp$24_sr_y2$$?.x2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$24_sr_y2$$,$APP.$cljs$cst$1525$x2$$),$sr_y1$$=
$selrect$jscomp$24_sr_y2$$?.y1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$24_sr_y2$$,$APP.$cljs$cst$1524$y1$$);$selrect$jscomp$24_sr_y2$$=$selrect$jscomp$24_sr_y2$$?.y2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$24_sr_y2$$,$APP.$cljs$cst$1526$y2$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$257$left$$,$app$common$geom$rect$corners__GT_rect$cljs$0core$0IFn$0_invoke$0arity$04$$($bound_x1$$,$sr_y1$$,$sr_x1$$,$selrect$jscomp$24_sr_y2$$),
$APP.$cljs$cst$1562$top$$,$app$common$geom$rect$corners__GT_rect$cljs$0core$0IFn$0_invoke$0arity$04$$($sr_x1$$,$bound_y1$$,$sr_x2$$,$sr_y1$$),$APP.$cljs$cst$258$right$$,$app$common$geom$rect$corners__GT_rect$cljs$0core$0IFn$0_invoke$0arity$04$$($sr_x2$$,$sr_y1$$,$bound_x2$$,$selrect$jscomp$24_sr_y2$$),$APP.$cljs$cst$1563$bottom$$,$app$common$geom$rect$corners__GT_rect$cljs$0core$0IFn$0_invoke$0arity$04$$($sr_x1$$,$selrect$jscomp$24_sr_y2$$,$sr_x2$$,$bound_y2_bounds$jscomp$9$$)],null)};
$app$common$geom$shapes$close_attrs_QMARK_$cljs$0core$0IFn$0_invoke$0arity$04$$=function($attr$jscomp$15$$,$val1$jscomp$4$$,$val2$jscomp$4$$,$precision$jscomp$9$$){function $close_val_QMARK_$$($num1$jscomp$3$$,$num2$jscomp$3$$){return typeof $num1$jscomp$3$$==="number"&&typeof $num2$jscomp$3$$==="number"?$APP.$app$common$math$abs$$($num1$jscomp$3$$-$num2$jscomp$3$$)<$precision$jscomp$9$$:null}return typeof $val1$jscomp$4$$==="number"&&typeof $val2$jscomp$4$$==="number"?$close_val_QMARK_$$($val1$jscomp$4$$,
$val2$jscomp$4$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$15$$,$APP.$cljs$cst$1605$selrect$$)?$APP.$cljs$core$every_QMARK_$$(function($p1__49190_SHARP_$$){return $close_val_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($val1$jscomp$4$$,$p1__49190_SHARP_$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($val2$jscomp$4$$,$p1__49190_SHARP_$$))},new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,
$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1523$x1$$,$APP.$cljs$cst$1524$y1$$,$APP.$cljs$cst$1525$x2$$,$APP.$cljs$cst$1526$y2$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$],null)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$15$$,$APP.$cljs$cst$1604$points$$)?$APP.$cljs$core$every_QMARK_$$(function($p1__49192_SHARP_$$){var $and__5023__auto__$jscomp$260$$=$close_val_QMARK_$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($p1__49192_SHARP_$$)),
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__49192_SHARP_$$)));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$260$$)?$close_val_QMARK_$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($p1__49192_SHARP_$$)),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__49192_SHARP_$$))):$and__5023__auto__$jscomp$260$$},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vector$$,
$val1$jscomp$4$$,$val2$jscomp$4$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$15$$,$APP.$cljs$cst$1891$position_data$$)?$APP.$cljs$core$every_QMARK_$$(function($p1__49193_SHARP_$$){var $and__5023__auto__$jscomp$261$$=$close_val_QMARK_$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($p1__49193_SHARP_$$)),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__49193_SHARP_$$)));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$261$$)?
$close_val_QMARK_$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($p1__49193_SHARP_$$)),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__49193_SHARP_$$))):$and__5023__auto__$jscomp$261$$},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vector$$,$val1$jscomp$4$$,$val2$jscomp$4$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($val1$jscomp$4$$,$val2$jscomp$4$$)};
$APP.$app$common$geom$shapes$shapes__GT_rect$$=function($param49202$$){return $APP.$app$common$geom$shapes$common$shapes__GT_rect$$($param49202$$)};$APP.$app$common$geom$shapes$shape__GT_points$$=function($param49213$$){return $app$common$geom$shapes$common$shape__GT_points$$($param49213$$)};$app$common$geom$shapes$move$$=function($param49214$$,$param49215$$){return $app$common$geom$shapes$transforms$move$$($param49214$$,$param49215$$)};
$app$common$geom$shapes$absolute_move$$=function($param49216$$,$param49217$$){return $app$common$geom$shapes$transforms$absolute_move$$($param49216$$,$param49217$$)};$APP.$app$common$geom$shapes$apply_transform$$=function($param49248$$,$param49249$$){return $APP.$app$common$geom$shapes$transforms$apply_transform$$($param49248$$,$param49249$$)};
$app$common$geom$shapes$move_position_data$$=function($param49271$$,$param49272$$){return $app$common$geom$shapes$transforms$move_position_data$$($param49271$$,$param49272$$)};$APP.$app$main$data$helpers$lookup_libraries$$=function($state$jscomp$49$$){return $APP.$cljs$cst$1916$files$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$49$$)};
$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$=function($state$jscomp$50$$){return $APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$50$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$50$$))};
$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$02$$=function($state$jscomp$51$$,$file_id$jscomp$1$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$51$$,$APP.$cljs$cst$1916$files$$),$file_id$jscomp$1$$)};
$APP.$app$main$data$helpers$get_page$$=function($fdata$$,$page_id$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fdata$$,$APP.$cljs$cst$1630$pages_index$$),$page_id$$)};$app$main$data$helpers$process_selected$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objects$jscomp$115$$,$selected$jscomp$7$$){return $app$main$data$helpers$process_selected$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$115$$,$selected$jscomp$7$$,null)};
$app$main$data$helpers$process_selected$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$116$$,$selected$jscomp$8_selected__$1$jscomp$2$$,$map__49363__$1_p__49362$$){$map__49363__$1_p__49362$$=$APP.$cljs$core$__destructure_map$$($map__49363__$1_p__49362$$);var $omit_blocked_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49363__$1_p__49362$$,$cljs$cst$1919$omit_blocked_QMARK_$$,!1);$selected$jscomp$8_selected__$1$jscomp$2$$=$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$116$$,
$selected$jscomp$8_selected__$1$jscomp$2$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($id$jscomp$156$$){return $APP.$cljs$core$contains_QMARK_$$($objects$jscomp$116$$,$id$jscomp$156$$)&&($APP.$cljs$core$not$$($omit_blocked_QMARK_$$)||$APP.$cljs$core$not$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$116$$,
$id$jscomp$156$$),$APP.$cljs$cst$1623$blocked$$,!1)))}),$selected$jscomp$8_selected__$1$jscomp$2$$)};$app$main$data$helpers$get_selected_ids$$=function($state$jscomp$61$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$61$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1921$selected$$)};
$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$=function($state$jscomp$62$$){return $app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$03$$($state$jscomp$62$$,$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$62$$),null)};
$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$02$$=function($state$jscomp$63$$){var $options$jscomp$440$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1919$omit_blocked_QMARK_$$,!0],null);return $app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$03$$($state$jscomp$63$$,$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$63$$),$options$jscomp$440$$)};
$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$03$$=function($selected$jscomp$9_state$jscomp$64$$,$objects$jscomp$118_page_id$jscomp$6$$,$options$jscomp$441$$){$objects$jscomp$118_page_id$jscomp$6$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$9_state$jscomp$64$$,$objects$jscomp$118_page_id$jscomp$6$$);$selected$jscomp$9_state$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$9_state$jscomp$64$$,
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1921$selected$$);return $app$main$data$helpers$process_selected$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$118_page_id$jscomp$6$$,$selected$jscomp$9_state$jscomp$64$$,$options$jscomp$441$$)};
$APP.$app$main$data$helpers$lookup_shape$cljs$0core$0IFn$0_invoke$0arity$02$$=function($state$jscomp$65$$,$id$jscomp$158$$){return $app$main$data$helpers$lookup_shape$cljs$0core$0IFn$0_invoke$0arity$03$$($state$jscomp$65$$,$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$65$$),$id$jscomp$158$$)};
$app$main$data$helpers$lookup_shape$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$119_state$jscomp$66$$,$page_id$jscomp$7$$,$id$jscomp$159$$){$objects$jscomp$119_state$jscomp$66$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$119_state$jscomp$66$$,$page_id$jscomp$7$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$119_state$jscomp$66$$,$id$jscomp$159$$)};
$app$main$data$helpers$lookup_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$=function($state$jscomp$67$$,$ids$jscomp$21$$){return $app$main$data$helpers$lookup_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($state$jscomp$67$$,$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$67$$),$ids$jscomp$21$$)};
$app$main$data$helpers$lookup_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$120_state$jscomp$68$$,$page_id$jscomp$8$$,$ids$jscomp$22$$){$objects$jscomp$120_state$jscomp$68$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$120_state$jscomp$68$$,$page_id$jscomp$8$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$120_state$jscomp$68$$)),
$ids$jscomp$22$$)};$app$main$data$helpers$update_page$cljs$0core$0IFn$0_invoke$0arity$02$$=function($state$jscomp$71$$,$f$jscomp$774$$){return $app$main$data$helpers$update_page$cljs$0core$0IFn$0_invoke$0arity$04$$($state$jscomp$71$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$71$$),$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$71$$),$f$jscomp$774$$)};
$app$main$data$helpers$update_page$cljs$0core$0IFn$0_invoke$0arity$03$$=function($state$jscomp$72$$,$page_id$jscomp$9$$,$f$jscomp$775$$){return $app$main$data$helpers$update_page$cljs$0core$0IFn$0_invoke$0arity$04$$($state$jscomp$72$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$72$$),$page_id$jscomp$9$$,$f$jscomp$775$$)};
$app$main$data$helpers$update_page$cljs$0core$0IFn$0_invoke$0arity$04$$=function($state$jscomp$73$$,$file_id$jscomp$8$$,$page_id$jscomp$10$$,$f$jscomp$776$$){return $APP.$app$common$data$update_in_when$$($state$jscomp$73$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,$file_id$jscomp$8$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$1630$pages_index$$,$page_id$jscomp$10$$],null),$f$jscomp$776$$)};
$app$main$data$helpers$filter_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objects$jscomp$inline_5263_state$jscomp$74$$,$filter_fn$$){var $page_id$jscomp$inline_5261$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$inline_5263_state$jscomp$74$$);$objects$jscomp$inline_5263_state$jscomp$74$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_5263_state$jscomp$74$$,$page_id$jscomp$inline_5261$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($filter_fn$$),$APP.$cljs$core$vals$$($objects$jscomp$inline_5263_state$jscomp$74$$))};
$app$main$data$helpers$select_bool_children$$=function($state$jscomp$76$$,$parent_id$jscomp$16$$){var $objects$jscomp$122$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$76$$),$shape_modifiers$$=$APP.$cljs$cst$1922$workspace_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$76$$),$content_modifiers$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$76$$,$APP.$cljs$cst$1920$workspace_local$$),
$APP.$cljs$cst$1923$edit_path$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$204$$,$id$jscomp$160$$){var $shape__$1$jscomp$8_shape__$2$jscomp$4_temp__5823__auto__$jscomp$109$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$122$$,$id$jscomp$160$$);if($APP.$cljs$core$truth_$$($shape__$1$jscomp$8_shape__$2$jscomp$4_temp__5823__auto__$jscomp$109$$)){var $modifiers$jscomp$41_modifiers__$1$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape_modifiers$$,
$id$jscomp$160$$),$APP.$cljs$cst$1810$modifiers$$);$shape__$1$jscomp$8_shape__$2$jscomp$4_temp__5823__auto__$jscomp$109$$=$modifiers$jscomp$41_modifiers__$1$jscomp$10$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$8_shape__$2$jscomp$4_temp__5823__auto__$jscomp$109$$,$modifiers$jscomp$41_modifiers__$1$jscomp$10$$):$shape__$1$jscomp$8_shape__$2$jscomp$4_temp__5823__auto__$jscomp$109$$;$modifiers$jscomp$41_modifiers__$1$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content_modifiers$$,
$id$jscomp$160$$),$APP.$cljs$cst$1924$content_modifiers$$);$shape__$1$jscomp$8_shape__$2$jscomp$4_temp__5823__auto__$jscomp$109$$=$modifiers$jscomp$41_modifiers__$1$jscomp$10$$!=null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape__$1$jscomp$8_shape__$2$jscomp$4_temp__5823__auto__$jscomp$109$$,$APP.$cljs$cst$1637$content$$,$APP.$app$common$types$path$apply_content_modifiers$$,$modifiers$jscomp$41_modifiers__$1$jscomp$10$$):$shape__$1$jscomp$8_shape__$2$jscomp$4_temp__5823__auto__$jscomp$109$$;
return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$204$$,$id$jscomp$160$$,$shape__$1$jscomp$8_shape__$2$jscomp$4_temp__5823__auto__$jscomp$109$$)}return $result$jscomp$204$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$122$$,$parent_id$jscomp$16$$))};
$APP.$app$main$data$helpers$get_viewport_center$$=function($state$jscomp$77_temp__5825__auto__$jscomp$130_x$jscomp$1122$$){$state$jscomp$77_temp__5825__auto__$jscomp$130_x$jscomp$1122$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$77_temp__5825__auto__$jscomp$130_x$jscomp$1122$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1925$vbox$$],null));if($APP.$cljs$core$truth_$$($state$jscomp$77_temp__5825__auto__$jscomp$130_x$jscomp$1122$$)){var $height$jscomp$63_map__49380__$1$$=
$APP.$cljs$core$__destructure_map$$($state$jscomp$77_temp__5825__auto__$jscomp$130_x$jscomp$1122$$);$state$jscomp$77_temp__5825__auto__$jscomp$130_x$jscomp$1122$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$63_map__49380__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$380$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$63_map__49380__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$70$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$63_map__49380__$1$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$63_map__49380__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$63_map__49380__$1$$,$APP.$cljs$cst$1522$height$$);return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$77_temp__5825__auto__$jscomp$130_x$jscomp$1122$$+$width$jscomp$70$$/2,$y$jscomp$380$$+$height$jscomp$63_map__49380__$1$$/2)}return null};
$APP.$app$main$data$helpers$lookup_team_files$cljs$0core$0IFn$0_invoke$0arity$02$$=function($state$jscomp$79$$,$team_id$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__49381_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($team_id$$,$APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_val$$($p1__49381_SHARP_$$)))},$APP.$cljs$cst$1916$files$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$79$$)))};
$APP.$app$main$data$helpers$lookup_team_projects$cljs$0core$0IFn$0_invoke$0arity$02$$=function($state$jscomp$81$$,$team_id$jscomp$1$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__49385_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($team_id$jscomp$1$$,$APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_val$$($p1__49385_SHARP_$$)))},
$APP.$cljs$cst$1928$projects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$81$$)))};
$app$common$geom$proportions$setup_proportions_image$$=function($map__48930__$1_p__48927$$){$map__48930__$1_p__48927$$=$APP.$cljs$core$__destructure_map$$($map__48930__$1_p__48927$$);var $map__48931_width$jscomp$73$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48930__$1_p__48927$$,$cljs$cst$1633$metadata$$),$height$jscomp$66_map__48931__$1$$=$APP.$cljs$core$__destructure_map$$($map__48931_width$jscomp$73$$);$map__48931_width$jscomp$73$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$66_map__48931__$1$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$66_map__48931__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$66_map__48931__$1$$,$APP.$cljs$cst$1522$height$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__48930__$1_p__48927$$,$APP.$cljs$cst$1807$proportion$$,$map__48931_width$jscomp$73$$/$height$jscomp$66_map__48931__$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1808$proportion_lock$$,!0]))};
$app$common$geom$proportions$setup_proportions_size$$=function($map__48933__$1_p__48932$$){$map__48933__$1_p__48932$$=$APP.$cljs$core$__destructure_map$$($map__48933__$1_p__48932$$);var $map__48934_width$jscomp$74$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48933__$1_p__48932$$,$APP.$cljs$cst$1605$selrect$$),$height$jscomp$67_map__48934__$1$$=$APP.$cljs$core$__destructure_map$$($map__48934_width$jscomp$74$$);$map__48934_width$jscomp$74$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$67_map__48934__$1$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$67_map__48934__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$67_map__48934__$1$$,$APP.$cljs$cst$1522$height$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__48933__$1_p__48932$$,$APP.$cljs$cst$1807$proportion$$,$map__48934_width$jscomp$74$$/$height$jscomp$67_map__48934__$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1808$proportion_lock$$,!0]))};
$app$common$geom$proportions$setup_proportions$$=function($map__48944__$1_p__48943$$){$map__48944__$1_p__48943$$=$APP.$cljs$core$__destructure_map$$($map__48944__$1_p__48943$$);var $type$jscomp$342$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48944__$1_p__48943$$,$APP.$cljs$cst$139$type$$),$image_fill_QMARK_$$=$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($map__48944__$1_p__48943$$))&&$APP.$cljs$core$every_QMARK_$$(function($p1__48942_SHARP_$$){return $APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($p1__48942_SHARP_$$)!=
null},$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($map__48944__$1_p__48943$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$342$$,$APP.$cljs$cst$1613$svg_raw$$)?$app$common$geom$proportions$setup_proportions_size$$($map__48944__$1_p__48943$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$342$$,$APP.$cljs$cst$1612$image$$)?$app$common$geom$proportions$setup_proportions_image$$($map__48944__$1_p__48943$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$342$$,
$APP.$cljs$cst$1588$text$$)?$map__48944__$1_p__48943$$:$image_fill_QMARK_$$?$app$common$geom$proportions$setup_proportions_size$$($map__48944__$1_p__48943$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__48944__$1_p__48943$$,$APP.$cljs$cst$1807$proportion$$,1,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1808$proportion_lock$$,!1]))};
$APP.$app$common$types$shape$interactions$has_destination$$=function($G__49016_interaction$jscomp$4$$){$G__49016_interaction$jscomp$4$$=$APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($G__49016_interaction$jscomp$4$$);var $fexpr__49015$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1941$navigate$$,null,$APP.$cljs$cst$1942$close_overlay$$,null,$APP.$cljs$cst$1944$toggle_overlay$$,null,$APP.$cljs$cst$1946$open_overlay$$,
null],null),null);return $fexpr__49015$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__49015$$.$cljs$core$IFn$_invoke$arity$1$($G__49016_interaction$jscomp$4$$):$fexpr__49015$$($G__49016_interaction$jscomp$4$$)};
$app$common$types$shape$interactions$calc_overlay_position$$=function($G__49076_G__49076__$1_interaction$jscomp$18$$,$overlay_position$jscomp$2_shape$jscomp$159_shape_frame$$,$objects$jscomp$126_overlay_size$jscomp$1$$,$overlay_position__$1_relative_to_shape$$,$base_frame_relative_to_shape_size$$,$base_frame_size_dest_frame$jscomp$1_relative_to_adjusted_to_base_frame$$,$base_position_frame_offset_frame_offset__$1$$){$overlay_position$jscomp$2_shape$jscomp$159_shape_frame$$=$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$126_overlay_size$jscomp$1$$,
$overlay_position$jscomp$2_shape$jscomp$159_shape_frame$$);$base_position_frame_offset_frame_offset__$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1673$manual$$,$APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($G__49076_G__49076__$1_interaction$jscomp$18$$))||$overlay_position$jscomp$2_shape$jscomp$159_shape_frame$$==null||$APP.$app$common$files$helpers$is_direct_child_of_root_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($overlay_position$jscomp$2_shape$jscomp$159_shape_frame$$)||
$APP.$app$common$files$helpers$root_QMARK_$$($overlay_position$jscomp$2_shape$jscomp$159_shape_frame$$)?$base_position_frame_offset_frame_offset__$1$$:$APP.$app$common$geom$point$add$$($base_position_frame_offset_frame_offset__$1$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$2_shape$jscomp$159_shape_frame$$));if($base_frame_size_dest_frame$jscomp$1_relative_to_adjusted_to_base_frame$$==null)return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1562$top$$,$APP.$cljs$cst$257$left$$],null)],null);$objects$jscomp$126_overlay_size$jscomp$1$$=$APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$126_overlay_size$jscomp$1$$,$base_frame_size_dest_frame$jscomp$1_relative_to_adjusted_to_base_frame$$);$base_frame_size_dest_frame$jscomp$1_relative_to_adjusted_to_base_frame$$=
$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_relative_to_shape_size$$);$base_frame_relative_to_shape_size$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position__$1_relative_to_shape$$);$base_frame_size_dest_frame$jscomp$1_relative_to_adjusted_to_base_frame$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_relative_to_shape_size$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_size_dest_frame$jscomp$1_relative_to_adjusted_to_base_frame$$),
$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_relative_to_shape_size$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_size_dest_frame$jscomp$1_relative_to_adjusted_to_base_frame$$)],null);$base_position_frame_offset_frame_offset__$1$$=$APP.$cljs$cst$1974$position_relative_to$$.$cljs$core$IFn$_invoke$arity$1$($G__49076_G__49076__$1_interaction$jscomp$18$$)==null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1673$manual$$,
$APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($G__49076_G__49076__$1_interaction$jscomp$18$$))?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,0,$APP.$cljs$cst$1511$y$$,0],null):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)+$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_size_dest_frame$jscomp$1_relative_to_adjusted_to_base_frame$$),
$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)+$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_size_dest_frame$jscomp$1_relative_to_adjusted_to_base_frame$$)],null);$overlay_position$jscomp$2_shape$jscomp$159_shape_frame$$=$APP.$cljs$cst$1970$overlay_position$$.$cljs$core$IFn$_invoke$arity$1$($G__49076_G__49076__$1_interaction$jscomp$18$$);$overlay_position__$1_relative_to_shape$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position__$1_relative_to_shape$$),
$APP.$cljs$cst$1606$frame$$)?$overlay_position$jscomp$2_shape$jscomp$159_shape_frame$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$2_shape$jscomp$159_shape_frame$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_size_dest_frame$jscomp$1_relative_to_adjusted_to_base_frame$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$2_shape$jscomp$159_shape_frame$$)-
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_size_dest_frame$jscomp$1_relative_to_adjusted_to_base_frame$$)],null);$G__49076_G__49076__$1_interaction$jscomp$18$$=$APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($G__49076_G__49076__$1_interaction$jscomp$18$$);$G__49076_G__49076__$1_interaction$jscomp$18$$=$G__49076_G__49076__$1_interaction$jscomp$18$$ instanceof $APP.$cljs$core$Keyword$$?$G__49076_G__49076__$1_interaction$jscomp$18$$.$fqn$:null;switch($G__49076_G__49076__$1_interaction$jscomp$18$$){case "center":return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_relative_to_shape_size$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$126_overlay_size$jscomp$1$$))/2,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)+
($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_relative_to_shape_size$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$126_overlay_size$jscomp$1$$))/2),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1667$center$$,$APP.$cljs$cst$1667$center$$],null)],null);case "top-left":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1562$top$$,$APP.$cljs$cst$257$left$$],null)],null);case "top-right":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)+
($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_relative_to_shape_size$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$126_overlay_size$jscomp$1$$)),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1562$top$$,$APP.$cljs$cst$258$right$$],null)],null);case "top-center":return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_relative_to_shape_size$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$126_overlay_size$jscomp$1$$))/2,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1562$top$$,$APP.$cljs$cst$1667$center$$],null)],null);case "bottom-left":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)+
($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_relative_to_shape_size$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$126_overlay_size$jscomp$1$$))),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1563$bottom$$,$APP.$cljs$cst$257$left$$],null)],null);case "bottom-right":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)+
($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_relative_to_shape_size$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$126_overlay_size$jscomp$1$$)),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)+($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_relative_to_shape_size$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$126_overlay_size$jscomp$1$$))),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1563$bottom$$,$APP.$cljs$cst$258$right$$],null)],null);case "bottom-center":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_relative_to_shape_size$$)-
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$126_overlay_size$jscomp$1$$))/2,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)+($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($base_frame_relative_to_shape_size$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$126_overlay_size$jscomp$1$$))),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1563$bottom$$,$APP.$cljs$cst$1667$center$$],null)],null);case "manual":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)+$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position__$1_relative_to_shape$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($base_position_frame_offset_frame_offset__$1$$)+
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position__$1_relative_to_shape$$)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1562$top$$,$APP.$cljs$cst$257$left$$],null)],null);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__49076_G__49076__$1_interaction$jscomp$18$$)].join(""));}};
$APP.$app$common$types$shape$interactions$invert_direction$$=function($animation$jscomp$1$$){var $G__49110$$=$APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$1$$);switch($G__49110$$ instanceof $APP.$cljs$core$Keyword$$?$G__49110$$.$fqn$:null){case "right":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($animation$jscomp$1$$,$APP.$cljs$cst$1963$direction$$,$APP.$cljs$cst$257$left$$);case "left":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($animation$jscomp$1$$,
$APP.$cljs$cst$1963$direction$$,$APP.$cljs$cst$258$right$$);case "up":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($animation$jscomp$1$$,$APP.$cljs$cst$1963$direction$$,$APP.$cljs$cst$1953$down$$);case "down":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($animation$jscomp$1$$,$APP.$cljs$cst$1963$direction$$,$APP.$cljs$cst$1954$up$$);default:return $animation$jscomp$1$$}};
$APP.$app$common$types$shape$interactions$add_interaction$$=function($interactions$$,$interaction$jscomp$33$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($interactions$$)?$interactions$$:$APP.$cljs$core$PersistentVector$EMPTY$$,$interaction$jscomp$33$$)};
$app$common$types$shape$interactions$remove_interaction$$=function($interactions$jscomp$1_interactions__$1$$,$index$jscomp$203$$){$interactions$jscomp$1_interactions__$1$$=$APP.$cljs$core$truth_$$($interactions$jscomp$1_interactions__$1$$)?$interactions$jscomp$1_interactions__$1$$:$APP.$cljs$core$PersistentVector$EMPTY$$;return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($interactions$jscomp$1_interactions__$1$$,0,$index$jscomp$203$$),
$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($interactions$jscomp$1_interactions__$1$$,$index$jscomp$203$$+1))};$app$common$types$shape$interactions$update_interaction$$=function($interactions$jscomp$2$$,$index$jscomp$204$$,$update_fn$jscomp$5$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($interactions$jscomp$2$$,$index$jscomp$204$$,$update_fn$jscomp$5$$)};
$app$common$types$shape$interactions$remap_interactions$$=function($interactions$jscomp$3$$,$ids_map$jscomp$6$$,$objects$jscomp$127$$){if($interactions$jscomp$3$$!=null){var $xform$jscomp$19$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($destination$jscomp$10_interaction$jscomp$34$$){$destination$jscomp$10_interaction$jscomp$34$$=$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($destination$jscomp$10_interaction$jscomp$34$$);
return $destination$jscomp$10_interaction$jscomp$34$$==null||$APP.$cljs$core$contains_QMARK_$$($ids_map$jscomp$6$$,$destination$jscomp$10_interaction$jscomp$34$$)||$APP.$cljs$core$contains_QMARK_$$($objects$jscomp$127$$,$destination$jscomp$10_interaction$jscomp$34$$)}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($interaction$jscomp$35$$){return $APP.$app$common$data$update_when$$($interaction$jscomp$35$$,$APP.$cljs$cst$1967$destination$$,function($p1__49115_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($ids_map$jscomp$6$$,
$p1__49115_SHARP_$$,$p1__49115_SHARP_$$)})}));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$xform$jscomp$19$$,$interactions$jscomp$3$$)}return null};
$app$common$types$shape$interactions$actionable_QMARK_$$=function($interactions$jscomp$5$$){return $APP.$cljs$core$some$$(function($p1__49119_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__49119_SHARP_$$),$APP.$cljs$cst$1939$click$$)},$interactions$jscomp$5$$)};
$app$common$types$token$schema_keys$$=function($schema$jscomp$229$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$malli$util$keys$$($APP.$app$common$schema$schema$$($schema$jscomp$229$$)))};
$APP.$app$common$types$token$find_token_value_references$$=function($G__49058_G__49058__$1_token_value$$){return typeof $G__49058_G__49058__$1_token_value$$==="string"?($G__49058_G__49058__$1_token_value$$=$APP.$cljs$core$re_seq$$(/\{([^}]*)\}/,$G__49058_G__49058__$1_token_value$$),$G__49058_G__49058__$1_token_value$$=$G__49058_G__49058__$1_token_value$$==null?null:$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$G__49058_G__49058__$1_token_value$$),$G__49058_G__49058__$1_token_value$$==
null?null:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$G__49058_G__49058__$1_token_value$$)):$APP.$cljs$core$PersistentHashSet$EMPTY$$};
$APP.$app$common$types$token$token_value_self_reference_QMARK_$$=function($self_reference_QMARK__token_name$$,$token_references_token_value$jscomp$1$$){$token_references_token_value$jscomp$1$$=$APP.$app$common$types$token$find_token_value_references$$($token_references_token_value$jscomp$1$$);$self_reference_QMARK__token_name$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token_references_token_value$jscomp$1$$,$self_reference_QMARK__token_name$$);return $APP.$cljs$core$boolean$0$$($self_reference_QMARK__token_name$$)};
$app$common$types$token$token_attr__GT_shape_attr$$=function($token_attr$$){switch($token_attr$$ instanceof $APP.$cljs$core$Keyword$$?$token_attr$$.$fqn$:null){case "fill":return $APP.$cljs$cst$1634$fills$$;case "stroke-color":return $APP.$cljs$cst$1636$strokes$$;case "stroke-width":return $APP.$cljs$cst$1636$strokes$$;default:return $token_attr$$}};
$APP.$app$common$types$token$shape_type__GT_attributes$$=function($type$jscomp$344$$,$is_layout$$){switch($type$jscomp$344$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$344$$.$fqn$:null){case "bool":return $app$common$types$token$generic_attributes$$;case "circle":return $app$common$types$token$generic_attributes$$;case "rect":return $app$common$types$token$rect_attributes$$;case "frame":return $APP.$cljs$core$truth_$$($is_layout$$)?$app$common$types$token$frame_with_layout_attributes$$:$app$common$types$token$rect_attributes$$;
case "image":return $app$common$types$token$rect_attributes$$;case "path":return $app$common$types$token$generic_attributes$$;case "svg-raw":return $app$common$types$token$generic_attributes$$;case "text":return $app$common$types$token$text_attributes$$;default:return null}};
$app$common$types$token$unapply_layout_item_tokens$$=function($shape$jscomp$162$$){var $layout_item_attrs$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$token$sizing_layout_item_keys$$,$APP.$app$common$types$token$spacing_margin_keys$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$162$$,$APP.$cljs$cst$1873$applied_tokens$$,$APP.$app$common$data$without_keys$$,$layout_item_attrs$$)};
$APP.$app$common$types$token$split_font_family$$=function($families_font_value$$){$families_font_value$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($families_font_value$$,",");var $xform$jscomp$20$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$trim$$),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$empty_QMARK_$$));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$xform$jscomp$20$$,$families_font_value$$)};$app$common$types$token$valid_text_decoration$$=function($normalized_value_value$jscomp$431$$){$normalized_value_value$jscomp$431$$=$APP.$cuerdas$core$lower$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($normalized_value_value$jscomp$431$$));return $APP.$cljs$core$contains_QMARK_$$($app$common$types$token$text_decoration_values$$,$normalized_value_value$jscomp$431$$)?$normalized_value_value$jscomp$431$$:null};
$app$common$types$token$valid_font_weight_variant$$=function($italic_QMARK_$jscomp$1_map__49164__$1_value$jscomp$432_variant$jscomp$inline_5267$$){var $G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$=$APP.$cljs$core$re_find$$(/^(.+?)\s*(italic)?$/,$APP.$cuerdas$core$lower$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($italic_QMARK_$jscomp$1_map__49164__$1_value$jscomp$432_variant$jscomp$inline_5267$$)));$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$,
0,null);$italic_QMARK_$jscomp$1_map__49164__$1_value$jscomp$432_variant$jscomp$inline_5267$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$,1,null);$G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$,
2,null);$italic_QMARK_$jscomp$1_map__49164__$1_value$jscomp$432_variant$jscomp$inline_5267$$=$APP.$cljs$core$__destructure_map$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1994$variant$$,$italic_QMARK_$jscomp$1_map__49164__$1_value$jscomp$432_variant$jscomp$inline_5267$$,$cljs$cst$1995$italic_QMARK_$$,$G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$!=null],null));$G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($italic_QMARK_$jscomp$1_map__49164__$1_value$jscomp$432_variant$jscomp$inline_5267$$,$APP.$cljs$cst$1994$variant$$);$italic_QMARK_$jscomp$1_map__49164__$1_value$jscomp$432_variant$jscomp$inline_5267$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($italic_QMARK_$jscomp$1_map__49164__$1_value$jscomp$432_variant$jscomp$inline_5267$$,$cljs$cst$1995$italic_QMARK_$$);$G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$token$font_weight_map$$,$G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$,$G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$);return $APP.$cljs$core$truth_$$($app$common$types$token$font_weight_values$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$font_weight_values$$.$cljs$core$IFn$_invoke$arity$1$($G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$):
$app$common$types$token$font_weight_values$$($G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$))?($G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1996$weight$$,$G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$],null),$APP.$cljs$core$truth_$$($italic_QMARK_$jscomp$1_map__49164__$1_value$jscomp$432_variant$jscomp$inline_5267$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$,$APP.$cljs$cst$1904$style$$,"italic"):$G__49165_italic$jscomp$inline_5268_variant$jscomp$3_vec__49155$jscomp$inline_5266_weight$jscomp$5$$):null};
$APP.$app$common$path_names$join_path$$=function($var_args$jscomp$988$$){for(var $args__5755__auto__$jscomp$152$$=[],$len__5749__auto___49149$$=arguments.length,$i__5750__auto___49150$$=0;;)if($i__5750__auto___49150$$<$len__5749__auto___49149$$)$args__5755__auto__$jscomp$152$$.push(arguments[$i__5750__auto___49150$$]),$i__5750__auto___49150$$+=1;else break;return $APP.$app$common$path_names$join_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$152$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$152$$.slice(1),0,null):null)};
$APP.$app$common$path_names$join_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($path$jscomp$155$$,$p__49078_separator$jscomp$5$$){var $map__49079__$1_with_spaces_QMARK_$$=$APP.$cljs$core$__destructure_map$$($p__49078_separator$jscomp$5$$);$p__49078_separator$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49079__$1_with_spaces_QMARK_$$,$APP.$cljs$cst$1472$separator$$,"/");$map__49079__$1_with_spaces_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49079__$1_with_spaces_QMARK_$$,
$APP.$cljs$cst$1998$with_spaces_QMARK_$$,!0);return $APP.$cljs$core$truth_$$($map__49079__$1_with_spaces_QMARK_$$)?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$([" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__49078_separator$jscomp$5$$)," "].join(""),$path$jscomp$155$$):$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$($p__49078_separator$jscomp$5$$,$path$jscomp$155$$)};
$app$common$path_names$split_group_name$$=function($var_args$jscomp$989$$){for(var $args__5755__auto__$jscomp$153$$=[],$len__5749__auto___49152$$=arguments.length,$i__5750__auto___49153$$=0;;)if($i__5750__auto___49153$$<$len__5749__auto___49152$$)$args__5755__auto__$jscomp$153$$.push(arguments[$i__5750__auto___49153$$]),$i__5750__auto___49153$$+=1;else break;return $APP.$app$common$path_names$split_group_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$153$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$153$$.slice(1),0,null):null)};
$APP.$app$common$path_names$split_group_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($or__5025__auto__$jscomp$inline_5270_path$jscomp$156_path_str$jscomp$2$$,$group_str_p__49092_separator$jscomp$6$$){var $map__49093__$1_with_spaces_QMARK_$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($group_str_p__49092_separator$jscomp$6$$);$group_str_p__49092_separator$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49093__$1_with_spaces_QMARK_$jscomp$1$$,$APP.$cljs$cst$1472$separator$$,
"/");$map__49093__$1_with_spaces_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49093__$1_with_spaces_QMARK_$jscomp$1$$,$APP.$cljs$cst$1998$with_spaces_QMARK_$$,!0);$or__5025__auto__$jscomp$inline_5270_path$jscomp$156_path_str$jscomp$2$$=$APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($or__5025__auto__$jscomp$inline_5270_path$jscomp$156_path_str$jscomp$2$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,
$group_str_p__49092_separator$jscomp$6$$]));$group_str_p__49092_separator$jscomp$6$$=$APP.$app$common$path_names$join_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$butlast$$($or__5025__auto__$jscomp$inline_5270_path$jscomp$156_path_str$jscomp$2$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,$group_str_p__49092_separator$jscomp$6$$,$APP.$cljs$cst$1998$with_spaces_QMARK_$$,$map__49093__$1_with_spaces_QMARK_$jscomp$1$$]));$or__5025__auto__$jscomp$inline_5270_path$jscomp$156_path_str$jscomp$2$$=
$APP.$cljs$core$last$$($or__5025__auto__$jscomp$inline_5270_path$jscomp$156_path_str$jscomp$2$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$group_str_p__49092_separator$jscomp$6$$,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_5270_path$jscomp$156_path_str$jscomp$2$$)?$or__5025__auto__$jscomp$inline_5270_path$jscomp$156_path_str$jscomp$2$$:""],null)};
$APP.$app$common$path_names$merge_path_item$$=function($path$jscomp$158$$,$name$jscomp$179$$){return $APP.$cljs$core$empty_QMARK_$$($path$jscomp$158$$)?$name$jscomp$179$$:$APP.$cljs$core$empty_QMARK_$$($name$jscomp$179$$)?$path$jscomp$158$$:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$158$$)," / ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$179$$)].join("")};
$APP.$app$common$types$variant$properties_to_name$$=function($properties$jscomp$89$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$empty_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$properties$jscomp$89$$)))};
$app$common$types$variant$next_property_number$$=function($properties$jscomp$90$$){var $numbers$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($G__49159_G__49159__$1_G__49159__$2_p1__49158_SHARP_$$){$G__49159_G__49159__$1_G__49159__$2_p1__49158_SHARP_$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($G__49159_G__49159__$1_G__49159__$2_p1__49158_SHARP_$$);$G__49159_G__49159__$1_G__49159__$2_p1__49158_SHARP_$$=$G__49159_G__49159__$1_G__49159__$2_p1__49158_SHARP_$$==
null?null:$APP.$cljs$core$re_find$$($app$common$types$variant$property_regex$$,$G__49159_G__49159__$1_G__49159__$2_p1__49158_SHARP_$$);$G__49159_G__49159__$1_G__49159__$2_p1__49158_SHARP_$$=$G__49159_G__49159__$1_G__49159__$2_p1__49158_SHARP_$$==null?null:$APP.$cljs$core$second$$($G__49159_G__49159__$1_G__49159__$2_p1__49158_SHARP_$$);return $G__49159_G__49159__$1_G__49159__$2_p1__49158_SHARP_$$==null?null:$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($G__49159_G__49159__$1_G__49159__$2_p1__49158_SHARP_$$)},
$properties$jscomp$90$$),$max_num$$=$APP.$cljs$core$seq$$($numbers$$)?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$max$$,$numbers$$):0;return function(){var $y__5111__auto__$jscomp$44$$=$APP.$cljs$core$count$$($properties$jscomp$90$$);return $max_num$$>$y__5111__auto__$jscomp$44$$?$max_num$$:$y__5111__auto__$jscomp$44$$}()+1};
$app$common$types$variant$add_new_prop$$=function($props$jscomp$65$$,$value$jscomp$439$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$65$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,["Property ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$common$types$variant$next_property_number$$($props$jscomp$65$$))].join(""),$APP.$cljs$cst$260$value$$,$value$jscomp$439$$],null))};
$app$common$types$variant$add_new_props$$=function($props$jscomp$66$$,$values$jscomp$36$$){var $next_prop_num$$=$app$common$types$variant$next_property_number$$($props$jscomp$66$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($props$jscomp$66$$,$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($i$jscomp$491$$,$v$jscomp$523$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,["Property ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($next_prop_num$$+
$i$jscomp$491$$)].join(""),$APP.$cljs$cst$260$value$$,$v$jscomp$523$$],null)}),$values$jscomp$36$$)};
$app$common$types$variant$path_to_properties$cljs$0core$0IFn$0_invoke$0arity$03$$=function($assigned_path$jscomp$166$$,$properties$jscomp$92_remaining$$,$min_props$$){var $cpath$$=$APP.$app$common$path_names$split_path$$($assigned_path$jscomp$166$$),$cpath__$1_total_props$$=function(){var $x__5110__auto__$jscomp$45$$=$APP.$cljs$core$count$$($cpath$$);return $x__5110__auto__$jscomp$45$$>$min_props$$?$x__5110__auto__$jscomp$45$$:$min_props$$}();$assigned_path$jscomp$166$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$3$(function($p1__49166_SHARP_$$,
$p2__49167_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__49166_SHARP_$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cpath$$,$p2__49167_SHARP_$$,""))},$properties$jscomp$92_remaining$$,$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$03$$(0,Number.MAX_VALUE,1));$cpath__$1_total_props$$=$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($cpath__$1_total_props$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($cpath$$,
$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$("")));$properties$jscomp$92_remaining$$=$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$count$$($properties$jscomp$92_remaining$$),$cpath__$1_total_props$$);return $app$common$types$variant$add_new_props$$($assigned_path$jscomp$166$$,$properties$jscomp$92_remaining$$)};
$app$common$types$variant$properties_map__GT_formula$$=function($properties$jscomp$93$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($name$jscomp$181_p__49174$$){var $map__49175__$1_value$jscomp$440$$=$APP.$cljs$core$__destructure_map$$($name$jscomp$181_p__49174$$);$name$jscomp$181_p__49174$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49175__$1_value$jscomp$440$$,$APP.$cljs$cst$725$name$$);
$map__49175__$1_value$jscomp$440$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49175__$1_value$jscomp$440$$,$APP.$cljs$cst$260$value$$);return $APP.$cuerdas$core$blank_QMARK_$$($map__49175__$1_value$jscomp$440$$)?null:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$181_p__49174$$),"\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__49175__$1_value$jscomp$440$$)].join("")},$properties$jscomp$93$$))};
$app$common$types$variant$properties_formula__GT_map$$=function($s$jscomp$527$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__49177_v$jscomp$524$$){var $k$jscomp$594$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49177_v$jscomp$524$$,0,null);$p__49177_v$jscomp$524$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49177_v$jscomp$524$$,1,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$594$$),
$APP.$cljs$cst$260$value$$,$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($p__49177_v$jscomp$524$$)],null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__49181_v$jscomp$525$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49181_v$jscomp$525$$,0,null);$p__49181_v$jscomp$525$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49181_v$jscomp$525$$,1,null);return!$APP.$cuerdas$core$blank_QMARK_$$($p__49181_v$jscomp$525$$)},$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__49176_SHARP_$$){return $APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__49176_SHARP_$$,
"\x3d",2)},$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$527$$,","))))};
$app$common$types$variant$valid_properties_formula_QMARK_$$=function($s$jscomp$528$$){return $APP.$cljs$core$every_QMARK_$$(function($p1__49188_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$APP.$cljs$core$count$$($p1__49188_SHARP_$$))&&!$APP.$cuerdas$core$blank_QMARK_$$($APP.$cljs$core$first$$($p1__49188_SHARP_$$))&&$APP.$cljs$core$count$$($APP.$cljs$core$first$$($p1__49188_SHARP_$$))<60&&$APP.$cljs$core$count$$($APP.$cljs$core$second$$($p1__49188_SHARP_$$))<60},$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__49187_SHARP_$$){return $APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__49187_SHARP_$$,
"\x3d",2)},$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$528$$,",")))};
$app$common$types$variant$find_properties_to_remove$$=function($prev_props$$,$upd_props$$){var $upd_names$$=$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$upd_props$$));return $APP.$cljs$core$filterv$$(function($p1__49189_SHARP_$$){return!$APP.$cljs$core$contains_QMARK_$$($upd_names$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__49189_SHARP_$$))},$prev_props$$)};
$app$common$types$variant$find_properties_to_update$$=function($prev_props$jscomp$1$$,$upd_props$jscomp$1$$){return $APP.$cljs$core$filterv$$(function($p1__49191_SHARP_$$){return $APP.$cljs$core$some$$(function($prop$jscomp$19$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__49191_SHARP_$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$19$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__49191_SHARP_$$),
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$19$$))},$prev_props$jscomp$1$$)},$upd_props$jscomp$1$$)};
$app$common$types$variant$find_properties_to_add$$=function($prev_props$jscomp$2$$,$upd_props$jscomp$2$$){var $prev_names$$=$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$prev_props$jscomp$2$$));return $APP.$cljs$core$filterv$$(function($p1__49196_SHARP_$$){return!$APP.$cljs$core$contains_QMARK_$$($prev_names$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__49196_SHARP_$$))},$upd_props$jscomp$2$$)};
$app$common$types$variant$split_base_name_and_number$$=function($G__49197__$1$jscomp$inline_5272_item$jscomp$46$$){var $pattern_num_parens$$=/\(\d+\)$/,$G__49197__$2$jscomp$inline_5273_pattern_num$$=/\d+/,$base$jscomp$24$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$replace$$($G__49197__$1$jscomp$inline_5272_item$jscomp$46$$,$pattern_num_parens$$,""));$G__49197__$1$jscomp$inline_5272_item$jscomp$46$$=$G__49197__$1$jscomp$inline_5272_item$jscomp$46$$==null?null:$APP.$cljs$core$re_find$$($pattern_num_parens$$,
$G__49197__$1$jscomp$inline_5272_item$jscomp$46$$);$G__49197__$2$jscomp$inline_5273_pattern_num$$=$G__49197__$1$jscomp$inline_5272_item$jscomp$46$$==null?null:$APP.$cljs$core$re_find$$($G__49197__$2$jscomp$inline_5273_pattern_num$$,$G__49197__$1$jscomp$inline_5272_item$jscomp$46$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$base$jscomp$24$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($G__49197__$2$jscomp$inline_5273_pattern_num$$==
null?null:$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($G__49197__$2$jscomp$inline_5273_pattern_num$$),0)],null)};
$app$common$types$variant$group_numbers_by_base_name$$=function($items$jscomp$21$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$97$$,$base$jscomp$25_item$jscomp$47$$){var $num$jscomp$29_vec__49198$$=$app$common$types$variant$split_base_name_and_number$$($base$jscomp$25_item$jscomp$47$$);$base$jscomp$25_item$jscomp$47$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($num$jscomp$29_vec__49198$$,0,null);$num$jscomp$29_vec__49198$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($num$jscomp$29_vec__49198$$,
1,null);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($acc$jscomp$97$$,$base$jscomp$25_item$jscomp$47$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$num$jscomp$29_vec__49198$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$items$jscomp$21$$)};
$app$common$types$variant$update_number_in_repeated_item$$=function($items$jscomp$22_names$jscomp$2_nums_taken$$,$base$jscomp$26_item$jscomp$48$$){$items$jscomp$22_names$jscomp$2_nums_taken$$=$app$common$types$variant$group_numbers_by_base_name$$($items$jscomp$22_names$jscomp$2_nums_taken$$);var $n$jscomp$278_num$jscomp$30_vec__49204$$=$app$common$types$variant$split_base_name_and_number$$($base$jscomp$26_item$jscomp$48$$);$base$jscomp$26_item$jscomp$48$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($n$jscomp$278_num$jscomp$30_vec__49204$$,
0,null);$n$jscomp$278_num$jscomp$30_vec__49204$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($n$jscomp$278_num$jscomp$30_vec__49204$$,1,null);for($items$jscomp$22_names$jscomp$2_nums_taken$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($items$jscomp$22_names$jscomp$2_nums_taken$$,$base$jscomp$26_item$jscomp$48$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);;)if($APP.$cljs$core$truth_$$($items$jscomp$22_names$jscomp$2_nums_taken$$.$cljs$core$IFn$_invoke$arity$1$?$items$jscomp$22_names$jscomp$2_nums_taken$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$278_num$jscomp$30_vec__49204$$):
$items$jscomp$22_names$jscomp$2_nums_taken$$($n$jscomp$278_num$jscomp$30_vec__49204$$)))$n$jscomp$278_num$jscomp$30_vec__49204$$+=1;else return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$26_item$jscomp$48$$),$n$jscomp$278_num$jscomp$30_vec__49204$$>0?[" (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$278_num$jscomp$30_vec__49204$$),")"].join(""):null].join("")};
$app$common$types$variant$update_number_in_repeated_prop_names$$=function($props$jscomp$67$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$98$$,$prop$jscomp$20$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$98$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,$app$common$types$variant$update_number_in_repeated_item$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$acc$jscomp$98$$),
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$20$$)),$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$20$$)],null))},$APP.$cljs$core$PersistentVector$EMPTY$$,$props$jscomp$67$$)};
$app$common$types$variant$find_index_for_property_name$$=function($props$jscomp$68$$,$name$jscomp$182$$){return $APP.$cljs$core$some$$(function($p__49224_prop$jscomp$21$$){var $idx$jscomp$75$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49224_prop$jscomp$21$$,0,null);$p__49224_prop$jscomp$21$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49224_prop$jscomp$21$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p__49224_prop$jscomp$21$$),
$name$jscomp$182$$)?$idx$jscomp$75$$:null},$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$props$jscomp$68$$))};
$app$common$types$variant$matching_indices$$=function($props1$jscomp$1$$,$props2$jscomp$1_xform$jscomp$21$$){var $names_in_p2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$app$common$types$variant$xf_COLON_map_name$$,$props2$jscomp$1_xform$jscomp$21$$);$props2$jscomp$1_xform$jscomp$21$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$205$$,$map__49245__$1_name$jscomp$184_p__49242$$){$map__49245__$1_name$jscomp$184_p__49242$$=
$APP.$cljs$core$__destructure_map$$($map__49245__$1_name$jscomp$184_p__49242$$);$map__49245__$1_name$jscomp$184_p__49242$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49245__$1_name$jscomp$184_p__49242$$,$APP.$cljs$cst$725$name$$);return $APP.$cljs$core$contains_QMARK_$$($names_in_p2$$,$map__49245__$1_name$jscomp$184_p__49242$$)?$index$jscomp$205$$:null}),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$some_QMARK_$$));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$props2$jscomp$1_xform$jscomp$21$$,$props1$jscomp$1$$)};
$app$common$types$variant$find_index_by_name$$=function($name$jscomp$185$$,$props$jscomp$69$$){return $APP.$cljs$core$some$$(function($item$jscomp$49_p__49250$$){var $idx$jscomp$76$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$49_p__49250$$,0,null);$item$jscomp$49_p__49250$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$49_p__49250$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$49_p__49250$$),$name$jscomp$185$$)?
$idx$jscomp$76$$:null},$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$props$jscomp$69$$))};
$app$common$types$variant$merge_properties$$=function($props1$jscomp$2$$,$props2$jscomp$2_props2__$1$$){$props2$jscomp$2_props2__$1$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__49259_SHARP_$$){return $APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__49259_SHARP_$$))},$props2$jscomp$2_props2__$1$$);return $APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__49260_props$jscomp$71$$,
$prop$jscomp$22$$){var $map__49261__$1_used_pos$jscomp$2_used_pos__$1$$=$APP.$cljs$core$__destructure_map$$($p__49260_props$jscomp$71$$);$p__49260_props$jscomp$71$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49261__$1_used_pos$jscomp$2_used_pos__$1$$,$APP.$cljs$cst$575$props$$);$map__49261__$1_used_pos$jscomp$2_used_pos__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49261__$1_used_pos$jscomp$2_used_pos__$1$$,$cljs$cst$2005$used_pos$$);var $JSCompiler_temp$jscomp$10781_name$jscomp$inline_5275_or__5025__auto__$jscomp$inline_5278_p$jscomp$inline_11998_pos$jscomp$94$$=
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$22$$);$JSCompiler_temp$jscomp$10781_name$jscomp$inline_5275_or__5025__auto__$jscomp$inline_5278_p$jscomp$inline_11998_pos$jscomp$94$$=$app$common$types$variant$find_index_by_name$$($JSCompiler_temp$jscomp$10781_name$jscomp$inline_5275_or__5025__auto__$jscomp$inline_5278_p$jscomp$inline_11998_pos$jscomp$94$$,$p__49260_props$jscomp$71$$);if(!$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10781_name$jscomp$inline_5275_or__5025__auto__$jscomp$inline_5278_p$jscomp$inline_11998_pos$jscomp$94$$))a:{for($JSCompiler_temp$jscomp$10781_name$jscomp$inline_5275_or__5025__auto__$jscomp$inline_5278_p$jscomp$inline_11998_pos$jscomp$94$$=
0;;)if($APP.$cljs$core$contains_QMARK_$$($map__49261__$1_used_pos$jscomp$2_used_pos__$1$$,$JSCompiler_temp$jscomp$10781_name$jscomp$inline_5275_or__5025__auto__$jscomp$inline_5278_p$jscomp$inline_11998_pos$jscomp$94$$))$JSCompiler_temp$jscomp$10781_name$jscomp$inline_5275_or__5025__auto__$jscomp$inline_5278_p$jscomp$inline_11998_pos$jscomp$94$$+=1;else break a;$JSCompiler_temp$jscomp$10781_name$jscomp$inline_5275_or__5025__auto__$jscomp$inline_5278_p$jscomp$inline_11998_pos$jscomp$94$$=void 0}$map__49261__$1_used_pos$jscomp$2_used_pos__$1$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($map__49261__$1_used_pos$jscomp$2_used_pos__$1$$,$JSCompiler_temp$jscomp$10781_name$jscomp$inline_5275_or__5025__auto__$jscomp$inline_5278_p$jscomp$inline_11998_pos$jscomp$94$$);return $JSCompiler_temp$jscomp$10781_name$jscomp$inline_5275_or__5025__auto__$jscomp$inline_5278_p$jscomp$inline_11998_pos$jscomp$94$$<$APP.$cljs$core$count$$($p__49260_props$jscomp$71$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$575$props$$,$APP.$cljs$core$assoc_in$$($APP.$cljs$core$vec$$($p__49260_props$jscomp$71$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$10781_name$jscomp$inline_5275_or__5025__auto__$jscomp$inline_5278_p$jscomp$inline_11998_pos$jscomp$94$$,$APP.$cljs$cst$260$value$$],null),$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$22$$)),$cljs$cst$2005$used_pos$$,$map__49261__$1_used_pos$jscomp$2_used_pos__$1$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$575$props$$,$app$common$types$variant$add_new_prop$$($p__49260_props$jscomp$71$$,
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$22$$)),$cljs$cst$2005$used_pos$$,$map__49261__$1_used_pos$jscomp$2_used_pos__$1$$],null)},new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$575$props$$,$APP.$cljs$core$vec$$($props1$jscomp$2$$),$cljs$cst$2005$used_pos$$,$app$common$types$variant$matching_indices$$($props1$jscomp$2$$,$props2$jscomp$2_props2__$1$$)],null),$props2$jscomp$2_props2__$1$$))};
$app$common$types$variant$distance$$=function($props1$jscomp$3$$,$props2$jscomp$3$$){var $total_num_props$$=$APP.$cljs$core$count$$($props1$jscomp$3$$);return $cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($idx$jscomp$77$$,$p2$jscomp$51_p__49303$$){var $p1$jscomp$69$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2$jscomp$51_p__49303$$,0,null);$p2$jscomp$51_p__49303$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2$jscomp$51_p__49303$$,
1,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$69$$,$p2$jscomp$51_p__49303$$)?Math.pow(2,$total_num_props$$-$idx$jscomp$77$$):0}),$APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vector$$,$props1$jscomp$3$$,$props2$jscomp$3$$))};
$app$common$types$variant$variant_name_to_name$$=function($variant$jscomp$4$$){return $APP.$app$common$path_names$merge_path_item$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$4$$),$APP.$cuerdas$core$replace$$($APP.$cljs$cst$2002$variant_name$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$4$$),/, /," / "))};
$app$common$types$shape$Shape$$=function($id$jscomp$161$$,$name$jscomp$188$$,$type$jscomp$345$$,$x$jscomp$1123$$,$y$jscomp$381$$,$width$jscomp$75$$,$height$jscomp$68$$,$rotation$jscomp$8$$,$selrect$jscomp$26$$,$points$jscomp$48$$,$transform$jscomp$58$$,$transform_inverse$jscomp$13$$,$parent_id$jscomp$17$$,$frame_id$jscomp$14$$,$flip_x$jscomp$4$$,$flip_y$jscomp$4$$,$$meta$jscomp$6$$,$$extmap$jscomp$6$$,$$hash$jscomp$6$$){this.id=$id$jscomp$161$$;this.name=$name$jscomp$188$$;this.type=$type$jscomp$345$$;
this.x=$x$jscomp$1123$$;this.y=$y$jscomp$381$$;this.width=$width$jscomp$75$$;this.height=$height$jscomp$68$$;this.rotation=$rotation$jscomp$8$$;this.$selrect$=$selrect$jscomp$26$$;this.points=$points$jscomp$48$$;this.transform=$transform$jscomp$58$$;this.$transform_inverse$=$transform_inverse$jscomp$13$$;this.$parent_id$=$parent_id$jscomp$17$$;this.$frame_id$=$frame_id$jscomp$14$$;this.$flip_x$=$flip_x$jscomp$4$$;this.$flip_y$=$flip_y$jscomp$4$$;this.$$meta$=$$meta$jscomp$6$$;this.$$extmap$=$$extmap$jscomp$6$$;
this.$$hash$=$$hash$jscomp$6$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139280};
$app$common$types$shape$map__GT_Shape$$=function($param_49343$$){var $exclude__42719__auto__$jscomp$3$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,16,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1289$transform$$,null,$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$725$name$$,null,$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$139$type$$,null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1787$transform_inverse$$,null,$APP.$cljs$cst$266$id$$,null,
$APP.$cljs$cst$1619$parent_id$$,null,$APP.$cljs$cst$1607$frame_id$$,null,$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1605$selrect$$,null,$APP.$cljs$cst$1879$flip_x$$,null,$APP.$cljs$cst$1522$height$$,null,$APP.$cljs$cst$1880$flip_y$$,null],null),null),$extmap__42720__auto__$jscomp$3$$=$APP.$cljs$core$reduce_kv$$(function($acc__42721__auto__$jscomp$3$$,$k__42722__auto__$jscomp$3$$,$v__42723__auto__$jscomp$3$$){return $APP.$cljs$core$contains_QMARK_$$($exclude__42719__auto__$jscomp$3$$,$k__42722__auto__$jscomp$3$$)?
$acc__42721__auto__$jscomp$3$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc__42721__auto__$jscomp$3$$,$k__42722__auto__$jscomp$3$$,$v__42723__auto__$jscomp$3$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$param_49343$$);return new $app$common$types$shape$Shape$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$266$id$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$725$name$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,
$APP.$cljs$cst$139$type$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$1510$x$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$1511$y$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$290$width$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$1522$height$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$1788$rotation$$),
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$1605$selrect$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$1604$points$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$1289$transform$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$1787$transform_inverse$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$1619$parent_id$$),
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$1607$frame_id$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$1879$flip_x$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($param_49343$$,$APP.$cljs$cst$1880$flip_y$$),null,$APP.$cljs$core$not_empty$$($extmap__42720__auto__$jscomp$3$$),null)};
$APP.$app$common$types$shape$shape_QMARK_$$=function($o$jscomp$249$$){return $o$jscomp$249$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$o$jscomp$249$$.$app$common$types$shape$IShape$$?!0:!1:!1};$app$common$types$shape$create_shape$$=function($attrs$jscomp$11$$){return $app$common$types$shape$wasm_enabled_QMARK_$$?$app$common$types$shape$wasm_create_shape$$($attrs$jscomp$11$$):$app$common$types$shape$map__GT_Shape$$($attrs$jscomp$11$$)};
$APP.$app$common$types$shape$has_images_QMARK_$$=function($fills$jscomp$10_or__5025__auto__$jscomp$377_p__49434$$){var $map__49436__$1_strokes$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($fills$jscomp$10_or__5025__auto__$jscomp$377_p__49434$$);$fills$jscomp$10_or__5025__auto__$jscomp$377_p__49434$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49436__$1_strokes$jscomp$2$$,$APP.$cljs$cst$1634$fills$$);$map__49436__$1_strokes$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49436__$1_strokes$jscomp$2$$,
$APP.$cljs$cst$1636$strokes$$);$fills$jscomp$10_or__5025__auto__$jscomp$377_p__49434$$=$APP.$cljs$core$some$$($APP.$cljs$cst$1632$fill_image$$,$fills$jscomp$10_or__5025__auto__$jscomp$377_p__49434$$);return $APP.$cljs$core$truth_$$($fills$jscomp$10_or__5025__auto__$jscomp$377_p__49434$$)?$fills$jscomp$10_or__5025__auto__$jscomp$377_p__49434$$:$APP.$cljs$core$some$$($APP.$cljs$cst$1635$stroke_image$$,$map__49436__$1_strokes$jscomp$2$$)};
$app$common$types$shape$is_allowed_switch_keep_attr_QMARK_$$=function($attr$jscomp$18$$,$G__49442__$1_type$jscomp$349$$){$G__49442__$1_type$jscomp$349$$=$G__49442__$1_type$jscomp$349$$ instanceof $APP.$cljs$core$Keyword$$?$G__49442__$1_type$jscomp$349$$.$fqn$:null;switch($G__49442__$1_type$jscomp$349$$){case "group":return $APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_group_attrs$$,$attr$jscomp$18$$)||$APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_generic_attrs$$,
$attr$jscomp$18$$);case "frame":return $APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_frame_attrs$$,$attr$jscomp$18$$)||$APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_generic_attrs$$,$attr$jscomp$18$$);case "bool":return $APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_bool_attrs$$,$attr$jscomp$18$$)||$APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_shape_attrs$$,$attr$jscomp$18$$)||$APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_shape_base_attrs$$,
$attr$jscomp$18$$);case "rect":return $APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_generic_attrs$$,$attr$jscomp$18$$);case "circle":return $APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_generic_attrs$$,$attr$jscomp$18$$);case "image":return $APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_image_attrs$$,$attr$jscomp$18$$)||$APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_generic_attrs$$,$attr$jscomp$18$$);case "svg-raw":return $APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_svg_attrs$$,
$attr$jscomp$18$$)||$APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_generic_attrs$$,$attr$jscomp$18$$);case "path":return $APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_path_attrs$$,$attr$jscomp$18$$)||$APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_shape_attrs$$,$attr$jscomp$18$$)||$APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_shape_base_attrs$$,$attr$jscomp$18$$);case "text":return $APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_text_attrs$$,
$attr$jscomp$18$$)||$APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$allowed_generic_attrs$$,$attr$jscomp$18$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__49442__$1_type$jscomp$349$$)].join(""));}};
$app$common$types$shape$get_minimal_shape$$=function($G__49457__$1_type$jscomp$350$$){$G__49457__$1_type$jscomp$350$$=$G__49457__$1_type$jscomp$350$$ instanceof $APP.$cljs$core$Keyword$$?$G__49457__$1_type$jscomp$350$$.$fqn$:null;switch($G__49457__$1_type$jscomp$350$$){case "rect":return $app$common$types$shape$minimal_rect_attrs$$;case "image":return $app$common$types$shape$minimal_image_attrs$$;case "circle":return $app$common$types$shape$minimal_circle_attrs$$;case "path":return $app$common$types$shape$minimal_path_attrs$$;
case "frame":return $app$common$types$shape$minimal_frame_attrs$$;case "bool":return $app$common$types$shape$minimal_bool_attrs$$;case "group":return $app$common$types$shape$minimal_group_attrs$$;case "text":return $app$common$types$shape$minimal_text_attrs$$;case "svg-raw":return $app$common$types$shape$minimal_svg_raw_attrs$$;case "multiple":return $app$common$types$shape$minimal_multiple_attrs$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__49457__$1_type$jscomp$350$$)].join(""));
}};
$app$common$types$shape$make_minimal_shape$$=function($attrs__$1_attrs__$2_type$jscomp$351_type__$1$jscomp$5$$){$attrs__$1_attrs__$2_type$jscomp$351_type__$1$jscomp$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attrs__$1_attrs__$2_type$jscomp$351_type__$1$jscomp$5$$,$APP.$cljs$cst$2052$curve$$)?$APP.$cljs$cst$296$path$$:$attrs__$1_attrs__$2_type$jscomp$351_type__$1$jscomp$5$$;var $attrs$jscomp$13$$=$app$common$types$shape$get_minimal_shape$$($attrs__$1_attrs__$2_type$jscomp$351_type__$1$jscomp$5$$);$attrs__$1_attrs__$2_type$jscomp$351_type__$1$jscomp$5$$=
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,$attrs__$1_attrs__$2_type$jscomp$351_type__$1$jscomp$5$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1610$bool$$,$attrs__$1_attrs__$2_type$jscomp$351_type__$1$jscomp$5$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$13$$,
$APP.$cljs$cst$1510$x$$,0),$APP.$cljs$cst$1511$y$$,0),$APP.$cljs$cst$290$width$$,.01),$APP.$cljs$cst$1522$height$$,.01):$attrs$jscomp$13$$;$attrs__$1_attrs__$2_type$jscomp$351_type__$1$jscomp$5$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs__$1_attrs__$2_type$jscomp$351_type__$1$jscomp$5$$,$APP.$cljs$cst$266$id$$,
$APP.$app$common$uuid$next$$()),$APP.$cljs$cst$1607$frame_id$$,$APP.$app$common$uuid$zero$$),$APP.$cljs$cst$1619$parent_id$$,$APP.$app$common$uuid$zero$$),$APP.$cljs$cst$1788$rotation$$,0);return $app$common$types$shape$create_shape$$($attrs__$1_attrs__$2_type$jscomp$351_type__$1$jscomp$5$$)};
$app$common$types$shape$setup_rect$$=function($map__49462__$1_p__49461$$){$map__49462__$1_p__49461$$=$APP.$cljs$core$__destructure_map$$($map__49462__$1_p__49461$$);var $JSCompiler_temp$jscomp$10777_selrect$jscomp$29_selrect__$1_x$jscomp$inline_12001$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49462__$1_p__49461$$,$APP.$cljs$cst$1605$selrect$$),$points$jscomp$51_points__$1$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49462__$1_p__49461$$,$APP.$cljs$cst$1604$points$$),
$transform$jscomp$61_transform__$1$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49462__$1_p__49461$$,$APP.$cljs$cst$1289$transform$$);if(!$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10777_selrect$jscomp$29_selrect__$1_x$jscomp$inline_12001$$)){$JSCompiler_temp$jscomp$10777_selrect$jscomp$29_selrect__$1_x$jscomp$inline_12001$$=$map__49462__$1_p__49461$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49462__$1_p__49461$$,$APP.$cljs$cst$1510$x$$);var $center$jscomp$30_y$jscomp$inline_12002$$=
$map__49462__$1_p__49461$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49462__$1_p__49461$$,$APP.$cljs$cst$1511$y$$),$w$jscomp$inline_12003$$=$map__49462__$1_p__49461$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49462__$1_p__49461$$,$APP.$cljs$cst$290$width$$),$h$jscomp$inline_12004$$=$map__49462__$1_p__49461$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49462__$1_p__49461$$,$APP.$cljs$cst$1522$height$$);$JSCompiler_temp$jscomp$10777_selrect$jscomp$29_selrect__$1_x$jscomp$inline_12001$$=
$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$04$$($JSCompiler_temp$jscomp$10777_selrect$jscomp$29_selrect__$1_x$jscomp$inline_12001$$,$center$jscomp$30_y$jscomp$inline_12002$$,$w$jscomp$inline_12003$$,$h$jscomp$inline_12004$$)?$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$10777_selrect$jscomp$29_selrect__$1_x$jscomp$inline_12001$$,$center$jscomp$30_y$jscomp$inline_12002$$,$w$jscomp$inline_12003$$,$h$jscomp$inline_12004$$):null}$center$jscomp$30_y$jscomp$inline_12002$$=
$APP.$app$common$geom$rect$rect__GT_center$$($JSCompiler_temp$jscomp$10777_selrect$jscomp$29_selrect__$1_x$jscomp$inline_12001$$);$transform$jscomp$61_transform__$1$jscomp$4$$=$APP.$cljs$core$truth_$$($transform$jscomp$61_transform__$1$jscomp$4$$)?$transform$jscomp$61_transform__$1$jscomp$4$$:$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$();$points$jscomp$51_points__$1$jscomp$3$$=$APP.$cljs$core$truth_$$($points$jscomp$51_points__$1$jscomp$3$$)?$points$jscomp$51_points__$1$jscomp$3$$:
$app$common$geom$shapes$transform_points$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$geom$rect$rect__GT_points$$($JSCompiler_temp$jscomp$10777_selrect$jscomp$29_selrect__$1_x$jscomp$inline_12001$$),$center$jscomp$30_y$jscomp$inline_12002$$,$transform$jscomp$61_transform__$1$jscomp$4$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__49462__$1_p__49461$$,$APP.$cljs$cst$1605$selrect$$,$JSCompiler_temp$jscomp$10777_selrect$jscomp$29_selrect__$1_x$jscomp$inline_12001$$),
$APP.$cljs$cst$1604$points$$,$points$jscomp$51_points__$1$jscomp$3$$)};
$APP.$app$common$types$shape$setup_shape$$=function($map__49468__$1_p__49467_props__$1$jscomp$6$$){$map__49468__$1_p__49467_props__$1$jscomp$6$$=$APP.$cljs$core$__destructure_map$$($map__49468__$1_p__49467_props__$1$jscomp$6$$);var $shape$jscomp$168_type$jscomp$352$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49468__$1_p__49467_props__$1$jscomp$6$$,$APP.$cljs$cst$139$type$$);$shape$jscomp$168_type$jscomp$352$$=$app$common$types$shape$make_minimal_shape$$($shape$jscomp$168_type$jscomp$352$$);
$map__49468__$1_p__49467_props__$1$jscomp$6$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$map__49468__$1_p__49467_props__$1$jscomp$6$$));var $shape__$1$jscomp$9$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shape$jscomp$168_type$jscomp$352$$,$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$map__49468__$1_p__49467_props__$1$jscomp$6$$))])),$shape__$2$jscomp$5$$=function(){var $G__49469_map__49464__$1$jscomp$inline_14268_map__49466__$1$jscomp$inline_5281_p__49465$jscomp$inline_5280$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$9$$);switch($G__49469_map__49464__$1$jscomp$inline_14268_map__49466__$1$jscomp$inline_5281_p__49465$jscomp$inline_5280$$ instanceof $APP.$cljs$core$Keyword$$?$G__49469_map__49464__$1$jscomp$inline_14268_map__49466__$1$jscomp$inline_5281_p__49465$jscomp$inline_5280$$.$fqn$:
null){case "bool":case "path":$G__49469_map__49464__$1$jscomp$inline_14268_map__49466__$1$jscomp$inline_5281_p__49465$jscomp$inline_5280$$=$APP.$cljs$core$__destructure_map$$($shape__$1$jscomp$9$$);var $content$jscomp$inline_14269_content__$1$jscomp$inline_14275_metadata$jscomp$inline_5282$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__49469_map__49464__$1$jscomp$inline_14268_map__49466__$1$jscomp$inline_5281_p__49465$jscomp$inline_5280$$,$APP.$cljs$cst$1637$content$$),$or__5025__auto____$1$jscomp$inline_14273_selrect$jscomp$inline_14270_selrect__$1$jscomp$inline_14272$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__49469_map__49464__$1$jscomp$inline_14268_map__49466__$1$jscomp$inline_5281_p__49465$jscomp$inline_5280$$,$APP.$cljs$cst$1605$selrect$$),$points$jscomp$inline_14271_points__$1$jscomp$inline_14274$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__49469_map__49464__$1$jscomp$inline_14268_map__49466__$1$jscomp$inline_5281_p__49465$jscomp$inline_5280$$,$APP.$cljs$cst$1604$points$$);$APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$inline_14273_selrect$jscomp$inline_14270_selrect__$1$jscomp$inline_14272$$)||
($or__5025__auto____$1$jscomp$inline_14273_selrect$jscomp$inline_14270_selrect__$1$jscomp$inline_14272$$=$APP.$app$common$types$path$calc_selrect$$($content$jscomp$inline_14269_content__$1$jscomp$inline_14275_metadata$jscomp$inline_5282$$),$or__5025__auto____$1$jscomp$inline_14273_selrect$jscomp$inline_14270_selrect__$1$jscomp$inline_14272$$=$APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$inline_14273_selrect$jscomp$inline_14270_selrect__$1$jscomp$inline_14272$$)?$or__5025__auto____$1$jscomp$inline_14273_selrect$jscomp$inline_14270_selrect__$1$jscomp$inline_14272$$:
$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$0$());$points$jscomp$inline_14271_points__$1$jscomp$inline_14274$$=$APP.$cljs$core$truth_$$($points$jscomp$inline_14271_points__$1$jscomp$inline_14274$$)?$points$jscomp$inline_14271_points__$1$jscomp$inline_14274$$:$APP.$app$common$geom$rect$rect__GT_points$$($or__5025__auto____$1$jscomp$inline_14273_selrect$jscomp$inline_14270_selrect__$1$jscomp$inline_14272$$);$content$jscomp$inline_14269_content__$1$jscomp$inline_14275_metadata$jscomp$inline_5282$$=
$APP.$app$common$types$path$impl$path_data$$($content$jscomp$inline_14269_content__$1$jscomp$inline_14275_metadata$jscomp$inline_5282$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__49469_map__49464__$1$jscomp$inline_14268_map__49466__$1$jscomp$inline_5281_p__49465$jscomp$inline_5280$$,$APP.$cljs$cst$1605$selrect$$,$or__5025__auto____$1$jscomp$inline_14273_selrect$jscomp$inline_14270_selrect__$1$jscomp$inline_14272$$),
$APP.$cljs$cst$1604$points$$,$points$jscomp$inline_14271_points__$1$jscomp$inline_14274$$),$APP.$cljs$cst$1637$content$$,$content$jscomp$inline_14269_content__$1$jscomp$inline_14275_metadata$jscomp$inline_5282$$);case "image":return $G__49469_map__49464__$1$jscomp$inline_14268_map__49466__$1$jscomp$inline_5281_p__49465$jscomp$inline_5280$$=$app$common$types$shape$setup_rect$$($shape__$1$jscomp$9$$),$G__49469_map__49464__$1$jscomp$inline_14268_map__49466__$1$jscomp$inline_5281_p__49465$jscomp$inline_5280$$=
$APP.$cljs$core$__destructure_map$$($G__49469_map__49464__$1$jscomp$inline_14268_map__49466__$1$jscomp$inline_5281_p__49465$jscomp$inline_5280$$),$content$jscomp$inline_14269_content__$1$jscomp$inline_14275_metadata$jscomp$inline_5282$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__49469_map__49464__$1$jscomp$inline_14268_map__49466__$1$jscomp$inline_5281_p__49465$jscomp$inline_5280$$,$cljs$cst$1633$metadata$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__49469_map__49464__$1$jscomp$inline_14268_map__49466__$1$jscomp$inline_5281_p__49465$jscomp$inline_5280$$,
$APP.$cljs$cst$1807$proportion$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$inline_14269_content__$1$jscomp$inline_14275_metadata$jscomp$inline_5282$$)/$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$inline_14269_content__$1$jscomp$inline_14275_metadata$jscomp$inline_5282$$)),$APP.$cljs$cst$1808$proportion_lock$$,!0);default:return $app$common$types$shape$setup_rect$$($shape__$1$jscomp$9$$)}}();return $app$common$geom$proportions$setup_proportions$$(function(){var $G__49470$$=
$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape__$2$jscomp$5$$)==null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$2$jscomp$5$$,$APP.$cljs$cst$1289$transform$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()):$shape__$2$jscomp$5$$;return $APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($shape__$2$jscomp$5$$)==null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__49470$$,$APP.$cljs$cst$1787$transform_inverse$$,
$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()):$G__49470$$}())};
$app$common$types$shape$extract_props$$=function($shape$jscomp$169$$){function $extract_text_props$$($props$jscomp$74$$,$shape__$1$jscomp$10$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($G__49481__$1_G__49481__$2_result$jscomp$206$$,$node$jscomp$240$$){$G__49481__$1_G__49481__$2_result$jscomp$206$$=$APP.$app$common$types$text$is_root_node_QMARK_$$($node$jscomp$240$$)?$assoc_props$$($G__49481__$1_G__49481__$2_result$jscomp$206$$,$node$jscomp$240$$,$APP.$app$common$types$text$text_valign_attrs$$):
$G__49481__$1_G__49481__$2_result$jscomp$206$$;$G__49481__$1_G__49481__$2_result$jscomp$206$$=$APP.$app$common$types$text$is_paragraph_node_QMARK_$$($node$jscomp$240$$)?$assoc_props$$($G__49481__$1_G__49481__$2_result$jscomp$206$$,$node$jscomp$240$$,$APP.$app$common$types$text$paragraph_attrs$$):$G__49481__$1_G__49481__$2_result$jscomp$206$$;return $APP.$app$common$types$text$is_text_node_QMARK_$$($node$jscomp$240$$)?$assoc_props$$($G__49481__$1_G__49481__$2_result$jscomp$206$$,$node$jscomp$240$$,
$APP.$app$common$types$text$text_node_attrs$$):$G__49481__$1_G__49481__$2_result$jscomp$206$$},$props$jscomp$74$$,$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$10$$)))}function $assoc_props$$($props$jscomp$73$$,$node$jscomp$239$$,$attrs$jscomp$14$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($props__$1$jscomp$7$$,$attr$jscomp$19$$){return $APP.$cljs$core$contains_QMARK_$$($props__$1$jscomp$7$$,
$attr$jscomp$19$$)||$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$239$$,$attr$jscomp$19$$)==null?$props__$1$jscomp$7$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($props__$1$jscomp$7$$,$attr$jscomp$19$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$239$$,$attr$jscomp$19$$))},$props$jscomp$73$$,$attrs$jscomp$14$$)}var $extract_props$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$169$$)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$shape$basic_extract_props$$,
$APP.$cljs$cst$1634$fills$$):$app$common$types$shape$basic_extract_props$$,$G__49488$$=function(){var $G__49489$$=$APP.$cljs$core$select_keys$$($shape$jscomp$169$$,$extract_props$$);return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$169$$)?$extract_text_props$$($G__49489$$,$shape$jscomp$169$$):$G__49489$$}();return $APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$169$$)?$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($G__49488$$,
$APP.$cljs$core$select_keys$$($shape$jscomp$169$$,$app$common$types$shape$layout$layout_attrs$$)):$G__49488$$};
$app$common$types$shape$patch_props$$=function($shape$jscomp$170$$,$props$jscomp$76$$,$objects$jscomp$128$$){function $patch_layout_props$$($shape__$1$jscomp$13_shape__$2$jscomp$6$$,$props__$1$jscomp$9$$){$shape__$1$jscomp$13_shape__$2$jscomp$6$$=$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$13_shape__$2$jscomp$6$$,$APP.$cljs$core$select_keys$$($props__$1$jscomp$9$$,$app$common$types$shape$layout$layout_attrs$$));return $APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$13_shape__$2$jscomp$6$$)?
$APP.$app$common$types$shape$layout$assign_cells$$($shape__$1$jscomp$13_shape__$2$jscomp$6$$,$objects$jscomp$128$$):$shape__$1$jscomp$13_shape__$2$jscomp$6$$}function $patch_text_props$$($shape__$1$jscomp$12$$,$props__$1$jscomp$8$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$12$$,$APP.$cljs$cst$1637$content$$,function($content$jscomp$102$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$02$$(function($node$jscomp$241$$){var $G__49492__$1_G__49492__$2$$=
$APP.$app$common$types$text$is_root_node_QMARK_$$($node$jscomp$241$$)?$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$241$$,$APP.$cljs$core$select_keys$$($props__$1$jscomp$8$$,$APP.$app$common$types$text$text_valign_attrs$$)):$node$jscomp$241$$;$G__49492__$1_G__49492__$2$$=$APP.$app$common$types$text$is_paragraph_node_QMARK_$$($node$jscomp$241$$)?$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($G__49492__$1_G__49492__$2$$,$APP.$cljs$core$select_keys$$($props__$1$jscomp$8$$,
$APP.$app$common$types$text$paragraph_attrs$$)):$G__49492__$1_G__49492__$2$$;return $APP.$app$common$types$text$is_text_node_QMARK_$$($node$jscomp$241$$)?$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($G__49492__$1_G__49492__$2$$,$APP.$cljs$core$select_keys$$($props__$1$jscomp$8$$,$APP.$app$common$types$text$text_node_attrs$$)):$G__49492__$1_G__49492__$2$$},$content$jscomp$102$$)})}var $G__49494$$=function(){var $G__49495$$=$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$170$$,
$APP.$cljs$core$select_keys$$($props$jscomp$76$$,$app$common$types$shape$basic_extract_props$$));return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$170$$)?$patch_text_props$$($G__49495$$,$props$jscomp$76$$):$G__49495$$}();return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$170$$)?$patch_layout_props$$($G__49494$$,$props$jscomp$76$$):$G__49494$$};
$app$common$types$shape$set_fill_color$$=function($shape$jscomp$171$$,$position$jscomp$18$$,$color$jscomp$21$$,$opacity$jscomp$8$$,$gradient$jscomp$2$$,$image$jscomp$10$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$171$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1634$fills$$,$position$jscomp$18$$],null),function($fill$jscomp$9$$){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($fill$jscomp$9$$,
$APP.$cljs$cst$1746$fill_color$$,$color$jscomp$21$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1747$fill_opacity$$,$opacity$jscomp$8$$,$APP.$cljs$cst$1748$fill_color_gradient$$,$gradient$jscomp$2$$,$APP.$cljs$cst$1632$fill_image$$,$image$jscomp$10$$])))})};
$app$common$types$shape$attach_fill_color$$=function($shape$jscomp$172$$,$position$jscomp$19$$,$ref_id$jscomp$3$$,$ref_file$jscomp$2$$){return $APP.$app$common$data$update_in_when$$($shape$jscomp$172$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1634$fills$$,$position$jscomp$19$$],null),function($fill$jscomp$10$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($fill$jscomp$10$$,
$APP.$cljs$cst$1640$fill_color_ref_file$$,$ref_file$jscomp$2$$),$APP.$cljs$cst$1745$fill_color_ref_id$$,$ref_id$jscomp$3$$)})};
$app$common$types$shape$detach_fill_color$$=function($shape$jscomp$173$$,$position$jscomp$20$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape$jscomp$173$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1634$fills$$,$position$jscomp$20$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1745$fill_color_ref_id$$,$APP.$cljs$cst$1640$fill_color_ref_file$$]))};
$app$common$types$shape$set_stroke_color$$=function($shape$jscomp$174$$,$position$jscomp$21$$,$color$jscomp$22$$,$opacity$jscomp$9$$,$gradient$jscomp$3$$,$image$jscomp$11$$){return $APP.$app$common$data$update_in_when$$($shape$jscomp$174$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$,$position$jscomp$21$$],null),function($stroke$jscomp$2$$){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($stroke$jscomp$2$$,
$APP.$cljs$cst$1739$stroke_color$$,$color$jscomp$22$$),$APP.$cljs$cst$1740$stroke_opacity$$,$opacity$jscomp$9$$),$APP.$cljs$cst$1741$stroke_color_gradient$$,$gradient$jscomp$3$$),$APP.$cljs$cst$1635$stroke_image$$,$image$jscomp$11$$))})};
$app$common$types$shape$attach_stroke_color$$=function($shape$jscomp$175$$,$position$jscomp$22$$,$ref_id$jscomp$4$$,$ref_file$jscomp$3$$){return $APP.$app$common$data$update_in_when$$($shape$jscomp$175$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$,$position$jscomp$22$$],null),function($stroke$jscomp$3$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($stroke$jscomp$3$$,
$APP.$cljs$cst$1742$stroke_color_ref_id$$,$ref_id$jscomp$4$$),$APP.$cljs$cst$1641$stroke_color_ref_file$$,$ref_file$jscomp$3$$)})};
$app$common$types$shape$detach_stroke_color$$=function($shape$jscomp$176$$,$position$jscomp$23$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape$jscomp$176$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$,$position$jscomp$23$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1742$stroke_color_ref_id$$,$APP.$cljs$cst$1641$stroke_color_ref_file$$]))};
$app$common$types$shape$set_shadow_color$$=function($shape$jscomp$177$$,$position$jscomp$24$$,$color$jscomp$23$$,$opacity$jscomp$10$$,$gradient$jscomp$4$$){return $APP.$app$common$data$update_in_when$$($shape$jscomp$177$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1654$shadow$$,$position$jscomp$24$$,$APP.$cljs$cst$1298$color$$],null),function($shadow_color$$){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shadow_color$$,
$APP.$cljs$cst$1298$color$$,$color$jscomp$23$$),$APP.$cljs$cst$1734$opacity$$,$opacity$jscomp$10$$),$APP.$cljs$cst$1724$gradient$$,$gradient$jscomp$4$$))})};
$app$common$types$shape$attach_shadow_color$$=function($shape$jscomp$178$$,$position$jscomp$25$$,$ref_id$jscomp$5$$,$ref_file$jscomp$4$$){return $APP.$app$common$data$update_in_when$$($shape$jscomp$178$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1654$shadow$$,$position$jscomp$25$$,$APP.$cljs$cst$1298$color$$],null),function($color$jscomp$24$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$24$$,
$APP.$cljs$cst$1735$ref_id$$,$ref_id$jscomp$5$$),$APP.$cljs$cst$1736$ref_file$$,$ref_file$jscomp$4$$)})};
$app$common$types$shape$detach_shadow_color$$=function($shape$jscomp$179$$,$position$jscomp$26$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape$jscomp$179$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1654$shadow$$,$position$jscomp$26$$,$APP.$cljs$cst$1298$color$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1735$ref_id$$,
$APP.$cljs$cst$1736$ref_file$$]))};
$app$common$types$shape$set_grid_color$$=function($shape$jscomp$180$$,$position$jscomp$27$$,$color$jscomp$25$$,$opacity$jscomp$11$$,$gradient$jscomp$5$$){return $APP.$app$common$data$update_in_when$$($shape$jscomp$180$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2050$grids$$,$position$jscomp$27$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1298$color$$],null),function($grid_color$$){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($grid_color$$,$APP.$cljs$cst$1298$color$$,
$color$jscomp$25$$),$APP.$cljs$cst$1734$opacity$$,$opacity$jscomp$11$$),$APP.$cljs$cst$1724$gradient$$,$gradient$jscomp$5$$))})};
$app$common$types$shape$attach_grid_color$$=function($shape$jscomp$181$$,$position$jscomp$28$$,$ref_id$jscomp$6$$,$ref_file$jscomp$5$$){return $APP.$app$common$data$update_in_when$$($shape$jscomp$181$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2050$grids$$,$position$jscomp$28$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1298$color$$],null),function($color$jscomp$26$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$26$$,
$APP.$cljs$cst$1735$ref_id$$,$ref_id$jscomp$6$$),$APP.$cljs$cst$1736$ref_file$$,$ref_file$jscomp$5$$)})};
$app$common$types$shape$detach_grid_color$$=function($shape$jscomp$182$$,$position$jscomp$29$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape$jscomp$182$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2050$grids$$,$position$jscomp$29$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$1298$color$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1735$ref_id$$,
$APP.$cljs$cst$1736$ref_file$$]))};
$app$common$types$shape$process_shape_colors$$=function($$__$1$jscomp$6_$__$2$jscomp$1_$__$3_shape$jscomp$183$$,$process_fn$$){function $process_text_node$$($$__$1$jscomp$7_node$jscomp$242$$){$$__$1$jscomp$7_node$jscomp$242$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($process_fill$$,$$__$1$jscomp$7_node$jscomp$242$$,$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($$__$1$jscomp$7_node$jscomp$242$$)));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($process_stroke$$,
$$__$1$jscomp$7_node$jscomp$242$$,$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($$__$1$jscomp$7_node$jscomp$242$$)))}function $process_stroke$$($shape__$1$jscomp$15$$,$G__49542_p__49536_stroke$jscomp$4$$){var $position$jscomp$31$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__49542_p__49536_stroke$jscomp$4$$,0,null);$G__49542_p__49536_stroke$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__49542_p__49536_stroke$jscomp$4$$,
1,null);$G__49542_p__49536_stroke$jscomp$4$$=$APP.$app$common$types$color$stroke__GT_color$$($G__49542_p__49536_stroke$jscomp$4$$);return $process_fn$$.$cljs$core$IFn$_invoke$arity$6$?$process_fn$$.$cljs$core$IFn$_invoke$arity$6$($shape__$1$jscomp$15$$,$position$jscomp$31$$,$G__49542_p__49536_stroke$jscomp$4$$,$app$common$types$shape$set_stroke_color$$,$app$common$types$shape$attach_stroke_color$$,$app$common$types$shape$detach_stroke_color$$):$process_fn$$($shape__$1$jscomp$15$$,$position$jscomp$31$$,
$G__49542_p__49536_stroke$jscomp$4$$,$app$common$types$shape$set_stroke_color$$,$app$common$types$shape$attach_stroke_color$$,$app$common$types$shape$detach_stroke_color$$)}function $process_fill$$($shape__$1$jscomp$14$$,$G__49532_fill$jscomp$11_p__49523$$){var $position$jscomp$30$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__49532_fill$jscomp$11_p__49523$$,0,null);$G__49532_fill$jscomp$11_p__49523$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__49532_fill$jscomp$11_p__49523$$,
1,null);$G__49532_fill$jscomp$11_p__49523$$=$APP.$app$common$types$fills$fill__GT_color$$($G__49532_fill$jscomp$11_p__49523$$);return $process_fn$$.$cljs$core$IFn$_invoke$arity$6$?$process_fn$$.$cljs$core$IFn$_invoke$arity$6$($shape__$1$jscomp$14$$,$position$jscomp$30$$,$G__49532_fill$jscomp$11_p__49523$$,$app$common$types$shape$set_fill_color$$,$app$common$types$shape$attach_fill_color$$,$app$common$types$shape$detach_fill_color$$):$process_fn$$($shape__$1$jscomp$14$$,$position$jscomp$30$$,$G__49532_fill$jscomp$11_p__49523$$,
$app$common$types$shape$set_fill_color$$,$app$common$types$shape$attach_fill_color$$,$app$common$types$shape$detach_fill_color$$)}$$__$1$jscomp$6_$__$2$jscomp$1_$__$3_shape$jscomp$183$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($process_fill$$,$$__$1$jscomp$6_$__$2$jscomp$1_$__$3_shape$jscomp$183$$,$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($$__$1$jscomp$6_$__$2$jscomp$1_$__$3_shape$jscomp$183$$)));
$$__$1$jscomp$6_$__$2$jscomp$1_$__$3_shape$jscomp$183$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($process_stroke$$,$$__$1$jscomp$6_$__$2$jscomp$1_$__$3_shape$jscomp$183$$,$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($$__$1$jscomp$6_$__$2$jscomp$1_$__$3_shape$jscomp$183$$)));$$__$1$jscomp$6_$__$2$jscomp$1_$__$3_shape$jscomp$183$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($shape__$1$jscomp$16$$,
$G__49552_p__49546_shadow__$1$jscomp$3$$){var $position$jscomp$32$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__49552_p__49546_shadow__$1$jscomp$3$$,0,null);$G__49552_p__49546_shadow__$1$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__49552_p__49546_shadow__$1$jscomp$3$$,1,null);$G__49552_p__49546_shadow__$1$jscomp$3$$=$app$common$types$color$shadow__GT_color$$($G__49552_p__49546_shadow__$1$jscomp$3$$);return $process_fn$$.$cljs$core$IFn$_invoke$arity$6$?$process_fn$$.$cljs$core$IFn$_invoke$arity$6$($shape__$1$jscomp$16$$,
$position$jscomp$32$$,$G__49552_p__49546_shadow__$1$jscomp$3$$,$app$common$types$shape$set_shadow_color$$,$app$common$types$shape$attach_shadow_color$$,$app$common$types$shape$detach_shadow_color$$):$process_fn$$($shape__$1$jscomp$16$$,$position$jscomp$32$$,$G__49552_p__49546_shadow__$1$jscomp$3$$,$app$common$types$shape$set_shadow_color$$,$app$common$types$shape$attach_shadow_color$$,$app$common$types$shape$detach_shadow_color$$)},$$__$1$jscomp$6_$__$2$jscomp$1_$__$3_shape$jscomp$183$$,$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($$__$1$jscomp$6_$__$2$jscomp$1_$__$3_shape$jscomp$183$$)));
return function($shape__$1$jscomp$18$$){var $content$jscomp$103$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$18$$),$new_content$jscomp$1$$=$APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$02$$($process_text_node$$,$content$jscomp$103$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$103$$,$new_content$jscomp$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$18$$,$APP.$cljs$cst$1637$content$$,
$new_content$jscomp$1$$):$shape__$1$jscomp$18$$}($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($shape__$1$jscomp$17$$,$G__49563_grid$jscomp$1_p__49556$$){var $position$jscomp$33$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__49563_grid$jscomp$1_p__49556$$,0,null);$G__49563_grid$jscomp$1_p__49556$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__49563_grid$jscomp$1_p__49556$$,1,null);$G__49563_grid$jscomp$1_p__49556$$=$app$common$types$color$grid__GT_color$$($G__49563_grid$jscomp$1_p__49556$$);
return $process_fn$$.$cljs$core$IFn$_invoke$arity$6$?$process_fn$$.$cljs$core$IFn$_invoke$arity$6$($shape__$1$jscomp$17$$,$position$jscomp$33$$,$G__49563_grid$jscomp$1_p__49556$$,$app$common$types$shape$set_grid_color$$,$app$common$types$shape$attach_grid_color$$,$app$common$types$shape$detach_grid_color$$):$process_fn$$($shape__$1$jscomp$17$$,$position$jscomp$33$$,$G__49563_grid$jscomp$1_p__49556$$,$app$common$types$shape$set_grid_color$$,$app$common$types$shape$attach_grid_color$$,$app$common$types$shape$detach_grid_color$$)},
$$__$1$jscomp$6_$__$2$jscomp$1_$__$3_shape$jscomp$183$$,$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2050$grids$$.$cljs$core$IFn$_invoke$arity$1$($$__$1$jscomp$6_$__$2$jscomp$1_$__$3_shape$jscomp$183$$))))};
$app$common$types$shape$get_all_colors$$=function($shape$jscomp$184$$){return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$fills$fill__GT_color$$,$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$184$$)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$color$stroke__GT_color$$,$APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$184$$)),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$color$shadow__GT_color$$,$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$184$$)),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$184$$),$APP.$cljs$cst$1606$frame$$)?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$color$grid__GT_color$$,
$APP.$cljs$cst$2050$grids$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$184$$)):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$184$$),$APP.$cljs$cst$1588$text$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($colors$$,$JSCompiler_inline_result$jscomp$815_node$jscomp$244$$){var $JSCompiler_temp_const$jscomp$813$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$;$JSCompiler_inline_result$jscomp$815_node$jscomp$244$$=
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$fills$fill__GT_color$$,$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$815_node$jscomp$244$$)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$color$stroke__GT_color$$,$APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$815_node$jscomp$244$$)));return $JSCompiler_temp_const$jscomp$813$$.call($APP.$cljs$core$concat$$,
$colors$$,$JSCompiler_inline_result$jscomp$815_node$jscomp$244$$)},$APP.$cljs$core$List$EMPTY$$,$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$184$$))):null]))};
$app$common$types$shape$uses_library_color_QMARK_$$=function($all_colors_shape$jscomp$185$$,$library_id$$,$color_id$$){$all_colors_shape$jscomp$185$$=$app$common$types$shape$get_all_colors$$($all_colors_shape$jscomp$185$$);return $APP.$cljs$core$some$$(function($p1__49573_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__49573_SHARP_$$),$color_id$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1736$ref_file$$.$cljs$core$IFn$_invoke$arity$1$($p1__49573_SHARP_$$),
$library_id$$)},$all_colors_shape$jscomp$185$$)};
$app$common$types$shape$uses_library_colors_QMARK_$$=function($all_colors$jscomp$1_shape$jscomp$186$$,$library_id$jscomp$1$$){$all_colors$jscomp$1_shape$jscomp$186$$=$app$common$types$shape$get_all_colors$$($all_colors$jscomp$1_shape$jscomp$186$$);return $APP.$cljs$core$some$$(function($p1__49576_SHARP_$$){return $APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__49576_SHARP_$$)!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1736$ref_file$$.$cljs$core$IFn$_invoke$arity$1$($p1__49576_SHARP_$$),$library_id$jscomp$1$$)},
$all_colors$jscomp$1_shape$jscomp$186$$)};
$app$common$types$page$make_empty_page$$=function($G__49638_id$jscomp$164_p__49636$$){var $background_map__49637__$1$$=$APP.$cljs$core$__destructure_map$$($G__49638_id$jscomp$164_p__49636$$);$G__49638_id$jscomp$164_p__49636$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($background_map__49637__$1$$,$APP.$cljs$cst$266$id$$);var $name$jscomp$191$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($background_map__49637__$1$$,$APP.$cljs$cst$725$name$$);$background_map__49637__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($background_map__49637__$1$$,
$APP.$cljs$cst$2058$background$$);$G__49638_id$jscomp$164_p__49636$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$page$empty_page_data$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$core$truth_$$($G__49638_id$jscomp$164_p__49636$$)?$G__49638_id$jscomp$164_p__49636$$:$APP.$app$common$uuid$next$$()),$APP.$cljs$cst$725$name$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$191$$,"Page 1"));return $APP.$cljs$core$truth_$$($background_map__49637__$1$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__49638_id$jscomp$164_p__49636$$,$APP.$cljs$cst$2058$background$$,$background_map__49637__$1$$):$G__49638_id$jscomp$164_p__49636$$};
$APP.$app$common$types$page$get_frame_flow$$=function($flows$$,$frame_id$jscomp$17$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__49643_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2053$starting_frame$$.$cljs$core$IFn$_invoke$arity$1$($p1__49643_SHARP_$$),$frame_id$jscomp$17$$)},$APP.$cljs$core$vals$$($flows$$))};
$app$common$types$component$resolve_sync_group$$=function($type$jscomp$353$$,$attr$jscomp$20_temp__5825__auto__$jscomp$131$$){$attr$jscomp$20_temp__5825__auto__$jscomp$131$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$component$sync_attrs$$,$attr$jscomp$20_temp__5825__auto__$jscomp$131$$);return $APP.$cljs$core$truth_$$($attr$jscomp$20_temp__5825__auto__$jscomp$131$$)?$APP.$cljs$core$map_QMARK_$$($attr$jscomp$20_temp__5825__auto__$jscomp$131$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$20_temp__5825__auto__$jscomp$131$$,
$type$jscomp$353$$):$attr$jscomp$20_temp__5825__auto__$jscomp$131$$:null};$APP.$app$common$types$component$instance_root_QMARK_$$=function($shape$jscomp$188$$){return $APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$188$$)===!0};$APP.$app$common$types$component$instance_head_QMARK_$$=function($shape$jscomp$189$$){return $APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$189$$)!=null};
$app$common$types$component$subinstance_head_QMARK_$$=function($shape$jscomp$190$$){return $APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$190$$)!=null&&$APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$190$$)==null};
$app$common$types$component$instance_of_QMARK_$$=function($shape$jscomp$192$$,$file_id$jscomp$9$$,$component_id$$){return $APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$192$$)!=null&&$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$192$$)!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$192$$),$component_id$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$192$$),
$file_id$jscomp$9$$)};$APP.$app$common$types$component$is_main_of_QMARK_$$=function($shape_main$$,$shape_inst$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_main$$))};
$APP.$app$common$types$component$main_instance_QMARK_$$=function($shape$jscomp$193$$){return $APP.$cljs$cst$2045$main_instance$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$193$$)===!0};$APP.$app$common$types$component$in_component_copy_QMARK_$$=function($shape$jscomp$194$$){return $APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$194$$)!=null};
$app$common$types$component$in_component_copy_not_head_QMARK_$$=function($shape$jscomp$195$$){return $APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$195$$)!=null&&$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$195$$)==null};$APP.$app$common$types$component$is_variant_QMARK_$$=function($item$jscomp$50$$){return $APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$50$$)!=null};
$APP.$app$common$types$component$is_variant_container_QMARK_$$=function($shape$jscomp$197$$){return $APP.$cljs$cst$2004$is_variant_container$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$197$$)};$app$common$types$component$set_touched_group$$=function($touched$$,$group$jscomp$7$$){return $APP.$cljs$core$truth_$$($group$jscomp$7$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($touched$$)?$touched$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,$group$jscomp$7$$):null};
$app$common$types$component$touched_group_QMARK_$$=function($fexpr__49682_or__5025__auto__$jscomp$inline_5286_shape$jscomp$198$$){$fexpr__49682_or__5025__auto__$jscomp$inline_5286_shape$jscomp$198$$=$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($fexpr__49682_or__5025__auto__$jscomp$inline_5286_shape$jscomp$198$$);$fexpr__49682_or__5025__auto__$jscomp$inline_5286_shape$jscomp$198$$=$APP.$cljs$core$truth_$$($fexpr__49682_or__5025__auto__$jscomp$inline_5286_shape$jscomp$198$$)?$fexpr__49682_or__5025__auto__$jscomp$inline_5286_shape$jscomp$198$$:
$APP.$cljs$core$PersistentHashSet$EMPTY$$;return $fexpr__49682_or__5025__auto__$jscomp$inline_5286_shape$jscomp$198$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__49682_or__5025__auto__$jscomp$inline_5286_shape$jscomp$198$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$3537$shapes_group$$):$fexpr__49682_or__5025__auto__$jscomp$inline_5286_shape$jscomp$198$$($cljs$cst$3537$shapes_group$$)};
$app$common$types$component$swap_slot_QMARK_$$=function($group$jscomp$9$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$core$name$$($group$jscomp$9$$),"swap-slot-")};
$app$common$types$component$normal_touched_groups$$=function($shape$jscomp$199_touched$jscomp$1$$){$shape$jscomp$199_touched$jscomp$1$$=$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$199_touched$jscomp$1$$);return $APP.$cljs$core$empty_QMARK_$$($shape$jscomp$199_touched$jscomp$1$$)?$APP.$cljs$core$PersistentHashSet$EMPTY$$:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$app$common$types$component$xf_COLON_normal_touched$$,
$shape$jscomp$199_touched$jscomp$1$$)};
$APP.$app$common$types$component$get_swap_slot$$=function($group$jscomp$11_shape$jscomp$200$$){$group$jscomp$11_shape$jscomp$200$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$component$swap_slot_QMARK_$$,$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$11_shape$jscomp$200$$));return $APP.$cljs$core$truth_$$($group$jscomp$11_shape$jscomp$200$$)?$cljs$core$parse_uuid$$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$name$$($group$jscomp$11_shape$jscomp$200$$),10)):
null};
$app$common$types$component$set_swap_slot$$=function($shape$jscomp$201$$,$swap_slot$jscomp$1$$){return $swap_slot$jscomp$1$$!=null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$201$$,$APP.$cljs$cst$1626$touched$$,$app$common$types$component$set_touched_group$$,$APP.$cljs$core$truth_$$($swap_slot$jscomp$1$$)?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$(["swap-slot-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($swap_slot$jscomp$1$$)].join("")):null):$shape$jscomp$201$$};
$app$common$types$component$remove_swap_slot$$=function($shape$jscomp$202$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$202$$,$APP.$cljs$cst$1626$touched$$,function($touched$jscomp$2$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__49687_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$core$name$$($p1__49687_SHARP_$$),
"swap-slot-")},$touched$jscomp$2$$))})};
$APP.$app$common$types$component$get_deleted_component_root$$=function($component$jscomp$8$$){return $APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$8$$)!=null?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$8$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$objects$$,$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$8$$)],null)):
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$8$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$objects$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$8$$)],null))};
$app$common$types$component$uses_library_components_QMARK_$$=function($shape$jscomp$203$$,$library_id$jscomp$3$$){return $APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$203$$)!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$203$$),$library_id$jscomp$3$$)};
$app$common$types$component$detach_shape$$=function($shape$jscomp$204$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape$jscomp$204$$,$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1643$component_file$$,$APP.$cljs$cst$2044$component_root$$,$APP.$cljs$cst$2045$main_instance$$,$APP.$cljs$cst$2046$remote_synced$$,$APP.$cljs$cst$2047$shape_ref$$,$APP.$cljs$cst$1626$touched$$]))};
$app$common$types$component$unhead_shape$$=function($shape$jscomp$205$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape$jscomp$205$$,$APP.$cljs$cst$2044$component_root$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1643$component_file$$,$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$cst$2045$main_instance$$]))};
$app$common$types$component$rehead_shape$$=function($shape$jscomp$206$$,$component_file$$,$component_id$jscomp$1$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape$jscomp$206$$,$APP.$cljs$cst$1643$component_file$$,$component_file$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1627$component_id$$,$component_id$jscomp$1$$]))};
$app$common$types$component$diff_components$$=function($comp1$$,$comp2$$){return $APP.$cljs$core$set$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__49700_SHARP_$$){var $val1$jscomp$inline_5289$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($comp1$$,$p1__49700_SHARP_$$),$val2$jscomp$inline_5290$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($comp2$$,$p1__49700_SHARP_$$);return!($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__49700_SHARP_$$,$APP.$cljs$cst$1631$objects$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$component$extract_ids$$($val1$jscomp$inline_5289$$),$app$common$types$component$extract_ids$$($val2$jscomp$inline_5290$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($val1$jscomp$inline_5289$$,$val2$jscomp$inline_5290$$))},$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keys$$($comp1$$),$APP.$cljs$core$keys$$($comp2$$)))))};
$app$common$types$shape_tree$add_shape$$=function($id$jscomp$165$$,$shape$jscomp$209$$,$container$jscomp$2$$,$frame_id$jscomp$18$$,$parent_id$jscomp$20$$,$index$jscomp$206$$,$ignore_touched$$){function $update_parent$$($parent$jscomp$188$$){var $G__49715$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($parent$jscomp$188$$,$APP.$cljs$cst$1614$shapes$$,$update_parent_shapes$$),$APP.$cljs$cst$1614$shapes$$,$APP.$app$common$data$vec_without_nils$$);
return $APP.$app$common$types$component$in_component_copy_QMARK_$$($parent$jscomp$188$$)&&$APP.$cljs$core$not$$($ignore_touched$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__49715$$,$APP.$cljs$cst$2046$remote_synced$$):$G__49715$$}function $update_parent_shapes$$($shapes$jscomp$13_shapes__$1$jscomp$1$$){$shapes$jscomp$13_shapes__$1$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$shapes$jscomp$13_shapes__$1$jscomp$1$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$165$$]),
$shapes$jscomp$13_shapes__$1$jscomp$1$$))?$shapes$jscomp$13_shapes__$1$jscomp$1$$:$index$jscomp$206$$==null?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($shapes$jscomp$13_shapes__$1$jscomp$1$$,$id$jscomp$165$$):$APP.$app$common$data$insert_at_index$$($shapes$jscomp$13_shapes__$1$jscomp$1$$,$index$jscomp$206$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$165$$],null))}return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($container$jscomp$2$$,
$APP.$cljs$cst$1631$objects$$,function($objects$jscomp$130$$,$parent_id__$1$jscomp$1_parent_id__$2$$){$parent_id__$1$jscomp$1_parent_id__$2$$=$APP.$cljs$core$contains_QMARK_$$($objects$jscomp$130$$,$parent_id__$1$jscomp$1_parent_id__$2$$)?$parent_id__$1$jscomp$1_parent_id__$2$$:$APP.$app$common$uuid$zero$$;var $frame_id__$1$jscomp$2$$=$APP.$cljs$core$contains_QMARK_$$($objects$jscomp$130$$,$frame_id$jscomp$18$$)?$frame_id$jscomp$18$$:$APP.$app$common$uuid$zero$$;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$130$$,
$id$jscomp$165$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$209$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id__$1$jscomp$2$$),$APP.$cljs$cst$1619$parent_id$$,$parent_id__$1$jscomp$1_parent_id__$2$$),$APP.$cljs$cst$266$id$$,$id$jscomp$165$$)),$parent_id__$1$jscomp$1_parent_id__$2$$,$update_parent$$)},$APP.$cljs$core$truth_$$($parent_id$jscomp$20$$)?$parent_id$jscomp$20$$:
$frame_id$jscomp$18$$)};$app$common$types$shape_tree$get_shape$$=function($container$jscomp$3$$,$id$jscomp$166$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$3$$),$id$jscomp$166$$)};
$app$common$types$shape_tree$fix_broken_children$$=function($map__49735__$1_p__49734$$,$id$jscomp$167$$){$map__49735__$1_p__49734$$=$APP.$cljs$core$__destructure_map$$($map__49735__$1_p__49734$$);var $objects$jscomp$132$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49735__$1_p__49734$$,$APP.$cljs$cst$1631$objects$$),$contains_QMARK_$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$contains_QMARK_$$,$objects$jscomp$132$$);return $APP.$app$common$data$update_in_when$$($map__49735__$1_p__49734$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$objects$$,$id$jscomp$167$$,$APP.$cljs$cst$1614$shapes$$],null),function($shapes$jscomp$14$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($contains_QMARK_$$),$shapes$jscomp$14$$)})};
$app$common$types$shape_tree$get_root_objects$$=function($objects$jscomp$139$$){return $APP.$app$common$files$helpers$reduce_objects$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$139$$,function($result$jscomp$208$$,$shape$jscomp$212$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$208$$,$shape$jscomp$212$$)})};
$app$common$types$shape_tree$is_shape_over_shape_QMARK_$$=function($JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$,$base_shape_id_layer_order_QMARK_$$,$JSCompiler_temp_const$jscomp$10751_over_shape_id_vec__49776_z_index_b$$,$JSCompiler_inline_result$jscomp$10752_and__5023__auto__$jscomp$inline_5298_bottom_frames_QMARK__id$jscomp$inline_12025$$,$id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$){var $idx_a$jscomp$inline_12021_index_a_parents_a_index$jscomp$inline_12013_vec__49767$jscomp$inline_12011$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$,$base_shape_id_layer_order_QMARK_$$),$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($idx_a$jscomp$inline_12021_index_a_parents_a_index$jscomp$inline_12013_vec__49767$jscomp$inline_12011$$,
0,null);$idx_a$jscomp$inline_12021_index_a_parents_a_index$jscomp$inline_12013_vec__49767$jscomp$inline_12011$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($idx_a$jscomp$inline_12021_index_a_parents_a_index$jscomp$inline_12013_vec__49767$jscomp$inline_12011$$,1,null);$id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$,
$JSCompiler_temp_const$jscomp$10751_over_shape_id_vec__49776_z_index_b$$);var $parents_b$jscomp$inline_12015_parents_b__$1$jscomp$inline_12018$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$,0,null);$id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$,
1,null);$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$=$APP.$cljs$core$cons$$($base_shape_id_layer_order_QMARK_$$,$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$);$parents_b$jscomp$inline_12015_parents_b__$1$jscomp$inline_12018$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$JSCompiler_temp_const$jscomp$10751_over_shape_id_vec__49776_z_index_b$$]),
$parents_b$jscomp$inline_12015_parents_b__$1$jscomp$inline_12018$$);$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($parents_b$jscomp$inline_12015_parents_b__$1$jscomp$inline_12018$$,$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$);
$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$=$APP.$cljs$core$truth_$$($base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$)?$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$:
$APP.$app$common$uuid$zero$$;$idx_a$jscomp$inline_12021_index_a_parents_a_index$jscomp$inline_12013_vec__49767$jscomp$inline_12011$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($idx_a$jscomp$inline_12021_index_a_parents_a_index$jscomp$inline_12013_vec__49767$jscomp$inline_12011$$,$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$);$id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$,$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$);$id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$=new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$,$idx_a$jscomp$inline_12021_index_a_parents_a_index$jscomp$inline_12013_vec__49767$jscomp$inline_12011$$,$id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$],null);$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$,0,null);$idx_a$jscomp$inline_12021_index_a_parents_a_index$jscomp$inline_12013_vec__49767$jscomp$inline_12011$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$,1,null);
$id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$,2,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$,
$base_shape_id_layer_order_QMARK_$$))return $JSCompiler_inline_result$jscomp$10752_and__5023__auto__$jscomp$inline_5298_bottom_frames_QMARK__id$jscomp$inline_12025$$&&$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$,$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$);
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$,$JSCompiler_temp_const$jscomp$10751_over_shape_id_vec__49776_z_index_b$$))return!$JSCompiler_inline_result$jscomp$10752_and__5023__auto__$jscomp$inline_5298_bottom_frames_QMARK__id$jscomp$inline_12025$$||!$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$,
$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$);$base_shape_id_layer_order_QMARK_$$=$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$,$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$);
$APP.$cljs$core$truth_$$($base_shape_id_layer_order_QMARK_$$)?($JSCompiler_temp_const$jscomp$10751_over_shape_id_vec__49776_z_index_b$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$JSCompiler_inline_result$jscomp$10752_and__5023__auto__$jscomp$inline_5298_bottom_frames_QMARK__id$jscomp$inline_12025$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$,
$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$),$APP.$cljs$cst$1614$shapes$$),$idx_a$jscomp$inline_12021_index_a_parents_a_index$jscomp$inline_12013_vec__49767$jscomp$inline_12011$$),$JSCompiler_inline_result$jscomp$10752_and__5023__auto__$jscomp$inline_5298_bottom_frames_QMARK__id$jscomp$inline_12025$$=$app$common$types$shape$layout$layout_z_index$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$,
$JSCompiler_inline_result$jscomp$10752_and__5023__auto__$jscomp$inline_5298_bottom_frames_QMARK__id$jscomp$inline_12025$$)),$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$,
$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$),$APP.$cljs$cst$1614$shapes$$),$id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$),$JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$=$app$common$types$shape$layout$layout_z_index$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$,
$base_id$jscomp$1_base_id$jscomp$inline_12019_id$jscomp$inline_12028_or__5025__auto__$jscomp$inline_12020_parents_a$jscomp$inline_12012_parents_a__$1$jscomp$inline_12017$$)),$JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$10751_over_shape_id_vec__49776_z_index_b$$,[$JSCompiler_inline_result$jscomp$10752_and__5023__auto__$jscomp$inline_5298_bottom_frames_QMARK__id$jscomp$inline_12025$$,
$JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$],null)):$JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,0],null);$JSCompiler_temp_const$jscomp$10751_over_shape_id_vec__49776_z_index_b$$=$JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$;
$JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$10751_over_shape_id_vec__49776_z_index_b$$,0,null);$JSCompiler_temp_const$jscomp$10751_over_shape_id_vec__49776_z_index_b$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$10751_over_shape_id_vec__49776_z_index_b$$,1,null);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$,
$JSCompiler_temp_const$jscomp$10751_over_shape_id_vec__49776_z_index_b$$)&&$APP.$cljs$core$not$$($base_shape_id_layer_order_QMARK_$$)?$JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$=$idx_a$jscomp$inline_12021_index_a_parents_a_index$jscomp$inline_12013_vec__49767$jscomp$inline_12011$$<$id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$:($JSCompiler_inline_result$jscomp$10752_and__5023__auto__$jscomp$inline_5298_bottom_frames_QMARK__id$jscomp$inline_12025$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$,$JSCompiler_temp_const$jscomp$10751_over_shape_id_vec__49776_z_index_b$$),$JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10752_and__5023__auto__$jscomp$inline_5298_bottom_frames_QMARK__id$jscomp$inline_12025$$?
$base_shape_id_layer_order_QMARK_$$:$JSCompiler_inline_result$jscomp$10752_and__5023__auto__$jscomp$inline_5298_bottom_frames_QMARK__id$jscomp$inline_12025$$)?$idx_a$jscomp$inline_12021_index_a_parents_a_index$jscomp$inline_12013_vec__49767$jscomp$inline_12011$$>$id_parents$jscomp$1_idx_b$jscomp$inline_12022_index_b_parents_b_index$jscomp$inline_12016_vec__49770$jscomp$inline_12014_vec__49773$$:$JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$<
$JSCompiler_temp_const$jscomp$10751_over_shape_id_vec__49776_z_index_b$$);return $JSCompiler_inline_result$jscomp$10754_JSCompiler_temp$jscomp$10750_JSCompiler_temp$jscomp$822_objects$jscomp$142_z_index_a$$};$APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objects$jscomp$143$$,$ids$jscomp$23$$){return $APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$143$$,$ids$jscomp$23$$,null)};
$APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$144$$,$ids$jscomp$24$$,$map__49783__$1_p__49782$$){$map__49783__$1_p__49782$$=$APP.$cljs$core$__destructure_map$$($map__49783__$1_p__49782$$);var $bottom_frames_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49783__$1_p__49782$$,$APP.$cljs$cst$2087$bottom_frames_QMARK_$$,!1),$id_parents$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__49779_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__49779_SHARP_$$,$app$common$files$helpers$get_parent_ids_with_index$$($objects$jscomp$144$$,$p1__49779_SHARP_$$)],null)}),$ids$jscomp$24$$);return $APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$02$$(function($id_a$jscomp$1$$,$id_b$jscomp$1$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id_a$jscomp$1$$,
$id_b$jscomp$1$$)?0:$app$common$types$shape_tree$is_shape_over_shape_QMARK_$$($objects$jscomp$144$$,$id_a$jscomp$1$$,$id_b$jscomp$1$$,$bottom_frames_QMARK_$jscomp$1$$,$id_parents$jscomp$2$$)?1:-1},$ids$jscomp$24$$)};$app$common$types$shape_tree$sort_z_index_objects$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objects$jscomp$145$$,$items$jscomp$23$$){return $app$common$types$shape_tree$sort_z_index_objects$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$145$$,$items$jscomp$23$$,null)};
$app$common$types$shape_tree$sort_z_index_objects$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$146$$,$items$jscomp$24$$,$map__49795__$1_p__49794$$){$map__49795__$1_p__49794$$=$APP.$cljs$core$__destructure_map$$($map__49795__$1_p__49794$$);var $bottom_frames_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49795__$1_p__49794$$,$APP.$cljs$cst$2087$bottom_frames_QMARK_$$,!1),$id_parents$jscomp$3$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__49789_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__49789_SHARP_$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__49789_SHARP_$$,$APP.$cljs$cst$266$id$$),$app$common$files$helpers$get_parent_ids_with_index$$($objects$jscomp$146$$,$p1__49789_SHARP_$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__49789_SHARP_$$,$APP.$cljs$cst$266$id$$))],
null)}),$items$jscomp$24$$);return $app$common$data$unstable_sort$cljs$0core$0IFn$0_invoke$0arity$02$$(function($id_a$jscomp$2_obj_a$$,$id_b$jscomp$2_obj_b$$){$id_a$jscomp$2_obj_a$$=$id_a$jscomp$2_obj_a$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id_a$jscomp$2_obj_a$$,$APP.$cljs$cst$266$id$$);$id_b$jscomp$2_obj_b$$=$id_b$jscomp$2_obj_b$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id_b$jscomp$2_obj_b$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id_a$jscomp$2_obj_a$$,
$id_b$jscomp$2_obj_b$$)?0:$app$common$types$shape_tree$is_shape_over_shape_QMARK_$$($objects$jscomp$146$$,$id_a$jscomp$2_obj_a$$,$id_b$jscomp$2_obj_b$$,$bottom_frames_QMARK_$jscomp$2$$,$id_parents$jscomp$3$$)?1:-1},$items$jscomp$24$$)};
$app$common$types$shape_tree$get_frame_by_position$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$148$$,$position$jscomp$36$$,$options$jscomp$444$$){var $frames$jscomp$8_frames__$1_or__5025__auto__$jscomp$389$$=$APP.$app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$148$$,$options$jscomp$444$$);$frames$jscomp$8_frames__$1_or__5025__auto__$jscomp$389$$=$app$common$types$shape_tree$sort_z_index_objects$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$148$$,
$frames$jscomp$8_frames__$1_or__5025__auto__$jscomp$389$$,$options$jscomp$444$$);var $validator$jscomp$34$$=function(){var $or__5025__auto__$jscomp$390$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$444$$,$cljs$cst$47$validator$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$390$$)?$or__5025__auto__$jscomp$390$$:function(){return!0}}();$frames$jscomp$8_frames__$1_or__5025__auto__$jscomp$389$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__49802_SHARP_$$){return $position$jscomp$36$$!=
null&&$APP.$app$common$geom$shapes$intersect$has_point_QMARK_$$($p1__49802_SHARP_$$,$position$jscomp$36$$)&&($validator$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$?$validator$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$($p1__49802_SHARP_$$):$validator$jscomp$34$$($p1__49802_SHARP_$$))},$frames$jscomp$8_frames__$1_or__5025__auto__$jscomp$389$$);return $APP.$cljs$core$truth_$$($frames$jscomp$8_frames__$1_or__5025__auto__$jscomp$389$$)?$frames$jscomp$8_frames__$1_or__5025__auto__$jscomp$389$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$148$$,
$APP.$app$common$uuid$zero$$)};$app$common$types$shape_tree$get_frame_id_by_position$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objects$jscomp$149$$,$position$jscomp$37$$){return $app$common$types$shape_tree$get_frame_id_by_position$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$149$$,$position$jscomp$37$$,null)};
$app$common$types$shape_tree$get_frame_id_by_position$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$150_temp__5825__auto__$jscomp$132$$,$position$jscomp$38$$,$options$jscomp$445$$){$objects$jscomp$150_temp__5825__auto__$jscomp$132$$=$app$common$types$shape_tree$get_frame_by_position$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$150_temp__5825__auto__$jscomp$132$$,$position$jscomp$38$$,$options$jscomp$445$$);return $APP.$cljs$core$truth_$$($objects$jscomp$150_temp__5825__auto__$jscomp$132$$)?
$objects$jscomp$150_temp__5825__auto__$jscomp$132$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$150_temp__5825__auto__$jscomp$132$$,$APP.$cljs$cst$266$id$$):null};
$APP.$app$common$types$shape_tree$get_frames_by_position$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$152$$,$position$jscomp$40$$){return $app$common$types$shape_tree$sort_z_index_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$152$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__49812_SHARP_$$){return $position$jscomp$40$$!=null&&$APP.$app$common$geom$shapes$intersect$has_point_QMARK_$$($p1__49812_SHARP_$$,$position$jscomp$40$$)},$APP.$app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$152$$,
null)))};
$APP.$app$common$types$shape_tree$top_nested_frame$cljs$0core$0IFn$0_invoke$0arity$04$$=function($objects$jscomp$155$$,$position$jscomp$43$$,$excluded$jscomp$1$$,$read_only_QMARK_$$){for(var $frames$jscomp$9_or__5025__auto__$jscomp$391$$=function(){var $G__49832_G__49832__$1$$=$APP.$app$common$types$shape_tree$get_frames_by_position$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$155$$,$position$jscomp$43$$);$G__49832_G__49832__$1$$=$excluded$jscomp$1$$!=null?$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$168_obj$jscomp$173$$){$id$jscomp$168_obj$jscomp$173$$=$id$jscomp$168_obj$jscomp$173$$?.id??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$168_obj$jscomp$173$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$contains_QMARK_$$($excluded$jscomp$1$$,$id$jscomp$168_obj$jscomp$173$$)},$G__49832_G__49832__$1$$):$G__49832_G__49832__$1$$;return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__49815_SHARP_$$){return $APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($p1__49815_SHARP_$$)===!0||$APP.$cljs$cst$1623$blocked$$.$cljs$core$IFn$_invoke$arity$1$($p1__49815_SHARP_$$)===
!0&&$APP.$cljs$core$not$$($read_only_QMARK_$$)},$G__49832_G__49832__$1$$)}(),$frame_set$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__49816_SHARP_$$){return $p1__49816_SHARP_$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__49816_SHARP_$$,$APP.$cljs$cst$266$id$$)}),$frames$jscomp$9_or__5025__auto__$jscomp$391$$),$current_shape$jscomp$1$$=$APP.$cljs$core$first$$($frames$jscomp$9_or__5025__auto__$jscomp$391$$);;){var $child_frame_id$$=
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($current_shape$jscomp$2$$,$frames$jscomp$10$$,$frame_set$jscomp$1$$){return function($p1__49817_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($frame_set$jscomp$1$$,$p1__49817_SHARP_$$)}}($current_shape$jscomp$1$$,$frames$jscomp$9_or__5025__auto__$jscomp$391$$,$frame_set$$),$APP.$cljs$core$reverse$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$jscomp$1$$)));if($child_frame_id$$==null)return $frames$jscomp$9_or__5025__auto__$jscomp$391$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$jscomp$1$$),$APP.$cljs$core$truth_$$($frames$jscomp$9_or__5025__auto__$jscomp$391$$)?$frames$jscomp$9_or__5025__auto__$jscomp$391$$:$APP.$app$common$uuid$zero$$;$current_shape$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$155$$,$child_frame_id$$)}};
$APP.$app$common$types$shape_tree$get_viewer_frames$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objects$jscomp$157$$,$all_frames_QMARK__map__49842__$1_p__49841$$){$all_frames_QMARK__map__49842__$1_p__49841$$=$APP.$cljs$core$__destructure_map$$($all_frames_QMARK__map__49842__$1_p__49841$$);$all_frames_QMARK__map__49842__$1_p__49841$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($all_frames_QMARK__map__49842__$1_p__49841$$,$APP.$cljs$cst$2088$all_frames_QMARK_$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$truth_$$($all_frames_QMARK__map__49842__$1_p__49841$$)?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$identity$$):$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1875$hide_in_viewer$$),$app$common$types$shape_tree$sort_z_index_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$157$$,$APP.$app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$157$$)))};
$app$common$types$shape_tree$start_page_index$$=function($objects$jscomp$158$$){return $APP.$cljs$core$with_meta$$($objects$jscomp$158$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2086$app_DOT_common_DOT_types_DOT_shape_tree_SLASH_index_frames$$,$APP.$app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($objects$jscomp$158$$,null))],null))};
$app$common$types$shape_tree$update_page_index$$=function($objects$jscomp$159$$){return $APP.$cljs$core$with_meta$$($objects$jscomp$159$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2086$app_DOT_common_DOT_types_DOT_shape_tree_SLASH_index_frames$$,$APP.$app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($objects$jscomp$159$$,null))],null))};
$APP.$app$common$types$shape_tree$clone_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($shape$jscomp$214$$,$parent_id$jscomp$22$$,$new_shape__$1_new_shape__$2_objects$jscomp$160$$,$p__49849$$){for(var $map__49850__$1$$=$APP.$cljs$core$__destructure_map$$($p__49849$$),$update_new_shape$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49850__$1$$,$APP.$cljs$cst$2089$update_new_shape$$,function($shape__$1$jscomp$20$$){return $shape__$1$jscomp$20$$}),$update_original_shape$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49850__$1$$,$APP.$cljs$cst$2090$update_original_shape$$,function($shape__$1$jscomp$21$$){return $shape__$1$jscomp$21$$}),$force_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49850__$1$$,$cljs$cst$2091$force_id$$,null),$keep_ids_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49850__$1$$,$APP.$cljs$cst$2092$keep_ids_QMARK_$$,!1),$frame_id$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49850__$1$$,
$APP.$cljs$cst$1607$frame_id$$,null),$dest_objects$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49850__$1$$,$cljs$cst$2093$dest_objects$$,$new_shape__$1_new_shape__$2_objects$jscomp$160$$),$new_id$$=$force_id$$!=null?$force_id$$:$APP.$cljs$core$truth_$$($keep_ids_QMARK_$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$214$$):$APP.$app$common$uuid$next$$(),$frame_id__$1$jscomp$3$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$272$$=$frame_id$jscomp$20$$==
null;return $and__5023__auto__$jscomp$272$$?$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($dest_objects$$,$parent_id$jscomp$22$$):$and__5023__auto__$jscomp$272$$}())?$parent_id$jscomp$22$$:$frame_id$jscomp$20$$==null?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dest_objects$$,$parent_id$jscomp$22$$),$APP.$cljs$cst$1607$frame_id$$,$APP.$app$common$uuid$zero$$):$frame_id$jscomp$20$$,$child_ids$jscomp$1$$=
$APP.$cljs$core$seq$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$214$$)),$new_direct_children$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$new_children$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$updated_children$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){if($APP.$cljs$core$empty_QMARK_$$($child_ids$jscomp$1$$)){var $new_shape$$=function(){var $G__49856__$1_G__49856__$2$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape$jscomp$214$$,$APP.$cljs$cst$266$id$$,
$new_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$parent_id$$,$parent_id$jscomp$22$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id__$1$jscomp$3$$]));$G__49856__$1_G__49856__$2$$=$APP.$cljs$core$with_meta$$($G__49856__$1_G__49856__$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2094$app_DOT_common_DOT_types_DOT_shape_tree_SLASH_old_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$214$$)],null));return $APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$214$$)!=
null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__49856__$1_G__49856__$2$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$new_direct_children$$)):$G__49856__$1_G__49856__$2$$}();$new_shape__$1_new_shape__$2_objects$jscomp$160$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$$)?function(){var $ids_map$jscomp$7$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function(){return function($p1__49844_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2094$app_DOT_common_DOT_types_DOT_shape_tree_SLASH_old_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($p1__49844_SHARP_$$)),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__49844_SHARP_$$)],null)}}($child_ids$jscomp$1$$,$new_direct_children$$,$new_children$$,$updated_children$$,
$new_shape$$,$new_id$$,$frame_id__$1$jscomp$3$$,$p__49849$$,$map__49850__$1$$,$update_new_shape$$,$update_original_shape$$,$force_id$$,$keep_ids_QMARK_$$,$frame_id$jscomp$20$$,$dest_objects$$)),$new_children$$);return $APP.$app$common$types$shape$layout$remap_grid_cells$$($new_shape$$,$ids_map$jscomp$7$$)}():$new_shape$$;$new_shape__$1_new_shape__$2_objects$jscomp$160$$=$update_new_shape$$.$cljs$core$IFn$_invoke$arity$2$?$update_new_shape$$.$cljs$core$IFn$_invoke$arity$2$($new_shape__$1_new_shape__$2_objects$jscomp$160$$,
$shape$jscomp$214$$):$update_new_shape$$($new_shape__$1_new_shape__$2_objects$jscomp$160$$,$shape$jscomp$214$$);var $G__49950_child$jscomp$69_child_id$jscomp$1_new_shapes$jscomp$1_vec__49858$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_shape__$1_new_shape__$2_objects$jscomp$160$$],null),$new_children$$),$G__49952_frame_id_child_new_child_shapes_updated_shape_updated_shapes$$=$update_original_shape$$.$cljs$core$IFn$_invoke$arity$2$?
$update_original_shape$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$214$$,$new_shape__$1_new_shape__$2_objects$jscomp$160$$):$update_original_shape$$($shape$jscomp$214$$,$new_shape__$1_new_shape__$2_objects$jscomp$160$$);$G__49952_frame_id_child_new_child_shapes_updated_shape_updated_shapes$$=$shape$jscomp$214$$===$G__49952_frame_id_child_new_child_shapes_updated_shape_updated_shapes$$?$updated_children$$:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__49952_frame_id_child_new_child_shapes_updated_shape_updated_shapes$$],null),$updated_children$$);return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_shape__$1_new_shape__$2_objects$jscomp$160$$,$G__49950_child$jscomp$69_child_id$jscomp$1_new_shapes$jscomp$1_vec__49858$$,$G__49952_frame_id_child_new_child_shapes_updated_shape_updated_shapes$$],null)}$G__49950_child$jscomp$69_child_id$jscomp$1_new_shapes$jscomp$1_vec__49858$$=
$APP.$cljs$core$first$$($child_ids$jscomp$1$$);$G__49950_child$jscomp$69_child_id$jscomp$1_new_shapes$jscomp$1_vec__49858$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_shape__$1_new_shape__$2_objects$jscomp$160$$,$G__49950_child$jscomp$69_child_id$jscomp$1_new_shapes$jscomp$1_vec__49858$$);$G__49952_frame_id_child_new_child_shapes_updated_shape_updated_shapes$$=$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$214$$)?$new_id$$:$frame_id__$1$jscomp$3$$;
$G__49950_child$jscomp$69_child_id$jscomp$1_new_shapes$jscomp$1_vec__49858$$=$APP.$app$common$types$shape_tree$clone_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__49950_child$jscomp$69_child_id$jscomp$1_new_shapes$jscomp$1_vec__49858$$,$new_id$$,$new_shape__$1_new_shape__$2_objects$jscomp$160$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2089$update_new_shape$$,$update_new_shape$$,$APP.$cljs$cst$2090$update_original_shape$$,$update_original_shape$$,$cljs$cst$2091$force_id$$,
null,$APP.$cljs$cst$2092$keep_ids_QMARK_$$,$keep_ids_QMARK_$$,$APP.$cljs$cst$1607$frame_id$$,$G__49952_frame_id_child_new_child_shapes_updated_shape_updated_shapes$$,$cljs$cst$2093$dest_objects$$,$dest_objects$$]));var $G__49951_new_child$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__49950_child$jscomp$69_child_id$jscomp$1_new_shapes$jscomp$1_vec__49858$$,0,null);$G__49952_frame_id_child_new_child_shapes_updated_shape_updated_shapes$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__49950_child$jscomp$69_child_id$jscomp$1_new_shapes$jscomp$1_vec__49858$$,
1,null);var $G__49953_updated_child_shapes$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__49950_child$jscomp$69_child_id$jscomp$1_new_shapes$jscomp$1_vec__49858$$,2,null);$G__49950_child$jscomp$69_child_id$jscomp$1_new_shapes$jscomp$1_vec__49858$$=$APP.$cljs$core$next$$($child_ids$jscomp$1$$);$G__49951_new_child$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($new_direct_children$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$G__49951_new_child$jscomp$2$$],null));$G__49952_frame_id_child_new_child_shapes_updated_shape_updated_shapes$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($new_children$$,$G__49952_frame_id_child_new_child_shapes_updated_shape_updated_shapes$$);$G__49953_updated_child_shapes$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($updated_children$$,$G__49953_updated_child_shapes$$);$child_ids$jscomp$1$$=$G__49950_child$jscomp$69_child_id$jscomp$1_new_shapes$jscomp$1_vec__49858$$;$new_direct_children$$=
$G__49951_new_child$jscomp$2$$;$new_children$$=$G__49952_frame_id_child_new_child_shapes_updated_shape_updated_shapes$$;$updated_children$$=$G__49953_updated_child_shapes$$}};
$clojure$core$protocols$datafy$$=function($JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$){var $m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$meta$$($JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$),$APP.$cljs$core$with_meta$$($cljs$cst$2095$clojure_DOT_core_DOT_protocols_SLASH_datafy$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$269$cljs_DOT_analyzer_SLASH_no_resolve$$,!0],null)));if($m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$)$JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$=$m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$):
$m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$($JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$);else if($JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$!=null&&$JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$.$clojure$core$protocols$Datafiable$datafy$arity$1$!=null)$JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$=$JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$.$clojure$core$protocols$Datafiable$datafy$arity$1$($JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$);
else if($m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$=$clojure$core$protocols$datafy$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$==null?null:$JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$)],$m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$!=null)$JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$=$m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$.$cljs$core$IFn$_invoke$arity$1$?
$m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$):$m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$($JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$);else if($m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$=$clojure$core$protocols$datafy$$._,
$m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$!=null)$JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$=$m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$):
$m__5372__auto__$jscomp$inline_5302_m__5374__auto__$jscomp$inline_5301_temp__5823__auto__$jscomp$113$$($JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$);else throw $APP.$cljs$core$missing_protocol$$("Datafiable.datafy",$JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$);return $JSCompiler_temp$jscomp$824_JSCompiler_temp$jscomp$825_o$jscomp$252$$};
$APP.$clojure$datafy$datafy$$=function($x$jscomp$1127$$){var $v$jscomp$531$$=$clojure$core$protocols$datafy$$($x$jscomp$1127$$);return $v$jscomp$531$$===$x$jscomp$1127$$?$v$jscomp$531$$:$v$jscomp$531$$!=null&&($v$jscomp$531$$.$cljs$lang$protocol_mask$partition0$$&262144||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$v$jscomp$531$$.$cljs$core$IWithMeta$$)?$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($v$jscomp$531$$,$cljs$cst$2097$clojure_DOT_datafy_SLASH_obj$$,$x$jscomp$1127$$):$v$jscomp$531$$};
$clojure$datafy$datify_ref$$=function($r$jscomp$99$$){return $APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$_deref$$($r$jscomp$99$$)],null),$APP.$cljs$core$meta$$($r$jscomp$99$$))};
$app$common$types$tokens_lib$valid_QMARK_$$=function($JSCompiler_temp$jscomp$826__$jscomp$1216$$){if($JSCompiler_temp$jscomp$826__$jscomp$1216$$!=null&&$JSCompiler_temp$jscomp$826__$jscomp$1216$$.$app$common$types$tokens_lib$IValidation$valid_QMARK_$arity$1$!=null)$JSCompiler_temp$jscomp$826__$jscomp$1216$$=$JSCompiler_temp$jscomp$826__$jscomp$1216$$.$app$common$types$tokens_lib$IValidation$valid_QMARK_$arity$1$($JSCompiler_temp$jscomp$826__$jscomp$1216$$);else{var $m__5372__auto__$jscomp$inline_5306_m__5374__auto__$jscomp$inline_5305$$=
$app$common$types$tokens_lib$valid_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$826__$jscomp$1216$$==null?null:$JSCompiler_temp$jscomp$826__$jscomp$1216$$)];if($m__5372__auto__$jscomp$inline_5306_m__5374__auto__$jscomp$inline_5305$$!=null)$JSCompiler_temp$jscomp$826__$jscomp$1216$$=$m__5372__auto__$jscomp$inline_5306_m__5374__auto__$jscomp$inline_5305$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5306_m__5374__auto__$jscomp$inline_5305$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$826__$jscomp$1216$$):
$m__5372__auto__$jscomp$inline_5306_m__5374__auto__$jscomp$inline_5305$$($JSCompiler_temp$jscomp$826__$jscomp$1216$$);else if($m__5372__auto__$jscomp$inline_5306_m__5374__auto__$jscomp$inline_5305$$=$app$common$types$tokens_lib$valid_QMARK_$$._,$m__5372__auto__$jscomp$inline_5306_m__5374__auto__$jscomp$inline_5305$$!=null)$JSCompiler_temp$jscomp$826__$jscomp$1216$$=$m__5372__auto__$jscomp$inline_5306_m__5374__auto__$jscomp$inline_5305$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5306_m__5374__auto__$jscomp$inline_5305$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$826__$jscomp$1216$$):
$m__5372__auto__$jscomp$inline_5306_m__5374__auto__$jscomp$inline_5305$$($JSCompiler_temp$jscomp$826__$jscomp$1216$$);else throw $APP.$cljs$core$missing_protocol$$("IValidation.valid?",$JSCompiler_temp$jscomp$826__$jscomp$1216$$);}return $JSCompiler_temp$jscomp$826__$jscomp$1216$$};
$APP.$app$common$types$tokens_lib$get_id$$=function($JSCompiler_temp$jscomp$827__$jscomp$1220$$){if($JSCompiler_temp$jscomp$827__$jscomp$1220$$!=null&&$JSCompiler_temp$jscomp$827__$jscomp$1220$$.$app$common$types$tokens_lib$INamedItem$get_id$arity$1$!=null)$JSCompiler_temp$jscomp$827__$jscomp$1220$$=$JSCompiler_temp$jscomp$827__$jscomp$1220$$.id;else{var $m__5372__auto__$jscomp$inline_5310_m__5374__auto__$jscomp$inline_5309$$=$APP.$app$common$types$tokens_lib$get_id$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$827__$jscomp$1220$$==
null?null:$JSCompiler_temp$jscomp$827__$jscomp$1220$$)];if($m__5372__auto__$jscomp$inline_5310_m__5374__auto__$jscomp$inline_5309$$!=null)$JSCompiler_temp$jscomp$827__$jscomp$1220$$=$m__5372__auto__$jscomp$inline_5310_m__5374__auto__$jscomp$inline_5309$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5310_m__5374__auto__$jscomp$inline_5309$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$827__$jscomp$1220$$):$m__5372__auto__$jscomp$inline_5310_m__5374__auto__$jscomp$inline_5309$$($JSCompiler_temp$jscomp$827__$jscomp$1220$$);
else if($m__5372__auto__$jscomp$inline_5310_m__5374__auto__$jscomp$inline_5309$$=$APP.$app$common$types$tokens_lib$get_id$$._,$m__5372__auto__$jscomp$inline_5310_m__5374__auto__$jscomp$inline_5309$$!=null)$JSCompiler_temp$jscomp$827__$jscomp$1220$$=$m__5372__auto__$jscomp$inline_5310_m__5374__auto__$jscomp$inline_5309$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5310_m__5374__auto__$jscomp$inline_5309$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$827__$jscomp$1220$$):
$m__5372__auto__$jscomp$inline_5310_m__5374__auto__$jscomp$inline_5309$$($JSCompiler_temp$jscomp$827__$jscomp$1220$$);else throw $APP.$cljs$core$missing_protocol$$("INamedItem.get-id",$JSCompiler_temp$jscomp$827__$jscomp$1220$$);}return $JSCompiler_temp$jscomp$827__$jscomp$1220$$};
$APP.$app$common$types$tokens_lib$get_name$$=function($JSCompiler_temp$jscomp$828__$jscomp$1222$$){if($JSCompiler_temp$jscomp$828__$jscomp$1222$$!=null&&$JSCompiler_temp$jscomp$828__$jscomp$1222$$.$app$common$types$tokens_lib$INamedItem$get_name$arity$1$!=null)$JSCompiler_temp$jscomp$828__$jscomp$1222$$=$JSCompiler_temp$jscomp$828__$jscomp$1222$$.name;else{var $m__5372__auto__$jscomp$inline_5314_m__5374__auto__$jscomp$inline_5313$$=$APP.$app$common$types$tokens_lib$get_name$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$828__$jscomp$1222$$==
null?null:$JSCompiler_temp$jscomp$828__$jscomp$1222$$)];if($m__5372__auto__$jscomp$inline_5314_m__5374__auto__$jscomp$inline_5313$$!=null)$JSCompiler_temp$jscomp$828__$jscomp$1222$$=$m__5372__auto__$jscomp$inline_5314_m__5374__auto__$jscomp$inline_5313$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5314_m__5374__auto__$jscomp$inline_5313$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$828__$jscomp$1222$$):$m__5372__auto__$jscomp$inline_5314_m__5374__auto__$jscomp$inline_5313$$($JSCompiler_temp$jscomp$828__$jscomp$1222$$);
else if($m__5372__auto__$jscomp$inline_5314_m__5374__auto__$jscomp$inline_5313$$=$APP.$app$common$types$tokens_lib$get_name$$._,$m__5372__auto__$jscomp$inline_5314_m__5374__auto__$jscomp$inline_5313$$!=null)$JSCompiler_temp$jscomp$828__$jscomp$1222$$=$m__5372__auto__$jscomp$inline_5314_m__5374__auto__$jscomp$inline_5313$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5314_m__5374__auto__$jscomp$inline_5313$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$828__$jscomp$1222$$):
$m__5372__auto__$jscomp$inline_5314_m__5374__auto__$jscomp$inline_5313$$($JSCompiler_temp$jscomp$828__$jscomp$1222$$);else throw $APP.$cljs$core$missing_protocol$$("INamedItem.get-name",$JSCompiler_temp$jscomp$828__$jscomp$1222$$);}return $JSCompiler_temp$jscomp$828__$jscomp$1222$$};
$APP.$app$common$types$tokens_lib$get_description$$=function($JSCompiler_temp$jscomp$829__$jscomp$1224$$){if($JSCompiler_temp$jscomp$829__$jscomp$1224$$!=null&&$JSCompiler_temp$jscomp$829__$jscomp$1224$$.$app$common$types$tokens_lib$INamedItem$get_description$arity$1$!=null)$JSCompiler_temp$jscomp$829__$jscomp$1224$$=$JSCompiler_temp$jscomp$829__$jscomp$1224$$.description;else{var $m__5372__auto__$jscomp$inline_5318_m__5374__auto__$jscomp$inline_5317$$=$APP.$app$common$types$tokens_lib$get_description$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$829__$jscomp$1224$$==
null?null:$JSCompiler_temp$jscomp$829__$jscomp$1224$$)];if($m__5372__auto__$jscomp$inline_5318_m__5374__auto__$jscomp$inline_5317$$!=null)$JSCompiler_temp$jscomp$829__$jscomp$1224$$=$m__5372__auto__$jscomp$inline_5318_m__5374__auto__$jscomp$inline_5317$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5318_m__5374__auto__$jscomp$inline_5317$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$829__$jscomp$1224$$):$m__5372__auto__$jscomp$inline_5318_m__5374__auto__$jscomp$inline_5317$$($JSCompiler_temp$jscomp$829__$jscomp$1224$$);
else if($m__5372__auto__$jscomp$inline_5318_m__5374__auto__$jscomp$inline_5317$$=$APP.$app$common$types$tokens_lib$get_description$$._,$m__5372__auto__$jscomp$inline_5318_m__5374__auto__$jscomp$inline_5317$$!=null)$JSCompiler_temp$jscomp$829__$jscomp$1224$$=$m__5372__auto__$jscomp$inline_5318_m__5374__auto__$jscomp$inline_5317$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5318_m__5374__auto__$jscomp$inline_5317$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$829__$jscomp$1224$$):
$m__5372__auto__$jscomp$inline_5318_m__5374__auto__$jscomp$inline_5317$$($JSCompiler_temp$jscomp$829__$jscomp$1224$$);else throw $APP.$cljs$core$missing_protocol$$("INamedItem.get-description",$JSCompiler_temp$jscomp$829__$jscomp$1224$$);}return $JSCompiler_temp$jscomp$829__$jscomp$1224$$};
$APP.$app$common$types$tokens_lib$rename$$=function($JSCompiler_temp$jscomp$830__$jscomp$1228$$,$new_name$jscomp$2$$){if($JSCompiler_temp$jscomp$830__$jscomp$1228$$!=null&&$JSCompiler_temp$jscomp$830__$jscomp$1228$$.$app$common$types$tokens_lib$INamedItem$rename$arity$2$!=null)$JSCompiler_temp$jscomp$830__$jscomp$1228$$=$JSCompiler_temp$jscomp$830__$jscomp$1228$$.$app$common$types$tokens_lib$INamedItem$rename$arity$2$($JSCompiler_temp$jscomp$830__$jscomp$1228$$,$new_name$jscomp$2$$);else{var $m__5372__auto__$jscomp$inline_5323_m__5374__auto__$jscomp$inline_5322$$=
$APP.$app$common$types$tokens_lib$rename$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$830__$jscomp$1228$$==null?null:$JSCompiler_temp$jscomp$830__$jscomp$1228$$)];if($m__5372__auto__$jscomp$inline_5323_m__5374__auto__$jscomp$inline_5322$$!=null)$JSCompiler_temp$jscomp$830__$jscomp$1228$$=$m__5372__auto__$jscomp$inline_5323_m__5374__auto__$jscomp$inline_5322$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5323_m__5374__auto__$jscomp$inline_5322$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$830__$jscomp$1228$$,
$new_name$jscomp$2$$):$m__5372__auto__$jscomp$inline_5323_m__5374__auto__$jscomp$inline_5322$$($JSCompiler_temp$jscomp$830__$jscomp$1228$$,$new_name$jscomp$2$$);else if($m__5372__auto__$jscomp$inline_5323_m__5374__auto__$jscomp$inline_5322$$=$APP.$app$common$types$tokens_lib$rename$$._,$m__5372__auto__$jscomp$inline_5323_m__5374__auto__$jscomp$inline_5322$$!=null)$JSCompiler_temp$jscomp$830__$jscomp$1228$$=$m__5372__auto__$jscomp$inline_5323_m__5374__auto__$jscomp$inline_5322$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5323_m__5374__auto__$jscomp$inline_5322$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$830__$jscomp$1228$$,$new_name$jscomp$2$$):$m__5372__auto__$jscomp$inline_5323_m__5374__auto__$jscomp$inline_5322$$($JSCompiler_temp$jscomp$830__$jscomp$1228$$,$new_name$jscomp$2$$);else throw $APP.$cljs$core$missing_protocol$$("INamedItem.rename",$JSCompiler_temp$jscomp$830__$jscomp$1228$$);}return $JSCompiler_temp$jscomp$830__$jscomp$1228$$};
$APP.$app$common$types$tokens_lib$reid$$=function($JSCompiler_temp$jscomp$831__$jscomp$1230$$){var $new_id$jscomp$3$$=$APP.$app$common$uuid$next$$();if($JSCompiler_temp$jscomp$831__$jscomp$1230$$!=null&&$JSCompiler_temp$jscomp$831__$jscomp$1230$$.$app$common$types$tokens_lib$INamedItem$reid$arity$2$!=null)$JSCompiler_temp$jscomp$831__$jscomp$1230$$=$JSCompiler_temp$jscomp$831__$jscomp$1230$$.$app$common$types$tokens_lib$INamedItem$reid$arity$2$($JSCompiler_temp$jscomp$831__$jscomp$1230$$,$new_id$jscomp$3$$);
else{var $m__5372__auto__$jscomp$inline_5328_m__5374__auto__$jscomp$inline_5327$$=$APP.$app$common$types$tokens_lib$reid$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$831__$jscomp$1230$$==null?null:$JSCompiler_temp$jscomp$831__$jscomp$1230$$)];if($m__5372__auto__$jscomp$inline_5328_m__5374__auto__$jscomp$inline_5327$$!=null)$JSCompiler_temp$jscomp$831__$jscomp$1230$$=$m__5372__auto__$jscomp$inline_5328_m__5374__auto__$jscomp$inline_5327$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5328_m__5374__auto__$jscomp$inline_5327$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$831__$jscomp$1230$$,
$new_id$jscomp$3$$):$m__5372__auto__$jscomp$inline_5328_m__5374__auto__$jscomp$inline_5327$$($JSCompiler_temp$jscomp$831__$jscomp$1230$$,$new_id$jscomp$3$$);else if($m__5372__auto__$jscomp$inline_5328_m__5374__auto__$jscomp$inline_5327$$=$APP.$app$common$types$tokens_lib$reid$$._,$m__5372__auto__$jscomp$inline_5328_m__5374__auto__$jscomp$inline_5327$$!=null)$JSCompiler_temp$jscomp$831__$jscomp$1230$$=$m__5372__auto__$jscomp$inline_5328_m__5374__auto__$jscomp$inline_5327$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5328_m__5374__auto__$jscomp$inline_5327$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$831__$jscomp$1230$$,$new_id$jscomp$3$$):$m__5372__auto__$jscomp$inline_5328_m__5374__auto__$jscomp$inline_5327$$($JSCompiler_temp$jscomp$831__$jscomp$1230$$,$new_id$jscomp$3$$);else throw $APP.$cljs$core$missing_protocol$$("INamedItem.reid",$JSCompiler_temp$jscomp$831__$jscomp$1230$$);}return $JSCompiler_temp$jscomp$831__$jscomp$1230$$};
$app$common$types$tokens_lib$Token$$=function($id$jscomp$169$$,$name$jscomp$192$$,$type$jscomp$354$$,$value$jscomp$441$$,$description$jscomp$5$$,$modified_at$$,$__meta$jscomp$19$$,$__extmap$jscomp$19$$,$__hash$jscomp$78$$){this.id=$id$jscomp$169$$;this.name=$name$jscomp$192$$;this.type=$type$jscomp$354$$;this.value=$value$jscomp$441$$;this.description=$description$jscomp$5$$;this.$modified_at$=$modified_at$$;this.$__meta$=$__meta$jscomp$19$$;this.$__extmap$=$__extmap$jscomp$19$$;this.$__hash$=$__hash$jscomp$78$$;
this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$app$common$types$tokens_lib$map__GT_Token$$=function($G__49408$$){var $G__49440$jscomp$inline_5330_extmap__5365__auto__$jscomp$19$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__49408$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$936$description$$,$APP.$cljs$cst$1737$modified_at$$]));$G__49440$jscomp$inline_5330_extmap__5365__auto__$jscomp$19$$=
$APP.$cljs$core$record_QMARK_$$($G__49408$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$G__49440$jscomp$inline_5330_extmap__5365__auto__$jscomp$19$$):$G__49440$jscomp$inline_5330_extmap__5365__auto__$jscomp$19$$;return new $app$common$types$tokens_lib$Token$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__49408$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($G__49408$$),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__49408$$),
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($G__49408$$),$APP.$cljs$cst$936$description$$.$cljs$core$IFn$_invoke$arity$1$($G__49408$$),$APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($G__49408$$),null,$APP.$cljs$core$not_empty$$($G__49440$jscomp$inline_5330_extmap__5365__auto__$jscomp$19$$),null)};$APP.$app$common$types$tokens_lib$token_QMARK_$$=function($o$jscomp$254$$){return $o$jscomp$254$$ instanceof $app$common$types$tokens_lib$Token$$};
$app$common$types$tokens_lib$make_token$$=function($var_args$jscomp$1003$$){for(var $args__5755__auto__$jscomp$155$$=[],$len__5749__auto___50168$$=arguments.length,$i__5750__auto___50169$$=0;;)if($i__5750__auto___50169$$<$len__5749__auto___50168$$)$args__5755__auto__$jscomp$155$$.push(arguments[$i__5750__auto___50169$$]),$i__5750__auto___50169$$+=1;else break;return $APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$155$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$155$$.slice(0),
0,null):null)};
$APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($attrs$jscomp$15_p__49452$$){$attrs$jscomp$15_p__49452$$=$APP.$cljs$core$__destructure_map$$($attrs$jscomp$15_p__49452$$);return $app$common$types$tokens_lib$map__GT_Token$$($app$common$types$tokens_lib$check_token_attrs$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$15_p__49452$$,$APP.$cljs$cst$266$id$$,
function($p1__49445_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__49445_SHARP_$$)?$p1__49445_SHARP_$$:$APP.$app$common$uuid$next$$()}),$APP.$cljs$cst$1737$modified_at$$,function($p1__49446_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__49446_SHARP_$$)?$p1__49446_SHARP_$$:$APP.$app$common$time$now$$()}),$APP.$cljs$cst$936$description$$,$APP.$app$common$data$nilv$$,"")))};
$APP.$app$common$types$tokens_lib$get_token_path$$=function($token$jscomp$44$$){return $APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$44$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,"."]))};
$app$common$types$tokens_lib$add_token_$$=function($JSCompiler_temp$jscomp$832__$jscomp$1245$$,$token$jscomp$47$$){if($JSCompiler_temp$jscomp$832__$jscomp$1245$$!=null&&$JSCompiler_temp$jscomp$832__$jscomp$1245$$.$app$common$types$tokens_lib$ITokenSet$add_token_$arity$2$!=null)$JSCompiler_temp$jscomp$832__$jscomp$1245$$=$JSCompiler_temp$jscomp$832__$jscomp$1245$$.$app$common$types$tokens_lib$ITokenSet$add_token_$arity$2$($JSCompiler_temp$jscomp$832__$jscomp$1245$$,$token$jscomp$47$$);else{var $m__5372__auto__$jscomp$inline_5335_m__5374__auto__$jscomp$inline_5334$$=
$app$common$types$tokens_lib$add_token_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$832__$jscomp$1245$$==null?null:$JSCompiler_temp$jscomp$832__$jscomp$1245$$)];if($m__5372__auto__$jscomp$inline_5335_m__5374__auto__$jscomp$inline_5334$$!=null)$JSCompiler_temp$jscomp$832__$jscomp$1245$$=$m__5372__auto__$jscomp$inline_5335_m__5374__auto__$jscomp$inline_5334$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5335_m__5374__auto__$jscomp$inline_5334$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$832__$jscomp$1245$$,
$token$jscomp$47$$):$m__5372__auto__$jscomp$inline_5335_m__5374__auto__$jscomp$inline_5334$$($JSCompiler_temp$jscomp$832__$jscomp$1245$$,$token$jscomp$47$$);else if($m__5372__auto__$jscomp$inline_5335_m__5374__auto__$jscomp$inline_5334$$=$app$common$types$tokens_lib$add_token_$$._,$m__5372__auto__$jscomp$inline_5335_m__5374__auto__$jscomp$inline_5334$$!=null)$JSCompiler_temp$jscomp$832__$jscomp$1245$$=$m__5372__auto__$jscomp$inline_5335_m__5374__auto__$jscomp$inline_5334$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5335_m__5374__auto__$jscomp$inline_5334$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$832__$jscomp$1245$$,$token$jscomp$47$$):$m__5372__auto__$jscomp$inline_5335_m__5374__auto__$jscomp$inline_5334$$($JSCompiler_temp$jscomp$832__$jscomp$1245$$,$token$jscomp$47$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSet.add-token-",$JSCompiler_temp$jscomp$832__$jscomp$1245$$);}return $JSCompiler_temp$jscomp$832__$jscomp$1245$$};
$app$common$types$tokens_lib$update_token_$$=function($JSCompiler_temp$jscomp$833__$jscomp$1247$$,$id$jscomp$172$$,$f$jscomp$780$$){if($JSCompiler_temp$jscomp$833__$jscomp$1247$$!=null&&$JSCompiler_temp$jscomp$833__$jscomp$1247$$.$app$common$types$tokens_lib$ITokenSet$update_token_$arity$3$!=null)$JSCompiler_temp$jscomp$833__$jscomp$1247$$=$JSCompiler_temp$jscomp$833__$jscomp$1247$$.$app$common$types$tokens_lib$ITokenSet$update_token_$arity$3$($JSCompiler_temp$jscomp$833__$jscomp$1247$$,$id$jscomp$172$$,
$f$jscomp$780$$);else{var $m__5372__auto__$jscomp$inline_5341_m__5374__auto__$jscomp$inline_5340$$=$app$common$types$tokens_lib$update_token_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$833__$jscomp$1247$$==null?null:$JSCompiler_temp$jscomp$833__$jscomp$1247$$)];if($m__5372__auto__$jscomp$inline_5341_m__5374__auto__$jscomp$inline_5340$$!=null)$JSCompiler_temp$jscomp$833__$jscomp$1247$$=$m__5372__auto__$jscomp$inline_5341_m__5374__auto__$jscomp$inline_5340$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_5341_m__5374__auto__$jscomp$inline_5340$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$833__$jscomp$1247$$,
$id$jscomp$172$$,$f$jscomp$780$$):$m__5372__auto__$jscomp$inline_5341_m__5374__auto__$jscomp$inline_5340$$($JSCompiler_temp$jscomp$833__$jscomp$1247$$,$id$jscomp$172$$,$f$jscomp$780$$);else if($m__5372__auto__$jscomp$inline_5341_m__5374__auto__$jscomp$inline_5340$$=$app$common$types$tokens_lib$update_token_$$._,$m__5372__auto__$jscomp$inline_5341_m__5374__auto__$jscomp$inline_5340$$!=null)$JSCompiler_temp$jscomp$833__$jscomp$1247$$=$m__5372__auto__$jscomp$inline_5341_m__5374__auto__$jscomp$inline_5340$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_5341_m__5374__auto__$jscomp$inline_5340$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$833__$jscomp$1247$$,$id$jscomp$172$$,$f$jscomp$780$$):$m__5372__auto__$jscomp$inline_5341_m__5374__auto__$jscomp$inline_5340$$($JSCompiler_temp$jscomp$833__$jscomp$1247$$,$id$jscomp$172$$,$f$jscomp$780$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSet.update-token-",$JSCompiler_temp$jscomp$833__$jscomp$1247$$);}return $JSCompiler_temp$jscomp$833__$jscomp$1247$$};
$app$common$types$tokens_lib$delete_token_$$=function($JSCompiler_temp$jscomp$834__$jscomp$1249$$,$id$jscomp$174$$){if($JSCompiler_temp$jscomp$834__$jscomp$1249$$!=null&&$JSCompiler_temp$jscomp$834__$jscomp$1249$$.$app$common$types$tokens_lib$ITokenSet$delete_token_$arity$2$!=null)$JSCompiler_temp$jscomp$834__$jscomp$1249$$=$JSCompiler_temp$jscomp$834__$jscomp$1249$$.$app$common$types$tokens_lib$ITokenSet$delete_token_$arity$2$($JSCompiler_temp$jscomp$834__$jscomp$1249$$,$id$jscomp$174$$);else{var $m__5372__auto__$jscomp$inline_5346_m__5374__auto__$jscomp$inline_5345$$=
$app$common$types$tokens_lib$delete_token_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$834__$jscomp$1249$$==null?null:$JSCompiler_temp$jscomp$834__$jscomp$1249$$)];if($m__5372__auto__$jscomp$inline_5346_m__5374__auto__$jscomp$inline_5345$$!=null)$JSCompiler_temp$jscomp$834__$jscomp$1249$$=$m__5372__auto__$jscomp$inline_5346_m__5374__auto__$jscomp$inline_5345$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5346_m__5374__auto__$jscomp$inline_5345$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$834__$jscomp$1249$$,
$id$jscomp$174$$):$m__5372__auto__$jscomp$inline_5346_m__5374__auto__$jscomp$inline_5345$$($JSCompiler_temp$jscomp$834__$jscomp$1249$$,$id$jscomp$174$$);else if($m__5372__auto__$jscomp$inline_5346_m__5374__auto__$jscomp$inline_5345$$=$app$common$types$tokens_lib$delete_token_$$._,$m__5372__auto__$jscomp$inline_5346_m__5374__auto__$jscomp$inline_5345$$!=null)$JSCompiler_temp$jscomp$834__$jscomp$1249$$=$m__5372__auto__$jscomp$inline_5346_m__5374__auto__$jscomp$inline_5345$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5346_m__5374__auto__$jscomp$inline_5345$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$834__$jscomp$1249$$,$id$jscomp$174$$):$m__5372__auto__$jscomp$inline_5346_m__5374__auto__$jscomp$inline_5345$$($JSCompiler_temp$jscomp$834__$jscomp$1249$$,$id$jscomp$174$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSet.delete-token-",$JSCompiler_temp$jscomp$834__$jscomp$1249$$);}return $JSCompiler_temp$jscomp$834__$jscomp$1249$$};
$app$common$types$tokens_lib$get_token_$$=function($JSCompiler_temp$jscomp$835__$jscomp$1251$$,$id$jscomp$176$$){if($JSCompiler_temp$jscomp$835__$jscomp$1251$$!=null&&$JSCompiler_temp$jscomp$835__$jscomp$1251$$.$app$common$types$tokens_lib$ITokenSet$get_token_$arity$2$!=null)$JSCompiler_temp$jscomp$835__$jscomp$1251$$=$JSCompiler_temp$jscomp$835__$jscomp$1251$$.$app$common$types$tokens_lib$ITokenSet$get_token_$arity$2$($JSCompiler_temp$jscomp$835__$jscomp$1251$$,$id$jscomp$176$$);else{var $m__5372__auto__$jscomp$inline_5351_m__5374__auto__$jscomp$inline_5350$$=
$app$common$types$tokens_lib$get_token_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$835__$jscomp$1251$$==null?null:$JSCompiler_temp$jscomp$835__$jscomp$1251$$)];if($m__5372__auto__$jscomp$inline_5351_m__5374__auto__$jscomp$inline_5350$$!=null)$JSCompiler_temp$jscomp$835__$jscomp$1251$$=$m__5372__auto__$jscomp$inline_5351_m__5374__auto__$jscomp$inline_5350$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5351_m__5374__auto__$jscomp$inline_5350$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$835__$jscomp$1251$$,
$id$jscomp$176$$):$m__5372__auto__$jscomp$inline_5351_m__5374__auto__$jscomp$inline_5350$$($JSCompiler_temp$jscomp$835__$jscomp$1251$$,$id$jscomp$176$$);else if($m__5372__auto__$jscomp$inline_5351_m__5374__auto__$jscomp$inline_5350$$=$app$common$types$tokens_lib$get_token_$$._,$m__5372__auto__$jscomp$inline_5351_m__5374__auto__$jscomp$inline_5350$$!=null)$JSCompiler_temp$jscomp$835__$jscomp$1251$$=$m__5372__auto__$jscomp$inline_5351_m__5374__auto__$jscomp$inline_5350$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5351_m__5374__auto__$jscomp$inline_5350$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$835__$jscomp$1251$$,$id$jscomp$176$$):$m__5372__auto__$jscomp$inline_5351_m__5374__auto__$jscomp$inline_5350$$($JSCompiler_temp$jscomp$835__$jscomp$1251$$,$id$jscomp$176$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSet.get-token-",$JSCompiler_temp$jscomp$835__$jscomp$1251$$);}return $JSCompiler_temp$jscomp$835__$jscomp$1251$$};
$APP.$app$common$types$tokens_lib$get_tokens_$$=function($JSCompiler_temp$jscomp$836__$jscomp$1255$$){if($JSCompiler_temp$jscomp$836__$jscomp$1255$$!=null&&$JSCompiler_temp$jscomp$836__$jscomp$1255$$.$app$common$types$tokens_lib$ITokenSet$get_tokens_$arity$1$!=null)$JSCompiler_temp$jscomp$836__$jscomp$1255$$=$JSCompiler_temp$jscomp$836__$jscomp$1255$$.tokens;else{var $m__5372__auto__$jscomp$inline_5355_m__5374__auto__$jscomp$inline_5354$$=$APP.$app$common$types$tokens_lib$get_tokens_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$836__$jscomp$1255$$==
null?null:$JSCompiler_temp$jscomp$836__$jscomp$1255$$)];if($m__5372__auto__$jscomp$inline_5355_m__5374__auto__$jscomp$inline_5354$$!=null)$JSCompiler_temp$jscomp$836__$jscomp$1255$$=$m__5372__auto__$jscomp$inline_5355_m__5374__auto__$jscomp$inline_5354$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5355_m__5374__auto__$jscomp$inline_5354$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$836__$jscomp$1255$$):$m__5372__auto__$jscomp$inline_5355_m__5374__auto__$jscomp$inline_5354$$($JSCompiler_temp$jscomp$836__$jscomp$1255$$);
else if($m__5372__auto__$jscomp$inline_5355_m__5374__auto__$jscomp$inline_5354$$=$APP.$app$common$types$tokens_lib$get_tokens_$$._,$m__5372__auto__$jscomp$inline_5355_m__5374__auto__$jscomp$inline_5354$$!=null)$JSCompiler_temp$jscomp$836__$jscomp$1255$$=$m__5372__auto__$jscomp$inline_5355_m__5374__auto__$jscomp$inline_5354$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5355_m__5374__auto__$jscomp$inline_5354$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$836__$jscomp$1255$$):
$m__5372__auto__$jscomp$inline_5355_m__5374__auto__$jscomp$inline_5354$$($JSCompiler_temp$jscomp$836__$jscomp$1255$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSet.get-tokens-",$JSCompiler_temp$jscomp$836__$jscomp$1255$$);}return $JSCompiler_temp$jscomp$836__$jscomp$1255$$};
$APP.$app$common$types$tokens_lib$TokenSet$$=function($id$jscomp$179$$,$name$jscomp$198$$,$description$jscomp$9$$,$modified_at$jscomp$4$$,$tokens$jscomp$7$$){this.id=$id$jscomp$179$$;this.name=$name$jscomp$198$$;this.description=$description$jscomp$9$$;this.$modified_at$=$modified_at$jscomp$4$$;this.tokens=$tokens$jscomp$7$$;this.$cljs$lang$protocol_mask$partition0$$=2097152;this.$cljs$lang$protocol_mask$partition1$$=0};
$APP.$app$common$types$tokens_lib$split_set_name$$=function($name$jscomp$200$$){return $APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($name$jscomp$200$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,"/"]))};
$APP.$app$common$types$tokens_lib$join_set_path$$=function($path$jscomp$167$$){return $APP.$app$common$path_names$join_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($path$jscomp$167$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,"/",$APP.$cljs$cst$1998$with_spaces_QMARK_$$,!1]))};$app$common$types$tokens_lib$token_set_QMARK_$$=function($o$jscomp$255$$){return $o$jscomp$255$$ instanceof $APP.$app$common$types$tokens_lib$TokenSet$$};
$app$common$types$tokens_lib$map__GT_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($attrs$jscomp$16_p__49601$$){$attrs$jscomp$16_p__49601$$=$APP.$cljs$core$__destructure_map$$($attrs$jscomp$16_p__49601$$);return new $APP.$app$common$types$tokens_lib$TokenSet$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$16_p__49601$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$16_p__49601$$),$APP.$cljs$cst$936$description$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$16_p__49601$$),
$APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$16_p__49601$$),$APP.$cljs$cst$2100$tokens$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$16_p__49601$$))};
$app$common$types$tokens_lib$make_token_set$$=function($var_args$jscomp$1007$$){for(var $args__5755__auto__$jscomp$157$$=[],$len__5749__auto___50240$$=arguments.length,$i__5750__auto___50241$$=0;;)if($i__5750__auto___50241$$<$len__5749__auto___50240$$)$args__5755__auto__$jscomp$157$$.push(arguments[$i__5750__auto___50241$$]),$i__5750__auto___50241$$+=1;else break;return $APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$157$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$157$$.slice(0),0,null):null)};
$APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($attrs$jscomp$17_p__49607$$){$attrs$jscomp$17_p__49607$$=$APP.$cljs$core$__destructure_map$$($attrs$jscomp$17_p__49607$$);return $app$common$types$tokens_lib$map__GT_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$types$tokens_lib$check_token_set_attrs$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$17_p__49607$$,$APP.$cljs$cst$266$id$$,
function($p1__49603_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__49603_SHARP_$$)?$p1__49603_SHARP_$$:$APP.$app$common$uuid$next$$()}),$APP.$cljs$cst$1737$modified_at$$,function($p1__49604_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__49604_SHARP_$$)?$p1__49604_SHARP_$$:$APP.$app$common$time$now$$()}),$APP.$cljs$cst$2100$tokens$$,function($p1__49605_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$linked$map$empty_linked_map$$,$p1__49605_SHARP_$$)}),$APP.$cljs$cst$936$description$$,
$APP.$app$common$data$nilv$$,""),$APP.$cljs$cst$725$name$$,$APP.$app$common$types$tokens_lib$normalize_set_name$$))]))};$APP.$app$common$types$tokens_lib$normalized_set_name_QMARK_$$=function($name$jscomp$203$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$203$$,$APP.$app$common$types$tokens_lib$normalize_set_name$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$203$$))};
$APP.$app$common$types$tokens_lib$replace_last_path_name$$=function($path$jscomp$168$$,$name$jscomp$204$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$01$$($path$jscomp$168$$)),$name$jscomp$204$$)};$app$common$types$tokens_lib$add_set_path_group_prefix$$=function($group_path_str$$){return["G-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($group_path_str$$)].join("")};
$app$common$types$tokens_lib$set_full_path__GT_set_prefixed_full_path$$=function($full_path$jscomp$1_set_name_set_name_str$jscomp$inline_5360$$){var $set_path$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$tokens_lib$add_set_path_group_prefix$$,$APP.$cljs$core$butlast$$($full_path$jscomp$1_set_name_set_name_str$jscomp$inline_5360$$));$full_path$jscomp$1_set_name_set_name_str$jscomp$inline_5360$$=$APP.$cljs$core$last$$($full_path$jscomp$1_set_name_set_name_str$jscomp$inline_5360$$);
$full_path$jscomp$1_set_name_set_name_str$jscomp$inline_5360$$=["S-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($full_path$jscomp$1_set_name_set_name_str$jscomp$inline_5360$$)].join("");return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($set_path$$,$full_path$jscomp$1_set_name_set_name_str$jscomp$inline_5360$$)};
$app$common$types$tokens_lib$get_set_prefixed_path$$=function($path$jscomp$171_token_set$jscomp$1$$){$path$jscomp$171_token_set$jscomp$1$$=$APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$types$tokens_lib$get_name$$($path$jscomp$171_token_set$jscomp$1$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,"/"]));return $app$common$types$tokens_lib$set_full_path__GT_set_prefixed_full_path$$($path$jscomp$171_token_set$jscomp$1$$)};
$APP.$app$common$types$tokens_lib$tokens_tree$$=function($var_args$jscomp$1008$$){for(var $args__5755__auto__$jscomp$158$$=[],$len__5749__auto___50248$$=arguments.length,$i__5750__auto___50249$$=0;;)if($i__5750__auto___50249$$<$len__5749__auto___50248$$)$args__5755__auto__$jscomp$158$$.push(arguments[$i__5750__auto___50249$$]),$i__5750__auto___50249$$+=1;else break;return $APP.$app$common$types$tokens_lib$tokens_tree$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$158$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$158$$.slice(1),0,null):null)};
$APP.$app$common$types$tokens_lib$tokens_tree$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($tokens$jscomp$9$$,$map__49633__$1_p__49629$$){$map__49633__$1_p__49629$$=$APP.$cljs$core$__destructure_map$$($map__49633__$1_p__49629$$);var $update_token_fn$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49633__$1_p__49629$$,$APP.$cljs$cst$2103$update_token_fn$$,$APP.$cljs$core$identity$$);return $APP.$cljs$core$reduce_kv$$(function($acc$jscomp$100$$,$_$jscomp$1269_path$jscomp$172$$,
$token$jscomp$51$$){$_$jscomp$1269_path$jscomp$172$$=$APP.$app$common$types$tokens_lib$get_token_path$$($token$jscomp$51$$);return $APP.$cljs$core$assoc_in$$($acc$jscomp$100$$,$_$jscomp$1269_path$jscomp$172$$,$update_token_fn$$.$cljs$core$IFn$_invoke$arity$1$?$update_token_fn$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$51$$):$update_token_fn$$($token$jscomp$51$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$tokens$jscomp$9$$)};
$app$common$types$tokens_lib$backtrace_tokens_tree$$=function($tokens$jscomp$10$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$101$$,$p__49639_token$jscomp$52$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49639_token$jscomp$52$$,0,null);$p__49639_token$jscomp$52$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49639_token$jscomp$52$$,1,null);var $path$jscomp$173$$=$APP.$app$common$types$tokens_lib$get_token_path$$($p__49639_token$jscomp$52$$);
return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($acc$jscomp$101$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2104$tokens_tree$$],null),$path$jscomp$173$$),$p__49639_token$jscomp$52$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1723$ids$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p__49639_token$jscomp$52$$)],
null),$p__49639_token$jscomp$52$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$2104$tokens_tree$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1723$ids$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null),$tokens$jscomp$10$$)};
$APP.$app$common$types$tokens_lib$add_set$$=function($JSCompiler_temp$jscomp$845__$jscomp$1272$$,$token_set$jscomp$3$$){if($JSCompiler_temp$jscomp$845__$jscomp$1272$$!=null&&$JSCompiler_temp$jscomp$845__$jscomp$1272$$.$app$common$types$tokens_lib$ITokenSets$add_set$arity$2$!=null)$JSCompiler_temp$jscomp$845__$jscomp$1272$$=$JSCompiler_temp$jscomp$845__$jscomp$1272$$.$app$common$types$tokens_lib$ITokenSets$add_set$arity$2$($JSCompiler_temp$jscomp$845__$jscomp$1272$$,$token_set$jscomp$3$$);else{var $m__5372__auto__$jscomp$inline_5365_m__5374__auto__$jscomp$inline_5364$$=
$APP.$app$common$types$tokens_lib$add_set$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$845__$jscomp$1272$$==null?null:$JSCompiler_temp$jscomp$845__$jscomp$1272$$)];if($m__5372__auto__$jscomp$inline_5365_m__5374__auto__$jscomp$inline_5364$$!=null)$JSCompiler_temp$jscomp$845__$jscomp$1272$$=$m__5372__auto__$jscomp$inline_5365_m__5374__auto__$jscomp$inline_5364$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5365_m__5374__auto__$jscomp$inline_5364$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$845__$jscomp$1272$$,
$token_set$jscomp$3$$):$m__5372__auto__$jscomp$inline_5365_m__5374__auto__$jscomp$inline_5364$$($JSCompiler_temp$jscomp$845__$jscomp$1272$$,$token_set$jscomp$3$$);else if($m__5372__auto__$jscomp$inline_5365_m__5374__auto__$jscomp$inline_5364$$=$APP.$app$common$types$tokens_lib$add_set$$._,$m__5372__auto__$jscomp$inline_5365_m__5374__auto__$jscomp$inline_5364$$!=null)$JSCompiler_temp$jscomp$845__$jscomp$1272$$=$m__5372__auto__$jscomp$inline_5365_m__5374__auto__$jscomp$inline_5364$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5365_m__5374__auto__$jscomp$inline_5364$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$845__$jscomp$1272$$,$token_set$jscomp$3$$):$m__5372__auto__$jscomp$inline_5365_m__5374__auto__$jscomp$inline_5364$$($JSCompiler_temp$jscomp$845__$jscomp$1272$$,$token_set$jscomp$3$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSets.add-set",$JSCompiler_temp$jscomp$845__$jscomp$1272$$);}return $JSCompiler_temp$jscomp$845__$jscomp$1272$$};
$app$common$types$tokens_lib$update_set$$=function($JSCompiler_temp$jscomp$846__$jscomp$1274$$,$id$jscomp$182$$,$f$jscomp$783$$){if($JSCompiler_temp$jscomp$846__$jscomp$1274$$!=null&&$JSCompiler_temp$jscomp$846__$jscomp$1274$$.$app$common$types$tokens_lib$ITokenSets$update_set$arity$3$!=null)$JSCompiler_temp$jscomp$846__$jscomp$1274$$=$JSCompiler_temp$jscomp$846__$jscomp$1274$$.$app$common$types$tokens_lib$ITokenSets$update_set$arity$3$($JSCompiler_temp$jscomp$846__$jscomp$1274$$,$id$jscomp$182$$,
$f$jscomp$783$$);else{var $m__5372__auto__$jscomp$inline_5371_m__5374__auto__$jscomp$inline_5370$$=$app$common$types$tokens_lib$update_set$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$846__$jscomp$1274$$==null?null:$JSCompiler_temp$jscomp$846__$jscomp$1274$$)];if($m__5372__auto__$jscomp$inline_5371_m__5374__auto__$jscomp$inline_5370$$!=null)$JSCompiler_temp$jscomp$846__$jscomp$1274$$=$m__5372__auto__$jscomp$inline_5371_m__5374__auto__$jscomp$inline_5370$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_5371_m__5374__auto__$jscomp$inline_5370$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$846__$jscomp$1274$$,
$id$jscomp$182$$,$f$jscomp$783$$):$m__5372__auto__$jscomp$inline_5371_m__5374__auto__$jscomp$inline_5370$$($JSCompiler_temp$jscomp$846__$jscomp$1274$$,$id$jscomp$182$$,$f$jscomp$783$$);else if($m__5372__auto__$jscomp$inline_5371_m__5374__auto__$jscomp$inline_5370$$=$app$common$types$tokens_lib$update_set$$._,$m__5372__auto__$jscomp$inline_5371_m__5374__auto__$jscomp$inline_5370$$!=null)$JSCompiler_temp$jscomp$846__$jscomp$1274$$=$m__5372__auto__$jscomp$inline_5371_m__5374__auto__$jscomp$inline_5370$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_5371_m__5374__auto__$jscomp$inline_5370$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$846__$jscomp$1274$$,$id$jscomp$182$$,$f$jscomp$783$$):$m__5372__auto__$jscomp$inline_5371_m__5374__auto__$jscomp$inline_5370$$($JSCompiler_temp$jscomp$846__$jscomp$1274$$,$id$jscomp$182$$,$f$jscomp$783$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSets.update-set",$JSCompiler_temp$jscomp$846__$jscomp$1274$$);}return $JSCompiler_temp$jscomp$846__$jscomp$1274$$};
$app$common$types$tokens_lib$delete_set$$=function($JSCompiler_temp$jscomp$847__$jscomp$1276$$,$id$jscomp$184$$){if($JSCompiler_temp$jscomp$847__$jscomp$1276$$!=null&&$JSCompiler_temp$jscomp$847__$jscomp$1276$$.$app$common$types$tokens_lib$ITokenSets$delete_set$arity$2$!=null)$JSCompiler_temp$jscomp$847__$jscomp$1276$$=$JSCompiler_temp$jscomp$847__$jscomp$1276$$.$app$common$types$tokens_lib$ITokenSets$delete_set$arity$2$($JSCompiler_temp$jscomp$847__$jscomp$1276$$,$id$jscomp$184$$);else{var $m__5372__auto__$jscomp$inline_5376_m__5374__auto__$jscomp$inline_5375$$=
$app$common$types$tokens_lib$delete_set$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$847__$jscomp$1276$$==null?null:$JSCompiler_temp$jscomp$847__$jscomp$1276$$)];if($m__5372__auto__$jscomp$inline_5376_m__5374__auto__$jscomp$inline_5375$$!=null)$JSCompiler_temp$jscomp$847__$jscomp$1276$$=$m__5372__auto__$jscomp$inline_5376_m__5374__auto__$jscomp$inline_5375$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5376_m__5374__auto__$jscomp$inline_5375$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$847__$jscomp$1276$$,
$id$jscomp$184$$):$m__5372__auto__$jscomp$inline_5376_m__5374__auto__$jscomp$inline_5375$$($JSCompiler_temp$jscomp$847__$jscomp$1276$$,$id$jscomp$184$$);else if($m__5372__auto__$jscomp$inline_5376_m__5374__auto__$jscomp$inline_5375$$=$app$common$types$tokens_lib$delete_set$$._,$m__5372__auto__$jscomp$inline_5376_m__5374__auto__$jscomp$inline_5375$$!=null)$JSCompiler_temp$jscomp$847__$jscomp$1276$$=$m__5372__auto__$jscomp$inline_5376_m__5374__auto__$jscomp$inline_5375$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5376_m__5374__auto__$jscomp$inline_5375$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$847__$jscomp$1276$$,$id$jscomp$184$$):$m__5372__auto__$jscomp$inline_5376_m__5374__auto__$jscomp$inline_5375$$($JSCompiler_temp$jscomp$847__$jscomp$1276$$,$id$jscomp$184$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSets.delete-set",$JSCompiler_temp$jscomp$847__$jscomp$1276$$);}return $JSCompiler_temp$jscomp$847__$jscomp$1276$$};
$app$common$types$tokens_lib$move_set$$=function($JSCompiler_temp$jscomp$848__$jscomp$1278$$,$from_path$jscomp$1$$,$to_path$jscomp$1$$,$before_path$jscomp$1$$,$before_group_QMARK_$jscomp$1$$){if($JSCompiler_temp$jscomp$848__$jscomp$1278$$!=null&&$JSCompiler_temp$jscomp$848__$jscomp$1278$$.$app$common$types$tokens_lib$ITokenSets$move_set$arity$5$!=null)$JSCompiler_temp$jscomp$848__$jscomp$1278$$=$JSCompiler_temp$jscomp$848__$jscomp$1278$$.$app$common$types$tokens_lib$ITokenSets$move_set$arity$5$($JSCompiler_temp$jscomp$848__$jscomp$1278$$,
$from_path$jscomp$1$$,$to_path$jscomp$1$$,$before_path$jscomp$1$$,$before_group_QMARK_$jscomp$1$$);else{var $m__5372__auto__$jscomp$inline_5384_m__5374__auto__$jscomp$inline_5383$$=$app$common$types$tokens_lib$move_set$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$848__$jscomp$1278$$==null?null:$JSCompiler_temp$jscomp$848__$jscomp$1278$$)];if($m__5372__auto__$jscomp$inline_5384_m__5374__auto__$jscomp$inline_5383$$!=null)$JSCompiler_temp$jscomp$848__$jscomp$1278$$=$m__5372__auto__$jscomp$inline_5384_m__5374__auto__$jscomp$inline_5383$$.$cljs$core$IFn$_invoke$arity$5$?
$m__5372__auto__$jscomp$inline_5384_m__5374__auto__$jscomp$inline_5383$$.$cljs$core$IFn$_invoke$arity$5$($JSCompiler_temp$jscomp$848__$jscomp$1278$$,$from_path$jscomp$1$$,$to_path$jscomp$1$$,$before_path$jscomp$1$$,$before_group_QMARK_$jscomp$1$$):$m__5372__auto__$jscomp$inline_5384_m__5374__auto__$jscomp$inline_5383$$($JSCompiler_temp$jscomp$848__$jscomp$1278$$,$from_path$jscomp$1$$,$to_path$jscomp$1$$,$before_path$jscomp$1$$,$before_group_QMARK_$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_5384_m__5374__auto__$jscomp$inline_5383$$=
$app$common$types$tokens_lib$move_set$$._,$m__5372__auto__$jscomp$inline_5384_m__5374__auto__$jscomp$inline_5383$$!=null)$JSCompiler_temp$jscomp$848__$jscomp$1278$$=$m__5372__auto__$jscomp$inline_5384_m__5374__auto__$jscomp$inline_5383$$.$cljs$core$IFn$_invoke$arity$5$?$m__5372__auto__$jscomp$inline_5384_m__5374__auto__$jscomp$inline_5383$$.$cljs$core$IFn$_invoke$arity$5$($JSCompiler_temp$jscomp$848__$jscomp$1278$$,$from_path$jscomp$1$$,$to_path$jscomp$1$$,$before_path$jscomp$1$$,$before_group_QMARK_$jscomp$1$$):
$m__5372__auto__$jscomp$inline_5384_m__5374__auto__$jscomp$inline_5383$$($JSCompiler_temp$jscomp$848__$jscomp$1278$$,$from_path$jscomp$1$$,$to_path$jscomp$1$$,$before_path$jscomp$1$$,$before_group_QMARK_$jscomp$1$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSets.move-set",$JSCompiler_temp$jscomp$848__$jscomp$1278$$);}return $JSCompiler_temp$jscomp$848__$jscomp$1278$$};
$app$common$types$tokens_lib$move_set_group$$=function($JSCompiler_temp$jscomp$849__$jscomp$1280$$,$from_path$jscomp$3$$,$to_path$jscomp$3$$,$before_path$jscomp$3$$,$before_group_QMARK_$jscomp$3$$){if($JSCompiler_temp$jscomp$849__$jscomp$1280$$!=null&&$JSCompiler_temp$jscomp$849__$jscomp$1280$$.$app$common$types$tokens_lib$ITokenSets$move_set_group$arity$5$!=null)$JSCompiler_temp$jscomp$849__$jscomp$1280$$=$JSCompiler_temp$jscomp$849__$jscomp$1280$$.$app$common$types$tokens_lib$ITokenSets$move_set_group$arity$5$($JSCompiler_temp$jscomp$849__$jscomp$1280$$,
$from_path$jscomp$3$$,$to_path$jscomp$3$$,$before_path$jscomp$3$$,$before_group_QMARK_$jscomp$3$$);else{var $m__5372__auto__$jscomp$inline_5392_m__5374__auto__$jscomp$inline_5391$$=$app$common$types$tokens_lib$move_set_group$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$849__$jscomp$1280$$==null?null:$JSCompiler_temp$jscomp$849__$jscomp$1280$$)];if($m__5372__auto__$jscomp$inline_5392_m__5374__auto__$jscomp$inline_5391$$!=null)$JSCompiler_temp$jscomp$849__$jscomp$1280$$=$m__5372__auto__$jscomp$inline_5392_m__5374__auto__$jscomp$inline_5391$$.$cljs$core$IFn$_invoke$arity$5$?
$m__5372__auto__$jscomp$inline_5392_m__5374__auto__$jscomp$inline_5391$$.$cljs$core$IFn$_invoke$arity$5$($JSCompiler_temp$jscomp$849__$jscomp$1280$$,$from_path$jscomp$3$$,$to_path$jscomp$3$$,$before_path$jscomp$3$$,$before_group_QMARK_$jscomp$3$$):$m__5372__auto__$jscomp$inline_5392_m__5374__auto__$jscomp$inline_5391$$($JSCompiler_temp$jscomp$849__$jscomp$1280$$,$from_path$jscomp$3$$,$to_path$jscomp$3$$,$before_path$jscomp$3$$,$before_group_QMARK_$jscomp$3$$);else if($m__5372__auto__$jscomp$inline_5392_m__5374__auto__$jscomp$inline_5391$$=
$app$common$types$tokens_lib$move_set_group$$._,$m__5372__auto__$jscomp$inline_5392_m__5374__auto__$jscomp$inline_5391$$!=null)$JSCompiler_temp$jscomp$849__$jscomp$1280$$=$m__5372__auto__$jscomp$inline_5392_m__5374__auto__$jscomp$inline_5391$$.$cljs$core$IFn$_invoke$arity$5$?$m__5372__auto__$jscomp$inline_5392_m__5374__auto__$jscomp$inline_5391$$.$cljs$core$IFn$_invoke$arity$5$($JSCompiler_temp$jscomp$849__$jscomp$1280$$,$from_path$jscomp$3$$,$to_path$jscomp$3$$,$before_path$jscomp$3$$,$before_group_QMARK_$jscomp$3$$):
$m__5372__auto__$jscomp$inline_5392_m__5374__auto__$jscomp$inline_5391$$($JSCompiler_temp$jscomp$849__$jscomp$1280$$,$from_path$jscomp$3$$,$to_path$jscomp$3$$,$before_path$jscomp$3$$,$before_group_QMARK_$jscomp$3$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSets.move-set-group",$JSCompiler_temp$jscomp$849__$jscomp$1280$$);}return $JSCompiler_temp$jscomp$849__$jscomp$1280$$};
$app$common$types$tokens_lib$rename_set_group$$=function($JSCompiler_temp$jscomp$850__$jscomp$1282$$,$from_path_str$jscomp$1$$,$to_path_str$jscomp$1$$){if($JSCompiler_temp$jscomp$850__$jscomp$1282$$!=null&&$JSCompiler_temp$jscomp$850__$jscomp$1282$$.$app$common$types$tokens_lib$ITokenSets$rename_set_group$arity$3$!=null)$JSCompiler_temp$jscomp$850__$jscomp$1282$$=$JSCompiler_temp$jscomp$850__$jscomp$1282$$.$app$common$types$tokens_lib$ITokenSets$rename_set_group$arity$3$($JSCompiler_temp$jscomp$850__$jscomp$1282$$,
$from_path_str$jscomp$1$$,$to_path_str$jscomp$1$$);else{var $m__5372__auto__$jscomp$inline_5398_m__5374__auto__$jscomp$inline_5397$$=$app$common$types$tokens_lib$rename_set_group$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$850__$jscomp$1282$$==null?null:$JSCompiler_temp$jscomp$850__$jscomp$1282$$)];if($m__5372__auto__$jscomp$inline_5398_m__5374__auto__$jscomp$inline_5397$$!=null)$JSCompiler_temp$jscomp$850__$jscomp$1282$$=$m__5372__auto__$jscomp$inline_5398_m__5374__auto__$jscomp$inline_5397$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_5398_m__5374__auto__$jscomp$inline_5397$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$850__$jscomp$1282$$,$from_path_str$jscomp$1$$,$to_path_str$jscomp$1$$):$m__5372__auto__$jscomp$inline_5398_m__5374__auto__$jscomp$inline_5397$$($JSCompiler_temp$jscomp$850__$jscomp$1282$$,$from_path_str$jscomp$1$$,$to_path_str$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_5398_m__5374__auto__$jscomp$inline_5397$$=$app$common$types$tokens_lib$rename_set_group$$._,$m__5372__auto__$jscomp$inline_5398_m__5374__auto__$jscomp$inline_5397$$!=
null)$JSCompiler_temp$jscomp$850__$jscomp$1282$$=$m__5372__auto__$jscomp$inline_5398_m__5374__auto__$jscomp$inline_5397$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_5398_m__5374__auto__$jscomp$inline_5397$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$850__$jscomp$1282$$,$from_path_str$jscomp$1$$,$to_path_str$jscomp$1$$):$m__5372__auto__$jscomp$inline_5398_m__5374__auto__$jscomp$inline_5397$$($JSCompiler_temp$jscomp$850__$jscomp$1282$$,$from_path_str$jscomp$1$$,$to_path_str$jscomp$1$$);
else throw $APP.$cljs$core$missing_protocol$$("ITokenSets.rename-set-group",$JSCompiler_temp$jscomp$850__$jscomp$1282$$);}return $JSCompiler_temp$jscomp$850__$jscomp$1282$$};
$APP.$app$common$types$tokens_lib$get_set$$=function($JSCompiler_temp$jscomp$851__$jscomp$1286$$,$id$jscomp$186$$){if($JSCompiler_temp$jscomp$851__$jscomp$1286$$!=null&&$JSCompiler_temp$jscomp$851__$jscomp$1286$$.$app$common$types$tokens_lib$ITokenSets$get_set$arity$2$!=null)$JSCompiler_temp$jscomp$851__$jscomp$1286$$=$JSCompiler_temp$jscomp$851__$jscomp$1286$$.$app$common$types$tokens_lib$ITokenSets$get_set$arity$2$($JSCompiler_temp$jscomp$851__$jscomp$1286$$,$id$jscomp$186$$);else{var $m__5372__auto__$jscomp$inline_5403_m__5374__auto__$jscomp$inline_5402$$=
$APP.$app$common$types$tokens_lib$get_set$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$851__$jscomp$1286$$==null?null:$JSCompiler_temp$jscomp$851__$jscomp$1286$$)];if($m__5372__auto__$jscomp$inline_5403_m__5374__auto__$jscomp$inline_5402$$!=null)$JSCompiler_temp$jscomp$851__$jscomp$1286$$=$m__5372__auto__$jscomp$inline_5403_m__5374__auto__$jscomp$inline_5402$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5403_m__5374__auto__$jscomp$inline_5402$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$851__$jscomp$1286$$,
$id$jscomp$186$$):$m__5372__auto__$jscomp$inline_5403_m__5374__auto__$jscomp$inline_5402$$($JSCompiler_temp$jscomp$851__$jscomp$1286$$,$id$jscomp$186$$);else if($m__5372__auto__$jscomp$inline_5403_m__5374__auto__$jscomp$inline_5402$$=$APP.$app$common$types$tokens_lib$get_set$$._,$m__5372__auto__$jscomp$inline_5403_m__5374__auto__$jscomp$inline_5402$$!=null)$JSCompiler_temp$jscomp$851__$jscomp$1286$$=$m__5372__auto__$jscomp$inline_5403_m__5374__auto__$jscomp$inline_5402$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5403_m__5374__auto__$jscomp$inline_5402$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$851__$jscomp$1286$$,$id$jscomp$186$$):$m__5372__auto__$jscomp$inline_5403_m__5374__auto__$jscomp$inline_5402$$($JSCompiler_temp$jscomp$851__$jscomp$1286$$,$id$jscomp$186$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSets.get-set",$JSCompiler_temp$jscomp$851__$jscomp$1286$$);}return $JSCompiler_temp$jscomp$851__$jscomp$1286$$};
$APP.$app$common$types$tokens_lib$get_set_by_name$$=function($JSCompiler_temp$jscomp$852__$jscomp$1288$$,$name$jscomp$207$$){if($JSCompiler_temp$jscomp$852__$jscomp$1288$$!=null&&$JSCompiler_temp$jscomp$852__$jscomp$1288$$.$app$common$types$tokens_lib$ITokenSets$get_set_by_name$arity$2$!=null)$JSCompiler_temp$jscomp$852__$jscomp$1288$$=$JSCompiler_temp$jscomp$852__$jscomp$1288$$.$app$common$types$tokens_lib$ITokenSets$get_set_by_name$arity$2$($JSCompiler_temp$jscomp$852__$jscomp$1288$$,$name$jscomp$207$$);
else{var $m__5372__auto__$jscomp$inline_5408_m__5374__auto__$jscomp$inline_5407$$=$APP.$app$common$types$tokens_lib$get_set_by_name$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$852__$jscomp$1288$$==null?null:$JSCompiler_temp$jscomp$852__$jscomp$1288$$)];if($m__5372__auto__$jscomp$inline_5408_m__5374__auto__$jscomp$inline_5407$$!=null)$JSCompiler_temp$jscomp$852__$jscomp$1288$$=$m__5372__auto__$jscomp$inline_5408_m__5374__auto__$jscomp$inline_5407$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5408_m__5374__auto__$jscomp$inline_5407$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$852__$jscomp$1288$$,
$name$jscomp$207$$):$m__5372__auto__$jscomp$inline_5408_m__5374__auto__$jscomp$inline_5407$$($JSCompiler_temp$jscomp$852__$jscomp$1288$$,$name$jscomp$207$$);else if($m__5372__auto__$jscomp$inline_5408_m__5374__auto__$jscomp$inline_5407$$=$APP.$app$common$types$tokens_lib$get_set_by_name$$._,$m__5372__auto__$jscomp$inline_5408_m__5374__auto__$jscomp$inline_5407$$!=null)$JSCompiler_temp$jscomp$852__$jscomp$1288$$=$m__5372__auto__$jscomp$inline_5408_m__5374__auto__$jscomp$inline_5407$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5408_m__5374__auto__$jscomp$inline_5407$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$852__$jscomp$1288$$,$name$jscomp$207$$):$m__5372__auto__$jscomp$inline_5408_m__5374__auto__$jscomp$inline_5407$$($JSCompiler_temp$jscomp$852__$jscomp$1288$$,$name$jscomp$207$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSets.get-set-by-name",$JSCompiler_temp$jscomp$852__$jscomp$1288$$);}return $JSCompiler_temp$jscomp$852__$jscomp$1288$$};
$APP.$app$common$types$tokens_lib$get_sets$$=function($JSCompiler_temp$jscomp$853__$jscomp$1290$$){if($JSCompiler_temp$jscomp$853__$jscomp$1290$$!=null&&$JSCompiler_temp$jscomp$853__$jscomp$1290$$.$app$common$types$tokens_lib$ITokenSets$get_sets$arity$1$!=null)$JSCompiler_temp$jscomp$853__$jscomp$1290$$=$JSCompiler_temp$jscomp$853__$jscomp$1290$$.$app$common$types$tokens_lib$ITokenSets$get_sets$arity$1$($JSCompiler_temp$jscomp$853__$jscomp$1290$$);else{var $m__5372__auto__$jscomp$inline_5412_m__5374__auto__$jscomp$inline_5411$$=
$APP.$app$common$types$tokens_lib$get_sets$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$853__$jscomp$1290$$==null?null:$JSCompiler_temp$jscomp$853__$jscomp$1290$$)];if($m__5372__auto__$jscomp$inline_5412_m__5374__auto__$jscomp$inline_5411$$!=null)$JSCompiler_temp$jscomp$853__$jscomp$1290$$=$m__5372__auto__$jscomp$inline_5412_m__5374__auto__$jscomp$inline_5411$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5412_m__5374__auto__$jscomp$inline_5411$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$853__$jscomp$1290$$):
$m__5372__auto__$jscomp$inline_5412_m__5374__auto__$jscomp$inline_5411$$($JSCompiler_temp$jscomp$853__$jscomp$1290$$);else if($m__5372__auto__$jscomp$inline_5412_m__5374__auto__$jscomp$inline_5411$$=$APP.$app$common$types$tokens_lib$get_sets$$._,$m__5372__auto__$jscomp$inline_5412_m__5374__auto__$jscomp$inline_5411$$!=null)$JSCompiler_temp$jscomp$853__$jscomp$1290$$=$m__5372__auto__$jscomp$inline_5412_m__5374__auto__$jscomp$inline_5411$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5412_m__5374__auto__$jscomp$inline_5411$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$853__$jscomp$1290$$):
$m__5372__auto__$jscomp$inline_5412_m__5374__auto__$jscomp$inline_5411$$($JSCompiler_temp$jscomp$853__$jscomp$1290$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSets.get-sets",$JSCompiler_temp$jscomp$853__$jscomp$1290$$);}return $JSCompiler_temp$jscomp$853__$jscomp$1290$$};
$APP.$app$common$types$tokens_lib$get_set_tree$$=function($JSCompiler_temp$jscomp$854__$jscomp$1294$$){if($JSCompiler_temp$jscomp$854__$jscomp$1294$$!=null&&$JSCompiler_temp$jscomp$854__$jscomp$1294$$.$app$common$types$tokens_lib$ITokenSets$get_set_tree$arity$1$!=null)$JSCompiler_temp$jscomp$854__$jscomp$1294$$=$JSCompiler_temp$jscomp$854__$jscomp$1294$$.$sets$;else{var $m__5372__auto__$jscomp$inline_5416_m__5374__auto__$jscomp$inline_5415$$=$APP.$app$common$types$tokens_lib$get_set_tree$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$854__$jscomp$1294$$==
null?null:$JSCompiler_temp$jscomp$854__$jscomp$1294$$)];if($m__5372__auto__$jscomp$inline_5416_m__5374__auto__$jscomp$inline_5415$$!=null)$JSCompiler_temp$jscomp$854__$jscomp$1294$$=$m__5372__auto__$jscomp$inline_5416_m__5374__auto__$jscomp$inline_5415$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5416_m__5374__auto__$jscomp$inline_5415$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$854__$jscomp$1294$$):$m__5372__auto__$jscomp$inline_5416_m__5374__auto__$jscomp$inline_5415$$($JSCompiler_temp$jscomp$854__$jscomp$1294$$);
else if($m__5372__auto__$jscomp$inline_5416_m__5374__auto__$jscomp$inline_5415$$=$APP.$app$common$types$tokens_lib$get_set_tree$$._,$m__5372__auto__$jscomp$inline_5416_m__5374__auto__$jscomp$inline_5415$$!=null)$JSCompiler_temp$jscomp$854__$jscomp$1294$$=$m__5372__auto__$jscomp$inline_5416_m__5374__auto__$jscomp$inline_5415$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5416_m__5374__auto__$jscomp$inline_5415$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$854__$jscomp$1294$$):
$m__5372__auto__$jscomp$inline_5416_m__5374__auto__$jscomp$inline_5415$$($JSCompiler_temp$jscomp$854__$jscomp$1294$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSets.get-set-tree",$JSCompiler_temp$jscomp$854__$jscomp$1294$$);}return $JSCompiler_temp$jscomp$854__$jscomp$1294$$};
$app$common$types$tokens_lib$set_sets$$=function($JSCompiler_temp$jscomp$855__$jscomp$1298$$,$set_names$jscomp$1$$){if($JSCompiler_temp$jscomp$855__$jscomp$1298$$!=null&&$JSCompiler_temp$jscomp$855__$jscomp$1298$$.$app$common$types$tokens_lib$ITokenTheme$set_sets$arity$2$!=null)$JSCompiler_temp$jscomp$855__$jscomp$1298$$=$JSCompiler_temp$jscomp$855__$jscomp$1298$$.$app$common$types$tokens_lib$ITokenTheme$set_sets$arity$2$($JSCompiler_temp$jscomp$855__$jscomp$1298$$,$set_names$jscomp$1$$);else{var $m__5372__auto__$jscomp$inline_5421_m__5374__auto__$jscomp$inline_5420$$=
$app$common$types$tokens_lib$set_sets$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$855__$jscomp$1298$$==null?null:$JSCompiler_temp$jscomp$855__$jscomp$1298$$)];if($m__5372__auto__$jscomp$inline_5421_m__5374__auto__$jscomp$inline_5420$$!=null)$JSCompiler_temp$jscomp$855__$jscomp$1298$$=$m__5372__auto__$jscomp$inline_5421_m__5374__auto__$jscomp$inline_5420$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5421_m__5374__auto__$jscomp$inline_5420$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$855__$jscomp$1298$$,
$set_names$jscomp$1$$):$m__5372__auto__$jscomp$inline_5421_m__5374__auto__$jscomp$inline_5420$$($JSCompiler_temp$jscomp$855__$jscomp$1298$$,$set_names$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_5421_m__5374__auto__$jscomp$inline_5420$$=$app$common$types$tokens_lib$set_sets$$._,$m__5372__auto__$jscomp$inline_5421_m__5374__auto__$jscomp$inline_5420$$!=null)$JSCompiler_temp$jscomp$855__$jscomp$1298$$=$m__5372__auto__$jscomp$inline_5421_m__5374__auto__$jscomp$inline_5420$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5421_m__5374__auto__$jscomp$inline_5420$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$855__$jscomp$1298$$,$set_names$jscomp$1$$):$m__5372__auto__$jscomp$inline_5421_m__5374__auto__$jscomp$inline_5420$$($JSCompiler_temp$jscomp$855__$jscomp$1298$$,$set_names$jscomp$1$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenTheme.set-sets",$JSCompiler_temp$jscomp$855__$jscomp$1298$$);}return $JSCompiler_temp$jscomp$855__$jscomp$1298$$};
$APP.$app$common$types$tokens_lib$toggle_set$$=function($JSCompiler_temp$jscomp$856__$jscomp$1308$$,$set_name$jscomp$6$$){if($JSCompiler_temp$jscomp$856__$jscomp$1308$$!=null&&$JSCompiler_temp$jscomp$856__$jscomp$1308$$.$app$common$types$tokens_lib$ITokenTheme$toggle_set$arity$2$!=null)$JSCompiler_temp$jscomp$856__$jscomp$1308$$=$JSCompiler_temp$jscomp$856__$jscomp$1308$$.$app$common$types$tokens_lib$ITokenTheme$toggle_set$arity$2$($JSCompiler_temp$jscomp$856__$jscomp$1308$$,$set_name$jscomp$6$$);
else{var $m__5372__auto__$jscomp$inline_5426_m__5374__auto__$jscomp$inline_5425$$=$APP.$app$common$types$tokens_lib$toggle_set$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$856__$jscomp$1308$$==null?null:$JSCompiler_temp$jscomp$856__$jscomp$1308$$)];if($m__5372__auto__$jscomp$inline_5426_m__5374__auto__$jscomp$inline_5425$$!=null)$JSCompiler_temp$jscomp$856__$jscomp$1308$$=$m__5372__auto__$jscomp$inline_5426_m__5374__auto__$jscomp$inline_5425$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5426_m__5374__auto__$jscomp$inline_5425$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$856__$jscomp$1308$$,
$set_name$jscomp$6$$):$m__5372__auto__$jscomp$inline_5426_m__5374__auto__$jscomp$inline_5425$$($JSCompiler_temp$jscomp$856__$jscomp$1308$$,$set_name$jscomp$6$$);else if($m__5372__auto__$jscomp$inline_5426_m__5374__auto__$jscomp$inline_5425$$=$APP.$app$common$types$tokens_lib$toggle_set$$._,$m__5372__auto__$jscomp$inline_5426_m__5374__auto__$jscomp$inline_5425$$!=null)$JSCompiler_temp$jscomp$856__$jscomp$1308$$=$m__5372__auto__$jscomp$inline_5426_m__5374__auto__$jscomp$inline_5425$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5426_m__5374__auto__$jscomp$inline_5425$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$856__$jscomp$1308$$,$set_name$jscomp$6$$):$m__5372__auto__$jscomp$inline_5426_m__5374__auto__$jscomp$inline_5425$$($JSCompiler_temp$jscomp$856__$jscomp$1308$$,$set_name$jscomp$6$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenTheme.toggle-set",$JSCompiler_temp$jscomp$856__$jscomp$1308$$);}return $JSCompiler_temp$jscomp$856__$jscomp$1308$$};
$app$common$types$tokens_lib$hidden_theme_QMARK_$$=function($JSCompiler_temp$jscomp$857__$jscomp$1314$$){if($JSCompiler_temp$jscomp$857__$jscomp$1314$$!=null&&$JSCompiler_temp$jscomp$857__$jscomp$1314$$.$app$common$types$tokens_lib$ITokenTheme$hidden_theme_QMARK_$arity$1$!=null)$JSCompiler_temp$jscomp$857__$jscomp$1314$$=$JSCompiler_temp$jscomp$857__$jscomp$1314$$.$app$common$types$tokens_lib$ITokenTheme$hidden_theme_QMARK_$arity$1$($JSCompiler_temp$jscomp$857__$jscomp$1314$$);else{var $m__5372__auto__$jscomp$inline_5430_m__5374__auto__$jscomp$inline_5429$$=
$app$common$types$tokens_lib$hidden_theme_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$857__$jscomp$1314$$==null?null:$JSCompiler_temp$jscomp$857__$jscomp$1314$$)];if($m__5372__auto__$jscomp$inline_5430_m__5374__auto__$jscomp$inline_5429$$!=null)$JSCompiler_temp$jscomp$857__$jscomp$1314$$=$m__5372__auto__$jscomp$inline_5430_m__5374__auto__$jscomp$inline_5429$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5430_m__5374__auto__$jscomp$inline_5429$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$857__$jscomp$1314$$):
$m__5372__auto__$jscomp$inline_5430_m__5374__auto__$jscomp$inline_5429$$($JSCompiler_temp$jscomp$857__$jscomp$1314$$);else if($m__5372__auto__$jscomp$inline_5430_m__5374__auto__$jscomp$inline_5429$$=$app$common$types$tokens_lib$hidden_theme_QMARK_$$._,$m__5372__auto__$jscomp$inline_5430_m__5374__auto__$jscomp$inline_5429$$!=null)$JSCompiler_temp$jscomp$857__$jscomp$1314$$=$m__5372__auto__$jscomp$inline_5430_m__5374__auto__$jscomp$inline_5429$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5430_m__5374__auto__$jscomp$inline_5429$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$857__$jscomp$1314$$):
$m__5372__auto__$jscomp$inline_5430_m__5374__auto__$jscomp$inline_5429$$($JSCompiler_temp$jscomp$857__$jscomp$1314$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenTheme.hidden-theme?",$JSCompiler_temp$jscomp$857__$jscomp$1314$$);}return $JSCompiler_temp$jscomp$857__$jscomp$1314$$};
$app$common$types$tokens_lib$TokenTheme$$=function($id$jscomp$187$$,$name$jscomp$210$$,$group$jscomp$15$$,$description$jscomp$11$$,$is_source$$,$external_id$$,$modified_at$jscomp$6$$,$sets$jscomp$4$$,$__meta$jscomp$21$$,$__extmap$jscomp$21$$,$__hash$jscomp$80$$){this.id=$id$jscomp$187$$;this.name=$name$jscomp$210$$;this.group=$group$jscomp$15$$;this.description=$description$jscomp$11$$;this.$is_source$=$is_source$$;this.$external_id$=$external_id$$;this.$modified_at$=$modified_at$jscomp$6$$;this.$sets$=
$sets$jscomp$4$$;this.$__meta$=$__meta$jscomp$21$$;this.$__extmap$=$__extmap$jscomp$21$$;this.$__hash$=$__hash$jscomp$80$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenTheme$update_set_name$arity$3$$=function($JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenTheme$update_set_name$arity$3$self$$,$prev_set_name$jscomp$2_sets__$1$$,$set_name$jscomp$11$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenTheme$update_set_name$arity$3$self$$.$sets$,$prev_set_name$jscomp$2_sets__$1$$))?($prev_set_name$jscomp$2_sets__$1$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenTheme$update_set_name$arity$3$self$$.$sets$,$prev_set_name$jscomp$2_sets__$1$$),$set_name$jscomp$11$$),$JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenTheme$update_set_name$arity$3$self$$.$app$common$types$tokens_lib$ITokenTheme$set_sets$arity$2$(null,$prev_set_name$jscomp$2_sets__$1$$)):$JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenTheme$update_set_name$arity$3$self$$};
$app$common$types$tokens_lib$map__GT_TokenTheme$$=function($G__49696$$){var $G__49722$jscomp$inline_5439_extmap__5365__auto__$jscomp$21$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__49696$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$1608$group$$,$APP.$cljs$cst$936$description$$,$cljs$cst$2106$is_source$$,$APP.$cljs$cst$2107$external_id$$,$APP.$cljs$cst$1737$modified_at$$,$APP.$cljs$cst$2108$sets$$]));
$G__49722$jscomp$inline_5439_extmap__5365__auto__$jscomp$21$$=$APP.$cljs$core$record_QMARK_$$($G__49696$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$G__49722$jscomp$inline_5439_extmap__5365__auto__$jscomp$21$$):$G__49722$jscomp$inline_5439_extmap__5365__auto__$jscomp$21$$;return new $app$common$types$tokens_lib$TokenTheme$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__49696$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($G__49696$$),
$APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($G__49696$$),$APP.$cljs$cst$936$description$$.$cljs$core$IFn$_invoke$arity$1$($G__49696$$),$cljs$cst$2106$is_source$$.$cljs$core$IFn$_invoke$arity$1$($G__49696$$),$APP.$cljs$cst$2107$external_id$$.$cljs$core$IFn$_invoke$arity$1$($G__49696$$),$APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($G__49696$$),$APP.$cljs$cst$2108$sets$$.$cljs$core$IFn$_invoke$arity$1$($G__49696$$),null,$APP.$cljs$core$not_empty$$($G__49722$jscomp$inline_5439_extmap__5365__auto__$jscomp$21$$),
null)};$app$common$types$tokens_lib$top_level_theme_group_QMARK_$$=function($group$jscomp$17$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($group$jscomp$17$$,"")};
$APP.$app$common$types$tokens_lib$make_token_theme$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($attrs$jscomp$18_p__49729$$){$attrs$jscomp$18_p__49729$$=$APP.$cljs$core$__destructure_map$$($attrs$jscomp$18_p__49729$$);var $new_id$jscomp$7$$=$APP.$app$common$uuid$next$$();return $app$common$types$tokens_lib$map__GT_TokenTheme$$($app$common$types$tokens_lib$check_token_theme_attrs$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$18_p__49729$$,$APP.$cljs$cst$266$id$$,
function($id$jscomp$189$$){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$(typeof $id$jscomp$189$$==="string"?$APP.$app$common$uuid$parse_STAR_$$($id$jscomp$189$$):$id$jscomp$189$$,$new_id$jscomp$7$$)}),$APP.$cljs$cst$1608$group$$,$APP.$app$common$data$nilv$$,""),$APP.$cljs$cst$936$description$$,$APP.$app$common$data$nilv$$,""),$cljs$cst$2106$is_source$$,$APP.$app$common$data$nilv$$,!1),$APP.$cljs$cst$2107$external_id$$,function($p1__49724_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__49724_SHARP_$$)?
$p1__49724_SHARP_$$:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($new_id$jscomp$7$$)}),$APP.$cljs$cst$1737$modified_at$$,function($p1__49725_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__49725_SHARP_$$)?$p1__49725_SHARP_$$:$APP.$app$common$time$now$$()}),$APP.$cljs$cst$2108$sets$$,function($p1__49726_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$some_QMARK_$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$tokens_lib$normalize_set_name$$)),$p1__49726_SHARP_$$)})))};
$app$common$types$tokens_lib$make_hidden_theme$$=function($var_args$jscomp$1010$$){for(var $args__5755__auto__$jscomp$160_attrs$jscomp$inline_5442$$=[],$len__5749__auto___50384$$=arguments.length,$i__5750__auto___50385$$=0;;)if($i__5750__auto___50385$$<$len__5749__auto___50384$$)$args__5755__auto__$jscomp$160_attrs$jscomp$inline_5442$$.push(arguments[$i__5750__auto___50385$$]),$i__5750__auto___50385$$+=1;else break;$args__5755__auto__$jscomp$160_attrs$jscomp$inline_5442$$=$APP.$cljs$core$__destructure_map$$(0<
$args__5755__auto__$jscomp$160_attrs$jscomp$inline_5442$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$160_attrs$jscomp$inline_5442$$.slice(0),0,null):null);return $APP.$app$common$types$tokens_lib$make_token_theme$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($args__5755__auto__$jscomp$160_attrs$jscomp$inline_5442$$,
$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$zero$$),$APP.$cljs$cst$2107$external_id$$,""),$APP.$cljs$cst$1608$group$$,""),$APP.$cljs$cst$725$name$$,"__PENPOT__HIDDEN__TOKEN__THEME__")]))};
$app$common$types$tokens_lib$join_theme_path$$=function($group$jscomp$18$$,$name$jscomp$212$$){return $APP.$app$common$path_names$join_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$group$jscomp$18$$,$name$jscomp$212$$],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,"/",$APP.$cljs$cst$1998$with_spaces_QMARK_$$,!1]))};
$APP.$app$common$types$tokens_lib$get_theme_path$$=function($theme$$){return $app$common$types$tokens_lib$join_theme_path$$($APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($theme$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($theme$$))};
$app$common$types$tokens_lib$add_theme$$=function($JSCompiler_temp$jscomp$862__$jscomp$1321$$,$token_theme$jscomp$1$$){if($JSCompiler_temp$jscomp$862__$jscomp$1321$$!=null&&$JSCompiler_temp$jscomp$862__$jscomp$1321$$.$app$common$types$tokens_lib$ITokenThemes$add_theme$arity$2$!=null)$JSCompiler_temp$jscomp$862__$jscomp$1321$$=$JSCompiler_temp$jscomp$862__$jscomp$1321$$.$app$common$types$tokens_lib$ITokenThemes$add_theme$arity$2$($JSCompiler_temp$jscomp$862__$jscomp$1321$$,$token_theme$jscomp$1$$);
else{var $m__5372__auto__$jscomp$inline_5447_m__5374__auto__$jscomp$inline_5446$$=$app$common$types$tokens_lib$add_theme$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$862__$jscomp$1321$$==null?null:$JSCompiler_temp$jscomp$862__$jscomp$1321$$)];if($m__5372__auto__$jscomp$inline_5447_m__5374__auto__$jscomp$inline_5446$$!=null)$JSCompiler_temp$jscomp$862__$jscomp$1321$$=$m__5372__auto__$jscomp$inline_5447_m__5374__auto__$jscomp$inline_5446$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5447_m__5374__auto__$jscomp$inline_5446$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$862__$jscomp$1321$$,
$token_theme$jscomp$1$$):$m__5372__auto__$jscomp$inline_5447_m__5374__auto__$jscomp$inline_5446$$($JSCompiler_temp$jscomp$862__$jscomp$1321$$,$token_theme$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_5447_m__5374__auto__$jscomp$inline_5446$$=$app$common$types$tokens_lib$add_theme$$._,$m__5372__auto__$jscomp$inline_5447_m__5374__auto__$jscomp$inline_5446$$!=null)$JSCompiler_temp$jscomp$862__$jscomp$1321$$=$m__5372__auto__$jscomp$inline_5447_m__5374__auto__$jscomp$inline_5446$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5447_m__5374__auto__$jscomp$inline_5446$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$862__$jscomp$1321$$,$token_theme$jscomp$1$$):$m__5372__auto__$jscomp$inline_5447_m__5374__auto__$jscomp$inline_5446$$($JSCompiler_temp$jscomp$862__$jscomp$1321$$,$token_theme$jscomp$1$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.add-theme",$JSCompiler_temp$jscomp$862__$jscomp$1321$$);}return $JSCompiler_temp$jscomp$862__$jscomp$1321$$};
$app$common$types$tokens_lib$update_theme$$=function($JSCompiler_temp$jscomp$863__$jscomp$1323$$,$id$jscomp$191$$,$f$jscomp$785$$){if($JSCompiler_temp$jscomp$863__$jscomp$1323$$!=null&&$JSCompiler_temp$jscomp$863__$jscomp$1323$$.$app$common$types$tokens_lib$ITokenThemes$update_theme$arity$3$!=null)$JSCompiler_temp$jscomp$863__$jscomp$1323$$=$JSCompiler_temp$jscomp$863__$jscomp$1323$$.$app$common$types$tokens_lib$ITokenThemes$update_theme$arity$3$($JSCompiler_temp$jscomp$863__$jscomp$1323$$,$id$jscomp$191$$,
$f$jscomp$785$$);else{var $m__5372__auto__$jscomp$inline_5453_m__5374__auto__$jscomp$inline_5452$$=$app$common$types$tokens_lib$update_theme$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$863__$jscomp$1323$$==null?null:$JSCompiler_temp$jscomp$863__$jscomp$1323$$)];if($m__5372__auto__$jscomp$inline_5453_m__5374__auto__$jscomp$inline_5452$$!=null)$JSCompiler_temp$jscomp$863__$jscomp$1323$$=$m__5372__auto__$jscomp$inline_5453_m__5374__auto__$jscomp$inline_5452$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_5453_m__5374__auto__$jscomp$inline_5452$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$863__$jscomp$1323$$,
$id$jscomp$191$$,$f$jscomp$785$$):$m__5372__auto__$jscomp$inline_5453_m__5374__auto__$jscomp$inline_5452$$($JSCompiler_temp$jscomp$863__$jscomp$1323$$,$id$jscomp$191$$,$f$jscomp$785$$);else if($m__5372__auto__$jscomp$inline_5453_m__5374__auto__$jscomp$inline_5452$$=$app$common$types$tokens_lib$update_theme$$._,$m__5372__auto__$jscomp$inline_5453_m__5374__auto__$jscomp$inline_5452$$!=null)$JSCompiler_temp$jscomp$863__$jscomp$1323$$=$m__5372__auto__$jscomp$inline_5453_m__5374__auto__$jscomp$inline_5452$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_5453_m__5374__auto__$jscomp$inline_5452$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$863__$jscomp$1323$$,$id$jscomp$191$$,$f$jscomp$785$$):$m__5372__auto__$jscomp$inline_5453_m__5374__auto__$jscomp$inline_5452$$($JSCompiler_temp$jscomp$863__$jscomp$1323$$,$id$jscomp$191$$,$f$jscomp$785$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.update-theme",$JSCompiler_temp$jscomp$863__$jscomp$1323$$);}return $JSCompiler_temp$jscomp$863__$jscomp$1323$$};
$app$common$types$tokens_lib$delete_theme$$=function($JSCompiler_temp$jscomp$864__$jscomp$1325$$,$id$jscomp$193$$){if($JSCompiler_temp$jscomp$864__$jscomp$1325$$!=null&&$JSCompiler_temp$jscomp$864__$jscomp$1325$$.$app$common$types$tokens_lib$ITokenThemes$delete_theme$arity$2$!=null)$JSCompiler_temp$jscomp$864__$jscomp$1325$$=$JSCompiler_temp$jscomp$864__$jscomp$1325$$.$app$common$types$tokens_lib$ITokenThemes$delete_theme$arity$2$($JSCompiler_temp$jscomp$864__$jscomp$1325$$,$id$jscomp$193$$);else{var $m__5372__auto__$jscomp$inline_5458_m__5374__auto__$jscomp$inline_5457$$=
$app$common$types$tokens_lib$delete_theme$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$864__$jscomp$1325$$==null?null:$JSCompiler_temp$jscomp$864__$jscomp$1325$$)];if($m__5372__auto__$jscomp$inline_5458_m__5374__auto__$jscomp$inline_5457$$!=null)$JSCompiler_temp$jscomp$864__$jscomp$1325$$=$m__5372__auto__$jscomp$inline_5458_m__5374__auto__$jscomp$inline_5457$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5458_m__5374__auto__$jscomp$inline_5457$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$864__$jscomp$1325$$,
$id$jscomp$193$$):$m__5372__auto__$jscomp$inline_5458_m__5374__auto__$jscomp$inline_5457$$($JSCompiler_temp$jscomp$864__$jscomp$1325$$,$id$jscomp$193$$);else if($m__5372__auto__$jscomp$inline_5458_m__5374__auto__$jscomp$inline_5457$$=$app$common$types$tokens_lib$delete_theme$$._,$m__5372__auto__$jscomp$inline_5458_m__5374__auto__$jscomp$inline_5457$$!=null)$JSCompiler_temp$jscomp$864__$jscomp$1325$$=$m__5372__auto__$jscomp$inline_5458_m__5374__auto__$jscomp$inline_5457$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5458_m__5374__auto__$jscomp$inline_5457$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$864__$jscomp$1325$$,$id$jscomp$193$$):$m__5372__auto__$jscomp$inline_5458_m__5374__auto__$jscomp$inline_5457$$($JSCompiler_temp$jscomp$864__$jscomp$1325$$,$id$jscomp$193$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.delete-theme",$JSCompiler_temp$jscomp$864__$jscomp$1325$$);}return $JSCompiler_temp$jscomp$864__$jscomp$1325$$};
$app$common$types$tokens_lib$get_theme_tree$$=function($JSCompiler_temp$jscomp$865__$jscomp$1329$$){if($JSCompiler_temp$jscomp$865__$jscomp$1329$$!=null&&$JSCompiler_temp$jscomp$865__$jscomp$1329$$.$app$common$types$tokens_lib$ITokenThemes$get_theme_tree$arity$1$!=null)$JSCompiler_temp$jscomp$865__$jscomp$1329$$=$JSCompiler_temp$jscomp$865__$jscomp$1329$$.$themes$;else{var $m__5372__auto__$jscomp$inline_5462_m__5374__auto__$jscomp$inline_5461$$=$app$common$types$tokens_lib$get_theme_tree$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$865__$jscomp$1329$$==
null?null:$JSCompiler_temp$jscomp$865__$jscomp$1329$$)];if($m__5372__auto__$jscomp$inline_5462_m__5374__auto__$jscomp$inline_5461$$!=null)$JSCompiler_temp$jscomp$865__$jscomp$1329$$=$m__5372__auto__$jscomp$inline_5462_m__5374__auto__$jscomp$inline_5461$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5462_m__5374__auto__$jscomp$inline_5461$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$865__$jscomp$1329$$):$m__5372__auto__$jscomp$inline_5462_m__5374__auto__$jscomp$inline_5461$$($JSCompiler_temp$jscomp$865__$jscomp$1329$$);
else if($m__5372__auto__$jscomp$inline_5462_m__5374__auto__$jscomp$inline_5461$$=$app$common$types$tokens_lib$get_theme_tree$$._,$m__5372__auto__$jscomp$inline_5462_m__5374__auto__$jscomp$inline_5461$$!=null)$JSCompiler_temp$jscomp$865__$jscomp$1329$$=$m__5372__auto__$jscomp$inline_5462_m__5374__auto__$jscomp$inline_5461$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5462_m__5374__auto__$jscomp$inline_5461$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$865__$jscomp$1329$$):
$m__5372__auto__$jscomp$inline_5462_m__5374__auto__$jscomp$inline_5461$$($JSCompiler_temp$jscomp$865__$jscomp$1329$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.get-theme-tree",$JSCompiler_temp$jscomp$865__$jscomp$1329$$);}return $JSCompiler_temp$jscomp$865__$jscomp$1329$$};
$APP.$app$common$types$tokens_lib$get_themes$$=function($JSCompiler_temp$jscomp$866__$jscomp$1331$$){if($JSCompiler_temp$jscomp$866__$jscomp$1331$$!=null&&$JSCompiler_temp$jscomp$866__$jscomp$1331$$.$app$common$types$tokens_lib$ITokenThemes$get_themes$arity$1$!=null)$JSCompiler_temp$jscomp$866__$jscomp$1331$$=$JSCompiler_temp$jscomp$866__$jscomp$1331$$.$app$common$types$tokens_lib$ITokenThemes$get_themes$arity$1$($JSCompiler_temp$jscomp$866__$jscomp$1331$$);else{var $m__5372__auto__$jscomp$inline_5466_m__5374__auto__$jscomp$inline_5465$$=
$APP.$app$common$types$tokens_lib$get_themes$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$866__$jscomp$1331$$==null?null:$JSCompiler_temp$jscomp$866__$jscomp$1331$$)];if($m__5372__auto__$jscomp$inline_5466_m__5374__auto__$jscomp$inline_5465$$!=null)$JSCompiler_temp$jscomp$866__$jscomp$1331$$=$m__5372__auto__$jscomp$inline_5466_m__5374__auto__$jscomp$inline_5465$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5466_m__5374__auto__$jscomp$inline_5465$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$866__$jscomp$1331$$):
$m__5372__auto__$jscomp$inline_5466_m__5374__auto__$jscomp$inline_5465$$($JSCompiler_temp$jscomp$866__$jscomp$1331$$);else if($m__5372__auto__$jscomp$inline_5466_m__5374__auto__$jscomp$inline_5465$$=$APP.$app$common$types$tokens_lib$get_themes$$._,$m__5372__auto__$jscomp$inline_5466_m__5374__auto__$jscomp$inline_5465$$!=null)$JSCompiler_temp$jscomp$866__$jscomp$1331$$=$m__5372__auto__$jscomp$inline_5466_m__5374__auto__$jscomp$inline_5465$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5466_m__5374__auto__$jscomp$inline_5465$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$866__$jscomp$1331$$):
$m__5372__auto__$jscomp$inline_5466_m__5374__auto__$jscomp$inline_5465$$($JSCompiler_temp$jscomp$866__$jscomp$1331$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.get-themes",$JSCompiler_temp$jscomp$866__$jscomp$1331$$);}return $JSCompiler_temp$jscomp$866__$jscomp$1331$$};
$APP.$app$common$types$tokens_lib$get_theme$$=function($JSCompiler_temp$jscomp$867__$jscomp$1333$$,$id$jscomp$195$$){if($JSCompiler_temp$jscomp$867__$jscomp$1333$$!=null&&$JSCompiler_temp$jscomp$867__$jscomp$1333$$.$app$common$types$tokens_lib$ITokenThemes$get_theme$arity$2$!=null)$JSCompiler_temp$jscomp$867__$jscomp$1333$$=$JSCompiler_temp$jscomp$867__$jscomp$1333$$.$app$common$types$tokens_lib$ITokenThemes$get_theme$arity$2$($JSCompiler_temp$jscomp$867__$jscomp$1333$$,$id$jscomp$195$$);else{var $m__5372__auto__$jscomp$inline_5471_m__5374__auto__$jscomp$inline_5470$$=
$APP.$app$common$types$tokens_lib$get_theme$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$867__$jscomp$1333$$==null?null:$JSCompiler_temp$jscomp$867__$jscomp$1333$$)];if($m__5372__auto__$jscomp$inline_5471_m__5374__auto__$jscomp$inline_5470$$!=null)$JSCompiler_temp$jscomp$867__$jscomp$1333$$=$m__5372__auto__$jscomp$inline_5471_m__5374__auto__$jscomp$inline_5470$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5471_m__5374__auto__$jscomp$inline_5470$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$867__$jscomp$1333$$,
$id$jscomp$195$$):$m__5372__auto__$jscomp$inline_5471_m__5374__auto__$jscomp$inline_5470$$($JSCompiler_temp$jscomp$867__$jscomp$1333$$,$id$jscomp$195$$);else if($m__5372__auto__$jscomp$inline_5471_m__5374__auto__$jscomp$inline_5470$$=$APP.$app$common$types$tokens_lib$get_theme$$._,$m__5372__auto__$jscomp$inline_5471_m__5374__auto__$jscomp$inline_5470$$!=null)$JSCompiler_temp$jscomp$867__$jscomp$1333$$=$m__5372__auto__$jscomp$inline_5471_m__5374__auto__$jscomp$inline_5470$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5471_m__5374__auto__$jscomp$inline_5470$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$867__$jscomp$1333$$,$id$jscomp$195$$):$m__5372__auto__$jscomp$inline_5471_m__5374__auto__$jscomp$inline_5470$$($JSCompiler_temp$jscomp$867__$jscomp$1333$$,$id$jscomp$195$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.get-theme",$JSCompiler_temp$jscomp$867__$jscomp$1333$$);}return $JSCompiler_temp$jscomp$867__$jscomp$1333$$};
$app$common$types$tokens_lib$get_theme_by_name$$=function($JSCompiler_temp$jscomp$868__$jscomp$1335$$,$group$jscomp$20$$,$name$jscomp$214$$){if($JSCompiler_temp$jscomp$868__$jscomp$1335$$!=null&&$JSCompiler_temp$jscomp$868__$jscomp$1335$$.$app$common$types$tokens_lib$ITokenThemes$get_theme_by_name$arity$3$!=null)$JSCompiler_temp$jscomp$868__$jscomp$1335$$=$JSCompiler_temp$jscomp$868__$jscomp$1335$$.$app$common$types$tokens_lib$ITokenThemes$get_theme_by_name$arity$3$($JSCompiler_temp$jscomp$868__$jscomp$1335$$,
$group$jscomp$20$$,$name$jscomp$214$$);else{var $m__5372__auto__$jscomp$inline_5477_m__5374__auto__$jscomp$inline_5476$$=$app$common$types$tokens_lib$get_theme_by_name$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$868__$jscomp$1335$$==null?null:$JSCompiler_temp$jscomp$868__$jscomp$1335$$)];if($m__5372__auto__$jscomp$inline_5477_m__5374__auto__$jscomp$inline_5476$$!=null)$JSCompiler_temp$jscomp$868__$jscomp$1335$$=$m__5372__auto__$jscomp$inline_5477_m__5374__auto__$jscomp$inline_5476$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_5477_m__5374__auto__$jscomp$inline_5476$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$868__$jscomp$1335$$,$group$jscomp$20$$,$name$jscomp$214$$):$m__5372__auto__$jscomp$inline_5477_m__5374__auto__$jscomp$inline_5476$$($JSCompiler_temp$jscomp$868__$jscomp$1335$$,$group$jscomp$20$$,$name$jscomp$214$$);else if($m__5372__auto__$jscomp$inline_5477_m__5374__auto__$jscomp$inline_5476$$=$app$common$types$tokens_lib$get_theme_by_name$$._,$m__5372__auto__$jscomp$inline_5477_m__5374__auto__$jscomp$inline_5476$$!=
null)$JSCompiler_temp$jscomp$868__$jscomp$1335$$=$m__5372__auto__$jscomp$inline_5477_m__5374__auto__$jscomp$inline_5476$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_5477_m__5374__auto__$jscomp$inline_5476$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$868__$jscomp$1335$$,$group$jscomp$20$$,$name$jscomp$214$$):$m__5372__auto__$jscomp$inline_5477_m__5374__auto__$jscomp$inline_5476$$($JSCompiler_temp$jscomp$868__$jscomp$1335$$,$group$jscomp$20$$,$name$jscomp$214$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.get-theme-by-name",
$JSCompiler_temp$jscomp$868__$jscomp$1335$$);}return $JSCompiler_temp$jscomp$868__$jscomp$1335$$};
$app$common$types$tokens_lib$get_theme_groups$$=function($JSCompiler_temp$jscomp$869__$jscomp$1337$$){if($JSCompiler_temp$jscomp$869__$jscomp$1337$$!=null&&$JSCompiler_temp$jscomp$869__$jscomp$1337$$.$app$common$types$tokens_lib$ITokenThemes$get_theme_groups$arity$1$!=null)$JSCompiler_temp$jscomp$869__$jscomp$1337$$=$JSCompiler_temp$jscomp$869__$jscomp$1337$$.$app$common$types$tokens_lib$ITokenThemes$get_theme_groups$arity$1$($JSCompiler_temp$jscomp$869__$jscomp$1337$$);else{var $m__5372__auto__$jscomp$inline_5481_m__5374__auto__$jscomp$inline_5480$$=
$app$common$types$tokens_lib$get_theme_groups$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$869__$jscomp$1337$$==null?null:$JSCompiler_temp$jscomp$869__$jscomp$1337$$)];if($m__5372__auto__$jscomp$inline_5481_m__5374__auto__$jscomp$inline_5480$$!=null)$JSCompiler_temp$jscomp$869__$jscomp$1337$$=$m__5372__auto__$jscomp$inline_5481_m__5374__auto__$jscomp$inline_5480$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5481_m__5374__auto__$jscomp$inline_5480$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$869__$jscomp$1337$$):
$m__5372__auto__$jscomp$inline_5481_m__5374__auto__$jscomp$inline_5480$$($JSCompiler_temp$jscomp$869__$jscomp$1337$$);else if($m__5372__auto__$jscomp$inline_5481_m__5374__auto__$jscomp$inline_5480$$=$app$common$types$tokens_lib$get_theme_groups$$._,$m__5372__auto__$jscomp$inline_5481_m__5374__auto__$jscomp$inline_5480$$!=null)$JSCompiler_temp$jscomp$869__$jscomp$1337$$=$m__5372__auto__$jscomp$inline_5481_m__5374__auto__$jscomp$inline_5480$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5481_m__5374__auto__$jscomp$inline_5480$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$869__$jscomp$1337$$):
$m__5372__auto__$jscomp$inline_5481_m__5374__auto__$jscomp$inline_5480$$($JSCompiler_temp$jscomp$869__$jscomp$1337$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.get-theme-groups",$JSCompiler_temp$jscomp$869__$jscomp$1337$$);}return $JSCompiler_temp$jscomp$869__$jscomp$1337$$};
$app$common$types$tokens_lib$get_active_theme_paths$$=function($JSCompiler_temp$jscomp$870__$jscomp$1339$$){if($JSCompiler_temp$jscomp$870__$jscomp$1339$$!=null&&$JSCompiler_temp$jscomp$870__$jscomp$1339$$.$app$common$types$tokens_lib$ITokenThemes$get_active_theme_paths$arity$1$!=null)$JSCompiler_temp$jscomp$870__$jscomp$1339$$=$JSCompiler_temp$jscomp$870__$jscomp$1339$$.$active_themes$;else{var $m__5372__auto__$jscomp$inline_5485_m__5374__auto__$jscomp$inline_5484$$=$app$common$types$tokens_lib$get_active_theme_paths$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$870__$jscomp$1339$$==
null?null:$JSCompiler_temp$jscomp$870__$jscomp$1339$$)];if($m__5372__auto__$jscomp$inline_5485_m__5374__auto__$jscomp$inline_5484$$!=null)$JSCompiler_temp$jscomp$870__$jscomp$1339$$=$m__5372__auto__$jscomp$inline_5485_m__5374__auto__$jscomp$inline_5484$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5485_m__5374__auto__$jscomp$inline_5484$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$870__$jscomp$1339$$):$m__5372__auto__$jscomp$inline_5485_m__5374__auto__$jscomp$inline_5484$$($JSCompiler_temp$jscomp$870__$jscomp$1339$$);
else if($m__5372__auto__$jscomp$inline_5485_m__5374__auto__$jscomp$inline_5484$$=$app$common$types$tokens_lib$get_active_theme_paths$$._,$m__5372__auto__$jscomp$inline_5485_m__5374__auto__$jscomp$inline_5484$$!=null)$JSCompiler_temp$jscomp$870__$jscomp$1339$$=$m__5372__auto__$jscomp$inline_5485_m__5374__auto__$jscomp$inline_5484$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5485_m__5374__auto__$jscomp$inline_5484$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$870__$jscomp$1339$$):
$m__5372__auto__$jscomp$inline_5485_m__5374__auto__$jscomp$inline_5484$$($JSCompiler_temp$jscomp$870__$jscomp$1339$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.get-active-theme-paths",$JSCompiler_temp$jscomp$870__$jscomp$1339$$);}return $JSCompiler_temp$jscomp$870__$jscomp$1339$$};
$app$common$types$tokens_lib$set_active_themes$$=function($JSCompiler_temp$jscomp$871__$jscomp$1343$$,$active_themes$jscomp$1$$){if($JSCompiler_temp$jscomp$871__$jscomp$1343$$!=null&&$JSCompiler_temp$jscomp$871__$jscomp$1343$$.$app$common$types$tokens_lib$ITokenThemes$set_active_themes$arity$2$!=null)$JSCompiler_temp$jscomp$871__$jscomp$1343$$=$JSCompiler_temp$jscomp$871__$jscomp$1343$$.$app$common$types$tokens_lib$ITokenThemes$set_active_themes$arity$2$($JSCompiler_temp$jscomp$871__$jscomp$1343$$,
$active_themes$jscomp$1$$);else{var $m__5372__auto__$jscomp$inline_5490_m__5374__auto__$jscomp$inline_5489$$=$app$common$types$tokens_lib$set_active_themes$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$871__$jscomp$1343$$==null?null:$JSCompiler_temp$jscomp$871__$jscomp$1343$$)];if($m__5372__auto__$jscomp$inline_5490_m__5374__auto__$jscomp$inline_5489$$!=null)$JSCompiler_temp$jscomp$871__$jscomp$1343$$=$m__5372__auto__$jscomp$inline_5490_m__5374__auto__$jscomp$inline_5489$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5490_m__5374__auto__$jscomp$inline_5489$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$871__$jscomp$1343$$,$active_themes$jscomp$1$$):$m__5372__auto__$jscomp$inline_5490_m__5374__auto__$jscomp$inline_5489$$($JSCompiler_temp$jscomp$871__$jscomp$1343$$,$active_themes$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_5490_m__5374__auto__$jscomp$inline_5489$$=$app$common$types$tokens_lib$set_active_themes$$._,$m__5372__auto__$jscomp$inline_5490_m__5374__auto__$jscomp$inline_5489$$!=
null)$JSCompiler_temp$jscomp$871__$jscomp$1343$$=$m__5372__auto__$jscomp$inline_5490_m__5374__auto__$jscomp$inline_5489$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5490_m__5374__auto__$jscomp$inline_5489$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$871__$jscomp$1343$$,$active_themes$jscomp$1$$):$m__5372__auto__$jscomp$inline_5490_m__5374__auto__$jscomp$inline_5489$$($JSCompiler_temp$jscomp$871__$jscomp$1343$$,$active_themes$jscomp$1$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.set-active-themes",
$JSCompiler_temp$jscomp$871__$jscomp$1343$$);}return $JSCompiler_temp$jscomp$871__$jscomp$1343$$};
$APP.$app$common$types$tokens_lib$activate_theme$$=function($JSCompiler_temp$jscomp$872__$jscomp$1347$$,$id$jscomp$199$$){if($JSCompiler_temp$jscomp$872__$jscomp$1347$$!=null&&$JSCompiler_temp$jscomp$872__$jscomp$1347$$.$app$common$types$tokens_lib$ITokenThemes$activate_theme$arity$2$!=null)$JSCompiler_temp$jscomp$872__$jscomp$1347$$=$JSCompiler_temp$jscomp$872__$jscomp$1347$$.$app$common$types$tokens_lib$ITokenThemes$activate_theme$arity$2$($JSCompiler_temp$jscomp$872__$jscomp$1347$$,$id$jscomp$199$$);
else{var $m__5372__auto__$jscomp$inline_5495_m__5374__auto__$jscomp$inline_5494$$=$APP.$app$common$types$tokens_lib$activate_theme$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$872__$jscomp$1347$$==null?null:$JSCompiler_temp$jscomp$872__$jscomp$1347$$)];if($m__5372__auto__$jscomp$inline_5495_m__5374__auto__$jscomp$inline_5494$$!=null)$JSCompiler_temp$jscomp$872__$jscomp$1347$$=$m__5372__auto__$jscomp$inline_5495_m__5374__auto__$jscomp$inline_5494$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5495_m__5374__auto__$jscomp$inline_5494$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$872__$jscomp$1347$$,
$id$jscomp$199$$):$m__5372__auto__$jscomp$inline_5495_m__5374__auto__$jscomp$inline_5494$$($JSCompiler_temp$jscomp$872__$jscomp$1347$$,$id$jscomp$199$$);else if($m__5372__auto__$jscomp$inline_5495_m__5374__auto__$jscomp$inline_5494$$=$APP.$app$common$types$tokens_lib$activate_theme$$._,$m__5372__auto__$jscomp$inline_5495_m__5374__auto__$jscomp$inline_5494$$!=null)$JSCompiler_temp$jscomp$872__$jscomp$1347$$=$m__5372__auto__$jscomp$inline_5495_m__5374__auto__$jscomp$inline_5494$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5495_m__5374__auto__$jscomp$inline_5494$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$872__$jscomp$1347$$,$id$jscomp$199$$):$m__5372__auto__$jscomp$inline_5495_m__5374__auto__$jscomp$inline_5494$$($JSCompiler_temp$jscomp$872__$jscomp$1347$$,$id$jscomp$199$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.activate-theme",$JSCompiler_temp$jscomp$872__$jscomp$1347$$);}return $JSCompiler_temp$jscomp$872__$jscomp$1347$$};
$app$common$types$tokens_lib$toggle_theme_active$$=function($JSCompiler_temp$jscomp$873__$jscomp$1351$$,$id$jscomp$203$$){if($JSCompiler_temp$jscomp$873__$jscomp$1351$$!=null&&$JSCompiler_temp$jscomp$873__$jscomp$1351$$.$app$common$types$tokens_lib$ITokenThemes$toggle_theme_active$arity$2$!=null)$JSCompiler_temp$jscomp$873__$jscomp$1351$$=$JSCompiler_temp$jscomp$873__$jscomp$1351$$.$app$common$types$tokens_lib$ITokenThemes$toggle_theme_active$arity$2$($JSCompiler_temp$jscomp$873__$jscomp$1351$$,$id$jscomp$203$$);
else{var $m__5372__auto__$jscomp$inline_5500_m__5374__auto__$jscomp$inline_5499$$=$app$common$types$tokens_lib$toggle_theme_active$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$873__$jscomp$1351$$==null?null:$JSCompiler_temp$jscomp$873__$jscomp$1351$$)];if($m__5372__auto__$jscomp$inline_5500_m__5374__auto__$jscomp$inline_5499$$!=null)$JSCompiler_temp$jscomp$873__$jscomp$1351$$=$m__5372__auto__$jscomp$inline_5500_m__5374__auto__$jscomp$inline_5499$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5500_m__5374__auto__$jscomp$inline_5499$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$873__$jscomp$1351$$,
$id$jscomp$203$$):$m__5372__auto__$jscomp$inline_5500_m__5374__auto__$jscomp$inline_5499$$($JSCompiler_temp$jscomp$873__$jscomp$1351$$,$id$jscomp$203$$);else if($m__5372__auto__$jscomp$inline_5500_m__5374__auto__$jscomp$inline_5499$$=$app$common$types$tokens_lib$toggle_theme_active$$._,$m__5372__auto__$jscomp$inline_5500_m__5374__auto__$jscomp$inline_5499$$!=null)$JSCompiler_temp$jscomp$873__$jscomp$1351$$=$m__5372__auto__$jscomp$inline_5500_m__5374__auto__$jscomp$inline_5499$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5500_m__5374__auto__$jscomp$inline_5499$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$873__$jscomp$1351$$,$id$jscomp$203$$):$m__5372__auto__$jscomp$inline_5500_m__5374__auto__$jscomp$inline_5499$$($JSCompiler_temp$jscomp$873__$jscomp$1351$$,$id$jscomp$203$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.toggle-theme-active",$JSCompiler_temp$jscomp$873__$jscomp$1351$$);}return $JSCompiler_temp$jscomp$873__$jscomp$1351$$};
$app$common$types$tokens_lib$get_hidden_theme$$=function($JSCompiler_temp$jscomp$874__$jscomp$1353$$){if($JSCompiler_temp$jscomp$874__$jscomp$1353$$!=null&&$JSCompiler_temp$jscomp$874__$jscomp$1353$$.$app$common$types$tokens_lib$ITokenThemes$get_hidden_theme$arity$1$!=null)$JSCompiler_temp$jscomp$874__$jscomp$1353$$=$JSCompiler_temp$jscomp$874__$jscomp$1353$$.$app$common$types$tokens_lib$ITokenThemes$get_hidden_theme$arity$1$($JSCompiler_temp$jscomp$874__$jscomp$1353$$);else{var $m__5372__auto__$jscomp$inline_5504_m__5374__auto__$jscomp$inline_5503$$=
$app$common$types$tokens_lib$get_hidden_theme$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$874__$jscomp$1353$$==null?null:$JSCompiler_temp$jscomp$874__$jscomp$1353$$)];if($m__5372__auto__$jscomp$inline_5504_m__5374__auto__$jscomp$inline_5503$$!=null)$JSCompiler_temp$jscomp$874__$jscomp$1353$$=$m__5372__auto__$jscomp$inline_5504_m__5374__auto__$jscomp$inline_5503$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5504_m__5374__auto__$jscomp$inline_5503$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$874__$jscomp$1353$$):
$m__5372__auto__$jscomp$inline_5504_m__5374__auto__$jscomp$inline_5503$$($JSCompiler_temp$jscomp$874__$jscomp$1353$$);else if($m__5372__auto__$jscomp$inline_5504_m__5374__auto__$jscomp$inline_5503$$=$app$common$types$tokens_lib$get_hidden_theme$$._,$m__5372__auto__$jscomp$inline_5504_m__5374__auto__$jscomp$inline_5503$$!=null)$JSCompiler_temp$jscomp$874__$jscomp$1353$$=$m__5372__auto__$jscomp$inline_5504_m__5374__auto__$jscomp$inline_5503$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5504_m__5374__auto__$jscomp$inline_5503$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$874__$jscomp$1353$$):
$m__5372__auto__$jscomp$inline_5504_m__5374__auto__$jscomp$inline_5503$$($JSCompiler_temp$jscomp$874__$jscomp$1353$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.get-hidden-theme",$JSCompiler_temp$jscomp$874__$jscomp$1353$$);}return $JSCompiler_temp$jscomp$874__$jscomp$1353$$};
$APP.$app$common$types$tokens_lib$empty_lib_QMARK_$$=function($JSCompiler_temp$jscomp$875__$jscomp$1355$$){if($JSCompiler_temp$jscomp$875__$jscomp$1355$$!=null&&$JSCompiler_temp$jscomp$875__$jscomp$1355$$.$app$common$types$tokens_lib$ITokensLib$empty_lib_QMARK_$arity$1$!=null)$JSCompiler_temp$jscomp$875__$jscomp$1355$$=$JSCompiler_temp$jscomp$875__$jscomp$1355$$.$app$common$types$tokens_lib$ITokensLib$empty_lib_QMARK_$arity$1$($JSCompiler_temp$jscomp$875__$jscomp$1355$$);else{var $m__5372__auto__$jscomp$inline_5508_m__5374__auto__$jscomp$inline_5507$$=
$APP.$app$common$types$tokens_lib$empty_lib_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$875__$jscomp$1355$$==null?null:$JSCompiler_temp$jscomp$875__$jscomp$1355$$)];if($m__5372__auto__$jscomp$inline_5508_m__5374__auto__$jscomp$inline_5507$$!=null)$JSCompiler_temp$jscomp$875__$jscomp$1355$$=$m__5372__auto__$jscomp$inline_5508_m__5374__auto__$jscomp$inline_5507$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5508_m__5374__auto__$jscomp$inline_5507$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$875__$jscomp$1355$$):
$m__5372__auto__$jscomp$inline_5508_m__5374__auto__$jscomp$inline_5507$$($JSCompiler_temp$jscomp$875__$jscomp$1355$$);else if($m__5372__auto__$jscomp$inline_5508_m__5374__auto__$jscomp$inline_5507$$=$APP.$app$common$types$tokens_lib$empty_lib_QMARK_$$._,$m__5372__auto__$jscomp$inline_5508_m__5374__auto__$jscomp$inline_5507$$!=null)$JSCompiler_temp$jscomp$875__$jscomp$1355$$=$m__5372__auto__$jscomp$inline_5508_m__5374__auto__$jscomp$inline_5507$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5508_m__5374__auto__$jscomp$inline_5507$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$875__$jscomp$1355$$):
$m__5372__auto__$jscomp$inline_5508_m__5374__auto__$jscomp$inline_5507$$($JSCompiler_temp$jscomp$875__$jscomp$1355$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.empty-lib?",$JSCompiler_temp$jscomp$875__$jscomp$1355$$);}return $JSCompiler_temp$jscomp$875__$jscomp$1355$$};
$app$common$types$tokens_lib$add_token$$=function($JSCompiler_temp$jscomp$876__$jscomp$1361$$,$set_id$jscomp$1$$,$token$jscomp$54$$){if($JSCompiler_temp$jscomp$876__$jscomp$1361$$!=null&&$JSCompiler_temp$jscomp$876__$jscomp$1361$$.$app$common$types$tokens_lib$ITokensLib$add_token$arity$3$!=null)$JSCompiler_temp$jscomp$876__$jscomp$1361$$=$JSCompiler_temp$jscomp$876__$jscomp$1361$$.$app$common$types$tokens_lib$ITokensLib$add_token$arity$3$($JSCompiler_temp$jscomp$876__$jscomp$1361$$,$set_id$jscomp$1$$,
$token$jscomp$54$$);else{var $m__5372__auto__$jscomp$inline_5514_m__5374__auto__$jscomp$inline_5513$$=$app$common$types$tokens_lib$add_token$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$876__$jscomp$1361$$==null?null:$JSCompiler_temp$jscomp$876__$jscomp$1361$$)];if($m__5372__auto__$jscomp$inline_5514_m__5374__auto__$jscomp$inline_5513$$!=null)$JSCompiler_temp$jscomp$876__$jscomp$1361$$=$m__5372__auto__$jscomp$inline_5514_m__5374__auto__$jscomp$inline_5513$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_5514_m__5374__auto__$jscomp$inline_5513$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$876__$jscomp$1361$$,
$set_id$jscomp$1$$,$token$jscomp$54$$):$m__5372__auto__$jscomp$inline_5514_m__5374__auto__$jscomp$inline_5513$$($JSCompiler_temp$jscomp$876__$jscomp$1361$$,$set_id$jscomp$1$$,$token$jscomp$54$$);else if($m__5372__auto__$jscomp$inline_5514_m__5374__auto__$jscomp$inline_5513$$=$app$common$types$tokens_lib$add_token$$._,$m__5372__auto__$jscomp$inline_5514_m__5374__auto__$jscomp$inline_5513$$!=null)$JSCompiler_temp$jscomp$876__$jscomp$1361$$=$m__5372__auto__$jscomp$inline_5514_m__5374__auto__$jscomp$inline_5513$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_5514_m__5374__auto__$jscomp$inline_5513$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$876__$jscomp$1361$$,$set_id$jscomp$1$$,$token$jscomp$54$$):$m__5372__auto__$jscomp$inline_5514_m__5374__auto__$jscomp$inline_5513$$($JSCompiler_temp$jscomp$876__$jscomp$1361$$,$set_id$jscomp$1$$,$token$jscomp$54$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.add-token",$JSCompiler_temp$jscomp$876__$jscomp$1361$$);}return $JSCompiler_temp$jscomp$876__$jscomp$1361$$};
$APP.$app$common$types$tokens_lib$get_token$$=function($JSCompiler_temp$jscomp$877__$jscomp$1363$$,$set_id$jscomp$3$$,$token_id$jscomp$4$$){if($JSCompiler_temp$jscomp$877__$jscomp$1363$$!=null&&$JSCompiler_temp$jscomp$877__$jscomp$1363$$.$app$common$types$tokens_lib$ITokensLib$get_token$arity$3$!=null)$JSCompiler_temp$jscomp$877__$jscomp$1363$$=$JSCompiler_temp$jscomp$877__$jscomp$1363$$.$app$common$types$tokens_lib$ITokensLib$get_token$arity$3$($JSCompiler_temp$jscomp$877__$jscomp$1363$$,$set_id$jscomp$3$$,
$token_id$jscomp$4$$);else{var $m__5372__auto__$jscomp$inline_5520_m__5374__auto__$jscomp$inline_5519$$=$APP.$app$common$types$tokens_lib$get_token$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$877__$jscomp$1363$$==null?null:$JSCompiler_temp$jscomp$877__$jscomp$1363$$)];if($m__5372__auto__$jscomp$inline_5520_m__5374__auto__$jscomp$inline_5519$$!=null)$JSCompiler_temp$jscomp$877__$jscomp$1363$$=$m__5372__auto__$jscomp$inline_5520_m__5374__auto__$jscomp$inline_5519$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_5520_m__5374__auto__$jscomp$inline_5519$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$877__$jscomp$1363$$,$set_id$jscomp$3$$,$token_id$jscomp$4$$):$m__5372__auto__$jscomp$inline_5520_m__5374__auto__$jscomp$inline_5519$$($JSCompiler_temp$jscomp$877__$jscomp$1363$$,$set_id$jscomp$3$$,$token_id$jscomp$4$$);else if($m__5372__auto__$jscomp$inline_5520_m__5374__auto__$jscomp$inline_5519$$=$APP.$app$common$types$tokens_lib$get_token$$._,$m__5372__auto__$jscomp$inline_5520_m__5374__auto__$jscomp$inline_5519$$!=
null)$JSCompiler_temp$jscomp$877__$jscomp$1363$$=$m__5372__auto__$jscomp$inline_5520_m__5374__auto__$jscomp$inline_5519$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_5520_m__5374__auto__$jscomp$inline_5519$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$877__$jscomp$1363$$,$set_id$jscomp$3$$,$token_id$jscomp$4$$):$m__5372__auto__$jscomp$inline_5520_m__5374__auto__$jscomp$inline_5519$$($JSCompiler_temp$jscomp$877__$jscomp$1363$$,$set_id$jscomp$3$$,$token_id$jscomp$4$$);
else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.get-token",$JSCompiler_temp$jscomp$877__$jscomp$1363$$);}return $JSCompiler_temp$jscomp$877__$jscomp$1363$$};
$app$common$types$tokens_lib$update_token$$=function($JSCompiler_temp$jscomp$878__$jscomp$1367$$,$set_id$jscomp$5$$,$token_id$jscomp$6$$,$f$jscomp$787$$){if($JSCompiler_temp$jscomp$878__$jscomp$1367$$!=null&&$JSCompiler_temp$jscomp$878__$jscomp$1367$$.$app$common$types$tokens_lib$ITokensLib$update_token$arity$4$!=null)$JSCompiler_temp$jscomp$878__$jscomp$1367$$=$JSCompiler_temp$jscomp$878__$jscomp$1367$$.$app$common$types$tokens_lib$ITokensLib$update_token$arity$4$($JSCompiler_temp$jscomp$878__$jscomp$1367$$,
$set_id$jscomp$5$$,$token_id$jscomp$6$$,$f$jscomp$787$$);else{var $m__5372__auto__$jscomp$inline_5527_m__5374__auto__$jscomp$inline_5526$$=$app$common$types$tokens_lib$update_token$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$878__$jscomp$1367$$==null?null:$JSCompiler_temp$jscomp$878__$jscomp$1367$$)];if($m__5372__auto__$jscomp$inline_5527_m__5374__auto__$jscomp$inline_5526$$!=null)$JSCompiler_temp$jscomp$878__$jscomp$1367$$=$m__5372__auto__$jscomp$inline_5527_m__5374__auto__$jscomp$inline_5526$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_5527_m__5374__auto__$jscomp$inline_5526$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$878__$jscomp$1367$$,$set_id$jscomp$5$$,$token_id$jscomp$6$$,$f$jscomp$787$$):$m__5372__auto__$jscomp$inline_5527_m__5374__auto__$jscomp$inline_5526$$($JSCompiler_temp$jscomp$878__$jscomp$1367$$,$set_id$jscomp$5$$,$token_id$jscomp$6$$,$f$jscomp$787$$);else if($m__5372__auto__$jscomp$inline_5527_m__5374__auto__$jscomp$inline_5526$$=$app$common$types$tokens_lib$update_token$$._,
$m__5372__auto__$jscomp$inline_5527_m__5374__auto__$jscomp$inline_5526$$!=null)$JSCompiler_temp$jscomp$878__$jscomp$1367$$=$m__5372__auto__$jscomp$inline_5527_m__5374__auto__$jscomp$inline_5526$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_5527_m__5374__auto__$jscomp$inline_5526$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$878__$jscomp$1367$$,$set_id$jscomp$5$$,$token_id$jscomp$6$$,$f$jscomp$787$$):$m__5372__auto__$jscomp$inline_5527_m__5374__auto__$jscomp$inline_5526$$($JSCompiler_temp$jscomp$878__$jscomp$1367$$,
$set_id$jscomp$5$$,$token_id$jscomp$6$$,$f$jscomp$787$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.update-token",$JSCompiler_temp$jscomp$878__$jscomp$1367$$);}return $JSCompiler_temp$jscomp$878__$jscomp$1367$$};
$app$common$types$tokens_lib$delete_token$$=function($JSCompiler_temp$jscomp$879__$jscomp$1369$$,$set_id$jscomp$7$$,$token_id$jscomp$8$$){if($JSCompiler_temp$jscomp$879__$jscomp$1369$$!=null&&$JSCompiler_temp$jscomp$879__$jscomp$1369$$.$app$common$types$tokens_lib$ITokensLib$delete_token$arity$3$!=null)$JSCompiler_temp$jscomp$879__$jscomp$1369$$=$JSCompiler_temp$jscomp$879__$jscomp$1369$$.$app$common$types$tokens_lib$ITokensLib$delete_token$arity$3$($JSCompiler_temp$jscomp$879__$jscomp$1369$$,$set_id$jscomp$7$$,
$token_id$jscomp$8$$);else{var $m__5372__auto__$jscomp$inline_5533_m__5374__auto__$jscomp$inline_5532$$=$app$common$types$tokens_lib$delete_token$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$879__$jscomp$1369$$==null?null:$JSCompiler_temp$jscomp$879__$jscomp$1369$$)];if($m__5372__auto__$jscomp$inline_5533_m__5374__auto__$jscomp$inline_5532$$!=null)$JSCompiler_temp$jscomp$879__$jscomp$1369$$=$m__5372__auto__$jscomp$inline_5533_m__5374__auto__$jscomp$inline_5532$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_5533_m__5374__auto__$jscomp$inline_5532$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$879__$jscomp$1369$$,
$set_id$jscomp$7$$,$token_id$jscomp$8$$):$m__5372__auto__$jscomp$inline_5533_m__5374__auto__$jscomp$inline_5532$$($JSCompiler_temp$jscomp$879__$jscomp$1369$$,$set_id$jscomp$7$$,$token_id$jscomp$8$$);else if($m__5372__auto__$jscomp$inline_5533_m__5374__auto__$jscomp$inline_5532$$=$app$common$types$tokens_lib$delete_token$$._,$m__5372__auto__$jscomp$inline_5533_m__5374__auto__$jscomp$inline_5532$$!=null)$JSCompiler_temp$jscomp$879__$jscomp$1369$$=$m__5372__auto__$jscomp$inline_5533_m__5374__auto__$jscomp$inline_5532$$.$cljs$core$IFn$_invoke$arity$3$?
$m__5372__auto__$jscomp$inline_5533_m__5374__auto__$jscomp$inline_5532$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$879__$jscomp$1369$$,$set_id$jscomp$7$$,$token_id$jscomp$8$$):$m__5372__auto__$jscomp$inline_5533_m__5374__auto__$jscomp$inline_5532$$($JSCompiler_temp$jscomp$879__$jscomp$1369$$,$set_id$jscomp$7$$,$token_id$jscomp$8$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.delete-token",$JSCompiler_temp$jscomp$879__$jscomp$1369$$);}return $JSCompiler_temp$jscomp$879__$jscomp$1369$$};
$APP.$app$common$types$tokens_lib$get_active_themes_set_names$$=function($JSCompiler_temp$jscomp$880__$jscomp$1373$$){if($JSCompiler_temp$jscomp$880__$jscomp$1373$$!=null&&$JSCompiler_temp$jscomp$880__$jscomp$1373$$.$app$common$types$tokens_lib$ITokensLib$get_active_themes_set_names$arity$1$!=null)$JSCompiler_temp$jscomp$880__$jscomp$1373$$=$JSCompiler_temp$jscomp$880__$jscomp$1373$$.$app$common$types$tokens_lib$ITokensLib$get_active_themes_set_names$arity$1$($JSCompiler_temp$jscomp$880__$jscomp$1373$$);
else{var $m__5372__auto__$jscomp$inline_5537_m__5374__auto__$jscomp$inline_5536$$=$APP.$app$common$types$tokens_lib$get_active_themes_set_names$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$880__$jscomp$1373$$==null?null:$JSCompiler_temp$jscomp$880__$jscomp$1373$$)];if($m__5372__auto__$jscomp$inline_5537_m__5374__auto__$jscomp$inline_5536$$!=null)$JSCompiler_temp$jscomp$880__$jscomp$1373$$=$m__5372__auto__$jscomp$inline_5537_m__5374__auto__$jscomp$inline_5536$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5537_m__5374__auto__$jscomp$inline_5536$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$880__$jscomp$1373$$):
$m__5372__auto__$jscomp$inline_5537_m__5374__auto__$jscomp$inline_5536$$($JSCompiler_temp$jscomp$880__$jscomp$1373$$);else if($m__5372__auto__$jscomp$inline_5537_m__5374__auto__$jscomp$inline_5536$$=$APP.$app$common$types$tokens_lib$get_active_themes_set_names$$._,$m__5372__auto__$jscomp$inline_5537_m__5374__auto__$jscomp$inline_5536$$!=null)$JSCompiler_temp$jscomp$880__$jscomp$1373$$=$m__5372__auto__$jscomp$inline_5537_m__5374__auto__$jscomp$inline_5536$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5537_m__5374__auto__$jscomp$inline_5536$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$880__$jscomp$1373$$):
$m__5372__auto__$jscomp$inline_5537_m__5374__auto__$jscomp$inline_5536$$($JSCompiler_temp$jscomp$880__$jscomp$1373$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.get-active-themes-set-names",$JSCompiler_temp$jscomp$880__$jscomp$1373$$);}return $JSCompiler_temp$jscomp$880__$jscomp$1373$$};
$APP.$app$common$types$tokens_lib$token_set_active_QMARK_$$=function($JSCompiler_temp$jscomp$881__$jscomp$1375$$,$set_name$jscomp$18$$){if($JSCompiler_temp$jscomp$881__$jscomp$1375$$!=null&&$JSCompiler_temp$jscomp$881__$jscomp$1375$$.$app$common$types$tokens_lib$ITokensLib$token_set_active_QMARK_$arity$2$!=null)$JSCompiler_temp$jscomp$881__$jscomp$1375$$=$JSCompiler_temp$jscomp$881__$jscomp$1375$$.$app$common$types$tokens_lib$ITokensLib$token_set_active_QMARK_$arity$2$($JSCompiler_temp$jscomp$881__$jscomp$1375$$,
$set_name$jscomp$18$$);else{var $m__5372__auto__$jscomp$inline_5542_m__5374__auto__$jscomp$inline_5541$$=$APP.$app$common$types$tokens_lib$token_set_active_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$881__$jscomp$1375$$==null?null:$JSCompiler_temp$jscomp$881__$jscomp$1375$$)];if($m__5372__auto__$jscomp$inline_5542_m__5374__auto__$jscomp$inline_5541$$!=null)$JSCompiler_temp$jscomp$881__$jscomp$1375$$=$m__5372__auto__$jscomp$inline_5542_m__5374__auto__$jscomp$inline_5541$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5542_m__5374__auto__$jscomp$inline_5541$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$881__$jscomp$1375$$,$set_name$jscomp$18$$):$m__5372__auto__$jscomp$inline_5542_m__5374__auto__$jscomp$inline_5541$$($JSCompiler_temp$jscomp$881__$jscomp$1375$$,$set_name$jscomp$18$$);else if($m__5372__auto__$jscomp$inline_5542_m__5374__auto__$jscomp$inline_5541$$=$APP.$app$common$types$tokens_lib$token_set_active_QMARK_$$._,$m__5372__auto__$jscomp$inline_5542_m__5374__auto__$jscomp$inline_5541$$!=
null)$JSCompiler_temp$jscomp$881__$jscomp$1375$$=$m__5372__auto__$jscomp$inline_5542_m__5374__auto__$jscomp$inline_5541$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5542_m__5374__auto__$jscomp$inline_5541$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$881__$jscomp$1375$$,$set_name$jscomp$18$$):$m__5372__auto__$jscomp$inline_5542_m__5374__auto__$jscomp$inline_5541$$($JSCompiler_temp$jscomp$881__$jscomp$1375$$,$set_name$jscomp$18$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.token-set-active?",
$JSCompiler_temp$jscomp$881__$jscomp$1375$$);}return $JSCompiler_temp$jscomp$881__$jscomp$1375$$};
$APP.$app$common$types$tokens_lib$get_tokens_in_active_sets$$=function($JSCompiler_temp$jscomp$882__$jscomp$1379$$){if($JSCompiler_temp$jscomp$882__$jscomp$1379$$!=null&&$JSCompiler_temp$jscomp$882__$jscomp$1379$$.$app$common$types$tokens_lib$ITokensLib$get_tokens_in_active_sets$arity$1$!=null)$JSCompiler_temp$jscomp$882__$jscomp$1379$$=$JSCompiler_temp$jscomp$882__$jscomp$1379$$.$app$common$types$tokens_lib$ITokensLib$get_tokens_in_active_sets$arity$1$($JSCompiler_temp$jscomp$882__$jscomp$1379$$);else{var $m__5372__auto__$jscomp$inline_5546_m__5374__auto__$jscomp$inline_5545$$=
$APP.$app$common$types$tokens_lib$get_tokens_in_active_sets$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$882__$jscomp$1379$$==null?null:$JSCompiler_temp$jscomp$882__$jscomp$1379$$)];if($m__5372__auto__$jscomp$inline_5546_m__5374__auto__$jscomp$inline_5545$$!=null)$JSCompiler_temp$jscomp$882__$jscomp$1379$$=$m__5372__auto__$jscomp$inline_5546_m__5374__auto__$jscomp$inline_5545$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5546_m__5374__auto__$jscomp$inline_5545$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$882__$jscomp$1379$$):
$m__5372__auto__$jscomp$inline_5546_m__5374__auto__$jscomp$inline_5545$$($JSCompiler_temp$jscomp$882__$jscomp$1379$$);else if($m__5372__auto__$jscomp$inline_5546_m__5374__auto__$jscomp$inline_5545$$=$APP.$app$common$types$tokens_lib$get_tokens_in_active_sets$$._,$m__5372__auto__$jscomp$inline_5546_m__5374__auto__$jscomp$inline_5545$$!=null)$JSCompiler_temp$jscomp$882__$jscomp$1379$$=$m__5372__auto__$jscomp$inline_5546_m__5374__auto__$jscomp$inline_5545$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5546_m__5374__auto__$jscomp$inline_5545$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$882__$jscomp$1379$$):
$m__5372__auto__$jscomp$inline_5546_m__5374__auto__$jscomp$inline_5545$$($JSCompiler_temp$jscomp$882__$jscomp$1379$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.get-tokens-in-active-sets",$JSCompiler_temp$jscomp$882__$jscomp$1379$$);}return $JSCompiler_temp$jscomp$882__$jscomp$1379$$};
$APP.$app$common$types$tokens_lib$get_all_tokens_map$$=function($JSCompiler_temp$jscomp$883__$jscomp$1385$$){if($JSCompiler_temp$jscomp$883__$jscomp$1385$$!=null&&$JSCompiler_temp$jscomp$883__$jscomp$1385$$.$app$common$types$tokens_lib$ITokensLib$get_all_tokens_map$arity$1$!=null)$JSCompiler_temp$jscomp$883__$jscomp$1385$$=$JSCompiler_temp$jscomp$883__$jscomp$1385$$.$app$common$types$tokens_lib$ITokensLib$get_all_tokens_map$arity$1$($JSCompiler_temp$jscomp$883__$jscomp$1385$$);else{var $m__5372__auto__$jscomp$inline_5550_m__5374__auto__$jscomp$inline_5549$$=
$APP.$app$common$types$tokens_lib$get_all_tokens_map$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$883__$jscomp$1385$$==null?null:$JSCompiler_temp$jscomp$883__$jscomp$1385$$)];if($m__5372__auto__$jscomp$inline_5550_m__5374__auto__$jscomp$inline_5549$$!=null)$JSCompiler_temp$jscomp$883__$jscomp$1385$$=$m__5372__auto__$jscomp$inline_5550_m__5374__auto__$jscomp$inline_5549$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5550_m__5374__auto__$jscomp$inline_5549$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$883__$jscomp$1385$$):
$m__5372__auto__$jscomp$inline_5550_m__5374__auto__$jscomp$inline_5549$$($JSCompiler_temp$jscomp$883__$jscomp$1385$$);else if($m__5372__auto__$jscomp$inline_5550_m__5374__auto__$jscomp$inline_5549$$=$APP.$app$common$types$tokens_lib$get_all_tokens_map$$._,$m__5372__auto__$jscomp$inline_5550_m__5374__auto__$jscomp$inline_5549$$!=null)$JSCompiler_temp$jscomp$883__$jscomp$1385$$=$m__5372__auto__$jscomp$inline_5550_m__5374__auto__$jscomp$inline_5549$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5550_m__5374__auto__$jscomp$inline_5549$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$883__$jscomp$1385$$):
$m__5372__auto__$jscomp$inline_5550_m__5374__auto__$jscomp$inline_5549$$($JSCompiler_temp$jscomp$883__$jscomp$1385$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.get-all-tokens-map",$JSCompiler_temp$jscomp$883__$jscomp$1385$$);}return $JSCompiler_temp$jscomp$883__$jscomp$1385$$};
$APP.$app$common$types$tokens_lib$get_tokens$$=function($JSCompiler_temp$jscomp$884__$jscomp$1387$$,$set_id$jscomp$9$$){if($JSCompiler_temp$jscomp$884__$jscomp$1387$$!=null&&$JSCompiler_temp$jscomp$884__$jscomp$1387$$.$app$common$types$tokens_lib$ITokensLib$get_tokens$arity$2$!=null)$JSCompiler_temp$jscomp$884__$jscomp$1387$$=$JSCompiler_temp$jscomp$884__$jscomp$1387$$.$app$common$types$tokens_lib$ITokensLib$get_tokens$arity$2$($JSCompiler_temp$jscomp$884__$jscomp$1387$$,$set_id$jscomp$9$$);else{var $m__5372__auto__$jscomp$inline_5555_m__5374__auto__$jscomp$inline_5554$$=
$APP.$app$common$types$tokens_lib$get_tokens$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$884__$jscomp$1387$$==null?null:$JSCompiler_temp$jscomp$884__$jscomp$1387$$)];if($m__5372__auto__$jscomp$inline_5555_m__5374__auto__$jscomp$inline_5554$$!=null)$JSCompiler_temp$jscomp$884__$jscomp$1387$$=$m__5372__auto__$jscomp$inline_5555_m__5374__auto__$jscomp$inline_5554$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5555_m__5374__auto__$jscomp$inline_5554$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$884__$jscomp$1387$$,
$set_id$jscomp$9$$):$m__5372__auto__$jscomp$inline_5555_m__5374__auto__$jscomp$inline_5554$$($JSCompiler_temp$jscomp$884__$jscomp$1387$$,$set_id$jscomp$9$$);else if($m__5372__auto__$jscomp$inline_5555_m__5374__auto__$jscomp$inline_5554$$=$APP.$app$common$types$tokens_lib$get_tokens$$._,$m__5372__auto__$jscomp$inline_5555_m__5374__auto__$jscomp$inline_5554$$!=null)$JSCompiler_temp$jscomp$884__$jscomp$1387$$=$m__5372__auto__$jscomp$inline_5555_m__5374__auto__$jscomp$inline_5554$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5555_m__5374__auto__$jscomp$inline_5554$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$884__$jscomp$1387$$,$set_id$jscomp$9$$):$m__5372__auto__$jscomp$inline_5555_m__5374__auto__$jscomp$inline_5554$$($JSCompiler_temp$jscomp$884__$jscomp$1387$$,$set_id$jscomp$9$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.get-tokens",$JSCompiler_temp$jscomp$884__$jscomp$1387$$);}return $JSCompiler_temp$jscomp$884__$jscomp$1387$$};
$app$common$types$tokens_lib$TokensLib$$=function($sets$jscomp$6$$,$themes$$,$active_themes$jscomp$2$$){this.$sets$=$sets$jscomp$6$$;this.$themes$=$themes$$;this.$active_themes$=$active_themes$jscomp$2$$};
$JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenThemes$get_active_themes$arity$1$$=function($JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenThemes$get_active_themes$arity$1$self$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$List$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$core$instance_QMARK_$$,$app$common$types$tokens_lib$TokenTheme$$)),
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__49924_SHARP_$$){return $JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenThemes$get_active_themes$arity$1$self$$.$app$common$types$tokens_lib$ITokenThemes$theme_active_QMARK_$arity$2$(null,$APP.$app$common$types$tokens_lib$get_id$$($p1__49924_SHARP_$$))})),$APP.$cljs$core$tree_seq$$($APP.$app$common$data$ordered_map_QMARK_$$,$APP.$cljs$core$vals$$,$JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenThemes$get_active_themes$arity$1$self$$.$themes$))};
$app$common$types$tokens_lib$ensure_hidden_theme$$=function($themes$jscomp$2$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($themes$jscomp$2$$,"",function($data$jscomp$139$$){return $APP.$cljs$core$contains_QMARK_$$($data$jscomp$139$$,"__PENPOT__HIDDEN__TOKEN__THEME__")?$data$jscomp$139$$:$app$common$data$oassoc$$.$cljs$core$IFn$_invoke$arity$variadic$($data$jscomp$139$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["__PENPOT__HIDDEN__TOKEN__THEME__",$app$common$types$tokens_lib$make_hidden_theme$$()]))})};
$app$common$types$tokens_lib$map__GT_tokens_lib$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__50005_sets$jscomp$8$$){var $active_themes$jscomp$4_map__50006__$1$$=$APP.$cljs$core$__destructure_map$$($p__50005_sets$jscomp$8$$);$p__50005_sets$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_themes$jscomp$4_map__50006__$1$$,$APP.$cljs$cst$2108$sets$$);var $themes$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_themes$jscomp$4_map__50006__$1$$,
$APP.$cljs$cst$2122$themes$$);$active_themes$jscomp$4_map__50006__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_themes$jscomp$4_map__50006__$1$$,$cljs$cst$2123$active_themes$$);return new $app$common$types$tokens_lib$TokensLib$$($p__50005_sets$jscomp$8$$,$themes$jscomp$3$$,$active_themes$jscomp$4_map__50006__$1$$)};
$APP.$app$common$types$tokens_lib$make_tokens_lib$$=function($var_args$jscomp$1014$$){for(var $args__5755__auto__$jscomp$164$$=[],$len__5749__auto___50668$$=arguments.length,$i__5750__auto___50669$$=0;;)if($i__5750__auto___50669$$<$len__5749__auto___50668$$)$args__5755__auto__$jscomp$164$$.push(arguments[$i__5750__auto___50669$$]),$i__5750__auto___50669$$+=1;else break;return $app$common$types$tokens_lib$make_tokens_lib$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$164$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$164$$.slice(0),0,null):null)};
$app$common$types$tokens_lib$make_tokens_lib$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__50011_params$jscomp$107$$){$p__50011_params$jscomp$107$$=$APP.$cljs$core$__destructure_map$$($p__50011_params$jscomp$107$$);return $app$common$types$tokens_lib$map__GT_tokens_lib$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$types$tokens_lib$check_tokens_lib_map$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p__50011_params$jscomp$107$$,$APP.$cljs$cst$2108$sets$$,
function($p1__50007_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__50007_SHARP_$$)?$p1__50007_SHARP_$$:$APP.$linked$map$empty_linked_map$$}),$APP.$cljs$cst$2122$themes$$,function($p1__50008_SHARP_$$){return $app$common$types$tokens_lib$ensure_hidden_theme$$($APP.$cljs$core$truth_$$($p1__50008_SHARP_$$)?$p1__50008_SHARP_$$:$APP.$linked$map$empty_linked_map$$)}),$cljs$cst$2123$active_themes$$,function($p1__50009_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__50009_SHARP_$$)?$p1__50009_SHARP_$$:$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$app$common$types$tokens_lib$hidden_theme_path$$])}))]))};
$app$common$types$tokens_lib$ensure_tokens_lib$$=function($tokens_lib$$){return $APP.$cljs$core$truth_$$($tokens_lib$$)?$tokens_lib$$:$APP.$app$common$types$tokens_lib$make_tokens_lib$$()};
$app$common$types$tokens_lib$token_name__GT_path_selector$$=function($path$jscomp$185_path_segments_token_name$jscomp$5$$){$path$jscomp$185_path_segments_token_name$jscomp$5$$=$APP.$app$common$types$tokens_lib$get_token_path$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$path$jscomp$185_path_segments_token_name$jscomp$5$$],null));var $last_idx$jscomp$1_selector$jscomp$12_vec__50033_vec__50036$$=$APP.$cljs$core$count$$($path$jscomp$185_path_segments_token_name$jscomp$5$$)-
1;$last_idx$jscomp$1_selector$jscomp$12_vec__50033_vec__50036$$=$cljs$core$split_at$$($last_idx$jscomp$1_selector$jscomp$12_vec__50033_vec__50036$$,$path$jscomp$185_path_segments_token_name$jscomp$5$$);$path$jscomp$185_path_segments_token_name$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($last_idx$jscomp$1_selector$jscomp$12_vec__50033_vec__50036$$,0,null);$last_idx$jscomp$1_selector$jscomp$12_vec__50033_vec__50036$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($last_idx$jscomp$1_selector$jscomp$12_vec__50033_vec__50036$$,
1,null);$last_idx$jscomp$1_selector$jscomp$12_vec__50033_vec__50036$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($last_idx$jscomp$1_selector$jscomp$12_vec__50033_vec__50036$$,0,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$296$path$$,$APP.$cljs$core$seq$$($path$jscomp$185_path_segments_token_name$jscomp$5$$),$APP.$cljs$cst$1452$selector$$,$last_idx$jscomp$1_selector$jscomp$12_vec__50033_vec__50036$$],null)};
$APP.$app$common$types$tokens_lib$token_name_path_exists_QMARK_$$=function($map__50039_path$jscomp$186_token_name$jscomp$6$$,$path_target_tokens_tree$$){$map__50039_path$jscomp$186_token_name$jscomp$6$$=$app$common$types$tokens_lib$token_name__GT_path_selector$$($map__50039_path$jscomp$186_token_name$jscomp$6$$);var $map__50039__$1_selector$jscomp$13$$=$APP.$cljs$core$__destructure_map$$($map__50039_path$jscomp$186_token_name$jscomp$6$$);$map__50039_path$jscomp$186_token_name$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50039__$1_selector$jscomp$13$$,
$APP.$cljs$cst$296$path$$);$map__50039__$1_selector$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50039__$1_selector$jscomp$13$$,$APP.$cljs$cst$1452$selector$$);$path_target_tokens_tree$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$102_target$jscomp$121$$,$cur$jscomp$6$$){$acc$jscomp$102_target$jscomp$121$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$102_target$jscomp$121$$,$cur$jscomp$6$$);return $acc$jscomp$102_target$jscomp$121$$==
null?$APP.$cljs$core$reduced$$(!1):$APP.$cljs$core$truth_$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($acc$jscomp$102_target$jscomp$121$$))?$APP.$cljs$core$reduced$$(!0):$acc$jscomp$102_target$jscomp$121$$},$path_target_tokens_tree$$,$map__50039_path$jscomp$186_token_name$jscomp$6$$);return $APP.$cljs$core$boolean_QMARK_$$($path_target_tokens_tree$$)?$path_target_tokens_tree$$:$APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($path_target_tokens_tree$$,
$APP.$cljs$cst$725$name$$))?!0:$APP.$cljs$core$boolean$0$$($APP.$cljs$core$seq$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($path_target_tokens_tree$$,$map__50039__$1_selector$jscomp$13$$)))};$APP.$app$common$types$tokens_lib$convert_dtcg_font_family$$=function($value$jscomp$443$$){if(typeof $value$jscomp$443$$==="string")return $APP.$app$common$types$token$split_font_family$$($value$jscomp$443$$);$APP.$cljs$core$sequential_QMARK_$$($value$jscomp$443$$);return $value$jscomp$443$$};
$APP.$app$common$types$tokens_lib$convert_dtcg_typography_composite$$=function($value$jscomp$444$$){return $APP.$cljs$core$map_QMARK_$$($value$jscomp$444$$)?$APP.$app$common$data$update_when$$($APP.$cljs$core$select_keys$$($APP.$clojure$set$rename_keys$$($value$jscomp$444$$,$app$common$types$token$composite_dtcg_token_type__GT_token_type$$),$app$common$types$token$typography_keys$$),$APP.$cljs$cst$1758$font_family$$,$APP.$app$common$types$tokens_lib$convert_dtcg_font_family$$):$value$jscomp$444$$};
$APP.$app$common$types$tokens_lib$convert_dtcg_shadow_composite$$=function($value$jscomp$445$$){function $process_shadow$jscomp$1$$($shadow__$1$jscomp$4$$){if($APP.$cljs$core$map_QMARK_$$($shadow__$1$jscomp$4$$)){var $legacy_shadow_type$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadow__$1$jscomp$4$$,"type");return $APP.$cljs$core$select_keys$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$clojure$set$rename_keys$$($shadow__$1$jscomp$4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
8,["x",$APP.$cljs$cst$1650$offset_x$$,"offsetX",$APP.$cljs$cst$1650$offset_x$$,"y",$APP.$cljs$cst$1651$offset_y$$,"offsetY",$APP.$cljs$cst$1651$offset_y$$,"blur",$APP.$cljs$cst$1653$blur$$,"spread",$APP.$cljs$cst$1652$spread$$,"color",$APP.$cljs$cst$1298$color$$,"inset",$APP.$cljs$cst$2133$inset$$],null)),$APP.$cljs$cst$2133$inset$$,function($p1__50061_SHARP_$$){return $APP.$cljs$core$boolean_QMARK_$$($p1__50061_SHARP_$$)?$p1__50061_SHARP_$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("true",
$p1__50061_SHARP_$$)?!0:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("false",$p1__50061_SHARP_$$)?!1:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($legacy_shadow_type$$,"innerShadow")?!0:!1}),new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1650$offset_x$$,$APP.$cljs$cst$1651$offset_y$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1652$spread$$,$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$2133$inset$$],null))}return $shadow__$1$jscomp$4$$}
return typeof $value$jscomp$445$$==="string"?$value$jscomp$445$$:$APP.$cljs$core$sequential_QMARK_$$($value$jscomp$445$$)?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($process_shadow$jscomp$1$$,$value$jscomp$445$$):$APP.$cljs$core$map_QMARK_$$($value$jscomp$445$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$process_shadow$jscomp$1$$($value$jscomp$445$$)],null):$value$jscomp$445$$};
$APP.$app$common$types$tokens_lib$parse_multi_set_dtcg_json$$=function($decoded_json$jscomp$4_themes$jscomp$4$$){var $metadata$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($decoded_json$jscomp$4_themes$jscomp$4$$,"$metadata"),$xf_normalize_set_name$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$tokens_lib$normalize_set_name$$),$library__$1_library__$2_library__$3_sets$jscomp$10$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($decoded_json$jscomp$4_themes$jscomp$4$$,
"$themes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["$metadata"])),$ordered_set_names$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$xf_normalize_set_name$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($metadata$jscomp$4$$,"tokenSetOrder")),$xf_normalize_set_name$$,$APP.$cljs$core$keys$$($library__$1_library__$2_library__$3_sets$jscomp$10$$)),
$active_set_names$jscomp$3$$=function(){var $or__5025__auto__$jscomp$405$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$xf_normalize_set_name$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($metadata$jscomp$4$$,"activeSets")));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$405$$)?$or__5025__auto__$jscomp$405$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$}(),$active_theme_names_library__$4$$=function(){var $or__5025__auto__$jscomp$406$$=
$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($metadata$jscomp$4$$,"activeThemes")));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$406$$)?$or__5025__auto__$jscomp$406$$:$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$app$common$types$tokens_lib$hidden_theme_path$$])}();$decoded_json$jscomp$4_themes$jscomp$4$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($theme$jscomp$7$$){return $APP.$app$common$types$tokens_lib$make_token_theme$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$,
function(){var $or__5025__auto__$jscomp$407$$=$APP.$app$common$uuid$parse_STAR_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($theme$jscomp$7$$,"id"));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$407$$)?$or__5025__auto__$jscomp$407$$:$APP.$app$common$uuid$next$$()}(),$APP.$cljs$cst$725$name$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($theme$jscomp$7$$,"name"),$APP.$cljs$cst$1608$group$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($theme$jscomp$7$$,"group"),
$cljs$cst$2106$is_source$$,function(){var $or__5025__auto__$jscomp$408$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($theme$jscomp$7$$,"isSource");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$408$$)?$or__5025__auto__$jscomp$408$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($theme$jscomp$7$$,"is-source")}(),$APP.$cljs$cst$2107$external_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($theme$jscomp$7$$,"id"),$APP.$cljs$cst$2108$sets$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$key$$),$xf_normalize_set_name$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__50071_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($ordered_set_names$$,$p1__50071_SHARP_$$)})),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($theme$jscomp$7$$,"selectedTokenSets"))]))},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($decoded_json$jscomp$4_themes$jscomp$4$$,
"$themes")));var $library$$=$APP.$app$common$types$tokens_lib$make_tokens_lib$$(),$sets__$1$jscomp$3$$=$APP.$cljs$core$reduce_kv$$(function($result$jscomp$210$$,$name$jscomp$220$$,$tokens$jscomp$17$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$210$$,$APP.$app$common$types$tokens_lib$normalize_set_name$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$220$$),$APP.$app$common$types$tokens_lib$flatten_nested_tokens_json$$($tokens$jscomp$17$$,""))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$library__$1_library__$2_library__$3_sets$jscomp$10$$);$library__$1_library__$2_library__$3_sets$jscomp$10$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($library__$1$jscomp$1$$,$name$jscomp$221$$){var $temp__5823__auto__$jscomp$121$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sets__$1$jscomp$3$$,$name$jscomp$221$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$121$$)?$APP.$app$common$types$tokens_lib$add_set$$($library__$1$jscomp$1$$,$APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,
$name$jscomp$221$$,$APP.$cljs$cst$2100$tokens$$,$temp__5823__auto__$jscomp$121$$]))):$library__$1$jscomp$1$$},$library$$,$ordered_set_names$$);$library__$1_library__$2_library__$3_sets$jscomp$10$$=$app$common$types$tokens_lib$update_theme$$($library__$1_library__$2_library__$3_sets$jscomp$10$$,$APP.$app$common$uuid$zero$$,function($p1__50072_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__50072_SHARP_$$,$APP.$cljs$cst$2108$sets$$,$active_set_names$jscomp$3$$)});$library__$1_library__$2_library__$3_sets$jscomp$10$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$tokens_lib$add_theme$$,$library__$1_library__$2_library__$3_sets$jscomp$10$$,$decoded_json$jscomp$4_themes$jscomp$4$$);$active_theme_names_library__$4$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($library__$4$jscomp$1$$,$group$jscomp$25_theme$jscomp$8_theme_path$$){var $name$jscomp$222_vec__50074$$=$APP.$app$common$path_names$split_group_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($group$jscomp$25_theme$jscomp$8_theme_path$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,"/",$APP.$cljs$cst$1998$with_spaces_QMARK_$$,!1]));$group$jscomp$25_theme$jscomp$8_theme_path$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$222_vec__50074$$,0,null);$name$jscomp$222_vec__50074$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$222_vec__50074$$,1,null);$group$jscomp$25_theme$jscomp$8_theme_path$$=$app$common$types$tokens_lib$get_theme_by_name$$($library__$4$jscomp$1$$,
$group$jscomp$25_theme$jscomp$8_theme_path$$,$name$jscomp$222_vec__50074$$);return $APP.$app$common$types$tokens_lib$activate_theme$$($library__$4$jscomp$1$$,$APP.$app$common$types$tokens_lib$get_id$$($group$jscomp$25_theme$jscomp$8_theme_path$$))},$library__$1_library__$2_library__$3_sets$jscomp$10$$,$active_theme_names_library__$4$$);if($APP.$cljs$core$empty_QMARK_$$($sets__$1$jscomp$3$$)&&$APP.$cljs$core$empty_QMARK_$$($decoded_json$jscomp$4_themes$jscomp$4$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("the file doesn't contain any tokens",
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$945$error_SLASH_code$$,$APP.$cljs$cst$2134$error_DOT_import_SLASH_invalid_json_data$$],null));return $active_theme_names_library__$4$$};
$app$common$types$tokens_lib$read_multi_set_dtcg$$=function($data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$){if($data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$ instanceof $app$common$types$tokens_lib$TokensLib$$)return $data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$;$data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$=typeof $data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$==="string"?$APP.$app$common$json$decode$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$291$key_fn$$,$APP.$cljs$core$identity$$])):$data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$;$data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$=$APP.$cljs$core$object_QMARK_$$($data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$)?$app$common$json$__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$291$key_fn$$,
$APP.$cljs$core$identity$$])):$data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$;$data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$=$app$common$types$tokens_lib$decode_multi_set_dtcg_data$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$tokens_lib$decode_multi_set_dtcg_data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$):$app$common$types$tokens_lib$decode_multi_set_dtcg_data$$($data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$);return $APP.$app$common$types$tokens_lib$parse_multi_set_dtcg_json$$($app$common$types$tokens_lib$check_multi_set_dtcg_data$$($data$jscomp$140_data__$1$jscomp$3_data__$2_data__$3$$))};
$app$common$types$tokens_lib$typography_token__GT_dtcg_token$$=function($value$jscomp$446$$){return $APP.$cljs$core$map_QMARK_$$($value$jscomp$446$$)?$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$103$$,$k$jscomp$602$$,$v$jscomp$537$$){return $APP.$cljs$core$contains_QMARK_$$($app$common$types$token$typography_keys$$,$k$jscomp$602$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$103$$,$app$common$types$token$composite_token_type__GT_dtcg_token_type$$.$cljs$core$IFn$_invoke$arity$1$?
$app$common$types$token$composite_token_type__GT_dtcg_token_type$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$602$$):$app$common$types$token$composite_token_type__GT_dtcg_token_type$$($k$jscomp$602$$),$v$jscomp$537$$):$acc$jscomp$103$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$value$jscomp$446$$):$value$jscomp$446$$};
$app$common$types$tokens_lib$shadow_token__GT_dtcg_token$$=function($value$jscomp$447$$){return $APP.$cljs$core$sequential_QMARK_$$($value$jscomp$447$$)?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($shadow__$1$jscomp$5$$){return $APP.$cljs$core$map_QMARK_$$($shadow__$1$jscomp$5$$)?$APP.$cljs$core$select_keys$$($APP.$clojure$set$rename_keys$$($shadow__$1$jscomp$5$$,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1650$offset_x$$,"offsetX",$APP.$cljs$cst$1651$offset_y$$,
"offsetY",$APP.$cljs$cst$1653$blur$$,"blur",$APP.$cljs$cst$1652$spread$$,"spread",$APP.$cljs$cst$1298$color$$,"color",$APP.$cljs$cst$2133$inset$$,"inset"],null)),new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"offsetX offsetY blur spread color inset".split(" "),null)):$shadow__$1$jscomp$5$$},$value$jscomp$447$$):$value$jscomp$447$$};
$APP.$app$common$types$tokens_lib$token__GT_dtcg_token$$=function($token$jscomp$56$$){var $G__50077$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,["$value",function(){var $G__50078_G__50078__$1$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$56$$);$G__50078_G__50078__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1981$typography$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$56$$))?$app$common$types$tokens_lib$typography_token__GT_dtcg_token$$($G__50078_G__50078__$1$$):
$G__50078_G__50078__$1$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$56$$))?$app$common$types$tokens_lib$shadow_token__GT_dtcg_token$$($G__50078_G__50078__$1$$):$G__50078_G__50078__$1$$}(),"$type",function(){var $G__50079$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$56$$);return $APP.$app$common$types$token$token_type__GT_dtcg_token_type$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$app$common$types$token$token_type__GT_dtcg_token_type$$.$cljs$core$IFn$_invoke$arity$1$($G__50079$$):(0,$APP.$app$common$types$token$token_type__GT_dtcg_token_type$$)($G__50079$$)}()],null);return $APP.$cljs$core$truth_$$($APP.$cljs$cst$936$description$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$56$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__50077$$,"$description",$APP.$cljs$cst$936$description$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$56$$)):$G__50077$$};
$APP.$app$common$types$tokens_lib$dtcg_export_themes$$=function($active_themes$jscomp$5_tokens_lib$jscomp$1$$){var $themes$jscomp$5_themes_xform$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__50080_SHARP_$$){return $p1__50080_SHARP_$$ instanceof $app$common$types$tokens_lib$TokenTheme$$&&$APP.$cljs$core$not$$($app$common$types$tokens_lib$hidden_theme_QMARK_$$($p1__50080_SHARP_$$))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($token_theme$jscomp$3$$){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,["id",$APP.$cljs$cst$2107$external_id$$.$cljs$core$IFn$_invoke$arity$1$($token_theme$jscomp$3$$),"name",$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token_theme$jscomp$3$$),"group",$APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($token_theme$jscomp$3$$),"description",$APP.$cljs$cst$936$description$$.$cljs$core$IFn$_invoke$arity$1$($token_theme$jscomp$3$$),"isSource",$cljs$cst$2106$is_source$$.$cljs$core$IFn$_invoke$arity$1$($token_theme$jscomp$3$$),"selectedTokenSets",
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__50081_SHARP_$$,$p2__50082_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__50081_SHARP_$$,$p2__50082_SHARP_$$,"enabled")},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$2108$sets$$.$cljs$core$IFn$_invoke$arity$1$($token_theme$jscomp$3$$))],null))}));$themes$jscomp$5_themes_xform$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$themes$jscomp$5_themes_xform$$,
$APP.$cljs$core$tree_seq$$($APP.$app$common$data$ordered_map_QMARK_$$,$APP.$cljs$core$vals$$,$app$common$types$tokens_lib$get_theme_tree$$($active_themes$jscomp$5_tokens_lib$jscomp$1$$)));$active_themes$jscomp$5_tokens_lib$jscomp$1$$=$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$tokens_lib$get_active_theme_paths$$($active_themes$jscomp$5_tokens_lib$jscomp$1$$),$app$common$types$tokens_lib$hidden_theme_path$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$themes$jscomp$5_themes_xform$$,$active_themes$jscomp$5_tokens_lib$jscomp$1$$],null)};
$APP.$app$common$types$tokens_lib$export_dtcg_json$$=function($tokens_lib$jscomp$3$$){var $active_themes$jscomp$7_vec__50086$$=$APP.$app$common$types$tokens_lib$dtcg_export_themes$$($tokens_lib$jscomp$3$$),$themes$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($active_themes$jscomp$7_vec__50086$$,0,null);$active_themes$jscomp$7_vec__50086$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($active_themes$jscomp$7_vec__50086$$,1,null);var $name_set_tuples_sets$jscomp$12$$=
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($set$jscomp$13$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$13$$),$APP.$app$common$types$tokens_lib$tokens_tree$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$tokens_lib$get_tokens_$$($set$jscomp$13$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2103$update_token_fn$$,
$APP.$app$common$types$tokens_lib$token__GT_dtcg_token$$]))],null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$core$instance_QMARK_$$,$APP.$app$common$types$tokens_lib$TokenSet$$),$APP.$cljs$core$tree_seq$$($APP.$app$common$data$ordered_map_QMARK_$$,$APP.$cljs$core$vals$$,$APP.$app$common$types$tokens_lib$get_set_tree$$($tokens_lib$jscomp$3$$)))),$ordered_set_names$jscomp$1$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,
$name_set_tuples_sets$jscomp$12$$);$name_set_tuples_sets$jscomp$12$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$name_set_tuples_sets$jscomp$12$$);var $active_set_names$jscomp$4$$=$APP.$app$common$types$tokens_lib$get_active_themes_set_names$$($tokens_lib$jscomp$3$$);return $APP.$cljs$core$truth_$$($APP.$app$common$types$tokens_lib$empty_lib_QMARK_$$($tokens_lib$jscomp$3$$))?null:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($name_set_tuples_sets$jscomp$12$$,
"$themes",$themes$jscomp$7$$),"$metadata",new $APP.$cljs$core$PersistentArrayMap$$(null,3,["tokenSetOrder",$ordered_set_names$jscomp$1$$,"activeThemes",$active_themes$jscomp$7_vec__50086$$,"activeSets",$active_set_names$jscomp$4$$],null))};
$APP.$app$main$data$workspace$tokens$selected_set$get_selected_token_set_id$$=function($G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$){var $or__5025__auto__$jscomp$409$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$2138$selected_token_set_id$$],null));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$409$$))return $or__5025__auto__$jscomp$409$$;
$G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$);$G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$=$G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$,$APP.$cljs$cst$2139$tokens_lib$$);
$G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$=$G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$==null?null:$APP.$app$common$types$tokens_lib$get_sets$$($G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$);$G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$=$G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$==null?null:$APP.$cljs$core$first$$($G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$);return $G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$==
null?null:$APP.$app$common$types$tokens_lib$get_id$$($G__50107_G__50107__$1_G__50107__$2_G__50107__$3_state$jscomp$82$$)};
$app$main$store$measure_time_to_render$$=function($event$jscomp$41$$){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($app$main$store$current_measure$$)))$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$main$store$current_measure$$,$APP.$cljs$core$conj$$,$event$jscomp$41$$);else{var $start$jscomp$209$$=performance.now();$APP.$cljs$core$reset_BANG_$$($app$main$store$current_measure$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$event$jscomp$41$$],null));(0,$APP.$app$util$timers$request_animation_frame$$)(function(){return scheduler.postTask(function(){var $time_49444$$=performance.now()-$start$jscomp$209$$;$time_49444$$>1E3&&$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($time_49444$$),"|",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",
$APP.$cljs$core$_deref$$($app$main$store$current_measure$$)))].join("")]));return $APP.$cljs$core$reset_BANG_$$($app$main$store$current_measure$$,null)},{priority:"user-blocking"})})}};$app$main$store$async_emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($params$jscomp$108$$){return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$store$emit_BANG_$$,$params$jscomp$108$$)})};
$APP.$app$util$keyboard$KeyboardEvent$$=function($type$jscomp$357$$,$key$jscomp$311$$,$shift$jscomp$28$$,$ctrl$$,$alt$$,$meta$jscomp$81$$,$mod$jscomp$1$$,$editing$$,$native_event$$,$__meta$jscomp$22$$,$__extmap$jscomp$22$$,$__hash$jscomp$81$$){this.type=$type$jscomp$357$$;this.key=$key$jscomp$311$$;this.shift=$shift$jscomp$28$$;this.$ctrl$=$ctrl$$;this.alt=$alt$$;this.$meta$=$meta$jscomp$81$$;this.$mod$=$mod$jscomp$1$$;this.editing=$editing$$;this.$native_event$=$native_event$$;this.$__meta$=$__meta$jscomp$22$$;
this.$__extmap$=$__extmap$jscomp$22$$;this.$__hash$=$__hash$jscomp$81$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};$app$util$keyboard$keyboard_event_QMARK_$$=function($o$jscomp$260$$){return $o$jscomp$260$$ instanceof $APP.$app$util$keyboard$KeyboardEvent$$};$app$util$keyboard$key_up_event_QMARK_$$=function($event$jscomp$45$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1954$up$$,$event$jscomp$45$$.type)};
$APP.$app$util$keyboard$key_down_event_QMARK_$$=function($event$jscomp$46$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1953$down$$,$event$jscomp$46$$.type)};$APP.$app$util$keyboard$editing_event_QMARK_$$=function($event$jscomp$48$$){return $event$jscomp$48$$.editing===!0};
$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($key$jscomp$313$$){return function($event$jscomp$49$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$49$$.key,$key$jscomp$313$$)}};
$APP.$app$util$keyboard$is_key_ignore_case_QMARK_$$=function($key$jscomp$315$$){var $key__$1$jscomp$3$$=$APP.$cuerdas$core$upper$$($key$jscomp$315$$);return function($e$jscomp$290$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$upper$$($e$jscomp$290$$.key),$key__$1$jscomp$3$$)}};$APP.$app$util$keyboard$mod_QMARK_$$=function($event$jscomp$55$$){return $APP.$app$config$check_platform_QMARK_$$()?$event$jscomp$55$$.metaKey:$event$jscomp$55$$.ctrlKey};
$APP.$app$util$mouse$MouseEvent$$=function($type$jscomp$359$$,$ctrl$jscomp$2$$,$shift$jscomp$30$$,$alt$jscomp$2$$,$meta$jscomp$83$$,$__meta$jscomp$23$$,$__extmap$jscomp$23$$,$__hash$jscomp$82$$){this.type=$type$jscomp$359$$;this.$ctrl$=$ctrl$jscomp$2$$;this.shift=$shift$jscomp$30$$;this.alt=$alt$jscomp$2$$;this.$meta$=$meta$jscomp$83$$;this.$__meta$=$__meta$jscomp$23$$;this.$__extmap$=$__extmap$jscomp$23$$;this.$__hash$=$__hash$jscomp$82$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=
139264};
$APP.$app$util$mouse$PointerEvent$$=function($source$jscomp$41$$,$pt$jscomp$19$$,$ctrl$jscomp$4$$,$shift$jscomp$32$$,$alt$jscomp$4$$,$meta$jscomp$85$$,$movement$$,$__meta$jscomp$24$$,$__extmap$jscomp$24$$,$__hash$jscomp$83$$){this.source=$source$jscomp$41$$;this.pt=$pt$jscomp$19$$;this.$ctrl$=$ctrl$jscomp$4$$;this.shift=$shift$jscomp$32$$;this.alt=$alt$jscomp$4$$;this.$meta$=$meta$jscomp$85$$;this.$movement$=$movement$$;this.$__meta$=$__meta$jscomp$24$$;this.$__extmap$=$__extmap$jscomp$24$$;this.$__hash$=
$__hash$jscomp$83$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};$APP.$app$util$mouse$BlurEvent$$=function($__meta$jscomp$26$$,$__extmap$jscomp$26$$,$__hash$jscomp$85$$){this.$__meta$=$__meta$jscomp$26$$;this.$__extmap$=$__extmap$jscomp$26$$;this.$__hash$=$__hash$jscomp$85$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$APP.$app$util$mouse$mouse_event_QMARK_$$=function($v$jscomp$539$$){return $v$jscomp$539$$ instanceof $APP.$app$util$mouse$MouseEvent$$};$APP.$app$util$mouse$pointer_event_QMARK_$$=function($v$jscomp$540$$){return $v$jscomp$540$$ instanceof $APP.$app$util$mouse$PointerEvent$$};$app$util$mouse$blur_event_QMARK_$$=function($v$jscomp$542$$){return $v$jscomp$542$$ instanceof $APP.$app$util$mouse$BlurEvent$$};
$app$util$mouse$mouse_down_event_QMARK_$$=function($v$jscomp$543$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1953$down$$,$v$jscomp$543$$.type)};$app$util$mouse$mouse_up_event_QMARK_$$=function($v$jscomp$544$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1954$up$$,$v$jscomp$544$$.type)};$APP.$app$util$mouse$get_pointer_position$$=function($ev$jscomp$2$$){return $ev$jscomp$2$$.pt};
$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$=function($stream$jscomp$13$$,$blur_QMARK__p__49670$$){var $interrupt_QMARK__map__49671__$1$$=$APP.$cljs$core$__destructure_map$$($blur_QMARK__p__49670$$);$blur_QMARK__p__49670$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($interrupt_QMARK__map__49671__$1$$,$cljs$cst$2166$blur_QMARK_$$,!0);var $up_mouse_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($interrupt_QMARK__map__49671__$1$$,$cljs$cst$2167$up_mouse_QMARK_$$,
!0);$interrupt_QMARK__map__49671__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($interrupt_QMARK__map__49671__$1$$,$cljs$cst$2168$interrupt_QMARK_$$,!0);return $APP.$beicon$v2$core$merge$$($APP.$cljs$core$truth_$$($blur_QMARK__p__49670$$)?$APP.$beicon$v2$core$filter$$($app$util$mouse$blur_event_QMARK_$$,$stream$jscomp$13$$):$APP.$beicon$v2$core$empty$$(),$APP.$cljs$core$truth_$$($up_mouse_QMARK_$$)?$APP.$beicon$v2$core$filter$$($app$util$mouse$mouse_up_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($APP.$app$util$mouse$mouse_event_QMARK_$$,
$stream$jscomp$13$$)):$APP.$beicon$v2$core$empty$$(),$APP.$cljs$core$truth_$$($interrupt_QMARK__map__49671__$1$$)?$APP.$beicon$v2$core$filter$$(function($p1__49666_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__49666_SHARP_$$,$APP.$cljs$cst$2169$interrupt$$)},$stream$jscomp$13$$):$APP.$beicon$v2$core$empty$$())};
$APP.$app$main$refs$select_libraries$$=function($files$jscomp$1$$,$file_id$jscomp$11$$){return $APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce_kv$$(function($result$jscomp$211$$,$id$jscomp$214$$,$file$jscomp$12$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$214$$,$file_id$jscomp$11$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2180$library_of$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$12$$),$file_id$jscomp$11$$)?$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$211$$,
$id$jscomp$214$$,$file$jscomp$12$$):$result$jscomp$211$$},$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$files$jscomp$1$$))};
$APP.$app$main$refs$extract_selected_files$$=function($files$jscomp$3$$,$selected$jscomp$10$$){var $xform$jscomp$24$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__50166_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$3$$,$p1__50166_SHARP_$$)}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__50167_SHARP_$$){return $APP.$cljs$core$select_keys$$($p1__50167_SHARP_$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$2181$project_id$$,$APP.$cljs$cst$2182$is_shared$$],null))}));return $APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($xform$jscomp$24$$,$selected$jscomp$10$$))};
$app$main$refs$workspace_page_object_by_id$$=function($page_id$jscomp$14$$,$shape_id$jscomp$22$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__50229_SHARP_$$){return $app$main$data$helpers$lookup_shape$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__50229_SHARP_$$,$page_id$jscomp$14$$,$shape_id$jscomp$22$$)},$APP.$app$main$store$state$$,$APP.$cljs$core$_EQ_$$)};
$app$main$refs$children_objects$$=function($id$jscomp$219$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects$jscomp$165$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$165$$)),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$165$$,
$id$jscomp$219$$),$APP.$cljs$cst$1614$shapes$$))},$APP.$app$main$refs$workspace_page_objects$$,$APP.$cljs$core$_EQ_$$)};
$app$main$refs$all_children_objects$$=function($id$jscomp$220$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects$jscomp$166$$){var $children_ids$jscomp$3$$=$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$166$$,$id$jscomp$220$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$166$$)),
$children_ids$jscomp$3$$)},$APP.$app$main$refs$workspace_page_objects$$,$APP.$cljs$core$_EQ_$$)};$app$main$refs$workspace_modifiers_by_frame_id$$=function($frame_id$jscomp$23$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__50275_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__50275_SHARP_$$,$frame_id$jscomp$23$$)},$app$main$refs$workspace_frame_modifiers$$,$APP.$cljs$core$_EQ_$$)};
$app$main$refs$select_bool_children$$=function($id$jscomp$222$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__50279_SHARP_$$){return $app$main$data$helpers$select_bool_children$$($p1__50279_SHARP_$$,$id$jscomp$222$$)},$APP.$app$main$store$state$$,$APP.$cljs$core$_EQ_$$)};
$app$main$refs$is_child_selected_QMARK_$$=function($id$jscomp$223$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($children$jscomp$169_map__50286__$1_objects$jscomp$168_p__50285$$){$children$jscomp$169_map__50286__$1_objects$jscomp$168_p__50285$$=$APP.$cljs$core$__destructure_map$$($children$jscomp$169_map__50286__$1_objects$jscomp$168_p__50285$$);var $selected$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$169_map__50286__$1_objects$jscomp$168_p__50285$$,
$APP.$cljs$cst$1921$selected$$);$children$jscomp$169_map__50286__$1_objects$jscomp$168_p__50285$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$169_map__50286__$1_objects$jscomp$168_p__50285$$,$APP.$cljs$cst$1631$objects$$);$children$jscomp$169_map__50286__$1_objects$jscomp$168_p__50285$$=$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$169_map__50286__$1_objects$jscomp$168_p__50285$$,$id$jscomp$223$$);return $APP.$cljs$core$some$$(function($p1__50282_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($selected$jscomp$14$$,
$p1__50282_SHARP_$$)},$children$jscomp$169_map__50286__$1_objects$jscomp$168_p__50285$$)},$app$main$refs$selected_shapes_data$$,$APP.$cljs$core$_EQ_$$)};
$APP.$app$main$refs$workspace_thumbnail_by_id$$=function($object_id$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($G__50363_state$jscomp$100$$){$G__50363_state$jscomp$100$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__50363_state$jscomp$100$$,$APP.$cljs$cst$2229$thumbnails$$),$object_id$$);return $G__50363_state$jscomp$100$$==null?null:$APP.$app$config$resolve_media$$($G__50363_state$jscomp$100$$)},
$APP.$app$main$store$state$$)};$APP.$app$main$refs$workspace_text_modifier_by_id$$=function($id$jscomp$225$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__50371_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__50371_SHARP_$$,$id$jscomp$225$$)},$APP.$app$main$refs$workspace_text_modifier$$,$APP.$cljs$core$_EQ_$$)};
$app$util$sse$read_stream$$=function($stream$jscomp$15$$){return $APP.$beicon$v2$core$mapcat$$(function($data$jscomp$143_data__$1$jscomp$4_event$jscomp$57$$){var $type$jscomp$361$$=$data$jscomp$143_data__$1$jscomp$4_event$jscomp$57$$.event;$data$jscomp$143_data__$1$jscomp$4_event$jscomp$57$$=$data$jscomp$143_data__$1$jscomp$4_event$jscomp$57$$.data;$data$jscomp$143_data__$1$jscomp$4_event$jscomp$57$$=$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$143_data__$1$jscomp$4_event$jscomp$57$$):
$APP.$app$common$transit$decode_str$$($data$jscomp$143_data__$1$jscomp$4_event$jscomp$57$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("error",$type$jscomp$361$$)?$APP.$beicon$v2$core$throw$0$$($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("stream exception",$data$jscomp$143_data__$1$jscomp$4_event$jscomp$57$$)):(0,$APP.$beicon$v2$core$of$$)({type:$type$jscomp$361$$,data:$data$jscomp$143_data__$1$jscomp$4_event$jscomp$57$$})},$APP.$beicon$v2$core$create$$(function($subs$jscomp$10$$){var $reader$jscomp$51$$=
$stream$jscomp$15$$.getReader();(function $app$util$sse$read_stream_$_pump$$(){return $reader$jscomp$51$$.read().then(function($result$jscomp$213$$){if($APP.$cljs$core$truth_$$($result$jscomp$213$$.done))return $subs$jscomp$10$$.complete();$subs$jscomp$10$$.next($result$jscomp$213$$.value);return $app$util$sse$read_stream_$_pump$$()}).catch(function($cause$jscomp$34$$){return $subs$jscomp$10$$.error($cause$jscomp$34$$)})})();return function(){return $reader$jscomp$51$$.cancel()}}))};
$APP.$app$util$sse$get_payload$$=function($event$jscomp$59$$){return $event$jscomp$59$$.data};$APP.$app$util$sse$end_of_stream_QMARK_$$=function($event$jscomp$60$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("end",$event$jscomp$60$$.type)};
$app$main$repo$with_retry$cljs$0core$0IFn$0_invoke$0arity$03$$=function($observable_fn$jscomp$2$$,$config$jscomp$14$$,$attempt$$){var $map__49675_map__49675__$1$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$repo$default_retry_config$$,$config$jscomp$14$$]));$map__49675_map__49675__$1$$=$APP.$cljs$core$__destructure_map$$($map__49675_map__49675__$1$$);var $max_retries$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49675_map__49675__$1$$,
$cljs$cst$2249$max_retries$$),$base_delay_ms$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49675_map__49675__$1$$,$cljs$cst$2250$base_delay_ms$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$35$$){if($APP.$cljs$core$contains_QMARK_$$($app$main$repo$retryable_types$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($cause$jscomp$35$$)))&&$attempt$$<$max_retries$$){var $delay_ms$$=$base_delay_ms$$*
(1<<$attempt$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.repo",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"retrying request"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$2251$attempt$$,$attempt$$+1],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1325$delay$$,$delay_ms$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$849$error$$,$APP.$cljs$core$ex_message$$($cause$jscomp$35$$)],null)],null)}),null,"app.main.repo",$APP.$cljs$cst$1162$warn$$,!1);return $APP.$beicon$v2$core$mapcat$$(function(){return $app$main$repo$with_retry$cljs$0core$0IFn$0_invoke$0arity$03$$($observable_fn$jscomp$2$$,
$config$jscomp$14$$,$attempt$$+1)},(0,$APP.$beicon$v2$core$timer$$)($delay_ms$$))}return $APP.$beicon$v2$core$throw$0$$($cause$jscomp$35$$)},$observable_fn$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$observable_fn$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$observable_fn$jscomp$2$$())};
$APP.$app$main$repo$handle_response$$=function($map__49680__$1_p__49678$$){$map__49680__$1_p__49678$$=$APP.$cljs$core$__destructure_map$$($map__49680__$1_p__49678$$);var $status$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49680__$1_p__49678$$,$APP.$cljs$cst$109$status$$),$body$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49680__$1_p__49678$$,$APP.$cljs$cst$1581$body$$),$headers$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49680__$1_p__49678$$,
$cljs$cst$1580$headers$$),$uri$jscomp$66$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49680__$1_p__49678$$,$APP.$cljs$cst$1579$uri$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(204,$status$jscomp$13$$)?(0,$APP.$beicon$v2$core$of$$)(null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(502,$status$jscomp$13$$)?$APP.$beicon$v2$core$throw$0$$($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("http error",new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$2248$bad_gateway$$],null))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(503,$status$jscomp$13$$)?$APP.$beicon$v2$core$throw$0$$($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("http error",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$2247$service_unavailable$$],null))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($map__49680__$1_p__49678$$))?
$APP.$beicon$v2$core$throw$0$$($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("http error",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$2246$offline$$],null))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(200,$status$jscomp$13$$)?(0,$APP.$beicon$v2$core$of$$)($body$jscomp$8$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(413,$status$jscomp$13$$)?$APP.$beicon$v2$core$throw$0$$($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("http error",
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2252$validation$$,$APP.$cljs$cst$273$code$$,$cljs$cst$2253$request_body_too_large$$],null))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($status$jscomp$13$$,403)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("cloudflare",$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($headers$jscomp$9$$,"server"))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("challenge",$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($headers$jscomp$9$$,
"cf-mitigated")))?$APP.$beicon$v2$core$throw$0$$($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("http error",new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2254$authorization$$,$APP.$cljs$cst$273$code$$,$cljs$cst$2255$challenge_required$$],null))):$status$jscomp$13$$>=400&&$APP.$cljs$core$map_QMARK_$$($body$jscomp$8$$)?$APP.$beicon$v2$core$throw$0$$($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("http error",$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($body$jscomp$8$$,
$APP.$cljs$cst$1579$uri$$,$uri$jscomp$66$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$109$status$$,$status$jscomp$13$$])))):$APP.$beicon$v2$core$throw$0$$($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("unable to process repository response",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$139$type$$,$cljs$cst$1752$internal$$,
$APP.$cljs$cst$273$code$$,$cljs$cst$2256$unable_to_process_repository_response$$,$APP.$cljs$cst$275$hint$$,"unable to process repository response",$APP.$cljs$cst$1579$uri$$,$uri$jscomp$66$$,$APP.$cljs$cst$109$status$$,$status$jscomp$13$$,$cljs$cst$1580$headers$$,$headers$jscomp$9$$,$APP.$cljs$cst$142$data$$,$body$jscomp$8$$],null),null])),null))};
$app$main$repo$send_BANG_$$=function($id$jscomp$228_nid$$,$params$jscomp$109$$){function $make_request$$(){return $APP.$beicon$v2$core$mapcat$$(function($map__49689__$1_p__49688$$){$map__49689__$1_p__49688$$=$APP.$cljs$core$__destructure_map$$($map__49689__$1_p__49688$$);var $ctype_headers$jscomp$10_response_stream_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49689__$1_p__49688$$,$cljs$cst$1580$headers$$),$body$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49689__$1_p__49688$$,
$APP.$cljs$cst$1581$body$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.repo",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"response received"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$,$id__$1$jscomp$1$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2278$elapsed$$,$tpoint$$()],null)],null)}),null,"app.main.repo",$APP.$cljs$cst$144$trace$$,!1);$ctype_headers$jscomp$10_response_stream_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ctype_headers$jscomp$10_response_stream_QMARK_$$,"content-type");$ctype_headers$jscomp$10_response_stream_QMARK_$$=$APP.$cuerdas$core$starts_with_QMARK_$$($ctype_headers$jscomp$10_response_stream_QMARK_$$,
"text/event-stream");var $tpoint__$1$$=$app$common$time$tpoint_ms$$();if($ctype_headers$jscomp$10_response_stream_QMARK_$$&&$APP.$cljs$core$not$$($stream_QMARK_$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("expected normal response, received sse stream",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$272$assertion$$,
$APP.$cljs$cst$273$code$$,$cljs$cst$2279$unexpected_response$$,$APP.$cljs$cst$275$hint$$,"expected normal response, received sse stream",$APP.$cljs$cst$1579$uri$$,$APP.$cljs$cst$1579$uri$$.$cljs$core$IFn$_invoke$arity$1$($map__49689__$1_p__49688$$),$APP.$cljs$cst$109$status$$,$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($map__49689__$1_p__49688$$)],null),null])),null);return $ctype_headers$jscomp$10_response_stream_QMARK_$$?$app$util$sse$read_stream$$($body$jscomp$9$$.pipeThrough(new TextDecoderStream).pipeThrough(new $shadow$js$shim$module$0eventsource_parser$0stream$$.EventSourceParserStream)):
$APP.$beicon$v2$core$mapcat$$($APP.$app$main$repo$handle_response$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.repo",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,
"response decoded"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$id__$1$jscomp$1$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2278$elapsed$$,$tpoint__$1$$()],null)],null)}),null,"app.main.repo",$APP.$cljs$cst$144$trace$$,!1);return null},$APP.$beicon$v2$core$map$$($decode_fn$jscomp$3$$,$app$util$http$process_response_type$$($response_type__$1$$,$map__49689__$1_p__49688$$))))},
$APP.$beicon$v2$core$map$$($app$util$http$response__GT_map$$,$APP.$app$util$http$fetch$$($request$jscomp$7$$)))}var $map__49684_response_type$jscomp$2$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$main$repo$default_options$$,$id$jscomp$228_nid$$),null])),$map__49684__$1_rename_to$$=$APP.$cljs$core$__destructure_map$$($map__49684_response_type$jscomp$2$$);$map__49684_response_type$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49684__$1_rename_to$$,$APP.$cljs$cst$1587$response_type$$);var $stream_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49684__$1_rename_to$$,$cljs$cst$2268$stream_QMARK_$$),$form_data_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49684__$1_rename_to$$,$cljs$cst$2271$form_data_QMARK_$$),$method$jscomp$45_raw_transit_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49684__$1_rename_to$$,
$cljs$cst$2275$raw_transit_QMARK_$$),$query_params$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49684__$1_rename_to$$,$APP.$cljs$cst$2269$query_params$$);$map__49684__$1_rename_to$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49684__$1_rename_to$$,$cljs$cst$2273$rename_to$$);var $decode_fn$jscomp$3$$=$APP.$cljs$core$truth_$$($method$jscomp$45_raw_transit_QMARK_$$)?$app$util$http$conditional_error_decode_transit$$:$app$util$http$conditional_decode_transit$$,$id__$1$jscomp$1$$=
$APP.$cljs$core$truth_$$($map__49684__$1_rename_to$$)?$map__49684__$1_rename_to$$:$id$jscomp$228_nid$$;$id$jscomp$228_nid$$=$APP.$cljs$core$name$$($id__$1$jscomp$1$$);$method$jscomp$45_raw_transit_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($query_params$$,$APP.$cljs$cst$2124$all$$)?$APP.$cljs$cst$1297$get$$:$APP.$cuerdas$core$starts_with_QMARK_$$($id$jscomp$228_nid$$,"get-")?$APP.$cljs$cst$1297$get$$:$APP.$cljs$cst$2276$post$$;var $response_type__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($map__49684_response_type$jscomp$2$$,
$APP.$cljs$cst$1588$text$$),$request$jscomp$7$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1578$method$$,$method$jscomp$45_raw_transit_QMARK_$$,$APP.$cljs$cst$1579$uri$$,$APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"api/main/methods/",$id$jscomp$228_nid$$])),$APP.$cljs$cst$1583$credentials$$,"include",$cljs$cst$1580$headers$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,["accept","application/transit+json,text/event-stream,*/*","x-external-session-id",$APP.$app$config$external_session_id$$(),"x-session-id",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$session_id$$),"x-event-origin",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($params$jscomp$109$$))],null),$APP.$cljs$cst$1581$body$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($method$jscomp$45_raw_transit_QMARK_$$,
$APP.$cljs$cst$2276$post$$)?$APP.$cljs$core$truth_$$($form_data_QMARK_$$)?$app$util$http$form_data$$($params$jscomp$109$$):new $APP.$app$util$http$t_app$0util$0http45214$$($params$jscomp$109$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$):null,$APP.$cljs$cst$747$query$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($method$jscomp$45_raw_transit_QMARK_$$,$APP.$cljs$cst$1297$get$$)?$params$jscomp$109$$:$APP.$cljs$core$truth_$$($query_params$$)?$APP.$cljs$core$select_keys$$($params$jscomp$109$$,
$query_params$$):null,$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$core$truth_$$($stream_QMARK_$$)?null:$response_type__$1$$],null),$tpoint$$=$app$common$time$tpoint_ms$$();$APP.$app$common$logging$enabled_QMARK_$$("app.main.repo",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$275$hint$$,"make request"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$id__$1$jscomp$1$$],null)],null)}),null,"app.main.repo",$APP.$cljs$cst$144$trace$$,!1);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$get$$,$method$jscomp$45_raw_transit_QMARK_$$)?$app$main$repo$with_retry$cljs$0core$0IFn$0_invoke$0arity$03$$($make_request$$,$app$main$repo$default_retry_config$$,0):
$make_request$$()};$app$common$i18n$c$$=function($x$jscomp$1131$$){return $x$jscomp$1131$$};$shadow$esm$dynamic_import$$=function($what$$){return shadow_esm_import($what$$)};
$APP.$shadow$esm$load_by_name$$=function($s$jscomp$529_the_name$jscomp$1$$){$s$jscomp$529_the_name$jscomp$1$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$529_the_name$jscomp$1$$);var $info$jscomp$4$$=$shadow$esm$loadables$$[$s$jscomp$529_the_name$jscomp$1$$];if(!$APP.$cljs$core$truth_$$($info$jscomp$4$$))throw Error(["could not find loadable info for: ",$s$jscomp$529_the_name$jscomp$1$$].join(""));var $accessor$$=$info$jscomp$4$$.get;return $shadow$esm$dynamic_import$$(["./",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$4$$.module),
".js"].join("")).then(function(){return $accessor$$})};$shadow$esm$add_loadable$$=function($the_name$jscomp$2$$,$module$jscomp$4$$,$accessor$jscomp$1$$){$shadow$esm$loadables$$[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($the_name$jscomp$2$$)]={module:$module$jscomp$4$$,get:$accessor$jscomp$1$$}};
$app$util$i18n$parse_locale$$=function($locale$jscomp$5_locale__$1$jscomp$1$$){$locale$jscomp$5_locale__$1$jscomp$1$$=$APP.$cuerdas$core$replace$$($APP.$cuerdas$core$lower$$($locale$jscomp$5_locale__$1$jscomp$1$$),"-","_");var $G__49784$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$locale$jscomp$5_locale__$1$jscomp$1$$],null);return $APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($locale$jscomp$5_locale__$1$jscomp$1$$,"_"))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__49784$$,
$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($locale$jscomp$5_locale__$1$jscomp$1$$,0,2)):$G__49784$$};
$app$util$i18n$autodetect$$=function(){for(var $supported$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$APP.$app$util$i18n$supported_locales$$)),$locales$jscomp$19$$=$APP.$cljs$core$seq$$($APP.$cljs$core$_deref$$($app$util$i18n$browser_locales$$));;){var $locale$jscomp$6_temp__5823__auto__$jscomp$122$$=$APP.$cljs$core$first$$($locales$jscomp$19$$);if($APP.$cljs$core$truth_$$($locale$jscomp$6_temp__5823__auto__$jscomp$122$$)){if($APP.$cljs$core$contains_QMARK_$$($supported$$,
$locale$jscomp$6_temp__5823__auto__$jscomp$122$$))return $locale$jscomp$6_temp__5823__auto__$jscomp$122$$;$locales$jscomp$19$$=$APP.$cljs$core$rest$$($locales$jscomp$19$$)}else return"en"}};$APP.$app$util$i18n$get_translations$$=function(){return $APP.$app$util$globals$global$$.penpotTranslations};
$APP.$app$util$i18n$load$$=function($locale$jscomp$8$$){var $path$jscomp$188$$=["./translation.",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($locale$jscomp$8$$),".js?version\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version_tag$$)].join("");return $promesa$core$fnly$cljs$0core$0IFn$0_invoke$0arity$02$$(function($JSCompiler_temp$jscomp$10782_data$jscomp$146$$,$cause$jscomp$36$$){$APP.$cljs$core$truth_$$($cause$jscomp$36$$)?$JSCompiler_temp$jscomp$10782_data$jscomp$146$$=
console.error("unexpected error on fetching locale",$cause$jscomp$36$$):($APP.$app$util$i18n$get_translations$$()[$locale$jscomp$8$$]=$JSCompiler_temp$jscomp$10782_data$jscomp$146$$,$JSCompiler_temp$jscomp$10782_data$jscomp$146$$=null);return $JSCompiler_temp$jscomp$10782_data$jscomp$146$$},$APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($result$jscomp$214$$){return $result$jscomp$214$$["default"]},$shadow$esm$dynamic_import$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$188$$))))};
$app$util$i18n$set_locale$$=function($lname$$){var $lname__$1$$=$lname$$==null||$APP.$cuerdas$core$empty_QMARK_$$($lname$$)?$app$util$i18n$autodetect$$():function(){for(var $supported$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$),$APP.$app$util$i18n$supported_locales$$),$locales$jscomp$20$$=$APP.$cljs$core$seq$$($app$util$i18n$parse_locale$$($lname$$));;){var $locale$jscomp$9_temp__5823__auto__$jscomp$123$$=
$APP.$cljs$core$first$$($locales$jscomp$20$$);if($APP.$cljs$core$truth_$$($locale$jscomp$9_temp__5823__auto__$jscomp$123$$)){if($APP.$cljs$core$contains_QMARK_$$($supported$jscomp$1$$,$locale$jscomp$9_temp__5823__auto__$jscomp$123$$))return $locale$jscomp$9_temp__5823__auto__$jscomp$123$$;$locales$jscomp$20$$=$APP.$cljs$core$rest$$($locales$jscomp$20$$)}else return"en"}}();return $promesa$core$fnly$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){$APP.$app$util$i18n$_STAR_current_locale_STAR_$$=$lname__$1$$;
return $APP.$cljs$core$reset_BANG_$$($app$util$i18n$locale$$,$lname__$1$$)},$APP.$app$util$i18n$load$$($lname__$1$$))};$app$util$i18n$C$$=function($val$jscomp$164$$){this.$val$=$val$jscomp$164$$;this.$cljs$lang$protocol_mask$partition0$$=32768;this.$cljs$lang$protocol_mask$partition1$$=0};$app$util$i18n$c_QMARK_$$=function($r$jscomp$105$$){return $r$jscomp$105$$ instanceof $app$util$i18n$C$$};$APP.$app$util$i18n$c$$=function($x$jscomp$1132$$){return new $app$util$i18n$C$$($x$jscomp$1132$$)};
$APP.$app$util$i18n$tr_html_STAR_$$=function($props_49843_tag_name__$1$$){var $content$jscomp$104$$=$props_49843_tag_name__$1$$.content,$on_click$$=$props_49843_tag_name__$1$$.onClick,$class$$jscomp$2$$=$props_49843_tag_name__$1$$.className;$props_49843_tag_name__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_49843_tag_name__$1$$.tagName,"p");return(0,$APP.$rumext$v2$jsx$$)($props_49843_tag_name__$1$$,{dangerouslySetInnerHTML:{__html:$content$jscomp$104$$},className:$class$$jscomp$2$$,
onClick:$on_click$$})};$APP.$app$main$data$event$event$$=function($props$jscomp$82$$){return $APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2336$app_DOT_main_DOT_data_DOT_event_SLASH_event$$,$props$jscomp$82$$)};
$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$=function($props$jscomp$83$$){return $app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$uuid$next$$(),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$83$$),$props$jscomp$83$$)};
$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$=function($type$jscomp$365$$,$props$jscomp$84$$){return $app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$uuid$next$$(),$type$jscomp$365$$,$props$jscomp$84$$)};
$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$03$$=function($id$jscomp$232$$,$type$jscomp$366$$,$props$jscomp$85$$){typeof $app$main$data$modal$show_modal_51434$$==="undefined"&&($app$main$data$modal$show_modal_51434$$=function($id$jscomp$233$$,$type$jscomp$367$$,$props$jscomp$86$$,$meta51435$$){this.id=$id$jscomp$233$$;this.type=$type$jscomp$367$$;this.props=$props$jscomp$86$$;this.$meta51435$=$meta51435$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$modal$show_modal_51434$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$modal$show_modal_51434$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2337$app_DOT_main_DOT_data_DOT_modal_SLASH_show_modal$$},$app$main$data$modal$show_modal_51434$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_51436$$,$meta51435__$1$$){return new $app$main$data$modal$show_modal_51434$$(this.id,this.type,this.props,$meta51435__$1$$)},
$app$main$data$modal$show_modal_51434$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta51435$},$app$main$data$modal$show_modal_51434$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$modal$show_modal_51434$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.props,$APP.$cljs$cst$139$type$$),$APP.$cljs$cst$725$name$$,
this.type)},$app$main$data$modal$show_modal_51434$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$modal$show_modal_51434$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1425$$,$state$jscomp$104$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$104$$,$APP.$cljs$cst$2338$app_DOT_main_DOT_data_DOT_modal_SLASH_modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$139$type$$,
this.type,$APP.$cljs$cst$575$props$$,this.props,$APP.$cljs$cst$2339$allow_click_outside$$,!1],null))});return new $app$main$data$modal$show_modal_51434$$($id$jscomp$232$$,$type$jscomp$366$$,$props$jscomp$85$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$modal$hide$$=function(){typeof $app$main$data$modal$hide_modal_51468$$==="undefined"&&($app$main$data$modal$hide_modal_51468$$=function($meta51469$$){this.$meta51469$=$meta51469$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$modal$hide_modal_51468$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$modal$hide_modal_51468$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2341$app_DOT_main_DOT_data_DOT_modal_SLASH_hide_modal$$},
$app$main$data$modal$hide_modal_51468$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_51470$$,$meta51469__$1$$){return new $app$main$data$modal$hide_modal_51468$$($meta51469__$1$$)},$app$main$data$modal$hide_modal_51468$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta51469$},$app$main$data$modal$hide_modal_51468$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$modal$hide_modal_51468$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$1427$$,$state$jscomp$106$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$106$$,$APP.$cljs$cst$2338$app_DOT_main_DOT_data_DOT_modal_SLASH_modal$$)});return new $app$main$data$modal$hide_modal_51468$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$modal$update$$=function($options$jscomp$448$$){typeof $app$main$data$modal$update_modal_51528$$==="undefined"&&($app$main$data$modal$update_modal_51528$$=function($options$jscomp$449$$,$meta51529$$){this.options=$options$jscomp$449$$;this.$meta51529$=$meta51529$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$modal$update_modal_51528$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$modal$update_modal_51528$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$2342$app_DOT_main_DOT_data_DOT_modal_SLASH_update_modal$$},$app$main$data$modal$update_modal_51528$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_51530$$,$meta51529__$1$$){return new $app$main$data$modal$update_modal_51528$$(this.options,$meta51529__$1$$)},$app$main$data$modal$update_modal_51528$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta51529$},$app$main$data$modal$update_modal_51528$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$modal$update_modal_51528$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1428$$,$state$jscomp$107$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2338$app_DOT_main_DOT_data_DOT_modal_SLASH_modal$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$107$$))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$107$$,$APP.$cljs$cst$2338$app_DOT_main_DOT_data_DOT_modal_SLASH_modal$$,$APP.$cljs$core$merge$$,this.options):
$state$jscomp$107$$});return new $app$main$data$modal$update_modal_51528$$($options$jscomp$448$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($type$jscomp$368$$,$props$jscomp$90$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($type$jscomp$368$$,$props$jscomp$90$$))};
$APP.$app$main$data$modal$disallow_click_outside_BANG_$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$update$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2339$allow_click_outside$$,!1],null)))};$APP.$app$main$data$modal$hide_BANG_$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())};
$APP.$app$main$data$notifications$show$$=function($data$jscomp$151$$){typeof $app$main$data$notifications$show_49872$$==="undefined"&&($app$main$data$notifications$show_49872$$=function($data$jscomp$152$$,$meta49873$$){this.data=$data$jscomp$152$$;this.$meta49873$=$meta49873$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$notifications$show_49872$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$notifications$show_49872$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$2358$app_DOT_main_DOT_data_DOT_notifications_SLASH_show$$},$app$main$data$notifications$show_49872$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_49874$$,$meta49873__$1$$){return new $app$main$data$notifications$show_49872$$(this.data,$meta49873__$1$$)},$app$main$data$notifications$show_49872$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta49873$},$app$main$data$notifications$show_49872$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$notifications$show_49872$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1429_notification$$,$state$jscomp$108$$){$_$jscomp$1429_notification$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.data,$APP.$cljs$cst$109$status$$,$APP.$cljs$cst$2346$visible$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$108$$,$APP.$cljs$cst$2359$notification$$,$_$jscomp$1429_notification$$)},$app$main$data$notifications$show_49872$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$notifications$show_49872$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1430$$,$state$jscomp$109$$,$stream$jscomp$18$$){var $self__$jscomp$3034$$=this;return $APP.$beicon$v2$core$merge$$(function(){var $stopper$jscomp$1$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$2360$app_DOT_main_DOT_data_DOT_notifications_SLASH_hide$$),$stream$jscomp$18$$),$route_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$109$$,
$APP.$cljs$cst$2171$route$$),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$725$name$$);return $APP.$beicon$v2$core$take_until$$($stopper$jscomp$1$$,$APP.$beicon$v2$core$map$$($APP.$app$main$data$notifications$hide$$,$APP.$beicon$v2$core$filter$$(function($p1__49871_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($route_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__49871_SHARP_$$))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2361$app_DOT_main_DOT_router_SLASH_navigate$$),
$stream$jscomp$18$$)))))}(),$APP.$cljs$core$truth_$$($APP.$cljs$cst$2353$timeout$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3034$$.data))?function(){var $stopper$jscomp$2$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$2358$app_DOT_main_DOT_data_DOT_notifications_SLASH_show$$),$stream$jscomp$18$$);return $APP.$beicon$v2$core$take_until$$($stopper$jscomp$2$$,$APP.$beicon$v2$core$delay$$($APP.$cljs$cst$2353$timeout$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3034$$.data),
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$hide$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$app$main$data$notifications$hide$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$app$main$data$notifications$hide$$())))}():null)});return new $app$main$data$notifications$show_49872$$($data$jscomp$151$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$notifications$error$$=function($content$jscomp$105$$){return $APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$content$jscomp$105$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1671$fixed$$],null))};$APP.$app$main$data$notifications$info$cljs$0core$0IFn$0_invoke$0arity$01$$=function($content$jscomp$106$$){return $APP.$app$main$data$notifications$info$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$106$$)};
$APP.$app$main$data$notifications$info$cljs$0core$0IFn$0_invoke$0arity$02$$=function($content$jscomp$107$$){var $map__49908__$1_timeout$jscomp$10$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$map__49908__$1_timeout$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49908__$1_timeout$jscomp$10$$,$APP.$cljs$cst$2353$timeout$$,7E3);return $APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1637$content$$,
$content$jscomp$107$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1671$fixed$$,$APP.$cljs$cst$2353$timeout$$,$map__49908__$1_timeout$jscomp$10$$],null))};$APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$=function($content$jscomp$108$$){return $APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$108$$)};
$APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$02$$=function($content$jscomp$109$$){var $map__49913__$1_timeout$jscomp$11$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$map__49913__$1_timeout$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49913__$1_timeout$jscomp$11$$,$APP.$cljs$cst$2353$timeout$$,7E3);return $APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1637$content$$,
$content$jscomp$109$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$2344$success$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1671$fixed$$,$APP.$cljs$cst$2353$timeout$$,$map__49913__$1_timeout$jscomp$11$$],null))};$APP.$app$main$data$notifications$warn$cljs$0core$0IFn$0_invoke$0arity$01$$=function($content$jscomp$110$$){return $APP.$app$main$data$notifications$warn$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$110$$)};
$APP.$app$main$data$notifications$warn$cljs$0core$0IFn$0_invoke$0arity$02$$=function($content$jscomp$111$$){var $map__49920__$1_timeout$jscomp$12$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$map__49920__$1_timeout$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49920__$1_timeout$jscomp$12$$,$APP.$cljs$cst$2353$timeout$$,7E3);return $APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1637$content$$,
$content$jscomp$111$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$2343$warning$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1671$fixed$$,$APP.$cljs$cst$2353$timeout$$,$map__49920__$1_timeout$jscomp$12$$],null))};
$APP.$app$main$data$notifications$dialog$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($content$jscomp$112_p__49930$$){var $links$jscomp$1_map__49931__$1$$=$APP.$cljs$core$__destructure_map$$($content$jscomp$112_p__49930$$);$content$jscomp$112_p__49930$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($links$jscomp$1_map__49931__$1$$,$APP.$cljs$cst$1637$content$$);var $accept$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($links$jscomp$1_map__49931__$1$$,$APP.$cljs$cst$924$accept$$),
$cancel$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($links$jscomp$1_map__49931__$1$$,$APP.$cljs$cst$2355$cancel$$),$tag$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($links$jscomp$1_map__49931__$1$$,$APP.$cljs$cst$78$tag$$);$links$jscomp$1_map__49931__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($links$jscomp$1_map__49931__$1$$,$APP.$cljs$cst$2357$links$$);return $APP.$app$main$data$notifications$show$$($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$1637$content$$,$content$jscomp$112_p__49930$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2348$inline$$,$APP.$cljs$cst$924$accept$$,$accept$jscomp$5$$,$APP.$cljs$cst$2355$cancel$$,$cancel$$,$APP.$cljs$cst$2357$links$$,$links$jscomp$1_map__49931__$1$$,$APP.$cljs$cst$78$tag$$,$tag$jscomp$53$$],null)))};$reitit$impl$form_encode$$=function($s$jscomp$538$$){return $APP.$cljs$core$truth_$$($s$jscomp$538$$)?$APP.$clojure$string$replace$$(encodeURIComponent($s$jscomp$538$$),"%20","+"):null};
$APP.$reitit$impl$into_string$$=function($JSCompiler_temp$jscomp$894__$jscomp$1460$$){if($JSCompiler_temp$jscomp$894__$jscomp$1460$$!=null&&$JSCompiler_temp$jscomp$894__$jscomp$1460$$.$reitit$impl$IntoString$into_string$arity$1$!=null)$JSCompiler_temp$jscomp$894__$jscomp$1460$$=$JSCompiler_temp$jscomp$894__$jscomp$1460$$.$reitit$impl$IntoString$into_string$arity$1$($JSCompiler_temp$jscomp$894__$jscomp$1460$$);else{var $m__5372__auto__$jscomp$inline_5608_m__5374__auto__$jscomp$inline_5607$$=$APP.$reitit$impl$into_string$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$894__$jscomp$1460$$==
null?null:$JSCompiler_temp$jscomp$894__$jscomp$1460$$)];if($m__5372__auto__$jscomp$inline_5608_m__5374__auto__$jscomp$inline_5607$$!=null)$JSCompiler_temp$jscomp$894__$jscomp$1460$$=$m__5372__auto__$jscomp$inline_5608_m__5374__auto__$jscomp$inline_5607$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5608_m__5374__auto__$jscomp$inline_5607$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$894__$jscomp$1460$$):$m__5372__auto__$jscomp$inline_5608_m__5374__auto__$jscomp$inline_5607$$($JSCompiler_temp$jscomp$894__$jscomp$1460$$);
else if($m__5372__auto__$jscomp$inline_5608_m__5374__auto__$jscomp$inline_5607$$=$APP.$reitit$impl$into_string$$._,$m__5372__auto__$jscomp$inline_5608_m__5374__auto__$jscomp$inline_5607$$!=null)$JSCompiler_temp$jscomp$894__$jscomp$1460$$=$m__5372__auto__$jscomp$inline_5608_m__5374__auto__$jscomp$inline_5607$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_5608_m__5374__auto__$jscomp$inline_5607$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$894__$jscomp$1460$$):$m__5372__auto__$jscomp$inline_5608_m__5374__auto__$jscomp$inline_5607$$($JSCompiler_temp$jscomp$894__$jscomp$1460$$);
else throw $APP.$cljs$core$missing_protocol$$("IntoString.into-string",$JSCompiler_temp$jscomp$894__$jscomp$1460$$);}return $JSCompiler_temp$jscomp$894__$jscomp$1460$$};$reitit$impl$query_parameter$$=function($k$jscomp$613$$,$v$jscomp$557$$){return[$reitit$impl$form_encode$$($APP.$reitit$impl$into_string$$($k$jscomp$613$$)),"\x3d",$reitit$impl$form_encode$$($APP.$reitit$impl$into_string$$($v$jscomp$557$$))].join("")};
$reitit$impl$query_string$$=function($params$jscomp$135$$){return $APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$("\x26",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__51656_v$jscomp$558$$){var $k$jscomp$614$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51656_v$jscomp$558$$,0,null);$p__51656_v$jscomp$558$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51656_v$jscomp$558$$,1,null);return $APP.$cljs$core$sequential_QMARK_$$($p__51656_v$jscomp$558$$)||
$APP.$cljs$core$set_QMARK_$$($p__51656_v$jscomp$558$$)?$APP.$cljs$core$seq$$($p__51656_v$jscomp$558$$)?$APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$("\x26",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($reitit$impl$query_parameter$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$($k$jscomp$614$$),$p__51656_v$jscomp$558$$)):$reitit$impl$query_parameter$$($k$jscomp$614$$,""):$reitit$impl$query_parameter$$($k$jscomp$614$$,$p__51656_v$jscomp$558$$)},$params$jscomp$135$$))};
$APP.$reitit$core$expand$$=function($JSCompiler_temp$jscomp$895_this$$jscomp$744$$,$opts$jscomp$272$$){if($JSCompiler_temp$jscomp$895_this$$jscomp$744$$!=null&&$JSCompiler_temp$jscomp$895_this$$jscomp$744$$.$reitit$core$Expand$expand$arity$2$!=null)$JSCompiler_temp$jscomp$895_this$$jscomp$744$$=$JSCompiler_temp$jscomp$895_this$$jscomp$744$$.$reitit$core$Expand$expand$arity$2$($JSCompiler_temp$jscomp$895_this$$jscomp$744$$,$opts$jscomp$272$$);else{var $m__5372__auto__$jscomp$inline_5613_m__5374__auto__$jscomp$inline_5612$$=
$APP.$reitit$core$expand$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$895_this$$jscomp$744$$==null?null:$JSCompiler_temp$jscomp$895_this$$jscomp$744$$)];if($m__5372__auto__$jscomp$inline_5613_m__5374__auto__$jscomp$inline_5612$$!=null)$JSCompiler_temp$jscomp$895_this$$jscomp$744$$=$m__5372__auto__$jscomp$inline_5613_m__5374__auto__$jscomp$inline_5612$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_5613_m__5374__auto__$jscomp$inline_5612$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$895_this$$jscomp$744$$,
$opts$jscomp$272$$):$m__5372__auto__$jscomp$inline_5613_m__5374__auto__$jscomp$inline_5612$$($JSCompiler_temp$jscomp$895_this$$jscomp$744$$,$opts$jscomp$272$$);else if($m__5372__auto__$jscomp$inline_5613_m__5374__auto__$jscomp$inline_5612$$=$APP.$reitit$core$expand$$._,$m__5372__auto__$jscomp$inline_5613_m__5374__auto__$jscomp$inline_5612$$!=null)$JSCompiler_temp$jscomp$895_this$$jscomp$744$$=$m__5372__auto__$jscomp$inline_5613_m__5374__auto__$jscomp$inline_5612$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_5613_m__5374__auto__$jscomp$inline_5612$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$895_this$$jscomp$744$$,$opts$jscomp$272$$):$m__5372__auto__$jscomp$inline_5613_m__5374__auto__$jscomp$inline_5612$$($JSCompiler_temp$jscomp$895_this$$jscomp$744$$,$opts$jscomp$272$$);else throw $APP.$cljs$core$missing_protocol$$("Expand.expand",$JSCompiler_temp$jscomp$895_this$$jscomp$744$$);}return $JSCompiler_temp$jscomp$895_this$$jscomp$744$$};
$APP.$app$main$router$resolve$cljs$0core$0IFn$0_invoke$0arity$03$$=function($G__51888__$1$jscomp$inline_5617_router$jscomp$2_temp__5825__auto__$jscomp$144$$,$id$jscomp$235$$,$JSCompiler_temp$jscomp$896_params$jscomp$136$$){return $APP.$cljs$core$truth_$$($G__51888__$1$jscomp$inline_5617_router$jscomp$2_temp__5825__auto__$jscomp$144$$)?($G__51888__$1$jscomp$inline_5617_router$jscomp$2_temp__5825__auto__$jscomp$144$$=$APP.$reitit$core$match_by_name$$($G__51888__$1$jscomp$inline_5617_router$jscomp$2_temp__5825__auto__$jscomp$144$$,
$id$jscomp$235$$),$APP.$cljs$core$truth_$$($G__51888__$1$jscomp$inline_5617_router$jscomp$2_temp__5825__auto__$jscomp$144$$)?($G__51888__$1$jscomp$inline_5617_router$jscomp$2_temp__5825__auto__$jscomp$144$$=$G__51888__$1$jscomp$inline_5617_router$jscomp$2_temp__5825__auto__$jscomp$144$$==null?null:$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($G__51888__$1$jscomp$inline_5617_router$jscomp$2_temp__5825__auto__$jscomp$144$$),$JSCompiler_temp$jscomp$896_params$jscomp$136$$=$G__51888__$1$jscomp$inline_5617_router$jscomp$2_temp__5825__auto__$jscomp$144$$==
null?null:$APP.$cljs$core$seq$$($JSCompiler_temp$jscomp$896_params$jscomp$136$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__51888__$1$jscomp$inline_5617_router$jscomp$2_temp__5825__auto__$jscomp$144$$),"?",$reitit$impl$query_string$$($JSCompiler_temp$jscomp$896_params$jscomp$136$$)].join(""):$G__51888__$1$jscomp$inline_5617_router$jscomp$2_temp__5825__auto__$jscomp$144$$):$JSCompiler_temp$jscomp$896_params$jscomp$136$$=null,$JSCompiler_temp$jscomp$896_params$jscomp$136$$):null};
$APP.$app$main$router$navigate$$=function($var_args$jscomp$1052$$){for(var $args__5755__auto__$jscomp$170$$=[],$len__5749__auto___52442$$=arguments.length,$i__5750__auto___52446$$=0;;)if($i__5750__auto___52446$$<$len__5749__auto___52442$$)$args__5755__auto__$jscomp$170$$.push(arguments[$i__5750__auto___52446$$]),$i__5750__auto___52446$$+=1;else break;return $app$main$router$navigate$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],2<$args__5755__auto__$jscomp$170$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$170$$.slice(2),
0,null):null)};
$app$main$router$navigate$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($id$jscomp$236$$,$params$jscomp$139$$,$p__52231$$){var $map__52233__$1$$=$APP.$cljs$core$__destructure_map$$($p__52231$$),$replace$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52233__$1$$,$APP.$cljs$cst$2455$app_DOT_main_DOT_router_SLASH_replace$$),$new_window$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52233__$1$$,$APP.$cljs$cst$2456$app_DOT_main_DOT_router_SLASH_new_window$$);typeof $app$main$router$navigate_52236$$===
"undefined"&&($app$main$router$navigate_52236$$=function($id$jscomp$237$$,$params$jscomp$140$$,$p__52231$jscomp$1$$,$map__52233$jscomp$1$$,$options$jscomp$453$$,$replace$jscomp$1$$,$new_window$jscomp$2$$,$meta52237$$){this.id=$id$jscomp$237$$;this.params=$params$jscomp$140$$;this.$p__52231$=$p__52231$jscomp$1$$;this.$map__52233$=$map__52233$jscomp$1$$;this.options=$options$jscomp$453$$;this.replace=$replace$jscomp$1$$;this.$new_window$=$new_window$jscomp$2$$;this.$meta52237$=$meta52237$$;this.$cljs$lang$protocol_mask$partition0$$=
425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$router$navigate_52236$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$navigate_52236$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2361$app_DOT_main_DOT_router_SLASH_navigate$$},$app$main$router$navigate_52236$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52238$$,$meta52237__$1$$){return new $app$main$router$navigate_52236$$(this.id,this.params,
this.$p__52231$,this.$map__52233$,this.options,this.replace,this.$new_window$,$meta52237__$1$$)},$app$main$router$navigate_52236$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52237$},$app$main$router$navigate_52236$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$1430$params$$,this.params,$APP.$cljs$cst$873$options$$,this.options],null)},$app$main$router$navigate_52236$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$navigate_52236$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1524_router$jscomp$4_uri$jscomp$70$$,$name$jscomp$251_state$jscomp$113$$){var $self__$jscomp$3248$$=this;$_$jscomp$1524_router$jscomp$4_uri$jscomp$70$$=$APP.$cljs$cst$2172$router$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$251_state$jscomp$113$$);var $history__$1$$=$APP.$cljs$cst$2457$history$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$251_state$jscomp$113$$),
$path$jscomp$224$$=$APP.$app$main$router$resolve$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$1524_router$jscomp$4_uri$jscomp$70$$,$self__$jscomp$3248$$.id,$self__$jscomp$3248$$.params);return $self__$jscomp$3248$$.$new_window$?($name$jscomp$251_state$jscomp$113$$=function(){var $or__5025__auto__$jscomp$440$$=$APP.$cljs$cst$2458$app_DOT_main_DOT_router_SLASH_window_name$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3248$$.options);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$440$$)?
$or__5025__auto__$jscomp$440$$:"_blank"}(),$_$jscomp$1524_router$jscomp$4_uri$jscomp$70$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$config$public_uri$$,$APP.$cljs$cst$738$fragment$$,$path$jscomp$224$$),$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$1524_router$jscomp$4_uri$jscomp$70$$,$name$jscomp$251_state$jscomp$113$$,null)):$APP.$app$util$timers$asap$$(function(){$self__$jscomp$3248$$.replace?$history__$1$$?.$replaceToken$($path$jscomp$224$$):
$history__$1$$.$setToken$($path$jscomp$224$$)})});return new $app$main$router$navigate_52236$$($id$jscomp$236$$,$params$jscomp$139$$,$p__52231$$,$map__52233__$1$$,$map__52233__$1$$,$replace$$,$new_window$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$router$assign_exception$$=function($error$jscomp$48$$){typeof $app$main$router$assign_exception_52270$$==="undefined"&&($app$main$router$assign_exception_52270$$=function($error$jscomp$49$$,$meta52271$$){this.error=$error$jscomp$49$$;this.$meta52271$=$meta52271$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$router$assign_exception_52270$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$assign_exception_52270$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$2145$app_DOT_main_DOT_router_SLASH_assign_exception$$},$app$main$router$assign_exception_52270$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52272$$,$meta52271__$1$$){return new $app$main$router$assign_exception_52270$$(this.error,$meta52271__$1$$)},$app$main$router$assign_exception_52270$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52271$},$app$main$router$assign_exception_52270$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$router$assign_exception_52270$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1525$$,$state$jscomp$114$$){return this.error==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$114$$,$APP.$cljs$cst$727$exception$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$114$$,$APP.$cljs$cst$727$exception$$,this.error)});return new $app$main$router$assign_exception_52270$$($error$jscomp$48$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$=function($id$jscomp$238$$){return $APP.$app$main$router$navigate$$($id$jscomp$238$$,null)};$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$=function($id$jscomp$239$$,$params$jscomp$141$$){return $APP.$app$main$router$navigate$$($id$jscomp$239$$,$params$jscomp$141$$)};
$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($id$jscomp$240$$,$params$jscomp$142$$,$options$jscomp$454_p__52309$$){$options$jscomp$454_p__52309$$=$APP.$cljs$core$__destructure_map$$($options$jscomp$454_p__52309$$);return $app$main$router$navigate$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($id$jscomp$240$$,$params$jscomp$142$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$options$jscomp$454_p__52309$$]))};
$APP.$app$main$router$get_params$$=function($state$jscomp$116$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$116$$,$APP.$cljs$cst$2171$route$$),$APP.$cljs$cst$1430$params$$),$APP.$cljs$cst$747$query$$)};
$APP.$app$main$router$get_query_param$$=function($params$jscomp$143_v$jscomp$559$$,$k$jscomp$615$$){$params$jscomp$143_v$jscomp$559$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$143_v$jscomp$559$$,$k$jscomp$615$$);return $APP.$cljs$core$sequential_QMARK_$$($params$jscomp$143_v$jscomp$559$$)?$APP.$cljs$core$peek$$($params$jscomp$143_v$jscomp$559$$):$params$jscomp$143_v$jscomp$559$$};
$app$main$router$nav_back$$=function(){typeof $app$main$router$nav_back_52329$$==="undefined"&&($app$main$router$nav_back_52329$$=function($meta52331$$){this.$meta52331$=$meta52331$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$router$nav_back_52329$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$nav_back_52329$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2459$app_DOT_main_DOT_router_SLASH_nav_back$$},
$app$main$router$nav_back_52329$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52332$$,$meta52331__$1$$){return new $app$main$router$nav_back_52329$$($meta52331__$1$$)},$app$main$router$nav_back_52329$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52331$},$app$main$router$nav_back_52329$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$nav_back_52329$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $APP.$app$util$timers$asap$$($app$util$dom$browser_back$$)});
return new $app$main$router$nav_back_52329$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$router$nav_back_local$$=function(){var $location__$1$jscomp$1$$=document.location,$referrer$$=$APP.$app$common$uri$uri$$(document.referrer);return $APP.$cljs$cst$744$host$$.$cljs$core$IFn$_invoke$arity$1$($referrer$$)==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($location__$1$jscomp$1$$.hostname,$APP.$cljs$cst$744$host$$.$cljs$core$IFn$_invoke$arity$1$($referrer$$))?$app$main$router$nav_back$$():null};
$app$main$router$nav_root$$=function(){typeof $app$main$router$nav_root_52349$$==="undefined"&&($app$main$router$nav_root_52349$$=function($meta52350$$){this.$meta52350$=$meta52350$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$router$nav_root_52349$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$nav_root_52349$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2460$app_DOT_main_DOT_router_SLASH_nav_root$$},
$app$main$router$nav_root_52349$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52351$$,$meta52350__$1$$){return new $app$main$router$nav_root_52349$$($meta52350__$1$$)},$app$main$router$nav_root_52349$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52350$},$app$main$router$nav_root_52349$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$nav_root_52349$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $APP.$app$util$globals$location$$.href=
"/"});return new $app$main$router$nav_root_52349$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$router$reload$$=function(){typeof $app$main$router$reload_52363$$==="undefined"&&($app$main$router$reload_52363$$=function($force_QMARK_$jscomp$2$$,$meta52364$$){this.$force_QMARK_$=$force_QMARK_$jscomp$2$$;this.$meta52364$=$meta52364$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$router$reload_52363$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$reload_52363$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$2461$app_DOT_main_DOT_router_SLASH_reload$$},$app$main$router$reload_52363$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52365$$,$meta52364__$1$$){return new $app$main$router$reload_52363$$(this.$force_QMARK_$,$meta52364__$1$$)},$app$main$router$reload_52363$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52364$},$app$main$router$reload_52363$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$reload_52363$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=
function(){return $APP.$app$util$timers$asap$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$dom$reload_current_window$$,this.$force_QMARK_$))});return new $app$main$router$reload_52363$$(!0,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52376$$){var $map__52377__$1$$=$APP.$cljs$core$__destructure_map$$($p__52376$$),$href$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52377__$1$$,$APP.$cljs$cst$2462$href$$),$uri$jscomp$71$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52377__$1$$,$APP.$cljs$cst$1579$uri$$);typeof $app$main$router$nav_raw_52379$$==="undefined"&&($app$main$router$nav_raw_52379$$=function($p__52376$jscomp$1$$,
$map__52377$jscomp$1$$,$href$jscomp$3$$,$uri$jscomp$72$$,$meta52380$$){this.$p__52376$=$p__52376$jscomp$1$$;this.$map__52377$=$map__52377$jscomp$1$$;this.href=$href$jscomp$3$$;this.uri=$uri$jscomp$72$$;this.$meta52380$=$meta52380$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$router$nav_raw_52379$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$nav_raw_52379$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$2463$app_DOT_main_DOT_router_SLASH_nav_raw$$},$app$main$router$nav_raw_52379$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52381$$,$meta52380__$1$$){return new $app$main$router$nav_raw_52379$$(this.$p__52376$,this.$map__52377$,this.href,this.uri,$meta52380__$1$$)},$app$main$router$nav_raw_52379$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52380$},$app$main$router$nav_raw_52379$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$router$nav_raw_52379$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return typeof this.uri==="string"?$APP.$app$util$globals$location$$.replace(this.uri):typeof this.href==="string"?$APP.$app$util$globals$location$$.href=this.href:null});return new $app$main$router$nav_raw_52379$$($p__52376$$,$map__52377__$1$$,$href$jscomp$2$$,$uri$jscomp$71$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$common$force_reload_BANG_$$=function(){return location.reload()};
$app$main$data$common$hide_notifications_BANG_$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$hide$$())};
$APP.$app$main$data$common$handle_notification$$=function($p__52490$$){var $map__52493__$1$$=$APP.$cljs$core$__destructure_map$$($p__52490$$),$message$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52493__$1$$,$APP.$cljs$cst$141$message$$),$code$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52493__$1$$,$APP.$cljs$cst$273$code$$);typeof $app$main$data$common$show_notification_52495$$==="undefined"&&($app$main$data$common$show_notification_52495$$=
function($p__52490$jscomp$1$$,$map__52493$jscomp$1$$,$params$jscomp$148$$,$message$jscomp$58$$,$code$jscomp$23$$,$meta52496$$){this.$p__52490$=$p__52490$jscomp$1$$;this.$map__52493$=$map__52493$jscomp$1$$;this.params=$params$jscomp$148$$;this.message=$message$jscomp$58$$;this.code=$code$jscomp$23$$;this.$meta52496$=$meta52496$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$show_notification_52495$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$show_notification_52495$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2470$app_DOT_main_DOT_data_DOT_common_SLASH_show_notification$$},$app$main$data$common$show_notification_52495$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52497$$,$meta52496__$1$$){return new $app$main$data$common$show_notification_52495$$(this.$p__52490$,this.$map__52493$,this.params,this.message,this.code,$meta52496__$1$$)},
$app$main$data$common$show_notification_52495$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52496$},$app$main$data$common$show_notification_52495$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$show_notification_52495$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $G__52499$$=this.code;switch($G__52499$$ instanceof $APP.$cljs$core$Keyword$$?$G__52499$$.$fqn$:null){case "upgrade-version":return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$dialog$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("notifications.by-code.upgrade-version"),$APP.$cljs$cst$924$accept$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.refresh"),$APP.$cljs$cst$2354$callback$$,$app$main$data$common$force_reload_BANG_$$],null),$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$2359$notification$$])));case "maintenance":return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$dialog$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("notifications.by-code.maintenance"),$APP.$cljs$cst$924$accept$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.accept"),$APP.$cljs$cst$2354$callback$$,$app$main$data$common$hide_notifications_BANG_$$],null),$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$2359$notification$$])));default:return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$dialog$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$,
this.message,$APP.$cljs$cst$924$accept$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),$APP.$cljs$cst$2354$callback$$,$app$main$data$common$hide_notifications_BANG_$$],null),$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$2359$notification$$])))}});return new $app$main$data$common$show_notification_52495$$($p__52490$$,$map__52493__$1$$,$map__52493__$1$$,$message$jscomp$57$$,$code$jscomp$22$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$common$show_shared_dialog$$=function($file_id$jscomp$17$$,$add_shared$$){typeof $app$main$data$common$show_shared_dialog_52501$$==="undefined"&&($app$main$data$common$show_shared_dialog_52501$$=function($file_id$jscomp$18$$,$add_shared$jscomp$1$$,$meta52502$$){this.$file_id$=$file_id$jscomp$18$$;this.$add_shared$=$add_shared$jscomp$1$$;this.$meta52502$=$meta52502$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$show_shared_dialog_52501$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$show_shared_dialog_52501$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2471$app_DOT_main_DOT_data_DOT_common_SLASH_show_shared_dialog$$},$app$main$data$common$show_shared_dialog_52501$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52503$$,$meta52502__$1$$){return new $app$main$data$common$show_shared_dialog_52501$$(this.$file_id$,this.$add_shared$,$meta52502__$1$$)},$app$main$data$common$show_shared_dialog_52501$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta52502$},$app$main$data$common$show_shared_dialog_52501$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$show_shared_dialog_52501$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$3294$$=this;return $APP.$beicon$v2$core$map$$(function($summary$$){var $count$jscomp$69$$=$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($summary$$))+
$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2472$graphics$$.$cljs$core$IFn$_invoke$arity$1$($summary$$))+$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($summary$$))+$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($summary$$));return $APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
7,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.add-shared-confirm.message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($summary$$)])),$APP.$cljs$cst$141$message$$,$count$jscomp$69$$===0?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.add-shared-confirm-empty.hint"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.add-shared-confirm.hint"),
$APP.$cljs$cst$2474$cancel_label$$,$count$jscomp$69$$===0?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel"):$APP.$cljs$cst$2475$omit$$,$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.add-shared-confirm.accept"),$APP.$cljs$cst$2477$accept_style$$,$APP.$cljs$cst$2478$primary$$,$APP.$cljs$cst$2479$on_accept$$,$self__$jscomp$3294$$.$add_shared$],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2480$get_file_summary$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$self__$jscomp$3294$$.$file_id$],null)))});return new $app$main$data$common$show_shared_dialog_52501$$($file_id$jscomp$17$$,$add_shared$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$get_change_role_msg$$=function($G__52522__$1_role$$){$G__52522__$1_role$$=$G__52522__$1_role$$ instanceof $APP.$cljs$core$Keyword$$?$G__52522__$1_role$$.$fqn$:null;switch($G__52522__$1_role$$){case "viewer":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.permissions-change.viewer");case "editor":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.permissions-change.editor");case "admin":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.permissions-change.admin");
case "owner":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.permissions-change.owner");default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__52522__$1_role$$)].join(""));}};
$APP.$app$main$data$common$change_team_role$$=function($p__52526$$){var $map__52527__$1$$=$APP.$cljs$core$__destructure_map$$($p__52526$$),$team_id$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52527__$1$$,$APP.$cljs$cst$1927$team_id$$),$role$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52527__$1$$,$APP.$cljs$cst$2490$role$$);typeof $app$main$data$common$change_team_role_52528$$==="undefined"&&($app$main$data$common$change_team_role_52528$$=function($p__52526$jscomp$1$$,
$map__52527$jscomp$1$$,$team_id$jscomp$5$$,$role$jscomp$2$$,$meta52529$$){this.$p__52526$=$p__52526$jscomp$1$$;this.$map__52527$=$map__52527$jscomp$1$$;this.$team_id$=$team_id$jscomp$5$$;this.role=$role$jscomp$2$$;this.$meta52529$=$meta52529$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$change_team_role_52528$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$change_team_role_52528$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$2491$app_DOT_main_DOT_data_DOT_common_SLASH_change_team_role$$},$app$main$data$common$change_team_role_52528$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52530$$,$meta52529__$1$$){return new $app$main$data$common$change_team_role_52528$$(this.$p__52526$,this.$map__52527$,this.$team_id$,this.role,$meta52529__$1$$)},$app$main$data$common$change_team_role_52528$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52529$},$app$main$data$common$change_team_role_52528$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$change_team_role_52528$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1540_current_team_id$$,$state$jscomp$122$$){$_$jscomp$1540_current_team_id$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$122$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$team_id$,$_$jscomp$1540_current_team_id$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$info$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$data$common$get_change_role_msg$$(this.role))):
null},$app$main$data$common$change_team_role_52528$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$change_team_role_52528$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1541_permissions$$,$state$jscomp$123$$){$_$jscomp$1541_permissions$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$team$permissions_for_role$$,this.role);return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$123$$,
$APP.$cljs$cst$1722$permissions$$,$APP.$cljs$core$merge$$,$_$jscomp$1541_permissions$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2492$team$$,$APP.$cljs$cst$1722$permissions$$],null),$APP.$cljs$core$merge$$,$_$jscomp$1541_permissions$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2173$teams$$,this.$team_id$,$APP.$cljs$cst$1722$permissions$$],null),$APP.$cljs$core$merge$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_$jscomp$1541_permissions$$]))});return new $app$main$data$common$change_team_role_52528$$($p__52526$$,$map__52527__$1$$,$team_id$jscomp$4$$,$role$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$common$team_membership_change$$=function($p__52541$$){var $map__52542__$1$$=$APP.$cljs$core$__destructure_map$$($p__52541$$),$team_id$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52542__$1$$,$APP.$cljs$cst$1927$team_id$$),$team_name$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52542__$1$$,$APP.$cljs$cst$2493$team_name$$),$change$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52542__$1$$,$cljs$cst$2494$change$$);typeof $app$main$data$common$team_membership_change_52543$$===
"undefined"&&($app$main$data$common$team_membership_change_52543$$=function($p__52541$jscomp$1$$,$map__52542$jscomp$1$$,$team_id$jscomp$7$$,$team_name$jscomp$1$$,$change$jscomp$1$$,$meta52544$$){this.$p__52541$=$p__52541$jscomp$1$$;this.$map__52542$=$map__52542$jscomp$1$$;this.$team_id$=$team_id$jscomp$7$$;this.$team_name$=$team_name$jscomp$1$$;this.$change$=$change$jscomp$1$$;this.$meta52544$=$meta52544$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$common$team_membership_change_52543$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$team_membership_change_52543$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2495$app_DOT_main_DOT_data_DOT_common_SLASH_team_membership_change$$},$app$main$data$common$team_membership_change_52543$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52545$$,$meta52544__$1$$){return new $app$main$data$common$team_membership_change_52543$$(this.$p__52541$,
this.$map__52542$,this.$team_id$,this.$team_name$,this.$change$,$meta52544__$1$$)},$app$main$data$common$team_membership_change_52543$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52544$},$app$main$data$common$team_membership_change_52543$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$team_membership_change_52543$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1542$$,$state$jscomp$124$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$124$$,
$APP.$cljs$cst$1926$current_team_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$124$$,$APP.$cljs$cst$1914$profile$$),$APP.$cljs$cst$2496$default_team_id$$))},$app$main$data$common$team_membership_change_52543$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$team_membership_change_52543$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1543_message$jscomp$59$$,
$state$jscomp$125_team_id__$1$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2497$removed$$,this.$change$)?($_$jscomp$1543_message$jscomp$59$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.removed-from-team",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$team_name$])),$state$jscomp$125_team_id__$1$$=$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1914$profile$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$125_team_id__$1$$)),
$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_dashboard_recent$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$main$data$common$go_to_dashboard_recent$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1927$team_id$$,$state$jscomp$125_team_id__$1$$):$APP.$app$main$data$common$go_to_dashboard_recent$$($APP.$cljs$cst$1927$team_id$$,$state$jscomp$125_team_id__$1$$)),$APP.$beicon$v2$core$delay$$(250,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$info$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$1543_message$jscomp$59$$))))):
null});return new $app$main$data$common$team_membership_change_52543$$($p__52541$$,$map__52542__$1$$,$team_id$jscomp$6$$,$team_name$$,$change$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$common$go_to_dashboard_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52618$$){var $map__52619__$1$$=$APP.$cljs$core$__destructure_map$$($p__52618$$),$project_id$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52619__$1$$,$APP.$cljs$cst$2181$project_id$$),$team_id$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52619__$1$$,$APP.$cljs$cst$1927$team_id$$);typeof $app$main$data$common$go_to_dashboard_files_52620$$==="undefined"&&
($app$main$data$common$go_to_dashboard_files_52620$$=function($p__52618$jscomp$1$$,$map__52619$jscomp$1$$,$options$jscomp$456$$,$project_id$jscomp$2$$,$team_id$jscomp$9$$,$meta52621$$){this.$p__52618$=$p__52618$jscomp$1$$;this.$map__52619$=$map__52619$jscomp$1$$;this.options=$options$jscomp$456$$;this.$project_id$=$project_id$jscomp$2$$;this.$team_id$=$team_id$jscomp$9$$;this.$meta52621$=$meta52621$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_dashboard_files_52620$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_files_52620$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2510$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_files$$},$app$main$data$common$go_to_dashboard_files_52620$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52622$$,$meta52621__$1$$){return new $app$main$data$common$go_to_dashboard_files_52620$$(this.$p__52618$,this.$map__52619$,this.options,this.$project_id$,this.$team_id$,
$meta52621__$1$$)},$app$main$data$common$go_to_dashboard_files_52620$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52621$},$app$main$data$common$go_to_dashboard_files_52620$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_files_52620$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1549_profile$jscomp$2_project_id__$1$$,$state$jscomp$130_team_id__$1$jscomp$1$$){$_$jscomp$1549_profile$jscomp$2_project_id__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$130_team_id__$1$jscomp$1$$,$APP.$cljs$cst$1914$profile$$);var $or__5025__auto__$jscomp$inline_5625$$=this.$team_id$;$state$jscomp$130_team_id__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_5625$$)?$or__5025__auto__$jscomp$inline_5625$$:$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$130_team_id__$1$jscomp$1$$);$_$jscomp$1549_profile$jscomp$2_project_id__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$project_id$,
$APP.$cljs$cst$205$default$$)?$APP.$cljs$cst$2511$default_project_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1549_profile$jscomp$2_project_id__$1$$):this.$project_id$;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2512$dashboard_files$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1927$team_id$$,$state$jscomp$130_team_id__$1$jscomp$1$$,$APP.$cljs$cst$2181$project_id$$,$_$jscomp$1549_profile$jscomp$2_project_id__$1$$],
null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.options])))});return new $app$main$data$common$go_to_dashboard_files_52620$$($p__52618$$,$map__52619__$1$$,$map__52619__$1$$,$project_id$jscomp$1$$,$team_id$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$go_to_dashboard_search$$=function($var_args$jscomp$1057$$){for(var $args__5755__auto__$jscomp$174$$=[],$len__5749__auto___52894$$=arguments.length,$i__5750__auto___52895$$=0;;)if($i__5750__auto___52895$$<$len__5749__auto___52894$$)$args__5755__auto__$jscomp$174$$.push(arguments[$i__5750__auto___52895$$]),$i__5750__auto___52895$$+=1;else break;return $app$main$data$common$go_to_dashboard_search$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$174$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$174$$.slice(0),0,null):null)};
$app$main$data$common$go_to_dashboard_search$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52632$$){var $map__52634__$1$$=$APP.$cljs$core$__destructure_map$$($p__52632$$),$term$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52634__$1$$,$APP.$cljs$cst$2513$term$$);typeof $app$main$data$common$go_to_dashboard_search_52636$$==="undefined"&&($app$main$data$common$go_to_dashboard_search_52636$$=function($p__52632$jscomp$1$$,$map__52634$jscomp$1$$,$options$jscomp$458$$,$term$jscomp$1$$,
$meta52637$$){this.$p__52632$=$p__52632$jscomp$1$$;this.$map__52634$=$map__52634$jscomp$1$$;this.options=$options$jscomp$458$$;this.term=$term$jscomp$1$$;this.$meta52637$=$meta52637$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_dashboard_search_52636$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_search_52636$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$2514$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_search$$},$app$main$data$common$go_to_dashboard_search_52636$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52638$$,$meta52637__$1$$){return new $app$main$data$common$go_to_dashboard_search_52636$$(this.$p__52632$,this.$map__52634$,this.options,this.term,$meta52637__$1$$)},$app$main$data$common$go_to_dashboard_search_52636$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52637$},
$app$main$data$common$go_to_dashboard_search_52636$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_search_52636$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1550_team_id$jscomp$10$$,$state$jscomp$131$$,$stream$jscomp$20$$){$_$jscomp$1550_team_id$jscomp$10$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$131$$);return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2515$dashboard_search$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1550_team_id$jscomp$10$$,$APP.$cljs$cst$2516$search_term$$,this.term],null)),$APP.$app$main$data$modal$hide$$())),$APP.$beicon$v2$core$map$$(function(){return $potok$v2$core$event$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$1567$app_DOT_util_DOT_dom_SLASH_focus_element$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$725$name$$,"search-input"],null))},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2454$app_DOT_main_DOT_router_SLASH_navigated$$),$stream$jscomp$20$$))))});return new $app$main$data$common$go_to_dashboard_search_52636$$($p__52632$$,$map__52634__$1$$,$map__52634__$1$$,$term$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$go_to_dashboard_libraries$$=function($var_args$jscomp$1058$$){for(var $args__5755__auto__$jscomp$175$$=[],$len__5749__auto___52898$$=arguments.length,$i__5750__auto___52899$$=0;;)if($i__5750__auto___52899$$<$len__5749__auto___52898$$)$args__5755__auto__$jscomp$175$$.push(arguments[$i__5750__auto___52899$$]),$i__5750__auto___52899$$+=1;else break;return $app$main$data$common$go_to_dashboard_libraries$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$175$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$175$$.slice(0),0,null):null)};
$app$main$data$common$go_to_dashboard_libraries$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52644$$){var $map__52645__$1$$=$APP.$cljs$core$__destructure_map$$($p__52644$$),$team_id$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52645__$1$$,$APP.$cljs$cst$1927$team_id$$);typeof $app$main$data$common$go_to_dashboard_libraries_52647$$==="undefined"&&($app$main$data$common$go_to_dashboard_libraries_52647$$=function($p__52644$jscomp$1$$,$map__52645$jscomp$1$$,$options$jscomp$460$$,
$team_id$jscomp$12$$,$meta52648$$){this.$p__52644$=$p__52644$jscomp$1$$;this.$map__52645$=$map__52645$jscomp$1$$;this.options=$options$jscomp$460$$;this.$team_id$=$team_id$jscomp$12$$;this.$meta52648$=$meta52648$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_dashboard_libraries_52647$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_libraries_52647$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$2517$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_libraries$$},$app$main$data$common$go_to_dashboard_libraries_52647$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52649$$,$meta52648__$1$$){return new $app$main$data$common$go_to_dashboard_libraries_52647$$(this.$p__52644$,this.$map__52645$,this.options,this.$team_id$,$meta52648__$1$$)},$app$main$data$common$go_to_dashboard_libraries_52647$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52648$},
$app$main$data$common$go_to_dashboard_libraries_52647$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_libraries_52647$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1551_or__5025__auto__$jscomp$inline_5627$$,$state$jscomp$132_team_id__$1$jscomp$2$$){$_$jscomp$1551_or__5025__auto__$jscomp$inline_5627$$=this.$team_id$;$state$jscomp$132_team_id__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($_$jscomp$1551_or__5025__auto__$jscomp$inline_5627$$)?
$_$jscomp$1551_or__5025__auto__$jscomp$inline_5627$$:$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$132_team_id__$1$jscomp$2$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2518$dashboard_libraries$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$state$jscomp$132_team_id__$1$jscomp$2$$],null)))});return new $app$main$data$common$go_to_dashboard_libraries_52647$$($p__52644$$,
$map__52645__$1$$,$map__52645__$1$$,$team_id$jscomp$11$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$go_to_dashboard_fonts$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52669$$){var $map__52671__$1$$=$APP.$cljs$core$__destructure_map$$($p__52669$$),$team_id$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52671__$1$$,$APP.$cljs$cst$1927$team_id$$);typeof $app$main$data$common$go_to_dashboard_fonts_52675$$==="undefined"&&($app$main$data$common$go_to_dashboard_fonts_52675$$=function($p__52669$jscomp$1$$,$map__52671$jscomp$1$$,$options$jscomp$462$$,
$team_id$jscomp$14$$,$meta52676$$){this.$p__52669$=$p__52669$jscomp$1$$;this.$map__52671$=$map__52671$jscomp$1$$;this.options=$options$jscomp$462$$;this.$team_id$=$team_id$jscomp$14$$;this.$meta52676$=$meta52676$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_dashboard_fonts_52675$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_fonts_52675$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$2519$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_fonts$$},$app$main$data$common$go_to_dashboard_fonts_52675$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52677$$,$meta52676__$1$$){return new $app$main$data$common$go_to_dashboard_fonts_52675$$(this.$p__52669$,this.$map__52671$,this.options,this.$team_id$,$meta52676__$1$$)},$app$main$data$common$go_to_dashboard_fonts_52675$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52676$},
$app$main$data$common$go_to_dashboard_fonts_52675$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_fonts_52675$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1552_or__5025__auto__$jscomp$inline_5629$$,$state$jscomp$133_team_id__$1$jscomp$3$$){$_$jscomp$1552_or__5025__auto__$jscomp$inline_5629$$=this.$team_id$;$state$jscomp$133_team_id__$1$jscomp$3$$=$APP.$cljs$core$truth_$$($_$jscomp$1552_or__5025__auto__$jscomp$inline_5629$$)?
$_$jscomp$1552_or__5025__auto__$jscomp$inline_5629$$:$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$133_team_id__$1$jscomp$3$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2520$dashboard_fonts$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$state$jscomp$133_team_id__$1$jscomp$3$$],null)))});return new $app$main$data$common$go_to_dashboard_fonts_52675$$($p__52669$$,
$map__52671__$1$$,$map__52671__$1$$,$team_id$jscomp$13$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$common$go_to_dashboard_recent$$=function($var_args$jscomp$1060$$){for(var $args__5755__auto__$jscomp$177$$=[],$len__5749__auto___52907$$=arguments.length,$i__5750__auto___52908$$=0;;)if($i__5750__auto___52908$$<$len__5749__auto___52907$$)$args__5755__auto__$jscomp$177$$.push(arguments[$i__5750__auto___52908$$]),$i__5750__auto___52908$$+=1;else break;return $APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$177$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$177$$.slice(0),0,null):null)};
$APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52685$$){var $map__52686__$1$$=$APP.$cljs$core$__destructure_map$$($p__52685$$),$team_id$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52686__$1$$,$APP.$cljs$cst$1927$team_id$$);typeof $app$main$data$common$go_to_dashboard_recent_52687$$==="undefined"&&($app$main$data$common$go_to_dashboard_recent_52687$$=function($p__52685$jscomp$1$$,$map__52686$jscomp$1$$,$options$jscomp$464$$,
$team_id$jscomp$16$$,$meta52688$$){this.$p__52685$=$p__52685$jscomp$1$$;this.$map__52686$=$map__52686$jscomp$1$$;this.options=$options$jscomp$464$$;this.$team_id$=$team_id$jscomp$16$$;this.$meta52688$=$meta52688$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_dashboard_recent_52687$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_recent_52687$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$2521$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_recent$$},$app$main$data$common$go_to_dashboard_recent_52687$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52689$$,$meta52688__$1$$){return new $app$main$data$common$go_to_dashboard_recent_52687$$(this.$p__52685$,this.$map__52686$,this.options,this.$team_id$,$meta52688__$1$$)},$app$main$data$common$go_to_dashboard_recent_52687$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52688$},
$app$main$data$common$go_to_dashboard_recent_52687$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_recent_52687$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1553_profile$jscomp$3$$,$params$jscomp$156_state$jscomp$134_team_id__$1$jscomp$4$$){$_$jscomp$1553_profile$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$156_state$jscomp$134_team_id__$1$jscomp$4$$,$APP.$cljs$cst$1914$profile$$);
$params$jscomp$156_state$jscomp$134_team_id__$1$jscomp$4$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$205$default$$,this.$team_id$)?$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1553_profile$jscomp$3$$):$APP.$cljs$core$uuid_QMARK_$$(this.$team_id$)?this.$team_id$:$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$156_state$jscomp$134_team_id__$1$jscomp$4$$);$params$jscomp$156_state$jscomp$134_team_id__$1$jscomp$4$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$params$jscomp$156_state$jscomp$134_team_id__$1$jscomp$4$$],null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$modal$hide$$(),$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2522$dashboard_recent$$,$params$jscomp$156_state$jscomp$134_team_id__$1$jscomp$4$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.options])))});return new $app$main$data$common$go_to_dashboard_recent_52687$$($p__52685$$,
$map__52686__$1$$,$map__52686__$1$$,$team_id$jscomp$15$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$common$go_to_dashboard_members$$=function($var_args$jscomp$1061$$){for(var $args__5755__auto__$jscomp$178$$=[],$len__5749__auto___52911$$=arguments.length,$i__5750__auto___52912$$=0;;)if($i__5750__auto___52912$$<$len__5749__auto___52911$$)$args__5755__auto__$jscomp$178$$.push(arguments[$i__5750__auto___52912$$]),$i__5750__auto___52912$$+=1;else break;return $app$main$data$common$go_to_dashboard_members$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$178$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$178$$.slice(0),0,null):null)};
$app$main$data$common$go_to_dashboard_members$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52698$$){var $map__52700__$1$$=$APP.$cljs$core$__destructure_map$$($p__52698$$);typeof $app$main$data$common$go_to_dashboard_members_52702$$==="undefined"&&($app$main$data$common$go_to_dashboard_members_52702$$=function($p__52698$jscomp$1$$,$map__52700$jscomp$1$$,$options$jscomp$466$$,$meta52703$$){this.$p__52698$=$p__52698$jscomp$1$$;this.$map__52700$=$map__52700$jscomp$1$$;this.options=$options$jscomp$466$$;
this.$meta52703$=$meta52703$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_dashboard_members_52702$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_members_52702$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2523$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_members$$},$app$main$data$common$go_to_dashboard_members_52702$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_52704$$,$meta52703__$1$$){return new $app$main$data$common$go_to_dashboard_members_52702$$(this.$p__52698$,this.$map__52700$,this.options,$meta52703__$1$$)},$app$main$data$common$go_to_dashboard_members_52702$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52703$},$app$main$data$common$go_to_dashboard_members_52702$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_members_52702$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1554_team_id$jscomp$17$$,$state$jscomp$135$$){$_$jscomp$1554_team_id$jscomp$17$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$135$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2524$dashboard_members$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1554_team_id$jscomp$17$$],null)))});return new $app$main$data$common$go_to_dashboard_members_52702$$($p__52698$$,
$map__52700__$1$$,$map__52700__$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$go_to_dashboard_invitations$$=function($var_args$jscomp$1062$$){for(var $args__5755__auto__$jscomp$179$$=[],$len__5749__auto___52914$$=arguments.length,$i__5750__auto___52915$$=0;;)if($i__5750__auto___52915$$<$len__5749__auto___52914$$)$args__5755__auto__$jscomp$179$$.push(arguments[$i__5750__auto___52915$$]),$i__5750__auto___52915$$+=1;else break;return $app$main$data$common$go_to_dashboard_invitations$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$179$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$179$$.slice(0),0,null):null)};
$app$main$data$common$go_to_dashboard_invitations$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52714$$){var $map__52715__$1$$=$APP.$cljs$core$__destructure_map$$($p__52714$$);typeof $app$main$data$common$go_to_dashboard_invitations_52716$$==="undefined"&&($app$main$data$common$go_to_dashboard_invitations_52716$$=function($p__52714$jscomp$1$$,$map__52715$jscomp$1$$,$options$jscomp$468$$,$meta52717$$){this.$p__52714$=$p__52714$jscomp$1$$;this.$map__52715$=$map__52715$jscomp$1$$;this.options=
$options$jscomp$468$$;this.$meta52717$=$meta52717$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_dashboard_invitations_52716$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_invitations_52716$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2525$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_invitations$$},$app$main$data$common$go_to_dashboard_invitations_52716$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_52718$$,$meta52717__$1$$){return new $app$main$data$common$go_to_dashboard_invitations_52716$$(this.$p__52714$,this.$map__52715$,this.options,$meta52717__$1$$)},$app$main$data$common$go_to_dashboard_invitations_52716$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52717$},$app$main$data$common$go_to_dashboard_invitations_52716$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_invitations_52716$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1555_team_id$jscomp$18$$,$state$jscomp$136$$){$_$jscomp$1555_team_id$jscomp$18$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$136$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2526$dashboard_invitations$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1555_team_id$jscomp$18$$],null)))});return new $app$main$data$common$go_to_dashboard_invitations_52716$$($p__52714$$,
$map__52715__$1$$,$map__52715__$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$go_to_dashboard_webhooks$$=function($var_args$jscomp$1063$$){for(var $args__5755__auto__$jscomp$180$$=[],$len__5749__auto___52917$$=arguments.length,$i__5750__auto___52918$$=0;;)if($i__5750__auto___52918$$<$len__5749__auto___52917$$)$args__5755__auto__$jscomp$180$$.push(arguments[$i__5750__auto___52918$$]),$i__5750__auto___52918$$+=1;else break;return $app$main$data$common$go_to_dashboard_webhooks$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$180$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$180$$.slice(0),0,null):null)};
$app$main$data$common$go_to_dashboard_webhooks$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52723$$){var $map__52724__$1$$=$APP.$cljs$core$__destructure_map$$($p__52723$$);typeof $app$main$data$common$go_to_dashboard_webhooks_52727$$==="undefined"&&($app$main$data$common$go_to_dashboard_webhooks_52727$$=function($p__52723$jscomp$1$$,$map__52724$jscomp$1$$,$options$jscomp$470$$,$meta52728$$){this.$p__52723$=$p__52723$jscomp$1$$;this.$map__52724$=$map__52724$jscomp$1$$;this.options=$options$jscomp$470$$;
this.$meta52728$=$meta52728$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_dashboard_webhooks_52727$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_webhooks_52727$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2527$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_webhooks$$},$app$main$data$common$go_to_dashboard_webhooks_52727$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_52729$$,$meta52728__$1$$){return new $app$main$data$common$go_to_dashboard_webhooks_52727$$(this.$p__52723$,this.$map__52724$,this.options,$meta52728__$1$$)},$app$main$data$common$go_to_dashboard_webhooks_52727$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52728$},$app$main$data$common$go_to_dashboard_webhooks_52727$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_webhooks_52727$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1556_team_id$jscomp$19$$,$state$jscomp$137$$){$_$jscomp$1556_team_id$jscomp$19$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$137$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2528$dashboard_webhooks$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1556_team_id$jscomp$19$$],null)))});return new $app$main$data$common$go_to_dashboard_webhooks_52727$$($p__52723$$,
$map__52724__$1$$,$map__52724__$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$go_to_dashboard_settings$$=function($var_args$jscomp$1064$$){for(var $args__5755__auto__$jscomp$181$$=[],$len__5749__auto___52920$$=arguments.length,$i__5750__auto___52921$$=0;;)if($i__5750__auto___52921$$<$len__5749__auto___52920$$)$args__5755__auto__$jscomp$181$$.push(arguments[$i__5750__auto___52921$$]),$i__5750__auto___52921$$+=1;else break;return $app$main$data$common$go_to_dashboard_settings$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$181$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$181$$.slice(0),0,null):null)};
$app$main$data$common$go_to_dashboard_settings$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52735$$){var $map__52736__$1$$=$APP.$cljs$core$__destructure_map$$($p__52735$$);typeof $app$main$data$common$go_to_dashboard_settings_52737$$==="undefined"&&($app$main$data$common$go_to_dashboard_settings_52737$$=function($p__52735$jscomp$1$$,$map__52736$jscomp$1$$,$options$jscomp$472$$,$meta52738$$){this.$p__52735$=$p__52735$jscomp$1$$;this.$map__52736$=$map__52736$jscomp$1$$;this.options=$options$jscomp$472$$;
this.$meta52738$=$meta52738$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_dashboard_settings_52737$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_settings_52737$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2529$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_settings$$},$app$main$data$common$go_to_dashboard_settings_52737$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_52739$$,$meta52738__$1$$){return new $app$main$data$common$go_to_dashboard_settings_52737$$(this.$p__52735$,this.$map__52736$,this.options,$meta52738__$1$$)},$app$main$data$common$go_to_dashboard_settings_52737$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52738$},$app$main$data$common$go_to_dashboard_settings_52737$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_settings_52737$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1557_team_id$jscomp$20$$,$state$jscomp$138$$){$_$jscomp$1557_team_id$jscomp$20$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$138$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2530$dashboard_settings$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1557_team_id$jscomp$20$$],null)))});return new $app$main$data$common$go_to_dashboard_settings_52737$$($p__52735$$,
$map__52736__$1$$,$map__52736__$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$go_to_workspace$$=function($var_args$jscomp$1065$$){for(var $args__5755__auto__$jscomp$182$$=[],$len__5749__auto___52923$$=arguments.length,$i__5750__auto___52924$$=0;;)if($i__5750__auto___52924$$<$len__5749__auto___52923$$)$args__5755__auto__$jscomp$182$$.push(arguments[$i__5750__auto___52924$$]),$i__5750__auto___52924$$+=1;else break;return $APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$182$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$182$$.slice(0),
0,null):null)};
$APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52746$$){var $map__52747__$1$$=$APP.$cljs$core$__destructure_map$$($p__52746$$),$team_id$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52747__$1$$,$APP.$cljs$cst$1927$team_id$$),$file_id$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52747__$1$$,$APP.$cljs$cst$1644$file_id$$),$page_id$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52747__$1$$,$APP.$cljs$cst$2043$page_id$$),
$layout$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52747__$1$$,$APP.$cljs$cst$1615$layout$$);typeof $app$main$data$common$go_to_workspace_52749$$==="undefined"&&($app$main$data$common$go_to_workspace_52749$$=function($p__52746$jscomp$1$$,$map__52747$jscomp$1$$,$options$jscomp$474$$,$team_id$jscomp$22$$,$file_id$jscomp$20$$,$page_id$jscomp$18$$,$layout$jscomp$2$$,$meta52750$$){this.$p__52746$=$p__52746$jscomp$1$$;this.$map__52747$=$map__52747$jscomp$1$$;this.options=$options$jscomp$474$$;
this.$team_id$=$team_id$jscomp$22$$;this.$file_id$=$file_id$jscomp$20$$;this.$page_id$=$page_id$jscomp$18$$;this.layout=$layout$jscomp$2$$;this.$meta52750$=$meta52750$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_workspace_52749$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_workspace_52749$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2531$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_workspace$$},
$app$main$data$common$go_to_workspace_52749$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52751$$,$meta52750__$1$$){return new $app$main$data$common$go_to_workspace_52749$$(this.$p__52746$,this.$map__52747$,this.options,this.$team_id$,this.$file_id$,this.$page_id$,this.layout,$meta52750__$1$$)},$app$main$data$common$go_to_workspace_52749$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52750$},$app$main$data$common$go_to_workspace_52749$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_workspace_52749$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1558_params$jscomp$157_team_id__$1$jscomp$5$$,$state$jscomp$139$$){var $self__$jscomp$3372$$=this;$_$jscomp$1558_params$jscomp$157_team_id__$1$jscomp$5$$=function(){var $or__5025__auto__$jscomp$445$$=$self__$jscomp$3372$$.$team_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$445$$)?$or__5025__auto__$jscomp$445$$:$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$139$$)}();
var $file_id__$1$$=function(){var $or__5025__auto__$jscomp$446$$=$self__$jscomp$3372$$.$file_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$446$$)?$or__5025__auto__$jscomp$446$$:$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$139$$)}(),$page_id__$1$$=function(){var $or__5025__auto__$jscomp$447_or__5025__auto____$1$jscomp$47$$=$self__$jscomp$3372$$.$page_id$;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$447_or__5025__auto____$1$jscomp$47$$))return $or__5025__auto__$jscomp$447_or__5025__auto____$1$jscomp$47$$;
$or__5025__auto__$jscomp$447_or__5025__auto____$1$jscomp$47$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$139$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$447_or__5025__auto____$1$jscomp$47$$)?$or__5025__auto__$jscomp$447_or__5025__auto____$1$jscomp$47$$:$APP.$cljs$core$first$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$139$$,$file_id__$1$$),
$APP.$cljs$cst$2228$pages$$))}();$_$jscomp$1558_params$jscomp$157_team_id__$1$jscomp$5$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$router$get_params$$($state$jscomp$139$$),$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1558_params$jscomp$157_team_id__$1$jscomp$5$$),
$APP.$cljs$cst$1644$file_id$$,$file_id__$1$$),$APP.$cljs$cst$2043$page_id$$,$page_id__$1$$),$APP.$cljs$cst$1615$layout$$,function($p1__52744_SHARP_$$){var $or__5025__auto__$jscomp$448$$=$self__$jscomp$3372$$.layout;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$448$$)?$or__5025__auto__$jscomp$448$$:$p1__52744_SHARP_$$}));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2532$workspace$$,$_$jscomp$1558_params$jscomp$157_team_id__$1$jscomp$5$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$3372$$.options])))});return new $app$main$data$common$go_to_workspace_52749$$($p__52746$$,$map__52747__$1$$,$map__52747__$1$$,$team_id$jscomp$21$$,$file_id$jscomp$19$$,$page_id$jscomp$17$$,$layout$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$go_to_viewer$$=function($var_args$jscomp$1066$$){for(var $args__5755__auto__$jscomp$183$$=[],$len__5749__auto___52926$$=arguments.length,$i__5750__auto___52927$$=0;;)if($i__5750__auto___52927$$<$len__5749__auto___52926$$)$args__5755__auto__$jscomp$183$$.push(arguments[$i__5750__auto___52927$$]),$i__5750__auto___52927$$+=1;else break;return $APP.$app$main$data$common$go_to_viewer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$183$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$183$$.slice(0),
0,null):null)};
$APP.$app$main$data$common$go_to_viewer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52765$$){var $map__52766__$1$$=$APP.$cljs$core$__destructure_map$$($p__52765$$),$file_id$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52766__$1$$,$APP.$cljs$cst$1644$file_id$$),$page_id$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52766__$1$$,$APP.$cljs$cst$2043$page_id$$),$section$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52766__$1$$,$APP.$cljs$cst$1366$section$$),
$frame_id$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52766__$1$$,$APP.$cljs$cst$1607$frame_id$$),$index$jscomp$214$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52766__$1$$,$APP.$cljs$cst$1795$index$$);typeof $app$main$data$common$go_to_viewer_52767$$==="undefined"&&($app$main$data$common$go_to_viewer_52767$$=function($p__52765$jscomp$1$$,$map__52766$jscomp$1$$,$options$jscomp$476$$,$file_id$jscomp$22$$,$page_id$jscomp$20$$,$section$jscomp$11$$,$frame_id$jscomp$25$$,
$index$jscomp$215$$,$meta52768$$){this.$p__52765$=$p__52765$jscomp$1$$;this.$map__52766$=$map__52766$jscomp$1$$;this.options=$options$jscomp$476$$;this.$file_id$=$file_id$jscomp$22$$;this.$page_id$=$page_id$jscomp$20$$;this.section=$section$jscomp$11$$;this.$frame_id$=$frame_id$jscomp$25$$;this.index=$index$jscomp$215$$;this.$meta52768$=$meta52768$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_viewer_52767$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_viewer_52767$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2533$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_viewer$$},$app$main$data$common$go_to_viewer_52767$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52769$$,$meta52768__$1$$){return new $app$main$data$common$go_to_viewer_52767$$(this.$p__52765$,this.$map__52766$,this.options,this.$file_id$,this.$page_id$,this.section,this.$frame_id$,
this.index,$meta52768__$1$$)},$app$main$data$common$go_to_viewer_52767$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52768$},$app$main$data$common$go_to_viewer_52767$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_viewer_52767$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1559_file_id__$1$jscomp$1_options__$1$jscomp$65$$,$state$jscomp$140$$){var $self__$jscomp$3376$$=this,$page_id__$1$jscomp$1_params__$1$jscomp$18$$=
function(){var $or__5025__auto__$jscomp$449$$=$self__$jscomp$3376$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$449$$)?$or__5025__auto__$jscomp$449$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$140$$)}();$_$jscomp$1559_file_id__$1$jscomp$1_options__$1$jscomp$65$$=function(){var $or__5025__auto__$jscomp$450$$=$self__$jscomp$3376$$.$file_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$450$$)?$or__5025__auto__$jscomp$450$$:$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$140$$)}();
var $section__$1$$=function(){var $or__5025__auto__$jscomp$451$$=$self__$jscomp$3376$$.section;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$451$$)?$or__5025__auto__$jscomp$451$$:$APP.$cljs$cst$2051$interactions$$}(),$selected$jscomp$15$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$140$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1921$selected$$],null)),$objects$jscomp$174$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$140$$,$_$jscomp$1559_file_id__$1$jscomp$1_options__$1$jscomp$65$$,$page_id__$1$jscomp$1_params__$1$jscomp$18$$),$frame_id__$1$jscomp$5$$=function(){var $or__5025__auto__$jscomp$452$$=$self__$jscomp$3376$$.$frame_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$452$$)?$or__5025__auto__$jscomp$452$$:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($___$3$jscomp$53_obj$jscomp$184$$,
$id$jscomp$243$$){$___$3$jscomp$53_obj$jscomp$184$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$174$$,$id$jscomp$243$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($___$3$jscomp$53_obj$jscomp$184$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($___$3$jscomp$53_obj$jscomp$184$$)):$___$3$jscomp$53_obj$jscomp$184$$)?$APP.$cljs$core$reduced$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($___$3$jscomp$53_obj$jscomp$184$$)):
null},null,$selected$jscomp$15$$)}();$page_id__$1$jscomp$1_params__$1$jscomp$18$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1644$file_id$$,$_$jscomp$1559_file_id__$1$jscomp$1_options__$1$jscomp$65$$,$APP.$cljs$cst$2043$page_id$$,$page_id__$1$jscomp$1_params__$1$jscomp$18$$,$APP.$cljs$cst$1366$section$$,$section__$1$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id__$1$jscomp$5$$,$APP.$cljs$cst$1795$index$$,$self__$jscomp$3376$$.index],
null));$_$jscomp$1559_file_id__$1$jscomp$1_options__$1$jscomp$65$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2456$app_DOT_main_DOT_router_SLASH_new_window$$,!0,$APP.$cljs$cst$2458$app_DOT_main_DOT_router_SLASH_window_name$$,"viewer-"+($_$jscomp$1559_file_id__$1$jscomp$1_options__$1$jscomp$65$$??"")],null),$self__$jscomp$3376$$.options]));return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2534$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$,
$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$1592$viewer$$,$page_id__$1$jscomp$1_params__$1$jscomp$18$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_$jscomp$1559_file_id__$1$jscomp$1_options__$1$jscomp$65$$])))});return new $app$main$data$common$go_to_viewer_52767$$($p__52765$$,$map__52766__$1$$,$map__52766__$1$$,$file_id$jscomp$21$$,$page_id$jscomp$19$$,$section$jscomp$10$$,$frame_id$jscomp$24$$,$index$jscomp$214$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$schema$desc_native$describe_STAR_$$=function($s$jscomp$540$$,$options$jscomp$483$$){return $malli$core$walk$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$540$$,function($schema$jscomp$234$$,$_$jscomp$1569$$,$children$jscomp$180$$,$options__$1$jscomp$66$$){return $app$common$schema$desc_native$visit$$.$cljs$core$IFn$_invoke$arity$4$($APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$234$$),$schema$jscomp$234$$,$children$jscomp$180$$,$options__$1$jscomp$66$$)},$options$jscomp$483$$)};
$APP.$app$common$types$components_list$components$cljs$0core$0IFn$0_invoke$0arity$01$$=function($file_data$$){return $app$common$types$components_list$components$cljs$0core$0IFn$0_invoke$0arity$02$$($file_data$$,null)};
$app$common$types$components_list$components$cljs$0core$0IFn$0_invoke$0arity$02$$=function($file_data$jscomp$1$$,$include_deleted_QMARK__map__50257__$1_p__50256$$){$include_deleted_QMARK__map__50257__$1_p__50256$$=$APP.$cljs$core$__destructure_map$$($include_deleted_QMARK__map__50257__$1_p__50256$$);$include_deleted_QMARK__map__50257__$1_p__50256$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($include_deleted_QMARK__map__50257__$1_p__50256$$,$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!1);
return $APP.$cljs$core$truth_$$($include_deleted_QMARK__map__50257__$1_p__50256$$)?$APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$1$$):$APP.$app$common$data$removem$$(function($component$jscomp$9_p__50262$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($component$jscomp$9_p__50262$$,0,null);$component$jscomp$9_p__50262$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($component$jscomp$9_p__50262$$,1,null);return $APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$9_p__50262$$)},
$APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$1$$))};$APP.$app$common$types$components_list$components_seq$$=function($file_data$jscomp$2$$){return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2541$deleted$$,$APP.$cljs$core$vals$$($APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$2$$)))};
$app$common$types$components_list$touch$$=function($component$jscomp$10$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($component$jscomp$10$$,$APP.$cljs$cst$1737$modified_at$$,$APP.$app$common$time$now$$())};
$app$common$types$components_list$mod_component$$=function($file_data$jscomp$4$$,$id$jscomp$245_map__50291__$1_p__50289$$){$id$jscomp$245_map__50291__$1_p__50289$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$245_map__50291__$1_p__50289$$);var $variant_id$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$245_map__50291__$1_p__50289$$,$APP.$cljs$cst$2000$variant_id$$),$annotation$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$245_map__50291__$1_p__50289$$,
$APP.$cljs$cst$2542$annotation$$),$path$jscomp$226$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$245_map__50291__$1_p__50289$$,$APP.$cljs$cst$296$path$$),$main_instance_id$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$245_map__50291__$1_p__50289$$,$APP.$cljs$cst$2062$main_instance_id$$),$objects$jscomp$175$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$245_map__50291__$1_p__50289$$,$APP.$cljs$cst$1631$objects$$),$name$jscomp$255$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$245_map__50291__$1_p__50289$$,$APP.$cljs$cst$725$name$$),$variant_properties$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$245_map__50291__$1_p__50289$$,$APP.$cljs$cst$2001$variant_properties$$),$modified_at$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$245_map__50291__$1_p__50289$$,$APP.$cljs$cst$1737$modified_at$$),$main_instance_page$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$245_map__50291__$1_p__50289$$,
$APP.$cljs$cst$2063$main_instance_page$$);$id$jscomp$245_map__50291__$1_p__50289$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$245_map__50291__$1_p__50289$$,$APP.$cljs$cst$266$id$$);return $APP.$app$common$data$update_in_when$$($file_data$jscomp$4$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$id$jscomp$245_map__50291__$1_p__50289$$],null),function($component$jscomp$11_diff$jscomp$3$$){var $G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$=
$name$jscomp$255$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($component$jscomp$11_diff$jscomp$3$$,$APP.$cljs$cst$725$name$$,$name$jscomp$255$$):$component$jscomp$11_diff$jscomp$3$$;$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$=
$path$jscomp$226$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$,$APP.$cljs$cst$296$path$$,
$path$jscomp$226$$):$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$;$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$=
$main_instance_id$jscomp$1$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$,$APP.$cljs$cst$2062$main_instance_id$$,
$main_instance_id$jscomp$1$$):$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$;$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$=
$main_instance_page$jscomp$1$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$,$APP.$cljs$cst$2063$main_instance_page$$,
$main_instance_page$jscomp$1$$):$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$;$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$=
$objects$jscomp$175$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$,$APP.$cljs$cst$1631$objects$$,
$objects$jscomp$175$$):$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$;$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$=
$objects$jscomp$175$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$,$APP.$cljs$cst$1631$objects$$):
$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$;$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$=
$modified_at$jscomp$8$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$,$APP.$cljs$cst$1737$modified_at$$,
$modified_at$jscomp$8$$):$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$;$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$=
$annotation$jscomp$1$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$,$APP.$cljs$cst$2542$annotation$$,
$annotation$jscomp$1$$):$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$;$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$=
$annotation$jscomp$1$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$,$APP.$cljs$cst$2542$annotation$$):
$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$;$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$=
$variant_id$jscomp$1$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$,$APP.$cljs$cst$2000$variant_id$$,
$variant_id$jscomp$1$$):$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$;$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$=
$variant_id$jscomp$1$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$,$APP.$cljs$cst$2000$variant_id$$):
$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$;$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$=
$variant_properties$jscomp$1$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$,$APP.$cljs$cst$2001$variant_properties$$,
$variant_properties$jscomp$1$$):$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$;$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$=
$variant_properties$jscomp$1$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$,$APP.$cljs$cst$2001$variant_properties$$):
$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$;$component$jscomp$11_diff$jscomp$3$$=$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$component$diff_components$$($component$jscomp$11_diff$jscomp$3$$,
$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2001$variant_properties$$,
null,$APP.$cljs$cst$1737$modified_at$$,null,$APP.$cljs$cst$2542$annotation$$,null,$APP.$cljs$cst$2000$variant_id$$,null],null),null));return $APP.$cljs$core$empty_QMARK_$$($component$jscomp$11_diff$jscomp$3$$)?$G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$:
$app$common$types$components_list$touch$$($G__50292__$1$jscomp$inline_5631_G__50292__$10$jscomp$inline_5640_G__50292__$11$jscomp$inline_5641_G__50292__$12$jscomp$inline_5642_G__50292__$2$jscomp$inline_5632_G__50292__$3$jscomp$inline_5633_G__50292__$4$jscomp$inline_5634_G__50292__$5$jscomp$inline_5635_G__50292__$6$jscomp$inline_5636_G__50292__$7$jscomp$inline_5637_G__50292__$8$jscomp$inline_5638_G__50292__$9$jscomp$inline_5639_new_comp$$)})};
$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$=function($file_data$jscomp$5$$,$component_id$jscomp$2$$){return $app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($file_data$jscomp$5$$,$component_id$jscomp$2$$,!1)};
$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$=function($component$jscomp$12_file_data$jscomp$6$$,$component_id$jscomp$3$$,$include_deleted_QMARK_$jscomp$1$$){$component$jscomp$12_file_data$jscomp$6$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$12_file_data$jscomp$6$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$component_id$jscomp$3$$],null));return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($include_deleted_QMARK_$jscomp$1$$)?
$include_deleted_QMARK_$jscomp$1$$:$APP.$cljs$core$not$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$12_file_data$jscomp$6$$)))?$component$jscomp$12_file_data$jscomp$6$$:null};
$APP.$app$common$types$components_list$get_deleted_component$$=function($component$jscomp$13_file_data$jscomp$7$$,$component_id$jscomp$4$$){$component$jscomp$13_file_data$jscomp$7$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$13_file_data$jscomp$7$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$component_id$jscomp$4$$],null));return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$13_file_data$jscomp$7$$))?
$component$jscomp$13_file_data$jscomp$7$$:null};
$app$common$types$components_list$update_component$$=function($var_args$jscomp$1071$$){for(var $args__5755__auto__$jscomp$185$$=[],$len__5749__auto___50392$$=arguments.length,$i__5750__auto___50393$$=0;;)if($i__5750__auto___50393$$<$len__5749__auto___50392$$)$args__5755__auto__$jscomp$185$$.push(arguments[$i__5750__auto___50393$$]),$i__5750__auto___50393$$+=1;else break;return $app$common$types$components_list$update_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],
arguments[2],3<$args__5755__auto__$jscomp$185$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$185$$.slice(3),0,null):null)};
$app$common$types$components_list$update_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($file_data$jscomp$8$$,$component_id$jscomp$5$$,$f$jscomp$798$$,$args$jscomp$241$$){return $APP.$app$common$data$update_in_when$$($file_data$jscomp$8$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$component_id$jscomp$5$$],null),function($p1__50324_SHARP_$$){return $app$common$types$components_list$touch$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($f$jscomp$798$$,
$p1__50324_SHARP_$$,$args$jscomp$241$$))})};
$app$common$types$components_list$mark_component_deleted$$=function($file_data$jscomp$11$$,$component_id$jscomp$8$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($file_data$jscomp$11$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$component_id$jscomp$8$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2541$deleted$$,!0]))};
$app$common$types$components_list$mark_component_undeleted$$=function($file_data$jscomp$12$$,$component_id$jscomp$9$$){return $APP.$app$common$data$dissoc_in$$($file_data$jscomp$12$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$component_id$jscomp$9$$,$APP.$cljs$cst$2541$deleted$$],null))};
$app$common$types$components_list$get_component_annotation$$=function($component$jscomp$15_shape$jscomp$217$$,$libraries_library$jscomp$2$$){$libraries_library$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries_library$jscomp$2$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$15_shape$jscomp$217$$)),$APP.$cljs$cst$142$data$$);$component$jscomp$15_shape$jscomp$217$$=$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($libraries_library$jscomp$2$$,
$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$15_shape$jscomp$217$$),!0);return $APP.$cljs$cst$2542$annotation$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$15_shape$jscomp$217$$)};$APP.$app$common$types$pages_list$get_page$$=function($file_data$jscomp$13$$,$id$jscomp$246$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_data$jscomp$13$$,$APP.$cljs$cst$1630$pages_index$$),$id$jscomp$246$$)};
$app$common$types$pages_list$add_page$$=function($file_data$jscomp$15$$,$map__50378__$1_p__50377$$){$map__50378__$1_p__50377$$=$APP.$cljs$core$__destructure_map$$($map__50378__$1_p__50377$$);var $id$jscomp$248$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50378__$1_p__50377$$,$APP.$cljs$cst$266$id$$),$index$jscomp$216$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50378__$1_p__50377$$,$APP.$cljs$cst$1795$index$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($file_data$jscomp$15$$,
$APP.$cljs$cst$2228$pages$$,function($pages$$){var $exists_QMARK_$$=$APP.$cljs$core$some$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_EQ_$$,$id$jscomp$248$$),$pages$$);return $APP.$cljs$core$truth_$$($exists_QMARK_$$)?$pages$$:$index$jscomp$216$$==null?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($pages$$,$id$jscomp$248$$):$APP.$app$common$data$insert_at_index$$($pages$$,$index$jscomp$216$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$id$jscomp$248$$],null))}),$APP.$cljs$cst$1630$pages_index$$,$APP.$cljs$core$assoc$$,$id$jscomp$248$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($map__50378__$1_p__50377$$,$APP.$cljs$cst$1795$index$$))};
$app$common$types$pages_list$delete_page$$=function($file_data$jscomp$17$$,$page_id$jscomp$22$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($file_data$jscomp$17$$,$APP.$cljs$cst$2228$pages$$,function($pages$jscomp$1$$){return $APP.$cljs$core$filterv$$(function($p1__50383_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__50383_SHARP_$$,$page_id$jscomp$22$$)},$pages$jscomp$1$$)}),$APP.$cljs$cst$1630$pages_index$$,
$APP.$cljs$core$dissoc$$,$page_id$jscomp$22$$)};$app$common$types$container$make_container$$=function($page_or_component$jscomp$1$$,$type$jscomp$373$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($page_or_component$jscomp$1$$,$APP.$cljs$cst$139$type$$,$type$jscomp$373$$)};
$APP.$app$common$types$container$get_container$$=function($file$jscomp$16$$,$id$jscomp$249$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1624$page$$,$APP.$cljs$cst$1624$page$$)?$APP.$app$common$types$pages_list$get_page$$($file$jscomp$16$$,$id$jscomp$249$$):$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($file$jscomp$16$$,$id$jscomp$249$$),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1624$page$$)};
$APP.$app$common$types$container$get_shape$$=function($container$jscomp$11$$,$shape_id$jscomp$23$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$11$$,$APP.$cljs$cst$1631$objects$$),$shape_id$jscomp$23$$)};
$app$common$types$container$get_direct_children$$=function($container$jscomp$15$$,$shape$jscomp$218$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51443_SHARP_$$){return $APP.$app$common$types$container$get_shape$$($container$jscomp$15$$,$p1__51443_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$218$$))};
$app$common$types$container$get_children_in_instance$$=function($objects$jscomp$176$$,$id$jscomp$250$$){return function $app$common$types$container$get_children_in_instance_$_get_children_rec$$($children$jscomp$181$$,$id__$1$jscomp$2_shape$jscomp$219$$){$id__$1$jscomp$2_shape$jscomp$219$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$176$$,$id__$1$jscomp$2_shape$jscomp$219$$);if($APP.$app$common$types$component$instance_head_QMARK_$$($id__$1$jscomp$2_shape$jscomp$219$$)&&$APP.$cljs$core$seq$$($children$jscomp$181$$))return $children$jscomp$181$$;
var $children_SINGLEQUOTE_$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$181$$,$id__$1$jscomp$2_shape$jscomp$219$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($children_SINGLEQUOTE_$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__51447_SHARP_$$){return $app$common$types$container$get_children_in_instance_$_get_children_rec$$($children_SINGLEQUOTE_$$,$p1__51447_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($id__$1$jscomp$2_shape$jscomp$219$$)])))}($APP.$cljs$core$PersistentVector$EMPTY$$,
$id$jscomp$250$$)};$APP.$app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objects$jscomp$177$$,$shape$jscomp$220$$){return $app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$177$$,$shape$jscomp$220$$,null)};
$app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$178$$,$shape$jscomp$221$$,$map__51465__$1_p__51464$$){$map__51465__$1_p__51464$$=$APP.$cljs$core$__destructure_map$$($map__51465__$1_p__51464$$);var $allow_main_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51465__$1_p__51464$$,$cljs$cst$2547$allow_main_QMARK_$$,!1),$parent$jscomp$192$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$178$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$221$$));
return $shape$jscomp$221$$==null?null:$APP.$app$common$files$helpers$root_QMARK_$$($shape$jscomp$221$$)?null:$APP.$app$common$types$component$instance_root_QMARK_$$($shape$jscomp$221$$)?$shape$jscomp$221$$:!$APP.$app$common$types$component$in_component_copy_QMARK_$$($shape$jscomp$221$$)&&$APP.$cljs$core$not$$($allow_main_QMARK_$$)?null:$APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$221$$)&&!$APP.$app$common$types$component$in_component_copy_QMARK_$$($parent$jscomp$192$$)?$shape$jscomp$221$$:
$app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$178$$,$parent$jscomp$192$$,$map__51465__$1_p__51464$$)};$APP.$app$common$types$container$get_head_shape$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objects$jscomp$179$$,$shape$jscomp$222$$){return $app$common$types$container$get_head_shape$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$179$$,$shape$jscomp$222$$,null)};
$app$common$types$container$get_head_shape$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$180$$,$shape$jscomp$223$$,$map__51488__$1_p__51486$$){$map__51488__$1_p__51486$$=$APP.$cljs$core$__destructure_map$$($map__51488__$1_p__51486$$);var $allow_main_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51488__$1_p__51486$$,$cljs$cst$2547$allow_main_QMARK_$$,!1);return $shape$jscomp$223$$==null?null:$APP.$app$common$files$helpers$root_QMARK_$$($shape$jscomp$223$$)?
null:$APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$223$$)?$shape$jscomp$223$$:!$APP.$app$common$types$component$in_component_copy_QMARK_$$($shape$jscomp$223$$)&&$APP.$cljs$core$not$$($allow_main_QMARK_$jscomp$1$$)?null:$app$common$types$container$get_head_shape$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$180$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$180$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$223$$)),
$map__51488__$1_p__51486$$)};$app$common$types$container$get_parent_heads$$=function($objects$jscomp$182$$,$shape$jscomp$225$$){return $APP.$cljs$core$reverse$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$instance_head_QMARK_$$,$app$common$files$helpers$get_parents_with_self$$($objects$jscomp$182$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$225$$))))};
$app$common$types$container$get_parent_copy_heads$$=function($objects$jscomp$183$$,$shape$jscomp$226$$){return $APP.$cljs$core$reverse$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51527_SHARP_$$){return $APP.$app$common$types$component$instance_head_QMARK_$$($p1__51527_SHARP_$$)&&$APP.$app$common$types$component$in_component_copy_QMARK_$$($p1__51527_SHARP_$$)},$app$common$files$helpers$get_parents_with_self$$($objects$jscomp$183$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$226$$))))};
$app$common$types$container$get_nesting_level_delta$$=function($common_count_dest_heads_objects$jscomp$184_pairs$jscomp$5$$,$shape$jscomp$227$$,$new_parent$$){var $orig_heads$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51531_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__51531_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$227$$))},$app$common$types$container$get_parent_copy_heads$$($common_count_dest_heads_objects$jscomp$184_pairs$jscomp$5$$,
$shape$jscomp$227$$));$common_count_dest_heads_objects$jscomp$184_pairs$jscomp$5$$=$app$common$types$container$get_parent_copy_heads$$($common_count_dest_heads_objects$jscomp$184_pairs$jscomp$5$$,$new_parent$$);$common_count_dest_heads_objects$jscomp$184_pairs$jscomp$5$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vector$$,$orig_heads$$,$common_count_dest_heads_objects$jscomp$184_pairs$jscomp$5$$);$common_count_dest_heads_objects$jscomp$184_pairs$jscomp$5$$=$APP.$cljs$core$count$$($APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$(function($a$jscomp$371$$,
$b$jscomp$300$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$371$$,$b$jscomp$300$$)},$common_count_dest_heads_objects$jscomp$184_pairs$jscomp$5$$));return $APP.$cljs$core$count$$($orig_heads$$)-$common_count_dest_heads_objects$jscomp$184_pairs$jscomp$5$$};
$APP.$app$common$types$container$find_component_main$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$187$$,$shape$jscomp$230_shape__$1$jscomp$22$$,$only_direct_child_QMARK_$$){for(var $G__51681_visited$jscomp$2$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$;;){if($shape$jscomp$230_shape__$1$jscomp$22$$==null||$APP.$app$common$files$helpers$root_QMARK_$$($shape$jscomp$230_shape__$1$jscomp$22$$)||$APP.$cljs$core$contains_QMARK_$$($G__51681_visited$jscomp$2$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$230_shape__$1$jscomp$22$$)))return null;
if($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$230_shape__$1$jscomp$22$$)==null||$APP.$app$common$types$component$main_instance_QMARK_$$($shape$jscomp$230_shape__$1$jscomp$22$$))return $shape$jscomp$230_shape__$1$jscomp$22$$;if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($only_direct_child_QMARK_$$)?$APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$230_shape__$1$jscomp$22$$):$only_direct_child_QMARK_$$)||$APP.$cljs$core$not$$($only_direct_child_QMARK_$$)&&
$APP.$app$common$types$component$instance_root_QMARK_$$($shape$jscomp$230_shape__$1$jscomp$22$$))return null;var $G__51680$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$187$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$230_shape__$1$jscomp$22$$));$G__51681_visited$jscomp$2$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__51681_visited$jscomp$2$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$230_shape__$1$jscomp$22$$));
$shape$jscomp$230_shape__$1$jscomp$22$$=$G__51680$$}};
$APP.$app$common$types$container$in_any_component_QMARK_$$=function($objects$jscomp$190$$,$shape$jscomp$233$$){var $or__5025__auto__$jscomp$454_or__5025__auto____$1$jscomp$48$$=$APP.$app$common$types$component$in_component_copy_QMARK_$$($shape$jscomp$233$$);return $or__5025__auto__$jscomp$454_or__5025__auto____$1$jscomp$48$$?$or__5025__auto__$jscomp$454_or__5025__auto____$1$jscomp$48$$:($or__5025__auto__$jscomp$454_or__5025__auto____$1$jscomp$48$$=$APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$233$$))?
$or__5025__auto__$jscomp$454_or__5025__auto____$1$jscomp$48$$:$APP.$app$common$types$container$find_component_main$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$190$$,$shape$jscomp$233$$,!0)!=null};
$APP.$app$common$types$container$convert_shape_in_component$$=function($root$jscomp$35$$,$new_children$jscomp$2_objects$jscomp$191$$,$file_id$jscomp$23$$){var $new_id$jscomp$8$$=$APP.$app$common$uuid$next$$(),$inside_component_QMARK_$$=$APP.$app$common$types$container$get_instance_root$$($new_children$jscomp$2_objects$jscomp$191$$,$root$jscomp$35$$)!=null,$new_root$jscomp$7$$=function(){var $G__51592$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($root$jscomp$35$$,$APP.$cljs$cst$1627$component_id$$,
$new_id$jscomp$8$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1643$component_file$$,$file_id$jscomp$23$$,$APP.$cljs$cst$2045$main_instance$$,!0]));return $inside_component_QMARK_$$?$G__51592$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__51592$$,$APP.$cljs$cst$2044$component_root$$,!0)}();$new_children$jscomp$2_objects$jscomp$191$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51590_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__51590_SHARP_$$,
$APP.$cljs$cst$2044$component_root$$)},$app$common$files$helpers$get_children$$($new_children$jscomp$2_objects$jscomp$191$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$35$$)));return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($new_root$jscomp$7$$,$APP.$cljs$cst$266$id$$,$new_id$jscomp$8$$),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_root$jscomp$7$$],null),$new_children$jscomp$2_objects$jscomp$191$$)],null)};
$app$common$types$container$remove_swap_keep_attrs$$=function($G__51603$jscomp$inline_5644_shape$jscomp$234$$){var $G__51602_layout_item_h_sizing$$=$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__51603$jscomp$inline_5644_shape$jscomp$234$$)&&$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($G__51603$jscomp$inline_5644_shape$jscomp$234$$)?$APP.$cljs$cst$1672$auto$$:null,$layout_item_v_sizing$$=$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__51603$jscomp$inline_5644_shape$jscomp$234$$)&&
$APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($G__51603$jscomp$inline_5644_shape$jscomp$234$$)?$APP.$cljs$cst$1672$auto$$:null;$G__51603$jscomp$inline_5644_shape$jscomp$234$$=$APP.$app$common$data$without_keys$$($G__51603$jscomp$inline_5644_shape$jscomp$234$$,$APP.$app$common$types$component$swap_keep_attrs$$);$G__51602_layout_item_h_sizing$$=$G__51602_layout_item_h_sizing$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__51603$jscomp$inline_5644_shape$jscomp$234$$,
$APP.$cljs$cst$1708$layout_item_h_sizing$$,$G__51602_layout_item_h_sizing$$):$G__51603$jscomp$inline_5644_shape$jscomp$234$$;return $layout_item_v_sizing$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__51602_layout_item_h_sizing$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$,$layout_item_v_sizing$$):$G__51602_layout_item_h_sizing$$};
$APP.$app$common$types$container$make_component_instance$cljs$0core$0IFn$0_invoke$0arity$05$$=function($page$jscomp$5_vec__51622$$,$component$jscomp$17$$,$library_data$jscomp$1$$,$frame_id$jscomp$26_position$jscomp$46$$,$force_id$jscomp$2_new_shape$jscomp$2_p__51619$$){function $remap_ids$$($shape$jscomp$235$$){var $G__51631$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$235$$,$APP.$cljs$cst$1619$parent_id$$,function($p1__51609_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__51609_SHARP_$$)?
$p1__51609_SHARP_$$:$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$235$$)});return $APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$235$$)?$APP.$app$common$types$shape$layout$remap_grid_cells$$($G__51631$$,$APP.$cljs$core$_deref$$($ids_map$jscomp$8$$)):$G__51631$$}var $force_parent_id_map__51620__$1$$=$APP.$cljs$core$__destructure_map$$($force_id$jscomp$2_new_shape$jscomp$2_p__51619$$),$main_instance_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($force_parent_id_map__51620__$1$$,
$cljs$cst$2548$main_instance_QMARK_$$,!1);$force_id$jscomp$2_new_shape$jscomp$2_p__51619$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($force_parent_id_map__51620__$1$$,$cljs$cst$2091$force_id$$,null);var $force_frame_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($force_parent_id_map__51620__$1$$,$APP.$cljs$cst$2549$force_frame_id$$,null),$keep_ids_QMARK_$jscomp$2_new_shapes$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($force_parent_id_map__51620__$1$$,$APP.$cljs$cst$2092$keep_ids_QMARK_$$,
!1);$force_parent_id_map__51620__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($force_parent_id_map__51620__$1$$,$APP.$cljs$cst$2550$force_parent_id$$,null);var $component_page$$=$APP.$app$common$types$pages_list$get_page$$($library_data$jscomp$1$$,$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$17$$)),$component_shape$$=$app$common$types$container$remove_swap_keep_attrs$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$types$container$get_shape$$($component_page$$,
$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$17$$)),$APP.$cljs$cst$1619$parent_id$$,null),$APP.$cljs$cst$1607$frame_id$$,$APP.$app$common$uuid$zero$$)),$orig_pos$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$$)),$delta$jscomp$11$$=$APP.$app$common$geom$point$subtract$$($frame_id$jscomp$26_position$jscomp$46$$,
$orig_pos$$),$objects$jscomp$192$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$5_vec__51622$$),$unames$jscomp$1$$=$APP.$cljs$core$volatile_BANG_$$($APP.$app$common$files$helpers$get_used_names$$($objects$jscomp$192$$)),$component_children$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$192$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$$)));
$frame_id$jscomp$26_position$jscomp$46$$=function(){return $APP.$cljs$core$truth_$$($force_frame_id$$)?$force_frame_id$$:$app$common$types$shape_tree$get_frame_id_by_position$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$192$$,$APP.$app$common$geom$point$add$$($orig_pos$$,$delta$jscomp$11$$),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$2083$skip_components_QMARK_$$,!0,$APP.$cljs$cst$2087$bottom_frames_QMARK_$$,!0,$cljs$cst$47$validator$$,function($p1__51608_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component_children$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__51608_SHARP_$$))==null&&!$APP.$app$common$types$component$in_component_copy_QMARK_$$($p1__51608_SHARP_$$)}],null))}();var $frame$jscomp$14$$=$APP.$app$common$types$container$get_shape$$($page$jscomp$5_vec__51622$$,$frame_id$jscomp$26_position$jscomp$46$$),$component_frame$$=$app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$192$$,$frame$jscomp$14$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$2547$allow_main_QMARK_$$,!0],null)),$ids_map$jscomp$8$$=$APP.$cljs$core$volatile_BANG_$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$page$jscomp$5_vec__51622$$=$APP.$app$common$types$shape_tree$clone_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($component_shape$$,$APP.$cljs$core$truth_$$($force_parent_id_map__51620__$1$$)?$force_parent_id_map__51620__$1$$:$frame_id$jscomp$26_position$jscomp$46$$,$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component_page$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2089$update_new_shape$$,
function($G__51625__$1_new_shape$jscomp$3$$,$original_shape$$){var $G__51625__$6_new_name$jscomp$9$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($G__51625__$1_new_shape$jscomp$3$$),$G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$=$APP.$app$common$types$component$instance_root_QMARK_$$($original_shape$$);$G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$&&$unames$jscomp$1$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($unames$jscomp$1$$.$cljs$core$IDeref$_deref$arity$1$(null),
$G__51625__$6_new_name$jscomp$9$$));$ids_map$jscomp$8$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($ids_map$jscomp$8$$.$cljs$core$IDeref$_deref$arity$1$(null),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($original_shape$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__51625__$1_new_shape$jscomp$3$$)));$G__51625__$1_new_shape$jscomp$3$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($app$common$geom$shapes$transforms$move$$($G__51625__$1_new_shape$jscomp$3$$,
$delta$jscomp$11$$),$APP.$cljs$cst$1626$touched$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2000$variant_id$$,$APP.$cljs$cst$2002$variant_name$$]));$G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($main_instance_QMARK_$$)?$G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$:$main_instance_QMARK_$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__51625__$1_new_shape$jscomp$3$$,
$APP.$cljs$cst$2045$main_instance$$,!0):$G__51625__$1_new_shape$jscomp$3$$;$G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$=$APP.$cljs$core$not$$($main_instance_QMARK_$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$,$APP.$cljs$cst$2045$main_instance$$):$G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$;$G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$=$APP.$cljs$core$truth_$$($main_instance_QMARK_$$)?
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$,$APP.$cljs$cst$2047$shape_ref$$):$G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$;$G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$=$APP.$cljs$core$not$$($main_instance_QMARK_$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$,$APP.$cljs$cst$2047$shape_ref$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($original_shape$$)):
$G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$;$G__51625__$6_new_name$jscomp$9$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($original_shape$$)==null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$,$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$17$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1643$component_file$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$1$$),$APP.$cljs$cst$2044$component_root$$,!0,$APP.$cljs$cst$725$name$$,$G__51625__$6_new_name$jscomp$9$$])):$G__51625__$2_G__51625__$3_G__51625__$4_G__51625__$5_root_QMARK_$$;return $APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($original_shape$$)!=null||$component_frame$$!=null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__51625__$6_new_name$jscomp$9$$,$APP.$cljs$cst$2044$component_root$$):
$G__51625__$6_new_name$jscomp$9$$},$cljs$cst$2091$force_id$$,$force_id$jscomp$2_new_shape$jscomp$2_p__51619$$,$APP.$cljs$cst$2092$keep_ids_QMARK_$$,$keep_ids_QMARK_$jscomp$2_new_shapes$jscomp$2$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$26_position$jscomp$46$$,$cljs$cst$2093$dest_objects$$,$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$5_vec__51622$$)]));$force_id$jscomp$2_new_shape$jscomp$2_p__51619$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($page$jscomp$5_vec__51622$$,
0,null);$keep_ids_QMARK_$jscomp$2_new_shapes$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($page$jscomp$5_vec__51622$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($page$jscomp$5_vec__51622$$,2,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$remap_ids$$($force_id$jscomp$2_new_shape$jscomp$2_p__51619$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($remap_ids$$,$keep_ids_QMARK_$jscomp$2_new_shapes$jscomp$2$$)],
null)};
$APP.$app$common$types$container$valid_shape_for_component_QMARK_$$=function($objects$jscomp$196$$,$shape$jscomp$239$$){var $children$jscomp$inline_5650_or__5025__auto__$jscomp$inline_5652$$=$APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$196$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$239$$));var $JSCompiler_inline_result$jscomp$903_parents$jscomp$inline_5651$$=$APP.$app$common$files$helpers$get_parents$$($objects$jscomp$196$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$239$$));$children$jscomp$inline_5650_or__5025__auto__$jscomp$inline_5652$$=
$APP.$cljs$core$some$$($APP.$app$common$types$component$main_instance_QMARK_$$,$children$jscomp$inline_5650_or__5025__auto__$jscomp$inline_5652$$);$JSCompiler_inline_result$jscomp$903_parents$jscomp$inline_5651$$=$APP.$cljs$core$truth_$$($children$jscomp$inline_5650_or__5025__auto__$jscomp$inline_5652$$)?$children$jscomp$inline_5650_or__5025__auto__$jscomp$inline_5652$$:$APP.$cljs$core$some$$($APP.$app$common$types$component$main_instance_QMARK_$$,$JSCompiler_inline_result$jscomp$903_parents$jscomp$inline_5651$$);
return $APP.$cljs$core$not$$($JSCompiler_inline_result$jscomp$903_parents$jscomp$inline_5651$$)&&$APP.$cljs$core$not$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$196$$,$shape$jscomp$239$$))};
$app$common$types$container$get_component_from_shape$$=function($shape$jscomp$241$$,$libraries$jscomp$1$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$241$$),$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$1638$components$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$241$$)],
null))};
$app$common$types$container$invalid_structure_for_component_QMARK_$$=function($comps_nesting_loop_QMARK__objects$jscomp$198_selected_components$$,$parent$jscomp$194$$,$children$jscomp$184$$,$pasting_QMARK_$$,$libraries$jscomp$2$$){var $objects__$1$jscomp$3$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$comps_nesting_loop_QMARK__objects$jscomp$198_selected_components$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,
$APP.$cljs$core$identity$$),$children$jscomp$184$$))]));$comps_nesting_loop_QMARK__objects$jscomp$198_selected_components$$=function(){var $G__51648$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$types$container$collect_main_shapes$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$children$jscomp$184$$,$objects__$1$jscomp$3$$]));return $APP.$cljs$core$truth_$$($pasting_QMARK_$$)?$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($component$jscomp$inline_5655_p1__51645_SHARP_$$){$component$jscomp$inline_5655_p1__51645_SHARP_$$=
$app$common$types$container$get_component_from_shape$$($component$jscomp$inline_5655_p1__51645_SHARP_$$,$libraries$jscomp$2$$);return $APP.$cljs$core$truth_$$($component$jscomp$inline_5655_p1__51645_SHARP_$$)?$APP.$cljs$core$not$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_5655_p1__51645_SHARP_$$)):$component$jscomp$inline_5655_p1__51645_SHARP_$$},$G__51648$$):$G__51648$$}();var $or__5025__auto____$2$jscomp$12_selected_main_instance_QMARK_$$=$APP.$cljs$core$seq$$($comps_nesting_loop_QMARK__objects$jscomp$198_selected_components$$),
$parent_in_component_QMARK_$$=$APP.$app$common$types$container$in_any_component_QMARK_$$($objects__$1$jscomp$3$$,$parent$jscomp$194$$);$comps_nesting_loop_QMARK__objects$jscomp$198_selected_components$$=!$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$nil_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51646_SHARP_$$){return $app$common$files$helpers$components_nesting_loop_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($objects__$1$jscomp$3$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__51646_SHARP_$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$194$$))},$children$jscomp$184$$));var $or__5025__auto__$jscomp$460_or__5025__auto____$1$jscomp$49$$=$APP.$app$common$types$component$in_component_copy_QMARK_$$($parent$jscomp$194$$);if($or__5025__auto__$jscomp$460_or__5025__auto____$1$jscomp$49$$)return $or__5025__auto__$jscomp$460_or__5025__auto____$1$jscomp$49$$;$or__5025__auto__$jscomp$460_or__5025__auto____$1$jscomp$49$$=$APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects__$1$jscomp$3$$,
$parent$jscomp$194$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$460_or__5025__auto____$1$jscomp$49$$))return $or__5025__auto__$jscomp$460_or__5025__auto____$1$jscomp$49$$;$or__5025__auto____$2$jscomp$12_selected_main_instance_QMARK_$$=$or__5025__auto____$2$jscomp$12_selected_main_instance_QMARK_$$?$parent_in_component_QMARK_$$:$or__5025__auto____$2$jscomp$12_selected_main_instance_QMARK_$$;return $APP.$cljs$core$truth_$$($or__5025__auto____$2$jscomp$12_selected_main_instance_QMARK_$$)?
$or__5025__auto____$2$jscomp$12_selected_main_instance_QMARK_$$:$comps_nesting_loop_QMARK__objects$jscomp$198_selected_components$$};
$app$common$types$container$parent_validation_cache$$=function($objects$jscomp$199$$,$children$jscomp$185$$,$libraries$jscomp$3$$){function $get_variant_id$$($shape$jscomp$243$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$243$$))?$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($app$common$types$container$get_component_from_shape$$($shape$jscomp$243$$,$libraries$jscomp$3$$)):null}var $children_ids$jscomp$4$$=$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$children$jscomp$185$$)),$top_children$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51649_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($children_ids$jscomp$4$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__51649_SHARP_$$))},$children$jscomp$185$$),$all_main_QMARK_$$=$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$component$main_instance_QMARK_$$,$top_children$$),$descendants$$=new $APP.$cljs$core$Delay$$(function(){return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__51650_SHARP_$$){return $APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$199$$,
$p1__51650_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$children_ids$jscomp$4$$]))});return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$2551$top_children$$,$top_children$$,$cljs$cst$2552$all_main_QMARK_$$,$all_main_QMARK_$$,$cljs$cst$129$descendants$$,$descendants$$,$cljs$cst$2553$any_variant_container_descendant$$,new $APP.$cljs$core$Delay$$(function(){return $APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_container_QMARK_$$,$APP.$cljs$core$_deref$$($descendants$$))}),
$cljs$cst$2554$descendants_variant_ids_set$$,new $APP.$cljs$core$Delay$$(function(){return $APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($get_variant_id$$,$APP.$cljs$core$_deref$$($descendants$$)))}),$cljs$cst$2555$any_main_descendant$$,new $APP.$cljs$core$Delay$$(function(){return $APP.$cljs$core$some$$(function($shape$jscomp$244$$){return $APP.$cljs$core$some$$($APP.$app$common$types$component$main_instance_QMARK_$$,$APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$199$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$244$$)))},$children$jscomp$185$$)})],null)};
$app$common$types$container$find_valid_parent_and_frame_ids$cljs$0core$0IFn$0_invoke$0arity$05$$=function($parent_id$jscomp$24$$,$objects$jscomp$201$$,$children$jscomp$187$$,$pasting_QMARK_$jscomp$1$$,$libraries$jscomp$4$$){return $app$common$types$container$find_valid_parent_and_frame_ids$cljs$0core$0IFn$0_invoke$0arity$06$$($parent_id$jscomp$24$$,$objects$jscomp$201$$,$children$jscomp$187$$,$pasting_QMARK_$jscomp$1$$,$libraries$jscomp$4$$,null)};
$app$common$types$container$find_valid_parent_and_frame_ids$cljs$0core$0IFn$0_invoke$0arity$06$$=function($parent_id$jscomp$25_parent_id__$1$jscomp$2$$,$objects$jscomp$202$$,$children$jscomp$188$$,$pasting_QMARK_$jscomp$2$$,$libraries$jscomp$5$$,$cache$jscomp$103_map__51655$$){function $get_frame$$($pid$jscomp$2$$){return $APP.$cljs$core$truth_$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$202$$,$pid$jscomp$2$$))?$pid$jscomp$2$$:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$202$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$pid$jscomp$2$$,$APP.$cljs$cst$1607$frame_id$$],null))}$cache$jscomp$103_map__51655$$=$APP.$cljs$core$truth_$$($cache$jscomp$103_map__51655$$)?$cache$jscomp$103_map__51655$$:$app$common$types$container$parent_validation_cache$$($objects$jscomp$202$$,$children$jscomp$188$$,$libraries$jscomp$5$$);for(var $map__51655__$1$$=$APP.$cljs$core$__destructure_map$$($cache$jscomp$103_map__51655$$),$top_children$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51655__$1$$,$cljs$cst$2551$top_children$$),$all_main_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51655__$1$$,$cljs$cst$2552$all_main_QMARK_$$),$any_variant_container_descendant$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51655__$1$$,$cljs$cst$2553$any_variant_container_descendant$$),$descendants_variant_ids_set$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51655__$1$$,
$cljs$cst$2554$descendants_variant_ids_set$$),$any_main_descendant$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51655__$1$$,$cljs$cst$2555$any_main_descendant$$);;){var $parent$jscomp$195$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$202$$,$parent_id$jscomp$25_parent_id__$1$jscomp$2$$),$no_changes_QMARK_$$=$APP.$cljs$core$every_QMARK_$$(function($parent_id__$1$jscomp$3$$){return function($p1__51651_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parent_id__$1$jscomp$3$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__51651_SHARP_$$))}}($parent_id$jscomp$25_parent_id__$1$jscomp$2$$,$parent$jscomp$195$$,$cache$jscomp$103_map__51655$$,$map__51655__$1$$,$top_children$jscomp$1$$,$all_main_QMARK_$jscomp$1$$,$any_variant_container_descendant$jscomp$1$$,$descendants_variant_ids_set$jscomp$1$$,$any_main_descendant$jscomp$1$$),$top_children$jscomp$1$$)&&$APP.$cljs$core$not$$($pasting_QMARK_$jscomp$2$$),$ascendants$$=$app$common$files$helpers$get_parents_with_self$$($objects$jscomp$202$$,
$parent_id$jscomp$25_parent_id__$1$jscomp$2$$),$any_main_ascendant$$=$APP.$cljs$core$some$$($APP.$app$common$types$component$main_instance_QMARK_$$,$ascendants$$),$any_variant_container_ascendant$$=$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_container_QMARK_$$,$ascendants$$);if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$=
$no_changes_QMARK_$$;return $and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$?$and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$:($and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$=
$APP.$cljs$core$not$$($app$common$types$container$invalid_structure_for_component_QMARK_$$($objects$jscomp$202$$,$parent$jscomp$195$$,$children$jscomp$188$$,$pasting_QMARK_$jscomp$2$$,$libraries$jscomp$5$$)))?($and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$=$APP.$cljs$core$truth_$$($pasting_QMARK_$jscomp$2$$)?$pasting_QMARK_$jscomp$2$$:!$APP.$app$common$types$component$main_instance_QMARK_$$($parent$jscomp$195$$)||
$APP.$cljs$core$_deref$$($any_main_descendant$jscomp$1$$)==null,$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$)?($and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$=$APP.$cljs$core$not$$($any_variant_container_ascendant$$)&&
$APP.$cljs$core$not$$($any_main_ascendant$$)||$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($any_variant_container_descendant$jscomp$1$$)))?($and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$=($and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$=
$APP.$cljs$core$not$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($parent$jscomp$195$$)))?$and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$:$all_main_QMARK_$jscomp$1$$,$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$)?
$APP.$cljs$core$not$$($pasting_QMARK_$jscomp$2$$)||!$APP.$app$common$types$component$is_variant_QMARK_$$($parent$jscomp$195$$)||!$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($descendants_variant_ids_set$jscomp$1$$),$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$195$$)):$and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$):
$and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$:$and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$):$and__5023__auto__$jscomp$299_and__5023__auto____$1$jscomp$53_and__5023__auto____$2$jscomp$22_and__5023__auto____$3$jscomp$3_or__5025__auto__$jscomp$462_or__5025__auto____$1$jscomp$inline_12054$$}()))return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent_id$jscomp$25_parent_id__$1$jscomp$2$$,$get_frame$$($parent_id$jscomp$25_parent_id__$1$jscomp$2$$)],null);$parent_id$jscomp$25_parent_id__$1$jscomp$2$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$195$$)}};
$app$common$types$container$get_token_groups$$=function($shape$jscomp$245$$,$new_applied_tokens$$){var $old_applied_tokens$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$245$$),$APP.$cljs$core$PersistentHashSet$EMPTY$$),$changed_token_attrs$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51661_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_applied_tokens$$,
$p1__51661_SHARP_$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_applied_tokens$$,$p1__51661_SHARP_$$))},$APP.$app$common$types$token$all_keys$$),$shape_type$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$245$$,$APP.$cljs$cst$139$type$$),$text_shape_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_type$jscomp$1$$,$APP.$cljs$cst$1588$text$$),$attrs_in_text_content_QMARK_$$=$APP.$cljs$core$some$$(function($p1__51662_SHARP_$$){return $app$common$types$token$attrs_in_text_content$$.$cljs$core$IFn$_invoke$arity$1$?
$app$common$types$token$attrs_in_text_content$$.$cljs$core$IFn$_invoke$arity$1$($p1__51662_SHARP_$$):$app$common$types$token$attrs_in_text_content$$($p1__51662_SHARP_$$)},$changed_token_attrs$$),$changed_groups$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$common$types$token$token_attr__GT_shape_attr$$),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__51663_SHARP_$$){return $app$common$types$component$resolve_sync_group$$($shape_type$jscomp$1$$,
$p1__51663_SHARP_$$)})),$changed_token_attrs$$);return $APP.$cljs$core$truth_$$(function(){if($text_shape_QMARK_$$){var $and__5023__auto____$1$jscomp$54$$=$APP.$app$common$data$not_empty_QMARK_$$($changed_groups$$);return $and__5023__auto____$1$jscomp$54$$?$attrs_in_text_content_QMARK_$$:$and__5023__auto____$1$jscomp$54$$}return $text_shape_QMARK_$$}())?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($changed_groups$$,$cljs$cst$2070$content_group$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$1775$text_content_attribute$$])):
$changed_groups$$};
$app$common$types$container$set_shape_attr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($G__51675__$1_G__51675__$2_shape$jscomp$246$$,$attr$jscomp$22$$,$G__51675__$3_val$jscomp$166$$,$ignore_touched$jscomp$2_p__51670_touched_QMARK_$$){var $group$jscomp$26_map__51671__$1$$=$APP.$cljs$core$__destructure_map$$($ignore_touched$jscomp$2_p__51670_touched_QMARK_$$);$ignore_touched$jscomp$2_p__51670_touched_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group$jscomp$26_map__51671__$1$$,$APP.$cljs$cst$2556$ignore_touched$$);
var $ignore_geometry$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group$jscomp$26_map__51671__$1$$,$APP.$cljs$cst$2557$ignore_geometry$$),$content_diff_type_type$jscomp$375$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__51675__$1_G__51675__$2_shape$jscomp$246$$,$APP.$cljs$cst$139$type$$);$group$jscomp$26_map__51671__$1$$=$app$common$types$component$resolve_sync_group$$($content_diff_type_type$jscomp$375$$,$attr$jscomp$22$$);var $equal_QMARK__shape_val$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__51675__$1_G__51675__$2_shape$jscomp$246$$,
$attr$jscomp$22$$),$ignore_QMARK_$jscomp$1$$=$APP.$cljs$core$truth_$$($ignore_touched$jscomp$2_p__51670_touched_QMARK_$$)?$ignore_touched$jscomp$2_p__51670_touched_QMARK_$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$22$$,$APP.$cljs$cst$1891$position_data$$),$is_geometry_QMARK_$$=($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($group$jscomp$26_map__51671__$1$$,$cljs$cst$2065$geometry_group$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($group$jscomp$26_map__51671__$1$$,
$cljs$cst$2070$content_group$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__51675__$1_G__51675__$2_shape$jscomp$246$$),$APP.$cljs$cst$296$path$$))&&$APP.$cljs$core$not$$(function(){var $fexpr__51673$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1522$height$$,null],null),null);return $fexpr__51673$$.$cljs$core$IFn$_invoke$arity$1$?
$fexpr__51673$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$22$$):$fexpr__51673$$($attr$jscomp$22$$)}()),$in_copy_QMARK_$$=$APP.$app$common$types$component$in_component_copy_QMARK_$$($G__51675__$1_G__51675__$2_shape$jscomp$246$$);$equal_QMARK__shape_val$$=$is_geometry_QMARK_$$?$app$common$geom$shapes$close_attrs_QMARK_$cljs$0core$0IFn$0_invoke$0arity$04$$($attr$jscomp$22$$,$G__51675__$3_val$jscomp$166$$,$equal_QMARK__shape_val$$,1):$app$common$geom$shapes$close_attrs_QMARK_$cljs$0core$0IFn$0_invoke$0arity$04$$($attr$jscomp$22$$,
$G__51675__$3_val$jscomp$166$$,$equal_QMARK__shape_val$$,.001);$ignore_touched$jscomp$2_p__51670_touched_QMARK_$$=$APP.$cljs$core$truth_$$($group$jscomp$26_map__51671__$1$$)?$APP.$cljs$core$not$$($equal_QMARK__shape_val$$)&&$APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($ignore_geometry$$)?$is_geometry_QMARK_$$:$ignore_geometry$$):$group$jscomp$26_map__51671__$1$$;$content_diff_type_type$jscomp$375$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($content_diff_type_type$jscomp$375$$,$APP.$cljs$cst$1588$text$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$22$$,$APP.$cljs$cst$1637$content$$)?$app$common$types$text$get_diff_type$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($G__51675__$1_G__51675__$2_shape$jscomp$246$$),$G__51675__$3_val$jscomp$166$$):null;var $token_groups$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$22$$,$APP.$cljs$cst$1873$applied_tokens$$)?$app$common$types$container$get_token_groups$$($G__51675__$1_G__51675__$2_shape$jscomp$246$$,
$G__51675__$3_val$jscomp$166$$):$APP.$cljs$core$PersistentHashSet$EMPTY$$,$groups$jscomp$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($group$jscomp$26_map__51671__$1$$)?$APP.$cljs$core$not$$($equal_QMARK__shape_val$$):$group$jscomp$26_map__51671__$1$$)?$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$variadic$($token_groups$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$group$jscomp$26_map__51671__$1$$]),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$content_diff_type_type$jscomp$375$$])):
$token_groups$$;$G__51675__$1_G__51675__$2_shape$jscomp$246$$=$APP.$cljs$core$truth_$$(function(){if($in_copy_QMARK_$$){var $and__5023__auto____$1$jscomp$55$$=$APP.$cljs$core$not_empty$$($groups$jscomp$1$$);return $APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$55$$)?$APP.$cljs$core$not$$($ignore_QMARK_$jscomp$1$$)&&$APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($ignore_geometry$$)?$is_geometry_QMARK_$$:$ignore_geometry$$):$and__5023__auto____$1$jscomp$55$$}return $in_copy_QMARK_$$}())?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__51675__$1_G__51675__$2_shape$jscomp$246$$,
$APP.$cljs$cst$1626$touched$$,function($touched$jscomp$3$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__51664_SHARP_$$,$p2__51665_SHARP_$$){return $app$common$types$component$set_touched_group$$($p1__51664_SHARP_$$,$p2__51665_SHARP_$$)},$touched$jscomp$3$$,$groups$jscomp$1$$)}),$APP.$cljs$cst$2046$remote_synced$$):$G__51675__$1_G__51675__$2_shape$jscomp$246$$;$G__51675__$1_G__51675__$2_shape$jscomp$246$$=$G__51675__$3_val$jscomp$166$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__51675__$1_G__51675__$2_shape$jscomp$246$$,
$attr$jscomp$22$$):$G__51675__$1_G__51675__$2_shape$jscomp$246$$;$G__51675__$3_val$jscomp$166$$=$G__51675__$3_val$jscomp$166$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__51675__$1_G__51675__$2_shape$jscomp$246$$,$attr$jscomp$22$$,$G__51675__$3_val$jscomp$166$$):$G__51675__$1_G__51675__$2_shape$jscomp$246$$;return $APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($G__51675__$3_val$jscomp$166$$,$cljs$cst$2558$app_DOT_common_DOT_types_DOT_container_SLASH_touched$$,
$ignore_touched$jscomp$2_p__51670_touched_QMARK_$$)};
$app$common$features$check_paste_features_BANG_$$=function($enabled_features$jscomp$4_not_supported$jscomp$3$$,$paste_features$$){var $not_supported_51570_not_supported_51573$$=$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($enabled_features$jscomp$4_not_supported$jscomp$3$$,$paste_features$$),$APP.$app$common$features$no_migration_features$$);if($APP.$cljs$core$seq$$($not_supported_51570_not_supported_51573$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("expected features '"+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",
$not_supported_51570_not_supported_51573$$)??"")+"' not present in pasted content",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2561$restriction$$,$APP.$cljs$cst$273$code$$,$cljs$cst$2568$missing_features_in_paste_content$$,$APP.$cljs$cst$2563$feature$$,$APP.$cljs$core$first$$($not_supported_51570_not_supported_51573$$),$APP.$cljs$cst$275$hint$$,
"expected features '"+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$not_supported_51570_not_supported_51573$$)??"")+"' not present in pasted content"],null),null])),null);$not_supported_51570_not_supported_51573$$=$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($enabled_features$jscomp$4_not_supported$jscomp$3$$,$APP.$app$common$features$supported_features$$);if($APP.$cljs$core$seq$$($not_supported_51570_not_supported_51573$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("features '"+
($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$not_supported_51570_not_supported_51573$$)??"")+"' not supported in the application",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2561$restriction$$,$APP.$cljs$cst$273$code$$,$cljs$cst$2569$paste_feature_not_supported$$,$APP.$cljs$cst$2563$feature$$,$APP.$cljs$core$first$$($not_supported_51570_not_supported_51573$$),
$APP.$cljs$cst$275$hint$$,"features '"+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$not_supported_51570_not_supported_51573$$)??"")+"' not supported in the application"],null),null])),null);$enabled_features$jscomp$4_not_supported$jscomp$3$$=$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($paste_features$$,$enabled_features$jscomp$4_not_supported$jscomp$3$$),
$app$common$features$backend_only_features$$),$APP.$app$common$features$frontend_only_features$$);if($APP.$cljs$core$seq$$($enabled_features$jscomp$4_not_supported$jscomp$3$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("paste features '"+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$enabled_features$jscomp$4_not_supported$jscomp$3$$)??"")+"' not enabled on the application",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2561$restriction$$,$APP.$cljs$cst$273$code$$,$cljs$cst$2570$paste_feature_not_enabled$$,$APP.$cljs$cst$2563$feature$$,$APP.$cljs$core$first$$($enabled_features$jscomp$4_not_supported$jscomp$3$$),$APP.$cljs$cst$275$hint$$,"paste features '"+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$enabled_features$jscomp$4_not_supported$jscomp$3$$)??"")+"' not enabled on the application"],null),null])),null);};
$APP.$app$common$geom$shapes$tree_seq$get_children_seq$$=function($id$jscomp$252$$,$objects$jscomp$203$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51416_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$203$$,$p1__51416_SHARP_$$)},$APP.$cljs$core$tree_seq$$(function($p1__51415_SHARP_$$){return $APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$203$$,
$p1__51415_SHARP_$$),$APP.$cljs$cst$1614$shapes$$))},function($id__$1$jscomp$3_shape$jscomp$247$$){$id__$1$jscomp$3_shape$jscomp$247$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$203$$,$id__$1$jscomp$3_shape$jscomp$247$$);var $G__51421$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($id__$1$jscomp$3_shape$jscomp$247$$);return $APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($id__$1$jscomp$3_shape$jscomp$247$$)&&$APP.$app$common$types$shape$layout$reverse_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($id__$1$jscomp$3_shape$jscomp$247$$)?
$APP.$cljs$core$reverse$$($G__51421$$):$G__51421$$},$id$jscomp$252$$))};
$app$common$geom$shapes$tree_seq$get_reflow_root$cljs$0core$0IFn$0_invoke$0arity$03$$=function($current$jscomp$29_parent_id$jscomp$26$$,$G__51472_G__51475_last_root$$,$G__51473_G__51476_objects$jscomp$205$$){for(;;){var $parent$jscomp$197_shape$jscomp$248$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__51473_G__51476_objects$jscomp$205$$,$current$jscomp$29_parent_id$jscomp$26$$);if(!$parent$jscomp$197_shape$jscomp$248$$||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,
$current$jscomp$29_parent_id$jscomp$26$$))return $G__51472_G__51475_last_root$$;$current$jscomp$29_parent_id$jscomp$26$$=$parent$jscomp$197_shape$jscomp$248$$?.$parent_id$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$197_shape$jscomp$248$$,$APP.$cljs$cst$1619$parent_id$$);$parent$jscomp$197_shape$jscomp$248$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__51473_G__51476_objects$jscomp$205$$,$current$jscomp$29_parent_id$jscomp$26$$);if($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$197_shape$jscomp$248$$)&&
!$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$197_shape$jscomp$248$$))return $G__51472_G__51475_last_root$$;if($APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$197_shape$jscomp$248$$)&&$app$common$types$shape$layout$auto_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$197_shape$jscomp$248$$))$G__51472_G__51475_last_root$$=$current$jscomp$29_parent_id$jscomp$26$$;else if($APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$197_shape$jscomp$248$$))return $current$jscomp$29_parent_id$jscomp$26$$}};
$app$common$geom$shapes$tree_seq$search_common_roots$$=function($ids$jscomp$33$$,$objects$jscomp$206$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($roots_roots__$1$$,$id$jscomp$254_root$jscomp$36$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$254_root$jscomp$36$$,$APP.$app$common$uuid$zero$$))return $roots_roots__$1$$;$id$jscomp$254_root$jscomp$36$$=$app$common$geom$shapes$tree_seq$get_reflow_root$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$254_root$jscomp$36$$,
$id$jscomp$254_root$jscomp$36$$,$objects$jscomp$206$$);var $contains_parent_QMARK__shape$jscomp$inline_12056$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$206$$,$id$jscomp$254_root$jscomp$36$$);$roots_roots__$1$$=$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($contains_parent_QMARK__shape$jscomp$inline_12056$$))?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$is_child_QMARK_$$,
$objects$jscomp$206$$,$id$jscomp$254_root$jscomp$36$$)),$roots_roots__$1$$):$roots_roots__$1$$;$contains_parent_QMARK__shape$jscomp$inline_12056$$=$APP.$cljs$core$some$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$contains_QMARK_$$,$roots_roots__$1$$),$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$206$$,$id$jscomp$254_root$jscomp$36$$));return $APP.$cljs$core$not$$($contains_parent_QMARK__shape$jscomp$inline_12056$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($roots_roots__$1$$,
$id$jscomp$254_root$jscomp$36$$):$roots_roots__$1$$},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$ids$jscomp$33$$)};
$app$common$geom$shapes$tree_seq$resolve_tree$$=function($ids$jscomp$34$$,$objects$jscomp$207$$){var $child_seq$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__51450_SHARP_$$){return $APP.$app$common$geom$shapes$tree_seq$get_children_seq$$($p1__51450_SHARP_$$,$objects$jscomp$207$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$geom$shapes$tree_seq$search_common_roots$$($ids$jscomp$34$$,$objects$jscomp$207$$)]));return $APP.$cljs$core$contains_QMARK_$$($ids$jscomp$34$$,
$APP.$app$common$uuid$zero$$)?$APP.$cljs$core$cons$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$207$$,$APP.$app$common$uuid$zero$$),$child_seq$$):$child_seq$$};
$app$common$geom$shapes$tree_seq$resolve_subtree$$=function($from_id$$,$to_id$$,$objects$jscomp$208$$){return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($app$common$data$take_until$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__51459_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__51459_SHARP_$$),$to_id$$)},$APP.$app$common$geom$shapes$tree_seq$get_children_seq$$($from_id$$,$objects$jscomp$208$$)),
$APP.$cljs$core$rest$$($APP.$app$common$geom$shapes$tree_seq$get_children_seq$$($to_id$$,$objects$jscomp$208$$)))};$app$common$types$library$get_colors$$=function($file_data$jscomp$18$$){return $APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$18$$)};
$APP.$app$common$types$library$get_color$$=function($file_data$jscomp$19$$,$color_id$jscomp$1$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_data$jscomp$19$$,$APP.$cljs$cst$2212$colors$$),$color_id$jscomp$1$$)};
$app$common$types$library$used_colors_changed_since$$=function($shape$jscomp$249$$,$library$jscomp$3$$,$since_date$jscomp$1$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($color$jscomp$32$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$249$$),$APP.$cljs$cst$2544$asset_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$32$$),$APP.$cljs$cst$2545$asset_type$$,
$APP.$cljs$cst$1298$color$$],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51452_SHARP_$$){return $APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($p1__51452_SHARP_$$)<$since_date$jscomp$1$$},$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__51451_SHARP_$$){var $library_data$jscomp$inline_5657$$=$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$3$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1736$ref_file$$.$cljs$core$IFn$_invoke$arity$1$($p1__51451_SHARP_$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$inline_5657$$))?$APP.$app$common$types$library$get_color$$($library_data$jscomp$inline_5657$$,$APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__51451_SHARP_$$)):null},$app$common$types$shape$get_all_colors$$($shape$jscomp$249$$))))};
$app$common$types$library$sync_colors$$=function($shape$jscomp$250$$,$library_id$jscomp$5$$,$library_colors$$){return $app$common$types$shape$process_shape_colors$$($shape$jscomp$250$$,function($shape__$1$jscomp$23$$,$position$jscomp$47$$,$G__51504_library_color_shape_color$jscomp$1$$,$set_fn$$,$G__51502__$jscomp$1572$$,$G__51501_detach_fn$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1736$ref_file$$.$cljs$core$IFn$_invoke$arity$1$($G__51504_library_color_shape_color$jscomp$1$$),
$library_id$jscomp$5$$)){$G__51504_library_color_shape_color$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($library_colors$$,$APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($G__51504_library_color_shape_color$jscomp$1$$));if($G__51504_library_color_shape_color$jscomp$1$$!=null){$G__51501_detach_fn$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($G__51504_library_color_shape_color$jscomp$1$$);$G__51502__$jscomp$1572$$=$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($G__51504_library_color_shape_color$jscomp$1$$);
var $G__51503$$=$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($G__51504_library_color_shape_color$jscomp$1$$);$G__51504_library_color_shape_color$jscomp$1$$=$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($G__51504_library_color_shape_color$jscomp$1$$);return $set_fn$$.$cljs$core$IFn$_invoke$arity$6$?$set_fn$$.$cljs$core$IFn$_invoke$arity$6$($shape__$1$jscomp$23$$,$position$jscomp$47$$,$G__51501_detach_fn$$,$G__51502__$jscomp$1572$$,$G__51503$$,$G__51504_library_color_shape_color$jscomp$1$$):
$set_fn$$($shape__$1$jscomp$23$$,$position$jscomp$47$$,$G__51501_detach_fn$$,$G__51502__$jscomp$1572$$,$G__51503$$,$G__51504_library_color_shape_color$jscomp$1$$)}return $G__51501_detach_fn$$.$cljs$core$IFn$_invoke$arity$2$?$G__51501_detach_fn$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$23$$,$position$jscomp$47$$):$G__51501_detach_fn$$($shape__$1$jscomp$23$$,$position$jscomp$47$$)}return $shape__$1$jscomp$23$$})};
$APP.$app$common$types$typographies_list$get_typography$$=function($file_data$jscomp$26$$,$typography_id$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file_data$jscomp$26$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2215$typographies$$,$typography_id$$],null))};
$app$common$types$typographies_list$update_typography$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($file_data$jscomp$28$$,$typography_id$jscomp$1$$,$args$jscomp$243$$){return $APP.$app$common$data$update_in_when$$($file_data$jscomp$28$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2215$typographies$$,$typography_id$jscomp$1$$],null),function($p1__51427_SHARP__typography$jscomp$inline_12058$$){$p1__51427_SHARP__typography$jscomp$inline_12058$$=
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$merge$$,$p1__51427_SHARP__typography$jscomp$inline_12058$$,$args$jscomp$243$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__51427_SHARP__typography$jscomp$inline_12058$$,$APP.$cljs$cst$1737$modified_at$$,$APP.$app$common$time$now$$())})};
$app$common$types$typographies_list$used_typographies_changed_since$$=function($shape$jscomp$251$$,$library$jscomp$4$$,$since_date$jscomp$2$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($node$jscomp$258$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$251$$),$APP.$cljs$cst$2544$asset_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$258$$),
$APP.$cljs$cst$2545$asset_type$$,$APP.$cljs$cst$1981$typography$$],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51446_SHARP_$$){return $APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($p1__51446_SHARP_$$)<$since_date$jscomp$2$$},$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__51445_SHARP_$$){var $library_data$jscomp$inline_5660$$=$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$4$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1642$typography_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($p1__51445_SHARP_$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$inline_5660$$))?$APP.$app$common$types$typographies_list$get_typography$$($library_data$jscomp$inline_5660$$,$APP.$cljs$cst$1756$typography_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__51445_SHARP_$$)):null},$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$251$$)))))};
$app$common$types$typography$uses_library_typographies_QMARK_$$=function($shape$jscomp$252$$,$library_id$jscomp$6$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$252$$),$APP.$cljs$cst$1588$text$$)&&$APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__51589_SHARP_$$){return $APP.$cljs$cst$1756$typography_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__51589_SHARP_$$)!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1642$typography_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($p1__51589_SHARP_$$),
$library_id$jscomp$6$$)},$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$252$$))};
$app$common$types$typography$uses_library_typography_QMARK_$$=function($shape$jscomp$253$$,$library_id$jscomp$7$$,$typography_id$jscomp$3$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$253$$),$APP.$cljs$cst$1588$text$$)&&$APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__51591_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1756$typography_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__51591_SHARP_$$),$typography_id$jscomp$3$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1642$typography_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($p1__51591_SHARP_$$),$library_id$jscomp$7$$)},$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$253$$))};$app$common$types$typography$remove_typography_from_node$$=function($node$jscomp$259$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($node$jscomp$259$$,$APP.$cljs$cst$1642$typography_ref_file$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1756$typography_ref_id$$]))};
$app$common$types$typography$remove_external_typographies$$=function($shape$jscomp$255$$,$file_id$jscomp$24$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$255$$,$APP.$cljs$cst$1637$content$$,function($content$jscomp$114$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__51613_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1642$typography_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($p1__51613_SHARP_$$),
$file_id$jscomp$24$$)},$app$common$types$typography$remove_typography_from_node$$,$content$jscomp$114$$)})};
$app$common$types$file$containers_seq$$=function($file_data$jscomp$30$$){return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51703_SHARP_$$){return $app$common$types$container$make_container$$($p1__51703_SHARP_$$,$APP.$cljs$cst$1624$page$$)},$APP.$cljs$core$seq$$($APP.$cljs$core$vals$$($APP.$cljs$cst$1630$pages_index$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$30$$)))),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51704_SHARP_$$){return $app$common$types$container$make_container$$($p1__51704_SHARP_$$,
$APP.$cljs$cst$1625$component$$)},$APP.$app$common$types$components_list$components_seq$$($file_data$jscomp$30$$)))};
$APP.$app$common$types$file$object_containers_seq$$=function($file_data$jscomp$31$$){return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51705_SHARP_$$){return $app$common$types$container$make_container$$($p1__51705_SHARP_$$,$APP.$cljs$cst$1624$page$$)},$APP.$cljs$core$seq$$($APP.$cljs$core$vals$$($APP.$cljs$cst$1630$pages_index$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$31$$)))),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51706_SHARP_$$){return $app$common$types$container$make_container$$($p1__51706_SHARP_$$,
$APP.$cljs$cst$1625$component$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2541$deleted$$,$APP.$cljs$core$vals$$($APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$31$$)))))};
$app$common$types$file$find_component_file$$=function($file$jscomp$20$$,$libraries$jscomp$6$$,$component_file$jscomp$1$$){return $file$jscomp$20$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($component_file$jscomp$1$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$20$$))?$file$jscomp$20$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$6$$,$component_file$jscomp$1$$)};
$APP.$app$common$types$file$get_component$$=function($var_args$jscomp$1084$$){for(var $args__5755__auto__$jscomp$190$$=[],$len__5749__auto___52243$$=arguments.length,$i__5750__auto___52244$$=0;;)if($i__5750__auto___52244$$<$len__5749__auto___52243$$)$args__5755__auto__$jscomp$190$$.push(arguments[$i__5750__auto___52244$$]),$i__5750__auto___52244$$+=1;else break;return $app$common$types$file$get_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],arguments[2],3<$args__5755__auto__$jscomp$190$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$190$$.slice(3),0,null):null)};
$app$common$types$file$get_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($libraries$jscomp$7$$,$library_id$jscomp$9$$,$component_id$jscomp$10$$,$include_deleted_QMARK_$jscomp$2_map__51736__$1_p__51735$$){$include_deleted_QMARK_$jscomp$2_map__51736__$1_p__51735$$=$APP.$cljs$core$__destructure_map$$($include_deleted_QMARK_$jscomp$2_map__51736__$1_p__51735$$);$include_deleted_QMARK_$jscomp$2_map__51736__$1_p__51735$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($include_deleted_QMARK_$jscomp$2_map__51736__$1_p__51735$$,
$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!1);return $app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$7$$,$library_id$jscomp$9$$),$APP.$cljs$cst$142$data$$),$component_id$jscomp$10$$,$include_deleted_QMARK_$jscomp$2_map__51736__$1_p__51735$$)};
$APP.$app$common$types$file$resolve_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($shape$jscomp$257$$,$file$jscomp$21$$,$libraries$jscomp$8$$,$include_deleted_QMARK_$jscomp$3_map__51749__$1_p__51748$$){$include_deleted_QMARK_$jscomp$3_map__51749__$1_p__51748$$=$APP.$cljs$core$__destructure_map$$($include_deleted_QMARK_$jscomp$3_map__51749__$1_p__51748$$);$include_deleted_QMARK_$jscomp$3_map__51749__$1_p__51748$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($include_deleted_QMARK_$jscomp$3_map__51749__$1_p__51748$$,
$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!1);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$257$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$21$$))?$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$21$$),$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$257$$),
$include_deleted_QMARK_$jscomp$3_map__51749__$1_p__51748$$):$app$common$types$file$get_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($libraries$jscomp$8$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$257$$),$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$257$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2540$include_deleted_QMARK_$$,$include_deleted_QMARK_$jscomp$3_map__51749__$1_p__51748$$]))};
$APP.$app$common$types$file$get_component_page$$=function($file_data$jscomp$37$$,$component$jscomp$20$$){return $APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$37$$,$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$20$$))};
$APP.$app$common$types$file$get_component_container$$=function($component_page$jscomp$1_file_data$jscomp$38$$,$component$jscomp$21$$){return $APP.$cljs$core$not$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$21$$))?($component_page$jscomp$1_file_data$jscomp$38$$=$APP.$app$common$types$file$get_component_page$$($component_page$jscomp$1_file_data$jscomp$38$$,$component$jscomp$21$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($component_page$jscomp$1_file_data$jscomp$38$$,
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1624$page$$)):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($component$jscomp$21$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1625$component$$)};
$app$common$types$file$get_component_container_from_head$$=function($var_args$jscomp$1086$$){for(var $args__5755__auto__$jscomp$192_include_deleted_QMARK_$jscomp$inline_5667_map__51767__$1$jscomp$inline_5666$$=[],$component$jscomp$inline_5669_instance_head$jscomp$inline_5663_len__5749__auto___52264$$=arguments.length,$i__5750__auto___52265_libraries$jscomp$inline_5664_library_data$jscomp$inline_5668$$=0;;)if($i__5750__auto___52265_libraries$jscomp$inline_5664_library_data$jscomp$inline_5668$$<$component$jscomp$inline_5669_instance_head$jscomp$inline_5663_len__5749__auto___52264$$)$args__5755__auto__$jscomp$192_include_deleted_QMARK_$jscomp$inline_5667_map__51767__$1$jscomp$inline_5666$$.push(arguments[$i__5750__auto___52265_libraries$jscomp$inline_5664_library_data$jscomp$inline_5668$$]),
$i__5750__auto___52265_libraries$jscomp$inline_5664_library_data$jscomp$inline_5668$$+=1;else break;$component$jscomp$inline_5669_instance_head$jscomp$inline_5663_len__5749__auto___52264$$=arguments[0];$i__5750__auto___52265_libraries$jscomp$inline_5664_library_data$jscomp$inline_5668$$=arguments[1];$args__5755__auto__$jscomp$192_include_deleted_QMARK_$jscomp$inline_5667_map__51767__$1$jscomp$inline_5666$$=$APP.$cljs$core$__destructure_map$$(2<$args__5755__auto__$jscomp$192_include_deleted_QMARK_$jscomp$inline_5667_map__51767__$1$jscomp$inline_5666$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$192_include_deleted_QMARK_$jscomp$inline_5667_map__51767__$1$jscomp$inline_5666$$.slice(2),0,null):null);$args__5755__auto__$jscomp$192_include_deleted_QMARK_$jscomp$inline_5667_map__51767__$1$jscomp$inline_5666$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($args__5755__auto__$jscomp$192_include_deleted_QMARK_$jscomp$inline_5667_map__51767__$1$jscomp$inline_5666$$,$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0);$i__5750__auto___52265_libraries$jscomp$inline_5664_library_data$jscomp$inline_5668$$=
$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($i__5750__auto___52265_libraries$jscomp$inline_5664_library_data$jscomp$inline_5668$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_5669_instance_head$jscomp$inline_5663_len__5749__auto___52264$$)));$component$jscomp$inline_5669_instance_head$jscomp$inline_5663_len__5749__auto___52264$$=$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($i__5750__auto___52265_libraries$jscomp$inline_5664_library_data$jscomp$inline_5668$$,
$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_5669_instance_head$jscomp$inline_5663_len__5749__auto___52264$$),$args__5755__auto__$jscomp$192_include_deleted_QMARK_$jscomp$inline_5667_map__51767__$1$jscomp$inline_5666$$);return $APP.$app$common$types$file$get_component_container$$($i__5750__auto___52265_libraries$jscomp$inline_5664_library_data$jscomp$inline_5668$$,$component$jscomp$inline_5669_instance_head$jscomp$inline_5663_len__5749__auto___52264$$)};
$APP.$app$common$types$file$get_component_root$$=function($file_data$jscomp$39$$,$component$jscomp$23$$){return $APP.$cljs$core$not$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$23$$))?$APP.$app$common$types$container$get_shape$$($APP.$app$common$types$file$get_component_page$$($file_data$jscomp$39$$,$component$jscomp$23$$),$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$23$$)):$APP.$app$common$types$component$get_deleted_component_root$$($component$jscomp$23$$)};
$APP.$app$common$types$file$get_ref_shape$$=function($var_args$jscomp$1088$$){for(var $args__5755__auto__$jscomp$194$$=[],$len__5749__auto___52281$$=arguments.length,$i__5750__auto___52282$$=0;;)if($i__5750__auto___52282$$<$len__5749__auto___52281$$)$args__5755__auto__$jscomp$194$$.push(arguments[$i__5750__auto___52282$$]),$i__5750__auto___52282$$+=1;else break;return $app$common$types$file$get_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],arguments[2],3<$args__5755__auto__$jscomp$194$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$194$$.slice(3),0,null):null)};
$app$common$types$file$get_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($JSCompiler_temp$jscomp$10786_file_data$jscomp$41$$,$child$jscomp$inline_12067_component$jscomp$25$$,$shape$jscomp$259_shape$jscomp$inline_12068_shape_id$jscomp$inline_12062$$,$map__51786__$1$jscomp$inline_12064_map__51798__$1_p__51797_with_context_QMARK_$jscomp$1_with_context_QMARK_$jscomp$inline_12065$$){$map__51786__$1$jscomp$inline_12064_map__51798__$1_p__51797_with_context_QMARK_$jscomp$1_with_context_QMARK_$jscomp$inline_12065$$=$APP.$cljs$core$__destructure_map$$($map__51786__$1$jscomp$inline_12064_map__51798__$1_p__51797_with_context_QMARK_$jscomp$1_with_context_QMARK_$jscomp$inline_12065$$);
$map__51786__$1$jscomp$inline_12064_map__51798__$1_p__51797_with_context_QMARK_$jscomp$1_with_context_QMARK_$jscomp$inline_12065$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51786__$1$jscomp$inline_12064_map__51798__$1_p__51797_with_context_QMARK_$jscomp$1_with_context_QMARK_$jscomp$inline_12065$$,$cljs$cst$2591$with_context_QMARK_$$,!1);if($APP.$cljs$core$truth_$$($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$259_shape$jscomp$inline_12068_shape_id$jscomp$inline_12062$$)))if($shape$jscomp$259_shape$jscomp$inline_12068_shape_id$jscomp$inline_12062$$=
$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$259_shape$jscomp$inline_12068_shape_id$jscomp$inline_12062$$),$map__51786__$1$jscomp$inline_12064_map__51798__$1_p__51797_with_context_QMARK_$jscomp$1_with_context_QMARK_$jscomp$inline_12065$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$2591$with_context_QMARK_$$,$map__51786__$1$jscomp$inline_12064_map__51798__$1_p__51797_with_context_QMARK_$jscomp$1_with_context_QMARK_$jscomp$inline_12065$$])),
$map__51786__$1$jscomp$inline_12064_map__51798__$1_p__51797_with_context_QMARK_$jscomp$1_with_context_QMARK_$jscomp$inline_12065$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51786__$1$jscomp$inline_12064_map__51798__$1_p__51797_with_context_QMARK_$jscomp$1_with_context_QMARK_$jscomp$inline_12065$$,$cljs$cst$2591$with_context_QMARK_$$,!1),$APP.$cljs$core$not$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$inline_12067_component$jscomp$25$$))){var $component_page$jscomp$inline_12066$$=
$APP.$app$common$types$file$get_component_page$$($JSCompiler_temp$jscomp$10786_file_data$jscomp$41$$,$child$jscomp$inline_12067_component$jscomp$25$$);$APP.$cljs$core$truth_$$($component_page$jscomp$inline_12066$$)?($child$jscomp$inline_12067_component$jscomp$25$$=$app$common$files$helpers$get_child$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component_page$jscomp$inline_12066$$),$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$inline_12067_component$jscomp$25$$),
$shape$jscomp$259_shape$jscomp$inline_12068_shape_id$jscomp$inline_12062$$),$JSCompiler_temp$jscomp$10786_file_data$jscomp$41$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($child$jscomp$inline_12067_component$jscomp$25$$)?$map__51786__$1$jscomp$inline_12064_map__51798__$1_p__51797_with_context_QMARK_$jscomp$1_with_context_QMARK_$jscomp$inline_12065$$:$child$jscomp$inline_12067_component$jscomp$25$$)?$APP.$cljs$core$with_meta$$($child$jscomp$inline_12067_component$jscomp$25$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$208$file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10786_file_data$jscomp$41$$),$APP.$cljs$cst$142$data$$,$JSCompiler_temp$jscomp$10786_file_data$jscomp$41$$],null),$APP.$cljs$cst$2588$container$$,$app$common$types$container$make_container$$($component_page$jscomp$inline_12066$$,$APP.$cljs$cst$1624$page$$)],null)):$child$jscomp$inline_12067_component$jscomp$25$$):$JSCompiler_temp$jscomp$10786_file_data$jscomp$41$$=
null}else $shape$jscomp$259_shape$jscomp$inline_12068_shape_id$jscomp$inline_12062$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($child$jscomp$inline_12067_component$jscomp$25$$,$APP.$cljs$cst$1631$objects$$),$shape$jscomp$259_shape$jscomp$inline_12068_shape_id$jscomp$inline_12062$$),$JSCompiler_temp$jscomp$10786_file_data$jscomp$41$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($shape$jscomp$259_shape$jscomp$inline_12068_shape_id$jscomp$inline_12062$$)?
$map__51786__$1$jscomp$inline_12064_map__51798__$1_p__51797_with_context_QMARK_$jscomp$1_with_context_QMARK_$jscomp$inline_12065$$:$shape$jscomp$259_shape$jscomp$inline_12068_shape_id$jscomp$inline_12062$$)?$APP.$cljs$core$with_meta$$($shape$jscomp$259_shape$jscomp$inline_12068_shape_id$jscomp$inline_12062$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$208$file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10786_file_data$jscomp$41$$),
$APP.$cljs$cst$142$data$$,$JSCompiler_temp$jscomp$10786_file_data$jscomp$41$$],null),$APP.$cljs$cst$2588$container$$,$app$common$types$container$make_container$$($child$jscomp$inline_12067_component$jscomp$25$$,$APP.$cljs$cst$1625$component$$)],null)):$shape$jscomp$259_shape$jscomp$inline_12068_shape_id$jscomp$inline_12062$$;else $JSCompiler_temp$jscomp$10786_file_data$jscomp$41$$=null;return $JSCompiler_temp$jscomp$10786_file_data$jscomp$41$$};
$app$common$types$file$find_ref_shape$$=function($var_args$jscomp$1089$$){for(var $args__5755__auto__$jscomp$195$$=[],$len__5749__auto___52292$$=arguments.length,$i__5750__auto___52293$$=0;;)if($i__5750__auto___52293$$<$len__5749__auto___52292$$)$args__5755__auto__$jscomp$195$$.push(arguments[$i__5750__auto___52293$$]),$i__5750__auto___52293$$+=1;else break;return $app$common$types$file$find_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],arguments[2],arguments[3],
4<$args__5755__auto__$jscomp$195$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$195$$.slice(4),0,null):null)};
$app$common$types$file$find_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($file$jscomp$22$$,$container$jscomp$19$$,$libraries$jscomp$11$$,$shape$jscomp$260$$,$map__51812__$1_p__51811$$){$map__51812__$1_p__51811$$=$APP.$cljs$core$__destructure_map$$($map__51812__$1_p__51811$$);var $include_deleted_QMARK_$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51812__$1_p__51811$$,$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!1),$with_context_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51812__$1_p__51811$$,
$cljs$cst$2591$with_context_QMARK_$$,!1);return $APP.$cljs$core$some$$(function($component$jscomp$26_head_shape$$){var $component_file$jscomp$2$$=$app$common$types$file$find_component_file$$($file$jscomp$22$$,$libraries$jscomp$11$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$26_head_shape$$));$component$jscomp$26_head_shape$$=$component_file$jscomp$2$$!=null?$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($component_file$jscomp$2$$),
$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$26_head_shape$$),$include_deleted_QMARK_$jscomp$5$$):null;return $component$jscomp$26_head_shape$$!=null?$app$common$types$file$get_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($component_file$jscomp$2$$),$component$jscomp$26_head_shape$$,$shape$jscomp$260$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$2591$with_context_QMARK_$$,
$with_context_QMARK_$jscomp$2$$])):null},$app$common$types$container$get_parent_heads$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$19$$),$shape$jscomp$260$$))};
$app$common$types$file$advance_shape_ref$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($file$jscomp$24$$,$container$jscomp$21_ref_shape$$,$libraries$jscomp$13$$,$shape$jscomp$262$$,$levels$jscomp$2$$,$include_deleted_QMARK_$jscomp$7_map__51828__$1_p__51827$$){$include_deleted_QMARK_$jscomp$7_map__51828__$1_p__51827$$=$APP.$cljs$core$__destructure_map$$($include_deleted_QMARK_$jscomp$7_map__51828__$1_p__51827$$);$include_deleted_QMARK_$jscomp$7_map__51828__$1_p__51827$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($include_deleted_QMARK_$jscomp$7_map__51828__$1_p__51827$$,
$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!1);$container$jscomp$21_ref_shape$$=$app$common$types$file$find_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($file$jscomp$24$$,$container$jscomp$21_ref_shape$$,$libraries$jscomp$13$$,$shape$jscomp$262$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2540$include_deleted_QMARK_$$,$include_deleted_QMARK_$jscomp$7_map__51828__$1_p__51827$$,$cljs$cst$2591$with_context_QMARK_$$,!0]));return $APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$21_ref_shape$$)!=
null&&$levels$jscomp$2$$>0?$app$common$types$file$advance_shape_ref$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($file$jscomp$24$$,$APP.$cljs$cst$2588$container$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($container$jscomp$21_ref_shape$$)),$libraries$jscomp$13$$,$container$jscomp$21_ref_shape$$,$levels$jscomp$2$$-1,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2540$include_deleted_QMARK_$$,$include_deleted_QMARK_$jscomp$7_map__51828__$1_p__51827$$])):$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$21_ref_shape$$)};
$app$common$types$file$find_ref_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($page$jscomp$8$$,$libraries$jscomp$14$$,$shape$jscomp$263$$){var $map__51835__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0])),$include_deleted_QMARK_$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51835__$1$$,$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!1);return $APP.$cljs$core$some$$(function($component$jscomp$27_head_shape$jscomp$1$$){var $component_file$jscomp$3$$=
$app$common$types$file$find_component_file$$(null,$libraries$jscomp$14$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$27_head_shape$jscomp$1$$));$component$jscomp$27_head_shape$jscomp$1$$=$component_file$jscomp$3$$!=null?$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($component_file$jscomp$3$$),$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$27_head_shape$jscomp$1$$),
$include_deleted_QMARK_$jscomp$8$$):null;return $component$jscomp$27_head_shape$jscomp$1$$!=null?$APP.$cljs$core$truth_$$($APP.$app$common$types$file$get_ref_shape$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($component_file$jscomp$3$$),$component$jscomp$27_head_shape$jscomp$1$$,$shape$jscomp$263$$))?$component$jscomp$27_head_shape$jscomp$1$$:null:null},$app$common$types$container$get_parent_copy_heads$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$8$$),
$shape$jscomp$263$$))};
$APP.$app$common$types$file$find_remote_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($component_container__$1_component_file__$1$jscomp$inline_12073_container$jscomp$22$$,$libraries$jscomp$15$$,$JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$,$map__51846__$1_p__51845_with_context_QMARK_$jscomp$4$$){$map__51846__$1_p__51845_with_context_QMARK_$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($map__51846__$1_p__51845_with_context_QMARK_$jscomp$4$$);$map__51846__$1_p__51845_with_context_QMARK_$jscomp$4$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51846__$1_p__51845_with_context_QMARK_$jscomp$4$$,$cljs$cst$2591$with_context_QMARK_$$,!1);var $remote_shape_top_instance$$=$APP.$app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component_container__$1_component_file__$1$jscomp$inline_12073_container$jscomp$22$$),$JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$),
$component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$15$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($remote_shape_top_instance$$),$APP.$cljs$cst$142$data$$],null)),$component$jscomp$28_component_container$$=
$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($remote_shape_top_instance$$),!0);$remote_shape_top_instance$$=$APP.$app$common$types$file$get_ref_shape$$($component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$,
$component$jscomp$28_component_container$$,$JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$);$component$jscomp$28_component_container$$=$APP.$app$common$types$file$get_component_container$$($component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$,$component$jscomp$28_component_container$$);$remote_shape_top_instance$$!=
null?$JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$remote_shape_top_instance$$,$component$jscomp$28_component_container$$,$component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$],null):($component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$=
$APP.$app$common$types$container$get_head_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component_container__$1_component_file__$1$jscomp$inline_12073_container$jscomp$22$$),$JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$),$component_container__$1_component_file__$1$jscomp$inline_12073_container$jscomp$22$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$15$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$),$APP.$cljs$cst$142$data$$],null)),$component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$=
$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($component_container__$1_component_file__$1$jscomp$inline_12073_container$jscomp$22$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$),!0),$JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$=
$APP.$app$common$types$file$get_ref_shape$$($component_container__$1_component_file__$1$jscomp$inline_12073_container$jscomp$22$$,$component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$,$JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$),$component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$=
$APP.$app$common$types$file$get_component_container$$($component_container__$1_component_file__$1$jscomp$inline_12073_container$jscomp$22$$,$component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$),$JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$,$component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$,$component_container__$1_component_file__$1$jscomp$inline_12073_container$jscomp$22$$],null));$component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$=
$JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$;$JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$,0,null);$component_container__$1_component_file__$1$jscomp$inline_12073_container$jscomp$22$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$,1,null);$component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$,
2,null);return $JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$==null?null:$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$)==null?$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$)?$map__51846__$1_p__51845_with_context_QMARK_$jscomp$4$$:
$JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$)?$APP.$cljs$core$with_meta$$($JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$208$file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$),
$APP.$cljs$cst$142$data$$,$component_container_SINGLEQUOTE_$jscomp$inline_12076_component_file$jscomp$4_component_file__$1_head_component$jscomp$inline_12074_head_instance$jscomp$inline_12072_vec__51847$$],null),$APP.$cljs$cst$2588$container$$,$component_container__$1_component_file__$1$jscomp$inline_12073_container$jscomp$22$$],null)):$JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$:$APP.$app$common$types$file$find_remote_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($component_container__$1_component_file__$1$jscomp$inline_12073_container$jscomp$22$$,
$libraries$jscomp$15$$,$JSCompiler_temp$jscomp$10788_remote_shape_SINGLEQUOTE_$jscomp$inline_12075_remote_shape__$1_shape$jscomp$264$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$2591$with_context_QMARK_$$,$map__51846__$1_p__51845_with_context_QMARK_$jscomp$4$$]))};
$app$common$types$file$find_swap_slot$cljs$0core$0IFn$0_invoke$0arity$05$$=function($shape$jscomp$267$$,$container$jscomp$24_ref_shape$jscomp$1$$,$file$jscomp$28_ref_file$jscomp$6$$,$libraries$jscomp$18$$,$viewed_ids$$){if($APP.$cljs$core$contains_QMARK_$$($viewed_ids$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$267$$)))return null;var $ref_container$jscomp$1_shape_meta_temp__5823__auto__$jscomp$146$$=$APP.$app$common$types$component$get_swap_slot$$($shape$jscomp$267$$);
if($APP.$cljs$core$truth_$$($ref_container$jscomp$1_shape_meta_temp__5823__auto__$jscomp$146$$))return $ref_container$jscomp$1_shape_meta_temp__5823__auto__$jscomp$146$$;$container$jscomp$24_ref_shape$jscomp$1$$=$app$common$types$file$find_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($file$jscomp$28_ref_file$jscomp$6$$,$container$jscomp$24_ref_shape$jscomp$1$$,$libraries$jscomp$18$$,$shape$jscomp$267$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2540$include_deleted_QMARK_$$,
!0,$cljs$cst$2591$with_context_QMARK_$$,!0]));$ref_container$jscomp$1_shape_meta_temp__5823__auto__$jscomp$146$$=$APP.$cljs$core$meta$$($container$jscomp$24_ref_shape$jscomp$1$$);$file$jscomp$28_ref_file$jscomp$6$$=$APP.$cljs$cst$208$file$$.$cljs$core$IFn$_invoke$arity$1$($ref_container$jscomp$1_shape_meta_temp__5823__auto__$jscomp$146$$);$ref_container$jscomp$1_shape_meta_temp__5823__auto__$jscomp$146$$=$APP.$cljs$cst$2588$container$$.$cljs$core$IFn$_invoke$arity$1$($ref_container$jscomp$1_shape_meta_temp__5823__auto__$jscomp$146$$);
if($APP.$cljs$core$truth_$$($container$jscomp$24_ref_shape$jscomp$1$$)){var $temp__5823__auto____$1$jscomp$10$$=$APP.$app$common$types$component$get_swap_slot$$($container$jscomp$24_ref_shape$jscomp$1$$);return $APP.$cljs$core$truth_$$($temp__5823__auto____$1$jscomp$10$$)?$temp__5823__auto____$1$jscomp$10$$:$APP.$app$common$types$component$main_instance_QMARK_$$($container$jscomp$24_ref_shape$jscomp$1$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$267$$):$app$common$types$file$find_swap_slot$cljs$0core$0IFn$0_invoke$0arity$05$$($container$jscomp$24_ref_shape$jscomp$1$$,
$ref_container$jscomp$1_shape_meta_temp__5823__auto__$jscomp$146$$,$file$jscomp$28_ref_file$jscomp$6$$,$libraries$jscomp$18$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($viewed_ids$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$267$$)))}return null};
$app$common$types$file$match_swap_slot_QMARK_$$=function($shape_main$jscomp$2$$,$shape_inst$jscomp$2_slot_inst$jscomp$1$$,$container_inst$$,$container_main_slot_main$jscomp$1$$,$file$jscomp$29$$,$libraries$jscomp$19$$){$container_main_slot_main$jscomp$1$$=$app$common$types$file$find_swap_slot$cljs$0core$0IFn$0_invoke$0arity$05$$($shape_main$jscomp$2$$,$container_main_slot_main$jscomp$1$$,$file$jscomp$29$$,$libraries$jscomp$19$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);$shape_inst$jscomp$2_slot_inst$jscomp$1$$=
$app$common$types$file$find_swap_slot$cljs$0core$0IFn$0_invoke$0arity$05$$($shape_inst$jscomp$2_slot_inst$jscomp$1$$,$container_inst$$,$file$jscomp$29$$,$libraries$jscomp$19$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $shape_inst$jscomp$2_slot_inst$jscomp$1$$!=null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($container_main_slot_main$jscomp$1$$,$shape_inst$jscomp$2_slot_inst$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_main$jscomp$2$$),
$shape_inst$jscomp$2_slot_inst$jscomp$1$$):null};
$app$common$types$file$get_component_shapes$$=function($file_data$jscomp$43_instance_page$$,$component$jscomp$30$$){return $APP.$cljs$core$not$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$30$$))?($file_data$jscomp$43_instance_page$$=$APP.$app$common$types$file$get_component_page$$($file_data$jscomp$43_instance_page$$,$component$jscomp$30$$),$APP.$app$common$files$helpers$get_children_with_self$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$43_instance_page$$),$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$30$$))):
$APP.$cljs$core$vals$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$30$$))};
$app$common$types$file$is_main_of_known_component_QMARK_$$=function($file_id$jscomp$27_shape$jscomp$269$$,$component$jscomp$31_libraries$jscomp$22$$){var $main_instance_QMARK_$jscomp$1$$=$APP.$app$common$types$component$main_instance_QMARK_$$($file_id$jscomp$27_shape$jscomp$269$$),$component_id$jscomp$11$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$27_shape$jscomp$269$$);$file_id$jscomp$27_shape$jscomp$269$$=$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$27_shape$jscomp$269$$);
$component$jscomp$31_libraries$jscomp$22$$=$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$31_libraries$jscomp$22$$,$file_id$jscomp$27_shape$jscomp$269$$),$APP.$cljs$cst$142$data$$),$component_id$jscomp$11$$,!0);return $main_instance_QMARK_$jscomp$1$$?$component$jscomp$31_libraries$jscomp$22$$:$main_instance_QMARK_$jscomp$1$$};
$app$common$types$file$delete_component$$=function($file_data$jscomp$46$$,$component_id$jscomp$12$$,$skip_undelete_QMARK_$$,$delta$jscomp$13$$){var $delta__$1$$=$APP.$cljs$core$truth_$$($delta$jscomp$13$$)?$delta$jscomp$13$$:$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0);return $APP.$cljs$core$truth_$$($skip_undelete_QMARK_$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($file_data$jscomp$46$$,$APP.$cljs$cst$1638$components$$,$APP.$cljs$core$dissoc$$,$component_id$jscomp$12$$):
$app$common$types$components_list$mark_component_deleted$$($app$common$types$components_list$update_component$$($file_data$jscomp$46$$,$component_id$jscomp$12$$,function($p1__51904_SHARP_$$){return $APP.$app$common$types$file$load_component_objects$$.$cljs$core$IFn$_invoke$arity$3$($file_data$jscomp$46$$,$p1__51904_SHARP_$$,$delta__$1$$)}),$component_id$jscomp$12$$)};
$app$common$types$file$restore_component$$=function($G__51915__$1_file_data$jscomp$47$$,$component_id$jscomp$13$$,$page_id$jscomp$25$$){var $G__51915__$2_update_page_QMARK_$$=$page_id$jscomp$25$$!=null,$component$jscomp$34$$=$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($G__51915__$1_file_data$jscomp$47$$,$component_id$jscomp$13$$,!0),$main_instance_page$jscomp$2$$=$APP.$cljs$core$truth_$$($page_id$jscomp$25$$)?$page_id$jscomp$25$$:$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$34$$),
$main_instance$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__51915__$1_file_data$jscomp$47$$,$APP.$cljs$cst$1630$pages_index$$),$main_instance_page$jscomp$2$$),$APP.$cljs$cst$1631$objects$$),$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$34$$));$G__51915__$1_file_data$jscomp$47$$=$app$common$types$components_list$mark_component_undeleted$$($app$common$types$components_list$update_component$$($G__51915__$1_file_data$jscomp$47$$,
$component_id$jscomp$13$$,function($p1__51907_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__51907_SHARP_$$,$APP.$cljs$cst$1631$objects$$)}),$component_id$jscomp$13$$);$G__51915__$2_update_page_QMARK_$$=$G__51915__$2_update_page_QMARK_$$?$app$common$types$components_list$update_component$$($G__51915__$1_file_data$jscomp$47$$,$component_id$jscomp$13$$,function($p1__51908_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__51908_SHARP_$$,$APP.$cljs$cst$2063$main_instance_page$$,
$page_id$jscomp$25$$)}):$G__51915__$1_file_data$jscomp$47$$;return $APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$34$$)?$app$common$types$components_list$update_component$$($G__51915__$2_update_page_QMARK_$$,$component_id$jscomp$13$$,function($p1__51909_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__51909_SHARP_$$,$APP.$cljs$cst$2000$variant_id$$,$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($main_instance$$))}):$G__51915__$2_update_page_QMARK_$$};
$app$common$types$file$used_assets_changed_since$$=function($file_data$jscomp$51$$,$library$jscomp$5$$,$since_date$jscomp$3$$){function $used_assets_shape$$($shape$jscomp$274$$){var $JSCompiler_temp_const$jscomp$899$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$;if($app$common$types$component$uses_library_components_QMARK_$$($shape$jscomp$274$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$5$$))){var $JSCompiler_inline_result$jscomp$901_component$jscomp$inline_5674$$=
$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$5$$),$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$274$$));$JSCompiler_inline_result$jscomp$901_component$jscomp$inline_5674$$=$APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$901_component$jscomp$inline_5674$$)<$since_date$jscomp$3$$?$APP.$cljs$core$PersistentVector$EMPTY$$:
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$274$$),$APP.$cljs$cst$2544$asset_id$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$274$$),$APP.$cljs$cst$2545$asset_type$$,$APP.$cljs$cst$1625$component$$],null)],null)}else $JSCompiler_inline_result$jscomp$901_component$jscomp$inline_5674$$=
$APP.$cljs$core$PersistentVector$EMPTY$$;return $JSCompiler_temp_const$jscomp$899$$.call($APP.$cljs$core$concat$$,$JSCompiler_inline_result$jscomp$901_component$jscomp$inline_5674$$,$app$common$types$library$used_colors_changed_since$$($shape$jscomp$274$$,$library$jscomp$5$$,$since_date$jscomp$3$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$types$typographies_list$used_typographies_changed_since$$($shape$jscomp$274$$,$library$jscomp$5$$,$since_date$jscomp$3$$)]))}return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($container$jscomp$29$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51961_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__51961_SHARP_$$,
$cljs$cst$2592$container_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$29$$))},$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($used_assets_shape$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vals$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$29$$))])))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$types$file$containers_seq$$($file_data$jscomp$51$$)]))};
$app$common$types$file$dump_shape_component_info$$=function($shape$jscomp$281$$,$objects$jscomp$213$$,$file$jscomp$31$$,$libraries$jscomp$24$$,$component_file$jscomp$5_component_file_id_map__52066__$1_p__52065_root_shape$$){$component_file$jscomp$5_component_file_id_map__52066__$1_p__52065_root_shape$$=$APP.$cljs$core$__destructure_map$$($component_file$jscomp$5_component_file_id_map__52066__$1_p__52065_root_shape$$);var $show_ids$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component_file$jscomp$5_component_file_id_map__52066__$1_p__52065_root_shape$$,
$cljs$cst$2593$show_ids$$);if($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$281$$)==null)return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$281$$))?[" #",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($show_ids$jscomp$1$$)?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$(" [Component %s]",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$281$$)])):
null)].join(""):"";$component_file$jscomp$5_component_file_id_map__52066__$1_p__52065_root_shape$$=$APP.$app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$213$$,$shape$jscomp$281$$);$component_file$jscomp$5_component_file_id_map__52066__$1_p__52065_root_shape$$=$APP.$cljs$core$truth_$$($component_file$jscomp$5_component_file_id_map__52066__$1_p__52065_root_shape$$)?$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($component_file$jscomp$5_component_file_id_map__52066__$1_p__52065_root_shape$$):
null;$component_file$jscomp$5_component_file_id_map__52066__$1_p__52065_root_shape$$=$APP.$cljs$core$truth_$$($component_file$jscomp$5_component_file_id_map__52066__$1_p__52065_root_shape$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($libraries$jscomp$24$$,$component_file$jscomp$5_component_file_id_map__52066__$1_p__52065_root_shape$$,null):null;var $component_shape$jscomp$1$$=$app$common$types$file$find_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($file$jscomp$31$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1631$objects$$,$objects$jscomp$213$$],null),$libraries$jscomp$24$$,$shape$jscomp$281$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0]));return $APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$(" %s--\x3e %s%s%s%s%s",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$281$$))?"#":$APP.$cljs$core$truth_$$($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$281$$))?
"@":"-",$APP.$cljs$core$truth_$$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$281$$))?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("\x3c%s\x3e ",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($component_file$jscomp$5_component_file_id_map__52066__$1_p__52065_root_shape$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_file$jscomp$5_component_file_id_map__52066__$1_p__52065_root_shape$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$31$$))?"local":$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component_file$jscomp$5_component_file_id_map__52066__$1_p__52065_root_shape$$):$APP.$cljs$core$truth_$$($show_ids$jscomp$1$$)?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("¿%s?",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$281$$)])):"?"])):
null,function(){var $or__5025__auto__$jscomp$483$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$jscomp$1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$483$$)?$or__5025__auto__$jscomp$483$$:$APP.$cljs$core$truth_$$($show_ids$jscomp$1$$)?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("¿%s?",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$281$$)])):
"?"}(),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($show_ids$jscomp$1$$)?$component_shape$jscomp$1$$:$show_ids$jscomp$1$$)?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$(" %s",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$jscomp$1$$)])):null,$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$484$$=$APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$281$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$484$$)?$or__5025__auto__$jscomp$484$$:$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$281$$)==null||!0}())?"":function(){var $component$jscomp$37_component_id$jscomp$15$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$281$$),$component_file__$1$jscomp$2_component_file_id__$1$$=$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$281$$);$component_file__$1$jscomp$2_component_file_id__$1$$=
$APP.$cljs$core$truth_$$($component_file__$1$jscomp$2_component_file_id__$1$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($libraries$jscomp$24$$,$component_file__$1$jscomp$2_component_file_id__$1$$,null):null;$component$jscomp$37_component_id$jscomp$15$$=$APP.$cljs$core$truth_$$($component_file__$1$jscomp$2_component_file_id__$1$$)?$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($component_file__$1$jscomp$2_component_file_id__$1$$),
$component$jscomp$37_component_id$jscomp$15$$,!0):$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$31$$),$component$jscomp$37_component_id$jscomp$15$$,!0);return $APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$(" (%s%s)",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($component_file__$1$jscomp$2_component_file_id__$1$$)?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("\x3c%s\x3e ",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_file__$1$jscomp$2_component_file_id__$1$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$31$$))?"local":$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component_file__$1$jscomp$2_component_file_id__$1$$)])):null,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$37_component_id$jscomp$15$$)]))}(),
$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($show_ids$jscomp$1$$)?$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$281$$):$show_ids$jscomp$1$$)?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$(" [Component %s]",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$281$$)])):null]))};
$app$common$types$file$dump_component$$=function($component$jscomp$38$$,$file$jscomp$32$$,$libraries$jscomp$25$$,$map__52071__$1_p__52070$$){$map__52071__$1_p__52070$$=$APP.$cljs$core$__destructure_map$$($map__52071__$1_p__52070$$);var $JSCompiler_inline_result$jscomp$913_and__5023__auto__$jscomp$inline_5679_root$jscomp$37_show_ids$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52071__$1_p__52070$$,$cljs$cst$2593$show_ids$$),$page_52437_show_modified$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52071__$1_p__52070$$,
$cljs$cst$2595$show_modified$$);$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("[%sComponent: %s]%s%s",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$38$$))?"DELETED ":null,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$38$$),
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$913_and__5023__auto__$jscomp$inline_5679_root$jscomp$37_show_ids$jscomp$2$$)?[" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$38$$))].join(""):null,$APP.$cljs$core$truth_$$($page_52437_show_modified$$)?[" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$38$$))].join(""):
null]))]));if($APP.$cljs$core$truth_$$($APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$38$$))){$page_52437_show_modified$$=$APP.$app$common$types$file$get_component_page$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$32$$),$component$jscomp$38$$);var $root_52438$$=$APP.$app$common$types$file$get_component_root$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$32$$),$component$jscomp$38$$);$APP.$cljs$core$not$$($JSCompiler_inline_result$jscomp$913_and__5023__auto__$jscomp$inline_5679_root$jscomp$37_show_ids$jscomp$2$$)?
$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([["  --\x3e [",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($page_52437_show_modified$$)),"] ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($root_52438$$))].join("")])):($APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([["  ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($page_52437_show_modified$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$(" %s",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page_52437_show_modified$$)])))].join("")])),$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([["  ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($root_52438$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$(" %s",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root_52438$$)])))].join("")])))}$JSCompiler_inline_result$jscomp$913_and__5023__auto__$jscomp$inline_5679_root$jscomp$37_show_ids$jscomp$2$$=
$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$38$$);$JSCompiler_inline_result$jscomp$913_and__5023__auto__$jscomp$inline_5679_root$jscomp$37_show_ids$jscomp$2$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$913_and__5023__auto__$jscomp$inline_5679_root$jscomp$37_show_ids$jscomp$2$$)?$APP.$cljs$core$seq$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$38$$)):$JSCompiler_inline_result$jscomp$913_and__5023__auto__$jscomp$inline_5679_root$jscomp$37_show_ids$jscomp$2$$;
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$913_and__5023__auto__$jscomp$inline_5679_root$jscomp$37_show_ids$jscomp$2$$)&&$APP.$cljs$core$println$$();return $APP.$cljs$core$seq$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$38$$))?($JSCompiler_inline_result$jscomp$913_and__5023__auto__$jscomp$inline_5679_root$jscomp$37_show_ids$jscomp$2$$=$APP.$app$common$types$component$get_deleted_component_root$$($component$jscomp$38$$),$app$common$types$file$dump_shape$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$913_and__5023__auto__$jscomp$inline_5679_root$jscomp$37_show_ids$jscomp$2$$),
1,$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$38$$),$file$jscomp$32$$,$libraries$jscomp$25$$,$map__52071__$1_p__52070$$)):null};
$app$common$types$file$dump_page$$=function($page$jscomp$11$$,$file$jscomp$33$$,$libraries$jscomp$26$$,$map__52085__$1_p__52084$$){$map__52085__$1_p__52084$$=$APP.$cljs$core$__destructure_map$$($map__52085__$1_p__52084$$);var $show_ids$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52085__$1_p__52084$$,$cljs$cst$2593$show_ids$$),$root$jscomp$38_root_id$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__52085__$1_p__52084$$,$cljs$cst$2596$root_id$$,$APP.$app$common$uuid$zero$$),
$objects$jscomp$214$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$11$$);$root$jscomp$38_root_id$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$214$$,$root$jscomp$38_root_id$jscomp$3$$);$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("[Page: %s]%s",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$11$$),
$APP.$cljs$core$truth_$$($show_ids$jscomp$3$$)?[" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$11$$))].join(""):null]))]));return $app$common$types$file$dump_shape$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$38_root_id$jscomp$3$$),1,$objects$jscomp$214$$,$file$jscomp$33$$,$libraries$jscomp$26$$,$map__52085__$1_p__52084$$)};
$app$common$types$file$dump_library$$=function($library$jscomp$6$$,$file$jscomp$34$$,$libraries$jscomp$27$$,$p__52086_show_ids$jscomp$4$$){var $map__52087__$1$$=$APP.$cljs$core$__destructure_map$$($p__52086_show_ids$jscomp$4$$);$p__52086_show_ids$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52087__$1$$,$cljs$cst$2593$show_ids$$);var $only$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52087__$1$$,$cljs$cst$2597$only$$),$include_deleted_QMARK_$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52087__$1$$,
$APP.$cljs$cst$2540$include_deleted_QMARK_$$),$lib_components$$=$app$common$types$components_list$components$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$6$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2540$include_deleted_QMARK_$$,$include_deleted_QMARK_$jscomp$9$$],null));$APP.$cljs$core$println$$();$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d\x3d %s%s",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$6$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$34$$))?"Local library":$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("Library %s",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$6$$)])),
$APP.$cljs$core$truth_$$($p__52086_show_ids$jscomp$4$$)?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$(" %s",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$6$$)])):null]))]));if($APP.$cljs$core$seq$$($lib_components$$))return $cljs$core$dorun$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return function $app$common$types$file$dump_library_$_iter__52088$$($s__52089$$){return new $APP.$cljs$core$LazySeq$$(null,
function(){for(;;){var $s__52089__$2_temp__5825__auto__$jscomp$147$$=$APP.$cljs$core$seq$$($s__52089$$);if($s__52089__$2_temp__5825__auto__$jscomp$147$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__52089__$2_temp__5825__auto__$jscomp$147$$)){var $c__5501__auto__$jscomp$24$$=$APP.$cljs$core$_chunked_first$$($s__52089__$2_temp__5825__auto__$jscomp$147$$),$size__5502__auto__$jscomp$24$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$24$$),$b__52091$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$24$$);
return function(){for(var $i__52090$$=0;;)if($i__52090$$<$size__5502__auto__$jscomp$24$$){var $JSCompiler_temp$jscomp$915_component$jscomp$40$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$24$$,$i__52090$$),$JSCompiler_temp_const$jscomp$914$$=$b__52091$$;var $G__52094$jscomp$inline_12082_JSCompiler_inline_result$jscomp$10792_or__5025__auto__$jscomp$inline_12081$$=$only$$==null;$G__52094$jscomp$inline_12082_JSCompiler_inline_result$jscomp$10792_or__5025__auto__$jscomp$inline_12081$$||($G__52094$jscomp$inline_12082_JSCompiler_inline_result$jscomp$10792_or__5025__auto__$jscomp$inline_12081$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$915_component$jscomp$40$$),$G__52094$jscomp$inline_12082_JSCompiler_inline_result$jscomp$10792_or__5025__auto__$jscomp$inline_12081$$=$only$$.$cljs$core$IFn$_invoke$arity$1$?$only$$.$cljs$core$IFn$_invoke$arity$1$($G__52094$jscomp$inline_12082_JSCompiler_inline_result$jscomp$10792_or__5025__auto__$jscomp$inline_12081$$):$only$$($G__52094$jscomp$inline_12082_JSCompiler_inline_result$jscomp$10792_or__5025__auto__$jscomp$inline_12081$$));
$APP.$cljs$core$truth_$$($G__52094$jscomp$inline_12082_JSCompiler_inline_result$jscomp$10792_or__5025__auto__$jscomp$inline_12081$$)?($APP.$cljs$core$println$$(),$JSCompiler_temp$jscomp$915_component$jscomp$40$$=$app$common$types$file$dump_component$$($JSCompiler_temp$jscomp$915_component$jscomp$40$$,$library$jscomp$6$$,$libraries$jscomp$27$$,$map__52087__$1$$)):$JSCompiler_temp$jscomp$915_component$jscomp$40$$=null;$JSCompiler_temp_const$jscomp$914$$.add($JSCompiler_temp$jscomp$915_component$jscomp$40$$);
$i__52090$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__52091$$),$app$common$types$file$dump_library_$_iter__52088$$($APP.$cljs$core$_chunked_rest$$($s__52089__$2_temp__5825__auto__$jscomp$147$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__52091$$),null)}var $component$jscomp$39$$=$APP.$cljs$core$first$$($s__52089__$2_temp__5825__auto__$jscomp$147$$);if($APP.$cljs$core$truth_$$(function(){var $G__52096_or__5025__auto__$jscomp$486$$=$only$$==null;if($G__52096_or__5025__auto__$jscomp$486$$)return $G__52096_or__5025__auto__$jscomp$486$$;
$G__52096_or__5025__auto__$jscomp$486$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$39$$);return $only$$.$cljs$core$IFn$_invoke$arity$1$?$only$$.$cljs$core$IFn$_invoke$arity$1$($G__52096_or__5025__auto__$jscomp$486$$):$only$$($G__52096_or__5025__auto__$jscomp$486$$)}())){$APP.$cljs$core$println$$();var $JSCompiler_temp$jscomp$916$$=$app$common$types$file$dump_component$$($component$jscomp$39$$,$library$jscomp$6$$,$libraries$jscomp$27$$,$map__52087__$1$$)}else $JSCompiler_temp$jscomp$916$$=
null;return $APP.$cljs$core$cons$$($JSCompiler_temp$jscomp$916$$,$app$common$types$file$dump_library_$_iter__52088$$($APP.$cljs$core$rest$$($s__52089__$2_temp__5825__auto__$jscomp$147$$)))}return null}},null,null)}($APP.$cljs$core$vals$$($lib_components$$))}());$APP.$cljs$core$println$$();return $APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["(no components)"]))};
$app$common$types$file$dump_tree$$=function($file$jscomp$35$$,$page$jscomp$12_page_id$jscomp$27$$,$libraries$jscomp$28$$,$flags$jscomp$23$$){$page$jscomp$12_page_id$jscomp$27$$=$APP.$app$common$types$pages_list$get_page$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$35$$),$page$jscomp$12_page_id$jscomp$27$$);$app$common$types$file$dump_page$$($page$jscomp$12_page_id$jscomp$27$$,$file$jscomp$35$$,$libraries$jscomp$28$$,$flags$jscomp$23$$);$app$common$types$file$dump_library$$($file$jscomp$35$$,
$file$jscomp$35$$,$libraries$jscomp$28$$,$flags$jscomp$23$$);$cljs$core$dorun$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return function $app$common$types$file$dump_tree_$_iter__52101$$($s__52102$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__52102__$2_temp__5825__auto__$jscomp$148$$=$APP.$cljs$core$seq$$($s__52102$$);if($s__52102__$2_temp__5825__auto__$jscomp$148$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__52102__$2_temp__5825__auto__$jscomp$148$$)){var $JSCompiler_inline_result$jscomp$917_c__5501__auto__$jscomp$25$$=
$APP.$cljs$core$_chunked_first$$($s__52102__$2_temp__5825__auto__$jscomp$148$$),$size__5502__auto__$jscomp$25$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$917_c__5501__auto__$jscomp$25$$),$b__52104_library$jscomp$7$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$25$$);a:{for(var $i__52103$jscomp$inline_5683$$=0;;)if($i__52103$jscomp$inline_5683$$<$size__5502__auto__$jscomp$25$$){var $library$jscomp$inline_5684_x$jscomp$inline_12088$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$917_c__5501__auto__$jscomp$25$$,
$i__52103$jscomp$inline_5683$$),$b$jscomp$inline_12087$$=$b__52104_library$jscomp$7$$;$library$jscomp$inline_5684_x$jscomp$inline_12088$$=$app$common$types$file$dump_library$$($library$jscomp$inline_5684_x$jscomp$inline_12088$$,$file$jscomp$35$$,$libraries$jscomp$28$$,$flags$jscomp$23$$);$b$jscomp$inline_12087$$.add($library$jscomp$inline_5684_x$jscomp$inline_12088$$);$i__52103$jscomp$inline_5683$$+=1}else{$JSCompiler_inline_result$jscomp$917_c__5501__auto__$jscomp$25$$=!0;break a}$JSCompiler_inline_result$jscomp$917_c__5501__auto__$jscomp$25$$=
void 0}return $JSCompiler_inline_result$jscomp$917_c__5501__auto__$jscomp$25$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__52104_library$jscomp$7$$),$app$common$types$file$dump_tree_$_iter__52101$$($APP.$cljs$core$_chunked_rest$$($s__52102__$2_temp__5825__auto__$jscomp$148$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__52104_library$jscomp$7$$),null)}$b__52104_library$jscomp$7$$=$APP.$cljs$core$first$$($s__52102__$2_temp__5825__auto__$jscomp$148$$);return $APP.$cljs$core$cons$$($app$common$types$file$dump_library$$($b__52104_library$jscomp$7$$,
$file$jscomp$35$$,$libraries$jscomp$28$$,$flags$jscomp$23$$),$app$common$types$file$dump_tree_$_iter__52101$$($APP.$cljs$core$rest$$($s__52102__$2_temp__5825__auto__$jscomp$148$$)))}return null}},null,null)}($APP.$cljs$core$vals$$($libraries$jscomp$28$$))}());return $APP.$cljs$core$println$$()};
$app$common$types$file$dump_subtree$$=function($file$jscomp$36$$,$page_id$jscomp$28$$,$shape_id$jscomp$29$$,$libraries$jscomp$29$$,$flags$jscomp$24$$){function $find_used_components$$($children$jscomp$190_page$jscomp$14$$,$root$jscomp$40$$){$children$jscomp$190_page$jscomp$14$$=$APP.$app$common$files$helpers$get_children_with_self$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$190_page$jscomp$14$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$40$$));
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($libs_to_show$jscomp$2$$,$shape$jscomp$283$$){return $APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$283$$)?$add_component$$($libs_to_show$jscomp$2$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$283$$),$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$283$$)):$libs_to_show$jscomp$2$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$children$jscomp$190_page$jscomp$14$$)}
function $add_component$$($libs_to_show$jscomp$1$$,$library_id$jscomp$14$$,$component_id$jscomp$16_component_ids$$){$component_id$jscomp$16_component_ids$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($libs_to_show$jscomp$1$$,$library_id$jscomp$14$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$component_id$jscomp$16_component_ids$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($libs_to_show$jscomp$1$$,$library_id$jscomp$14$$,
$component_id$jscomp$16_component_ids$$)}var $libraries_STAR_$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($libraries$jscomp$29$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$36$$),$file$jscomp$36$$),$page$jscomp$13$$=$APP.$app$common$types$pages_list$get_page$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$36$$),$page_id$jscomp$28$$),$shape$jscomp$282$$=$app$common$types$shape_tree$get_shape$$($page$jscomp$13$$,$shape_id$jscomp$29$$),
$root$jscomp$39$$=function(){var $or__5025__auto__$jscomp$487$$=$APP.$app$common$types$container$get_instance_root$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$13$$),$shape$jscomp$282$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$487$$)?$or__5025__auto__$jscomp$487$$:$shape$jscomp$282$$}(),$libs_to_show$$=function($libs_to_show$jscomp$3$$,$page$jscomp$15_sublibs_to_show$$,$root$jscomp$41$$){$page$jscomp$15_sublibs_to_show$$=$find_used_components$$($page$jscomp$15_sublibs_to_show$$,
$root$jscomp$41$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($libs_to_show__$1$$,$components$jscomp$2_p__52122$$){var $library_id$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$2_p__52122$$,0,null);$components$jscomp$2_p__52122$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$2_p__52122$$,1,null);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($libs_to_show__$2$$,$component_id$jscomp$17$$){var $library$jscomp$9_root__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries_STAR_$$,$library_id$jscomp$15$$),$component$jscomp$41$$=$app$common$types$file$get_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($libraries_STAR_$$,$library_id$jscomp$15$$,$component_id$jscomp$17$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0],null)]));$library$jscomp$9_root__$1$$=$APP.$cljs$core$truth_$$($component$jscomp$41$$)?
$APP.$app$common$types$file$get_component_root$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$9_root__$1$$),$component$jscomp$41$$):null;return $component$jscomp$41$$==null?($APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("(Cannot find component %s in library %s)",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$component_id$jscomp$17$$,
$library_id$jscomp$15$$]))])),$libs_to_show__$2$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libs_to_show__$2$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$library_id$jscomp$15$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$9_root__$1$$)],null)))?$libs_to_show__$2$$:$add_component$$($libs_to_show__$2$$,$library_id$jscomp$15$$,$component_id$jscomp$17$$)},$libs_to_show__$1$$,$components$jscomp$2_p__52122$$)},
$libs_to_show$jscomp$3$$,$page$jscomp$15_sublibs_to_show$$)}($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$page$jscomp$13$$,$root$jscomp$39$$);if($root$jscomp$39$$==null)return $APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([["Cannot find shape ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$29$$)].join("")]));$app$common$types$file$dump_page$$($page$jscomp$13$$,$file$jscomp$36$$,$libraries_STAR_$$,
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($flags$jscomp$24$$,$cljs$cst$2596$root_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$39$$)));return $cljs$core$dorun$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return function $app$common$types$file$dump_subtree_$_iter__52127$$($s__52128$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $temp__5825__auto__$jscomp$149$$=$APP.$cljs$core$seq$$($s__52128$$);if($temp__5825__auto__$jscomp$149$$){var $s__52128__$2$$=
$temp__5825__auto__$jscomp$149$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($s__52128__$2$$)){var $c__5501__auto__$jscomp$26$$=$APP.$cljs$core$_chunked_first$$($s__52128__$2$$),$size__5502__auto__$jscomp$26$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$26$$),$b__52130$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$26$$);return function(){for(var $i__52129$$=0;;)if($i__52129$$<$size__5502__auto__$jscomp$26$$){var $vec__52131$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$26$$,$i__52129$$),
$library_id$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52131$$,0,null),$component_ids$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52131$$,1,null);$APP.$cljs$core$chunk_append$$($b__52130$$,function(){var $library$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries_STAR_$$,$library_id$jscomp$17$$);$app$common$types$file$dump_library$$($library$jscomp$10$$,$file$jscomp$36$$,$libraries_STAR_$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($flags$jscomp$24$$,
$cljs$cst$2597$only$$,$component_ids$jscomp$2$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0])));return $cljs$core$dorun$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return function($i__52129$jscomp$1$$,$library$jscomp$11$$,$vec__52131$jscomp$1$$,$library_id$jscomp$18$$,$component_ids$jscomp$3$$,$c__5501__auto__$jscomp$27$$,$size__5502__auto__$jscomp$27$$,$b__52130$jscomp$1$$,$s__52128__$2$jscomp$1$$,$temp__5825__auto__$jscomp$150$$,
$page$jscomp$16$$,$shape$jscomp$284$$,$root$jscomp$42$$,$libs_to_show$jscomp$4$$,$libraries_STAR_$jscomp$1$$){return function $app$common$types$file$dump_subtree_$_iter__52127_$_iter__52134$$($s__52135$$){return new $APP.$cljs$core$LazySeq$$(null,function($i__52129$jscomp$2$$,$library$jscomp$12$$,$vec__52131$jscomp$2$$,$library_id$jscomp$19$$,$component_ids$jscomp$4$$,$c__5501__auto__$jscomp$28$$,$size__5502__auto__$jscomp$28$$,$b__52130$jscomp$2$$,$s__52128__$2$jscomp$2$$,$temp__5825__auto__$jscomp$151$$,
$page$jscomp$17$$,$shape$jscomp$285$$,$root$jscomp$43$$,$libs_to_show$jscomp$5$$,$libraries_STAR_$jscomp$2$$){return function(){for(;;){var $s__52135__$2_temp__5825__auto____$1$jscomp$7$$=$APP.$cljs$core$seq$$($s__52135$$);if($s__52135__$2_temp__5825__auto____$1$jscomp$7$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__52135__$2_temp__5825__auto____$1$jscomp$7$$)){var $c__5501__auto____$1$$=$APP.$cljs$core$_chunked_first$$($s__52135__$2_temp__5825__auto____$1$jscomp$7$$),$size__5502__auto____$1$$=$APP.$cljs$core$count$$($c__5501__auto____$1$$),
$b__52137$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto____$1$$);return function(){for(var $i__52136$$=0;;)if($i__52136$$<$size__5502__auto____$1$$){var $component$jscomp$inline_5687_component_id$jscomp$19$$=$APP.$cljs$core$_nth$$($c__5501__auto____$1$$,$i__52136$$),$JSCompiler_temp_const$jscomp$918$$=$b__52137$$;var $JSCompiler_inline_result$jscomp$919_library__$1$jscomp$inline_5686_root__$1$jscomp$inline_5689$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries_STAR_$jscomp$2$$,
$library_id$jscomp$19$$);$component$jscomp$inline_5687_component_id$jscomp$19$$=$app$common$types$file$get_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($libraries_STAR_$jscomp$2$$,$library_id$jscomp$19$$,$component$jscomp$inline_5687_component_id$jscomp$19$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0],null)]));var $page__$1$jscomp$inline_5688$$=$APP.$app$common$types$file$get_component_page$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$919_library__$1$jscomp$inline_5686_root__$1$jscomp$inline_5689$$),
$component$jscomp$inline_5687_component_id$jscomp$19$$);$JSCompiler_inline_result$jscomp$919_library__$1$jscomp$inline_5686_root__$1$jscomp$inline_5689$$=$APP.$app$common$types$file$get_component_root$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$919_library__$1$jscomp$inline_5686_root__$1$jscomp$inline_5689$$),$component$jscomp$inline_5687_component_id$jscomp$19$$);$APP.$cljs$core$truth_$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_5687_component_id$jscomp$19$$))?
$JSCompiler_inline_result$jscomp$919_library__$1$jscomp$inline_5686_root__$1$jscomp$inline_5689$$=null:($APP.$cljs$core$println$$(),$JSCompiler_inline_result$jscomp$919_library__$1$jscomp$inline_5686_root__$1$jscomp$inline_5689$$=$app$common$types$file$dump_page$$($page__$1$jscomp$inline_5688$$,$file$jscomp$36$$,$libraries_STAR_$jscomp$2$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($flags$jscomp$24$$,$cljs$cst$2596$root_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$919_library__$1$jscomp$inline_5686_root__$1$jscomp$inline_5689$$))));
$JSCompiler_temp_const$jscomp$918$$.add($JSCompiler_inline_result$jscomp$919_library__$1$jscomp$inline_5686_root__$1$jscomp$inline_5689$$);$i__52136$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__52137$$),$app$common$types$file$dump_subtree_$_iter__52127_$_iter__52134$$($APP.$cljs$core$_chunked_rest$$($s__52135__$2_temp__5825__auto____$1$jscomp$7$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__52137$$),null)}var $component_id$jscomp$18$$=$APP.$cljs$core$first$$($s__52135__$2_temp__5825__auto____$1$jscomp$7$$);
return $APP.$cljs$core$cons$$(function(){var $library__$1$jscomp$3_root__$1$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries_STAR_$jscomp$2$$,$library_id$jscomp$19$$),$component$jscomp$43$$=$app$common$types$file$get_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($libraries_STAR_$jscomp$2$$,$library_id$jscomp$19$$,$component_id$jscomp$18$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2540$include_deleted_QMARK_$$,
!0],null)])),$page__$1$jscomp$2$$=$APP.$app$common$types$file$get_component_page$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library__$1$jscomp$3_root__$1$jscomp$2$$),$component$jscomp$43$$);$library__$1$jscomp$3_root__$1$jscomp$2$$=$APP.$app$common$types$file$get_component_root$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library__$1$jscomp$3_root__$1$jscomp$2$$),$component$jscomp$43$$);if($APP.$cljs$core$truth_$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$43$$)))return null;
$APP.$cljs$core$println$$();return $app$common$types$file$dump_page$$($page__$1$jscomp$2$$,$file$jscomp$36$$,$libraries_STAR_$jscomp$2$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($flags$jscomp$24$$,$cljs$cst$2596$root_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library__$1$jscomp$3_root__$1$jscomp$2$$)))}(),$app$common$types$file$dump_subtree_$_iter__52127_$_iter__52134$$($APP.$cljs$core$rest$$($s__52135__$2_temp__5825__auto____$1$jscomp$7$$)))}return null}}}($i__52129$jscomp$1$$,
$library$jscomp$11$$,$vec__52131$jscomp$1$$,$library_id$jscomp$18$$,$component_ids$jscomp$3$$,$c__5501__auto__$jscomp$27$$,$size__5502__auto__$jscomp$27$$,$b__52130$jscomp$1$$,$s__52128__$2$jscomp$1$$,$temp__5825__auto__$jscomp$150$$,$page$jscomp$16$$,$shape$jscomp$284$$,$root$jscomp$42$$,$libs_to_show$jscomp$4$$,$libraries_STAR_$jscomp$1$$),null,null)}}($i__52129$$,$library$jscomp$10$$,$vec__52131$$,$library_id$jscomp$17$$,$component_ids$jscomp$2$$,$c__5501__auto__$jscomp$26$$,$size__5502__auto__$jscomp$26$$,
$b__52130$$,$s__52128__$2$$,$temp__5825__auto__$jscomp$149$$,$page$jscomp$13$$,$shape$jscomp$282$$,$root$jscomp$39$$,$libs_to_show$$,$libraries_STAR_$$)($component_ids$jscomp$2$$)}())}());$i__52129$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__52130$$),$app$common$types$file$dump_subtree_$_iter__52127$$($APP.$cljs$core$_chunked_rest$$($s__52128__$2$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__52130$$),null)}var $vec__52148$$=$APP.$cljs$core$first$$($s__52128__$2$$),
$library_id$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52148$$,0,null),$component_ids$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52148$$,1,null);return $APP.$cljs$core$cons$$(function(){var $library$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries_STAR_$$,$library_id$jscomp$16$$);$app$common$types$file$dump_library$$($library$jscomp$13$$,$file$jscomp$36$$,$libraries_STAR_$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($flags$jscomp$24$$,
$cljs$cst$2597$only$$,$component_ids$jscomp$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0])));return $cljs$core$dorun$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return function($library$jscomp$14$$,$vec__52148$jscomp$1$$,$library_id$jscomp$20$$,$component_ids$jscomp$5$$,$s__52128__$2$jscomp$3$$,$temp__5825__auto__$jscomp$152$$,$page$jscomp$18$$,$shape$jscomp$286$$,$root$jscomp$44$$,$libs_to_show$jscomp$6$$,$libraries_STAR_$jscomp$3$$){return function $app$common$types$file$dump_subtree_$_iter__52127_$_iter__52151$$($s__52152$$){return new $APP.$cljs$core$LazySeq$$(null,
function(){for(;;){var $s__52152__$2_temp__5825__auto____$1$jscomp$8$$=$APP.$cljs$core$seq$$($s__52152$$);if($s__52152__$2_temp__5825__auto____$1$jscomp$8$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__52152__$2_temp__5825__auto____$1$jscomp$8$$)){var $c__5501__auto__$jscomp$29$$=$APP.$cljs$core$_chunked_first$$($s__52152__$2_temp__5825__auto____$1$jscomp$8$$),$size__5502__auto__$jscomp$29$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$29$$),$b__52154$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$29$$);
return function(){for(var $i__52153$$=0;;)if($i__52153$$<$size__5502__auto__$jscomp$29$$){var $component$jscomp$inline_5692_component_id$jscomp$21$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$29$$,$i__52153$$),$JSCompiler_temp_const$jscomp$920$$=$b__52154$$;var $JSCompiler_inline_result$jscomp$921_library__$1$jscomp$inline_5691_root__$1$jscomp$inline_5694$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries_STAR_$jscomp$3$$,$library_id$jscomp$20$$);$component$jscomp$inline_5692_component_id$jscomp$21$$=
$app$common$types$file$get_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($libraries_STAR_$jscomp$3$$,$library_id$jscomp$20$$,$component$jscomp$inline_5692_component_id$jscomp$21$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0],null)]));var $page__$1$jscomp$inline_5693$$=$APP.$app$common$types$file$get_component_page$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$921_library__$1$jscomp$inline_5691_root__$1$jscomp$inline_5694$$),
$component$jscomp$inline_5692_component_id$jscomp$21$$);$JSCompiler_inline_result$jscomp$921_library__$1$jscomp$inline_5691_root__$1$jscomp$inline_5694$$=$APP.$app$common$types$file$get_component_root$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$921_library__$1$jscomp$inline_5691_root__$1$jscomp$inline_5694$$),$component$jscomp$inline_5692_component_id$jscomp$21$$);$APP.$cljs$core$truth_$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_5692_component_id$jscomp$21$$))?
$JSCompiler_inline_result$jscomp$921_library__$1$jscomp$inline_5691_root__$1$jscomp$inline_5694$$=null:($APP.$cljs$core$println$$(),$JSCompiler_inline_result$jscomp$921_library__$1$jscomp$inline_5691_root__$1$jscomp$inline_5694$$=$app$common$types$file$dump_page$$($page__$1$jscomp$inline_5693$$,$file$jscomp$36$$,$libraries_STAR_$jscomp$3$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($flags$jscomp$24$$,$cljs$cst$2596$root_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$921_library__$1$jscomp$inline_5691_root__$1$jscomp$inline_5694$$))));
$JSCompiler_temp_const$jscomp$920$$.add($JSCompiler_inline_result$jscomp$921_library__$1$jscomp$inline_5691_root__$1$jscomp$inline_5694$$);$i__52153$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__52154$$),$app$common$types$file$dump_subtree_$_iter__52127_$_iter__52151$$($APP.$cljs$core$_chunked_rest$$($s__52152__$2_temp__5825__auto____$1$jscomp$8$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__52154$$),null)}var $component_id$jscomp$20$$=$APP.$cljs$core$first$$($s__52152__$2_temp__5825__auto____$1$jscomp$8$$);
return $APP.$cljs$core$cons$$(function(){var $library__$1$jscomp$5_root__$1$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries_STAR_$jscomp$3$$,$library_id$jscomp$20$$),$component$jscomp$45$$=$app$common$types$file$get_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($libraries_STAR_$jscomp$3$$,$library_id$jscomp$20$$,$component_id$jscomp$20$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2540$include_deleted_QMARK_$$,
!0],null)])),$page__$1$jscomp$4$$=$APP.$app$common$types$file$get_component_page$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library__$1$jscomp$5_root__$1$jscomp$4$$),$component$jscomp$45$$);$library__$1$jscomp$5_root__$1$jscomp$4$$=$APP.$app$common$types$file$get_component_root$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library__$1$jscomp$5_root__$1$jscomp$4$$),$component$jscomp$45$$);if($APP.$cljs$core$truth_$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$45$$)))return null;
$APP.$cljs$core$println$$();return $app$common$types$file$dump_page$$($page__$1$jscomp$4$$,$file$jscomp$36$$,$libraries_STAR_$jscomp$3$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($flags$jscomp$24$$,$cljs$cst$2596$root_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library__$1$jscomp$5_root__$1$jscomp$4$$)))}(),$app$common$types$file$dump_subtree_$_iter__52127_$_iter__52151$$($APP.$cljs$core$rest$$($s__52152__$2_temp__5825__auto____$1$jscomp$8$$)))}return null}},null,null)}}($library$jscomp$13$$,
$vec__52148$$,$library_id$jscomp$16$$,$component_ids$jscomp$1$$,$s__52128__$2$$,$temp__5825__auto__$jscomp$149$$,$page$jscomp$13$$,$shape$jscomp$282$$,$root$jscomp$39$$,$libs_to_show$$,$libraries_STAR_$$)($component_ids$jscomp$1$$)}())}(),$app$common$types$file$dump_subtree_$_iter__52127$$($APP.$cljs$core$rest$$($s__52128__$2$$)))}return null}},null,null)}($libs_to_show$$)}())};
$app$common$types$file$get_touched_from_ref_chain_until_target_ref$$=function($chain$jscomp$4_container$jscomp$34_more_touched$$,$JSCompiler_temp_const$jscomp$922_libraries$jscomp$31$$,$or__5025__auto__$jscomp$inline_5696_shape$jscomp$290$$,$target_ref$jscomp$1$$){a:{for(var $G__52498$jscomp$inline_12104_chain$jscomp$inline_12100$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$or__5025__auto__$jscomp$inline_5696_shape$jscomp$290$$],null),$G__52500$jscomp$inline_12105_current$jscomp$inline_12101_ref$jscomp$inline_12103_temp__5823__auto__$jscomp$inline_12102$$=
$or__5025__auto__$jscomp$inline_5696_shape$jscomp$290$$;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__52500$jscomp$inline_12105_current$jscomp$inline_12101_ref$jscomp$inline_12103_temp__5823__auto__$jscomp$inline_12102$$,$target_ref$jscomp$1$$)){$chain$jscomp$4_container$jscomp$34_more_touched$$=$G__52498$jscomp$inline_12104_chain$jscomp$inline_12100$$;break a}$G__52500$jscomp$inline_12105_current$jscomp$inline_12101_ref$jscomp$inline_12103_temp__5823__auto__$jscomp$inline_12102$$=
$app$common$types$file$find_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(null,$chain$jscomp$4_container$jscomp$34_more_touched$$,$JSCompiler_temp_const$jscomp$922_libraries$jscomp$31$$,$G__52500$jscomp$inline_12105_current$jscomp$inline_12101_ref$jscomp$inline_12103_temp__5823__auto__$jscomp$inline_12102$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$2591$with_context_QMARK_$$,!0]));if($APP.$cljs$core$truth_$$($G__52500$jscomp$inline_12105_current$jscomp$inline_12101_ref$jscomp$inline_12103_temp__5823__auto__$jscomp$inline_12102$$))$G__52498$jscomp$inline_12104_chain$jscomp$inline_12100$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__52498$jscomp$inline_12104_chain$jscomp$inline_12100$$,$G__52500$jscomp$inline_12105_current$jscomp$inline_12101_ref$jscomp$inline_12103_temp__5823__auto__$jscomp$inline_12102$$);else{$chain$jscomp$4_container$jscomp$34_more_touched$$=$G__52498$jscomp$inline_12104_chain$jscomp$inline_12100$$;break a}}$chain$jscomp$4_container$jscomp$34_more_touched$$=void 0}$chain$jscomp$4_container$jscomp$34_more_touched$$=$APP.$cljs$core$set$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$component$swap_slot_QMARK_$$,
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$union$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nil_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1626$touched$$,$chain$jscomp$4_container$jscomp$34_more_touched$$)))));$JSCompiler_temp_const$jscomp$922_libraries$jscomp$31$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$;$or__5025__auto__$jscomp$inline_5696_shape$jscomp$290$$=$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$inline_5696_shape$jscomp$290$$);
return $JSCompiler_temp_const$jscomp$922_libraries$jscomp$31$$.call($APP.$clojure$set$union$$,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_5696_shape$jscomp$290$$)?$or__5025__auto__$jscomp$inline_5696_shape$jscomp$290$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,$chain$jscomp$4_container$jscomp$34_more_touched$$)};
$app$common$files$changes$process_touched_change$$=function($JSCompiler_temp$jscomp$898_data$jscomp$192$$,$component_id$jscomp$22_component_id$jscomp$inline_5699_map__52308__$1_p__52307$$){$component_id$jscomp$22_component_id$jscomp$inline_5699_map__52308__$1_p__52307$$=$APP.$cljs$core$__destructure_map$$($component_id$jscomp$22_component_id$jscomp$inline_5699_map__52308__$1_p__52307$$);var $croot_id$jscomp$258_shape$jscomp$292$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component_id$jscomp$22_component_id$jscomp$inline_5699_map__52308__$1_p__52307$$,
$APP.$cljs$cst$266$id$$),$objects$jscomp$218_page_id$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component_id$jscomp$22_component_id$jscomp$inline_5699_map__52308__$1_p__52307$$,$APP.$cljs$cst$2043$page_id$$);$component_id$jscomp$22_component_id$jscomp$inline_5699_map__52308__$1_p__52307$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component_id$jscomp$22_component_id$jscomp$inline_5699_map__52308__$1_p__52307$$,$APP.$cljs$cst$1627$component_id$$);$objects$jscomp$218_page_id$jscomp$30$$=
$APP.$cljs$core$truth_$$($objects$jscomp$218_page_id$jscomp$30$$)?$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1630$pages_index$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$898_data$jscomp$192$$),$objects$jscomp$218_page_id$jscomp$30$$)):$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$898_data$jscomp$192$$),
$component_id$jscomp$22_component_id$jscomp$inline_5699_map__52308__$1_p__52307$$));$croot_id$jscomp$258_shape$jscomp$292$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$218_page_id$jscomp$30$$,$croot_id$jscomp$258_shape$jscomp$292$$);$croot_id$jscomp$258_shape$jscomp$292$$=$app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$218_page_id$jscomp$30$$,$croot_id$jscomp$258_shape$jscomp$292$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$2547$allow_main_QMARK_$$,!0],null));$croot_id$jscomp$258_shape$jscomp$292$$!=null&&$APP.$app$common$types$component$main_instance_QMARK_$$($croot_id$jscomp$258_shape$jscomp$292$$)?($component_id$jscomp$22_component_id$jscomp$inline_5699_map__52308__$1_p__52307$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($croot_id$jscomp$258_shape$jscomp$292$$),$JSCompiler_temp$jscomp$898_data$jscomp$192$$=$app$common$types$components_list$update_component$$($JSCompiler_temp$jscomp$898_data$jscomp$192$$,
$component_id$jscomp$22_component_id$jscomp$inline_5699_map__52308__$1_p__52307$$,$APP.$cljs$core$identity$$)):$JSCompiler_temp$jscomp$898_data$jscomp$192$$=$component_id$jscomp$22_component_id$jscomp$inline_5699_map__52308__$1_p__52307$$!=null?$app$common$types$components_list$update_component$$($JSCompiler_temp$jscomp$898_data$jscomp$192$$,$component_id$jscomp$22_component_id$jscomp$inline_5699_map__52308__$1_p__52307$$,$APP.$cljs$core$identity$$):$JSCompiler_temp$jscomp$898_data$jscomp$192$$;return $JSCompiler_temp$jscomp$898_data$jscomp$192$$};
$app$common$files$changes$collect_shape_media_refs$$=function($state$jscomp$142$$,$obj$jscomp$185$$,$page_id$jscomp$35$$){var $media_refs$$=$APP.$cljs$core$not_empty$$($app$common$files$helpers$collect_shape_media_refs$$($obj$jscomp$185$$)),$xform$jscomp$25$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($id$jscomp$261$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$35$$,$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$185$$),
$APP.$cljs$cst$266$id$$,$id$jscomp$261$$],null)});return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$142$$,$cljs$cst$2660$media_refs$$,$APP.$cljs$core$into$$,$xform$jscomp$25$$,$media_refs$$)};
$app$common$files$changes$process_operations$$=function($objects$jscomp$219$$,$map__52375__$1_p__52374$$){$map__52375__$1_p__52374$$=$APP.$cljs$core$__destructure_map$$($map__52375__$1_p__52374$$);var $page_id$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52375__$1_p__52374$$,$APP.$cljs$cst$2043$page_id$$),$id$jscomp$263$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52375__$1_p__52374$$,$APP.$cljs$cst$266$id$$),$operations$jscomp$5_shape__$1$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52375__$1_p__52374$$,
$APP.$cljs$cst$2613$operations$$),$G__52382_52897_temp__5823__auto__$jscomp$148_touched_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$219$$,$id$jscomp$263$$);return $APP.$cljs$core$truth_$$($G__52382_52897_temp__5823__auto__$jscomp$148_touched_QMARK_$jscomp$1$$)?($operations$jscomp$5_shape__$1$jscomp$25$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$files$changes$process_operation$$,$G__52382_52897_temp__5823__auto__$jscomp$148_touched_QMARK_$jscomp$1$$,
$operations$jscomp$5_shape__$1$jscomp$25$$),$G__52382_52897_temp__5823__auto__$jscomp$148_touched_QMARK_$jscomp$1$$=$cljs$cst$2558$app_DOT_common_DOT_types_DOT_container_SLASH_touched$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($operations$jscomp$5_shape__$1$jscomp$25$$)),$APP.$cljs$core$truth_$$($G__52382_52897_temp__5823__auto__$jscomp$148_touched_QMARK_$jscomp$1$$)&&($G__52382_52897_temp__5823__auto__$jscomp$148_touched_QMARK_$jscomp$1$$=$app$common$files$changes$_STAR_touched_changes_STAR_$$,
$G__52382_52897_temp__5823__auto__$jscomp$148_touched_QMARK_$jscomp$1$$!=null&&$APP.$cljs$core$_vreset_BANG_$$($G__52382_52897_temp__5823__auto__$jscomp$148_touched_QMARK_$jscomp$1$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($G__52382_52897_temp__5823__auto__$jscomp$148_touched_QMARK_$jscomp$1$$),$map__52375__$1_p__52374$$))),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$(null)?$page_id$jscomp$37$$:null)&&$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$(null,
$app$common$files$changes$collect_shape_media_refs$$,$operations$jscomp$5_shape__$1$jscomp$25$$,$page_id$jscomp$37$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$219$$,$id$jscomp$263$$,$operations$jscomp$5_shape__$1$jscomp$25$$)):$objects$jscomp$219$$};
$app$common$files$changes$process_children_reordering$$=function($objects$jscomp$220$$,$map__52393__$1_p__52392$$){$map__52393__$1_p__52392$$=$APP.$cljs$core$__destructure_map$$($map__52393__$1_p__52392$$);var $parent_id$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52393__$1_p__52392$$,$APP.$cljs$cst$1619$parent_id$$),$new_shapes$jscomp$3_shapes$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52393__$1_p__52392$$,$APP.$cljs$cst$1614$shapes$$),$G__52394_52901_temp__5823__auto__$jscomp$149$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$220$$,$parent_id$jscomp$28$$),$APP.$cljs$cst$1614$shapes$$);if($APP.$cljs$core$truth_$$($G__52394_52901_temp__5823__auto__$jscomp$149$$)){var $id__GT_idx$$=$APP.$cljs$core$update_vals$$($APP.$cljs$core$group_by$$($APP.$cljs$core$second$$,$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($new_shapes$jscomp$3_shapes$jscomp$19$$)),$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,
$APP.$cljs$core$first$$));$new_shapes$jscomp$3_shapes$jscomp$19$$=$APP.$cljs$core$vec$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$(function($p1__52391_SHARP_$$){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($id__GT_idx$$.$cljs$core$IFn$_invoke$arity$1$?$id__GT_idx$$.$cljs$core$IFn$_invoke$arity$1$($p1__52391_SHARP_$$):$id__GT_idx$$($p1__52391_SHARP_$$),-1)},$APP.$cljs$core$_LT_$$,$G__52394_52901_temp__5823__auto__$jscomp$149$$));if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__52394_52901_temp__5823__auto__$jscomp$149$$,
$new_shapes$jscomp$3_shapes$jscomp$19$$))return $G__52394_52901_temp__5823__auto__$jscomp$149$$=$app$common$files$changes$_STAR_touched_changes_STAR_$$,$G__52394_52901_temp__5823__auto__$jscomp$149$$!=null&&$APP.$cljs$core$_vreset_BANG_$$($G__52394_52901_temp__5823__auto__$jscomp$149$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($G__52394_52901_temp__5823__auto__$jscomp$149$$),$map__52393__$1_p__52392$$)),$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($objects$jscomp$220$$,
$parent_id$jscomp$28$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1614$shapes$$,$new_shapes$jscomp$3_shapes$jscomp$19$$)}return $objects$jscomp$220$$};$app$common$files$changes$parents_frames$$=function($id$jscomp$282$$,$objects$jscomp$230$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,$app$common$files$helpers$get_parents_with_self$$($objects$jscomp$230$$,$id$jscomp$282$$))};
$APP.$app$common$files$focus$focus_objects$$=function($objects$jscomp$231$$,$focus$$){var $ids_with_children$$=$APP.$app$common$data$not_empty_QMARK_$$($focus$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($focus$$,$APP.$app$common$uuid$zero$$),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$helpers$get_children_ids$$,$objects$jscomp$231$$)),
$focus$$):null;return $ids_with_children$$!=null?$APP.$cljs$core$assoc_in$$($APP.$cljs$core$select_keys$$($objects$jscomp$231$$,$ids_with_children$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$uuid$zero$$,$APP.$cljs$cst$1614$shapes$$],null),$APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$231$$,$focus$$)):$objects$jscomp$231$$};
$app$common$files$focus$filter_not_focus$$=function($objects$jscomp$232$$,$focus$jscomp$1$$,$ids$jscomp$35$$){var $focused_ids$$=$APP.$app$common$data$not_empty_QMARK_$$($focus$jscomp$1$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($focus$jscomp$1$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$helpers$get_children_ids$$,$objects$jscomp$232$$)),$focus$jscomp$1$$):null;return $focused_ids$$!=
null?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__51702_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($focused_ids$$,$p1__51702_SHARP_$$)}),$ids$jscomp$35$$):$ids$jscomp$35$$};
$app$main$data$render_wasm$context_lost$$=function(){typeof $app$main$data$render_wasm$context_lost_51723$$==="undefined"&&($app$main$data$render_wasm$context_lost_51723$$=function($meta51724$$){this.$meta51724$=$meta51724$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$render_wasm$context_lost_51723$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$render_wasm$context_lost_51723$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$2669$app_DOT_main_DOT_data_DOT_render_wasm_SLASH_context_lost$$},$app$main$data$render_wasm$context_lost_51723$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_51725$$,$meta51724__$1$$){return new $app$main$data$render_wasm$context_lost_51723$$($meta51724__$1$$)},$app$main$data$render_wasm$context_lost_51723$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta51724$},$app$main$data$render_wasm$context_lost_51723$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$render_wasm$context_lost_51723$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1585$$,$state$jscomp$143$$){var $already_lost_QMARK_$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$143$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2186$render_state$$,$cljs$cst$2187$lost$$],null)),$prev_read_only_QMARK_$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$143$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$2217$read_only_QMARK_$$],null)),$prev_options_mode$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$143$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$2200$options_mode$$],null));return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$143$$,
$cljs$cst$2186$render_state$$,function($G__51726_render_state$$){$G__51726_render_state$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__51726_render_state$$,$cljs$cst$2187$lost$$,!0);return $APP.$cljs$core$not$$($already_lost_QMARK_$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__51726_render_state$$,$cljs$cst$2670$pre_context_lost_read_only_QMARK_$$,$prev_read_only_QMARK_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$2671$pre_context_lost_options_mode$$,
$prev_options_mode$$])):$G__51726_render_state$$}),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$2200$options_mode$$],null),$APP.$cljs$cst$2672$inspect$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$2217$read_only_QMARK_$$],null),!0)},$app$main$data$render_wasm$context_lost_51723$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$render_wasm$context_lost_51723$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2169$interrupt$$)});return new $app$main$data$render_wasm$context_lost_51723$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$render_wasm$context_restored$$=function(){typeof $app$main$data$render_wasm$context_restored_51732$$==="undefined"&&($app$main$data$render_wasm$context_restored_51732$$=function($meta51733$$){this.$meta51733$=$meta51733$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$render_wasm$context_restored_51732$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$render_wasm$context_restored_51732$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$2673$app_DOT_main_DOT_data_DOT_render_wasm_SLASH_context_restored$$},$app$main$data$render_wasm$context_restored_51732$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_51734$$,$meta51733__$1$$){return new $app$main$data$render_wasm$context_restored_51732$$($meta51733__$1$$)},$app$main$data$render_wasm$context_restored_51732$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta51733$},$app$main$data$render_wasm$context_restored_51732$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$render_wasm$context_restored_51732$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1587_restored_read_only_QMARK_$$,$state$jscomp$144$$){$_$jscomp$1587_restored_read_only_QMARK_$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$144$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2186$render_state$$,$cljs$cst$2670$pre_context_lost_read_only_QMARK_$$],
null),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$144$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$2217$read_only_QMARK_$$],null)));var $restored_options_mode$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$144$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2186$render_state$$,$cljs$cst$2671$pre_context_lost_options_mode$$],
null),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$144$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$2200$options_mode$$],null)));return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$144$$,$cljs$cst$2186$render_state$$,function($p1__51731_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__51731_SHARP_$$,
$cljs$cst$2187$lost$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$2670$pre_context_lost_read_only_QMARK_$$,$cljs$cst$2671$pre_context_lost_options_mode$$]))}),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$2200$options_mode$$],null),$restored_options_mode$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,
$APP.$cljs$cst$2217$read_only_QMARK_$$],null),$_$jscomp$1587_restored_read_only_QMARK_$$)},$app$main$data$render_wasm$context_restored_51732$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$render_wasm$context_restored_51732$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2169$interrupt$$)});return new $app$main$data$render_wasm$context_restored_51732$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$texts_v3$v3_update_text_editor_styles$$=function($id$jscomp$286$$,$new_styles$$){typeof $app$main$data$workspace$texts_v3$v3_update_text_editor_styles_51737$$==="undefined"&&($app$main$data$workspace$texts_v3$v3_update_text_editor_styles_51737$$=function($id$jscomp$287$$,$new_styles$jscomp$1$$,$meta51738$$){this.id=$id$jscomp$287$$;this.$new_styles$=$new_styles$jscomp$1$$;this.$meta51738$=$meta51738$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$texts_v3$v3_update_text_editor_styles_51737$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts_v3$v3_update_text_editor_styles_51737$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2674$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_v3_SLASH_v3_update_text_editor_styles$$},$app$main$data$workspace$texts_v3$v3_update_text_editor_styles_51737$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_51739$$,$meta51738__$1$$){return new $app$main$data$workspace$texts_v3$v3_update_text_editor_styles_51737$$(this.id,this.$new_styles$,$meta51738__$1$$)},$app$main$data$workspace$texts_v3$v3_update_text_editor_styles_51737$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta51738$},$app$main$data$workspace$texts_v3$v3_update_text_editor_styles_51737$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts_v3$v3_update_text_editor_styles_51737$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$1589_merged_styles$$,$state$jscomp$145$$){$_$jscomp$1589_merged_styles$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$get_default_text_attrs$$(),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$145$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$2201$default_font$$],
null)),this.$new_styles$]));return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$145$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2224$workspace_wasm_editor_styles$$,this.id],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$merge$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),$_$jscomp$1589_merged_styles$$)});return new $app$main$data$workspace$texts_v3$v3_update_text_editor_styles_51737$$($id$jscomp$286$$,
$new_styles$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$fonts$register_BANG_$$=function($backend$jscomp$6$$,$fonts$jscomp$2$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$fonts$fontsdb$$,function($db$jscomp$7_db__$1$$){$db$jscomp$7_db__$1$$=$APP.$cljs$core$reduce_kv$$(function($p1__53014_SHARP_$$,$p2__53016_SHARP_$$,$p3__53015_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($backend$jscomp$6$$,$APP.$cljs$cst$2584$backend$$.$cljs$core$IFn$_invoke$arity$1$($p3__53015_SHARP_$$))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__53014_SHARP_$$,
$p2__53016_SHARP_$$):$p1__53014_SHARP_$$},$db$jscomp$7_db__$1$$,$db$jscomp$7_db__$1$$);var $fonts__$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__53017_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__53017_SHARP_$$,$APP.$cljs$cst$2584$backend$$,$backend$jscomp$6$$)},$fonts$jscomp$2$$);return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$db$jscomp$7_db__$1$$,$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,
$fonts__$1$$)]))})};$APP.$app$main$fonts$get_font_data$$=function($id$jscomp$288$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$),$id$jscomp$288$$)};
$APP.$app$main$fonts$find_font_data$$=function($data$jscomp$234$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($font$jscomp$6$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$select_keys$$($font$jscomp$6$$,$APP.$cljs$core$keys$$($data$jscomp$234$$)),$data$jscomp$234$$)},$APP.$cljs$core$vals$$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$)))};
$APP.$app$main$fonts$find_font_family$$=function($family$$){var $family_SINGLEQUOTE_$$=$APP.$cuerdas$core$lower$$($family$$);return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($family__$1_map__53029__$1_p__53028$$){$family__$1_map__53029__$1_p__53028$$=$APP.$cljs$core$__destructure_map$$($family__$1_map__53029__$1_p__53028$$);$family__$1_map__53029__$1_p__53028$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($family__$1_map__53029__$1_p__53028$$,$APP.$cljs$cst$2675$family$$);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($family_SINGLEQUOTE_$$,$APP.$cuerdas$core$lower$$($family__$1_map__53029__$1_p__53028$$))},$APP.$cljs$core$vals$$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$)))};
$app$main$fonts$add_font_css_BANG_$$=function($id$jscomp$290_temp__5825__auto__$jscomp$153$$,$css$$){var $node$jscomp$260$$=$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("style");$APP.$app$util$dom$set_attribute_BANG_$$($node$jscomp$260$$,"id",$id$jscomp$290_temp__5825__auto__$jscomp$153$$);$app$util$dom$set_html_BANG_$$($node$jscomp$260$$,$css$$);$id$jscomp$290_temp__5825__auto__$jscomp$153$$=$APP.$app$util$globals$document$$.head;return $APP.$cljs$core$truth_$$($id$jscomp$290_temp__5825__auto__$jscomp$153$$)?
$APP.$app$util$dom$append_child_BANG_$$($id$jscomp$290_temp__5825__auto__$jscomp$153$$,$node$jscomp$260$$):null};
$app$main$fonts$generate_gfonts_url$$=function($family$jscomp$1_p__53048_query$jscomp$23$$){var $map__53049__$1_variants$$=$APP.$cljs$core$__destructure_map$$($family$jscomp$1_p__53048_query$jscomp$23$$);$family$jscomp$1_p__53048_query$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53049__$1_variants$$,$APP.$cljs$cst$2675$family$$);$map__53049__$1_variants$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53049__$1_variants$$,$APP.$cljs$cst$2676$variants$$);$family$jscomp$1_p__53048_query$jscomp$23$$=
"family\x3d"+($family$jscomp$1_p__53048_query$jscomp$23$$??"")+":"+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$map__53049__$1_variants$$))??"")+"\x26display\x3dblock";return""+($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"internal/gfonts/css"])),
$APP.$cljs$cst$747$query$$,$family$jscomp$1_p__53048_query$jscomp$23$$)??"")};$app$main$fonts$process_gfont_css$$=function($css$jscomp$1$$){var $base$jscomp$27$$=$APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"internal/gfonts/font"]));return $APP.$cuerdas$core$replace$$($css$jscomp$1$$,"https://fonts.gstatic.com/s",""+($base$jscomp$27$$??""))};
$app$main$fonts$fetch_gfont_css$$=function($url$jscomp$79$$){return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($err$jscomp$33$$){console.warn("Cannot find the font",$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($err$jscomp$33$$,"message"));return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1581$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$,
$APP.$cljs$cst$1579$uri$$,$url$jscomp$79$$,$APP.$cljs$cst$320$mode$$,$APP.$cljs$cst$1190$cors$$,$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$1588$text$$],null))))};
$app$main$fonts$generate_custom_font_variant_css$$=function($G__53053_family$jscomp$2$$,$JSCompiler_inline_result$jscomp$927_asset_id$jscomp$inline_5739_variant$jscomp$5$$){var $JSCompiler_temp_const$jscomp$926$$=$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$927_asset_id$jscomp$inline_5739_variant$jscomp$5$$),$JSCompiler_temp_const$jscomp$925$$=$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$927_asset_id$jscomp$inline_5739_variant$jscomp$5$$);
$JSCompiler_inline_result$jscomp$927_asset_id$jscomp$inline_5739_variant$jscomp$5$$=$cljs$cst$2681$app_DOT_main_DOT_fonts_SLASH_woff1_file_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$927_asset_id$jscomp$inline_5739_variant$jscomp$5$$);$JSCompiler_inline_result$jscomp$927_asset_id$jscomp$inline_5739_variant$jscomp$5$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,
"assets/by-id/",$JSCompiler_inline_result$jscomp$927_asset_id$jscomp$inline_5739_variant$jscomp$5$$])));$G__53053_family$jscomp$2$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2675$family$$,$G__53053_family$jscomp$2$$,$APP.$cljs$cst$1904$style$$,$JSCompiler_temp_const$jscomp$926$$,$APP.$cljs$cst$1996$weight$$,$JSCompiler_temp_const$jscomp$925$$,$APP.$cljs$cst$1579$uri$$,$JSCompiler_inline_result$jscomp$927_asset_id$jscomp$inline_5739_variant$jscomp$5$$],null);return $APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$("@font-face {\n    font-family: '%(family)s';\n    font-style: %(style)s;\n    font-weight: %(weight)s;\n    font-display: block;\n    src: url(%(uri)s) format('woff');\n  }",$G__53053_family$jscomp$2$$):$APP.$cuerdas$core$format$$("@font-face {\n    font-family: '%(family)s';\n    font-style: %(style)s;\n    font-weight: %(weight)s;\n    font-display: block;\n    src: url(%(uri)s) format('woff');\n  }",$G__53053_family$jscomp$2$$)};
$app$main$fonts$generate_custom_font_css$$=function($map__53059__$1_p__53058_variants$jscomp$1$$){$map__53059__$1_p__53058_variants$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($map__53059__$1_p__53058_variants$jscomp$1$$);var $family$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53059__$1_p__53058_variants$jscomp$1$$,$APP.$cljs$cst$2675$family$$);$map__53059__$1_p__53058_variants$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53059__$1_p__53058_variants$jscomp$1$$,
$APP.$cljs$cst$2676$variants$$);return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__53056_SHARP_$$){return $app$main$fonts$generate_custom_font_variant_css$$($family$jscomp$3$$,$p1__53056_SHARP_$$)},$map__53059__$1_p__53058_variants$jscomp$1$$))};
$APP.$app$main$fonts$get_default_variant$$=function($map__53066__$1_p__53065_variants$jscomp$2$$){$map__53066__$1_p__53065_variants$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__53066__$1_p__53065_variants$jscomp$2$$);$map__53066__$1_p__53065_variants$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53066__$1_p__53065_variants$jscomp$2$$,$APP.$cljs$cst$2676$variants$$);var $or__5025__auto__$jscomp$493$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__53064_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__53064_SHARP_$$),
"regular")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__53064_SHARP_$$),"regular")},$map__53066__$1_p__53065_variants$jscomp$2$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$493$$)?$or__5025__auto__$jscomp$493$$:$APP.$cljs$core$first$$($map__53066__$1_p__53065_variants$jscomp$2$$)};
$APP.$app$main$fonts$get_variant$$=function($map__53069__$1_p__53068$$,$font_variant_id$jscomp$1$$){$map__53069__$1_p__53068$$=$APP.$cljs$core$__destructure_map$$($map__53069__$1_p__53068$$);var $or__5025__auto__$jscomp$494_variants$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53069__$1_p__53068$$,$APP.$cljs$cst$2676$variants$$);$or__5025__auto__$jscomp$494_variants$jscomp$3$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__53067_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__53067_SHARP_$$),
$font_variant_id$jscomp$1$$)},$or__5025__auto__$jscomp$494_variants$jscomp$3$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$494_variants$jscomp$3$$)?$or__5025__auto__$jscomp$494_variants$jscomp$3$$:$APP.$app$main$fonts$get_default_variant$$($map__53069__$1_p__53068$$)};
$app$main$fonts$find_closest_variant$$=function($font$jscomp$15_result$jscomp$230_variants$jscomp$5$$,$target_weight$$,$target_style$$){var $temp__5825__auto__$jscomp$154$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($target_weight$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$154$$)?($font$jscomp$15_result$jscomp$230_variants$jscomp$5$$=$APP.$cljs$cst$2676$variants$$.$cljs$core$IFn$_invoke$arity$2$($font$jscomp$15_result$jscomp$230_variants$jscomp$5$$,
$APP.$cljs$core$PersistentVector$EMPTY$$),$font$jscomp$15_result$jscomp$230_variants$jscomp$5$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($closest_match$$,$current$jscomp$31_variant$jscomp$6$$){var $weight$jscomp$6$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$31_variant$jscomp$6$$)),$distance$jscomp$3$$=$APP.$cljs$core$abs$$($temp__5825__auto__$jscomp$154$$-$weight$jscomp$6$$),
$matches_style_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($target_style$$,$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$31_variant$jscomp$6$$));$current$jscomp$31_variant$jscomp$6$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1994$variant$$,$current$jscomp$31_variant$jscomp$6$$,$APP.$cljs$cst$1996$weight$$,$weight$jscomp$6$$,$APP.$cljs$cst$2684$distance$$,$distance$jscomp$3$$],null);var $and__5023__auto__$jscomp$inline_5741$$=
$distance$jscomp$3$$===0;return($and__5023__auto__$jscomp$inline_5741$$?$APP.$cljs$core$truth_$$($target_style$$)?$matches_style_QMARK_$$:1:$and__5023__auto__$jscomp$inline_5741$$)?$APP.$cljs$core$reduced$$($current$jscomp$31_variant$jscomp$6$$):$closest_match$$==null?$current$jscomp$31_variant$jscomp$6$$:$distance$jscomp$3$$<$APP.$cljs$cst$2684$distance$$.$cljs$core$IFn$_invoke$arity$1$($closest_match$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($distance$jscomp$3$$,$APP.$cljs$cst$2684$distance$$.$cljs$core$IFn$_invoke$arity$1$($closest_match$$))&&
$weight$jscomp$6$$>$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($closest_match$$)?$current$jscomp$31_variant$jscomp$6$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($weight$jscomp$6$$,$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($closest_match$$))&&$matches_style_QMARK_$$?$current$jscomp$31_variant$jscomp$6$$:$closest_match$$},null,$font$jscomp$15_result$jscomp$230_variants$jscomp$5$$),$APP.$cljs$cst$1994$variant$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$15_result$jscomp$230_variants$jscomp$5$$)):
null};
$app$main$fonts$get_content_fonts$$=function($content$jscomp$116$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$232$$,$current_font_map__53082__$1_p__53081$$){$current_font_map__53082__$1_p__53081$$=$APP.$cljs$core$__destructure_map$$($current_font_map__53082__$1_p__53081$$);$current_font_map__53082__$1_p__53081$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_font_map__53082__$1_p__53081$$,$APP.$cljs$cst$1757$font_id$$)!=null?$APP.$cljs$core$select_keys$$($current_font_map__53082__$1_p__53081$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$1759$font_variant_id$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1762$font_style$$],null)):$APP.$cljs$core$select_keys$$($APP.$app$common$types$text$default_typography$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$1759$font_variant_id$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1762$font_style$$],
null));return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$232$$,$current_font_map__53082__$1_p__53081$$)},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$text$is_text_node_QMARK_$$,$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$01$$($content$jscomp$116$$)))};
$APP.$app$main$fonts$fetch_font_css$$=function($font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$){$font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$=$APP.$cljs$core$__destructure_map$$($font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$);var $family$jscomp$5_font_id$jscomp$5_map__53085$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$,
$APP.$cljs$cst$1757$font_id$$);$font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$,$APP.$cljs$cst$1759$font_variant_id$$,"regular");$family$jscomp$5_font_id$jscomp$5_map__53085$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$),
$family$jscomp$5_font_id$jscomp$5_map__53085$$);var $map__53085__$1_map__53086_weight$jscomp$7$$=$APP.$cljs$core$__destructure_map$$($family$jscomp$5_font_id$jscomp$5_map__53085$$),$backend$jscomp$9_style$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53085__$1_map__53086_weight$jscomp$7$$,$APP.$cljs$cst$2584$backend$$);$family$jscomp$5_font_id$jscomp$5_map__53085$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53085__$1_map__53086_weight$jscomp$7$$,$APP.$cljs$cst$2675$family$$);
if($map__53085__$1_map__53086_weight$jscomp$7$$==null)return $APP.$beicon$v2$core$empty$$();if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2679$google$$,$backend$jscomp$9_style$jscomp$14$$))return $font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$=$APP.$app$main$fonts$get_variant$$($map__53085__$1_map__53086_weight$jscomp$7$$,$font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$),
$APP.$beicon$v2$core$map$$($app$main$fonts$process_gfont_css$$,$APP.$beicon$v2$core$mapcat$$($app$main$fonts$fetch_gfont_css$$,(0,$APP.$beicon$v2$core$of$$)($app$main$fonts$generate_gfonts_url$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2675$family$$,$family$jscomp$5_font_id$jscomp$5_map__53085$$,$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$],
null)],null)))));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2682$custom$$,$backend$jscomp$9_style$jscomp$14$$))return $font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$=$APP.$app$main$fonts$get_variant$$($map__53085__$1_map__53086_weight$jscomp$7$$,$font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$),$font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$=
$app$main$fonts$generate_custom_font_variant_css$$($family$jscomp$5_font_id$jscomp$5_map__53085$$,$font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$),(0,$APP.$beicon$v2$core$of$$)($font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$);$map__53085__$1_map__53086_weight$jscomp$7$$=$APP.$app$main$fonts$get_variant$$($map__53085__$1_map__53086_weight$jscomp$7$$,$font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$);
var $map__53086__$1_suffix$jscomp$17$$=$APP.$cljs$core$__destructure_map$$($map__53085__$1_map__53086_weight$jscomp$7$$);$map__53085__$1_map__53086_weight$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53086__$1_suffix$jscomp$17$$,$APP.$cljs$cst$1996$weight$$);$backend$jscomp$9_style$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53086__$1_suffix$jscomp$17$$,$APP.$cljs$cst$1904$style$$);$map__53086__$1_suffix$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53086__$1_suffix$jscomp$17$$,
$APP.$cljs$cst$1371$suffix$$);$font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$=$APP.$cljs$core$truth_$$($map__53086__$1_suffix$jscomp$17$$)?$map__53086__$1_suffix$jscomp$17$$:$font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$;$font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1579$uri$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,["fonts/",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($family$jscomp$5_font_id$jscomp$5_map__53085$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$),
".woff"].join("")]))),$APP.$cljs$cst$2675$family$$,$family$jscomp$5_font_id$jscomp$5_map__53085$$,$APP.$cljs$cst$1904$style$$,$backend$jscomp$9_style$jscomp$14$$,$APP.$cljs$cst$1996$weight$$,$map__53085__$1_map__53086_weight$jscomp$7$$],null);return(0,$APP.$beicon$v2$core$of$$)($APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$("@font-face {\n    font-family: '%(family)s';\n    font-style: %(style)s;\n    font-weight: %(weight)s;\n    font-display: block;\n    src: url(%(uri)s) format('woff');\n  }",
$font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$):$APP.$cuerdas$core$format$$("@font-face {\n    font-family: '%(family)s';\n    font-style: %(style)s;\n    font-weight: %(weight)s;\n    font-display: block;\n    src: url(%(uri)s) format('woff');\n  }",$font_variant_id$jscomp$3_map__53084__$1_p__53083_params$jscomp$170_result$jscomp$233_suffix__$1_variant$jscomp$7$$))};
$app$main$fonts$get_font_style_id$$=function($font_id$jscomp$6_p__53087$$){var $font_variant_id$jscomp$4_map__53088__$1$$=$APP.$cljs$core$__destructure_map$$($font_id$jscomp$6_p__53087$$);$font_id$jscomp$6_p__53087$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_id$jscomp$4_map__53088__$1$$,$APP.$cljs$cst$1757$font_id$$);$font_variant_id$jscomp$4_map__53088__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($font_variant_id$jscomp$4_map__53088__$1$$,$APP.$cljs$cst$1759$font_variant_id$$,
"regular");return""+($font_id$jscomp$6_p__53087$$??"")+":"+($font_variant_id$jscomp$4_map__53088__$1$$??"")};
$app$main$fonts$get_font_styles_by_font_ref$$=function($font_ref$$){var $id$jscomp$295$$=$app$main$fonts$get_font_style_id$$($font_ref$$);return $APP.$cljs$core$truth_$$($app$main$fonts$font_styles$$.has($id$jscomp$295$$))?(0,$APP.$beicon$v2$core$of$$)($app$main$fonts$font_styles$$.get($id$jscomp$295$$)):$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($css$jscomp$5$$){return $app$main$fonts$font_styles$$.set($id$jscomp$295$$,$css$jscomp$5$$)},$APP.$beicon$v2$core$mapcat$$($APP.$app$main$fonts$fetch_font_css$$,
(0,$APP.$beicon$v2$core$of$$)($font_ref$$)))};$APP.$app$main$fonts$render_font_styles_cached$$=function($font_refs$jscomp$1$$){return $APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$109$$,$css$jscomp$6$$){return""+($acc$jscomp$109$$??"")+"\n"+($css$jscomp$6$$??"")},"",$APP.$beicon$v2$core$merge_map$$($app$main$fonts$get_font_styles_by_font_ref$$,$APP.$beicon$v2$core$from$$($font_refs$jscomp$1$$)))};
$APP.$app$main$ui$formats$format_percent$cljs$0core$0IFn$0_invoke$0arity$02$$=function($value$jscomp$457_value__$1$jscomp$7$$,$map__51843__$1_p__51838_precision$jscomp$10$$){$map__51843__$1_p__51838_precision$jscomp$10$$=$APP.$cljs$core$__destructure_map$$($map__51843__$1_p__51838_precision$jscomp$10$$);$map__51843__$1_p__51838_precision$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51843__$1_p__51838_precision$jscomp$10$$,$APP.$cljs$cst$267$precision$$,2);$value$jscomp$457_value__$1$jscomp$7$$=
typeof $value$jscomp$457_value__$1$jscomp$7$$==="string"?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$457_value__$1$jscomp$7$$):$value$jscomp$457_value__$1$jscomp$7$$;return $APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($value$jscomp$457_value__$1$jscomp$7$$))?""+($APP.$app$common$math$precision$$($value$jscomp$457_value__$1$jscomp$7$$*100,$map__51843__$1_p__51838_precision$jscomp$10$$)??"")+"%":null};
$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$=function($value$jscomp$460$$){return $APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$460$$)};
$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$=function($value$jscomp$461_value__$1$jscomp$9$$){var $map__51863__$1_precision$jscomp$12$$=$APP.$cljs$core$__destructure_map$$(null);$map__51863__$1_precision$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51863__$1_precision$jscomp$12$$,$APP.$cljs$cst$267$precision$$,2);$value$jscomp$461_value__$1$jscomp$9$$=typeof $value$jscomp$461_value__$1$jscomp$9$$==="string"?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$461_value__$1$jscomp$9$$):
$value$jscomp$461_value__$1$jscomp$9$$;return $APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($value$jscomp$461_value__$1$jscomp$9$$))?""+($APP.$app$common$math$precision$$($value$jscomp$461_value__$1$jscomp$9$$,$map__51863__$1_precision$jscomp$12$$)??""):null};
$app$main$ui$formats$format_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$=function($a$jscomp$372_p__51910$$){var $f$jscomp$810_map__51912__$1$$=$APP.$cljs$core$__destructure_map$$($a$jscomp$372_p__51910$$);$a$jscomp$372_p__51910$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$810_map__51912__$1$$,$APP.$cljs$cst$1519$a$$);var $b$jscomp$301$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$810_map__51912__$1$$,$APP.$cljs$cst$1520$b$$),$c$jscomp$290$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$810_map__51912__$1$$,
$cljs$cst$1521$c$$),$d$jscomp$230$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$810_map__51912__$1$$,$cljs$cst$1447$d$$),$e$jscomp$296$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$810_map__51912__$1$$,$cljs$cst$1449$e$$);$f$jscomp$810_map__51912__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$810_map__51912__$1$$,$cljs$cst$598$f$$);return"matrix("+($a$jscomp$372_p__51910$$.toFixed(2)??"")+", "+($b$jscomp$301$$.toFixed(2)??"")+", "+($c$jscomp$290$$.toFixed(2)??
"")+", "+($d$jscomp$230$$.toFixed(2)??"")+", "+($e$jscomp$296$$.toFixed(2)??"")+", "+($f$jscomp$810_map__51912__$1$$.toFixed(2)??"")+")"};
$app$util$color$gradient__GT_css$$=function($p__51889_type$jscomp$379$$){var $map__51890__$1_stops$jscomp$4_stops_css$$=$APP.$cljs$core$__destructure_map$$($p__51889_type$jscomp$379$$);$p__51889_type$jscomp$379$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51890__$1_stops$jscomp$4_stops_css$$,$APP.$cljs$cst$139$type$$);$map__51890__$1_stops$jscomp$4_stops_css$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51890__$1_stops$jscomp$4_stops_css$$,$APP.$cljs$cst$1733$stops$$);
$map__51890__$1_stops$jscomp$4_stops_css$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($G__51903_offset$jscomp$121_p__51891$$){var $map__51892__$1_opacity$jscomp$12$$=$APP.$cljs$core$__destructure_map$$($G__51903_offset$jscomp$121_p__51891$$);$G__51903_offset$jscomp$121_p__51891$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51892__$1_opacity$jscomp$12$$,$APP.$cljs$cst$195$offset$$);var $color$jscomp$37_r$jscomp$109$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51892__$1_opacity$jscomp$12$$,$APP.$cljs$cst$1298$color$$);$map__51892__$1_opacity$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51892__$1_opacity$jscomp$12$$,$APP.$cljs$cst$1734$opacity$$);var $b$jscomp$302_vec__51894$$=$APP.$app$common$types$color$hex__GT_rgb$$($color$jscomp$37_r$jscomp$109$$);$color$jscomp$37_r$jscomp$109$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$302_vec__51894$$,0,
null);var $g$jscomp$133$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$302_vec__51894$$,1,null);$b$jscomp$302_vec__51894$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$302_vec__51894$$,2,null);$G__51903_offset$jscomp$121_p__51891$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__51903_offset$jscomp$121_p__51891$$*100),"%"].join("");return $APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$6$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$6$("rgba(%s, %s, %s, %s) %s",
$color$jscomp$37_r$jscomp$109$$,$g$jscomp$133$$,$b$jscomp$302_vec__51894$$,$map__51892__$1_opacity$jscomp$12$$,$G__51903_offset$jscomp$121_p__51891$$):$APP.$cuerdas$core$format$$("rgba(%s, %s, %s, %s) %s",$color$jscomp$37_r$jscomp$109$$,$g$jscomp$133$$,$b$jscomp$302_vec__51894$$,$map__51892__$1_opacity$jscomp$12$$,$G__51903_offset$jscomp$121_p__51891$$)},$map__51890__$1_stops$jscomp$4_stops_css$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__51889_type$jscomp$379$$,$APP.$cljs$cst$287$linear$$)?
$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$("linear-gradient(to bottom, %s)",$map__51890__$1_stops$jscomp$4_stops_css$$):$APP.$cuerdas$core$format$$("linear-gradient(to bottom, %s)",$map__51890__$1_stops$jscomp$4_stops_css$$):$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$("radial-gradient(circle, %s)",$map__51890__$1_stops$jscomp$4_stops_css$$):$APP.$cuerdas$core$format$$("radial-gradient(circle, %s)",
$map__51890__$1_stops$jscomp$4_stops_css$$)};$APP.$app$util$color$gradient_type__GT_string$$=function($type$jscomp$380$$){switch($type$jscomp$380$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$380$$.$fqn$:null){case "linear":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.gradients.linear");case "radial":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.gradients.radial");default:return null}};
$app$util$color$color__GT_background$$=function($opacity$jscomp$13_opacity__$1$jscomp$1_p__51916$$){var $b$jscomp$303_map__51917__$1_value$jscomp$466_vec__51924$$=$APP.$cljs$core$__destructure_map$$($opacity$jscomp$13_opacity__$1$jscomp$1_p__51916$$),$color$jscomp$38_color__$1$jscomp$1_g$jscomp$134$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$303_map__51917__$1_value$jscomp$466_vec__51924$$,$APP.$cljs$cst$1298$color$$);$opacity$jscomp$13_opacity__$1$jscomp$1_p__51916$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$303_map__51917__$1_value$jscomp$466_vec__51924$$,
$APP.$cljs$cst$1734$opacity$$);var $color__$2_gradient$jscomp$6_r$jscomp$110$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$303_map__51917__$1_value$jscomp$466_vec__51924$$,$APP.$cljs$cst$1724$gradient$$);$b$jscomp$303_map__51917__$1_value$jscomp$466_vec__51924$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$303_map__51917__$1_value$jscomp$466_vec__51924$$,$APP.$cljs$cst$260$value$$);$color$jscomp$38_color__$1$jscomp$1_g$jscomp$134$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$38_color__$1$jscomp$1_g$jscomp$134$$,
$b$jscomp$303_map__51917__$1_value$jscomp$466_vec__51924$$);$opacity$jscomp$13_opacity__$1$jscomp$1_p__51916$$=$APP.$cljs$core$truth_$$($opacity$jscomp$13_opacity__$1$jscomp$1_p__51916$$)?$opacity$jscomp$13_opacity__$1$jscomp$1_p__51916$$:1;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($color__$2_gradient$jscomp$6_r$jscomp$110$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$color__$2_gradient$jscomp$6_r$jscomp$110$$):$color__$2_gradient$jscomp$6_r$jscomp$110$$)?
$app$util$color$gradient__GT_css$$($color__$2_gradient$jscomp$6_r$jscomp$110$$):$color$jscomp$38_color__$1$jscomp$1_g$jscomp$134$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$38_color__$1$jscomp$1_g$jscomp$134$$,$APP.$cljs$cst$1616$multiple$$)?($color__$2_gradient$jscomp$6_r$jscomp$110$$=$APP.$app$common$types$color$prepend_hash$$($APP.$app$common$types$color$expand_hex$$($APP.$cuerdas$core$replace$$($color$jscomp$38_color__$1$jscomp$1_g$jscomp$134$$,"#",""))),$b$jscomp$303_map__51917__$1_value$jscomp$466_vec__51924$$=
$APP.$app$common$types$color$hex__GT_rgb$$($color__$2_gradient$jscomp$6_r$jscomp$110$$),$color__$2_gradient$jscomp$6_r$jscomp$110$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$303_map__51917__$1_value$jscomp$466_vec__51924$$,0,null),$color$jscomp$38_color__$1$jscomp$1_g$jscomp$134$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$303_map__51917__$1_value$jscomp$466_vec__51924$$,1,null),$b$jscomp$303_map__51917__$1_value$jscomp$466_vec__51924$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$303_map__51917__$1_value$jscomp$466_vec__51924$$,
2,null),$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$5$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$5$("rgba(%s, %s, %s, %s)",$color__$2_gradient$jscomp$6_r$jscomp$110$$,$color$jscomp$38_color__$1$jscomp$1_g$jscomp$134$$,$b$jscomp$303_map__51917__$1_value$jscomp$466_vec__51924$$,$opacity$jscomp$13_opacity__$1$jscomp$1_p__51916$$):$APP.$cuerdas$core$format$$("rgba(%s, %s, %s, %s)",$color__$2_gradient$jscomp$6_r$jscomp$110$$,$color$jscomp$38_color__$1$jscomp$1_g$jscomp$134$$,
$b$jscomp$303_map__51917__$1_value$jscomp$466_vec__51924$$,$opacity$jscomp$13_opacity__$1$jscomp$1_p__51916$$)):"transparent"};
$app$util$color$color__GT_format__GT_background$$=function($G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$,$G__51941__$1_format$jscomp$31_h$jscomp$152_r$jscomp$111$$){var $b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$=$APP.$cljs$core$__destructure_map$$($G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$),$color$jscomp$39_g$jscomp$135_s$jscomp$543$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$,
$APP.$cljs$cst$1298$color$$);$G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$,$APP.$cljs$cst$1734$opacity$$);$b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$,$APP.$cljs$cst$1724$gradient$$);
$G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$=$APP.$cljs$core$truth_$$($G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$)?$G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$:1;if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$):
$b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$))return $app$util$color$gradient__GT_css$$($b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$);if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$39_g$jscomp$135_s$jscomp$543$$,$APP.$cljs$cst$1616$multiple$$))switch($G__51941__$1_format$jscomp$31_h$jscomp$152_r$jscomp$111$$=$G__51941__$1_format$jscomp$31_h$jscomp$152_r$jscomp$111$$ instanceof $APP.$cljs$core$Keyword$$?
$G__51941__$1_format$jscomp$31_h$jscomp$152_r$jscomp$111$$.$fqn$:null,$G__51941__$1_format$jscomp$31_h$jscomp$152_r$jscomp$111$$){case "rgba":return $b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$=$APP.$app$common$types$color$hex__GT_rgb$$($color$jscomp$39_g$jscomp$135_s$jscomp$543$$),$G__51941__$1_format$jscomp$31_h$jscomp$152_r$jscomp$111$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$,
0,null),$color$jscomp$39_g$jscomp$135_s$jscomp$543$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$,1,null),$b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$,2,null),$G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$=
$app$common$types$color$format_rgba$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__51941__$1_format$jscomp$31_h$jscomp$152_r$jscomp$111$$,$color$jscomp$39_g$jscomp$135_s$jscomp$543$$,$b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$,$G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$],null)),$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$("rgba(%s)",
$G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$):$APP.$cuerdas$core$format$$("rgba(%s)",$G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$);case "hsla":return $b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$=$APP.$app$common$types$color$hex__GT_hsl$$($color$jscomp$39_g$jscomp$135_s$jscomp$543$$),$G__51941__$1_format$jscomp$31_h$jscomp$152_r$jscomp$111$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$,
0,null),$color$jscomp$39_g$jscomp$135_s$jscomp$543$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$,1,null),$b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$,2,null),$G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$=
$app$common$types$color$format_hsla$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__51941__$1_format$jscomp$31_h$jscomp$152_r$jscomp$111$$,$color$jscomp$39_g$jscomp$135_s$jscomp$543$$,$b$jscomp$304_gradient$jscomp$7_l$jscomp$100_map__51939__$1_vec__51944_vec__51950$$,$G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$],null)),$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$("hsla(%s)",
$G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$):$APP.$cuerdas$core$format$$("hsla(%s)",$G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$);case "hex":return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$39_g$jscomp$135_s$jscomp$543$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$upper$$($APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($G__51948_G__51954_opacity$jscomp$14_opacity__$1$jscomp$2_p__51938$$*
255).toString(16).padStart(2,"0")))].join("");default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__51941__$1_format$jscomp$31_h$jscomp$152_r$jscomp$111$$)].join(""));}else return"transparent"};
$APP.$app$util$color$multiple_QMARK_$$=function($id$jscomp$296_p__51958$$){var $gradient$jscomp$8_map__51959__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$296_p__51958$$);$id$jscomp$296_p__51958$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient$jscomp$8_map__51959__$1$$,$APP.$cljs$cst$266$id$$);var $file_id$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient$jscomp$8_map__51959__$1$$,$APP.$cljs$cst$1644$file_id$$),$value$jscomp$467$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient$jscomp$8_map__51959__$1$$,
$APP.$cljs$cst$260$value$$),$color$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient$jscomp$8_map__51959__$1$$,$APP.$cljs$cst$1298$color$$);$gradient$jscomp$8_map__51959__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient$jscomp$8_map__51959__$1$$,$APP.$cljs$cst$1724$gradient$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$467$$,$APP.$cljs$cst$1616$multiple$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$40$$,
$APP.$cljs$cst$1616$multiple$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($gradient$jscomp$8_map__51959__$1$$,$APP.$cljs$cst$1616$multiple$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$296_p__51958$$,$APP.$cljs$cst$1616$multiple$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$29$$,$APP.$cljs$cst$1616$multiple$$)};
$app$main$ui$shapes$text$styles$generate_root_styles$cljs$0core$0IFn$0_invoke$0arity$03$$=function($p__53091_width$jscomp$78$$,$node$jscomp$264_valign$$,$G__53093_G__53093__$1_G__53093__$2_code_QMARK_$$){var $height$jscomp$71_map__53092__$1$$=$APP.$cljs$core$__destructure_map$$($p__53091_width$jscomp$78$$);$p__53091_width$jscomp$78$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$71_map__53092__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$71_map__53092__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$71_map__53092__$1$$,
$APP.$cljs$cst$1522$height$$);$node$jscomp$264_valign$$=$APP.$cljs$cst$1767$vertical_align$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$264_valign$$,"top");$G__53093_G__53093__$1_G__53093__$2_code_QMARK_$$={height:$APP.$cljs$core$truth_$$($G__53093_G__53093__$1_G__53093__$2_code_QMARK_$$)?null:$APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($height$jscomp$71_map__53092__$1$$),width:$APP.$cljs$core$truth_$$($G__53093_G__53093__$1_G__53093__$2_code_QMARK_$$)?null:$APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($p__53091_width$jscomp$78$$),
display:"flex",whiteSpace:"break-spaces"};$G__53093_G__53093__$1_G__53093__$2_code_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$264_valign$$,"top")?$APP.$app$util$object$set_BANG_$$($G__53093_G__53093__$1_G__53093__$2_code_QMARK_$$,"alignItems","flex-start"):$G__53093_G__53093__$1_G__53093__$2_code_QMARK_$$;$G__53093_G__53093__$1_G__53093__$2_code_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$264_valign$$,"center")?$APP.$app$util$object$set_BANG_$$($G__53093_G__53093__$1_G__53093__$2_code_QMARK_$$,
"alignItems","center"):$G__53093_G__53093__$1_G__53093__$2_code_QMARK_$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$264_valign$$,"bottom")?$APP.$app$util$object$set_BANG_$$($G__53093_G__53093__$1_G__53093__$2_code_QMARK_$$,"alignItems","flex-end"):$G__53093_G__53093__$1_G__53093__$2_code_QMARK_$$};
$app$main$ui$shapes$text$styles$generate_paragraph_set_styles$$=function($grow_type_map__53095__$1_p__53094$$){$grow_type_map__53095__$1_p__53094$$=$APP.$cljs$core$__destructure_map$$($grow_type_map__53095__$1_p__53094$$);$grow_type_map__53095__$1_p__53094$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grow_type_map__53095__$1_p__53094$$,$APP.$cljs$cst$1770$grow_type$$);return{display:"inline-flex",flexDirection:"column",justifyContent:"inherit",minWidth:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type_map__53095__$1_p__53094$$,
$APP.$cljs$cst$2036$auto_width$$)?null:"100%",marginRight:"1px",verticalAlign:"top"}};
$APP.$app$main$ui$shapes$text$styles$generate_paragraph_styles$$=function($data$jscomp$235_text_align$$){var $G__53097__$1_line_height$jscomp$1_line_height__$1$$=$APP.$cljs$cst$1765$line_height$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$235_text_align$$);$G__53097__$1_line_height$jscomp$1_line_height__$1$$=$G__53097__$1_line_height$jscomp$1_line_height__$1$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",$G__53097__$1_line_height$jscomp$1_line_height__$1$$)?$G__53097__$1_line_height$jscomp$1_line_height__$1$$:
$APP.$cljs$cst$1765$line_height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$);$data$jscomp$235_text_align$$=$APP.$cljs$cst$1763$text_align$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$235_text_align$$,"start");var $G__53097$$={fontSize:0,lineHeight:$G__53097__$1_line_height$jscomp$1_line_height__$1$$,margin:0};$G__53097__$1_line_height$jscomp$1_line_height__$1$$=$G__53097__$1_line_height$jscomp$1_line_height__$1$$!=null?$APP.$app$util$object$set_BANG_$$($G__53097$$,
"lineHeight",$G__53097__$1_line_height$jscomp$1_line_height__$1$$):$G__53097$$;return $data$jscomp$235_text_align$$!=null?$APP.$app$util$object$set_BANG_$$($G__53097__$1_line_height$jscomp$1_line_height__$1$$,"textAlign",$data$jscomp$235_text_align$$):$G__53097__$1_line_height$jscomp$1_line_height__$1$$};
$APP.$app$main$ui$shapes$text$styles$generate_text_styles$cljs$0core$0IFn$0_invoke$0arity$03$$=function($grow_type$jscomp$1_map__53123__$1_p__53121$$,$data$jscomp$237$$,$G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$){$grow_type$jscomp$1_map__53123__$1_p__53121$$=$APP.$cljs$core$__destructure_map$$($grow_type$jscomp$1_map__53123__$1_p__53121$$);$grow_type$jscomp$1_map__53123__$1_p__53121$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$1_map__53123__$1_p__53121$$,
$APP.$cljs$cst$1770$grow_type$$);$G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$=$APP.$cljs$core$__destructure_map$$($G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$);var $base$jscomp$30_font_family$jscomp$3_show_text_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$,$APP.$cljs$cst$2685$show_text_QMARK_$$,!0),$G__53153__$2_letter_spacing$jscomp$2$$=$APP.$cljs$cst$1766$letter_spacing$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$237$$,
0),$font_style$jscomp$1_text_decoration$$=$APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$),$font_weight$jscomp$2_text_transform$jscomp$1_vec__53129$$=$APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$),$G__53153_G__53153__$1_font_id$jscomp$7$$=function(){var $or__5025__auto__$jscomp$499$$=$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$499$$)?
$or__5025__auto__$jscomp$499$$:$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$)}(),$font_variant_id$jscomp$5$$=$APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$);$G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$=$APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$);var $fill_color_fontsdb_text_color$jscomp$1$$=function(){var $or__5025__auto__$jscomp$500$$=
$APP.$cljs$cst$1746$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$)));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$500$$)?$or__5025__auto__$jscomp$500$$:$APP.$cljs$cst$1746$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$)}(),$base__$1_fill_opacity$$=function(){var $or__5025__auto__$jscomp$501$$=$APP.$cljs$cst$1747$fill_opacity$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$)));
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$501$$)?$or__5025__auto__$jscomp$501$$:$APP.$cljs$cst$1747$fill_opacity$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$)}(),$fill_gradient_fills$jscomp$11$$=function(){var $or__5025__auto__$jscomp$502$$=$APP.$cljs$cst$1748$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$)));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$502$$)?
$or__5025__auto__$jscomp$502$$:$APP.$cljs$cst$1748$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$)}(),$a$jscomp$373_vec__53126$$=$app$common$types$color$hex__GT_rgba$$($fill_color_fontsdb_text_color$jscomp$1$$,$base__$1_fill_opacity$$),$r$jscomp$112$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$373_vec__53126$$,0,null),$g$jscomp$136$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$373_vec__53126$$,1,null),$b$jscomp$305$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$373_vec__53126$$,
2,null);$a$jscomp$373_vec__53126$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$373_vec__53126$$,3,null);$fill_color_fontsdb_text_color$jscomp$1$$=$fill_color_fontsdb_text_color$jscomp$1$$!=null&&$base__$1_fill_opacity$$!=null?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("rgba(%s, %s, %s, %s)",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$r$jscomp$112$$,$g$jscomp$136$$,$b$jscomp$305$$,$a$jscomp$373_vec__53126$$])):null;var $gradient_QMARK_$$=
$fill_gradient_fills$jscomp$11$$!=null,$text_color__$1$$=$gradient_QMARK_$$?$app$util$color$color__GT_background$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1724$gradient$$,$fill_gradient_fills$jscomp$11$$],null)):$fill_color_fontsdb_text_color$jscomp$1$$;$fill_color_fontsdb_text_color$jscomp$1$$=$APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$);$base$jscomp$30_font_family$jscomp$3_show_text_QMARK_$$={color:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($base$jscomp$30_font_family$jscomp$3_show_text_QMARK_$$)?
!$gradient_QMARK_$$:$base$jscomp$30_font_family$jscomp$3_show_text_QMARK_$$)?$text_color__$1$$:"transparent",textTransform:$font_weight$jscomp$2_text_transform$jscomp$1_vec__53129$$,background:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($base$jscomp$30_font_family$jscomp$3_show_text_QMARK_$$)?$gradient_QMARK_$$:$base$jscomp$30_font_family$jscomp$3_show_text_QMARK_$$)?$text_color__$1$$:null,lineBreak:"auto",overflowWrap:"initial",whiteSpace:"break-spaces",fontSize:$G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$,
textRendering:"geometricPrecision",caretColor:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$324$$=!$gradient_QMARK_$$;return $and__5023__auto__$jscomp$324$$?$text_color__$1$$:$and__5023__auto__$jscomp$324$$}())?$text_color__$1$$:"black",textDecoration:$font_style$jscomp$1_text_decoration$$};$base__$1_fill_opacity$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1765$line_height$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$),"0")?$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($base$jscomp$30_font_family$jscomp$3_show_text_QMARK_$$,
"display","inline-block"),"verticalAlign","top"):$base$jscomp$30_font_family$jscomp$3_show_text_QMARK_$$;$fill_gradient_fills$jscomp$11$$=$APP.$cljs$cst$1746$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$)!=null||$APP.$cljs$cst$1747$fill_opacity$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$)!=null||$APP.$cljs$cst$1748$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$)!=null?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$select_keys$$($data$jscomp$237$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1746$fill_color$$,$APP.$cljs$cst$1747$fill_opacity$$,$APP.$cljs$cst$1748$fill_color_gradient$$,$APP.$cljs$cst$1745$fill_color_ref_id$$,$APP.$cljs$cst$1640$fill_color_ref_file$$],null)))],null):$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$)==
null?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1746$fill_color$$,"#000000",$APP.$cljs$cst$1747$fill_opacity$$,1],null)],null):$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$);var $font$jscomp$18$$=$G__53153_G__53153__$1_font_id$jscomp$7$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill_color_fontsdb_text_color$jscomp$1$$,$G__53153_G__53153__$1_font_id$jscomp$7$$);
$font_weight$jscomp$2_text_transform$jscomp$1_vec__53129$$=$font$jscomp$18$$!=null?function(){var $font_variant$jscomp$1$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__53112_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_id$jscomp$5$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__53112_SHARP_$$))},$APP.$cljs$cst$2676$variants$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$18$$));return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cuerdas$core$quote$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $or__5025__auto__$jscomp$503$$=$APP.$cljs$cst$2675$family$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$18$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$503$$)?$or__5025__auto__$jscomp$503$$:$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$)}()),function(){var $or__5025__auto__$jscomp$504$$=$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($font_variant$jscomp$1$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$504$$)?$or__5025__auto__$jscomp$504$$:$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$)}(),function(){var $or__5025__auto__$jscomp$505$$=$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($font_variant$jscomp$1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$505$$)?$or__5025__auto__$jscomp$505$$:$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$237$$)}()],
null)}():null;$base$jscomp$30_font_family$jscomp$3_show_text_QMARK_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font_weight$jscomp$2_text_transform$jscomp$1_vec__53129$$,0,null);$font_style$jscomp$1_text_decoration$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font_weight$jscomp$2_text_transform$jscomp$1_vec__53129$$,1,null);$font_weight$jscomp$2_text_transform$jscomp$1_vec__53129$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font_weight$jscomp$2_text_transform$jscomp$1_vec__53129$$,
2,null);$G__53153_G__53153__$1_font_id$jscomp$7$$=$APP.$app$util$object$set_BANG_$$($base__$1_fill_opacity$$,"--font-id",$G__53153_G__53153__$1_font_id$jscomp$7$$);$G__53153_G__53153__$1_font_id$jscomp$7$$=$fill_gradient_fills$jscomp$11$$!=null?$APP.$app$util$object$set_BANG_$$($G__53153_G__53153__$1_font_id$jscomp$7$$,"--fills",$APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($fill_gradient_fills$jscomp$11$$,null)):$G__53153_G__53153__$1_font_id$jscomp$7$$;$G__53153__$2_letter_spacing$jscomp$2$$=
typeof $G__53153__$2_letter_spacing$jscomp$2$$==="string"&&$G__53153__$2_letter_spacing$jscomp$2$$.length>0?$APP.$app$util$object$set_BANG_$$($G__53153_G__53153__$1_font_id$jscomp$7$$,"letterSpacing",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__53153__$2_letter_spacing$jscomp$2$$),"px"].join("")):$G__53153_G__53153__$1_font_id$jscomp$7$$;$G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$=typeof $G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$===
"string"&&$G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$.length>0?$APP.$app$util$object$set_BANG_$$($G__53153__$2_letter_spacing$jscomp$2$$,"fontSize",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$),"px"].join("")):$G__53153__$2_letter_spacing$jscomp$2$$;$G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$=$font$jscomp$18$$!=null?$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$,
"fontFamily",$base$jscomp$30_font_family$jscomp$3_show_text_QMARK_$$),"fontStyle",$font_style$jscomp$1_text_decoration$$),"fontWeight",$font_weight$jscomp$2_text_transform$jscomp$1_vec__53129$$):$G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$1_map__53123__$1_p__53121$$,$APP.$cljs$cst$2036$auto_width$$)?$APP.$app$util$object$set_BANG_$$($G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$,
"whiteSpace","pre"):$G__53153__$3_G__53153__$4_font_size$jscomp$4_map__53125__$1_p__53122$$};
$app$main$ui$shapes$text$fo_text$render_text$$=function($props_53160_text$jscomp$23$$){var $node$jscomp$265_style$jscomp$15$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_53160_text$jscomp$23$$,"node"),$parent$jscomp$202$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_53160_text$jscomp$23$$,"parent"),$shape$jscomp$303$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_53160_text$jscomp$23$$,"shape");$props_53160_text$jscomp$23$$=
$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$265_style$jscomp$15$$);$node$jscomp$265_style$jscomp$15$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_53160_text$jscomp$23$$,"")?$APP.$app$main$ui$shapes$text$styles$generate_text_styles$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$303$$,$parent$jscomp$202$$,null):$APP.$app$main$ui$shapes$text$styles$generate_text_styles$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$303$$,$node$jscomp$265_style$jscomp$15$$,
null);return(0,$APP.$rumext$v2$jsx$$)("span",{className:"text-node",style:$node$jscomp$265_style$jscomp$15$$,children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_53160_text$jscomp$23$$,"")?" ":$props_53160_text$jscomp$23$$})};
$app$main$ui$shapes$text$fo_text$render_root$$=function($props_53161_style$jscomp$16$$){var $children$jscomp$193$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_53161_style$jscomp$16$$,"children");$props_53161_style$jscomp$16$$=$app$main$ui$shapes$text$styles$generate_root_styles$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_53161_style$jscomp$16$$,"shape"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_53161_style$jscomp$16$$,
"node"),!1);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"root rich-text",style:$props_53161_style$jscomp$16$$,xmlns:"http://www.w3.org/1999/xhtml",children:$children$jscomp$193$$})};
$app$main$ui$shapes$text$fo_text$render_paragraph_set$$=function($props_53163_style$jscomp$17$$){var $children$jscomp$194$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_53163_style$jscomp$17$$,"children");$props_53163_style$jscomp$17$$=$app$main$ui$shapes$text$styles$generate_paragraph_set_styles$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_53163_style$jscomp$17$$,"shape"));return(0,$APP.$rumext$v2$jsx$$)("div",{className:"paragraph-set",style:$props_53163_style$jscomp$17$$,
children:$children$jscomp$194$$})};
$app$main$ui$shapes$text$fo_text$render_paragraph$$=function($children$jscomp$195_props_53168$$){var $dir$jscomp$2_node$jscomp$267$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($children$jscomp$195_props_53168$$,"node");$children$jscomp$195_props_53168$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($children$jscomp$195_props_53168$$,"children");var $style$jscomp$18$$=$APP.$app$main$ui$shapes$text$styles$generate_paragraph_styles$$($dir$jscomp$2_node$jscomp$267$$);$dir$jscomp$2_node$jscomp$267$$=
$APP.$cljs$cst$1764$text_direction$$.$cljs$core$IFn$_invoke$arity$2$($dir$jscomp$2_node$jscomp$267$$,"auto");return(0,$APP.$rumext$v2$jsx$$)("p",{className:"paragraph",style:$style$jscomp$18$$,dir:$dir$jscomp$2_node$jscomp$267$$,children:$children$jscomp$195_props_53168$$})};
$app$main$ui$shapes$text$fo_text$fill__GT_color$$=function($fill_color$jscomp$1_p__53179$$){var $fill_color_gradient_map__53180__$1$$=$APP.$cljs$core$__destructure_map$$($fill_color$jscomp$1_p__53179$$);$fill_color$jscomp$1_p__53179$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill_color_gradient_map__53180__$1$$,$APP.$cljs$cst$1746$fill_color$$);var $fill_opacity$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill_color_gradient_map__53180__$1$$,$APP.$cljs$cst$1747$fill_opacity$$);
$fill_color_gradient_map__53180__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill_color_gradient_map__53180__$1$$,$APP.$cljs$cst$1748$fill_color_gradient$$);return $fill_color_gradient_map__53180__$1$$!=null?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$cst$1724$gradient$$,$fill_color_gradient_map__53180__$1$$],null):typeof $fill_color$jscomp$1_p__53179$$==="string"&&$fill_opacity$jscomp$1$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($fill_opacity$jscomp$1$$,
1)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$2686$transparent$$,$APP.$cljs$cst$2687$hex$$,$fill_color$jscomp$1_p__53179$$,$APP.$cljs$cst$1734$opacity$$,$fill_opacity$jscomp$1$$],null):typeof $fill_color$jscomp$1_p__53179$$==="string"?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2037$solid$$,$APP.$cljs$cst$2687$hex$$,$fill_color$jscomp$1_p__53179$$,$cljs$cst$2688$map_to$$,$fill_color$jscomp$1_p__53179$$],null):
null};
$app$main$ui$shapes$text$fo_text$retrieve_colors$$=function($colors__$1_shape$jscomp$307$$){var $color_data$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$some_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$text$fo_text$fill__GT_color$$,$APP.$cljs$core$tree_seq$$($APP.$cljs$core$map_QMARK_$$,$APP.$cljs$cst$342$children$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($colors__$1_shape$jscomp$307$$)))),$colors$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$(["#000000"]),
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__53181_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2037$solid$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__53181_SHARP_$$))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2687$hex$$)),$color_data$$),$color_mapping_inverse_vec__53189$$=function(){for(var $G__53203_G__53208_colors__$1$jscomp$1$$=
$colors$jscomp$2$$,$head$jscomp$14_head__$1$jscomp$1$$=$APP.$cljs$core$first$$($color_data$$),$G__53205_G__53210_tail$jscomp$9$$=$APP.$cljs$core$rest$$($color_data$$),$G__53206_G__53211_result$jscomp$234$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){if($head$jscomp$14_head__$1$jscomp$1$$==null)return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__53203_G__53208_colors__$1$jscomp$1$$,$G__53206_G__53211_result$jscomp$234$$],null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2037$solid$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$14_head__$1$jscomp$1$$))){var $G__53204_G__53209_colors$jscomp$inline_5745_next_color$$=$APP.$cljs$core$first$$($G__53205_G__53210_tail$jscomp$9$$);$G__53205_G__53210_tail$jscomp$9$$=$APP.$cljs$core$rest$$($G__53205_G__53210_tail$jscomp$9$$);$G__53206_G__53211_result$jscomp$234$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__53206_G__53211_result$jscomp$234$$,$head$jscomp$14_head__$1$jscomp$1$$);$head$jscomp$14_head__$1$jscomp$1$$=
$G__53204_G__53209_colors$jscomp$inline_5745_next_color$$}else{a:{$G__53204_G__53209_colors$jscomp$inline_5745_next_color$$=$G__53203_G__53208_colors__$1$jscomp$1$$;for(var $current_rgb$jscomp$inline_5746_r$jscomp$inline_12123$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,0,0],null);;){var $current_hex$jscomp$inline_5747_g$jscomp$inline_12124$$=$APP.$app$common$types$color$rgb__GT_hex$$($current_rgb$jscomp$inline_5746_r$jscomp$inline_12123$$);if($APP.$cljs$core$contains_QMARK_$$($G__53204_G__53209_colors$jscomp$inline_5745_next_color$$,
$current_hex$jscomp$inline_5747_g$jscomp$inline_12124$$)){var $b$jscomp$inline_12125_p__45511$jscomp$inline_12122$$=$current_rgb$jscomp$inline_5746_r$jscomp$inline_12123$$;$current_rgb$jscomp$inline_5746_r$jscomp$inline_12123$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_12125_p__45511$jscomp$inline_12122$$,0,null);$current_hex$jscomp$inline_5747_g$jscomp$inline_12124$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_12125_p__45511$jscomp$inline_12122$$,
1,null);$b$jscomp$inline_12125_p__45511$jscomp$inline_12122$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_12125_p__45511$jscomp$inline_12122$$,2,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(255,$current_rgb$jscomp$inline_5746_r$jscomp$inline_12123$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(255,$current_hex$jscomp$inline_5747_g$jscomp$inline_12124$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(255,$b$jscomp$inline_12125_p__45511$jscomp$inline_12122$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("cannot get next color",
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1743$r$$,$current_rgb$jscomp$inline_5746_r$jscomp$inline_12123$$,$APP.$cljs$cst$1744$g$$,$current_hex$jscomp$inline_5747_g$jscomp$inline_12124$$,$APP.$cljs$cst$1520$b$$,$b$jscomp$inline_12125_p__45511$jscomp$inline_12122$$],null));$current_rgb$jscomp$inline_5746_r$jscomp$inline_12123$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(255,$current_hex$jscomp$inline_5747_g$jscomp$inline_12124$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(255,
$b$jscomp$inline_12125_p__45511$jscomp$inline_12122$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$current_rgb$jscomp$inline_5746_r$jscomp$inline_12123$$+1,0,0],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(255,$b$jscomp$inline_12125_p__45511$jscomp$inline_12122$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$current_rgb$jscomp$inline_5746_r$jscomp$inline_12123$$,$current_hex$jscomp$inline_5747_g$jscomp$inline_12124$$+
1,0],null):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$current_rgb$jscomp$inline_5746_r$jscomp$inline_12123$$,$current_hex$jscomp$inline_5747_g$jscomp$inline_12124$$,$b$jscomp$inline_12125_p__45511$jscomp$inline_12122$$+1],null)}else{$G__53204_G__53209_colors$jscomp$inline_5745_next_color$$=$current_hex$jscomp$inline_5747_g$jscomp$inline_12124$$;break a}}$G__53204_G__53209_colors$jscomp$inline_5745_next_color$$=void 0}$head$jscomp$14_head__$1$jscomp$1$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($head$jscomp$14_head__$1$jscomp$1$$,$cljs$cst$2688$map_to$$,$G__53204_G__53209_colors$jscomp$inline_5745_next_color$$);$G__53203_G__53208_colors__$1$jscomp$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__53203_G__53208_colors__$1$jscomp$1$$,$G__53204_G__53209_colors$jscomp$inline_5745_next_color$$);$G__53204_G__53209_colors$jscomp$inline_5745_next_color$$=$APP.$cljs$core$first$$($G__53205_G__53210_tail$jscomp$9$$);$G__53205_G__53210_tail$jscomp$9$$=
$APP.$cljs$core$rest$$($G__53205_G__53210_tail$jscomp$9$$);$G__53206_G__53211_result$jscomp$234$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__53206_G__53211_result$jscomp$234$$,$head$jscomp$14_head__$1$jscomp$1$$);$head$jscomp$14_head__$1$jscomp$1$$=$G__53204_G__53209_colors$jscomp$inline_5745_next_color$$}}}();$colors__$1_shape$jscomp$307$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($color_mapping_inverse_vec__53189$$,0,null);var $color_data__$1_color_mapping$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($color_mapping_inverse_vec__53189$$,
1,null);$color_mapping_inverse_vec__53189$$=$APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__53184_SHARP_$$,$p2__53183_SHARP_$$){return $APP.$cljs$core$first$$($p2__53183_SHARP_$$)},$APP.$cljs$core$group_by$$($cljs$cst$2688$map_to$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__53182_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2037$solid$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__53182_SHARP_$$))},
$color_data__$1_color_mapping$$)));$color_data__$1_color_mapping$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__53186_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2687$hex$$.$cljs$core$IFn$_invoke$arity$1$($p1__53186_SHARP_$$),$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($p1__53186_SHARP_$$)],null),$cljs$cst$2688$map_to$$.$cljs$core$IFn$_invoke$arity$1$($p1__53186_SHARP_$$)],null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__53185_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2686$transparent$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__53185_SHARP_$$))},
$color_data__$1_color_mapping$$))),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__53188_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($p1__53188_SHARP_$$),$cljs$cst$2688$map_to$$.$cljs$core$IFn$_invoke$arity$1$($p1__53188_SHARP_$$)],null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__53187_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1724$gradient$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__53187_SHARP_$$))},$color_data__$1_color_mapping$$)))]));return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$colors__$1_shape$jscomp$307$$,$color_data__$1_color_mapping$$,$color_mapping_inverse_vec__53189$$],null)};
$app$common$svg$camelize$$=function($result$jscomp$235_s$jscomp$544$$){if(typeof $result$jscomp$235_s$jscomp$544$$==="string"){var $vendor_QMARK_$$=$APP.$cuerdas$core$starts_with_QMARK_$$($result$jscomp$235_s$jscomp$544$$,"-");$result$jscomp$235_s$jscomp$544$$=$result$jscomp$235_s$jscomp$544$$.replace(":","-").replace(/-./g,$x$jscomp$1147$$=>$x$jscomp$1147$$[1].toUpperCase());return $vendor_QMARK_$$?$APP.$cuerdas$core$capital$$($result$jscomp$235_s$jscomp$544$$):$result$jscomp$235_s$jscomp$544$$}return null};
$app$common$svg$prop_key$$=function($k$jscomp$618_kn$jscomp$2$$){$k$jscomp$618_kn$jscomp$2$$=typeof $k$jscomp$618_kn$jscomp$2$$==="string"?$k$jscomp$618_kn$jscomp$2$$:$k$jscomp$618_kn$jscomp$2$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$($k$jscomp$618_kn$jscomp$2$$):null;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",$k$jscomp$618_kn$jscomp$2$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$k$jscomp$618_kn$jscomp$2$$))return null;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("class",
$k$jscomp$618_kn$jscomp$2$$))return $cljs$cst$2937$className$$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("for",$k$jscomp$618_kn$jscomp$2$$))return $cljs$cst$2938$htmlFor$$;var $kn1$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($k$jscomp$618_kn$jscomp$2$$,0,1);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($kn1$$,$APP.$cuerdas$core$upper$$($kn1$$))?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$capital$$($app$common$svg$camelize$$($k$jscomp$618_kn$jscomp$2$$))):
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($app$common$svg$camelize$$($k$jscomp$618_kn$jscomp$2$$))};
$app$common$svg$parse_style$$=function($style$jscomp$19$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($res$jscomp$35$$,$item$jscomp$55_k$jscomp$619_k__$1$jscomp$21$$){var $v$jscomp$561_vec__52115$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$55_k$jscomp$619_k__$1$jscomp$21$$),":",2);$item$jscomp$55_k$jscomp$619_k__$1$jscomp$21$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$561_vec__52115$$,
0,null);$v$jscomp$561_vec__52115$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$561_vec__52115$$,1,null);$item$jscomp$55_k$jscomp$619_k__$1$jscomp$21$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$55_k$jscomp$619_k__$1$jscomp$21$$);return $APP.$cljs$core$contains_QMARK_$$($res$jscomp$35$$,$item$jscomp$55_k$jscomp$619_k__$1$jscomp$21$$)?$res$jscomp$35$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($res$jscomp$35$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$55_k$jscomp$619_k__$1$jscomp$21$$),
$v$jscomp$561_vec__52115$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($style$jscomp$19$$,";"))};
$app$common$svg$format_styles$$=function($attrs$jscomp$23$$){return $APP.$cljs$core$contains_QMARK_$$($attrs$jscomp$23$$,$APP.$cljs$cst$1904$style$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$23$$,$APP.$cljs$cst$1904$style$$,function($style$jscomp$20$$){return typeof $style$jscomp$20$$==="string"?$app$common$svg$parse_style$$($style$jscomp$20$$):$style$jscomp$20$$}):$attrs$jscomp$23$$};
$app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$01$$=function($attrs$jscomp$24$$){return $app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$02$$($attrs$jscomp$24$$,!0)};
$app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$02$$=function($attrs$jscomp$25$$,$whitelist_QMARK_$$){return $APP.$cljs$core$reduce_kv$$(function($res$jscomp$36$$,$k$jscomp$620_k__$1$jscomp$22$$,$v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$){$k$jscomp$620_k__$1$jscomp$22$$=$app$common$svg$prop_key$$($k$jscomp$620_k__$1$jscomp$22$$);return $k$jscomp$620_k__$1$jscomp$22$$==null||$v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$==null?$res$jscomp$36$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$620_k__$1$jscomp$22$$,
$APP.$cljs$cst$1904$style$$)?($v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$=typeof $v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$==="string"?$app$common$svg$parse_style$$($v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$):$v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$,$v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$=$APP.$cljs$core$not_empty$$($app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$,!1)),$APP.$cljs$core$truth_$$($v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($res$jscomp$36$$,$k$jscomp$620_k__$1$jscomp$22$$,$v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$):$res$jscomp$36$$):$APP.$cljs$core$not$$($whitelist_QMARK_$$)||$APP.$cljs$core$contains_QMARK_$$($app$common$svg$svg_props$$,$k$jscomp$620_k__$1$jscomp$22$$)?($v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$=typeof $v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$==="string"?$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$):
$v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($res$jscomp$36$$,$k$jscomp$620_k__$1$jscomp$22$$,$v$jscomp$562_v__$1$jscomp$28_v__$2$jscomp$3$$)):$res$jscomp$36$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$attrs$jscomp$25$$)};
$app$common$svg$update_attr_ids$$=function($attrs$jscomp$26$$,$replace_fn$$){return $APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$(function $app$common$svg$update_attr_ids_$_update_ids$$($key$jscomp$331$$,$val$jscomp$168$$){return $APP.$cljs$core$map_QMARK_$$($val$jscomp$168$$)?$APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$svg$update_attr_ids_$_update_ids$$,$val$jscomp$168$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$331$$,$APP.$cljs$cst$266$id$$)?
$replace_fn$$.$cljs$core$IFn$_invoke$arity$1$?$replace_fn$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$168$$):$replace_fn$$($val$jscomp$168$$):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$236$$,$it$jscomp$138$$){var $to_replace$$=$replace_fn$$.$cljs$core$IFn$_invoke$arity$1$?$replace_fn$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$138$$):$replace_fn$$($it$jscomp$138$$);return $APP.$cuerdas$core$replace$$($result$jscomp$236$$,["#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$138$$)].join(""),
["#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($to_replace$$)].join(""))},$val$jscomp$168$$,$app$common$svg$extract_ids$$($val$jscomp$168$$))},$attrs$jscomp$26$$)};
$app$common$svg$replace_attrs_ids$$=function($attrs$jscomp$27$$,$ids_mapping$$){return $APP.$cljs$core$empty_QMARK_$$($ids_mapping$$)?$attrs$jscomp$27$$:$app$common$svg$update_attr_ids$$($attrs$jscomp$27$$,function($id$jscomp$298$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($ids_mapping$$,$id$jscomp$298$$,$id$jscomp$298$$)})};
$app$common$svg$generate_id_mapping$$=function($content$jscomp$118$$){return function $app$common$svg$generate_id_mapping_$_visit_node$$($result$jscomp$237_result__$1$jscomp$31$$,$node$jscomp$269$$){var $element_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$269$$,$APP.$cljs$cst$2645$attrs$$),$APP.$cljs$cst$266$id$$);$result$jscomp$237_result__$1$jscomp$31$$=$element_id$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$237_result__$1$jscomp$31$$,
$element_id$$,""+($APP.$app$common$uuid$next$$()??"")):$result$jscomp$237_result__$1$jscomp$31$$;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$svg$generate_id_mapping_$_visit_node$$,$result$jscomp$237_result__$1$jscomp$31$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$269$$))}($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$content$jscomp$118$$)};
$app$common$svg$find_def_references$$=function($defs$jscomp$2$$,$G__52422_G__52427_pending$jscomp$9_pending__$1$jscomp$2_references$jscomp$1$$){var $G__52419_G__52424_result$jscomp$238$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$G__52422_G__52427_pending$jscomp$9_pending__$1$jscomp$2_references$jscomp$1$$),$G__52420_G__52425_checked_QMARK_$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$,$G__52421_G__52426_to_check$$=$APP.$cljs$core$first$$($G__52422_G__52427_pending$jscomp$9_pending__$1$jscomp$2_references$jscomp$1$$);
for($G__52422_G__52427_pending$jscomp$9_pending__$1$jscomp$2_references$jscomp$1$$=$APP.$cljs$core$rest$$($G__52422_G__52427_pending$jscomp$9_pending__$1$jscomp$2_references$jscomp$1$$);;){if($G__52421_G__52426_to_check$$==null)return $G__52419_G__52424_result$jscomp$238$$;if($APP.$cljs$core$truth_$$($G__52420_G__52425_checked_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$G__52420_G__52425_checked_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__52421_G__52426_to_check$$):$G__52420_G__52425_checked_QMARK_$$($G__52421_G__52426_to_check$$)))$G__52421_G__52426_to_check$$=
$APP.$cljs$core$first$$($G__52422_G__52427_pending$jscomp$9_pending__$1$jscomp$2_references$jscomp$1$$),$G__52422_G__52427_pending$jscomp$9_pending__$1$jscomp$2_references$jscomp$1$$=$APP.$cljs$core$rest$$($G__52422_G__52427_pending$jscomp$9_pending__$1$jscomp$2_references$jscomp$1$$);else{var $new_refs_node$jscomp$272$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$2$$,$G__52421_G__52426_to_check$$);$new_refs_node$jscomp$272$$=$app$common$svg$find_node_references$$($new_refs_node$jscomp$272$$);
$G__52422_G__52427_pending$jscomp$9_pending__$1$jscomp$2_references$jscomp$1$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($G__52422_G__52427_pending$jscomp$9_pending__$1$jscomp$2_references$jscomp$1$$,$new_refs_node$jscomp$272$$);$G__52419_G__52424_result$jscomp$238$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($G__52419_G__52424_result$jscomp$238$$,$new_refs_node$jscomp$272$$);$G__52420_G__52425_checked_QMARK_$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__52420_G__52425_checked_QMARK_$$,
$G__52421_G__52426_to_check$$);$G__52421_G__52426_to_check$$=$APP.$cljs$core$first$$($G__52422_G__52427_pending$jscomp$9_pending__$1$jscomp$2_references$jscomp$1$$);$G__52422_G__52427_pending$jscomp$9_pending__$1$jscomp$2_references$jscomp$1$$=$APP.$cljs$core$rest$$($G__52422_G__52427_pending$jscomp$9_pending__$1$jscomp$2_references$jscomp$1$$)}}};
$app$common$svg$svg_transform_matrix$$=function($shape$jscomp$309$$){if($APP.$cljs$core$truth_$$($cljs$cst$1893$svg_viewbox$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$309$$))){var $map__52188_svg_x$$=$cljs$cst$1893$svg_viewbox$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$309$$),$map__52188__$1_scale_y$jscomp$1_svg_height$$=$APP.$cljs$core$__destructure_map$$($map__52188_svg_x$$);$map__52188_svg_x$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52188__$1_scale_y$jscomp$1_svg_height$$,
$APP.$cljs$cst$1510$x$$);var $svg_y$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52188__$1_scale_y$jscomp$1_svg_height$$,$APP.$cljs$cst$1511$y$$),$scale_x$jscomp$1_svg_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52188__$1_scale_y$jscomp$1_svg_height$$,$APP.$cljs$cst$290$width$$);$map__52188__$1_scale_y$jscomp$1_svg_height$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52188__$1_scale_y$jscomp$1_svg_height$$,$APP.$cljs$cst$1522$height$$);var $map__52189_x$jscomp$1148$$=
$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$309$$),$height$jscomp$73_map__52189__$1$$=$APP.$cljs$core$__destructure_map$$($map__52189_x$jscomp$1148$$);$map__52189_x$jscomp$1148$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$73_map__52189__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$386$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$73_map__52189__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$80$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$73_map__52189__$1$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$73_map__52189__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$73_map__52189__$1$$,$APP.$cljs$cst$1522$height$$);$scale_x$jscomp$1_svg_width$$=$width$jscomp$80$$/$scale_x$jscomp$1_svg_width$$;$map__52188__$1_scale_y$jscomp$1_svg_height$$=$height$jscomp$73_map__52189__$1$$/$map__52188__$1_scale_y$jscomp$1_svg_height$$;return $APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$(),
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$309$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$309$$))?$APP.$app$common$geom$shapes$transform_matrix$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$309$$):$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($map__52189_x$jscomp$1148$$-
$scale_x$jscomp$1_svg_width$$*$map__52188_svg_x$$,$y$jscomp$386$$-$map__52188__$1_scale_y$jscomp$1_svg_height$$*$svg_y$$)),$app$common$geom$matrix$scale_matrix$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($scale_x$jscomp$1_svg_width$$,$map__52188__$1_scale_y$jscomp$1_svg_height$$))]))}return $APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()};
$app$common$svg$to_matrix$$=function($JSCompiler_temp_const$jscomp$933_JSCompiler_temp_const$jscomp$936_JSCompiler_temp_const$jscomp$939_type$jscomp$382$$,$JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$){switch($JSCompiler_temp_const$jscomp$933_JSCompiler_temp_const$jscomp$936_JSCompiler_temp_const$jscomp$939_type$jscomp$382$$){case "matrix":return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$matrix$matrix$$,
$JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$);case "translate":$JSCompiler_temp_const$jscomp$933_JSCompiler_temp_const$jscomp$936_JSCompiler_temp_const$jscomp$939_type$jscomp$382$$=$APP.$cljs$core$apply$$;var $JSCompiler_temp_const$jscomp$932_JSCompiler_temp_const$jscomp$935_JSCompiler_temp_const$jscomp$938$$=$JSCompiler_temp_const$jscomp$933_JSCompiler_temp_const$jscomp$936_JSCompiler_temp_const$jscomp$939_type$jscomp$382$$.$cljs$core$IFn$_invoke$arity$2$;
$JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$),1)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$,
0),0)],null):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$,0),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$,
1))],null);return $JSCompiler_temp_const$jscomp$932_JSCompiler_temp_const$jscomp$935_JSCompiler_temp_const$jscomp$938$$.call($JSCompiler_temp_const$jscomp$933_JSCompiler_temp_const$jscomp$936_JSCompiler_temp_const$jscomp$939_type$jscomp$382$$,$APP.$app$common$geom$matrix$translate_matrix$$,$JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$);case "scale":return $JSCompiler_temp_const$jscomp$933_JSCompiler_temp_const$jscomp$936_JSCompiler_temp_const$jscomp$939_type$jscomp$382$$=
$APP.$cljs$core$apply$$,$JSCompiler_temp_const$jscomp$932_JSCompiler_temp_const$jscomp$935_JSCompiler_temp_const$jscomp$938$$=$JSCompiler_temp_const$jscomp$933_JSCompiler_temp_const$jscomp$936_JSCompiler_temp_const$jscomp$939_type$jscomp$382$$.$cljs$core$IFn$_invoke$arity$2$,$JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$),
1)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$,0))],null):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$,
0),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$,1))],null),$JSCompiler_temp_const$jscomp$932_JSCompiler_temp_const$jscomp$935_JSCompiler_temp_const$jscomp$938$$.call($JSCompiler_temp_const$jscomp$933_JSCompiler_temp_const$jscomp$936_JSCompiler_temp_const$jscomp$939_type$jscomp$382$$,$app$common$geom$matrix$scale_matrix$$,$JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$);
case "rotate":return $JSCompiler_temp_const$jscomp$933_JSCompiler_temp_const$jscomp$936_JSCompiler_temp_const$jscomp$939_type$jscomp$382$$=$APP.$cljs$core$apply$$,$JSCompiler_temp_const$jscomp$932_JSCompiler_temp_const$jscomp$935_JSCompiler_temp_const$jscomp$938$$=$JSCompiler_temp_const$jscomp$933_JSCompiler_temp_const$jscomp$936_JSCompiler_temp_const$jscomp$939_type$jscomp$382$$.$cljs$core$IFn$_invoke$arity$2$,$JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$),1)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$,0),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,
0)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$,0),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$,
1),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$,2))],null),$JSCompiler_temp_const$jscomp$932_JSCompiler_temp_const$jscomp$935_JSCompiler_temp_const$jscomp$938$$.call($JSCompiler_temp_const$jscomp$933_JSCompiler_temp_const$jscomp$936_JSCompiler_temp_const$jscomp$939_type$jscomp$382$$,$APP.$app$common$geom$matrix$rotate_matrix$$,$JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$);
case "skewX":return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($app$common$geom$matrix$skew_matrix$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$,0),0],null));case "skewY":return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($app$common$geom$matrix$skew_matrix$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$934_JSCompiler_inline_result$jscomp$937_JSCompiler_inline_result$jscomp$940_params$jscomp$176$$,0)],null));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$933_JSCompiler_temp_const$jscomp$936_JSCompiler_temp_const$jscomp$939_type$jscomp$382$$)].join(""));
}};
$app$common$svg$parse_transform$$=function($transform$jscomp$63$$){return typeof $transform$jscomp$63$$==="string"?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$geom$matrix$multiply$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__52201_params$jscomp$177_params__$1$jscomp$21$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52201_params$jscomp$177_params__$1$jscomp$21$$,0,
null);var $type$jscomp$383$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52201_params$jscomp$177_params__$1$jscomp$21$$,1,null);$p__52201_params$jscomp$177_params__$1$jscomp$21$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52201_params$jscomp$177_params__$1$jscomp$21$$,2,null);$p__52201_params$jscomp$177_params__$1$jscomp$21$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$common$svg$xf_parse_numbers$$,$APP.$cljs$core$re_seq$$($app$common$svg$number_regex$$,
$p__52201_params$jscomp$177_params__$1$jscomp$21$$));return $app$common$svg$to_matrix$$($type$jscomp$383$$,$p__52201_params$jscomp$177_params__$1$jscomp$21$$)},$APP.$cljs$core$re_seq$$($app$common$svg$matrices_regex$$,$transform$jscomp$63$$))):$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()};
$app$common$svg$format_line$$=function($p__52215_y$jscomp$388$$){var $x$jscomp$1150$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52215_y$jscomp$388$$,0,null);$p__52215_y$jscomp$388$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52215_y$jscomp$388$$,1,null);return["L",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$1150$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__52215_y$jscomp$388$$)].join("")};
$app$common$svg$points__GT_path$$=function($head$jscomp$15_points_str_y$jscomp$inline_5759$$){var $other$jscomp$191_points$jscomp$53$$=$APP.$cljs$core$partition$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$parse_double$$,$APP.$cljs$core$first$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$not$$,
$APP.$cljs$core$empty_QMARK_$$,$APP.$cljs$core$first$$),$APP.$cljs$core$re_seq$$($app$common$svg$number_regex$$,$head$jscomp$15_points_str_y$jscomp$inline_5759$$))));$head$jscomp$15_points_str_y$jscomp$inline_5759$$=$APP.$cljs$core$first$$($other$jscomp$191_points$jscomp$53$$);$other$jscomp$191_points$jscomp$53$$=$APP.$cljs$core$rest$$($other$jscomp$191_points$jscomp$53$$);var $x$jscomp$inline_5758$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($head$jscomp$15_points_str_y$jscomp$inline_5759$$,
0,null);$head$jscomp$15_points_str_y$jscomp$inline_5759$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($head$jscomp$15_points_str_y$jscomp$inline_5759$$,1,null);return[["M",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$inline_5758$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$15_points_str_y$jscomp$inline_5759$$)].join(""),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$common$svg$format_line$$,
$other$jscomp$191_points$jscomp$53$$)))].join("")};
$app$common$svg$add_transform$$=function($attrs$jscomp$33$$,$transform$jscomp$64$$){function $append_transform$$($old_transform$$){return $old_transform$$==null||$APP.$cljs$core$empty_QMARK_$$($old_transform$$)?$transform$jscomp$64$$:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($transform$jscomp$64$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($old_transform$$)].join("")}return $APP.$cljs$core$truth_$$($transform$jscomp$64$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$33$$,
$APP.$cljs$cst$1289$transform$$,$append_transform$$):$attrs$jscomp$33$$};
$app$common$svg$inherit_attributes$$=function($attrs__$2$jscomp$1_group_attrs_inheritable_props$$,$map__52261__$1_p__52260$$){$map__52261__$1_p__52260$$=$APP.$cljs$core$__destructure_map$$($map__52261__$1_p__52260$$);var $attrs$jscomp$34_group_attrs__$1_group_attrs__$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52261__$1_p__52260$$,$APP.$cljs$cst$2645$attrs$$);if($APP.$cljs$core$map_QMARK_$$($map__52261__$1_p__52260$$)){var $attrs__$1$jscomp$4$$=$app$common$svg$add_transform$$($app$common$svg$format_styles$$($attrs$jscomp$34_group_attrs__$1_group_attrs__$2$$),
$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($attrs__$2$jscomp$1_group_attrs_inheritable_props$$));$attrs$jscomp$34_group_attrs__$1_group_attrs__$2$$=$app$common$svg$format_styles$$($attrs__$2$jscomp$1_group_attrs_inheritable_props$$);var $inherit_style$$=$APP.$app$common$data$without_keys$$($APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$34_group_attrs__$1_group_attrs__$2$$),$APP.$cljs$core$keys$$($attrs__$1$jscomp$4$$));$attrs__$2$jscomp$1_group_attrs_inheritable_props$$=
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__52256_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$2940$styles$$.$cljs$core$IFn$_invoke$arity$1$($attrs__$1$jscomp$4$$),$p1__52256_SHARP_$$)},$app$common$svg$inheritable_props$$);$attrs$jscomp$34_group_attrs__$1_group_attrs__$2$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$34_group_attrs__$1_group_attrs__$2$$,$APP.$cljs$cst$1904$style$$,$inherit_style$$);$attrs__$2$jscomp$1_group_attrs_inheritable_props$$=
$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$select_keys$$($attrs$jscomp$34_group_attrs__$1_group_attrs__$2$$,$attrs__$2$jscomp$1_group_attrs_inheritable_props$$),$attrs__$1$jscomp$4$$));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__52261__$1_p__52260$$,$APP.$cljs$cst$2645$attrs$$,$attrs__$2$jscomp$1_group_attrs_inheritable_props$$)}return $map__52261__$1_p__52260$$};
$app$common$svg$fix_default_values$$=function($svg_data$$){function $add_defaults$jscomp$1$$($map__52291__$1_p__52290$$){$map__52291__$1_p__52290$$=$APP.$cljs$core$__destructure_map$$($map__52291__$1_p__52290$$);var $tag$jscomp$58$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52291__$1_p__52290$$,$APP.$cljs$cst$78$tag$$),$attrs$jscomp$35_units$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52291__$1_p__52290$$,$APP.$cljs$cst$2645$attrs$$),$prop$jscomp$23$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($app$common$svg$svg_tag_defaults$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$tag$jscomp$58$$,$cljs$cst$2939$units$$],null)),$default_units$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($app$common$svg$svg_tag_defaults$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$tag$jscomp$58$$,$APP.$cljs$cst$205$default$$],null));$attrs$jscomp$35_units$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$35_units$jscomp$1$$,$prop$jscomp$23$$,$default_units$$);var $tag_default$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($app$common$svg$svg_tag_defaults$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$tag$jscomp$58$$,$attrs$jscomp$35_units$jscomp$1$$],null));return $APP.$app$common$data$update_when$$($map__52291__$1_p__52290$$,$APP.$cljs$cst$2645$attrs$$,function($p1__52284_SHARP_$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tag_default$$,
$p1__52284_SHARP_$$]))})}return $app$common$svg$map_nodes$$(function($node$jscomp$280$$){return $APP.$cljs$core$contains_QMARK_$$($app$common$svg$svg_tag_defaults$$,$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$280$$))?$add_defaults$jscomp$1$$($node$jscomp$280$$):$node$jscomp$280$$},$svg_data$$)};$app$common$svg$calculate_ratio$$=function($width$jscomp$81$$,$height$jscomp$74$$){return $APP.$app$common$math$hypot$$($width$jscomp$81$$,$height$jscomp$74$$)/Math.sqrt(2)};
$app$common$svg$fix_percents$$=function($svg_data$jscomp$1$$){function $fix_percent_attr_numeric$$($JSCompiler_temp$jscomp$949_JSCompiler_temp$jscomp$950_JSCompiler_temp$jscomp$951_JSCompiler_temp$jscomp$952_attrs$jscomp$37$$,$key$jscomp$332$$,$JSCompiler_inline_result$jscomp$955_val$jscomp$172_val__$1$jscomp$inline_5779$$){if(!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$332$$,$APP.$cljs$cst$1904$style$$)&&!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$332$$,
$cljs$cst$2878$unicode$$)&&!$APP.$cuerdas$core$starts_with_QMARK_$$($APP.$app$common$data$name$$($key$jscomp$332$$),"data-")&&$APP.$cuerdas$core$ends_with_QMARK_$$($JSCompiler_inline_result$jscomp$955_val$jscomp$172_val__$1$jscomp$inline_5779$$,"%")){var $JSCompiler_temp_const$jscomp$953$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;$JSCompiler_inline_result$jscomp$955_val$jscomp$172_val__$1$jscomp$inline_5779$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($cuerdas$core$rtrim$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$955_val$jscomp$172_val__$1$jscomp$inline_5779$$));
$JSCompiler_inline_result$jscomp$955_val$jscomp$172_val__$1$jscomp$inline_5779$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$955_val$jscomp$172_val__$1$jscomp$inline_5779$$/100);$JSCompiler_temp$jscomp$949_JSCompiler_temp$jscomp$950_JSCompiler_temp$jscomp$951_JSCompiler_temp$jscomp$952_attrs$jscomp$37$$=$JSCompiler_temp_const$jscomp$953$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp$jscomp$949_JSCompiler_temp$jscomp$950_JSCompiler_temp$jscomp$951_JSCompiler_temp$jscomp$952_attrs$jscomp$37$$,
$key$jscomp$332$$,$JSCompiler_inline_result$jscomp$955_val$jscomp$172_val__$1$jscomp$inline_5779$$)}return $JSCompiler_temp$jscomp$949_JSCompiler_temp$jscomp$950_JSCompiler_temp$jscomp$951_JSCompiler_temp$jscomp$952_attrs$jscomp$37$$}function $fix_percent_attrs_viewbox$$($attrs$jscomp$36$$){return $APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$($fix_percent_attr_viewbox$$,$attrs$jscomp$36$$)}function $fix_percent_attr_viewbox$$($JSCompiler_temp$jscomp$947_attr_key$$,$attr_val$$){var $JSCompiler_temp_const$jscomp$946_is_percent_QMARK_$$=
$APP.$cuerdas$core$ends_with_QMARK_$$($attr_val$$,"%"),$is_x_QMARK_$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1897$cx$$,null,$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1523$x1$$,null,$APP.$cljs$cst$1525$x2$$,null],null),null),$is_y_QMARK_$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1524$y1$$,null,$APP.$cljs$cst$1898$cy$$,null,$APP.$cljs$cst$1526$y2$$,
null],null),null),$is_width_QMARK_$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$290$width$$,null],null),null),$is_height_QMARK_$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1522$height$$,null],null),null),$is_other_QMARK_$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1743$r$$,null,$APP.$cljs$cst$1655$stroke_width$$,
null],null),null);if($JSCompiler_temp_const$jscomp$946_is_percent_QMARK_$$){var $attr_num$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($cuerdas$core$rtrim$cljs$0core$0IFn$0_invoke$0arity$02$$($attr_val$$));$JSCompiler_temp_const$jscomp$946_is_percent_QMARK_$$=$APP.$cljs$core$str$$;var $JSCompiler_temp_const$jscomp$945$$=$JSCompiler_temp_const$jscomp$946_is_percent_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$;$JSCompiler_temp$jscomp$947_attr_key$$=$APP.$cljs$core$truth_$$($is_x_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?
$is_x_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$947_attr_key$$):$is_x_QMARK_$$($JSCompiler_temp$jscomp$947_attr_key$$))?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($viewbox$$,$APP.$cljs$cst$1510$x$$)+$fix_length$$($APP.$cljs$cst$290$width$$,$attr_num$$):$APP.$cljs$core$truth_$$($is_y_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$is_y_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$947_attr_key$$):$is_y_QMARK_$$($JSCompiler_temp$jscomp$947_attr_key$$))?
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($viewbox$$,$APP.$cljs$cst$1511$y$$)+$fix_length$$($APP.$cljs$cst$1522$height$$,$attr_num$$):$APP.$cljs$core$truth_$$($is_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$is_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$947_attr_key$$):$is_width_QMARK_$$($JSCompiler_temp$jscomp$947_attr_key$$))?$fix_length$$($APP.$cljs$cst$290$width$$,$attr_num$$):$APP.$cljs$core$truth_$$($is_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?
$is_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$947_attr_key$$):$is_height_QMARK_$$($JSCompiler_temp$jscomp$947_attr_key$$))?$fix_length$$($APP.$cljs$cst$1522$height$$,$attr_num$$):$APP.$cljs$core$truth_$$($is_other_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$is_other_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$947_attr_key$$):$is_other_QMARK_$$($JSCompiler_temp$jscomp$947_attr_key$$))?$fix_length$$($cljs$cst$2941$ratio$$,$attr_num$$):$attr_val$$;return $JSCompiler_temp_const$jscomp$945$$.call($JSCompiler_temp_const$jscomp$946_is_percent_QMARK_$$,
$JSCompiler_temp$jscomp$947_attr_key$$)}return $attr_val$$}function $fix_length$$($prop_length$$,$val$jscomp$169$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($viewbox$$,$prop_length$$)*($val$jscomp$169$$/100)}var $viewbox$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1650$offset_x$$.$cljs$core$IFn$_invoke$arity$1$($svg_data$jscomp$1$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1651$offset_y$$.$cljs$core$IFn$_invoke$arity$1$($svg_data$jscomp$1$$),
$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($svg_data$jscomp$1$$),$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($svg_data$jscomp$1$$),$cljs$cst$2941$ratio$$,$app$common$svg$calculate_ratio$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($svg_data$jscomp$1$$),$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($svg_data$jscomp$1$$))],null);return $app$common$svg$map_nodes$$(function($node$jscomp$281$$){var $units$jscomp$2$$=
function(){var $or__5025__auto__$jscomp$510_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$14$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$281$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2645$attrs$$,$cljs$cst$2789$filterUnits$$],null));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$510_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$14$$))return $or__5025__auto__$jscomp$510_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$14$$;
$or__5025__auto__$jscomp$510_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$14$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$281$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2645$attrs$$,$cljs$cst$2753$gradientUnits$$],null));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$510_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$14$$))return $or__5025__auto__$jscomp$510_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$14$$;
$or__5025__auto__$jscomp$510_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$14$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$281$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2645$attrs$$,$cljs$cst$2776$patternUnits$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$510_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$14$$)?$or__5025__auto__$jscomp$510_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$14$$:
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$281$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2645$attrs$$,$cljs$cst$2942$clipUnits$$],null))}(),$G__52353__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("objectBoundingBox",$units$jscomp$2$$)||$units$jscomp$2$$==null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$281$$,$APP.$cljs$cst$2645$attrs$$,function($p1__52305_SHARP_$$){return $APP.$cljs$core$reduce_kv$$($fix_percent_attr_numeric$$,
$p1__52305_SHARP_$$,$p1__52305_SHARP_$$)}):$node$jscomp$281$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("objectBoundingBox",$units$jscomp$2$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__52353__$1$$,$APP.$cljs$cst$2645$attrs$$,$fix_percent_attrs_viewbox$$):$G__52353__$1$$},$svg_data$jscomp$1$$)};
$app$common$svg$collect_images$$=function($svg_data$jscomp$2$$){return $app$common$svg$reduce_nodes$$(function($JSCompiler_temp$jscomp$956_acc$jscomp$110$$,$attrs$jscomp$38_map__52360__$1_p__52358$$){$attrs$jscomp$38_map__52360__$1_p__52358$$=$APP.$cljs$core$__destructure_map$$($attrs$jscomp$38_map__52360__$1_p__52358$$);var $JSCompiler_temp_const$jscomp$957_tag$jscomp$59$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$38_map__52360__$1_p__52358$$,$APP.$cljs$cst$78$tag$$);$attrs$jscomp$38_map__52360__$1_p__52358$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$38_map__52360__$1_p__52358$$,$APP.$cljs$cst$2645$attrs$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1612$image$$,$JSCompiler_temp_const$jscomp$957_tag$jscomp$59$$)){$JSCompiler_temp_const$jscomp$957_tag$jscomp$59$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$;var $JSCompiler_inline_result$jscomp$959_or__5025__auto__$jscomp$inline_5781$$=$APP.$cljs$cst$2462$href$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$38_map__52360__$1_p__52358$$);
$JSCompiler_inline_result$jscomp$959_or__5025__auto__$jscomp$inline_5781$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$959_or__5025__auto__$jscomp$inline_5781$$)?$JSCompiler_inline_result$jscomp$959_or__5025__auto__$jscomp$inline_5781$$:$cljs$cst$2853$xlink_COLON_href$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$38_map__52360__$1_p__52358$$);$JSCompiler_temp$jscomp$956_acc$jscomp$110$$=$JSCompiler_temp_const$jscomp$957_tag$jscomp$59$$.call($APP.$cljs$core$conj$$,$JSCompiler_temp$jscomp$956_acc$jscomp$110$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2462$href$$,$JSCompiler_inline_result$jscomp$959_or__5025__auto__$jscomp$inline_5781$$,$APP.$cljs$cst$290$width$$,$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$38_map__52360__$1_p__52358$$),0),$APP.$cljs$cst$1522$height$$,$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$38_map__52360__$1_p__52358$$),
0)],null))}return $JSCompiler_temp$jscomp$956_acc$jscomp$110$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$svg_data$jscomp$2$$)};
$app$main$ui$shapes$attrs$calculate_dasharray$$=function($style$jscomp$21$$,$width$jscomp$82$$){var $w_PLUS_5$$=5+$width$jscomp$82$$,$w_PLUS_10$$=10+$width$jscomp$82$$;switch($style$jscomp$21$$ instanceof $APP.$cljs$core$Keyword$$?$style$jscomp$21$$.$fqn$:null){case "mixed":return""+($w_PLUS_5$$??"")+","+($w_PLUS_5$$??"")+","+(1+$width$jscomp$82$$??"")+","+($w_PLUS_5$$??"");case "dotted":return"0,"+($w_PLUS_5$$??"");case "dashed":return""+($w_PLUS_10$$??"")+","+($w_PLUS_10$$??"");default:return""}};
$APP.$app$main$ui$shapes$attrs$get_border_props$$=function($height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$){var $G__52385_G__52385__$1_r1$jscomp$18$$=$app$common$types$shape$radius$all_equal_QMARK_$$($height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$)?$cljs$cst$1877$radius_1$$:$cljs$cst$1878$radius_4$$;$G__52385_G__52385__$1_r1$jscomp$18$$=$G__52385_G__52385__$1_r1$jscomp$18$$ instanceof $APP.$cljs$core$Keyword$$?$G__52385_G__52385__$1_r1$jscomp$18$$.$fqn$:null;switch($G__52385_G__52385__$1_r1$jscomp$18$$){case "radius-1":return $height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$=
$app$common$geom$shapes$corners$shape_corners_1$$($height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$),{rx:$height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$,ry:$height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$};case "radius-4":var $r4$jscomp$4_vec__52388$$=$app$common$geom$shapes$corners$shape_corners_4$$($height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$);$G__52385_G__52385__$1_r1$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r4$jscomp$4_vec__52388$$,0,null);
var $r2$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r4$jscomp$4_vec__52388$$,1,null),$r3$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r4$jscomp$4_vec__52388$$,2,null);$r4$jscomp$4_vec__52388$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r4$jscomp$4_vec__52388$$,3,null);var $x$jscomp$1151$$=$height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$,
$APP.$cljs$cst$1510$x$$),$y$jscomp$389$$=$height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$83$$=$height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$,$APP.$cljs$cst$290$width$$);$height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$=
$height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$,$APP.$cljs$cst$1522$height$$);return{d:"M"+($x$jscomp$1151$$+$G__52385_G__52385__$1_r1$jscomp$18$$??"")+","+($y$jscomp$389$$??"")+" h"+($width$jscomp$83$$-$G__52385_G__52385__$1_r1$jscomp$18$$-$r2$jscomp$16$$)+" a"+($r2$jscomp$16$$??"")+","+($r2$jscomp$16$$??"")+" 0 0 1 "+($r2$jscomp$16$$??"")+","+($r2$jscomp$16$$??"")+" v"+($height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$-
$r2$jscomp$16$$-$r3$jscomp$4$$)+" a"+($r3$jscomp$4$$??"")+","+($r3$jscomp$4$$??"")+" 0 0 1 "+-$r3$jscomp$4$$+","+($r3$jscomp$4$$??"")+" h"+-($width$jscomp$83$$-$r3$jscomp$4$$-$r4$jscomp$4_vec__52388$$)+" a"+($r4$jscomp$4_vec__52388$$??"")+","+($r4$jscomp$4_vec__52388$$??"")+" 0 0 1 "+-$r4$jscomp$4_vec__52388$$+","+-$r4$jscomp$4_vec__52388$$+" v"+-($height$jscomp$75_radius$jscomp$10_shape$jscomp$310$$-$r4$jscomp$4_vec__52388$$-$G__52385_G__52385__$1_r1$jscomp$18$$)+" a"+($G__52385_G__52385__$1_r1$jscomp$18$$??
"")+","+($G__52385_G__52385__$1_r1$jscomp$18$$??"")+" 0 0 1 "+($G__52385_G__52385__$1_r1$jscomp$18$$??"")+","+-$G__52385_G__52385__$1_r1$jscomp$18$$+" z"};default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__52385_G__52385__$1_r1$jscomp$18$$)].join(""));}};
$app$main$ui$shapes$attrs$add_border_props_BANG_$$=function($props$jscomp$101$$,$shape$jscomp$311$$){return $APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$101$$,$APP.$app$main$ui$shapes$attrs$get_border_props$$($shape$jscomp$311$$))};
$app$main$ui$shapes$attrs$add_fill_BANG_$cljs$0core$0IFn$0_invoke$0arity$06$$=function($fill_data$jscomp$1$$,$render_id$jscomp$1$$,$index$jscomp$222_index__$1$jscomp$4$$,$type$jscomp$385$$,$fill_default$$){var $attrs$jscomp$40$$={};$index$jscomp$222_index__$1$jscomp$4$$=$index$jscomp$222_index__$1$jscomp$4$$!=null?"-"+($index$jscomp$222_index__$1$jscomp$4$$??""):"";$APP.$cljs$core$contains_QMARK_$$($fill_data$jscomp$1$$,$APP.$cljs$cst$1632$fill_image$$)?$APP.$app$util$object$set_BANG_$$($attrs$jscomp$40$$,
"fill","url(#fill-image-"+($render_id$jscomp$1$$??"")+")"):$APP.$cljs$cst$1748$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($fill_data$jscomp$1$$)!=null?$APP.$app$util$object$set_BANG_$$($attrs$jscomp$40$$,"fill","url(#"+("fill-color-gradient-"+($render_id$jscomp$1$$??"")+($index$jscomp$222_index__$1$jscomp$4$$??""))+")"):$APP.$cljs$core$contains_QMARK_$$($fill_data$jscomp$1$$,$APP.$cljs$cst$1746$fill_color$$)?$APP.$app$util$object$set_BANG_$$($attrs$jscomp$40$$,"fill",$APP.$cljs$cst$1746$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($fill_data$jscomp$1$$)):
$APP.$app$util$object$set_BANG_$$($attrs$jscomp$40$$,"fill",$fill_default$$);$APP.$cljs$core$contains_QMARK_$$($fill_data$jscomp$1$$,$APP.$cljs$cst$1747$fill_opacity$$)&&$APP.$app$util$object$set_BANG_$$($attrs$jscomp$40$$,"fillOpacity",$APP.$cljs$cst$1747$fill_opacity$$.$cljs$core$IFn$_invoke$arity$1$($fill_data$jscomp$1$$));$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$type$jscomp$385$$)&&$APP.$cljs$cst$1748$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($fill_data$jscomp$1$$)==
null&&$APP.$cljs$cst$1746$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($fill_data$jscomp$1$$)==null&&$APP.$app$util$object$set_BANG_$$($attrs$jscomp$40$$,"fill","black");return $attrs$jscomp$40$$};
$app$main$ui$shapes$attrs$add_stroke_BANG_$$=function($attrs$jscomp$41$$,$data$jscomp$239$$,$render_id$jscomp$2$$,$index$jscomp$223$$,$open_path_QMARK_$jscomp$1$$){var $style$jscomp$22$$=$APP.$cljs$cst$1866$stroke_style$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$239$$,$APP.$cljs$cst$2037$solid$$);if(!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($style$jscomp$22$$,$APP.$cljs$cst$226$none$$)){var $width_52531$$=$APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$239$$,
1),$gradient_52532$$=$APP.$cljs$cst$1741$stroke_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$239$$),$color_52533$$=$APP.$cljs$cst$1739$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$239$$),$opacity_52534$$=$APP.$cljs$cst$1740$stroke_opacity$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$239$$);$APP.$app$util$object$set_BANG_$$($attrs$jscomp$41$$,"strokeWidth",$width_52531$$);$gradient_52532$$!=null?$APP.$app$util$object$set_BANG_$$($attrs$jscomp$41$$,"stroke","url(#stroke-color-gradient-"+
(($render_id$jscomp$2$$??"")+"-"+($index$jscomp$223$$??""))+")"):$color_52533$$!=null&&$APP.$app$util$object$set_BANG_$$($attrs$jscomp$41$$,"stroke",$color_52533$$);$opacity_52534$$!=null&&$APP.$app$util$object$set_BANG_$$($attrs$jscomp$41$$,"strokeOpacity",$opacity_52534$$);$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($style$jscomp$22$$,$APP.$cljs$cst$1538$svg$$)&&$APP.$app$util$object$set_BANG_$$($attrs$jscomp$41$$,"strokeDasharray",$app$main$ui$shapes$attrs$calculate_dasharray$$($style$jscomp$22$$,
$width_52531$$));var $caps_start_52536$$=$APP.$cljs$cst$1865$stroke_cap_start$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$239$$),$caps_end_52537$$=$APP.$cljs$cst$1869$stroke_cap_end$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$239$$),$alignment_52538$$=$APP.$cljs$cst$1868$stroke_alignment$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$239$$);$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$325_and__5023__auto____$1$jscomp$59_and__5023__auto____$2$jscomp$25$$=$APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$stroke_caps_line$$,
$caps_start_52536$$);return $and__5023__auto__$jscomp$325_and__5023__auto____$1$jscomp$59_and__5023__auto____$2$jscomp$25$$?($and__5023__auto__$jscomp$325_and__5023__auto____$1$jscomp$59_and__5023__auto____$2$jscomp$25$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($caps_start_52536$$,$caps_end_52537$$))?($and__5023__auto__$jscomp$325_and__5023__auto____$1$jscomp$59_and__5023__auto____$2$jscomp$25$$=$APP.$cljs$core$truth_$$($open_path_QMARK_$jscomp$1$$)?$open_path_QMARK_$jscomp$1$$:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2041$inner$$,
$alignment_52538$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2042$outer$$,$alignment_52538$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$325_and__5023__auto____$1$jscomp$59_and__5023__auto____$2$jscomp$25$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2040$dotted$$,$style$jscomp$22$$):$and__5023__auto__$jscomp$325_and__5023__auto____$1$jscomp$59_and__5023__auto____$2$jscomp$25$$):$and__5023__auto__$jscomp$325_and__5023__auto____$1$jscomp$59_and__5023__auto____$2$jscomp$25$$:
$and__5023__auto__$jscomp$325_and__5023__auto____$1$jscomp$59_and__5023__auto____$2$jscomp$25$$}())?$APP.$app$util$object$set_BANG_$$($attrs$jscomp$41$$,"strokeLinecap",$APP.$cljs$core$name$$($caps_start_52536$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2040$dotted$$,$style$jscomp$22$$)&&$APP.$app$util$object$set_BANG_$$($attrs$jscomp$41$$,"strokeLinecap","round");$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($open_path_QMARK_$jscomp$1$$)?$open_path_QMARK_$jscomp$1$$:
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2041$inner$$,$alignment_52538$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2042$outer$$,$alignment_52538$$))&&(($APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$stroke_caps_marker$$,$caps_start_52536$$)||$APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$stroke_caps_line$$,$caps_start_52536$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($caps_start_52536$$,$caps_end_52537$$))&&
$APP.$app$util$object$set_BANG_$$($attrs$jscomp$41$$,"markerStart","url(#marker-"+($render_id$jscomp$2$$??"")+"-"+($APP.$cljs$core$name$$($caps_start_52536$$)??"")+")"),($APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$stroke_caps_marker$$,$caps_end_52537$$)||$APP.$cljs$core$contains_QMARK_$$($app$common$types$shape$stroke_caps_line$$,$caps_end_52537$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($caps_start_52536$$,$caps_end_52537$$))&&$APP.$app$util$object$set_BANG_$$($attrs$jscomp$41$$,
"markerEnd","url(#marker-"+($render_id$jscomp$2$$??"")+"-"+($APP.$cljs$core$name$$($caps_end_52537$$)??"")+")"))}return $attrs$jscomp$41$$};
$app$main$ui$shapes$attrs$get_svg_props$$=function($shape$jscomp$312$$,$render_id$jscomp$3$$){var $attrs$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$312$$,$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),$defs$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$312$$,$cljs$cst$2943$svg_defs$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);return $APP.$cljs$core$empty_QMARK_$$($defs$jscomp$3$$)&&$APP.$cljs$core$empty_QMARK_$$($attrs$jscomp$42$$)?
{}:$APP.$app$common$json$__GT_js$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($app$common$svg$update_attr_ids$$($attrs$jscomp$42$$,function($id$jscomp$299$$){return $APP.$cljs$core$contains_QMARK_$$($defs$jscomp$3$$,$id$jscomp$299$$)?""+($render_id$jscomp$3$$??"")+"-"+($id$jscomp$299$$??""):$id$jscomp$299$$}),$APP.$cljs$cst$266$id$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$291$key_fn$$,$APP.$cljs$core$name$$]))};
$app$main$ui$shapes$attrs$add_fill_props_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($props$jscomp$102$$,$shape$jscomp$313$$,$render_id$jscomp$6$$){return $app$main$ui$shapes$attrs$add_fill_props_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($props$jscomp$102$$,$shape$jscomp$313$$,0,$render_id$jscomp$6$$)};
$app$main$ui$shapes$attrs$add_fill_props_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$=function($props$jscomp$103_props__$1$jscomp$11$$,$fill_52557_shape$jscomp$314$$,$JSCompiler_temp$jscomp$556_position$jscomp$52$$,$JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$){var $fill_default_52559_shape_fills$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill_52557_shape$jscomp$314$$,$APP.$cljs$cst$1634$fills$$),$shape_shadow$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill_52557_shape$jscomp$314$$,
$APP.$cljs$cst$1654$shadow$$),$shape_blur$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill_52557_shape$jscomp$314$$,$APP.$cljs$cst$1653$blur$$),$svg_attrs$$=$app$main$ui$shapes$attrs$get_svg_props$$($fill_52557_shape$jscomp$314$$,$JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$),$JSCompiler_temp_const$jscomp$960_svg_styles$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($svg_attrs$$,"style"),$opacity_52554_opacity_52556_shape_type$jscomp$2$$=
$fill_52557_shape$jscomp$314$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill_52557_shape$jscomp$314$$,$APP.$cljs$cst$139$type$$),$style$jscomp$23$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$clone$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props$jscomp$103_props__$1$jscomp$11$$,"style")),$JSCompiler_temp_const$jscomp$960_svg_styles$$),$url_fill_QMARK_$$=$APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($fill_52557_shape$jscomp$314$$)!=
null||$app$common$files$helpers$image_shape_QMARK_$$($fill_52557_shape$jscomp$314$$)||$APP.$cljs$core$count$$($fill_default_52559_shape_fills$$)>1||$APP.$cljs$core$some$$($APP.$cljs$cst$1748$fill_color_gradient$$,$fill_default_52559_shape_fills$$)!=null||$APP.$cljs$core$some$$($APP.$cljs$cst$1632$fill_image$$,$fill_default_52559_shape_fills$$)!=null;$props$jscomp$103_props__$1$jscomp$11$$=$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($fill_52557_shape$jscomp$314$$)?
$props$jscomp$103_props__$1$jscomp$11$$:$APP.$cljs$core$seq$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,$shape_shadow$$))!=null||$shape_blur$$!=null&&!$APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($shape_blur$$)?$APP.$app$util$object$set_BANG_$$($props$jscomp$103_props__$1$jscomp$11$$,"filter","url(#filter-"+($JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$??"")+")"):$props$jscomp$103_props__$1$jscomp$11$$;
if($APP.$cljs$core$contains_QMARK_$$($fill_52557_shape$jscomp$314$$,$APP.$cljs$cst$1890$svg_attrs$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$svg_raw$$,$opacity_52554_opacity_52556_shape_type$jscomp$2$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,$opacity_52554_opacity_52556_shape_type$jscomp$2$$))&&$APP.$cljs$core$empty_QMARK_$$($fill_default_52559_shape_fills$$))$JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill_52557_shape$jscomp$314$$,$cljs$cst$2944$wrapper_styles$$),$JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$,"fill"),"#000000"),$APP.$app$util$object$set_BANG_$$($style$jscomp$23$$,
"fill",$JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$);else if($url_fill_QMARK_$$)$APP.$app$util$object$unset_BANG_$$($style$jscomp$23$$,"fill"),$APP.$app$util$object$unset_BANG_$$($style$jscomp$23$$,"fillOpacity"),$APP.$app$util$object$set_BANG_$$($props$jscomp$103_props__$1$jscomp$11$$,"fill","url(#fill-"+($JSCompiler_temp$jscomp$556_position$jscomp$52$$??"")+"-"+($JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$??
"")+")");else{if($JSCompiler_temp$jscomp$556_position$jscomp$52$$=$JSCompiler_temp_const$jscomp$960_svg_styles$$!=null)$JSCompiler_temp$jscomp$556_position$jscomp$52$$=$JSCompiler_temp_const$jscomp$960_svg_styles$$!=null?Object.hasOwn($JSCompiler_temp_const$jscomp$960_svg_styles$$,"fill"):null;$JSCompiler_temp$jscomp$556_position$jscomp$52$$?($JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp_const$jscomp$960_svg_styles$$,
"fill"),$opacity_52554_opacity_52556_shape_type$jscomp$2$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp_const$jscomp$960_svg_styles$$,"fillOpacity"),$JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$!=null&&$APP.$app$util$object$set_BANG_$$($style$jscomp$23$$,"fill",$JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$),$opacity_52554_opacity_52556_shape_type$jscomp$2$$!=
null&&$APP.$app$util$object$set_BANG_$$($style$jscomp$23$$,"fillOpacity",$opacity_52554_opacity_52556_shape_type$jscomp$2$$)):$svg_attrs$$!=null&&$APP.$cljs$core$empty_QMARK_$$($fill_default_52559_shape_fills$$)?($JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($svg_attrs$$,"fill"),$opacity_52554_opacity_52556_shape_type$jscomp$2$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($svg_attrs$$,
"fillOpacity"),$JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$!=null&&$APP.$app$util$object$set_BANG_$$($style$jscomp$23$$,"fill",$JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$),$opacity_52554_opacity_52556_shape_type$jscomp$2$$!=null&&$APP.$app$util$object$set_BANG_$$($style$jscomp$23$$,"fillOpacity",$opacity_52554_opacity_52556_shape_type$jscomp$2$$)):$APP.$app$common$data$not_empty_QMARK_$$($fill_default_52559_shape_fills$$)?
($fill_52557_shape$jscomp$314$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($fill_default_52559_shape_fills$$,0),$fill_default_52559_shape_fills$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($svg_attrs$$,"fill"),"none"),$JSCompiler_temp_const$jscomp$960_svg_styles$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$,$JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$=
$app$main$ui$shapes$attrs$add_fill_BANG_$cljs$0core$0IFn$0_invoke$0arity$06$$($fill_52557_shape$jscomp$314$$,0,$JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$,$opacity_52554_opacity_52556_shape_type$jscomp$2$$,$fill_default_52559_shape_fills$$),$JSCompiler_temp_const$jscomp$960_svg_styles$$.call($APP.$app$util$object$merge_BANG_$$,$style$jscomp$23$$,$JSCompiler_inline_result$jscomp$962_fill_52552__$1_fill_52553_fill_52555_render_id$jscomp$7_wstyle_52550$$)):
$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($fill_52557_shape$jscomp$314$$)&&$APP.$cljs$core$empty_QMARK_$$($fill_default_52559_shape_fills$$)&&$APP.$app$util$object$set_BANG_$$($style$jscomp$23$$,"fill","none")}return $APP.$app$util$object$set_BANG_$$($APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$103_props__$1$jscomp$11$$,$svg_attrs$$),"style",$style$jscomp$23$$)};
$app$main$broadcast$BroadcastMessage$$=function($id$jscomp$300$$,$type$jscomp$388$$,$data$jscomp$240$$,$__meta$jscomp$33$$,$__extmap$jscomp$33$$,$__hash$jscomp$92$$){this.id=$id$jscomp$300$$;this.type=$type$jscomp$388$$;this.data=$data$jscomp$240$$;this.$__meta$=$__meta$jscomp$33$$;this.$__extmap$=$__extmap$jscomp$33$$;this.$__hash$=$__hash$jscomp$92$$;this.$cljs$lang$protocol_mask$partition0$$=2230748938;this.$cljs$lang$protocol_mask$partition1$$=139264};
$app$main$broadcast$map__GT_BroadcastMessage$$=function($G__52250$$){var $G__52310$jscomp$inline_5792_extmap__5365__auto__$jscomp$33$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__52250$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$142$data$$]));$G__52310$jscomp$inline_5792_extmap__5365__auto__$jscomp$33$$=$APP.$cljs$core$record_QMARK_$$($G__52250$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$G__52310$jscomp$inline_5792_extmap__5365__auto__$jscomp$33$$):$G__52310$jscomp$inline_5792_extmap__5365__auto__$jscomp$33$$;return new $app$main$broadcast$BroadcastMessage$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__52250$$),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__52250$$),$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($G__52250$$),null,$APP.$cljs$core$not_empty$$($G__52310$jscomp$inline_5792_extmap__5365__auto__$jscomp$33$$),null)};
$APP.$app$main$broadcast$emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($id$jscomp$302$$,$type$jscomp$391$$,$data$jscomp$243$$){$APP.$cljs$core$truth_$$($app$main$broadcast$default_channel$$)&&$app$main$broadcast$default_channel$$.postMessage($APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$id$jscomp$302$$,$APP.$cljs$cst$139$type$$,$type$jscomp$391$$,$APP.$cljs$cst$142$data$$,$data$jscomp$243$$],
null),null));return null};$app$main$broadcast$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($type$jscomp$392$$){return function($obj$jscomp$189$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$189$$),$type$jscomp$392$$)}};
$APP.$app$main$broadcast$event$$=function($type$jscomp$394$$,$data$jscomp$244$$){typeof $app$main$broadcast$event_52343$$==="undefined"&&($app$main$broadcast$event_52343$$=function($type$jscomp$395$$,$data$jscomp$245$$,$meta52344$$){this.type=$type$jscomp$395$$;this.data=$data$jscomp$245$$;this.$meta52344$=$meta52344$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$broadcast$event_52343$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$broadcast$event_52343$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2945$app_DOT_main_DOT_broadcast_SLASH_event$$},$app$main$broadcast$event_52343$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52345$$,$meta52344__$1$$){return new $app$main$broadcast$event_52343$$(this.type,this.data,$meta52344__$1$$)},$app$main$broadcast$event_52343$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52344$},$app$main$broadcast$event_52343$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$broadcast$event_52343$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1597_session_id$$,$state$jscomp$146$$){$_$jscomp$1597_session_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$146$$,$APP.$cljs$cst$2332$session_id$$);return $APP.$app$main$broadcast$emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$1597_session_id$$,this.type,this.data)});return new $app$main$broadcast$event_52343$$($type$jscomp$394$$,
$data$jscomp$244$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$main$data$shortcuts$c_mod$$=function($shortcut$$){return $APP.$app$config$check_platform_QMARK_$$()?["command+",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shortcut$$)].join(""):["ctrl+",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shortcut$$)].join("")};$app$main$data$shortcuts$a_mod$$=function($shortcut$jscomp$1$$){return["alt+",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shortcut$jscomp$1$$)].join("")};
$APP.$app$main$data$shortcuts$meta$$=function($key$jscomp$333_key__$1$jscomp$4$$){$key$jscomp$333_key__$1$jscomp$4$$=!$APP.$app$config$check_platform_QMARK_$$()&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$333_key__$1$jscomp$4$$,"+")?'"+"':$key$jscomp$333_key__$1$jscomp$4$$;return[$APP.$app$config$check_platform_QMARK_$$()?"⌘":"Ctrl+",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$333_key__$1$jscomp$4$$)].join("")};
$APP.$app$main$data$shortcuts$shift$$=function($key$jscomp$334$$){return[$APP.$app$config$check_platform_QMARK_$$()?"⇧":"Shift+",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$334$$)].join("")};$app$main$data$shortcuts$alt$$=function($key$jscomp$335$$){return[$APP.$app$config$check_platform_QMARK_$$()?"⌥":"Alt+",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$335$$)].join("")};$app$main$data$shortcuts$meta_shift$$=function($key$jscomp$336$$){return $APP.$app$main$data$shortcuts$shift$$($APP.$app$main$data$shortcuts$meta$$($key$jscomp$336$$))};
$APP.$app$main$data$shortcuts$supr$$=function(){return $APP.$app$config$check_platform_QMARK_$$()?"⌫":"Del"};$APP.$app$main$data$shortcuts$esc$$=function(){return $APP.$app$config$check_platform_QMARK_$$()?"⎋":"Escape"};$app$main$data$shortcuts$enter$$=function(){return $APP.$app$config$check_platform_QMARK_$$()?"⏎":"Enter"};
$APP.$app$main$data$shortcuts$split_sc$$=function($sc$jscomp$5_sc__$1$$){$sc$jscomp$5_sc__$1$$=$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($sc$jscomp$5_sc__$1$$,"++"))?$APP.$cuerdas$core$replace$$($sc$jscomp$5_sc__$1$$,"++","+plus"):$sc$jscomp$5_sc__$1$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($sc$jscomp$5_sc__$1$$),1)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$sc$jscomp$5_sc__$1$$],
null):$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($sc$jscomp$5_sc__$1$$,/\+| /)};
$app$main$data$shortcuts$wrap_cb$$=function($key$jscomp$339$$,$cb$jscomp$11$$){return function($event$jscomp$69$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.shortcuts",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,
["Shortcut",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$339$$)].join("")],null)],null)}),null,"app.main.data.shortcuts",$APP.$cljs$cst$1160$debug$$,!1);$APP.$cljs$core$truth_$$($event$jscomp$69$$.preventDefault)&&$event$jscomp$69$$.preventDefault();return $cb$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$?$cb$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$69$$):$cb$jscomp$11$$($event$jscomp$69$$)}};
$app$main$data$shortcuts$bind_BANG_$$=function($shortcuts$$){return $APP.$cljs$core$run_BANG_$$(function($map__52435_p__52431_type$jscomp$396$$){var $callback$jscomp$82_key$jscomp$340$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52435_p__52431_type$jscomp$396$$,0,null);$map__52435_p__52431_type$jscomp$396$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52435_p__52431_type$jscomp$396$$,1,null);var $map__52435__$1_overwrite$$=$APP.$cljs$core$__destructure_map$$($map__52435_p__52431_type$jscomp$396$$),
$command$jscomp$19_commands$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52435__$1_overwrite$$,$APP.$cljs$cst$1812$command$$),$fn$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52435__$1_overwrite$$,$APP.$cljs$cst$516$fn$$);$map__52435_p__52431_type$jscomp$396$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52435__$1_overwrite$$,$APP.$cljs$cst$139$type$$);$map__52435__$1_overwrite$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52435__$1_overwrite$$,
$APP.$cljs$cst$2947$overwrite$$);$callback$jscomp$82_key$jscomp$340$$=$app$main$data$shortcuts$wrap_cb$$($callback$jscomp$82_key$jscomp$340$$,$fn$jscomp$48$$);$command$jscomp$19_commands$$=$APP.$cljs$core$vector_QMARK_$$($command$jscomp$19_commands$$)?$APP.$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$02$$($command$jscomp$19_commands$$):[$command$jscomp$19_commands$$];return $APP.$cljs$core$truth_$$($map__52435_p__52431_type$jscomp$396$$)?$shadow$js$shim$module$0$0penpot$0mousetrap$0default$$.bind($command$jscomp$19_commands$$,
$callback$jscomp$82_key$jscomp$340$$,$map__52435_p__52431_type$jscomp$396$$,$map__52435__$1_overwrite$$):$shadow$js$shim$module$0$0penpot$0mousetrap$0default$$.bind($command$jscomp$19_commands$$,$callback$jscomp$82_key$jscomp$340$$,void 0,$map__52435__$1_overwrite$$)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__52430_SHARP_$$){return $APP.$cljs$cst$2948$disabled$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__52430_SHARP_$$))},$shortcuts$$))};
$app$main$data$shortcuts$reset_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($shortcuts$jscomp$1$$){$shadow$js$shim$module$0$0penpot$0mousetrap$0default$$.reset();return $app$main$data$shortcuts$bind_BANG_$$($shortcuts$jscomp$1$$)};
$APP.$app$main$data$shortcuts$push_shortcuts$$=function($key$jscomp$341$$,$shortcuts$jscomp$2_shortcuts__$1$$){$shortcuts$jscomp$2_shortcuts__$1$$=$app$main$data$shortcuts$check_shortcuts$$($shortcuts$jscomp$2_shortcuts__$1$$);typeof $app$main$data$shortcuts$push_shortcuts_52443$$==="undefined"&&($app$main$data$shortcuts$push_shortcuts_52443$$=function($key$jscomp$342$$,$shortcuts$jscomp$3$$,$meta52444$$){this.key=$key$jscomp$342$$;this.$shortcuts$=$shortcuts$jscomp$3$$;this.$meta52444$=$meta52444$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$shortcuts$push_shortcuts_52443$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$shortcuts$push_shortcuts_52443$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2949$app_DOT_main_DOT_data_DOT_shortcuts_SLASH_push_shortcuts$$},$app$main$data$shortcuts$push_shortcuts_52443$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52445$$,
$meta52444__$1$$){return new $app$main$data$shortcuts$push_shortcuts_52443$$(this.key,this.$shortcuts$,$meta52444__$1$$)},$app$main$data$shortcuts$push_shortcuts_52443$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52444$},$app$main$data$shortcuts$push_shortcuts_52443$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$shortcuts$push_shortcuts_52443$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1598$$,$state$jscomp$147$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$147$$,
$APP.$cljs$cst$2950$shortcuts$$,$app$main$data$shortcuts$conj_STAR_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key,this.$shortcuts$],null))},$app$main$data$shortcuts$push_shortcuts_52443$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$shortcuts$push_shortcuts_52443$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $app$main$data$shortcuts$reset_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(this.$shortcuts$)});
return new $app$main$data$shortcuts$push_shortcuts_52443$$($key$jscomp$341$$,$shortcuts$jscomp$2_shortcuts__$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$shortcuts$pop_shortcuts$$=function($key$jscomp$343$$){typeof $app$main$data$shortcuts$pop_shortcuts_52467$$==="undefined"&&($app$main$data$shortcuts$pop_shortcuts_52467$$=function($key$jscomp$344$$,$meta52468$$){this.key=$key$jscomp$344$$;this.$meta52468$=$meta52468$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$shortcuts$pop_shortcuts_52467$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$shortcuts$pop_shortcuts_52467$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2951$app_DOT_main_DOT_data_DOT_shortcuts_SLASH_pop_shortcuts$$},$app$main$data$shortcuts$pop_shortcuts_52467$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52469$$,$meta52468__$1$$){return new $app$main$data$shortcuts$pop_shortcuts_52467$$(this.key,$meta52468__$1$$)},$app$main$data$shortcuts$pop_shortcuts_52467$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52468$},
$app$main$data$shortcuts$pop_shortcuts_52467$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$shortcuts$pop_shortcuts_52467$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1600$$,$state$jscomp$148$$){var $self__$jscomp$3424$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$148$$,$APP.$cljs$cst$2950$shortcuts$$,function($shortcuts$jscomp$4$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shortcuts$jscomp$4$$,
$self__$jscomp$3424$$.key)})},$app$main$data$shortcuts$pop_shortcuts_52467$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$shortcuts$pop_shortcuts_52467$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1601_shortcuts$jscomp$5_vec__52473$$,$state$jscomp$149$$){$_$jscomp$1601_shortcuts$jscomp$5_vec__52473$$=$APP.$cljs$core$last$$($APP.$cljs$cst$2950$shortcuts$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$149$$));$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$1601_shortcuts$jscomp$5_vec__52473$$,
0,null);$_$jscomp$1601_shortcuts$jscomp$5_vec__52473$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$1601_shortcuts$jscomp$5_vec__52473$$,1,null);return $app$main$data$shortcuts$reset_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$($_$jscomp$1601_shortcuts$jscomp$5_vec__52473$$)});return new $app$main$data$shortcuts$pop_shortcuts_52467$$($key$jscomp$343$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$util$dom$dnd$set_data_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($dt$jscomp$1_e$jscomp$298$$,$data_type$$,$data$jscomp$248$$){$dt$jscomp$1_e$jscomp$298$$=$dt$jscomp$1_e$jscomp$298$$.dataTransfer;$APP.$cuerdas$core$starts_with_QMARK_$$($data_type$$,"application")||$APP.$cuerdas$core$starts_with_QMARK_$$($data_type$$,"penpot")?$dt$jscomp$1_e$jscomp$298$$.setData($data_type$$,$APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$248$$,null)):$dt$jscomp$1_e$jscomp$298$$.setData($data_type$$,
$data$jscomp$248$$)};$APP.$app$util$dom$dnd$set_drag_image_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($e$jscomp$299$$){var $img$jscomp$inline_5796$$=new Image;$img$jscomp$inline_5796$$.src="data:image/gif;base64,R0lGODlhAQABAIAAAAUEBAAAACwAAAAAAQABAAACAkQBADs\x3d";$APP.$app$util$dom$dnd$set_drag_image_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($e$jscomp$299$$,$img$jscomp$inline_5796$$,0,0)};
$APP.$app$util$dom$dnd$set_drag_image_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$=function($e$jscomp$300$$,$image$jscomp$13$$,$offset_x$jscomp$1$$,$offset_y$jscomp$1$$){$e$jscomp$300$$.dataTransfer.setDragImage($image$jscomp$13$$,$offset_x$jscomp$1$$,$offset_y$jscomp$1$$)};$APP.$app$util$dom$dnd$set_allowed_effect_BANG_$$=function($e$jscomp$301$$){$e$jscomp$301$$.dataTransfer.effectAllowed="move";return $e$jscomp$301$$};$APP.$app$util$dom$dnd$has_type_QMARK_$$=function($e$jscomp$303$$,$data_type$jscomp$1$$){return $e$jscomp$303$$.dataTransfer.types.includes($data_type$jscomp$1$$)};
$APP.$app$util$dom$dnd$from_child_QMARK_$$=function($e$jscomp$304$$){return $e$jscomp$304$$.currentTarget.contains($e$jscomp$304$$.relatedTarget)};
$APP.$app$util$dom$dnd$get_data$cljs$0core$0IFn$0_invoke$0arity$02$$=function($data$jscomp$249_e$jscomp$307$$,$data_type$jscomp$2$$){$data$jscomp$249_e$jscomp$307$$=$data$jscomp$249_e$jscomp$307$$.dataTransfer.getData($data_type$jscomp$2$$);return $data$jscomp$249_e$jscomp$307$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$249_e$jscomp$307$$,"")&&($APP.$cuerdas$core$starts_with_QMARK_$$($data_type$jscomp$2$$,"penpot")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($data_type$jscomp$2$$,
"application/json"))?$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$249_e$jscomp$307$$):$data$jscomp$249_e$jscomp$307$$};
$app$util$dom$dnd$drop_side$$=function($e$jscomp$309_innerHeight$$,$detect_center_QMARK_$$){var $ypos$$=$e$jscomp$309_innerHeight$$.offsetY,$target$jscomp$123_thold$$=$e$jscomp$309_innerHeight$$.currentTarget;$e$jscomp$309_innerHeight$$=$target$jscomp$123_thold$$.firstChild.clientHeight;$target$jscomp$123_thold$$=$target$jscomp$123_thold$$.clientHeight/2;return $APP.$cljs$core$truth_$$($detect_center_QMARK_$$)?$ypos$$<$e$jscomp$309_innerHeight$$*.2?$APP.$cljs$cst$1562$top$$:$ypos$$>$e$jscomp$309_innerHeight$$*
.8?$APP.$cljs$cst$2952$bot$$:$APP.$cljs$cst$1667$center$$:$ypos$$>$target$jscomp$123_thold$$?$APP.$cljs$cst$2952$bot$$:$APP.$cljs$cst$1562$top$$};$app$main$ui$hooks$use_render_id$$=function(){return(0,$APP.$rumext$v2$useMemo$$)(function(){return"render-"+ ++$app$main$ui$hooks$render_id$$},[])};
$APP.$app$main$ui$hooks$use_shortcuts$$=function($key$jscomp$345$$,$shortcuts$jscomp$6$$){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$345$$),$shortcuts$jscomp$6$$],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$push_shortcuts$$($key$jscomp$345$$,$shortcuts$jscomp$6$$));return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$pop_shortcuts$$($key$jscomp$345$$))}})};
$app$main$ui$hooks$cancel_timer$$=function($state$jscomp$152$$){var $timer$$=$cljs$cst$2953$timer$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$152$$);return $APP.$cljs$core$truth_$$($timer$$)?($APP.$beicon$v2$core$_dispose$$($timer$$),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$152$$,$cljs$cst$2953$timer$$)):$state$jscomp$152$$};
$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($map__52603__$1_p__52602$$){function $on_drag_end$$($event$jscomp$76$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$76$$);$global_drag_end$jscomp$1$$.next(null);return $cleanup$$()}function $on_drop_SINGLEQUOTE_$$($event$jscomp$75$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$75$$);var $side$jscomp$1$$=$app$util$dom$dnd$drop_side$$($event$jscomp$75$$,$detect_center_QMARK_$jscomp$1$$),$drop_data$$=
$APP.$app$util$dom$dnd$get_data$cljs$0core$0IFn$0_invoke$0arity$02$$($event$jscomp$75$$,$data_type$jscomp$3$$);$cleanup$$();$global_drag_end$jscomp$1$$.next(null);return $APP.$cljs$core$fn_QMARK_$$($on_drop$$)?$on_drop$$.$cljs$core$IFn$_invoke$arity$3$?$on_drop$$.$cljs$core$IFn$_invoke$arity$3$($side$jscomp$1$$,$drop_data$$,$event$jscomp$75$$):$on_drop$$($side$jscomp$1$$,$drop_data$$,$event$jscomp$75$$):null}function $on_drag_leave$$($event$jscomp$74$$){return $APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($event$jscomp$74$$))?
null:$cleanup$$()}function $on_drag_over$$($event$jscomp$73$$){if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($event$jscomp$73$$,$data_type$jscomp$3$$))){$APP.$app$util$dom$prevent_default$$($event$jscomp$73$$);if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($event$jscomp$73$$)))return null;$APP.$app$util$dom$stop_propagation$$($event$jscomp$73$$);$subscribe_to_drag_end$$();return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$153$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2960$over$$,$app$util$dom$dnd$drop_side$$($event$jscomp$73$$,$detect_center_QMARK_$jscomp$1$$))}return null}function $on_drag_enter$$($event$jscomp$72$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$72$$);if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($event$jscomp$72$$)))return null;$APP.$app$util$dom$stop_propagation$$($event$jscomp$72$$);$subscribe_to_drag_end$$();return $APP.$cljs$core$fn_QMARK_$$($on_hold$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$153$$,
function($state$jscomp$inline_5798_state__$1$jscomp$12$$){$state$jscomp$inline_5798_state__$1$jscomp$12$$=$app$main$ui$hooks$cancel_timer$$($state$jscomp$inline_5798_state__$1$jscomp$12$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$inline_5798_state__$1$jscomp$12$$,$cljs$cst$2953$timer$$,$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(1E3,$on_hold$$))}):null}function $on_drag_start$$($event$jscomp$71$$){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($disabled$jscomp$1$$)?
$disabled$jscomp$1$$:$APP.$cljs$core$not$$($draggable_QMARK_$$)))return $APP.$app$util$dom$stop_propagation$$($event$jscomp$71$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$71$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$71$$);$APP.$app$util$dom$dnd$set_data_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($event$jscomp$71$$,$data_type$jscomp$3$$,$data$jscomp$250$$);$APP.$app$util$dom$dnd$set_drag_image_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($event$jscomp$71$$);$APP.$app$util$dom$dnd$set_allowed_effect_BANG_$$($event$jscomp$71$$);
return $APP.$cljs$core$fn_QMARK_$$($on_drag$$)?$on_drag$$.$cljs$core$IFn$_invoke$arity$1$?$on_drag$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$250$$):$on_drag$$($data$jscomp$250$$):null}function $subscribe_to_drag_end$$(){return $cljs$cst$2961$subscr$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$153$$))==null?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$153$$,function($p1__52597_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__52597_SHARP_$$,
$cljs$cst$2961$subscr$$,$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($global_drag_end$jscomp$1$$,$cleanup$$))}):null}function $cleanup$$(){var $G__52604_52731$$=$cljs$cst$2961$subscr$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$153$$));$G__52604_52731$$!=null&&$APP.$beicon$v2$core$_dispose$$($G__52604_52731$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$153$$,function($state__$1$jscomp$11$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$ui$hooks$cancel_timer$$($state__$1$jscomp$11$$),
$APP.$cljs$cst$2960$over$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$2961$subscr$$]))})}$map__52603__$1_p__52602$$=$APP.$cljs$core$__destructure_map$$($map__52603__$1_p__52602$$);var $data_type$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52603__$1_p__52602$$,$APP.$cljs$cst$2954$data_type$$),$data$jscomp$250$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52603__$1_p__52602$$,$APP.$cljs$cst$142$data$$),$on_drop$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52603__$1_p__52602$$,
$APP.$cljs$cst$2955$on_drop$$),$on_drag$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52603__$1_p__52602$$,$APP.$cljs$cst$2956$on_drag$$),$on_hold$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52603__$1_p__52602$$,$cljs$cst$2957$on_hold$$),$disabled$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52603__$1_p__52602$$,$APP.$cljs$cst$2948$disabled$$),$detect_center_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52603__$1_p__52602$$,
$APP.$cljs$cst$2958$detect_center_QMARK_$$),$draggable_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__52603__$1_p__52602$$,$APP.$cljs$cst$2959$draggable_QMARK_$$,!0),$ref$jscomp$24$$=(0,$APP.$rumext$v2$use_ref$$)(),$state$jscomp$153$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2960$over$$,null,$cljs$cst$2953$timer$$,null,$cljs$cst$2961$subscr$$,null],null)),$global_drag_end$jscomp$1$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$hooks$sortable_ctx$$);
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($data$jscomp$250$$),$APP.$rumext$v2$adapt$$($on_drop$$),$APP.$rumext$v2$adapt$$($draggable_QMARK_$$)],function(){var $dom$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$24$$);$dom$$.setAttribute("draggable",$APP.$cljs$core$truth_$$($draggable_QMARK_$$)?$APP.$cljs$core$not$$($disabled$jscomp$1$$):$draggable_QMARK_$$);$dom$$.addEventListener("dragstart",$on_drag_start$$,!1);$dom$$.addEventListener("dragenter",$on_drag_enter$$,
!1);$dom$$.addEventListener("dragover",$on_drag_over$$,!1);$dom$$.addEventListener("dragleave",$on_drag_leave$$,!1);$dom$$.addEventListener("drop",$on_drop_SINGLEQUOTE_$$,!1);$dom$$.addEventListener("dragend",$on_drag_end$$,!1);return function(){$dom$$.removeEventListener("dragstart",$on_drag_start$$);$dom$$.removeEventListener("dragenter",$on_drag_enter$$);$dom$$.removeEventListener("dragover",$on_drag_over$$);$dom$$.removeEventListener("dragleave",$on_drag_leave$$);$dom$$.removeEventListener("drop",
$on_drop_SINGLEQUOTE_$$);return $dom$$.removeEventListener("dragend",$on_drag_end$$)}});return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$_deref$$($state$jscomp$153$$),$ref$jscomp$24$$],null)};
$APP.$app$main$ui$hooks$use_previous$$=function($value$jscomp$469$$){var $ref$jscomp$25$$=(0,$APP.$rumext$v2$use_ref$$)($value$jscomp$469$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value$jscomp$469$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($ref$jscomp$25$$,$value$jscomp$469$$)});return $APP.$rumext$v2$ref_val$$($ref$jscomp$25$$)};
$APP.$app$main$ui$hooks$use_equal_memo$$=function($val$jscomp$173$$){var $ref$jscomp$28$$=(0,$APP.$rumext$v2$use_ref$$)(null);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($ref$jscomp$28$$),$val$jscomp$173$$)||$APP.$rumext$v2$set_ref_val_BANG_$$($ref$jscomp$28$$,$val$jscomp$173$$);return $APP.$rumext$v2$ref_val$$($ref$jscomp$28$$)};
$APP.$app$main$ui$hooks$use_visible$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($ref$jscomp$29$$){var $map__52681__$1_state$jscomp$157_state__$1$jscomp$13$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$2962$once_QMARK_$$,!0])),$once_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52681__$1_state$jscomp$157_state__$1$jscomp$13$$,$cljs$cst$2962$once_QMARK_$$);$map__52681__$1_state$jscomp$157_state__$1$jscomp$13$$=
(0,$APP.$rumext$v2$useState$$)(!1);var $update_state_BANG_$$=$map__52681__$1_state$jscomp$157_state__$1$jscomp$13$$[1];$map__52681__$1_state$jscomp$157_state__$1$jscomp$13$$=$map__52681__$1_state$jscomp$157_state__$1$jscomp$13$$[0];$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($once_QMARK_$$)],function(){var $node$jscomp$282$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$29$$),$stream$jscomp$25$$=$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$APP.$beicon$v2$core$map$$(function($entry$jscomp$41_intersecting_QMARK___$1$$){var $ratio$jscomp$1$$=$entry$jscomp$41_intersecting_QMARK___$1$$.intersectionRatio;$entry$jscomp$41_intersecting_QMARK___$1$$=$entry$jscomp$41_intersecting_QMARK___$1$$.isIntersecting||$ratio$jscomp$1$$>.5;$entry$jscomp$41_intersecting_QMARK___$1$$===!0&&$once_QMARK_$$===!0&&$APP.$cljs$core$_deref$$($app$main$ui$hooks$intersection_observer$$).unobserve($node$jscomp$282$$);return $entry$jscomp$41_intersecting_QMARK___$1$$},
$APP.$beicon$v2$core$filter$$(function($entry$jscomp$42$$){return $entry$jscomp$42$$.target===$node$jscomp$282$$},$app$main$ui$hooks$intersection_subject$$))),$subs$jscomp$16$$=$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($stream$jscomp$25$$,$update_state_BANG_$$);$APP.$cljs$core$_deref$$($app$main$ui$hooks$intersection_observer$$).observe($node$jscomp$282$$);return function(){$APP.$cljs$core$_deref$$($app$main$ui$hooks$intersection_observer$$).unobserve($node$jscomp$282$$);
return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$16$$)}});return $map__52681__$1_state$jscomp$157_state__$1$jscomp$13$$};
$APP.$app$main$ui$hooks$use_portal_container$cljs$0core$0IFn$0_invoke$0arity$01$$=function($category$jscomp$1$$){var $category__$1$$=$APP.$cljs$core$name$$($category$jscomp$1$$);return $APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($category__$1$$)],function(){var $JSCompiler_inline_result$jscomp$965_body$jscomp$inline_5803$$=$APP.$app$util$globals$document$$.body;var $id$jscomp$inline_5804$$=["portal-container-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($category__$1$$)].join(""),
$container$jscomp$inline_5806_or__5025__auto__$jscomp$inline_5805$$=$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$965_body$jscomp$inline_5803$$,["#",$id$jscomp$inline_5804$$].join(""));$APP.$cljs$core$truth_$$($container$jscomp$inline_5806_or__5025__auto__$jscomp$inline_5805$$)?$JSCompiler_inline_result$jscomp$965_body$jscomp$inline_5803$$=$container$jscomp$inline_5806_or__5025__auto__$jscomp$inline_5805$$:($container$jscomp$inline_5806_or__5025__auto__$jscomp$inline_5805$$=
$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("div"),$APP.$app$util$dom$set_attribute_BANG_$$($container$jscomp$inline_5806_or__5025__auto__$jscomp$inline_5805$$,"id",$id$jscomp$inline_5804$$),$APP.$app$util$dom$append_child_BANG_$$($JSCompiler_inline_result$jscomp$965_body$jscomp$inline_5803$$,$container$jscomp$inline_5806_or__5025__auto__$jscomp$inline_5805$$),$JSCompiler_inline_result$jscomp$965_body$jscomp$inline_5803$$=$container$jscomp$inline_5806_or__5025__auto__$jscomp$inline_5805$$);
return $JSCompiler_inline_result$jscomp$965_body$jscomp$inline_5803$$})};
$app$main$ui$shapes$embed$use_data_uris$$=function($urls$jscomp$2$$){var $embed_QMARK_$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$shapes$embed$context$$),$urls__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($urls$jscomp$2$$),$uri_data$$=(0,$APP.$rumext$v2$use_ref$$)($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$state$jscomp$158$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0);$rumext$v2$use_ssr_effect$$([$APP.$rumext$v2$adapt$$($embed_QMARK_$$),$APP.$rumext$v2$adapt$$($urls__$1$$)],
function(){var $sub$jscomp$15$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($data$jscomp$251$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$251$$,$APP.$rumext$v2$ref_val$$($uri_data$$)))return null;$APP.$rumext$v2$set_ref_val_BANG_$$($uri_data$$,$data$jscomp$251$$);return $APP.$cljs$core$reset_BANG_$$($state$jscomp$158$$,$APP.$cljs$core$inc$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,
function($obs$jscomp$3$$){return $APP.$cljs$core$truth_$$($embed_QMARK_$$)?$APP.$beicon$v2$core$merge_map$$(function($uri$jscomp$73$$){return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$PersistentHashMap$fromArrays$$([$uri$jscomp$73$$],[$uri$jscomp$73$$]))},$app$util$http$fetch_data_uri$$.$cljs$core$IFn$_invoke$arity$2$($uri$jscomp$73$$,!0))},$obs$jscomp$3$$):$APP.$beicon$v2$core$map$$(function($uri$jscomp$74$$){return $APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$uri$jscomp$74$$,
$uri$jscomp$74$$])},$obs$jscomp$3$$)}($APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,$APP.$beicon$v2$core$from$$($urls__$1$$)))));return function(){return $APP.$cljs$core$truth_$$($sub$jscomp$15$$)?$APP.$beicon$v2$core$_dispose$$($sub$jscomp$15$$):null}});return $APP.$rumext$v2$ref_val$$($uri_data$$)};
$app$main$ui$shapes$export$0$touched__GT_str$$=function($val$jscomp$175$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$val$jscomp$175$$))};
$app$main$ui$shapes$export$0$add_factory$$=function($shape$jscomp$315$$){return function(){function $app$main$ui$shapes$export$add_factory_$_add_BANG___3$$($props$jscomp$106$$,$attr$jscomp$24_ns_attr$$,$trfn$$){var $val$jscomp$176_val__$1$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$315$$,$attr$jscomp$24_ns_attr$$);$val$jscomp$176_val__$1$jscomp$12$$=$val$jscomp$176_val__$1$jscomp$12$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$app$common$data$name$$($val$jscomp$176_val__$1$jscomp$12$$):
$val$jscomp$176_val__$1$jscomp$12$$;$attr$jscomp$24_ns_attr$$=$APP.$cuerdas$core$strip_suffix$$(["penpot:",$APP.$app$common$data$name$$($attr$jscomp$24_ns_attr$$)].join(""),"?");return $val$jscomp$176_val__$1$jscomp$12$$!=null?$APP.$app$util$object$set_BANG_$$($props$jscomp$106$$,$attr$jscomp$24_ns_attr$$,$trfn$$.$cljs$core$IFn$_invoke$arity$1$?$trfn$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$176_val__$1$jscomp$12$$):$trfn$$($val$jscomp$176_val__$1$jscomp$12$$)):$props$jscomp$106$$}function $app$main$ui$shapes$export$add_factory_$_add_BANG___2$$($props$jscomp$105$$,
$attr$jscomp$23$$){return $app$main$ui$shapes$export$add_factory_$_add_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($props$jscomp$105$$,$attr$jscomp$23$$,$APP.$cljs$core$str$$)}var $app$main$ui$shapes$export$add_factory_$_add_BANG_$$=null;$app$main$ui$shapes$export$add_factory_$_add_BANG_$$=function($props$jscomp$107$$,$attr$jscomp$25$$,$trfn$jscomp$1$$){switch(arguments.length){case 2:return $app$main$ui$shapes$export$add_factory_$_add_BANG___2$$.call(this,$props$jscomp$107$$,$attr$jscomp$25$$);case 3:return $app$main$ui$shapes$export$add_factory_$_add_BANG___3$$.call(this,
$props$jscomp$107$$,$attr$jscomp$25$$,$trfn$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$main$ui$shapes$export$add_factory_$_add_BANG_$$.$cljs$core$IFn$_invoke$arity$2$=$app$main$ui$shapes$export$add_factory_$_add_BANG___2$$;$app$main$ui$shapes$export$add_factory_$_add_BANG_$$.$cljs$core$IFn$_invoke$arity$3$=$app$main$ui$shapes$export$add_factory_$_add_BANG___3$$;return $app$main$ui$shapes$export$add_factory_$_add_BANG_$$}()};
$app$main$ui$shapes$export$0$add_data$$=function($shape$jscomp$316$$){var $props$jscomp$108$$={},$add_BANG_$$=$app$main$ui$shapes$export$0$add_factory$$($shape$jscomp$316$$),$frame_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$316$$)),$bool_QMARK__group_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$316$$)),
$rect_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1611$rect$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$316$$)),$image_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1612$image$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$316$$)),$text_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$316$$)),
$path_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$316$$)),$mask_QMARK_$$=$bool_QMARK__group_QMARK_$$?$APP.$cljs$cst$1609$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$316$$):$bool_QMARK__group_QMARK_$$;$bool_QMARK__group_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1610$bool$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$316$$));
var $center$jscomp$31$$=$APP.$app$common$geom$shapes$common$shape__GT_center$$($shape$jscomp$316$$),$G__52784$$=function(){var $G__52785$$=function(){var $G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$=$add_BANG_$$($add_BANG_$$($add_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($props$jscomp$108$$,
$APP.$cljs$cst$725$name$$),$APP.$cljs$cst$1623$blocked$$),$APP.$cljs$cst$1620$hidden$$),$APP.$cljs$cst$139$type$$),$APP.$cljs$cst$1866$stroke_style$$),$APP.$cljs$cst$1868$stroke_alignment$$),$APP.$cljs$cst$1874$hide_fill_on_export$$),$APP.$cljs$cst$1289$transform$$),$APP.$cljs$cst$1787$transform_inverse$$),$APP.$cljs$cst$1879$flip_x$$),$APP.$cljs$cst$1880$flip_y$$),$APP.$cljs$cst$1807$proportion$$),$APP.$cljs$cst$1808$proportion_lock$$),$APP.$cljs$cst$1788$rotation$$),"penpot:center-x",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$31$$))),
"penpot:center-y",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$31$$))),$APP.$cljs$cst$1872$constraints_h$$),$APP.$cljs$cst$1871$constraints_v$$),$APP.$cljs$cst$1645$fixed_scroll$$);$G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$=$frame_QMARK_$$?$add_BANG_$$($add_BANG_$$($G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$,
$APP.$cljs$cst$1876$show_content$$),$APP.$cljs$cst$1875$hide_in_viewer$$):$G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$;$G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$=$APP.$cljs$core$truth_$$($frame_QMARK_$$?$APP.$cljs$cst$2964$use_for_thumbnail$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$316$$):$frame_QMARK_$$)?$add_BANG_$$($G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$,
$APP.$cljs$cst$2964$use_for_thumbnail$$):$G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$;$G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$=($rect_QMARK_$$||$image_QMARK_$$||$frame_QMARK_$$)&&$APP.$cljs$cst$1646$r1$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$316$$)!=null?$add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$,
$APP.$cljs$cst$1646$r1$$),$APP.$cljs$cst$1647$r2$$),$APP.$cljs$cst$1648$r3$$),$APP.$cljs$cst$1649$r4$$):$G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$;$G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$=$path_QMARK_$$?$add_BANG_$$($add_BANG_$$($G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$,
$APP.$cljs$cst$1865$stroke_cap_start$$),$APP.$cljs$cst$1869$stroke_cap_end$$):$G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$;return $text_QMARK_$$?$add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($add_BANG_$$($G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$,$APP.$cljs$cst$1510$x$$),$APP.$cljs$cst$1511$y$$),$APP.$cljs$cst$290$width$$),
$APP.$cljs$cst$1522$height$$),$APP.$cljs$cst$1770$grow_type$$),$APP.$cljs$cst$1637$content$$,$APP.$app$common$json$encode$$),$APP.$cljs$cst$1891$position_data$$,$APP.$app$common$json$encode$$):$G__52786_G__52787$jscomp$inline_14837_G__52788$jscomp$inline_14838_G__52789$jscomp$inline_14839_G__52790$jscomp$inline_14840$$}();return $APP.$cljs$core$truth_$$($mask_QMARK_$$)?$APP.$app$util$object$set_BANG_$$($G__52785$$,"penpot:masked-group","true"):$G__52785$$}();return $bool_QMARK__group_QMARK_$$?$add_BANG_$$($G__52784$$,
$APP.$cljs$cst$1888$bool_type$$):$G__52784$$};
$app$main$ui$shapes$export$0$prefix_keys$$=function($m$jscomp$215$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p__52802_v$jscomp$564$$){var $k$jscomp$621$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52802_v$jscomp$564$$,0,null);$p__52802_v$jscomp$564$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52802_v$jscomp$564$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[["penpot:",$APP.$app$common$data$name$$($k$jscomp$621$$)].join(""),$p__52802_v$jscomp$564$$],null)}),$m$jscomp$215$$)};
$app$main$ui$shapes$export$0$export_grid_data$$=function($grids_map__52810__$1_p__52809$$){$grids_map__52810__$1_p__52809$$=$APP.$cljs$core$__destructure_map$$($grids_map__52810__$1_p__52809$$);$grids_map__52810__$1_p__52809$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grids_map__52810__$1_p__52809$$,$APP.$cljs$cst$2050$grids$$);return $APP.$app$common$data$not_empty_QMARK_$$($grids_map__52810__$1_p__52809$$)?(0,$APP.$rumext$v2$create_element$$)("penpot:grids",{},$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$2$$,
$JSCompiler_temp_const$jscomp$10795_map__52812__$1_p__52811$$){$JSCompiler_temp_const$jscomp$10795_map__52812__$1_p__52811$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp_const$jscomp$10795_map__52812__$1_p__52811$$);var $G__52813$jscomp$inline_12131_type$jscomp$397$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$10795_map__52812__$1_p__52811$$,$APP.$cljs$cst$139$type$$),$JSCompiler_inline_result$jscomp$10797_JSCompiler_inline_result$jscomp$inline_12130_display$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$10795_map__52812__$1_p__52811$$,$APP.$cljs$cst$1932$display$$),$params$jscomp$178$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$10795_map__52812__$1_p__52811$$,$APP.$cljs$cst$1430$params$$);$JSCompiler_temp_const$jscomp$10795_map__52812__$1_p__52811$$=$out_arr__44124__auto__$jscomp$2$$.push;var $props$jscomp$inline_12129$$=$APP.$cljs$core$clj__GT_js$$($app$main$ui$shapes$export$0$prefix_keys$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$178$$,
$APP.$cljs$cst$1298$color$$)));$G__52813$jscomp$inline_12131_type$jscomp$397$$=$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($props$jscomp$inline_12129$$,"penpot:color",$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$178$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1298$color$$],null))),"penpot:opacity",$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$178$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1734$opacity$$],null))),"penpot:type",$APP.$app$common$data$name$$($G__52813$jscomp$inline_12131_type$jscomp$397$$));$JSCompiler_inline_result$jscomp$10797_JSCompiler_inline_result$jscomp$inline_12130_display$$=$JSCompiler_inline_result$jscomp$10797_JSCompiler_inline_result$jscomp$inline_12130_display$$!=null?$APP.$app$util$object$set_BANG_$$($G__52813$jscomp$inline_12131_type$jscomp$397$$,
"penpot:display",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10797_JSCompiler_inline_result$jscomp$inline_12130_display$$)):$G__52813$jscomp$inline_12131_type$jscomp$397$$;$JSCompiler_inline_result$jscomp$10797_JSCompiler_inline_result$jscomp$inline_12130_display$$=(0,$APP.$rumext$v2$create_element$$)("penpot:grid",$JSCompiler_inline_result$jscomp$10797_JSCompiler_inline_result$jscomp$inline_12130_display$$);$JSCompiler_temp_const$jscomp$10795_map__52812__$1_p__52811$$.call($out_arr__44124__auto__$jscomp$2$$,
$JSCompiler_inline_result$jscomp$10797_JSCompiler_inline_result$jscomp$inline_12130_display$$);return $out_arr__44124__auto__$jscomp$2$$},[],$grids_map__52810__$1_p__52809$$)):null};
$app$main$ui$shapes$export$0$export_flows$$=function($flows$jscomp$2_map__52815_map__52815__$1_props_52814$$){$flows$jscomp$2_map__52815_map__52815__$1_props_52814$$=$APP.$rumext$v2$util$wrap_props$$($flows$jscomp$2_map__52815_map__52815__$1_props_52814$$);$flows$jscomp$2_map__52815_map__52815__$1_props_52814$$=$APP.$cljs$core$__destructure_map$$($flows$jscomp$2_map__52815_map__52815__$1_props_52814$$);$flows$jscomp$2_map__52815_map__52815__$1_props_52814$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($flows$jscomp$2_map__52815_map__52815__$1_props_52814$$,
$APP.$cljs$cst$2056$flows$$);return(0,$APP.$rumext$v2$create_element$$)("penpot:flows",{},$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$3$$,$id$jscomp$306_p__52816$$){var $map__52817__$1_starting_frame$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$306_p__52816$$);$id$jscomp$306_p__52816$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52817__$1_starting_frame$$,$APP.$cljs$cst$266$id$$);var $name$jscomp$260$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52817__$1_starting_frame$$,
$APP.$cljs$cst$725$name$$);$map__52817__$1_starting_frame$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52817__$1_starting_frame$$,$APP.$cljs$cst$2053$starting_frame$$);$out_arr__44124__auto__$jscomp$3$$.push((0,$APP.$rumext$v2$create_element$$)("penpot:flow",{id:$id$jscomp$306_p__52816$$,key:$id$jscomp$306_p__52816$$,name:$name$jscomp$260$$,"starting-frame":$map__52817__$1_starting_frame$$}));return $out_arr__44124__auto__$jscomp$3$$},[],$APP.$cljs$core$vals$$($flows$jscomp$2_map__52815_map__52815__$1_props_52814$$)))};
$app$main$ui$shapes$export$0$export_guides$$=function($guides$jscomp$1_map__52819_map__52819__$1_props_52818$$){$guides$jscomp$1_map__52819_map__52819__$1_props_52818$$=$APP.$rumext$v2$util$wrap_props$$($guides$jscomp$1_map__52819_map__52819__$1_props_52818$$);$guides$jscomp$1_map__52819_map__52819__$1_props_52818$$=$APP.$cljs$core$__destructure_map$$($guides$jscomp$1_map__52819_map__52819__$1_props_52818$$);$guides$jscomp$1_map__52819_map__52819__$1_props_52818$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($guides$jscomp$1_map__52819_map__52819__$1_props_52818$$,
$APP.$cljs$cst$2057$guides$$);return(0,$APP.$rumext$v2$create_element$$)("penpot:guides",{},$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$4$$,$p__52820_position$jscomp$53$$){var $axis$jscomp$20_map__52821__$1$$=$APP.$cljs$core$__destructure_map$$($p__52820_position$jscomp$53$$);$p__52820_position$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$20_map__52821__$1$$,$APP.$cljs$cst$1676$position$$);var $frame_id$jscomp$31$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$20_map__52821__$1$$,$APP.$cljs$cst$1607$frame_id$$);$axis$jscomp$20_map__52821__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$20_map__52821__$1$$,$APP.$cljs$cst$2054$axis$$);$out_arr__44124__auto__$jscomp$4$$.push((0,$APP.$rumext$v2$create_element$$)("penpot:guide",{position:$p__52820_position$jscomp$53$$,"frame-id":$frame_id$jscomp$31$$,axis:$APP.$app$common$data$name$$($axis$jscomp$20_map__52821__$1$$)}));
return $out_arr__44124__auto__$jscomp$4$$},[],$APP.$cljs$core$vals$$($guides$jscomp$1_map__52819_map__52819__$1_props_52818$$)))};
$APP.$app$main$ui$shapes$export$0$export_page$$=function($id$jscomp$307_props_52822$$){var $guides$jscomp$2_page$jscomp$33$$=$id$jscomp$307_props_52822$$.page;$id$jscomp$307_props_52822$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($guides$jscomp$2_page$jscomp$33$$,$APP.$cljs$cst$266$id$$);var $grids$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($guides$jscomp$2_page$jscomp$33$$,$APP.$cljs$cst$2050$grids$$),$flows$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($guides$jscomp$2_page$jscomp$33$$,
$APP.$cljs$cst$2056$flows$$);$guides$jscomp$2_page$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($guides$jscomp$2_page$jscomp$33$$,$APP.$cljs$cst$2057$guides$$);return(0,$APP.$rumext$v2$create_element$$)("penpot:page",{id:$id$jscomp$307_props_52822$$},$APP.$app$common$data$not_empty_QMARK_$$($grids$jscomp$1$$)?function(){var $grids__$1$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__52823_params$jscomp$179$$){var $type$jscomp$398$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52823_params$jscomp$179$$,
0,null);$p__52823_params$jscomp$179$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52823_params$jscomp$179$$,1,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$type$jscomp$398$$,$APP.$cljs$cst$1430$params$$,$p__52823_params$jscomp$179$$],null)},$grids$jscomp$1$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$export$0$export_grid_data$$,{grids:$grids__$1$$})}():null,$APP.$app$common$data$not_empty_QMARK_$$($flows$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$export$0$export_flows$$,
{flows:$flows$jscomp$3$$}):null,$APP.$app$common$data$not_empty_QMARK_$$($guides$jscomp$2_page$jscomp$33$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$export$0$export_guides$$,{guides:$guides$jscomp$2_page$jscomp$33$$}):null)};
$app$main$ui$shapes$export$0$export_shadow_data$$=function($map__52828__$1_p__52827_shadow__$1$jscomp$6$$){$map__52828__$1_p__52827_shadow__$1$jscomp$6$$=$APP.$cljs$core$__destructure_map$$($map__52828__$1_p__52827_shadow__$1$jscomp$6$$);$map__52828__$1_p__52827_shadow__$1$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52828__$1_p__52827_shadow__$1$jscomp$6$$,$APP.$cljs$cst$1654$shadow$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$5$$,
$p__52829_style$jscomp$24$$){var $map__52830__$1_spread$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($p__52829_style$jscomp$24$$);$p__52829_style$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52830__$1_spread$jscomp$1$$,$APP.$cljs$cst$1904$style$$);var $hidden$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52830__$1_spread$jscomp$1$$,$APP.$cljs$cst$1620$hidden$$),$color$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52830__$1_spread$jscomp$1$$,
$APP.$cljs$cst$1298$color$$),$offset_x$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52830__$1_spread$jscomp$1$$,$APP.$cljs$cst$1650$offset_x$$),$offset_y$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52830__$1_spread$jscomp$1$$,$APP.$cljs$cst$1651$offset_y$$),$blur$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52830__$1_spread$jscomp$1$$,$APP.$cljs$cst$1653$blur$$);$map__52830__$1_spread$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52830__$1_spread$jscomp$1$$,
$APP.$cljs$cst$1652$spread$$);$out_arr__44124__auto__$jscomp$5$$.push((0,$APP.$rumext$v2$create_element$$)("penpot:shadow",{key:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$export$0$internal_counter$$,$APP.$cljs$core$inc$$),"penpot:offset-y":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset_y$jscomp$2$$),"penpot:blur":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($blur$jscomp$1$$),"penpot:shadow-type":$APP.$app$common$data$name$$($p__52829_style$jscomp$24$$),
"penpot:hidden":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hidden$$),"penpot:spread":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__52830__$1_spread$jscomp$1$$),"penpot:color":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$42$$)),"penpot:offset-x":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset_x$jscomp$2$$),"penpot:opacity":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$42$$))}));
return $out_arr__44124__auto__$jscomp$5$$},[],$map__52828__$1_p__52827_shadow__$1$jscomp$6$$)};
$app$main$ui$shapes$export$0$export_exports_data$$=function($exports__$1_map__52836__$1_p__52835$$){$exports__$1_map__52836__$1_p__52835$$=$APP.$cljs$core$__destructure_map$$($exports__$1_map__52836__$1_p__52835$$);$exports__$1_map__52836__$1_p__52835$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($exports__$1_map__52836__$1_p__52835$$,$APP.$cljs$cst$1870$exports$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$6$$,$p__52837_scale$jscomp$19$$){var $map__52838__$1_type$jscomp$400$$=
$APP.$cljs$core$__destructure_map$$($p__52837_scale$jscomp$19$$);$p__52837_scale$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52838__$1_type$jscomp$400$$,$APP.$cljs$cst$1902$scale$$);var $suffix$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52838__$1_type$jscomp$400$$,$APP.$cljs$cst$1371$suffix$$);$map__52838__$1_type$jscomp$400$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52838__$1_type$jscomp$400$$,$APP.$cljs$cst$139$type$$);
$out_arr__44124__auto__$jscomp$6$$.push((0,$APP.$rumext$v2$create_element$$)("penpot:export",{"penpot:type":$APP.$app$common$data$name$$($map__52838__$1_type$jscomp$400$$),key:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$export$0$internal_counter$$,$APP.$cljs$core$inc$$),"penpot:suffix":$suffix$jscomp$18$$,"penpot:scale":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__52837_scale$jscomp$19$$)}));return $out_arr__44124__auto__$jscomp$6$$},[],$exports__$1_map__52836__$1_p__52835$$)};
$app$main$ui$shapes$export$0$str__GT_style$$=function($style_str$$){return typeof $style_str$$==="string"?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__52840_val$jscomp$177$$){var $key$jscomp$348$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52840_val$jscomp$177$$,0,null);$p__52840_val$jscomp$177$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52840_val$jscomp$177$$,
1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$348$$),$APP.$cljs$core$second$$($APP.$cljs$core$first$$($p__52840_val$jscomp$177$$))],null)},$APP.$cljs$core$group_by$$($APP.$cljs$core$first$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__52839_SHARP_$$){return $APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__52839_SHARP_$$,":")},
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$trim$$,$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($style_str$$,";")))))):$style_str$$};
$app$main$ui$shapes$export$0$style__GT_str$$=function($style$jscomp$25$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("; ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__52844_val$jscomp$178$$){var $key$jscomp$349$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52844_val$jscomp$178$$,0,null);$p__52844_val$jscomp$178$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52844_val$jscomp$178$$,1,null);return[$APP.$app$common$data$name$$($key$jscomp$349$$),
":",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__52844_val$jscomp$178$$)].join("")},$style$jscomp$25$$))};
$app$main$ui$shapes$export$0$export_svg_data$$=function($shape$jscomp$318$$){return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$contains_QMARK_$$($shape$jscomp$318$$,$APP.$cljs$cst$1890$svg_attrs$$)?function(){var $svg_transform$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$318$$,$cljs$cst$2965$svg_transform$$),$svg_attrs$jscomp$1$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$name$$,
$APP.$cuerdas$core$kebab$$),$APP.$cljs$core$keys$$($APP.$cljs$cst$1890$svg_attrs$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$318$$)))),$svg_defs$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$name$$,$APP.$cljs$core$keys$$($cljs$cst$2943$svg_defs$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$318$$))));return(0,$APP.$rumext$v2$create_element$$)("penpot:svg-import",{"penpot:svg-viewbox-x":$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$318$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1893$svg_viewbox$$,$APP.$cljs$cst$1510$x$$],null)),"penpot:svg-viewbox-y":$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$318$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1893$svg_viewbox$$,$APP.$cljs$cst$1511$y$$],null)),"penpot:svg-viewbox-width":$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$318$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1893$svg_viewbox$$,$APP.$cljs$cst$290$width$$],null)),"penpot:svg-attrs":$APP.$cljs$core$empty_QMARK_$$($svg_attrs$jscomp$1$$)?null:$svg_attrs$jscomp$1$$,"penpot:svg-defs":$APP.$cljs$core$empty_QMARK_$$($svg_defs$$)?null:$svg_defs$$,"penpot:svg-viewbox-height":$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$318$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$1893$svg_viewbox$$,$APP.$cljs$cst$1522$height$$],null)),"penpot:svg-filter":$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$1890$svg_attrs$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$318$$),$APP.$cljs$cst$2691$filter$$)?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$318$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$cst$2691$filter$$],null)):null,"penpot:svg-transform":$APP.$cljs$core$truth_$$($svg_transform$$)?
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($svg_transform$$):null,"penpot:svg-style":$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$1890$svg_attrs$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$318$$),$APP.$cljs$cst$1904$style$$)?$app$main$ui$shapes$export$0$style__GT_str$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$318$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$cst$1904$style$$],
null))):null},$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$7$$,$def_xml_p__52849$$){var $def_id$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($def_xml_p__52849$$,0,null);$def_xml_p__52849$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($def_xml_p__52849$$,1,null);$out_arr__44124__auto__$jscomp$7$$.push((0,$APP.$rumext$v2$create_element$$)("penpot:svg-def",{"def-id":$def_id$$,key:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$export$0$internal_counter$$,
$APP.$cljs$core$inc$$)},(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$export$0$render_xml$$,{xml:$def_xml_p__52849$$})));return $out_arr__44124__auto__$jscomp$7$$},[],$cljs$cst$2943$svg_defs$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$318$$)))}():null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$318$$),$APP.$cljs$cst$1613$svg_raw$$)?function(){var $shape__$1$jscomp$27$$=$APP.$app$common$data$update_in_when$$($shape$jscomp$318$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$2645$attrs$$,$APP.$cljs$cst$1904$style$$],null),$app$main$ui$shapes$export$0$str__GT_style$$),$props$jscomp$111$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$({},"penpot:x",
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$27$$)),"penpot:y",$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$27$$)),"penpot:width",$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$27$$)),"penpot:height",$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$27$$)),"penpot:tag",$APP.$app$common$data$name$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$27$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$78$tag$$],null)))),$APP.$cljs$core$clj__GT_js$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$27$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$2645$attrs$$],null))));return(0,$APP.$rumext$v2$create_element$$)("penpot:svg-content",$props$jscomp$111$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$8$$,
$leaf$$){$out_arr__44124__auto__$jscomp$8$$.push((0,$APP.$rumext$v2$jsx$$)("penpot:svg-child",{children:$leaf$$},$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$export$0$internal_counter$$,$APP.$cljs$core$inc$$)));return $out_arr__44124__auto__$jscomp$8$$},[],$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$string_QMARK_$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$27$$)))))}():
null]})};
$app$main$ui$shapes$export$0$export_fills_data$$=function($fills$jscomp$12_map__52854__$1_p__52853_temp__5825__auto__$jscomp$156$$){$fills$jscomp$12_map__52854__$1_p__52853_temp__5825__auto__$jscomp$156$$=$APP.$cljs$core$__destructure_map$$($fills$jscomp$12_map__52854__$1_p__52853_temp__5825__auto__$jscomp$156$$);$fills$jscomp$12_map__52854__$1_p__52853_temp__5825__auto__$jscomp$156$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fills$jscomp$12_map__52854__$1_p__52853_temp__5825__auto__$jscomp$156$$,$APP.$cljs$cst$1634$fills$$);
if($fills$jscomp$12_map__52854__$1_p__52853_temp__5825__auto__$jscomp$156$$=$APP.$cljs$core$seq$$($fills$jscomp$12_map__52854__$1_p__52853_temp__5825__auto__$jscomp$156$$)){var $render_id$jscomp$8$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$);return(0,$APP.$rumext$v2$create_element$$)("penpot:fills",{},$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$9$$,$JSCompiler_temp_const$jscomp$969_p__52856$$){var $JSCompiler_inline_result$jscomp$971_index$jscomp$226$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$969_p__52856$$,0,null),$fill$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$969_p__52856$$,1,null);$JSCompiler_temp_const$jscomp$969_p__52856$$=$out_arr__44124__auto__$jscomp$9$$.push;var $fill_image_id$jscomp$inline_5810$$="fill-image-"+($render_id$jscomp$8$$??"")+"-"+($JSCompiler_inline_result$jscomp$971_index$jscomp$226$$??"");$JSCompiler_inline_result$jscomp$971_index$jscomp$226$$=
(0,$APP.$rumext$v2$create_element$$)("penpot:fill",{"penpot:fill-color":$APP.$cljs$cst$1748$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$12$$)!=null?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("url(#%s)",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([["fill-color-gradient-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($render_id$jscomp$8$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$971_index$jscomp$226$$)].join("")])):
$APP.$app$common$data$name$$($APP.$cljs$cst$1746$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$12$$)),key:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$export$0$internal_counter$$,$APP.$cljs$core$inc$$),"penpot:fill-image-id":$APP.$cljs$core$truth_$$($APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$12$$))?$fill_image_id$jscomp$inline_5810$$:null,"penpot:fill-color-ref-file":$APP.$app$common$data$name$$($APP.$cljs$cst$1640$fill_color_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$12$$)),
"penpot:fill-color-ref-id":$APP.$app$common$data$name$$($APP.$cljs$cst$1745$fill_color_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$12$$)),"penpot:fill-opacity":$APP.$app$common$data$name$$($APP.$cljs$cst$1747$fill_opacity$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$12$$))});$JSCompiler_temp_const$jscomp$969_p__52856$$.call($out_arr__44124__auto__$jscomp$9$$,$JSCompiler_inline_result$jscomp$971_index$jscomp$226$$);return $out_arr__44124__auto__$jscomp$9$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($fills$jscomp$12_map__52854__$1_p__52853_temp__5825__auto__$jscomp$156$$)))}return null};
$app$main$ui$shapes$export$0$export_strokes_data$$=function($map__52861__$1_p__52860_strokes$jscomp$3_temp__5825__auto__$jscomp$157$$){$map__52861__$1_p__52860_strokes$jscomp$3_temp__5825__auto__$jscomp$157$$=$APP.$cljs$core$__destructure_map$$($map__52861__$1_p__52860_strokes$jscomp$3_temp__5825__auto__$jscomp$157$$);$map__52861__$1_p__52860_strokes$jscomp$3_temp__5825__auto__$jscomp$157$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52861__$1_p__52860_strokes$jscomp$3_temp__5825__auto__$jscomp$157$$,
$APP.$cljs$cst$1636$strokes$$);if($map__52861__$1_p__52860_strokes$jscomp$3_temp__5825__auto__$jscomp$157$$=$APP.$cljs$core$seq$$($map__52861__$1_p__52860_strokes$jscomp$3_temp__5825__auto__$jscomp$157$$)){var $render_id$jscomp$9$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$);return(0,$APP.$rumext$v2$create_element$$)("penpot:strokes",{},$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$10$$,$JSCompiler_temp_const$jscomp$972_p__52862$$){var $JSCompiler_inline_result$jscomp$974_index$jscomp$227$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$972_p__52862$$,0,null),$stroke$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$972_p__52862$$,1,null);$JSCompiler_temp_const$jscomp$972_p__52862$$=$out_arr__44124__auto__$jscomp$10$$.push;var $stroke_image_id$jscomp$inline_5812$$="stroke-image-"+($render_id$jscomp$9$$??"")+"-"+($JSCompiler_inline_result$jscomp$974_index$jscomp$227$$??"");$JSCompiler_inline_result$jscomp$974_index$jscomp$227$$=
(0,$APP.$rumext$v2$create_element$$)("penpot:stroke",{"penpot:stroke-alignment":$APP.$app$common$data$name$$($APP.$cljs$cst$1868$stroke_alignment$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$5$$)),key:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$export$0$internal_counter$$,$APP.$cljs$core$inc$$),"penpot:stroke-image-id":$APP.$cljs$core$truth_$$($APP.$cljs$cst$1635$stroke_image$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$5$$))?$stroke_image_id$jscomp$inline_5812$$:
null,"penpot:stroke-color":$APP.$cljs$cst$1741$stroke_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$5$$)!=null?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("url(#%s)",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([["stroke-color-gradient-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($render_id$jscomp$9$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$974_index$jscomp$227$$)].join("")])):
$APP.$app$common$data$name$$($APP.$cljs$cst$1739$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$5$$)),"penpot:stroke-opacity":$APP.$app$common$data$name$$($APP.$cljs$cst$1740$stroke_opacity$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$5$$)),"penpot:stroke-width":$APP.$app$common$data$name$$($APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$5$$)),"penpot:stroke-style":$APP.$app$common$data$name$$($APP.$cljs$cst$1866$stroke_style$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$5$$)),
"penpot:stroke-cap-start":$APP.$app$common$data$name$$($APP.$cljs$cst$1865$stroke_cap_start$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$5$$)),"penpot:stroke-color-ref-file":$APP.$app$common$data$name$$($APP.$cljs$cst$1641$stroke_color_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$5$$)),"penpot:stroke-color-ref-id":$APP.$app$common$data$name$$($APP.$cljs$cst$1742$stroke_color_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$5$$)),"penpot:stroke-cap-end":$APP.$app$common$data$name$$($APP.$cljs$cst$1869$stroke_cap_end$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$5$$))});
$JSCompiler_temp_const$jscomp$972_p__52862$$.call($out_arr__44124__auto__$jscomp$10$$,$JSCompiler_inline_result$jscomp$974_index$jscomp$227$$);return $out_arr__44124__auto__$jscomp$10$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($map__52861__$1_p__52860_strokes$jscomp$3_temp__5825__auto__$jscomp$157$$)))}return null};
$app$main$ui$shapes$export$0$export_interactions_data$$=function($interactions$jscomp$8_map__52870__$1_p__52869_temp__5825__auto__$jscomp$158$$){$interactions$jscomp$8_map__52870__$1_p__52869_temp__5825__auto__$jscomp$158$$=$APP.$cljs$core$__destructure_map$$($interactions$jscomp$8_map__52870__$1_p__52869_temp__5825__auto__$jscomp$158$$);$interactions$jscomp$8_map__52870__$1_p__52869_temp__5825__auto__$jscomp$158$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interactions$jscomp$8_map__52870__$1_p__52869_temp__5825__auto__$jscomp$158$$,
$APP.$cljs$cst$2051$interactions$$);return($interactions$jscomp$8_map__52870__$1_p__52869_temp__5825__auto__$jscomp$158$$=$APP.$cljs$core$seq$$($interactions$jscomp$8_map__52870__$1_p__52869_temp__5825__auto__$jscomp$158$$))?(0,$APP.$rumext$v2$create_element$$)("penpot:interactions",{},$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$11$$,$interaction$jscomp$36$$){$out_arr__44124__auto__$jscomp$11$$.push((0,$APP.$rumext$v2$create_element$$)("penpot:interaction",
{"penpot:overlay-position-x":$app$common$data$nilf$$($APP.$cljs$core$get_in$$)($interaction$jscomp$36$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1970$overlay_position$$,$APP.$cljs$cst$1510$x$$],null)),"penpot:preserve-scroll":$app$common$data$nilf$$($APP.$cljs$core$str$$)($APP.$cljs$cst$1968$preserve_scroll$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$36$$)),key:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$export$0$internal_counter$$,
$APP.$cljs$core$inc$$),"penpot:background-overlay":$app$common$data$nilf$$($APP.$cljs$core$str$$)($APP.$cljs$cst$1973$background_overlay$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$36$$)),"penpot:event-type":$APP.$app$common$data$name$$($APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$36$$)),"penpot:overlay-pos-type":$app$common$data$nilf$$($APP.$app$common$data$name$$)($APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$36$$)),
"penpot:url":$APP.$cljs$cst$1975$url$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$36$$),"penpot:destination":$app$common$data$nilf$$($APP.$cljs$core$str$$)($APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$36$$)),"penpot:close-click-outside":$app$common$data$nilf$$($APP.$cljs$core$str$$)($APP.$cljs$cst$1972$close_click_outside$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$36$$)),"penpot:overlay-position-y":$app$common$data$nilf$$($APP.$cljs$core$get_in$$)($interaction$jscomp$36$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1970$overlay_position$$,$APP.$cljs$cst$1511$y$$],null)),"penpot:action-type":$APP.$app$common$data$name$$($APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$36$$)),"penpot:delay":$app$common$data$nilf$$($APP.$cljs$core$str$$)($APP.$cljs$cst$1325$delay$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$36$$))}));return $out_arr__44124__auto__$jscomp$11$$},
[],$interactions$jscomp$8_map__52870__$1_p__52869_temp__5825__auto__$jscomp$158$$)):null};
$app$main$ui$shapes$export$0$export_layout_container_data$$=function($layout_grid_rows_p__52872$$){var $layout_align_content$jscomp$7_map__52873__$1$$=$APP.$cljs$core$__destructure_map$$($layout_grid_rows_p__52872$$);$layout_grid_rows_p__52872$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,$APP.$cljs$cst$1694$layout_grid_rows$$);var $layout_grid_dir$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,
$APP.$cljs$cst$1693$layout_grid_dir$$),$layout_grid_columns$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,$APP.$cljs$cst$1695$layout_grid_columns$$),$layout_gap_type$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,$APP.$cljs$cst$1683$layout_gap_type$$),$layout_padding$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,$APP.$cljs$cst$1686$layout_padding$$),
$layout_wrap_type$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,$APP.$cljs$cst$1684$layout_wrap_type$$),$layout$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,$APP.$cljs$cst$1615$layout$$),$layout_align_items$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,$APP.$cljs$cst$1692$layout_align_items$$),$layout_padding_type$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,$APP.$cljs$cst$1685$layout_padding_type$$),$layout_grid_cells$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,$APP.$cljs$cst$1696$layout_grid_cells$$),$layout_gap$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,$APP.$cljs$cst$1680$layout_gap$$),$layout_justify_content$jscomp$9$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,$APP.$cljs$cst$1689$layout_justify_content$$),$layout_justify_items$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,$APP.$cljs$cst$1690$layout_justify_items$$),$layout_flex_dir$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,$APP.$cljs$cst$1679$layout_flex_dir$$);$layout_align_content$jscomp$7_map__52873__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_align_content$jscomp$7_map__52873__$1$$,$APP.$cljs$cst$1691$layout_align_content$$);return $APP.$cljs$core$truth_$$($layout$jscomp$3$$)?(0,$APP.$rumext$v2$create_element$$)("penpot:layout",{"penpot:layout":$APP.$app$common$data$name$$($layout$jscomp$3$$),"penpot:layout-gap-type":$APP.$app$common$data$name$$($layout_gap_type$$),"penpot:layout-padding-p1":$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$3$$),
"penpot:layout-justify-content":$APP.$app$common$data$name$$($layout_justify_content$jscomp$9$$),"penpot:layout-gap-column":$APP.$cljs$cst$1682$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($layout_gap$jscomp$1$$),"penpot:layout-gap-row":$APP.$cljs$cst$1681$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($layout_gap$jscomp$1$$),"penpot:layout-wrap-type":$APP.$app$common$data$name$$($layout_wrap_type$jscomp$1$$),"penpot:layout-grid-dir":$APP.$app$common$data$name$$($layout_grid_dir$jscomp$1$$),"penpot:layout-padding-p3":$APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$3$$),
"penpot:layout-align-items":$APP.$app$common$data$name$$($layout_align_items$jscomp$10$$),"penpot:layout-justify-items":$APP.$app$common$data$name$$($layout_justify_items$$),"penpot:layout-padding-p4":$APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$3$$),"penpot:layout-align-content":$APP.$app$common$data$name$$($layout_align_content$jscomp$7_map__52873__$1$$),"penpot:layout-padding-p2":$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$3$$),
"penpot:layout-padding-type":$APP.$app$common$data$name$$($layout_padding_type$jscomp$3$$),"penpot:layout-flex-dir":$APP.$app$common$data$name$$($layout_flex_dir$jscomp$3$$)},(0,$APP.$rumext$v2$create_element$$)("penpot:grid-rows",{},$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$12$$,$map__52878_p__52874_type$jscomp$401$$){var $idx$jscomp$78$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52878_p__52874_type$jscomp$401$$,0,null);
$map__52878_p__52874_type$jscomp$401$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52878_p__52874_type$jscomp$401$$,1,null);var $map__52878__$1_value$jscomp$474$$=$APP.$cljs$core$__destructure_map$$($map__52878_p__52874_type$jscomp$401$$);$map__52878_p__52874_type$jscomp$401$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52878__$1_value$jscomp$474$$,$APP.$cljs$cst$139$type$$);$map__52878__$1_value$jscomp$474$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52878__$1_value$jscomp$474$$,
$APP.$cljs$cst$260$value$$);$out_arr__44124__auto__$jscomp$12$$.push((0,$APP.$rumext$v2$create_element$$)("penpot:grid-track",{"penpot:index":$idx$jscomp$78$$,key:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$export$0$internal_counter$$,$APP.$cljs$core$inc$$),"penpot:type":$APP.$app$common$data$name$$($map__52878_p__52874_type$jscomp$401$$),"penpot:value":$map__52878__$1_value$jscomp$474$$}));return $out_arr__44124__auto__$jscomp$12$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($layout_grid_rows_p__52872$$))),
(0,$APP.$rumext$v2$create_element$$)("penpot:grid-columns",{},$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$13$$,$map__52886_p__52882_type$jscomp$402$$){var $idx$jscomp$79$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52886_p__52882_type$jscomp$402$$,0,null);$map__52886_p__52882_type$jscomp$402$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52886_p__52882_type$jscomp$402$$,1,null);var $map__52886__$1_value$jscomp$475$$=
$APP.$cljs$core$__destructure_map$$($map__52886_p__52882_type$jscomp$402$$);$map__52886_p__52882_type$jscomp$402$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52886__$1_value$jscomp$475$$,$APP.$cljs$cst$139$type$$);$map__52886__$1_value$jscomp$475$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52886__$1_value$jscomp$475$$,$APP.$cljs$cst$260$value$$);$out_arr__44124__auto__$jscomp$13$$.push((0,$APP.$rumext$v2$create_element$$)("penpot:grid-track",{"penpot:index":$idx$jscomp$79$$,
key:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$export$0$internal_counter$$,$APP.$cljs$core$inc$$),"penpot:type":$APP.$app$common$data$name$$($map__52886_p__52882_type$jscomp$402$$),"penpot:value":$map__52886__$1_value$jscomp$475$$}));return $out_arr__44124__auto__$jscomp$13$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($layout_grid_columns$$))),(0,$APP.$rumext$v2$create_element$$)("penpot:grid-cells",{},$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$14$$,
$column_span$jscomp$9_map__52891_p__52887$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column_span$jscomp$9_map__52891_p__52887$$,0,null);$column_span$jscomp$9_map__52891_p__52887$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column_span$jscomp$9_map__52891_p__52887$$,1,null);var $map__52891__$1_position$jscomp$54$$=$APP.$cljs$core$__destructure_map$$($column_span$jscomp$9_map__52891_p__52887$$);$column_span$jscomp$9_map__52891_p__52887$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52891__$1_position$jscomp$54$$,
$APP.$cljs$cst$1658$column_span$$);var $align_self$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52891__$1_position$jscomp$54$$,$APP.$cljs$cst$1677$align_self$$),$row_span$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52891__$1_position$jscomp$54$$,$APP.$cljs$cst$1657$row_span$$),$shapes$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52891__$1_position$jscomp$54$$,$APP.$cljs$cst$1614$shapes$$),$row$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52891__$1_position$jscomp$54$$,
$APP.$cljs$cst$1656$row$$),$area_name$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52891__$1_position$jscomp$54$$,$APP.$cljs$cst$1675$area_name$$),$justify_self$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52891__$1_position$jscomp$54$$,$APP.$cljs$cst$1678$justify_self$$),$column$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52891__$1_position$jscomp$54$$,$APP.$cljs$cst$216$column$$),$id$jscomp$308$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52891__$1_position$jscomp$54$$,
$APP.$cljs$cst$266$id$$);$map__52891__$1_position$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52891__$1_position$jscomp$54$$,$APP.$cljs$cst$1676$position$$);$out_arr__44124__auto__$jscomp$14$$.push((0,$APP.$rumext$v2$create_element$$)("penpot:grid-cell",{"penpot:align-self":$APP.$app$common$data$name$$($align_self$$),"penpot:row-span":$row_span$jscomp$9$$,"penpot:shapes":$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$shapes$jscomp$24$$),key:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$export$0$internal_counter$$,
$APP.$cljs$core$inc$$),"penpot:justify-self":$APP.$app$common$data$name$$($justify_self$$),"penpot:position":$APP.$app$common$data$name$$($map__52891__$1_position$jscomp$54$$),"penpot:column":$column$jscomp$25$$,"penpot:id":$id$jscomp$308$$,"penpot:row":$row$jscomp$19$$,"penpot:area-name":$area_name$$,"penpot:column-span":$column_span$jscomp$9_map__52891_p__52887$$}));return $out_arr__44124__auto__$jscomp$14$$},[],$layout_grid_cells$jscomp$2$$))):null};
$app$main$ui$shapes$export$0$export_data$$=function($map__52906_map__52906__$1_props$jscomp$112_props$jscomp$inline_5814_props_52905$$){$map__52906_map__52906__$1_props$jscomp$112_props$jscomp$inline_5814_props_52905$$=$APP.$rumext$v2$util$wrap_props$$($map__52906_map__52906__$1_props$jscomp$112_props$jscomp$inline_5814_props_52905$$);$map__52906_map__52906__$1_props$jscomp$112_props$jscomp$inline_5814_props_52905$$=$APP.$cljs$core$__destructure_map$$($map__52906_map__52906__$1_props$jscomp$112_props$jscomp$inline_5814_props_52905$$);
var $JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52906_map__52906__$1_props$jscomp$112_props$jscomp$inline_5814_props_52905$$,$APP.$cljs$cst$1811$shape$$);$map__52906_map__52906__$1_props$jscomp$112_props$jscomp$inline_5814_props_52905$$=$app$main$ui$shapes$export$0$add_data$$($JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$);var $JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$=
$app$main$ui$shapes$export$0$add_factory$$($JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$);$map__52906_map__52906__$1_props$jscomp$112_props$jscomp$inline_5814_props_52905$$=$JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$($JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$($JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$($JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$($JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$($JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$($JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$($JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$($JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$($JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$($JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$($JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$($map__52906_map__52906__$1_props$jscomp$112_props$jscomp$inline_5814_props_52905$$,
$APP.$cljs$cst$1745$fill_color_ref_id$$),$APP.$cljs$cst$1640$fill_color_ref_file$$),$APP.$cljs$cst$1742$stroke_color_ref_id$$),$APP.$cljs$cst$1641$stroke_color_ref_file$$),$APP.$cljs$cst$1756$typography_ref_id$$),$APP.$cljs$cst$1642$typography_ref_file$$),$APP.$cljs$cst$1643$component_file$$),$APP.$cljs$cst$1627$component_id$$),$APP.$cljs$cst$2044$component_root$$),$APP.$cljs$cst$2045$main_instance$$),$APP.$cljs$cst$2047$shape_ref$$),$APP.$cljs$cst$1626$touched$$,$app$main$ui$shapes$export$0$touched__GT_str$$);
$JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$=$app$main$ui$shapes$export$0$export_shadow_data$$($JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$);var $JSCompiler_inline_result$jscomp$968_JSCompiler_temp_const$jscomp$10805_map__52833__$1$jscomp$inline_5819_temp__5825__auto__$jscomp$inline_5820_type$jscomp$inline_5822$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$);
$JSCompiler_inline_result$jscomp$968_JSCompiler_temp_const$jscomp$10805_map__52833__$1$jscomp$inline_5819_temp__5825__auto__$jscomp$inline_5820_type$jscomp$inline_5822$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$968_JSCompiler_temp_const$jscomp$10805_map__52833__$1$jscomp$inline_5819_temp__5825__auto__$jscomp$inline_5820_type$jscomp$inline_5822$$,$APP.$cljs$cst$1653$blur$$);if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$968_JSCompiler_temp_const$jscomp$10805_map__52833__$1$jscomp$inline_5819_temp__5825__auto__$jscomp$inline_5820_type$jscomp$inline_5822$$)){var $JSCompiler_temp_const$jscomp$10803_map__52834__$1$jscomp$inline_5821_value$jscomp$inline_5824$$=
$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$968_JSCompiler_temp_const$jscomp$10805_map__52833__$1$jscomp$inline_5819_temp__5825__auto__$jscomp$inline_5820_type$jscomp$inline_5822$$);$JSCompiler_inline_result$jscomp$968_JSCompiler_temp_const$jscomp$10805_map__52833__$1$jscomp$inline_5819_temp__5825__auto__$jscomp$inline_5820_type$jscomp$inline_5822$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$10803_map__52834__$1$jscomp$inline_5821_value$jscomp$inline_5824$$,
$APP.$cljs$cst$139$type$$);var $JSCompiler_temp_const$jscomp$10804_hidden$jscomp$inline_5823$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$10803_map__52834__$1$jscomp$inline_5821_value$jscomp$inline_5824$$,$APP.$cljs$cst$1620$hidden$$);$JSCompiler_temp_const$jscomp$10803_map__52834__$1$jscomp$inline_5821_value$jscomp$inline_5824$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$10803_map__52834__$1$jscomp$inline_5821_value$jscomp$inline_5824$$,
$APP.$cljs$cst$260$value$$);$JSCompiler_inline_result$jscomp$968_JSCompiler_temp_const$jscomp$10805_map__52833__$1$jscomp$inline_5819_temp__5825__auto__$jscomp$inline_5820_type$jscomp$inline_5822$$=(0,$APP.$rumext$v2$create_element$$)("penpot:blur",{"penpot:blur-type":$APP.$app$common$data$name$$($JSCompiler_inline_result$jscomp$968_JSCompiler_temp_const$jscomp$10805_map__52833__$1$jscomp$inline_5819_temp__5825__auto__$jscomp$inline_5820_type$jscomp$inline_5822$$),"penpot:hidden":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10804_hidden$jscomp$inline_5823$$),
"penpot:value":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10803_map__52834__$1$jscomp$inline_5821_value$jscomp$inline_5824$$)})}else $JSCompiler_inline_result$jscomp$968_JSCompiler_temp_const$jscomp$10805_map__52833__$1$jscomp$inline_5819_temp__5825__auto__$jscomp$inline_5820_type$jscomp$inline_5822$$=null;$JSCompiler_temp_const$jscomp$10804_hidden$jscomp$inline_5823$$=$app$main$ui$shapes$export$0$export_exports_data$$($JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$);
$JSCompiler_temp_const$jscomp$10803_map__52834__$1$jscomp$inline_5821_value$jscomp$inline_5824$$=$app$main$ui$shapes$export$0$export_svg_data$$($JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$);var $JSCompiler_temp_const$jscomp$10802$$=$app$main$ui$shapes$export$0$export_interactions_data$$($JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$),$JSCompiler_temp_const$jscomp$10801$$=$app$main$ui$shapes$export$0$export_fills_data$$($JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$),
$JSCompiler_temp_const$jscomp$10800$$=$app$main$ui$shapes$export$0$export_strokes_data$$($JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$),$JSCompiler_temp_const$jscomp$10799$$=$app$main$ui$shapes$export$0$export_grid_data$$($JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$),$JSCompiler_temp_const$jscomp$10798$$=$app$main$ui$shapes$export$0$export_layout_container_data$$($JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$),
$layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$);$JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$,$APP.$cljs$cst$1705$layout_item_min_h$$);var $layout_item_margin$jscomp$inline_12136$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$,$APP.$cljs$cst$1699$layout_item_margin$$),$layout_item_align_self$jscomp$inline_12137$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$,$APP.$cljs$cst$1710$layout_item_align_self$$),$layout_item_max_h$jscomp$inline_12138$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$,
$APP.$cljs$cst$1704$layout_item_max_h$$),$layout_item_z_index$jscomp$inline_12139$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$,$APP.$cljs$cst$1712$layout_item_z_index$$),$layout_item_absolute$jscomp$inline_12140$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$,$APP.$cljs$cst$1711$layout_item_absolute$$),$layout_item_margin_type$jscomp$inline_12141$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$,$APP.$cljs$cst$1698$layout_item_margin_type$$),$layout_item_max_w$jscomp$inline_12142$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$,$APP.$cljs$cst$1706$layout_item_max_w$$),$layout_item_h_sizing$jscomp$inline_12143$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$,
$APP.$cljs$cst$1708$layout_item_h_sizing$$),$layout_item_v_sizing$jscomp$inline_12144$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$);$layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$,$APP.$cljs$cst$1707$layout_item_min_w$$);
$JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($layout_item_margin$jscomp$inline_12136$$)?$layout_item_margin$jscomp$inline_12136$$:$APP.$cljs$core$truth_$$($layout_item_margin_type$jscomp$inline_12141$$)?$layout_item_margin_type$jscomp$inline_12141$$:$APP.$cljs$core$truth_$$($layout_item_h_sizing$jscomp$inline_12143$$)?$layout_item_h_sizing$jscomp$inline_12143$$:$APP.$cljs$core$truth_$$($layout_item_v_sizing$jscomp$inline_12144$$)?
$layout_item_v_sizing$jscomp$inline_12144$$:$APP.$cljs$core$truth_$$($layout_item_max_h$jscomp$inline_12138$$)?$layout_item_max_h$jscomp$inline_12138$$:$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$)?$JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$:$APP.$cljs$core$truth_$$($layout_item_max_w$jscomp$inline_12142$$)?$layout_item_max_w$jscomp$inline_12142$$:$APP.$cljs$core$truth_$$($layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$)?
$layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$:$APP.$cljs$core$truth_$$($layout_item_align_self$jscomp$inline_12137$$)?$layout_item_align_self$jscomp$inline_12137$$:$APP.$cljs$core$truth_$$($layout_item_absolute$jscomp$inline_12140$$)?$layout_item_absolute$jscomp$inline_12140$$:$layout_item_z_index$jscomp$inline_12139$$)?(0,$APP.$rumext$v2$create_element$$)("penpot:layout-item",{"penpot:layout-item-min-w":$layout_item_min_w$jscomp$inline_12145_map__52893__$1$jscomp$inline_12134$$,
"penpot:layout-item-margin-m4":$APP.$cljs$cst$1703$m4$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12136$$),"penpot:layout-item-margin-m2":$APP.$cljs$cst$1701$m2$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12136$$),"penpot:layout-item-h-sizing":$APP.$app$common$data$name$$($layout_item_h_sizing$jscomp$inline_12143$$),"penpot:layout-item-max-w":$layout_item_max_w$jscomp$inline_12142$$,"penpot:layout-item-margin-type":$APP.$app$common$data$name$$($layout_item_margin_type$jscomp$inline_12141$$),
"penpot:layout-item-min-h":$JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$,"penpot:layout-item-margin-m3":$APP.$cljs$cst$1702$m3$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12136$$),"penpot:layout-item-absolute":$layout_item_absolute$jscomp$inline_12140$$,"penpot:layout-item-z-index":$layout_item_z_index$jscomp$inline_12139$$,"penpot:layout-item-v-sizing":$APP.$app$common$data$name$$($layout_item_v_sizing$jscomp$inline_12144$$),
"penpot:layout-item-max-h":$layout_item_max_h$jscomp$inline_12138$$,"penpot:layout-item-margin-m1":$APP.$cljs$cst$1700$m1$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12136$$),"penpot:layout-item-align-self":$APP.$app$common$data$name$$($layout_item_align_self$jscomp$inline_12137$$)}):null;return(0,$APP.$rumext$v2$create_element$$)("penpot:shape",$map__52906_map__52906__$1_props$jscomp$112_props$jscomp$inline_5814_props_52905$$,$JSCompiler_temp_const$jscomp$967_add_BANG_$jscomp$inline_5816$$,
$JSCompiler_inline_result$jscomp$968_JSCompiler_temp_const$jscomp$10805_map__52833__$1$jscomp$inline_5819_temp__5825__auto__$jscomp$inline_5820_type$jscomp$inline_5822$$,$JSCompiler_temp_const$jscomp$10804_hidden$jscomp$inline_5823$$,$JSCompiler_temp_const$jscomp$10803_map__52834__$1$jscomp$inline_5821_value$jscomp$inline_5824$$,$JSCompiler_temp_const$jscomp$10802$$,$JSCompiler_temp_const$jscomp$10801$$,$JSCompiler_temp_const$jscomp$10800$$,$JSCompiler_temp_const$jscomp$10799$$,$JSCompiler_temp_const$jscomp$10798$$,
$JSCompiler_inline_result$jscomp$10806_layout_item_min_h$jscomp$inline_12135_shape$jscomp$319$$)};
$app$main$ui$shapes$gradients$add_metadata_BANG_$$=function($props$jscomp$113$$,$gradient$jscomp$9$$){$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($props$jscomp$113$$,"penpot:gradient","true"),"penpot:start-x",$APP.$cljs$cst$1729$start_x$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$9$$)),"penpot:start-y",$APP.$cljs$cst$1730$start_y$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$9$$)),
"penpot:end-x",$APP.$cljs$cst$1731$end_x$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$9$$)),"penpot:end-y",$APP.$cljs$cst$1732$end_y$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$9$$)),"penpot:width",$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$9$$))};
$app$main$ui$shapes$gradients$linear_gradient$$=function($metadata_QMARK__props_52929$$){var $force_transform$$=$metadata_QMARK__props_52929$$["force-transform"],$id$jscomp$309$$=$metadata_QMARK__props_52929$$.id,$gradient$jscomp$10$$=$metadata_QMARK__props_52929$$.gradient,$shape$jscomp$320$$=$metadata_QMARK__props_52929$$.shape,$props$jscomp$114_transform$jscomp$65$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$320$$)],function(){return $APP.$cljs$core$truth_$$($force_transform$$)?
$APP.$app$common$geom$shapes$transform_matrix$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$320$$,null,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(.5,.5)):null});$metadata_QMARK__props_52929$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$shapes$export$0$include_metadata_ctx$$);$props$jscomp$114_transform$jscomp$65$$={id:$id$jscomp$309$$,x1:$APP.$cljs$cst$1729$start_x$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$10$$),y1:$APP.$cljs$cst$1730$start_y$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$10$$),
x2:$APP.$cljs$cst$1731$end_x$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$10$$),y2:$APP.$cljs$cst$1732$end_y$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$10$$),gradientTransform:""+($props$jscomp$114_transform$jscomp$65$$??"")};$metadata_QMARK__props_52929$$&&$app$main$ui$shapes$gradients$add_metadata_BANG_$$($props$jscomp$114_transform$jscomp$65$$,$gradient$jscomp$10$$);return(0,$APP.$rumext$v2$create_element$$)("linearGradient",$props$jscomp$114_transform$jscomp$65$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$15$$,
$map__52938_offset$jscomp$122_p__52934$$){var $index$jscomp$228$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52938_offset$jscomp$122_p__52934$$,0,null);$map__52938_offset$jscomp$122_p__52934$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52938_offset$jscomp$122_p__52934$$,1,null);var $map__52938__$1_opacity$jscomp$15$$=$APP.$cljs$core$__destructure_map$$($map__52938_offset$jscomp$122_p__52934$$);$map__52938_offset$jscomp$122_p__52934$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52938__$1_opacity$jscomp$15$$,
$APP.$cljs$cst$195$offset$$);var $color$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52938__$1_opacity$jscomp$15$$,$APP.$cljs$cst$1298$color$$);$map__52938__$1_opacity$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52938__$1_opacity$jscomp$15$$,$APP.$cljs$cst$1734$opacity$$);$out_arr__44124__auto__$jscomp$15$$.push((0,$APP.$rumext$v2$jsx$$)("stop",{offset:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($map__52938_offset$jscomp$122_p__52934$$,
0),stopColor:$color$jscomp$43$$,stopOpacity:$map__52938__$1_opacity$jscomp$15$$},""+($id$jscomp$309$$??"")+"-stop-"+($index$jscomp$228$$??"")));return $out_arr__44124__auto__$jscomp$15$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$10$$)))))};
$app$main$ui$shapes$gradients$radial_gradient$$=function($metadata_QMARK_$jscomp$1_path_QMARK_$jscomp$1_props_52939$$){var $id$jscomp$310$$=$metadata_QMARK_$jscomp$1_path_QMARK_$jscomp$1_props_52939$$.id,$gradient$jscomp$11$$=$metadata_QMARK_$jscomp$1_path_QMARK_$jscomp$1_props_52939$$.gradient,$selrect$jscomp$31_shape$jscomp$321_transform__$2$$=$metadata_QMARK_$jscomp$1_path_QMARK_$jscomp$1_props_52939$$.shape,$props$jscomp$115_start_x$jscomp$3_transform$jscomp$66_transform_inv$$=($metadata_QMARK_$jscomp$1_path_QMARK_$jscomp$1_props_52939$$=
$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$31_shape$jscomp$321_transform__$2$$))?$selrect$jscomp$31_shape$jscomp$321_transform__$2$$?.transform??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$31_shape$jscomp$321_transform__$2$$,$APP.$cljs$cst$1289$transform$$):null,$transform__$1$jscomp$5$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$115_start_x$jscomp$3_transform$jscomp$66_transform_inv$$,
$app$common$geom$matrix$base$$);$props$jscomp$115_start_x$jscomp$3_transform$jscomp$66_transform_inv$$=$metadata_QMARK_$jscomp$1_path_QMARK_$jscomp$1_props_52939$$?$selrect$jscomp$31_shape$jscomp$321_transform__$2$$?.$transform_inverse$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$31_shape$jscomp$321_transform__$2$$,$APP.$cljs$cst$1787$transform_inverse$$):null;var $transform_inv__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$115_start_x$jscomp$3_transform$jscomp$66_transform_inv$$,
$app$common$geom$matrix$base$$),$bounds$jscomp$12_end_y$jscomp$3_map__52940__$1$$=$APP.$cljs$core$__destructure_map$$($gradient$jscomp$11$$),$gwidth$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$12_end_y$jscomp$3_map__52940__$1$$,$APP.$cljs$cst$290$width$$);$props$jscomp$115_start_x$jscomp$3_transform$jscomp$66_transform_inv$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$12_end_y$jscomp$3_map__52940__$1$$,$APP.$cljs$cst$1729$start_x$$);var $start_y$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$12_end_y$jscomp$3_map__52940__$1$$,$APP.$cljs$cst$1730$start_y$$),$end_x$jscomp$3_gend_pt_gradient_vec$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$12_end_y$jscomp$3_map__52940__$1$$,$APP.$cljs$cst$1731$end_x$$);$bounds$jscomp$12_end_y$jscomp$3_map__52940__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$12_end_y$jscomp$3_map__52940__$1$$,$APP.$cljs$cst$1732$end_y$$);var $gstart_pt$$=
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$115_start_x$jscomp$3_transform$jscomp$66_transform_inv$$,$start_y$jscomp$3$$);$end_x$jscomp$3_gend_pt_gradient_vec$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($end_x$jscomp$3_gend_pt_gradient_vec$$,$bounds$jscomp$12_end_y$jscomp$3_map__52940__$1$$);$end_x$jscomp$3_gend_pt_gradient_vec$$=$APP.$app$common$geom$point$subtract$$($end_x$jscomp$3_gend_pt_gradient_vec$$,$gstart_pt$$);var $angle$jscomp$24$$=
$APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$01$$($end_x$jscomp$3_gend_pt_gradient_vec$$)+90,$points$jscomp$54$$=$selrect$jscomp$31_shape$jscomp$321_transform__$2$$?.points??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$31_shape$jscomp$321_transform__$2$$,$APP.$cljs$cst$1604$points$$);$bounds$jscomp$12_end_y$jscomp$3_map__52940__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($points$jscomp$54$$)],function(){return $APP.$app$common$geom$rect$points__GT_rect$$($points$jscomp$54$$)});
$selrect$jscomp$31_shape$jscomp$321_transform__$2$$=$selrect$jscomp$31_shape$jscomp$321_transform__$2$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$31_shape$jscomp$321_transform__$2$$,$APP.$cljs$cst$1605$selrect$$);var $factor$jscomp$2$$=$metadata_QMARK_$jscomp$1_path_QMARK_$jscomp$1_props_52939$$?($selrect$jscomp$31_shape$jscomp$321_transform__$2$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$31_shape$jscomp$321_transform__$2$$,
$APP.$cljs$cst$1522$height$$))/($bounds$jscomp$12_end_y$jscomp$3_map__52940__$1$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$12_end_y$jscomp$3_map__52940__$1$$,$APP.$cljs$cst$1522$height$$)):1;$selrect$jscomp$31_shape$jscomp$321_transform__$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($gradient$jscomp$11$$),$APP.$rumext$v2$adapt$$($transform__$1$jscomp$5$$),$APP.$rumext$v2$adapt$$($transform_inv__$1$$),$APP.$rumext$v2$adapt$$($factor$jscomp$2$$)],
function(){return $APP.$app$common$geom$matrix$translate$$($APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($app$common$geom$matrix$scale$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$matrix$rotate$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$matrix$translate$$($APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$(),$gstart_pt$$),$transform__$1$jscomp$5$$),$angle$jscomp$24$$),
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($gwidth$$,$factor$jscomp$2$$)),$transform_inv__$1$$),$APP.$app$common$geom$point$negate$$($gstart_pt$$))});$metadata_QMARK_$jscomp$1_path_QMARK_$jscomp$1_props_52939$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$shapes$export$0$include_metadata_ctx$$);$props$jscomp$115_start_x$jscomp$3_transform$jscomp$66_transform_inv$$={id:$id$jscomp$310$$,cx:$props$jscomp$115_start_x$jscomp$3_transform$jscomp$66_transform_inv$$,cy:$start_y$jscomp$3$$,
r:$APP.$app$common$geom$point$length$$($end_x$jscomp$3_gend_pt_gradient_vec$$),gradientTransform:$selrect$jscomp$31_shape$jscomp$321_transform__$2$$};$metadata_QMARK_$jscomp$1_path_QMARK_$jscomp$1_props_52939$$&&$app$main$ui$shapes$gradients$add_metadata_BANG_$$($props$jscomp$115_start_x$jscomp$3_transform$jscomp$66_transform_inv$$,$gradient$jscomp$11$$);return(0,$APP.$rumext$v2$create_element$$)("radialGradient",$props$jscomp$115_start_x$jscomp$3_transform$jscomp$66_transform_inv$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$16$$,
$map__52945_offset$jscomp$123_p__52941$$){var $index$jscomp$229$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52945_offset$jscomp$123_p__52941$$,0,null);$map__52945_offset$jscomp$123_p__52941$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52945_offset$jscomp$123_p__52941$$,1,null);var $map__52945__$1_opacity$jscomp$16$$=$APP.$cljs$core$__destructure_map$$($map__52945_offset$jscomp$123_p__52941$$);$map__52945_offset$jscomp$123_p__52941$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52945__$1_opacity$jscomp$16$$,
$APP.$cljs$cst$195$offset$$);var $color$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52945__$1_opacity$jscomp$16$$,$APP.$cljs$cst$1298$color$$);$map__52945__$1_opacity$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52945__$1_opacity$jscomp$16$$,$APP.$cljs$cst$1734$opacity$$);$out_arr__44124__auto__$jscomp$16$$.push((0,$APP.$rumext$v2$jsx$$)("stop",{offset:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($map__52945_offset$jscomp$123_p__52941$$,
0),stopColor:$color$jscomp$44$$,stopOpacity:$map__52945__$1_opacity$jscomp$16$$},""+($id$jscomp$310$$??"")+"-stop-"+($index$jscomp$229$$??"")));return $out_arr__44124__auto__$jscomp$16$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$11$$))))};
$app$main$ui$shapes$gradients$gradient$$=function($id$jscomp$311_id__$1$jscomp$5_props_52946$$){var $G__52947_attr$jscomp$26_gradient__$1$$=$id$jscomp$311_id__$1$jscomp$5_props_52946$$.attr,$props__$1$jscomp$12_shape$jscomp$322$$=$id$jscomp$311_id__$1$jscomp$5_props_52946$$.shape;$id$jscomp$311_id__$1$jscomp$5_props_52946$$=$id$jscomp$311_id__$1$jscomp$5_props_52946$$.id;var $rid$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$);$id$jscomp$311_id__$1$jscomp$5_props_52946$$=$id$jscomp$311_id__$1$jscomp$5_props_52946$$!=
null?$id$jscomp$311_id__$1$jscomp$5_props_52946$$:""+($APP.$cljs$core$name$$($G__52947_attr$jscomp$26_gradient__$1$$)??"")+"-"+($rid$$??"");$G__52947_attr$jscomp$26_gradient__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props__$1$jscomp$12_shape$jscomp$322$$,$G__52947_attr$jscomp$26_gradient__$1$$);$props__$1$jscomp$12_shape$jscomp$322$$={id:$id$jscomp$311_id__$1$jscomp$5_props_52946$$,gradient:$G__52947_attr$jscomp$26_gradient__$1$$,shape:$props__$1$jscomp$12_shape$jscomp$322$$};if($G__52947_attr$jscomp$26_gradient__$1$$!=
null)switch($G__52947_attr$jscomp$26_gradient__$1$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__52947_attr$jscomp$26_gradient__$1$$),$G__52947_attr$jscomp$26_gradient__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__52947_attr$jscomp$26_gradient__$1$$.$fqn$:null){case "linear":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$gradients$linear_gradient$$,$props__$1$jscomp$12_shape$jscomp$322$$);case "radial":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$gradients$radial_gradient$$,
$props__$1$jscomp$12_shape$jscomp$322$$);default:return null}else return null};
$app$main$ui$shapes$custom_stroke$inner_stroke_clip_path$$=function($props_52950_shape$jscomp$323_shape_id$jscomp$35$$){var $index$jscomp$230_suffix$jscomp$19$$=$props_52950_shape$jscomp$323_shape_id$jscomp$35$$.index,$render_id$jscomp$10$$=$props_52950_shape$jscomp$323_shape_id$jscomp$35$$["render-id"];$props_52950_shape$jscomp$323_shape_id$jscomp$35$$=$props_52950_shape$jscomp$323_shape_id$jscomp$35$$.shape;$props_52950_shape$jscomp$323_shape_id$jscomp$35$$=$props_52950_shape$jscomp$323_shape_id$jscomp$35$$?.id??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_52950_shape$jscomp$323_shape_id$jscomp$35$$,$APP.$cljs$cst$266$id$$);$index$jscomp$230_suffix$jscomp$19$$=$index$jscomp$230_suffix$jscomp$19$$!=null?"-"+($index$jscomp$230_suffix$jscomp$19$$??""):"";return(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:"inner-stroke-"+($render_id$jscomp$10$$??"")+"-"+($props_52950_shape$jscomp$323_shape_id$jscomp$35$$??"")+($index$jscomp$230_suffix$jscomp$19$$??""),children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#stroke-shape-"+
($render_id$jscomp$10$$??"")+"-"+($props_52950_shape$jscomp$323_shape_id$jscomp$35$$??"")+($index$jscomp$230_suffix$jscomp$19$$??"")})})};
$app$main$ui$shapes$custom_stroke$outer_stroke_mask$$=function($props_52960_shape_id$jscomp$36_stroke_width$jscomp$2$$){var $stroke$jscomp$6$$=$props_52960_shape_id$jscomp$36_stroke_width$jscomp$2$$.stroke,$index$jscomp$231_mask_id$$=$props_52960_shape_id$jscomp$36_stroke_width$jscomp$2$$.index,$href$jscomp$5_render_id$jscomp$11$$=$props_52960_shape_id$jscomp$36_stroke_width$jscomp$2$$["render-id"],$shape$jscomp$324$$=$props_52960_shape_id$jscomp$36_stroke_width$jscomp$2$$.shape;$props_52960_shape_id$jscomp$36_stroke_width$jscomp$2$$=
$shape$jscomp$324$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$324$$,$APP.$cljs$cst$266$id$$);var $suffix$jscomp$20_x$jscomp$1152$$=$index$jscomp$231_mask_id$$!=null?"-"+($index$jscomp$231_mask_id$$??""):"";$index$jscomp$231_mask_id$$="outer-stroke-"+($href$jscomp$5_render_id$jscomp$11$$??"")+"-"+($props_52960_shape_id$jscomp$36_stroke_width$jscomp$2$$??"")+($suffix$jscomp$20_x$jscomp$1152$$??"");$href$jscomp$5_render_id$jscomp$11$$="#stroke-shape-"+(($href$jscomp$5_render_id$jscomp$11$$??
"")+"-"+($props_52960_shape_id$jscomp$36_stroke_width$jscomp$2$$??"")+($suffix$jscomp$20_x$jscomp$1152$$??""));$props_52960_shape_id$jscomp$36_stroke_width$jscomp$2$$=function(){var $G__52964$$=$APP.$cljs$cst$1868$stroke_alignment$$.$cljs$core$IFn$_invoke$arity$2$($stroke$jscomp$6$$,$APP.$cljs$cst$1667$center$$);switch($G__52964$$ instanceof $APP.$cljs$core$Keyword$$?$G__52964$$.$fqn$:null){case "center":return $APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$2$($stroke$jscomp$6$$,
0)/2;case "outer":return $APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$2$($stroke$jscomp$6$$,0);default:return 0}}();var $h$jscomp$153_stroke_margin$jscomp$1$$=$app$common$geom$shapes$bounds$shape_stroke_margin$$($shape$jscomp$324$$,$props_52960_shape_id$jscomp$36_stroke_width$jscomp$2$$),$selrect$jscomp$32$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$324$$)],function(){return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$324$$)?
$APP.$app$common$geom$shapes$text$shape__GT_rect$$($shape$jscomp$324$$):$APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$324$$))});$suffix$jscomp$20_x$jscomp$1152$$=($selrect$jscomp$32$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$32$$,$APP.$cljs$cst$1510$x$$))-$h$jscomp$153_stroke_margin$jscomp$1$$;var $y$jscomp$390$$=($selrect$jscomp$32$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$32$$,
$APP.$cljs$cst$1511$y$$))-$h$jscomp$153_stroke_margin$jscomp$1$$,$w$jscomp$31$$=($selrect$jscomp$32$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$32$$,$APP.$cljs$cst$290$width$$))+2*$h$jscomp$153_stroke_margin$jscomp$1$$;$h$jscomp$153_stroke_margin$jscomp$1$$=($selrect$jscomp$32$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$32$$,$APP.$cljs$cst$1522$height$$))+2*$h$jscomp$153_stroke_margin$jscomp$1$$;return(0,$APP.$rumext$v2$jsxs$$)("mask",
{id:$index$jscomp$231_mask_id$$,x:$suffix$jscomp$20_x$jscomp$1152$$,y:$y$jscomp$390$$,width:$w$jscomp$31$$,height:$h$jscomp$153_stroke_margin$jscomp$1$$,maskUnits:"userSpaceOnUse",children:[(0,$APP.$rumext$v2$jsx$$)("use",{href:$href$jscomp$5_render_id$jscomp$11$$,style:{fill:"none",stroke:"white",strokeWidth:$props_52960_shape_id$jscomp$36_stroke_width$jscomp$2$$*2}}),(0,$APP.$rumext$v2$jsx$$)("use",{href:$href$jscomp$5_render_id$jscomp$11$$,style:{fill:"black",stroke:"none"}})]})};
$app$main$ui$shapes$custom_stroke$cap_markers$$=function($id_prefix_props_52969$$){var $opacity$jscomp$17_stroke$jscomp$7$$=$id_prefix_props_52969$$.stroke,$color$jscomp$45_index$jscomp$232$$=$id_prefix_props_52969$$.index,$render_id$jscomp$12$$=$id_prefix_props_52969$$["render-id"];$id_prefix_props_52969$$="marker-"+($render_id$jscomp$12$$??"");var $gradient$jscomp$12$$=$APP.$cljs$cst$1741$stroke_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($opacity$jscomp$17_stroke$jscomp$7$$),$image$jscomp$14$$=
$APP.$cljs$cst$1635$stroke_image$$.$cljs$core$IFn$_invoke$arity$1$($opacity$jscomp$17_stroke$jscomp$7$$),$cap_start$$=$APP.$cljs$cst$1865$stroke_cap_start$$.$cljs$core$IFn$_invoke$arity$1$($opacity$jscomp$17_stroke$jscomp$7$$),$cap_end$$=$APP.$cljs$cst$1869$stroke_cap_end$$.$cljs$core$IFn$_invoke$arity$1$($opacity$jscomp$17_stroke$jscomp$7$$);$color$jscomp$45_index$jscomp$232$$=$gradient$jscomp$12$$!=null?"url(#stroke-color-gradient-"+($render_id$jscomp$12$$??"")+"-"+($color$jscomp$45_index$jscomp$232$$??
"")+")":$image$jscomp$14$$!=null?"url(#stroke-fill-"+($render_id$jscomp$12$$??"")+"-"+($color$jscomp$45_index$jscomp$232$$??"")+")":$APP.$cljs$cst$1739$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$($opacity$jscomp$17_stroke$jscomp$7$$);$opacity$jscomp$17_stroke$jscomp$7$$=$gradient$jscomp$12$$!=null?null:$APP.$cljs$cst$1740$stroke_opacity$$.$cljs$core$IFn$_invoke$arity$1$($opacity$jscomp$17_stroke$jscomp$7$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_start$$,
$APP.$cljs$cst$2013$line_arrow$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_end$$,$APP.$cljs$cst$2013$line_arrow$$)?(0,$APP.$rumext$v2$jsx$$)("marker",{refX:"2",children:(0,$APP.$rumext$v2$jsx$$)("path",{d:"M 0.5 0.5 L 3 3 L 0.5 5.5 L 0 5 L 2 3 L 0 1 z"}),orient:"auto-start-reverse",id:""+($id_prefix_props_52969$$??"")+"-line-arrow",viewBox:"0 0 3 6",fill:$color$jscomp$45_index$jscomp$232$$,refY:"3",fillOpacity:$opacity$jscomp$17_stroke$jscomp$7$$,markerWidth:"8.5",markerHeight:"8.5"}):
null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_start$$,$APP.$cljs$cst$2015$triangle_arrow$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_end$$,$APP.$cljs$cst$2015$triangle_arrow$$)?(0,$APP.$rumext$v2$jsx$$)("marker",{refX:"2",children:(0,$APP.$rumext$v2$jsx$$)("path",{d:"M 0 0 L 3 3 L 0 6 z"}),orient:"auto-start-reverse",id:""+($id_prefix_props_52969$$??"")+"-triangle-arrow",viewBox:"0 0 3 6",fill:$color$jscomp$45_index$jscomp$232$$,refY:"3",fillOpacity:$opacity$jscomp$17_stroke$jscomp$7$$,
markerWidth:"8.5",markerHeight:"8.5"}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_start$$,$APP.$cljs$cst$2017$square_marker$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_end$$,$APP.$cljs$cst$2017$square_marker$$)?(0,$APP.$rumext$v2$jsx$$)("marker",{refX:"3",children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:0,y:0,width:6,height:6}),orient:"auto-start-reverse",id:""+($id_prefix_props_52969$$??"")+"-square-marker",viewBox:"0 0 6 6",fill:$color$jscomp$45_index$jscomp$232$$,
refY:"3",fillOpacity:$opacity$jscomp$17_stroke$jscomp$7$$,markerWidth:"4.2426",markerHeight:"4.2426"}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_start$$,$APP.$cljs$cst$2016$circle_marker$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_end$$,$APP.$cljs$cst$2016$circle_marker$$)?(0,$APP.$rumext$v2$jsx$$)("marker",{refX:"3",children:(0,$APP.$rumext$v2$jsx$$)("circle",{cx:"3",cy:"3",r:"3"}),orient:"auto-start-reverse",id:""+($id_prefix_props_52969$$??"")+"-circle-marker",
viewBox:"0 0 6 6",fill:$color$jscomp$45_index$jscomp$232$$,refY:"3",fillOpacity:$opacity$jscomp$17_stroke$jscomp$7$$,markerWidth:"4",markerHeight:"4"}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_start$$,$APP.$cljs$cst$2014$diamond_marker$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_end$$,$APP.$cljs$cst$2014$diamond_marker$$)?(0,$APP.$rumext$v2$jsx$$)("marker",{refX:"3",children:(0,$APP.$rumext$v2$jsx$$)("path",{d:"M 3 0 L 6 3 L 3 6 L 0 3 z"}),orient:"auto-start-reverse",
id:""+($id_prefix_props_52969$$??"")+"-diamond-marker",viewBox:"0 0 6 6",fill:$color$jscomp$45_index$jscomp$232$$,refY:"3",fillOpacity:$opacity$jscomp$17_stroke$jscomp$7$$,markerWidth:"6",markerHeight:"6"}):null,($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_start$$,$APP.$cljs$cst$2012$round$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_end$$,$APP.$cljs$cst$2012$round$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_start$$,$cap_end$$)?(0,$APP.$rumext$v2$jsx$$)("marker",
{refX:"3",children:(0,$APP.$rumext$v2$jsx$$)("path",{d:"M 3 2.5 A 0.5 0.5 0 0 1 3 3.5 "}),orient:"auto-start-reverse",id:""+($id_prefix_props_52969$$??"")+"-round",viewBox:"0 0 6 6",fill:$color$jscomp$45_index$jscomp$232$$,refY:"3",fillOpacity:$opacity$jscomp$17_stroke$jscomp$7$$,markerWidth:"6",markerHeight:"6"}):null,($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_start$$,$APP.$cljs$cst$1933$square$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_end$$,$APP.$cljs$cst$1933$square$$))&&
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap_start$$,$cap_end$$)?(0,$APP.$rumext$v2$jsx$$)("marker",{refX:"3",children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:3,y:2.5,width:.5,height:1}),orient:"auto-start-reverse",id:""+($id_prefix_props_52969$$??"")+"-square",viewBox:"0 0 6 6",fill:$color$jscomp$45_index$jscomp$232$$,refY:"3",fillOpacity:$opacity$jscomp$17_stroke$jscomp$7$$,markerWidth:"6",markerHeight:"6"}):null]})};
$app$main$ui$shapes$custom_stroke$stroke_defs$$=function($open_path_QMARK_$jscomp$2_props_52972$$){var $stroke$jscomp$8$$=$open_path_QMARK_$jscomp$2_props_52972$$.stroke,$index$jscomp$233$$=$open_path_QMARK_$jscomp$2_props_52972$$.index,$render_id$jscomp$13$$=$open_path_QMARK_$jscomp$2_props_52972$$["render-id"],$shape$jscomp$325$$=$open_path_QMARK_$jscomp$2_props_52972$$.shape;$open_path_QMARK_$jscomp$2_props_52972$$=$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$325$$)&&
$APP.$app$common$types$path$shape_with_open_path_QMARK_$$($shape$jscomp$325$$);var $gradient$jscomp$13$$=$APP.$cljs$cst$1741$stroke_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$8$$),$alignment$$=$APP.$cljs$cst$1868$stroke_alignment$$.$cljs$core$IFn$_invoke$arity$2$($stroke$jscomp$8$$,$APP.$cljs$cst$1667$center$$),$width$jscomp$85$$=$APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$2$($stroke$jscomp$8$$,0),$props$jscomp$117$$={id:"stroke-color-gradient-"+($render_id$jscomp$13$$??
"")+"-"+($index$jscomp$233$$??""),gradient:$gradient$jscomp$13$$,shape:$shape$jscomp$325$$,"force-transform":$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$325$$)},$selrect$jscomp$33_stroke_image$$=$APP.$cljs$cst$1635$stroke_image$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$8$$),$image_props_uri$jscomp$75$$=$APP.$cljs$core$truth_$$($selrect$jscomp$33_stroke_image$$)?$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$33_stroke_image$$):
null,$embed$jscomp$2$$=$app$main$ui$shapes$embed$use_data_uris$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$image_props_uri$jscomp$75$$],null)),$stroke_margin$jscomp$2_stroke_width$jscomp$3$$=function(){var $G__52973$$=$APP.$cljs$cst$1868$stroke_alignment$$.$cljs$core$IFn$_invoke$arity$2$($stroke$jscomp$8$$,$APP.$cljs$cst$1667$center$$);switch($G__52973$$ instanceof $APP.$cljs$core$Keyword$$?$G__52973$$.$fqn$:null){case "center":return $APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$2$($stroke$jscomp$8$$,
0)/2;case "outer":return $APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$2$($stroke$jscomp$8$$,0);default:return 0}}(),$margin_w$jscomp$32$$=$app$common$geom$shapes$bounds$shape_stroke_margin$$($stroke$jscomp$8$$,$stroke_margin$jscomp$2_stroke_width$jscomp$3$$);$selrect$jscomp$33_stroke_image$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$325$$)],function(){return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$325$$)?
$APP.$app$common$geom$shapes$text$shape__GT_rect$$($shape$jscomp$325$$):$APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$325$$))});$stroke_margin$jscomp$2_stroke_width$jscomp$3$$+=$margin_w$jscomp$32$$;$margin_w$jscomp$32$$=($selrect$jscomp$33_stroke_image$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$33_stroke_image$$,$APP.$cljs$cst$290$width$$))+2*$stroke_margin$jscomp$2_stroke_width$jscomp$3$$;
var $h$jscomp$154$$=($selrect$jscomp$33_stroke_image$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$33_stroke_image$$,$APP.$cljs$cst$1522$height$$))+2*$stroke_margin$jscomp$2_stroke_width$jscomp$3$$;$image_props_uri$jscomp$75$$={href:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($embed$jscomp$2$$,$image_props_uri$jscomp$75$$,$image_props_uri$jscomp$75$$),preserveAspectRatio:"xMidYMid slice",width:1,height:1,id:"stroke-image-"+($render_id$jscomp$13$$??"")+
"-"+($index$jscomp$233$$??"")};return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$gradient$jscomp$13$$!=null?function(){var $G__52974_G__52974__$1$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$13$$);$G__52974_G__52974__$1$$=$G__52974_G__52974__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__52974_G__52974__$1$$.$fqn$:null;switch($G__52974_G__52974__$1$$){case "linear":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$gradients$linear_gradient$$,
$props$jscomp$117$$);case "radial":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$gradients$radial_gradient$$,$props$jscomp$117$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__52974_G__52974__$1$$)].join(""));}}():null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1635$stroke_image$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$8$$))?(0,$APP.$rumext$v2$jsx$$)("pattern",{width:$margin_w$jscomp$32$$/($selrect$jscomp$33_stroke_image$$?.width??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$33_stroke_image$$,$APP.$cljs$cst$290$width$$)),height:$h$jscomp$154$$/($selrect$jscomp$33_stroke_image$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$33_stroke_image$$,$APP.$cljs$cst$1522$height$$)),children:(0,$APP.$rumext$v2$create_element$$)("image",$image_props_uri$jscomp$75$$),patternTransform:$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$325$$)?
$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$325$$):null,x:-($stroke_margin$jscomp$2_stroke_width$jscomp$3$$/($selrect$jscomp$33_stroke_image$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$33_stroke_image$$,$APP.$cljs$cst$290$width$$))),id:"stroke-fill-"+($render_id$jscomp$13$$??"")+"-"+($index$jscomp$233$$??""),viewBox:"0 0 1 1",preserveAspectRatio:"xMidYMid slice",y:-($stroke_margin$jscomp$2_stroke_width$jscomp$3$$/($selrect$jscomp$33_stroke_image$$?.height??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$33_stroke_image$$,$APP.$cljs$cst$1522$height$$))),patternContentUnits:"objectBoundingBox"}):null,!$open_path_QMARK_$jscomp$2_props_52972$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2041$inner$$,$alignment$$)&&$width$jscomp$85$$>0?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$inner_stroke_clip_path$$,{shape:$shape$jscomp$325$$,"render-id":$render_id$jscomp$13$$,index:$index$jscomp$233$$}):
!$open_path_QMARK_$jscomp$2_props_52972$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2042$outer$$,$alignment$$)&&$width$jscomp$85$$>0?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$outer_stroke_mask$$,{shape:$shape$jscomp$325$$,stroke:$stroke$jscomp$8$$,"render-id":$render_id$jscomp$13$$,index:$index$jscomp$233$$}):$APP.$cljs$cst$1865$stroke_cap_start$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$8$$)!=null||$APP.$cljs$cst$1869$stroke_cap_end$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$8$$)!=
null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$cap_markers$$,{stroke:$stroke$jscomp$8$$,"render-id":$render_id$jscomp$13$$,index:$index$jscomp$233$$}):null]})};
$app$main$ui$shapes$custom_stroke$outer_stroke$$=function($props_52975_style$jscomp$26$$){var $children$jscomp$199_type$jscomp$inline_5826$$=$props_52975_style$jscomp$26$$.children,$JSCompiler_temp_const$jscomp$975_stroke$jscomp$9$$=$props_52975_style$jscomp$26$$.stroke,$index$jscomp$234_style__$1$jscomp$inline_5827$$=$props_52975_style$jscomp$26$$.index,$shape$jscomp$326$$=$props_52975_style$jscomp$26$$.shape,$href$jscomp$6_shape_id$jscomp$37$$=$shape$jscomp$326$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$326$$,
$APP.$cljs$cst$266$id$$),$render_id$jscomp$14$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$),$JSCompiler_inline_result$jscomp$976_props$jscomp$118_props__$1$jscomp$inline_5828$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($children$jscomp$199_type$jscomp$inline_5826$$,"props");$props_52975_style$jscomp$26$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$976_props$jscomp$118_props__$1$jscomp$inline_5828$$,"style");
var $stroke_width$jscomp$4$$=$APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$975_stroke$jscomp$9$$,0),$shape_id__$1$jscomp$3_suffix$jscomp$21$$=$index$jscomp$234_style__$1$jscomp$inline_5827$$!=null?"-"+($index$jscomp$234_style__$1$jscomp$inline_5827$$??""):"",$mask_id$jscomp$1$$="outer-stroke-"+($render_id$jscomp$14$$??"")+"-"+($href$jscomp$6_shape_id$jscomp$37$$??"")+($shape_id__$1$jscomp$3_suffix$jscomp$21$$??"");$shape_id__$1$jscomp$3_suffix$jscomp$21$$=
"stroke-shape-"+($render_id$jscomp$14$$??"")+"-"+($href$jscomp$6_shape_id$jscomp$37$$??"")+($shape_id__$1$jscomp$3_suffix$jscomp$21$$??"");$href$jscomp$6_shape_id$jscomp$37$$="#"+($shape_id__$1$jscomp$3_suffix$jscomp$21$$??"");$JSCompiler_temp_const$jscomp$975_stroke$jscomp$9$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$stroke_defs$$,{shape:$shape$jscomp$326$$,stroke:$JSCompiler_temp_const$jscomp$975_stroke$jscomp$9$$,"render-id":$render_id$jscomp$14$$,index:$index$jscomp$234_style__$1$jscomp$inline_5827$$});
$children$jscomp$199_type$jscomp$inline_5826$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($children$jscomp$199_type$jscomp$inline_5826$$,"type");$index$jscomp$234_style__$1$jscomp$inline_5827$$=$APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$clone$$($props_52975_style$jscomp$26$$),
"fill"),"fillOpacity"),"stroke"),"strokeWidth"),"strokeOpacity"),"strokeStyle"),"strokeDasharray");$JSCompiler_inline_result$jscomp$976_props$jscomp$118_props__$1$jscomp$inline_5828$$=$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$clone$$($JSCompiler_inline_result$jscomp$976_props$jscomp$118_props__$1$jscomp$inline_5828$$),"id",$shape_id__$1$jscomp$3_suffix$jscomp$21$$),"style",$index$jscomp$234_style__$1$jscomp$inline_5827$$);$JSCompiler_inline_result$jscomp$976_props$jscomp$118_props__$1$jscomp$inline_5828$$=
(0,$APP.$rumext$v2$create_element$$)($children$jscomp$199_type$jscomp$inline_5826$$,$JSCompiler_inline_result$jscomp$976_props$jscomp$118_props__$1$jscomp$inline_5828$$);return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"outer-stroke-shape",children:[(0,$APP.$rumext$v2$jsxs$$)("defs",{children:[$JSCompiler_temp_const$jscomp$975_stroke$jscomp$9$$,$JSCompiler_inline_result$jscomp$976_props$jscomp$118_props__$1$jscomp$inline_5828$$]}),(0,$APP.$rumext$v2$jsx$$)("use",{href:$href$jscomp$6_shape_id$jscomp$37$$,
mask:"url(#"+($mask_id$jscomp$1$$??"")+")",style:$APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$clone$$($props_52975_style$jscomp$26$$),"strokeWidth",$stroke_width$jscomp$4$$*2),"fill","none"),"fillOpacity")}),(0,$APP.$rumext$v2$jsx$$)("use",{href:$href$jscomp$6_shape_id$jscomp$37$$,style:$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$clone$$($props_52975_style$jscomp$26$$),"stroke","none")})]})};
$app$main$ui$shapes$custom_stroke$inner_stroke$$=function($index$jscomp$235_props_52976$$){var $child$jscomp$73_transform$jscomp$67$$=$index$jscomp$235_props_52976$$.children,$shape$jscomp$327$$=$index$jscomp$235_props_52976$$.shape,$stroke$jscomp$10$$=$index$jscomp$235_props_52976$$.stroke;$index$jscomp$235_props_52976$$=$index$jscomp$235_props_52976$$.index;var $clip_path_shape_id$jscomp$38$$=$shape$jscomp$327$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$327$$,$APP.$cljs$cst$266$id$$),
$render_id$jscomp$15$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$),$type$jscomp$404$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$73_transform$jscomp$67$$,"type"),$props__$1$jscomp$14_props__$2$jscomp$2$$=$APP.$app$util$object$clone$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$73_transform$jscomp$67$$,"props")),$style$jscomp$27_style__$1$jscomp$2$$=$APP.$app$util$object$clone$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props__$1$jscomp$14_props__$2$jscomp$2$$,
"style"));$child$jscomp$73_transform$jscomp$67$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props__$1$jscomp$14_props__$2$jscomp$2$$,"transform");var $stroke_width$jscomp$5$$=$APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$2$($stroke$jscomp$10$$,0),$suffix$jscomp$22$$=$index$jscomp$235_props_52976$$!=null?"-"+($index$jscomp$235_props_52976$$??""):"",$shape_id__$1$jscomp$4$$="stroke-shape-"+($render_id$jscomp$15$$??"")+"-"+($clip_path_shape_id$jscomp$38$$??"")+
($suffix$jscomp$22$$??"");$clip_path_shape_id$jscomp$38$$="url('#inner-stroke-"+(($render_id$jscomp$15$$??"")+"-"+($clip_path_shape_id$jscomp$38$$??"")+($suffix$jscomp$22$$??""))+"')";$style$jscomp$27_style__$1$jscomp$2$$=$APP.$app$util$object$set_BANG_$$($style$jscomp$27_style__$1$jscomp$2$$,"strokeWidth",$stroke_width$jscomp$5$$*2);$props__$1$jscomp$14_props__$2$jscomp$2$$=$APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($props__$1$jscomp$14_props__$2$jscomp$2$$,
"id",""+($shape_id__$1$jscomp$4$$??"")),"style",$style$jscomp$27_style__$1$jscomp$2$$),"transform");return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"inner-stroke-shape",transform:$child$jscomp$73_transform$jscomp$67$$,children:[(0,$APP.$rumext$v2$jsxs$$)("defs",{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$stroke_defs$$,{shape:$shape$jscomp$327$$,stroke:$stroke$jscomp$10$$,"render-id":$render_id$jscomp$15$$,index:$index$jscomp$235_props_52976$$}),(0,$APP.$rumext$v2$create_element$$)($type$jscomp$404$$,
$props__$1$jscomp$14_props__$2$jscomp$2$$)]}),(0,$APP.$rumext$v2$jsx$$)("use",{href:"#"+($shape_id__$1$jscomp$4$$??""),clipPath:$clip_path_shape_id$jscomp$38$$})]})};
$app$main$ui$shapes$custom_stroke$shape_custom_stroke$$=function($props_52977_render_id__$1$$){var $child$jscomp$74$$=$props_52977_render_id__$1$$.children,$shape$jscomp$328$$=$props_52977_render_id__$1$$.shape,$stroke$jscomp$11$$=$props_52977_render_id__$1$$.stroke,$index$jscomp$236$$=$props_52977_render_id__$1$$.index,$outer_QMARK__render_id$jscomp$16_stroke_position$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$);$props_52977_render_id__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_52977_render_id__$1$$["render-id"],
$outer_QMARK__render_id$jscomp$16_stroke_position$$);var $has_stroke_QMARK__stroke_width$jscomp$6$$=$APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$2$($stroke$jscomp$11$$,0),$closed_QMARK_$jscomp$2_stroke_style$$=$APP.$cljs$cst$1866$stroke_style$$.$cljs$core$IFn$_invoke$arity$2$($stroke$jscomp$11$$,$APP.$cljs$cst$226$none$$);$outer_QMARK__render_id$jscomp$16_stroke_position$$=$APP.$cljs$cst$1868$stroke_alignment$$.$cljs$core$IFn$_invoke$arity$2$($stroke$jscomp$11$$,$APP.$cljs$cst$1667$center$$);
$has_stroke_QMARK__stroke_width$jscomp$6$$=$has_stroke_QMARK__stroke_width$jscomp$6$$>0&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($closed_QMARK_$jscomp$2_stroke_style$$,$APP.$cljs$cst$226$none$$);$closed_QMARK_$jscomp$2_stroke_style$$=!$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$328$$)||!$APP.$app$common$types$path$shape_with_open_path_QMARK_$$($shape$jscomp$328$$);var $inner_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2041$inner$$,
$outer_QMARK__render_id$jscomp$16_stroke_position$$);$outer_QMARK__render_id$jscomp$16_stroke_position$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2042$outer$$,$outer_QMARK__render_id$jscomp$16_stroke_position$$);return $has_stroke_QMARK__stroke_width$jscomp$6$$&&$inner_QMARK_$$&&$closed_QMARK_$jscomp$2_stroke_style$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$inner_stroke$$,{shape:$shape$jscomp$328$$,stroke:$stroke$jscomp$11$$,index:$index$jscomp$236$$,
children:$child$jscomp$74$$}):$has_stroke_QMARK__stroke_width$jscomp$6$$&&$outer_QMARK__render_id$jscomp$16_stroke_position$$&&$closed_QMARK_$jscomp$2_stroke_style$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$outer_stroke$$,{shape:$shape$jscomp$328$$,stroke:$stroke$jscomp$11$$,index:$index$jscomp$236$$,children:$child$jscomp$74$$}):(0,$APP.$rumext$v2$jsxs$$)("g",{className:"stroke-shape",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$stroke_defs$$,
{shape:$shape$jscomp$328$$,stroke:$stroke$jscomp$11$$,"render-id":$props_52977_render_id__$1$$,index:$index$jscomp$236$$})}),$child$jscomp$74$$]})};
$app$main$ui$shapes$custom_stroke$build_stroke_element$$=function($child$jscomp$76_type$jscomp$406$$,$style__$1$jscomp$3_value$jscomp$476$$,$position$jscomp$56$$,$render_id$jscomp$18$$,$open_path_QMARK_$jscomp$3_style$jscomp$28$$){var $props$jscomp$122_props__$1$jscomp$16$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$76_type$jscomp$406$$,"props");$child$jscomp$76_type$jscomp$406$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$76_type$jscomp$406$$,
"type");$open_path_QMARK_$jscomp$3_style$jscomp$28$$=$app$main$ui$shapes$attrs$add_stroke_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$clone$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props$jscomp$122_props__$1$jscomp$16$$,"style")),"fill","none"),"fillOpacity","none"),$style__$1$jscomp$3_value$jscomp$476$$,$render_id$jscomp$18$$,$position$jscomp$56$$,$open_path_QMARK_$jscomp$3_style$jscomp$28$$);$style__$1$jscomp$3_value$jscomp$476$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1635$stroke_image$$.$cljs$core$IFn$_invoke$arity$1$($style__$1$jscomp$3_value$jscomp$476$$))?$APP.$app$util$object$set_BANG_$$($open_path_QMARK_$jscomp$3_style$jscomp$28$$,"stroke","url(#stroke-fill-"+($render_id$jscomp$18$$??"")+"-"+($position$jscomp$56$$??"")+")"):$open_path_QMARK_$jscomp$3_style$jscomp$28$$;$props$jscomp$122_props__$1$jscomp$16$$=$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$clone$$($props$jscomp$122_props__$1$jscomp$16$$),
"fill"),"fillOpacity"),"style",$style__$1$jscomp$3_value$jscomp$476$$);return(0,$APP.$rumext$v2$create_element$$)($child$jscomp$76_type$jscomp$406$$,$props$jscomp$122_props__$1$jscomp$16$$)};
$app$main$ui$shapes$custom_stroke$shape_fills$$=function($props_52978_type$jscomp$inline_5834$$){var $child$jscomp$77_props$jscomp$inline_5835$$=$props_52978_type$jscomp$inline_5834$$.children,$JSCompiler_inline_result$jscomp$977_props__$1$jscomp$inline_5836_shape$jscomp$330$$=$props_52978_type$jscomp$inline_5834$$.shape,$shape_id$jscomp$39$$=$JSCompiler_inline_result$jscomp$977_props__$1$jscomp$inline_5836_shape$jscomp$330$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$977_props__$1$jscomp$inline_5836_shape$jscomp$330$$,
$APP.$cljs$cst$266$id$$),$position$jscomp$57$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_52978_type$jscomp$inline_5834$$.position,0),$render_id$jscomp$19_render_id__$1$jscomp$1$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$);$render_id$jscomp$19_render_id__$1$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_52978_type$jscomp$inline_5834$$["render-id"],$render_id$jscomp$19_render_id__$1$jscomp$1$$);$props_52978_type$jscomp$inline_5834$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$77_props$jscomp$inline_5835$$,"type");$child$jscomp$77_props$jscomp$inline_5835$$=$APP.$app$util$object$clone$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$77_props$jscomp$inline_5835$$,"props"));$JSCompiler_inline_result$jscomp$977_props__$1$jscomp$inline_5836_shape$jscomp$330$$=$app$main$ui$shapes$attrs$add_fill_props_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($child$jscomp$77_props$jscomp$inline_5835$$,
$JSCompiler_inline_result$jscomp$977_props__$1$jscomp$inline_5836_shape$jscomp$330$$,$position$jscomp$57$$,$render_id$jscomp$19_render_id__$1$jscomp$1$$);$JSCompiler_inline_result$jscomp$977_props__$1$jscomp$inline_5836_shape$jscomp$330$$=(0,$APP.$rumext$v2$create_element$$)($props_52978_type$jscomp$inline_5834$$,$JSCompiler_inline_result$jscomp$977_props__$1$jscomp$inline_5836_shape$jscomp$330$$);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"fills",id:"fills-"+($shape_id$jscomp$39$$??""),children:$JSCompiler_inline_result$jscomp$977_props__$1$jscomp$inline_5836_shape$jscomp$330$$})};
$app$main$ui$shapes$custom_stroke$shape_strokes$$=function($props_52979_props__$1$jscomp$17_style$jscomp$29$$){var $child$jscomp$78$$=$props_52979_props__$1$jscomp$17_style$jscomp$29$$.children,$shape$jscomp$331$$=$props_52979_props__$1$jscomp$17_style$jscomp$29$$.shape,$shape_blur$jscomp$1_shape_id$jscomp$40$$=$shape$jscomp$331$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$331$$,$APP.$cljs$cst$266$id$$),$render_id$jscomp$20_shape_fills$jscomp$1$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$),
$render_id__$1$jscomp$2$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_52979_props__$1$jscomp$17_style$jscomp$29$$["render-id"],$render_id$jscomp$20_shape_fills$jscomp$1$$),$strokes$jscomp$4_svg_attrs$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$331$$,$APP.$cljs$cst$1636$strokes$$),$stroke_id$$="strokes-"+($APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($strokes$jscomp$4_svg_attrs$jscomp$2$$)],function(){return""+
($APP.$app$common$uuid$next$$()??"")})??"")+"-"+($shape_blur$jscomp$1_shape_id$jscomp$40$$??"");$shape_blur$jscomp$1_shape_id$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$331$$,$APP.$cljs$cst$1653$blur$$);$render_id$jscomp$20_shape_fills$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$331$$,$APP.$cljs$cst$1634$fills$$);var $shape_shadow$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$331$$,$APP.$cljs$cst$1654$shadow$$),
$shape_strokes__$1$$=$APP.$cljs$core$not_empty$$($strokes$jscomp$4_svg_attrs$jscomp$2$$);$strokes$jscomp$4_svg_attrs$jscomp$2$$=$app$main$ui$shapes$attrs$get_svg_props$$($shape$jscomp$331$$,$render_id__$1$jscomp$2$$);$props_52979_props__$1$jscomp$17_style$jscomp$29$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$clone$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_52979_props__$1$jscomp$17_style$jscomp$29$$,"style")),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($strokes$jscomp$4_svg_attrs$jscomp$2$$,
"style"));$props_52979_props__$1$jscomp$17_style$jscomp$29$$={...$strokes$jscomp$4_svg_attrs$jscomp$2$$,id:$stroke_id$$,className:"strokes",style:$props_52979_props__$1$jscomp$17_style$jscomp$29$$};var $open_path_QMARK_$jscomp$4$$=$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$331$$)&&$APP.$app$common$types$path$shape_with_open_path_QMARK_$$($shape$jscomp$331$$);$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$331$$)||
($shape_blur$jscomp$1_shape_id$jscomp$40$$==null||$APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($shape_blur$jscomp$1_shape_id$jscomp$40$$)||$APP.$app$util$object$set_BANG_$$($props_52979_props__$1$jscomp$17_style$jscomp$29$$,"filter","url(#filter-blur-"+($render_id__$1$jscomp$2$$??"")+")"),$APP.$cljs$core$empty_QMARK_$$($render_id$jscomp$20_shape_fills$jscomp$1$$)&&$APP.$cljs$core$not_empty$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,$shape_shadow$jscomp$1$$))!=
null&&$APP.$app$util$object$set_BANG_$$($props_52979_props__$1$jscomp$17_style$jscomp$29$$,"filter","url(#filter-"+($render_id__$1$jscomp$2$$??"")+")"));return $shape_strokes__$1$$!=null?(0,$APP.$rumext$v2$create_element$$)("g",$props_52979_props__$1$jscomp$17_style$jscomp$29$$,$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return function $app$main$ui$shapes$custom_stroke$shape_strokes_$_iter__52986$$($s__52987$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__52987__$1_s__52987__$2_temp__5825__auto__$jscomp$159$$=
$s__52987$$;;)if($s__52987__$1_s__52987__$2_temp__5825__auto__$jscomp$159$$=$APP.$cljs$core$seq$$($s__52987__$1_s__52987__$2_temp__5825__auto__$jscomp$159$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__52987__$1_s__52987__$2_temp__5825__auto__$jscomp$159$$)){var $JSCompiler_inline_result$jscomp$978_c__5501__auto__$jscomp$30_value$jscomp$477_vec__53003$$=$APP.$cljs$core$_chunked_first$$($s__52987__$1_s__52987__$2_temp__5825__auto__$jscomp$159$$),$size__5502__auto__$jscomp$30$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$978_c__5501__auto__$jscomp$30_value$jscomp$477_vec__53003$$),
$b__52989_index$jscomp$237$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$30$$);a:{for(var $i__52988$jscomp$inline_5838$$=0;;)if($i__52988$jscomp$inline_5838$$<$size__5502__auto__$jscomp$30$$){var $b$jscomp$inline_12147_vec__52994$jscomp$inline_5839$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$978_c__5501__auto__$jscomp$30_value$jscomp$477_vec__53003$$,$i__52988$jscomp$inline_5838$$),$index$jscomp$inline_5840_x$jscomp$inline_12148$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_12147_vec__52994$jscomp$inline_5839$$,
0,null),$value$jscomp$inline_5841$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_12147_vec__52994$jscomp$inline_5839$$,1,null);$APP.$cljs$core$not$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$inline_5841$$))&&($b$jscomp$inline_12147_vec__52994$jscomp$inline_5839$$=$b__52989_index$jscomp$237$$,$index$jscomp$inline_5840_x$jscomp$inline_12148$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$shape_custom_stroke$$,{shape:$shape$jscomp$331$$,
stroke:$value$jscomp$inline_5841$$,index:$index$jscomp$inline_5840_x$jscomp$inline_12148$$,children:$app$main$ui$shapes$custom_stroke$build_stroke_element$$($child$jscomp$78$$,$value$jscomp$inline_5841$$,$index$jscomp$inline_5840_x$jscomp$inline_12148$$,$render_id__$1$jscomp$2$$,$open_path_QMARK_$jscomp$4$$)},""+($index$jscomp$inline_5840_x$jscomp$inline_12148$$??"")+"-"+($stroke_id$$??"")),$b$jscomp$inline_12147_vec__52994$jscomp$inline_5839$$.add($index$jscomp$inline_5840_x$jscomp$inline_12148$$));
$i__52988$jscomp$inline_5838$$+=1}else{$JSCompiler_inline_result$jscomp$978_c__5501__auto__$jscomp$30_value$jscomp$477_vec__53003$$=!0;break a}$JSCompiler_inline_result$jscomp$978_c__5501__auto__$jscomp$30_value$jscomp$477_vec__53003$$=void 0}return $JSCompiler_inline_result$jscomp$978_c__5501__auto__$jscomp$30_value$jscomp$477_vec__53003$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__52989_index$jscomp$237$$),$app$main$ui$shapes$custom_stroke$shape_strokes_$_iter__52986$$($APP.$cljs$core$_chunked_rest$$($s__52987__$1_s__52987__$2_temp__5825__auto__$jscomp$159$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__52989_index$jscomp$237$$),null)}$JSCompiler_inline_result$jscomp$978_c__5501__auto__$jscomp$30_value$jscomp$477_vec__53003$$=$APP.$cljs$core$first$$($s__52987__$1_s__52987__$2_temp__5825__auto__$jscomp$159$$);$b__52989_index$jscomp$237$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$978_c__5501__auto__$jscomp$30_value$jscomp$477_vec__53003$$,0,null);$JSCompiler_inline_result$jscomp$978_c__5501__auto__$jscomp$30_value$jscomp$477_vec__53003$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$978_c__5501__auto__$jscomp$30_value$jscomp$477_vec__53003$$,1,null);if($APP.$cljs$core$not$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$978_c__5501__auto__$jscomp$30_value$jscomp$477_vec__53003$$)))return $APP.$cljs$core$cons$$((0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$shape_custom_stroke$$,{shape:$shape$jscomp$331$$,stroke:$JSCompiler_inline_result$jscomp$978_c__5501__auto__$jscomp$30_value$jscomp$477_vec__53003$$,
index:$b__52989_index$jscomp$237$$,children:$app$main$ui$shapes$custom_stroke$build_stroke_element$$($child$jscomp$78$$,$JSCompiler_inline_result$jscomp$978_c__5501__auto__$jscomp$30_value$jscomp$477_vec__53003$$,$b__52989_index$jscomp$237$$,$render_id__$1$jscomp$2$$,$open_path_QMARK_$jscomp$4$$)},""+($b__52989_index$jscomp$237$$??"")+"-"+($stroke_id$$??"")),$app$main$ui$shapes$custom_stroke$shape_strokes_$_iter__52986$$($APP.$cljs$core$rest$$($s__52987__$1_s__52987__$2_temp__5825__auto__$jscomp$159$$)));
$s__52987__$1_s__52987__$2_temp__5825__auto__$jscomp$159$$=$APP.$cljs$core$rest$$($s__52987__$1_s__52987__$2_temp__5825__auto__$jscomp$159$$)}else return null},null,null)}($APP.$cljs$core$reverse$$($APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_strokes__$1$$)))}())):null};
$app$main$ui$shapes$custom_stroke$shape_custom_strokes$$=function($props_53007$$){return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$custom_stroke$shape_fills$$,$props_53007$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$custom_stroke$shape_strokes$$,$props_53007$$)]})};
$app$main$ui$shapes$fills$internal_fills$$=function($image$jscomp$15_props_52949_transform$jscomp$68_uris$jscomp$7$$){var $shape$jscomp$332$$=$image$jscomp$15_props_52949_transform$jscomp$68_uris$jscomp$7$$.shape,$render_id$jscomp$21$$=$image$jscomp$15_props_52949_transform$jscomp$68_uris$jscomp$7$$["render-id"],$type$jscomp$407$$=$shape$jscomp$332$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$332$$,$APP.$cljs$cst$139$type$$);$image$jscomp$15_props_52949_transform$jscomp$68_uris$jscomp$7$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$332$$,$APP.$cljs$cst$1632$fill_image$$);var $fills$jscomp$13_pat_props$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$332$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$selrect$jscomp$34$$=$shape$jscomp$332$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$332$$,$APP.$cljs$cst$1605$selrect$$),$bounds$jscomp$13$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$332$$)?
$APP.$app$common$geom$shapes$text$shape__GT_rect$$($shape$jscomp$332$$):null,$metadata$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$332$$,$cljs$cst$1633$metadata$$),$x$jscomp$1153$$=$selrect$jscomp$34$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$34$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$391$$=$selrect$jscomp$34$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$34$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$86$$=
$selrect$jscomp$34$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$34$$,$APP.$cljs$cst$290$width$$),$height$jscomp$77$$=$selrect$jscomp$34$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$34$$,$APP.$cljs$cst$1522$height$$),$has_image_QMARK_$$=$metadata$jscomp$6$$!=null||$image$jscomp$15_props_52949_transform$jscomp$68_uris$jscomp$7$$!=null,$uri$jscomp$76$$=$metadata$jscomp$6$$!=null?$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($metadata$jscomp$6$$):
$image$jscomp$15_props_52949_transform$jscomp$68_uris$jscomp$7$$!=null?$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($image$jscomp$15_props_52949_transform$jscomp$68_uris$jscomp$7$$):null;$image$jscomp$15_props_52949_transform$jscomp$68_uris$jscomp$7$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$uri$jscomp$76$$],null),$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1632$fill_image$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$resolve_file_media$$)),$fills$jscomp$13_pat_props$$);var $embed$jscomp$3$$=$app$main$ui$shapes$embed$use_data_uris$$($image$jscomp$15_props_52949_transform$jscomp$68_uris$jscomp$7$$);$image$jscomp$15_props_52949_transform$jscomp$68_uris$jscomp$7$$=$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$332$$);$fills$jscomp$13_pat_props$$={patternUnits:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,
$type$jscomp$407$$)?"objectBoundingBox":"userSpaceOnUse",x:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$type$jscomp$407$$)?null:$x$jscomp$1153$$,y:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$type$jscomp$407$$)?null:$y$jscomp$391$$,width:$width$jscomp$86$$,height:$height$jscomp$77$$};var $pat_props__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,$type$jscomp$407$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1610$bool$$,
$type$jscomp$407$$)?$APP.$app$util$object$set_BANG_$$($fills$jscomp$13_pat_props$$,"patternTransform",$image$jscomp$15_props_52949_transform$jscomp$68_uris$jscomp$7$$):$fills$jscomp$13_pat_props$$;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$17$$,$p__52951$$){var $obj_index$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52951$$,0,null),$obj$jscomp$192$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52951$$,
1,null);$out_arr__44124__auto__$jscomp$17$$.push((0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$$,$JSCompiler_temp_const$jscomp$10807_p__52955$$){var $JSCompiler_temp$jscomp$10809_fill_index_props__$1$jscomp$inline_12154$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$10807_p__52955$$,0,null),$G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$10807_p__52955$$,1,null);$JSCompiler_temp_const$jscomp$10807_p__52955$$=$out_arr__44124__auto____$1$$.push;if($APP.$cljs$cst$1748$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$)!=null)a:{$G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$=
$APP.$cljs$cst$1748$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$);var $from_p$jscomp$inline_12151$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1153$$+$width$jscomp$86$$*$APP.$cljs$cst$1729$start_x$$.$cljs$core$IFn$_invoke$arity$1$($G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$),$y$jscomp$391$$+
$height$jscomp$77$$*$APP.$cljs$cst$1730$start_y$$.$cljs$core$IFn$_invoke$arity$1$($G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$)),$to_p$jscomp$inline_12152$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1153$$+$width$jscomp$86$$*$APP.$cljs$cst$1731$end_x$$.$cljs$core$IFn$_invoke$arity$1$($G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$),$y$jscomp$391$$+
$height$jscomp$77$$*$APP.$cljs$cst$1732$end_y$$.$cljs$core$IFn$_invoke$arity$1$($G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$));$G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$=$bounds$jscomp$13$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$,
$APP.$cljs$cst$1729$start_x$$,($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($from_p$jscomp$inline_12151$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$13$$))/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$13$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1730$start_y$$,($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($from_p$jscomp$inline_12151$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$13$$))/
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$13$$),$APP.$cljs$cst$1731$end_x$$,($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($to_p$jscomp$inline_12152$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$13$$))/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$13$$),$APP.$cljs$cst$1732$end_y$$,($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($to_p$jscomp$inline_12152$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$13$$))/
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$13$$)])):$G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$;$JSCompiler_temp$jscomp$10809_fill_index_props__$1$jscomp$inline_12154$$={id:"fill-color-gradient-"+($render_id$jscomp$21$$??"")+"-"+($JSCompiler_temp$jscomp$10809_fill_index_props__$1$jscomp$inline_12154$$??""),key:""+($JSCompiler_temp$jscomp$10809_fill_index_props__$1$jscomp$inline_12154$$??""),gradient:$G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$,
shape:$obj$jscomp$192$$};$G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$=$APP.$app$common$data$name$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$));switch($G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$){case "linear":$JSCompiler_temp$jscomp$10809_fill_index_props__$1$jscomp$inline_12154$$=
(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$gradients$linear_gradient$$,$JSCompiler_temp$jscomp$10809_fill_index_props__$1$jscomp$inline_12154$$);break a;case "radial":$JSCompiler_temp$jscomp$10809_fill_index_props__$1$jscomp$inline_12154$$=(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$gradients$radial_gradient$$,$JSCompiler_temp$jscomp$10809_fill_index_props__$1$jscomp$inline_12154$$);break a;default:throw Error(["No matching clause: ",$G__52961$jscomp$inline_12155_gradient$jscomp$inline_12150_gradient__$1$jscomp$inline_12153_value$jscomp$479$$].join(""));
}}else $JSCompiler_temp$jscomp$10809_fill_index_props__$1$jscomp$inline_12154$$=null;$JSCompiler_temp_const$jscomp$10807_p__52955$$.call($out_arr__44124__auto____$1$$,$JSCompiler_temp$jscomp$10809_fill_index_props__$1$jscomp$inline_12154$$);return $out_arr__44124__auto____$1$$},[],$APP.$cljs$core$reverse$$($APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($obj$jscomp$192$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$)))),
function(){var $fill_id$$="fill-"+($obj_index$$??"")+"-"+($render_id$jscomp$21$$??"");return(0,$APP.$rumext$v2$create_element$$)("pattern",function(){var $G__52962_G__52963$jscomp$inline_5843$$=$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$clone$$($pat_props__$1$$),"id",$fill_id$$);$G__52962_G__52963$jscomp$inline_5843$$=$has_image_QMARK_$$&&$bounds$jscomp$13$$==null?$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($G__52962_G__52963$jscomp$inline_5843$$,"width",$width$jscomp$86$$*
1.05),"height",$height$jscomp$77$$*1.05):$G__52962_G__52963$jscomp$inline_5843$$;return $bounds$jscomp$13$$!=null?$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($G__52962_G__52963$jscomp$inline_5843$$,"width",$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$13$$)),"height",$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$13$$)):$G__52962_G__52963$jscomp$inline_5843$$}(),(0,$APP.$rumext$v2$jsxs$$)("g",{children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$1$$,
$JSCompiler_temp_const$jscomp$979_p__52965$$){var $JSCompiler_inline_result$jscomp$981_fill_index$jscomp$1_image_props$jscomp$inline_5849$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$979_p__52965$$,0,null),$value$jscomp$480$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$979_p__52965$$,1,null);$JSCompiler_temp_const$jscomp$979_p__52965$$=$out_arr__44124__auto____$1$jscomp$1$$.push;var $props__$1$jscomp$inline_5846_style$jscomp$inline_5845_uri__$1$jscomp$inline_5847$$=
$app$main$ui$shapes$attrs$add_fill_BANG_$cljs$0core$0IFn$0_invoke$0arity$06$$($value$jscomp$480$$,$render_id$jscomp$21$$,$JSCompiler_inline_result$jscomp$981_fill_index$jscomp$1_image_props$jscomp$inline_5849$$,$type$jscomp$407$$,"none");$props__$1$jscomp$inline_5846_style$jscomp$inline_5845_uri__$1$jscomp$inline_5847$$={key:""+($JSCompiler_inline_result$jscomp$981_fill_index$jscomp$1_image_props$jscomp$inline_5849$$??""),width:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$13$$),
$width$jscomp$86$$),height:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$13$$),$height$jscomp$77$$),style:$props__$1$jscomp$inline_5846_style$jscomp$inline_5845_uri__$1$jscomp$inline_5847$$};if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$480$$))){$props__$1$jscomp$inline_5846_style$jscomp$inline_5845_uri__$1$jscomp$inline_5847$$=$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$480$$));
var $keep_ar_QMARK_$jscomp$inline_5848$$=$APP.$cljs$cst$1727$keep_aspect_ratio$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$480$$));$JSCompiler_inline_result$jscomp$981_fill_index$jscomp$1_image_props$jscomp$inline_5849$$={id:"fill-image-"+($render_id$jscomp$21$$??"")+"-"+($JSCompiler_inline_result$jscomp$981_fill_index$jscomp$1_image_props$jscomp$inline_5849$$??""),href:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($embed$jscomp$3$$,
$props__$1$jscomp$inline_5846_style$jscomp$inline_5845_uri__$1$jscomp$inline_5847$$,$props__$1$jscomp$inline_5846_style$jscomp$inline_5845_uri__$1$jscomp$inline_5847$$),preserveAspectRatio:$APP.$cljs$core$truth_$$($keep_ar_QMARK_$jscomp$inline_5848$$)?"xMidYMid slice":"none",width:$width$jscomp$86$$,height:$height$jscomp$77$$,key:""+($JSCompiler_inline_result$jscomp$981_fill_index$jscomp$1_image_props$jscomp$inline_5849$$??""),opacity:$APP.$cljs$cst$1747$fill_opacity$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$480$$)};
$JSCompiler_inline_result$jscomp$981_fill_index$jscomp$1_image_props$jscomp$inline_5849$$=(0,$APP.$rumext$v2$create_element$$)("image",$JSCompiler_inline_result$jscomp$981_fill_index$jscomp$1_image_props$jscomp$inline_5849$$)}else $JSCompiler_inline_result$jscomp$981_fill_index$jscomp$1_image_props$jscomp$inline_5849$$=(0,$APP.$rumext$v2$create_element$$)("rect",$props__$1$jscomp$inline_5846_style$jscomp$inline_5845_uri__$1$jscomp$inline_5847$$);$JSCompiler_temp_const$jscomp$979_p__52965$$.call($out_arr__44124__auto____$1$jscomp$1$$,
$JSCompiler_inline_result$jscomp$981_fill_index$jscomp$1_image_props$jscomp$inline_5849$$);return $out_arr__44124__auto____$1$jscomp$1$$},[],$APP.$cljs$core$reverse$$($APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($obj$jscomp$192$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$)))),$has_image_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("g",{children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:0,y:0,width:$width$jscomp$86$$*
1.05,height:$height$jscomp$77$$*1.05,fill:"none"}),(0,$APP.$rumext$v2$jsx$$)("image",{href:$uri$jscomp$76$$,preserveAspectRatio:"none",x:0,y:0,width:$width$jscomp$86$$,height:$height$jscomp$77$$})]}):null]}))}()]},""+($obj_index$$??"")));return $out_arr__44124__auto__$jscomp$17$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $or__5025__auto__$jscomp$517$$=$APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$332$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$517$$)?
$or__5025__auto__$jscomp$517$$:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$332$$],null)}()))};
$app$main$ui$shapes$fills$fills$$=function($props_52970$$){var $shape$jscomp$333$$=$props_52970$$.shape,$type$jscomp$408$$=$shape$jscomp$333$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$333$$,$APP.$cljs$cst$139$type$$),$image$jscomp$16$$=$APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$333$$),$fills__$1$jscomp$4$$=$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$333$$,$APP.$cljs$core$PersistentVector$EMPTY$$);return $APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$518_or__5025__auto____$1$jscomp$56_or__5025__auto____$2$jscomp$16_or__5025__auto____$3$jscomp$7$$=
$image$jscomp$16$$!=null;if($or__5025__auto__$jscomp$518_or__5025__auto____$1$jscomp$56_or__5025__auto____$2$jscomp$16_or__5025__auto____$3$jscomp$7$$||($or__5025__auto__$jscomp$518_or__5025__auto____$1$jscomp$56_or__5025__auto____$2$jscomp$16_or__5025__auto____$3$jscomp$7$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$408$$,$APP.$cljs$cst$1612$image$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$408$$,$APP.$cljs$cst$1588$text$$))||($or__5025__auto__$jscomp$518_or__5025__auto____$1$jscomp$56_or__5025__auto____$2$jscomp$16_or__5025__auto____$3$jscomp$7$$=
$APP.$cljs$core$count$$($fills__$1$jscomp$4$$)>1))return $or__5025__auto__$jscomp$518_or__5025__auto____$1$jscomp$56_or__5025__auto____$2$jscomp$16_or__5025__auto____$3$jscomp$7$$;$or__5025__auto__$jscomp$518_or__5025__auto____$1$jscomp$56_or__5025__auto____$2$jscomp$16_or__5025__auto____$3$jscomp$7$$=$APP.$cljs$core$some$$($APP.$cljs$cst$1748$fill_color_gradient$$,$fills__$1$jscomp$4$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$518_or__5025__auto____$1$jscomp$56_or__5025__auto____$2$jscomp$16_or__5025__auto____$3$jscomp$7$$)?
$or__5025__auto__$jscomp$518_or__5025__auto____$1$jscomp$56_or__5025__auto____$2$jscomp$16_or__5025__auto____$3$jscomp$7$$:$APP.$cljs$core$some$$($APP.$cljs$cst$1632$fill_image$$,$fills__$1$jscomp$4$$)}())?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$fills$internal_fills$$,$props_52970$$):null};
$app$main$ui$shapes$text$svg_text$set_white_fill$$=function($shape$jscomp$334$$){function $update_color$$($data$jscomp$252$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($data$jscomp$252$$,$APP.$cljs$cst$1746$fill_color$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1747$fill_opacity$$,$APP.$cljs$cst$1748$fill_color_gradient$$])),$APP.$cljs$cst$1634$fills$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1746$fill_color$$,"#FFFFFF",$APP.$cljs$cst$1747$fill_opacity$$,1],null)],null))}return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$data$update_when$$($shape$jscomp$334$$,$APP.$cljs$cst$1891$position_data$$,function($p1__53026_SHARP_$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($update_color$$,$p1__53026_SHARP_$$)}),$APP.$cljs$cst$1739$stroke_color$$,
"#FFFFFF",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1740$stroke_opacity$$,1]))};
$app$main$ui$shapes$text$load_fonts_BANG_$$=function($content$jscomp$122$$){var $extract_fn$$=$APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$1759$font_variant_id$$),$default$$jscomp$56$$=$extract_fn$$($APP.$app$common$types$text$default_typography$$);return $APP.$cljs$core$run_BANG_$$(function($p__53220_variant_id$jscomp$3$$){var $font_id$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__53220_variant_id$jscomp$3$$,0,null);
$p__53220_variant_id$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__53220_variant_id$jscomp$3$$,1,null);return $font_id$jscomp$8$$!=null?$APP.$app$main$fonts$ensure_loaded_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($font_id$jscomp$8$$,$p__53220_variant_id$jscomp$3$$):null},$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$default$$jscomp$56$$]),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($extract_fn$$),
$APP.$cljs$core$tree_seq$$($APP.$cljs$core$map_QMARK_$$,$APP.$cljs$cst$342$children$$,$content$jscomp$122$$)))};
$APP.$app$main$ui$shapes$text$text_shape$$=function($props_53224$$){var $map__53225__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_53224$$,"shape")),$position_data$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53225__$1$$,$APP.$cljs$cst$1891$position_data$$),$content$jscomp$123$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53225__$1$$,$APP.$cljs$cst$1637$content$$),$is_render_QMARK_$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$is_render_QMARK_$$),
$is_component_QMARK_$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$is_component_QMARK_$$);$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($content$jscomp$123$$)],function(){return $app$main$ui$shapes$text$load_fonts_BANG_$$($content$jscomp$123$$)});return $position_data$jscomp$5$$!=null?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$text$svg_text$text_shape$$,$props_53224$$):$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$329$$=
$position_data$jscomp$5$$==null;return $and__5023__auto__$jscomp$329$$?$APP.$cljs$core$truth_$$($is_component_QMARK_$$)?$is_component_QMARK_$$:$is_render_QMARK_$$:$and__5023__auto__$jscomp$329$$}())?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$text$fo_text$text_shape$$,$props_53224$$):null};
$app$render_wasm$wasm$module_ready_QMARK_$$=function(){var $and__5023__auto__$jscomp$330$$=$APP.$app$render_wasm$wasm$internal_module$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$330$$)?$APP.$cljs$core$fn_QMARK_$$($APP.$app$render_wasm$wasm$internal_module$$._init):$and__5023__auto__$jscomp$330$$};
$app$render_wasm$wasm$reset_context_state_BANG_$$=function(){$app$render_wasm$wasm$gl_context$$=$app$render_wasm$wasm$gl_context_handle$$=$APP.$app$render_wasm$wasm$canvas_snapshot_url$$=$app$render_wasm$wasm$canvas$$=$app$render_wasm$wasm$internal_frame_id$$=null;$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$=!1;$APP.$cljs$core$reset_BANG_$$($app$render_wasm$wasm$context_lost_QMARK_$$,!1)};
$app$render_wasm$api$fonts$google_font_id__GT_uuid$$=function($font$jscomp$19_font_id$jscomp$9_or__5025__auto__$jscomp$520$$){$font$jscomp$19_font_id$jscomp$9_or__5025__auto__$jscomp$520$$=$APP.$app$main$fonts$get_font_data$$($font$jscomp$19_font_id$jscomp$9_or__5025__auto__$jscomp$520$$);$font$jscomp$19_font_id$jscomp$9_or__5025__auto__$jscomp$520$$=$cljs$cst$424$uuid$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$19_font_id$jscomp$9_or__5025__auto__$jscomp$520$$);return $APP.$cljs$core$truth_$$($font$jscomp$19_font_id$jscomp$9_or__5025__auto__$jscomp$520$$)?
$font$jscomp$19_font_id$jscomp$9_or__5025__auto__$jscomp$520$$:$APP.$app$common$uuid$zero$$};$app$render_wasm$api$fonts$font_backend$$=function($font_id$jscomp$11$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($font_id$jscomp$11$$,"gfont-")?$cljs$cst$2679$google$$:$APP.$cuerdas$core$starts_with_QMARK_$$($font_id$jscomp$11$$,"custom-")?$cljs$cst$2682$custom$$:$cljs$cst$2678$builtin$$};
$app$render_wasm$api$fonts$font_db_data$$=function($font$jscomp$20_font_id$jscomp$12$$,$font_variant_id$jscomp$6_variant$jscomp$8$$,$closest_variant_font_weight_fallback$$,$font_style_fallback$$){$font$jscomp$20_font_id$jscomp$12$$=$APP.$app$main$fonts$get_font_data$$($font$jscomp$20_font_id$jscomp$12$$);$closest_variant_font_weight_fallback$$=$app$main$fonts$find_closest_variant$$($font$jscomp$20_font_id$jscomp$12$$,$closest_variant_font_weight_fallback$$,$font_style_fallback$$);$font_variant_id$jscomp$6_variant$jscomp$8$$=
$APP.$app$main$fonts$get_variant$$($font$jscomp$20_font_id$jscomp$12$$,$font_variant_id$jscomp$6_variant$jscomp$8$$);return $closest_variant_font_weight_fallback$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($closest_variant_font_weight_fallback$$,$font_variant_id$jscomp$6_variant$jscomp$8$$)?$font_variant_id$jscomp$6_variant$jscomp$8$$:$closest_variant_font_weight_fallback$$};
$app$render_wasm$api$fonts$font_id__GT_uuid$$=function($font_id$jscomp$13$$){var $G__53096_G__53096__$1$$=$app$render_wasm$api$fonts$font_backend$$($font_id$jscomp$13$$);$G__53096_G__53096__$1$$=$G__53096_G__53096__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__53096_G__53096__$1$$.$fqn$:null;switch($G__53096_G__53096__$1$$){case "google":return $app$render_wasm$api$fonts$google_font_id__GT_uuid$$($font_id$jscomp$13$$);case "custom":return $app$common$uuid$uuid$$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($font_id$jscomp$13$$,
$APP.$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($font_id$jscomp$13$$,"-")+1));case "builtin":return $APP.$app$common$uuid$zero$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__53096_G__53096__$1$$)].join(""));}};
$app$render_wasm$api$fonts$uuid__GT_font_id$$=function($font_uuid$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font_uuid$$,$APP.$app$common$uuid$zero$$))return"sourcesanspro";var $or__5025__auto__$jscomp$521$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$fonts$find_font_data$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$424$uuid$$,$font_uuid$$],null)));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$521$$)?$or__5025__auto__$jscomp$521$$:
"custom-"+($font_uuid$$??"")};
$app$render_wasm$api$fonts$font_id__GT_asset_id$$=function($font_id$jscomp$15_matching_font_variant$jscomp$9$$,$font_variant_id$jscomp$7$$,$font_weight$jscomp$3$$,$font_style$jscomp$2$$){var $G__53099_G__53099__$1$$=$app$render_wasm$api$fonts$font_backend$$($font_id$jscomp$15_matching_font_variant$jscomp$9$$);$G__53099_G__53099__$1$$=$G__53099_G__53099__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__53099_G__53099__$1$$.$fqn$:null;switch($G__53099_G__53099__$1$$){case "google":return $font_id$jscomp$15_matching_font_variant$jscomp$9$$;case "custom":var $font_uuid$jscomp$1$$=
$app$common$uuid$uuid$$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($font_id$jscomp$15_matching_font_variant$jscomp$9$$,$APP.$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($font_id$jscomp$15_matching_font_variant$jscomp$9$$,"-")+1));$font_id$jscomp$15_matching_font_variant$jscomp$9$$=$APP.$cljs$core$some$$(function($font$jscomp$21_p__53100$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font$jscomp$21_p__53100$$,0,null);$font$jscomp$21_p__53100$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font$jscomp$21_p__53100$$,
1,null);var $and__5023__auto__$jscomp$331_and__5023__auto____$1$jscomp$60_and__5023__auto____$2$jscomp$26$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$21_p__53100$$),$font_uuid$jscomp$1$$);return $and__5023__auto__$jscomp$331_and__5023__auto____$1$jscomp$60_and__5023__auto____$2$jscomp$26$$?($and__5023__auto__$jscomp$331_and__5023__auto____$1$jscomp$60_and__5023__auto____$2$jscomp$26$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$21_p__53100$$)),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($font_weight$jscomp$3$$)))?($and__5023__auto__$jscomp$331_and__5023__auto____$1$jscomp$60_and__5023__auto____$2$jscomp$26$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$21_p__53100$$),$font_style$jscomp$2$$))?$font$jscomp$21_p__53100$$:$and__5023__auto__$jscomp$331_and__5023__auto____$1$jscomp$60_and__5023__auto____$2$jscomp$26$$:$and__5023__auto__$jscomp$331_and__5023__auto____$1$jscomp$60_and__5023__auto____$2$jscomp$26$$:
$and__5023__auto__$jscomp$331_and__5023__auto____$1$jscomp$60_and__5023__auto____$2$jscomp$26$$},$APP.$cljs$core$seq$$($APP.$cljs$core$_deref$$($app$render_wasm$api$fonts$fonts$$)));return $APP.$cljs$core$truth_$$($font_id$jscomp$15_matching_font_variant$jscomp$9$$)?$cljs$cst$2970$ttf_file_id$$.$cljs$core$IFn$_invoke$arity$1$($font_id$jscomp$15_matching_font_variant$jscomp$9$$):null;case "builtin":return $font_id$jscomp$15_matching_font_variant$jscomp$9$$=$app$render_wasm$api$fonts$font_db_data$$($font_id$jscomp$15_matching_font_variant$jscomp$9$$,
$font_variant_id$jscomp$7$$,$font_weight$jscomp$3$$,$font_style$jscomp$2$$),$cljs$cst$2677$ttf_url$$.$cljs$core$IFn$_invoke$arity$1$($font_id$jscomp$15_matching_font_variant$jscomp$9$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__53099_G__53099__$1$$)].join(""));}};
$app$render_wasm$api$fonts$update_text_layout$$=function($cause53105_id$jscomp$313_shape_id_buffer$$){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){$cause53105_id$jscomp$313_shape_id_buffer$$=$APP.$app$common$uuid$get_u32$$($cause53105_id$jscomp$313_shape_id_buffer$$);var $code__52999__auto___code_num__52998__auto___fn_53104_read_code_fn__52997__auto__$$=$APP.$app$render_wasm$wasm$internal_module$$._update_shape_text_layout_for;try{return $code__52999__auto___code_num__52998__auto___fn_53104_read_code_fn__52997__auto__$$($cause53105_id$jscomp$313_shape_id_buffer$$[0],
$cause53105_id$jscomp$313_shape_id_buffer$$[1],$cause53105_id$jscomp$313_shape_id_buffer$$[2],$cause53105_id$jscomp$313_shape_id_buffer$$[3])}catch($e53106$$){$cause53105_id$jscomp$313_shape_id_buffer$$=$e53106$$;$code__52999__auto___code_num__52998__auto___fn_53104_read_code_fn__52997__auto__$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___code_num__52998__auto___fn_53104_read_code_fn__52997__auto__$$=$APP.$cljs$core$truth_$$($code__52999__auto___code_num__52998__auto___fn_53104_read_code_fn__52997__auto__$$)?
$code__52999__auto___code_num__52998__auto___fn_53104_read_code_fn__52997__auto__$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___code_num__52998__auto___fn_53104_read_code_fn__52997__auto__$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___code_num__52998__auto___fn_53104_read_code_fn__52997__auto__$$():null;$code__52999__auto___code_num__52998__auto___fn_53104_read_code_fn__52997__auto__$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code__52999__auto___code_num__52998__auto___fn_53104_read_code_fn__52997__auto__$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___code_num__52998__auto___fn_53104_read_code_fn__52997__auto__$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_update_shape_text_layout_for",$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___code_num__52998__auto___fn_53104_read_code_fn__52997__auto__$$],null),$cause53105_id$jscomp$313_shape_id_buffer$$);}}else return null};
$app$render_wasm$api$fonts$fetch_font$$=function($font_data$jscomp$1$$,$font_url$$,$emoji_QMARK_$jscomp$1$$,$fallback_QMARK_$jscomp$1$$){if($APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($app$render_wasm$api$fonts$fetching$$),$font_url$$))return $APP.$cljs$core$truth_$$($fallback_QMARK_$jscomp$1$$)&&$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$render_wasm$api$fonts$fetching$$,$APP.$cljs$core$assoc$$,$font_url$$,!0),null;$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$render_wasm$api$fonts$fetching$$,
$APP.$cljs$core$assoc$$,$font_url$$,$fallback_QMARK_$jscomp$1$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$font_url$$,$APP.$cljs$cst$2354$callback$$,function(){return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$41$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$render_wasm$api$fonts$fetching$$,$APP.$cljs$core$dissoc$$,$font_url$$);$APP.$app$common$logging$enabled_QMARK_$$("app.render-wasm.api.fonts",
$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"Could not fetch font"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2975$font_url$$,$font_url$$],null)],null)}),
$cause$jscomp$41$$,"app.render-wasm.api.fonts",$APP.$cljs$cst$849$error$$,!1);return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$map$$(function($code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$){$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$=
$APP.$cljs$core$__destructure_map$$($code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$);var $body$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$,
$APP.$cljs$cst$1581$body$$);$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($app$render_wasm$api$fonts$fetching$$),$font_url$$,$fallback_QMARK_$jscomp$1$$);
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$render_wasm$api$fonts$fetching$$,$APP.$cljs$core$dissoc$$,$font_url$$);if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $font_id_buffer$jscomp$inline_12170_hint__53000__auto__$jscomp$inline_12178_hint__53000__auto___53216$jscomp$inline_12184$$=$cljs$cst$2973$family_id_buffer$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$1$$),$size$jscomp$inline_12171$$=$body$jscomp$11$$.byteLength;var $fn_53110$jscomp$inline_12173$$=
$APP.$app$render_wasm$wasm$internal_module$$._alloc_bytes;try{var $JSCompiler_inline_result$jscomp$10814_cause53111$jscomp$inline_12174_cause53117_53212$jscomp$inline_12180_fn_53116_53207$jscomp$inline_12179_ptr$jscomp$inline_12172$$=$fn_53110$jscomp$inline_12173$$($size$jscomp$inline_12171$$)}catch($e53113$jscomp$inline_12185$$){throw $JSCompiler_inline_result$jscomp$10814_cause53111$jscomp$inline_12174_cause53117_53212$jscomp$inline_12180_fn_53116_53207$jscomp$inline_12179_ptr$jscomp$inline_12172$$=
$e53113$jscomp$inline_12185$$,$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$)?$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$():
null,$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$,
$APP.$cljs$cst$2971$wasm_critical$$),$font_id_buffer$jscomp$inline_12170_hint__53000__auto__$jscomp$inline_12178_hint__53000__auto___53216$jscomp$inline_12184$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($font_id_buffer$jscomp$inline_12170_hint__53000__auto__$jscomp$inline_12178_hint__53000__auto___53216$jscomp$inline_12184$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_alloc_bytes",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$font_id_buffer$jscomp$inline_12170_hint__53000__auto__$jscomp$inline_12178_hint__53000__auto___53216$jscomp$inline_12184$$,$APP.$cljs$cst$273$code$$,
$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$],null),$JSCompiler_inline_result$jscomp$10814_cause53111$jscomp$inline_12174_cause53117_53212$jscomp$inline_12180_fn_53116_53207$jscomp$inline_12179_ptr$jscomp$inline_12172$$);
}(new Uint8Array($APP.$module$contents$goog$object_get$$($APP.$app$render_wasm$wasm$internal_module$$,"HEAPU8").buffer,$JSCompiler_inline_result$jscomp$10814_cause53111$jscomp$inline_12174_cause53117_53212$jscomp$inline_12180_fn_53116_53207$jscomp$inline_12179_ptr$jscomp$inline_12172$$,$size$jscomp$inline_12171$$)).set(new Uint8Array($body$jscomp$11$$));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2974$font_loaded$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$1$$)],null)));$JSCompiler_inline_result$jscomp$10814_cause53111$jscomp$inline_12174_cause53117_53212$jscomp$inline_12180_fn_53116_53207$jscomp$inline_12179_ptr$jscomp$inline_12172$$=$APP.$app$render_wasm$wasm$internal_module$$._store_font;try{$JSCompiler_inline_result$jscomp$10814_cause53111$jscomp$inline_12174_cause53117_53212$jscomp$inline_12180_fn_53116_53207$jscomp$inline_12179_ptr$jscomp$inline_12172$$($font_id_buffer$jscomp$inline_12170_hint__53000__auto__$jscomp$inline_12178_hint__53000__auto___53216$jscomp$inline_12184$$[0],
$font_id_buffer$jscomp$inline_12170_hint__53000__auto__$jscomp$inline_12178_hint__53000__auto___53216$jscomp$inline_12184$$[1],$font_id_buffer$jscomp$inline_12170_hint__53000__auto__$jscomp$inline_12178_hint__53000__auto___53216$jscomp$inline_12184$$[2],$font_id_buffer$jscomp$inline_12170_hint__53000__auto__$jscomp$inline_12178_hint__53000__auto___53216$jscomp$inline_12184$$[3],$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$1$$),$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$1$$),
$emoji_QMARK_$jscomp$1$$,$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$)}catch($e53118$jscomp$inline_12186$$){throw $JSCompiler_inline_result$jscomp$10814_cause53111$jscomp$inline_12174_cause53117_53212$jscomp$inline_12180_fn_53116_53207$jscomp$inline_12179_ptr$jscomp$inline_12172$$=
$e53118$jscomp$inline_12186$$,$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$)?$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$():
null,$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$,
$APP.$cljs$cst$2971$wasm_critical$$),$font_id_buffer$jscomp$inline_12170_hint__53000__auto__$jscomp$inline_12178_hint__53000__auto___53216$jscomp$inline_12184$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($font_id_buffer$jscomp$inline_12170_hint__53000__auto__$jscomp$inline_12178_hint__53000__auto___53216$jscomp$inline_12184$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_store_font",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$font_id_buffer$jscomp$inline_12170_hint__53000__auto__$jscomp$inline_12178_hint__53000__auto___53216$jscomp$inline_12184$$,$APP.$cljs$cst$273$code$$,
$code__52999__auto__$jscomp$inline_12177_code__52999__auto___53215$jscomp$inline_12183_code_num__52998__auto__$jscomp$inline_12176_code_num__52998__auto___53214$jscomp$inline_12182_fallback_QMARK___$1_map__53138__$1_p__53137_read_code_fn__52997__auto__$jscomp$inline_12175_read_code_fn__52997__auto___53213$jscomp$inline_12181$$],null),$JSCompiler_inline_result$jscomp$10814_cause53111$jscomp$inline_12174_cause53117_53212$jscomp$inline_12180_fn_53116_53207$jscomp$inline_12179_ptr$jscomp$inline_12172$$);
}$JSCompiler_inline_result$jscomp$10814_cause53111$jscomp$inline_12174_cause53117_53212$jscomp$inline_12180_fn_53116_53207$jscomp$inline_12179_ptr$jscomp$inline_12172$$=!0}else $JSCompiler_inline_result$jscomp$10814_cause53111$jscomp$inline_12174_cause53117_53212$jscomp$inline_12180_fn_53116_53207$jscomp$inline_12179_ptr$jscomp$inline_12172$$=null;return $JSCompiler_inline_result$jscomp$10814_cause53111$jscomp$inline_12174_cause53117_53212$jscomp$inline_12180_fn_53116_53207$jscomp$inline_12179_ptr$jscomp$inline_12172$$},
$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$,$APP.$cljs$cst$1579$uri$$,$font_url$$,$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$194$buffer$$],null))))}],null)};
$app$render_wasm$api$fonts$font_stored_QMARK_$$=function($JSCompiler_temp$jscomp$985_cause53147$jscomp$inline_5864_font_data$jscomp$2$$,$code__52999__auto__$jscomp$inline_5867_code_num__52998__auto__$jscomp$inline_5866_emoji_QMARK_$jscomp$2_read_code_fn__52997__auto__$jscomp$inline_5865$$){var $hint__53000__auto__$jscomp$inline_5868_temp__5825__auto__$jscomp$160$$=$APP.$app$common$uuid$get_u32$$($cljs$cst$2976$wasm_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$985_cause53147$jscomp$inline_5864_font_data$jscomp$2$$));
if($APP.$cljs$core$truth_$$($hint__53000__auto__$jscomp$inline_5868_temp__5825__auto__$jscomp$160$$)){var $JSCompiler_temp_const$jscomp$986$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$;var $fn_53146$jscomp$inline_5863$$=$APP.$app$render_wasm$wasm$internal_module$$._is_font_uploaded;try{var $JSCompiler_inline_result$jscomp$988$$=$fn_53146$jscomp$inline_5863$$($hint__53000__auto__$jscomp$inline_5868_temp__5825__auto__$jscomp$160$$[0],$hint__53000__auto__$jscomp$inline_5868_temp__5825__auto__$jscomp$160$$[1],
$hint__53000__auto__$jscomp$inline_5868_temp__5825__auto__$jscomp$160$$[2],$hint__53000__auto__$jscomp$inline_5868_temp__5825__auto__$jscomp$160$$[3],$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$985_cause53147$jscomp$inline_5864_font_data$jscomp$2$$),$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$985_cause53147$jscomp$inline_5864_font_data$jscomp$2$$),$code__52999__auto__$jscomp$inline_5867_code_num__52998__auto__$jscomp$inline_5866_emoji_QMARK_$jscomp$2_read_code_fn__52997__auto__$jscomp$inline_5865$$)}catch($e53148$jscomp$inline_5869$$){throw $JSCompiler_temp$jscomp$985_cause53147$jscomp$inline_5864_font_data$jscomp$2$$=
$e53148$jscomp$inline_5869$$,$code__52999__auto__$jscomp$inline_5867_code_num__52998__auto__$jscomp$inline_5866_emoji_QMARK_$jscomp$2_read_code_fn__52997__auto__$jscomp$inline_5865$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$inline_5867_code_num__52998__auto__$jscomp$inline_5866_emoji_QMARK_$jscomp$2_read_code_fn__52997__auto__$jscomp$inline_5865$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_5867_code_num__52998__auto__$jscomp$inline_5866_emoji_QMARK_$jscomp$2_read_code_fn__52997__auto__$jscomp$inline_5865$$)?
$code__52999__auto__$jscomp$inline_5867_code_num__52998__auto__$jscomp$inline_5866_emoji_QMARK_$jscomp$2_read_code_fn__52997__auto__$jscomp$inline_5865$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$inline_5867_code_num__52998__auto__$jscomp$inline_5866_emoji_QMARK_$jscomp$2_read_code_fn__52997__auto__$jscomp$inline_5865$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$inline_5867_code_num__52998__auto__$jscomp$inline_5866_emoji_QMARK_$jscomp$2_read_code_fn__52997__auto__$jscomp$inline_5865$$():
null,$code__52999__auto__$jscomp$inline_5867_code_num__52998__auto__$jscomp$inline_5866_emoji_QMARK_$jscomp$2_read_code_fn__52997__auto__$jscomp$inline_5865$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$inline_5867_code_num__52998__auto__$jscomp$inline_5866_emoji_QMARK_$jscomp$2_read_code_fn__52997__auto__$jscomp$inline_5865$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto__$jscomp$inline_5868_temp__5825__auto__$jscomp$160$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_5867_code_num__52998__auto__$jscomp$inline_5866_emoji_QMARK_$jscomp$2_read_code_fn__52997__auto__$jscomp$inline_5865$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$inline_5868_temp__5825__auto__$jscomp$160$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_is_font_uploaded",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53000__auto__$jscomp$inline_5868_temp__5825__auto__$jscomp$160$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_5867_code_num__52998__auto__$jscomp$inline_5866_emoji_QMARK_$jscomp$2_read_code_fn__52997__auto__$jscomp$inline_5865$$],null),$JSCompiler_temp$jscomp$985_cause53147$jscomp$inline_5864_font_data$jscomp$2$$);}$JSCompiler_temp$jscomp$985_cause53147$jscomp$inline_5864_font_data$jscomp$2$$=$JSCompiler_temp_const$jscomp$986$$.call($APP.$cljs$core$not_EQ_$$,0,$JSCompiler_inline_result$jscomp$988$$)}else $JSCompiler_temp$jscomp$985_cause53147$jscomp$inline_5864_font_data$jscomp$2$$=
null;return $JSCompiler_temp$jscomp$985_cause53147$jscomp$inline_5864_font_data$jscomp$2$$};$app$render_wasm$api$fonts$serialize_font_style$$=function($font_style$jscomp$5$$){switch($font_style$jscomp$5$$){case "normal":return 0;case "regular":return 0;case "italic":return 1;default:return 0}};
$app$render_wasm$api$fonts$normalize_font_id$$=function($font_id$jscomp$18$$){try{if($APP.$cuerdas$core$starts_with_QMARK_$$($font_id$jscomp$18$$,"gfont-"))return $app$render_wasm$api$fonts$google_font_id__GT_uuid$$($font_id$jscomp$18$$);var $no_prefix$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($font_id$jscomp$18$$,$APP.$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($font_id$jscomp$18$$,"-")+1);return $no_prefix$$==null||typeof $no_prefix$$!=="string"||$APP.$cuerdas$core$blank_QMARK_$$($no_prefix$$)?
$APP.$app$common$uuid$zero$$:$APP.$app$common$uuid$parse$$($no_prefix$$)}catch($e53151$$){return $APP.$app$common$uuid$zero$$}};
$app$render_wasm$api$fonts$normalize_span_font$$=function($span$$,$paragraph$$){var $font_id$jscomp$19$$=$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($span$$),$font_variant_id$jscomp$10$$=$APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($span$$),$font_weight_fallback$jscomp$1$$=function(){var $or__5025__auto__$jscomp$523$$=$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($span$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$523$$)?
$or__5025__auto__$jscomp$523$$:$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$$)}(),$font_style_fallback$jscomp$1$$=function(){var $or__5025__auto__$jscomp$524$$=$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($span$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$524$$)?$or__5025__auto__$jscomp$524$$:$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$$)}(),$font_data$jscomp$4$$=$app$render_wasm$api$fonts$font_db_data$$($font_id$jscomp$19$$,
$font_variant_id$jscomp$10$$,$font_weight_fallback$jscomp$1$$,$font_style_fallback$jscomp$1$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($span$$,$APP.$cljs$cst$1759$font_variant_id$$,function(){var $or__5025__auto__$jscomp$525_or__5025__auto____$1$jscomp$57$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$4$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$525_or__5025__auto____$1$jscomp$57$$))return $or__5025__auto__$jscomp$525_or__5025__auto____$1$jscomp$57$$;
$or__5025__auto__$jscomp$525_or__5025__auto____$1$jscomp$57$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$4$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$525_or__5025__auto____$1$jscomp$57$$)?$or__5025__auto__$jscomp$525_or__5025__auto____$1$jscomp$57$$:$font_variant_id$jscomp$10$$}(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1761$font_weight$$,function(){var $or__5025__auto__$jscomp$526$$=$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$4$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$526$$)?$or__5025__auto__$jscomp$526$$:$font_weight_fallback$jscomp$1$$}(),$APP.$cljs$cst$1762$font_style$$,function(){var $or__5025__auto__$jscomp$527$$=$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$4$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$527$$)?$or__5025__auto__$jscomp$527$$:$font_style_fallback$jscomp$1$$}()]))};
$app$render_wasm$api$fonts$normalize_paragraph_font$$=function($paragraph$jscomp$1$$){var $font_id$jscomp$20$$=$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$1$$),$font_variant_id$jscomp$11$$=$APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$1$$),$font_weight_fallback$jscomp$2$$=$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$1$$),$font_style_fallback$jscomp$2$$=$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$1$$),
$font_data$jscomp$5$$=$app$render_wasm$api$fonts$font_db_data$$($font_id$jscomp$20$$,$font_variant_id$jscomp$11$$,$font_weight_fallback$jscomp$2$$,$font_style_fallback$jscomp$2$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($paragraph$jscomp$1$$,$APP.$cljs$cst$1759$font_variant_id$$,function(){var $or__5025__auto__$jscomp$528_or__5025__auto____$1$jscomp$58$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$5$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$528_or__5025__auto____$1$jscomp$58$$))return $or__5025__auto__$jscomp$528_or__5025__auto____$1$jscomp$58$$;
$or__5025__auto__$jscomp$528_or__5025__auto____$1$jscomp$58$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$5$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$528_or__5025__auto____$1$jscomp$58$$)?$or__5025__auto__$jscomp$528_or__5025__auto____$1$jscomp$58$$:$font_variant_id$jscomp$11$$}(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1761$font_weight$$,function(){var $or__5025__auto__$jscomp$529$$=$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$5$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$529$$)?$or__5025__auto__$jscomp$529$$:$font_weight_fallback$jscomp$2$$}(),$APP.$cljs$cst$1762$font_style$$,function(){var $or__5025__auto__$jscomp$530$$=$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$5$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$530$$)?$or__5025__auto__$jscomp$530$$:$font_style_fallback$jscomp$2$$}()]))};
$app$render_wasm$api$fonts$serialize_font_size$$=function($font_size$jscomp$5_or__5025__auto__$jscomp$531$$){return typeof $font_size$jscomp$5_or__5025__auto__$jscomp$531$$==="number"?$font_size$jscomp$5_or__5025__auto__$jscomp$531$$:typeof $font_size$jscomp$5_or__5025__auto__$jscomp$531$$==="string"?($font_size$jscomp$5_or__5025__auto__$jscomp$531$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($font_size$jscomp$5_or__5025__auto__$jscomp$531$$),$APP.$cljs$core$truth_$$($font_size$jscomp$5_or__5025__auto__$jscomp$531$$)?
$font_size$jscomp$5_or__5025__auto__$jscomp$531$$:14):null};
$app$render_wasm$api$fonts$serialize_font_weight$$=function($font_weight$jscomp$6_font_weight_str$$){if(typeof $font_weight$jscomp$6_font_weight_str$$==="number")return $font_weight$jscomp$6_font_weight_str$$;$font_weight$jscomp$6_font_weight_str$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($font_weight$jscomp$6_font_weight_str$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$re_matches$$(/\d+/,$font_weight$jscomp$6_font_weight_str$$))?Number($font_weight$jscomp$6_font_weight_str$$):
$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($font_weight$jscomp$6_font_weight_str$$,"bold"))?700:$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($font_weight$jscomp$6_font_weight_str$$,"black"))?900:$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($font_weight$jscomp$6_font_weight_str$$,"extrabold"))?800:$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($font_weight$jscomp$6_font_weight_str$$,"extralight"))?200:$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($font_weight$jscomp$6_font_weight_str$$,
"light"))?300:$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($font_weight$jscomp$6_font_weight_str$$,"medium"))?500:$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($font_weight$jscomp$6_font_weight_str$$,"semibold"))?600:$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($font_weight$jscomp$6_font_weight_str$$,"thin"))?100:400};
$app$render_wasm$api$fonts$serialize_line_height$cljs$0core$0IFn$0_invoke$0arity$01$$=function($line_height$jscomp$2$$){return $app$render_wasm$api$fonts$serialize_line_height$cljs$0core$0IFn$0_invoke$0arity$02$$($line_height$jscomp$2$$,1.2)};
$app$render_wasm$api$fonts$serialize_line_height$cljs$0core$0IFn$0_invoke$0arity$02$$=function($line_height$jscomp$3_or__5025__auto__$jscomp$532$$,$default_value$$){return typeof $line_height$jscomp$3_or__5025__auto__$jscomp$532$$==="number"?$line_height$jscomp$3_or__5025__auto__$jscomp$532$$:typeof $line_height$jscomp$3_or__5025__auto__$jscomp$532$$==="string"?($line_height$jscomp$3_or__5025__auto__$jscomp$532$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($line_height$jscomp$3_or__5025__auto__$jscomp$532$$),
$APP.$cljs$core$truth_$$($line_height$jscomp$3_or__5025__auto__$jscomp$532$$)?$line_height$jscomp$3_or__5025__auto__$jscomp$532$$:$default_value$$):null};
$app$render_wasm$api$fonts$serialize_letter_spacing$$=function($letter_spacing$jscomp$3_or__5025__auto__$jscomp$533$$){return typeof $letter_spacing$jscomp$3_or__5025__auto__$jscomp$533$$==="number"?$letter_spacing$jscomp$3_or__5025__auto__$jscomp$533$$:typeof $letter_spacing$jscomp$3_or__5025__auto__$jscomp$533$$==="string"?($letter_spacing$jscomp$3_or__5025__auto__$jscomp$533$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($letter_spacing$jscomp$3_or__5025__auto__$jscomp$533$$),
$APP.$cljs$core$truth_$$($letter_spacing$jscomp$3_or__5025__auto__$jscomp$533$$)?$letter_spacing$jscomp$3_or__5025__auto__$jscomp$533$$:0):null};
$app$render_wasm$api$fonts$make_font_data$$=function($font$jscomp$22$$){var $font_id$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font$jscomp$22$$,$APP.$cljs$cst$1757$font_id$$),$emoji_QMARK_$jscomp$4_font_variant_id$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font$jscomp$22$$,$APP.$cljs$cst$1759$font_variant_id$$),$normalized_variant_id$$=$APP.$cljs$core$truth_$$($emoji_QMARK_$jscomp$4_font_variant_id$jscomp$13$$)?$APP.$cuerdas$core$replace$$($APP.$cuerdas$core$lower$$($emoji_QMARK_$jscomp$4_font_variant_id$jscomp$13$$),
/\s+/,""):null,$font_weight_fallback$jscomp$3$$=function(){var $or__5025__auto__$jscomp$534$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font$jscomp$22$$,$APP.$cljs$cst$1761$font_weight$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$534$$)?$or__5025__auto__$jscomp$534$$:400}(),$font_style_fallback$jscomp$3_style$jscomp$31$$=function(){var $or__5025__auto__$jscomp$535$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font$jscomp$22$$,$APP.$cljs$cst$1762$font_style$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$535$$)?$or__5025__auto__$jscomp$535$$:"normal"}();$emoji_QMARK_$jscomp$4_font_variant_id$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($font$jscomp$22$$,$cljs$cst$2978$is_emoji$$,!1);var $fallback_QMARK_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($font$jscomp$22$$,$cljs$cst$2979$is_fallback$$,!1),$font_data$jscomp$6$$=$app$render_wasm$api$fonts$font_db_data$$($font_id$jscomp$21$$,$normalized_variant_id$$,
$font_weight_fallback$jscomp$3$$,$font_style_fallback$jscomp$3_style$jscomp$31$$),$wasm_id$$=$app$render_wasm$api$fonts$font_id__GT_uuid$$($font_id$jscomp$21$$),$asset_id$jscomp$3_raw_weight$$=function(){var $or__5025__auto__$jscomp$536$$=$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$536$$)?$or__5025__auto__$jscomp$536$$:$font_weight_fallback$jscomp$3$$}(),$weight$jscomp$8$$=$app$render_wasm$api$fonts$serialize_font_weight$$($asset_id$jscomp$3_raw_weight$$);
$font_style_fallback$jscomp$3_style$jscomp$31$$=$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($APP.$cljs$core$truth_$$($normalized_variant_id$$)?$normalized_variant_id$$:"","italic"))?"italic":$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($asset_id$jscomp$3_raw_weight$$,"italic"))?"italic":$font_style_fallback$jscomp$3_style$jscomp$31$$;var $variant_id$jscomp$4$$=function(){var $or__5025__auto__$jscomp$538$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$6$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$538$$)?$or__5025__auto__$jscomp$538$$:$normalized_variant_id$$}();$asset_id$jscomp$3_raw_weight$$=$app$render_wasm$api$fonts$font_id__GT_asset_id$$($font_id$jscomp$21$$,$variant_id$jscomp$4$$,$asset_id$jscomp$3_raw_weight$$,$font_style_fallback$jscomp$3_style$jscomp$31$$);return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$2980$emoji_QMARK_$$,$cljs$cst$2977$style_name$$,$cljs$cst$2981$fallback_QMARK_$$,$APP.$cljs$cst$1757$font_id$$,
$APP.$cljs$cst$1759$font_variant_id$$,$APP.$cljs$cst$1904$style$$,$cljs$cst$2976$wasm_id$$,$APP.$cljs$cst$1996$weight$$,$APP.$cljs$cst$2544$asset_id$$],[$emoji_QMARK_$jscomp$4_font_variant_id$jscomp$13$$,$font_style_fallback$jscomp$3_style$jscomp$31$$,$fallback_QMARK_$jscomp$3$$,$font_id$jscomp$21$$,$variant_id$jscomp$4$$,$app$render_wasm$api$fonts$serialize_font_style$$($font_style_fallback$jscomp$3_style$jscomp$31$$),$wasm_id$$,$weight$jscomp$8$$,$asset_id$jscomp$3_raw_weight$$])};
$app$render_wasm$api$fonts$get_content_fonts$$=function($content$jscomp$124_paragraph_set_paragraphs$jscomp$1$$){$content$jscomp$124_paragraph_set_paragraphs$jscomp$1$$=$APP.$cljs$core$first$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$124_paragraph_set_paragraphs$jscomp$1$$,$APP.$cljs$cst$342$children$$));$content$jscomp$124_paragraph_set_paragraphs$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$124_paragraph_set_paragraphs$jscomp$1$$,
$APP.$cljs$cst$342$children$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$240$$,$font_ref$jscomp$1_font_variant_id$jscomp$14_p__53177$$){var $map__53178__$1_resolved_font_id$$=$APP.$cljs$core$__destructure_map$$($font_ref$jscomp$1_font_variant_id$jscomp$14_p__53177$$),$font_id$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53178__$1_resolved_font_id$$,$APP.$cljs$cst$1757$font_id$$);$font_ref$jscomp$1_font_variant_id$jscomp$14_p__53177$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53178__$1_resolved_font_id$$,$APP.$cljs$cst$1759$font_variant_id$$);var $font_weight$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53178__$1_resolved_font_id$$,$APP.$cljs$cst$1761$font_weight$$),$font_style$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53178__$1_resolved_font_id$$,$APP.$cljs$cst$1762$font_style$$);$map__53178__$1_resolved_font_id$$=$APP.$cljs$core$truth_$$($font_id$jscomp$22$$)?
$font_id$jscomp$22$$:$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$);var $resolved_variant_id$$=$APP.$cljs$core$truth_$$($font_ref$jscomp$1_font_variant_id$jscomp$14_p__53177$$)?$font_ref$jscomp$1_font_variant_id$jscomp$14_p__53177$$:$APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$),$font_weight_fallback$jscomp$4$$=function(){if($APP.$cljs$core$truth_$$($font_weight$jscomp$7$$))return $font_weight$jscomp$7$$;
var $or__5025__auto____$1$jscomp$59$$=$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$59$$)?$or__5025__auto____$1$jscomp$59$$:400}(),$font_style_fallback$jscomp$4$$=function(){if($APP.$cljs$core$truth_$$($font_style$jscomp$6$$))return $font_style$jscomp$6$$;var $or__5025__auto____$1$jscomp$60$$=$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$);
return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$60$$)?$or__5025__auto____$1$jscomp$60$$:"normal"}(),$font_data$jscomp$8$$=$app$render_wasm$api$fonts$font_db_data$$($map__53178__$1_resolved_font_id$$,$resolved_variant_id$$,$font_weight_fallback$jscomp$4$$,$font_style_fallback$jscomp$4$$);$font_ref$jscomp$1_font_variant_id$jscomp$14_p__53177$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1757$font_id$$,$map__53178__$1_resolved_font_id$$,$APP.$cljs$cst$1759$font_variant_id$$,
function(){var $or__5025__auto__$jscomp$543_or__5025__auto____$1$jscomp$61$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$8$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$543_or__5025__auto____$1$jscomp$61$$))return $or__5025__auto__$jscomp$543_or__5025__auto____$1$jscomp$61$$;$or__5025__auto__$jscomp$543_or__5025__auto____$1$jscomp$61$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$8$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$543_or__5025__auto____$1$jscomp$61$$)?
$or__5025__auto__$jscomp$543_or__5025__auto____$1$jscomp$61$$:$resolved_variant_id$$}(),$APP.$cljs$cst$1761$font_weight$$,function(){var $or__5025__auto__$jscomp$544$$=$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$8$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$544$$)?$or__5025__auto__$jscomp$544$$:$font_weight_fallback$jscomp$4$$}(),$APP.$cljs$cst$1762$font_style$$,function(){var $or__5025__auto__$jscomp$545$$=$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$8$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$545$$)?$or__5025__auto__$jscomp$545$$:$font_style_fallback$jscomp$4$$}()],null);return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$240$$,$font_ref$jscomp$1_font_variant_id$jscomp$14_p__53177$$)},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$text$is_text_node_QMARK_$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__53170_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__53170_SHARP_$$,
$APP.$cljs$cst$342$children$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$content$jscomp$124_paragraph_set_paragraphs$jscomp$1$$]))))};
$app$render_wasm$api$fonts$store_fonts$$=function($fonts$jscomp$5$$){return $APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($JSCompiler_inline_result$jscomp$989_emoji_QMARK_$jscomp$inline_5875_font$jscomp$25_map__53162$jscomp$inline_5872$$){$JSCompiler_inline_result$jscomp$989_emoji_QMARK_$jscomp$inline_5875_font$jscomp$25_map__53162$jscomp$inline_5872$$=$app$render_wasm$api$fonts$make_font_data$$($JSCompiler_inline_result$jscomp$989_emoji_QMARK_$jscomp$inline_5875_font$jscomp$25_map__53162$jscomp$inline_5872$$);
var $font_data__$1$jscomp$inline_12195_map__53162__$1$jscomp$inline_5873$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$989_emoji_QMARK_$jscomp$inline_5875_font$jscomp$25_map__53162$jscomp$inline_5872$$),$asset_id$jscomp$inline_5874_temp__5823__auto__$jscomp$inline_14784_uri$jscomp$inline_12193_variant$jscomp$inline_14783$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_data__$1$jscomp$inline_12195_map__53162__$1$jscomp$inline_5873$$,$APP.$cljs$cst$2544$asset_id$$);
$JSCompiler_inline_result$jscomp$989_emoji_QMARK_$jscomp$inline_5875_font$jscomp$25_map__53162$jscomp$inline_5872$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_data__$1$jscomp$inline_12195_map__53162__$1$jscomp$inline_5873$$,$cljs$cst$2980$emoji_QMARK_$$);var $fallback_QMARK_$jscomp$inline_5876$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_data__$1$jscomp$inline_12195_map__53162__$1$jscomp$inline_5873$$,$cljs$cst$2981$fallback_QMARK_$$);if($APP.$cljs$core$truth_$$($asset_id$jscomp$inline_5874_temp__5823__auto__$jscomp$inline_14784_uri$jscomp$inline_12193_variant$jscomp$inline_14783$$)){b:{var $font_id$jscomp$inline_14281_font_stored_QMARK_$jscomp$inline_12196_id_buffer$jscomp$inline_12194$$=
$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($font_data__$1$jscomp$inline_12195_map__53162__$1$jscomp$inline_5873$$),$font_variant_id$jscomp$inline_14283$$=$APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($font_data__$1$jscomp$inline_12195_map__53162__$1$jscomp$inline_5873$$),$font_weight$jscomp$inline_14284$$=$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($font_data__$1$jscomp$inline_12195_map__53162__$1$jscomp$inline_5873$$),$font_style$jscomp$inline_14285$$=
$cljs$cst$2977$style_name$$.$cljs$core$IFn$_invoke$arity$1$($font_data__$1$jscomp$inline_12195_map__53162__$1$jscomp$inline_5873$$),$G__53145$jscomp$inline_14286_G__53145__$1$jscomp$inline_14287$$=$app$render_wasm$api$fonts$font_backend$$($font_id$jscomp$inline_14281_font_stored_QMARK_$jscomp$inline_12196_id_buffer$jscomp$inline_12194$$);$G__53145$jscomp$inline_14286_G__53145__$1$jscomp$inline_14287$$=$G__53145$jscomp$inline_14286_G__53145__$1$jscomp$inline_14287$$ instanceof $APP.$cljs$core$Keyword$$?
$G__53145$jscomp$inline_14286_G__53145__$1$jscomp$inline_14287$$.$fqn$:null;switch($G__53145$jscomp$inline_14286_G__53145__$1$jscomp$inline_14287$$){case "google":$asset_id$jscomp$inline_5874_temp__5823__auto__$jscomp$inline_14784_uri$jscomp$inline_12193_variant$jscomp$inline_14783$$=$app$render_wasm$api$fonts$font_db_data$$($font_id$jscomp$inline_14281_font_stored_QMARK_$jscomp$inline_12196_id_buffer$jscomp$inline_12194$$,$font_variant_id$jscomp$inline_14283$$,$font_weight$jscomp$inline_14284$$,
$font_style$jscomp$inline_14285$$);$asset_id$jscomp$inline_5874_temp__5823__auto__$jscomp$inline_14784_uri$jscomp$inline_12193_variant$jscomp$inline_14783$$=$cljs$cst$2677$ttf_url$$.$cljs$core$IFn$_invoke$arity$1$($asset_id$jscomp$inline_5874_temp__5823__auto__$jscomp$inline_14784_uri$jscomp$inline_12193_variant$jscomp$inline_14783$$);$asset_id$jscomp$inline_5874_temp__5823__auto__$jscomp$inline_14784_uri$jscomp$inline_12193_variant$jscomp$inline_14783$$=$APP.$cljs$core$truth_$$($asset_id$jscomp$inline_5874_temp__5823__auto__$jscomp$inline_14784_uri$jscomp$inline_12193_variant$jscomp$inline_14783$$)?
$APP.$cuerdas$core$replace$$($asset_id$jscomp$inline_5874_temp__5823__auto__$jscomp$inline_14784_uri$jscomp$inline_12193_variant$jscomp$inline_14783$$,"https://fonts.gstatic.com/s/",$APP.$lambdaisland$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"internal/gfonts/font/"]))):null;break b;case "custom":$asset_id$jscomp$inline_5874_temp__5823__auto__$jscomp$inline_14784_uri$jscomp$inline_12193_variant$jscomp$inline_14783$$=
""+($APP.$lambdaisland$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"assets/by-id/",$asset_id$jscomp$inline_5874_temp__5823__auto__$jscomp$inline_14784_uri$jscomp$inline_12193_variant$jscomp$inline_14783$$]))??"");break b;case "builtin":$asset_id$jscomp$inline_5874_temp__5823__auto__$jscomp$inline_14784_uri$jscomp$inline_12193_variant$jscomp$inline_14783$$=""+($APP.$lambdaisland$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,
"fonts/",$asset_id$jscomp$inline_5874_temp__5823__auto__$jscomp$inline_14784_uri$jscomp$inline_12193_variant$jscomp$inline_14783$$]))??"");break b;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__53145$jscomp$inline_14286_G__53145__$1$jscomp$inline_14287$$)].join(""));}}$font_id$jscomp$inline_14281_font_stored_QMARK_$jscomp$inline_12196_id_buffer$jscomp$inline_12194$$=$APP.$app$common$uuid$get_u32$$($cljs$cst$2976$wasm_id$$.$cljs$core$IFn$_invoke$arity$1$($font_data__$1$jscomp$inline_12195_map__53162__$1$jscomp$inline_5873$$));
$font_data__$1$jscomp$inline_12195_map__53162__$1$jscomp$inline_5873$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($font_data__$1$jscomp$inline_12195_map__53162__$1$jscomp$inline_5873$$,$cljs$cst$2973$family_id_buffer$$,$font_id$jscomp$inline_14281_font_stored_QMARK_$jscomp$inline_12196_id_buffer$jscomp$inline_12194$$);$font_id$jscomp$inline_14281_font_stored_QMARK_$jscomp$inline_12196_id_buffer$jscomp$inline_12194$$=$app$render_wasm$api$fonts$font_stored_QMARK_$$($font_data__$1$jscomp$inline_12195_map__53162__$1$jscomp$inline_5873$$,
$JSCompiler_inline_result$jscomp$989_emoji_QMARK_$jscomp$inline_5875_font$jscomp$25_map__53162$jscomp$inline_5872$$);$JSCompiler_inline_result$jscomp$989_emoji_QMARK_$jscomp$inline_5875_font$jscomp$25_map__53162$jscomp$inline_5872$$=$APP.$cljs$core$truth_$$($font_id$jscomp$inline_14281_font_stored_QMARK_$jscomp$inline_12196_id_buffer$jscomp$inline_12194$$)?$app$main$store$async_emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2974$font_loaded$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($font_data__$1$jscomp$inline_12195_map__53162__$1$jscomp$inline_5873$$)],null))])):$app$render_wasm$api$fonts$fetch_font$$($font_data__$1$jscomp$inline_12195_map__53162__$1$jscomp$inline_5873$$,$asset_id$jscomp$inline_5874_temp__5823__auto__$jscomp$inline_14784_uri$jscomp$inline_12193_variant$jscomp$inline_14783$$,$JSCompiler_inline_result$jscomp$989_emoji_QMARK_$jscomp$inline_5875_font$jscomp$25_map__53162$jscomp$inline_5872$$,
$fallback_QMARK_$jscomp$inline_5876$$)}else $JSCompiler_inline_result$jscomp$989_emoji_QMARK_$jscomp$inline_5875_font$jscomp$25_map__53162$jscomp$inline_5872$$=null;return $JSCompiler_inline_result$jscomp$989_emoji_QMARK_$jscomp$inline_5875_font$jscomp$25_map__53162$jscomp$inline_5872$$},$fonts$jscomp$5$$)};
$app$render_wasm$api$fonts$add_noto_fonts$$=function($fonts$jscomp$7$$,$languages$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$111$$,$lang_temp__5823__auto__$jscomp$151$$){$lang_temp__5823__auto__$jscomp$151$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$render_wasm$api$fonts$noto_fonts$$,$lang_temp__5823__auto__$jscomp$151$$);return $APP.$cljs$core$truth_$$($lang_temp__5823__auto__$jscomp$151$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$111$$,
$lang_temp__5823__auto__$jscomp$151$$):$acc$jscomp$111$$},$fonts$jscomp$7$$,$languages$$)};$app$render_wasm$mem$__GT_offset_32$$=function($value$jscomp$481$$){return $value$jscomp$481$$>>2};
$APP.$app$render_wasm$mem$alloc$$=function($cause53108_size$jscomp$104$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cause53108_size$jscomp$104$$,0)&&console.trace("Tried to allocate 0 bytes");var $code__52999__auto__$jscomp$3_code_num__52998__auto__$jscomp$3_fn_53107_read_code_fn__52997__auto__$jscomp$3$$=$APP.$app$render_wasm$wasm$internal_module$$._alloc_bytes;try{return $code__52999__auto__$jscomp$3_code_num__52998__auto__$jscomp$3_fn_53107_read_code_fn__52997__auto__$jscomp$3$$($cause53108_size$jscomp$104$$)}catch($e53109$$){$cause53108_size$jscomp$104$$=
$e53109$$;$code__52999__auto__$jscomp$3_code_num__52998__auto__$jscomp$3_fn_53107_read_code_fn__52997__auto__$jscomp$3$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$3_code_num__52998__auto__$jscomp$3_fn_53107_read_code_fn__52997__auto__$jscomp$3$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$3_code_num__52998__auto__$jscomp$3_fn_53107_read_code_fn__52997__auto__$jscomp$3$$)?$code__52999__auto__$jscomp$3_code_num__52998__auto__$jscomp$3_fn_53107_read_code_fn__52997__auto__$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$3_code_num__52998__auto__$jscomp$3_fn_53107_read_code_fn__52997__auto__$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$3_code_num__52998__auto__$jscomp$3_fn_53107_read_code_fn__52997__auto__$jscomp$3$$():null;$code__52999__auto__$jscomp$3_code_num__52998__auto__$jscomp$3_fn_53107_read_code_fn__52997__auto__$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$3_code_num__52998__auto__$jscomp$3_fn_53107_read_code_fn__52997__auto__$jscomp$3$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$3$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$3_code_num__52998__auto__$jscomp$3_fn_53107_read_code_fn__52997__auto__$jscomp$3$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_alloc_bytes",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53000__auto__$jscomp$3$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$3_code_num__52998__auto__$jscomp$3_fn_53107_read_code_fn__52997__auto__$jscomp$3$$],null),$cause53108_size$jscomp$104$$);}};$APP.$app$render_wasm$mem$alloc__GT_offset_32$$=function($size$jscomp$105$$){return $APP.$app$render_wasm$mem$alloc$$($size$jscomp$105$$)>>2};$APP.$app$render_wasm$mem$get_heap_u8$$=function(){return $APP.$app$render_wasm$wasm$internal_module$$.HEAPU8};
$APP.$app$render_wasm$mem$get_heap_u32$$=function(){return $APP.$app$render_wasm$wasm$internal_module$$.HEAPU32};$app$render_wasm$mem$get_heap_f32$$=function(){return $APP.$app$render_wasm$wasm$internal_module$$.HEAPF32};
$APP.$app$render_wasm$mem$free$$=function(){var $cause53120_fn_53119$$=$APP.$app$render_wasm$wasm$internal_module$$._free_bytes;try{$cause53120_fn_53119$$()}catch($e53124$$){$cause53120_fn_53119$$=$e53124$$;var $code__52999__auto__$jscomp$4_code_num__52998__auto__$jscomp$4_read_code_fn__52997__auto__$jscomp$4$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$4_code_num__52998__auto__$jscomp$4_read_code_fn__52997__auto__$jscomp$4$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$4_code_num__52998__auto__$jscomp$4_read_code_fn__52997__auto__$jscomp$4$$)?
$code__52999__auto__$jscomp$4_code_num__52998__auto__$jscomp$4_read_code_fn__52997__auto__$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$4_code_num__52998__auto__$jscomp$4_read_code_fn__52997__auto__$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$4_code_num__52998__auto__$jscomp$4_read_code_fn__52997__auto__$jscomp$4$$():null;$code__52999__auto__$jscomp$4_code_num__52998__auto__$jscomp$4_read_code_fn__52997__auto__$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code__52999__auto__$jscomp$4_code_num__52998__auto__$jscomp$4_read_code_fn__52997__auto__$jscomp$4$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$4$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$4_code_num__52998__auto__$jscomp$4_read_code_fn__52997__auto__$jscomp$4$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,
"_free_bytes",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$4$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$4_code_num__52998__auto__$jscomp$4_read_code_fn__52997__auto__$jscomp$4$$],null),$cause53120_fn_53119$$);}};$app$render_wasm$mem$slice$$=function($heap$jscomp$2$$,$offset$jscomp$124$$,$size$jscomp$106$$){return $heap$jscomp$2$$.slice($offset$jscomp$124$$,$offset$jscomp$124$$+$size$jscomp$106$$)};
$app$render_wasm$mem$write_u8$$=function($offset$jscomp$125$$,$target$jscomp$125$$,$value$jscomp$482$$){$target$jscomp$125$$.setUint8($offset$jscomp$125$$,$value$jscomp$482$$,!0);return $offset$jscomp$125$$+1};$app$render_wasm$mem$write_f32$$=function($offset$jscomp$126$$,$target$jscomp$126$$,$value$jscomp$483$$){$target$jscomp$126$$.setFloat32($offset$jscomp$126$$,$value$jscomp$483$$,!0);return $offset$jscomp$126$$+4};
$app$render_wasm$mem$write_i32$$=function($offset$jscomp$127$$,$target$jscomp$127$$,$value$jscomp$484$$){$target$jscomp$127$$.setInt32($offset$jscomp$127$$,$value$jscomp$484$$,!0);return $offset$jscomp$127$$+4};$app$render_wasm$mem$write_u32$$=function($offset$jscomp$128$$,$target$jscomp$128$$,$value$jscomp$485$$){$target$jscomp$128$$.setInt32($offset$jscomp$128$$,$value$jscomp$485$$,!0);return $offset$jscomp$128$$+4};
$app$render_wasm$mem$write_uuid$$=function($offset$jscomp$130$$,$target$jscomp$130$$,$barray__45664__auto___53156_value$jscomp$487$$){$barray__45664__auto___53156_value$jscomp$487$$=$APP.$app$common$uuid$get_u32$$($barray__45664__auto___53156_value$jscomp$487$$);$target$jscomp$130$$.setUint32($offset$jscomp$130$$+0,$barray__45664__auto___53156_value$jscomp$487$$[0],!0);$target$jscomp$130$$.setUint32($offset$jscomp$130$$+4,$barray__45664__auto___53156_value$jscomp$487$$[1],!0);$target$jscomp$130$$.setUint32($offset$jscomp$130$$+
8,$barray__45664__auto___53156_value$jscomp$487$$[2],!0);$target$jscomp$130$$.setUint32($offset$jscomp$130$$+12,$barray__45664__auto___53156_value$jscomp$487$$[3],!0);return $offset$jscomp$130$$+16};
$APP.$app$render_wasm$mem$write_buffer$$=function($offset$jscomp$131$$,$target$jscomp$131$$,$JSCompiler_temp$jscomp$991_value$jscomp$488$$){if($JSCompiler_temp$jscomp$991_value$jscomp$488$$ instanceof ArrayBuffer)$JSCompiler_temp$jscomp$991_value$jscomp$488$$=new Uint8Array($JSCompiler_temp$jscomp$991_value$jscomp$488$$);else if(!($JSCompiler_temp$jscomp$991_value$jscomp$488$$ instanceof Uint8Array))throw Error("unexpected type");$target$jscomp$131$$.set($JSCompiler_temp$jscomp$991_value$jscomp$488$$,
$offset$jscomp$131$$)};$app$render_wasm$mem$assert_written$$=function($final_offset$$){return $final_offset$$};$app$render_wasm$serializers$translate_shape_type$$=function($type$jscomp$409$$){var $values$jscomp$40$$=$app$render_wasm$wasm$serializers$$["shape-type"],$default$$jscomp$57$$=$values$jscomp$40$$.rect;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$40$$[$APP.$app$common$data$name$$($type$jscomp$409$$)],$default$$jscomp$57$$)};
$app$render_wasm$serializers$translate_stroke_linecap$$=function($stroke_linecap$$){var $values$jscomp$41$$=$app$render_wasm$wasm$serializers$$["stroke-linecap"],$default$$jscomp$58$$=$values$jscomp$41$$.butt;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$41$$[$APP.$app$common$data$name$$($stroke_linecap$$)],$default$$jscomp$58$$)};
$app$render_wasm$serializers$translate_stroke_linejoin$$=function($stroke_linejoin$$){var $values$jscomp$42$$=$app$render_wasm$wasm$serializers$$["stroke-linejoin"],$default$$jscomp$59$$=$values$jscomp$42$$.miter;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$42$$[$APP.$app$common$data$name$$($stroke_linejoin$$)],$default$$jscomp$59$$)};
$app$render_wasm$serializers$translate_fill_rule$$=function($fill_rule$$){var $values$jscomp$43$$=$app$render_wasm$wasm$serializers$$["fill-rule"],$default$$jscomp$60$$=$values$jscomp$43$$.nonzero;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$43$$[$APP.$app$common$data$name$$($fill_rule$$)],$default$$jscomp$60$$)};
$app$render_wasm$serializers$translate_stroke_style$$=function($stroke_style$jscomp$1$$){var $values$jscomp$44$$=$app$render_wasm$wasm$serializers$$["stroke-style"],$default$$jscomp$61$$=$values$jscomp$44$$.solid;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$44$$[$APP.$app$common$data$name$$($stroke_style$jscomp$1$$)],$default$$jscomp$61$$)};
$app$render_wasm$serializers$translate_stroke_cap$$=function($stroke_cap$$){var $values$jscomp$45$$=$app$render_wasm$wasm$serializers$$["stroke-cap"],$default$$jscomp$62$$=$values$jscomp$45$$.none;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$45$$[$APP.$app$common$data$name$$($stroke_cap$$)],$default$$jscomp$62$$)};
$app$render_wasm$serializers$translate_blend_mode$$=function($blend_mode$$){var $values$jscomp$46$$=$app$render_wasm$wasm$serializers$$["blend-mode"],$default$$jscomp$63$$=$values$jscomp$46$$.normal;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$46$$[$APP.$app$common$data$name$$($blend_mode$$)],$default$$jscomp$63$$)};
$app$render_wasm$serializers$translate_bool_type$$=function($bool_type$jscomp$3$$){var $values$jscomp$49$$=$app$render_wasm$wasm$serializers$$["bool-type"],$default$$jscomp$66$$=$values$jscomp$49$$.union;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$49$$[$APP.$app$common$data$name$$($bool_type$jscomp$3$$)],$default$$jscomp$66$$)};
$app$render_wasm$serializers$translate_layout_align_items$$=function($align_items$$){var $values$jscomp$53$$=$app$render_wasm$wasm$serializers$$["align-items"],$default$$jscomp$68$$=$values$jscomp$53$$.start;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$53$$[$APP.$app$common$data$name$$($align_items$$)],$default$$jscomp$68$$)};
$app$render_wasm$serializers$translate_layout_align_content$$=function($align_content$$){var $values$jscomp$54$$=$app$render_wasm$wasm$serializers$$["align-content"],$default$$jscomp$69$$=$values$jscomp$54$$.stretch;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$54$$[$APP.$app$common$data$name$$($align_content$$)],$default$$jscomp$69$$)};
$app$render_wasm$serializers$translate_layout_justify_items$$=function($justify_items$$){var $values$jscomp$55$$=$app$render_wasm$wasm$serializers$$["justify-items"],$default$$jscomp$70$$=$values$jscomp$55$$.start;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$55$$[$APP.$app$common$data$name$$($justify_items$$)],$default$$jscomp$70$$)};
$app$render_wasm$serializers$translate_layout_justify_content$$=function($justify_content$$){var $values$jscomp$56$$=$app$render_wasm$wasm$serializers$$["justify-content"],$default$$jscomp$71$$=$values$jscomp$56$$.stretch;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$56$$[$APP.$app$common$data$name$$($justify_content$$)],$default$$jscomp$71$$)};
$app$render_wasm$serializers$translate_layout_sizing$$=function($sizing$jscomp$1$$){var $values$jscomp$59$$=$app$render_wasm$wasm$serializers$$.sizing,$default$$jscomp$73$$=$values$jscomp$59$$.fix;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$59$$[$APP.$app$common$data$name$$($sizing$jscomp$1$$)],$default$$jscomp$73$$)};
$app$render_wasm$serializers$translate_align_self$$=function($align_self$jscomp$1$$){var $values$jscomp$60$$=$app$render_wasm$wasm$serializers$$["align-self"],$default$$jscomp$74$$=$values$jscomp$60$$.none;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$60$$[$APP.$app$common$data$name$$($align_self$jscomp$1$$)],$default$$jscomp$74$$)};
$app$render_wasm$serializers$translate_text_transform$$=function($text_transform$jscomp$2$$){var $values$jscomp$66$$=$app$render_wasm$wasm$serializers$$["text-transform"],$default$$jscomp$80$$=$values$jscomp$66$$.none;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$66$$[$APP.$app$common$data$name$$($text_transform$jscomp$2$$)],$default$$jscomp$80$$)};
$app$render_wasm$serializers$translate_text_decoration$$=function($text_decoration$jscomp$1$$){var $values$jscomp$67$$=$app$render_wasm$wasm$serializers$$["text-decoration"],$default$$jscomp$81$$=$values$jscomp$67$$.none;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$67$$[$APP.$app$common$data$name$$($text_decoration$jscomp$1$$)],$default$$jscomp$81$$)};
$app$render_wasm$serializers$translate_text_direction$$=function($text_direction$$){var $values$jscomp$68$$=$app$render_wasm$wasm$serializers$$["text-direction"],$default$$jscomp$82$$=$values$jscomp$68$$.ltr;return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$68$$[$APP.$app$common$data$name$$($text_direction$$)],$default$$jscomp$82$$)};
$app$render_wasm$serializers$translate_font_style$$=function($font_style$jscomp$7$$){var $values$jscomp$69$$=$app$render_wasm$wasm$serializers$$["font-style"],$default$$jscomp$83$$=$values$jscomp$69$$.normal;switch($font_style$jscomp$7$$){case "normal":return $values$jscomp$69$$.normal;case "regular":return $values$jscomp$69$$.normal;case "italic":return $values$jscomp$69$$.italic;default:return $default$$jscomp$83$$}};
$app$render_wasm$serializers$translate_browser$$=function(){switch($app$config$browser$$ instanceof $APP.$cljs$core$Keyword$$?$app$config$browser$$.$fqn$:null){case "firefox":return 0;case "chrome":return 1;case "safari":return 2;case "safari-16":return 2;case "safari-17":return 2;case "edge":return 3;case "unknown":return 4;default:return 4}};
$app$render_wasm$api$shapes$write_uuid_to_heap$$=function($dview$$,$offset$jscomp$132$$,$buffer$jscomp$64_id$jscomp$316$$){$buffer$jscomp$64_id$jscomp$316$$=$APP.$app$common$uuid$get_u32$$($buffer$jscomp$64_id$jscomp$316$$);$dview$$.setUint32($offset$jscomp$132$$,$buffer$jscomp$64_id$jscomp$316$$[0],!0);$dview$$.setUint32($offset$jscomp$132$$+4,$buffer$jscomp$64_id$jscomp$316$$[1],!0);$dview$$.setUint32($offset$jscomp$132$$+8,$buffer$jscomp$64_id$jscomp$316$$[2],!0);$dview$$.setUint32($offset$jscomp$132$$+
12,$buffer$jscomp$64_id$jscomp$316$$[3],!0)};
$app$render_wasm$api$shapes$serialize_transform$$=function($transform$jscomp$70$$){return $transform$jscomp$70$$!=null?new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$transform$jscomp$70$$?.a??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$70$$,$APP.$cljs$cst$1519$a$$),$transform$jscomp$70$$?.b??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$70$$,$APP.$cljs$cst$1520$b$$),$transform$jscomp$70$$?.c??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$70$$,
$cljs$cst$1521$c$$),$transform$jscomp$70$$?.d??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$70$$,$cljs$cst$1447$d$$),$transform$jscomp$70$$?.e??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$70$$,$cljs$cst$1449$e$$),$transform$jscomp$70$$?.f??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$70$$,$cljs$cst$598$f$$)],null):new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,0,0,1,
0,0],null)};
$app$render_wasm$api$shapes$serialize_selrect$$=function($selrect$jscomp$35$$){return $selrect$jscomp$35$$!=null?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$selrect$jscomp$35$$?.x1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$35$$,$APP.$cljs$cst$1523$x1$$),$selrect$jscomp$35$$?.y1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$35$$,$APP.$cljs$cst$1524$y1$$),$selrect$jscomp$35$$?.x2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$35$$,$APP.$cljs$cst$1525$x2$$),
$selrect$jscomp$35$$?.y2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$35$$,$APP.$cljs$cst$1526$y2$$)],null):new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,0,0,0],null)};
$app$render_wasm$api$shapes$set_shape_base_props$$=function($shape$jscomp$337$$){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $cause53262_53270_fn_53261_53269_id$jscomp$317$$=$shape$jscomp$337$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,$APP.$cljs$cst$266$id$$),$code__52999__auto___53273_code_num__52998__auto___53272_parent_id$jscomp$34_read_code_fn__52997__auto___53271$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,
$APP.$cljs$cst$1619$parent_id$$),$hint__53000__auto___53274_shape_type$jscomp$3$$=$shape$jscomp$337$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,$APP.$cljs$cst$139$type$$),$clip_content$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hint__53000__auto___53274_shape_type$jscomp$3$$,$APP.$cljs$cst$1606$frame$$)?$APP.$cljs$core$not$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,$APP.$cljs$cst$1876$show_content$$)):!1,$hidden$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$337$$,$APP.$cljs$cst$1620$hidden$$,!1),$flags$jscomp$25$$=function(){var $G__53252__$1$$=$clip_content$$?1:0;return $APP.$cljs$core$truth_$$($hidden$jscomp$2$$)?$G__53252__$1$$|2:$G__53252__$1$$}(),$blend_mode$jscomp$1$$=$app$render_wasm$serializers$translate_blend_mode$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,$APP.$cljs$cst$1867$blend_mode$$)),$constraint_h$$=function(){var $c$jscomp$291$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,
$APP.$cljs$cst$1872$constraints_h$$);return $c$jscomp$291$$!=null?$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($app$render_wasm$wasm$serializers$$["constraint-h"][$APP.$app$common$data$name$$($c$jscomp$291$$)],5):255}(),$constraint_v$$=function(){var $c$jscomp$292$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,$APP.$cljs$cst$1871$constraints_v$$);return $c$jscomp$292$$!=null?$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($app$render_wasm$wasm$serializers$$["constraint-v"][$APP.$app$common$data$name$$($c$jscomp$292$$)],
5):255}(),$opacity$jscomp$18$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,$APP.$cljs$cst$1734$opacity$$),1),$rotation$jscomp$11$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,$APP.$cljs$cst$1788$rotation$$),0),$tf$jscomp$6_vec__53246$$=$app$render_wasm$api$shapes$serialize_transform$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,
$APP.$cljs$cst$1289$transform$$)),$ta$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($tf$jscomp$6_vec__53246$$,0,null),$tb$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($tf$jscomp$6_vec__53246$$,1,null),$tc$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($tf$jscomp$6_vec__53246$$,2,null),$td$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($tf$jscomp$6_vec__53246$$,3,null),$te$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($tf$jscomp$6_vec__53246$$,
4,null);$tf$jscomp$6_vec__53246$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($tf$jscomp$6_vec__53246$$,5,null);var $selrect$jscomp$36_sx1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,$APP.$cljs$cst$1605$selrect$$),$sy2_vec__53249$$=$app$render_wasm$api$shapes$serialize_selrect$$($selrect$jscomp$36_sx1$$);$selrect$jscomp$36_sx1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($sy2_vec__53249$$,0,null);var $sy1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($sy2_vec__53249$$,
1,null),$sx2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($sy2_vec__53249$$,2,null);$sy2_vec__53249$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($sy2_vec__53249$$,3,null);var $r1$jscomp$19$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,$APP.$cljs$cst$1646$r1$$),0),$r2$jscomp$17$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,
$APP.$cljs$cst$1647$r2$$),0),$r3$jscomp$5$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,$APP.$cljs$cst$1648$r3$$),0),$r4$jscomp$5$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$337$$,$APP.$cljs$cst$1649$r4$$),0),$offset$jscomp$133$$=$APP.$app$render_wasm$mem$alloc$$(104),$dview$jscomp$1$$=new DataView($APP.$app$render_wasm$mem$get_heap_u8$$().buffer);
$app$render_wasm$api$shapes$write_uuid_to_heap$$($dview$jscomp$1$$,$offset$jscomp$133$$,$cause53262_53270_fn_53261_53269_id$jscomp$317$$);$app$render_wasm$api$shapes$write_uuid_to_heap$$($dview$jscomp$1$$,$offset$jscomp$133$$+16,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto___53273_code_num__52998__auto___53272_parent_id$jscomp$34_read_code_fn__52997__auto___53271$$,$APP.$app$common$uuid$zero$$));$dview$jscomp$1$$.setUint8($offset$jscomp$133$$+32,$app$render_wasm$serializers$translate_shape_type$$($hint__53000__auto___53274_shape_type$jscomp$3$$));
$dview$jscomp$1$$.setUint8($offset$jscomp$133$$+33,$flags$jscomp$25$$);$dview$jscomp$1$$.setUint8($offset$jscomp$133$$+34,$blend_mode$jscomp$1$$);$dview$jscomp$1$$.setUint8($offset$jscomp$133$$+35,$constraint_h$$);$dview$jscomp$1$$.setUint8($offset$jscomp$133$$+36,$constraint_v$$);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+40,$opacity$jscomp$18$$,!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+44,$rotation$jscomp$11$$,!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+48,$ta$jscomp$3$$,
!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+52,$tb$$,!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+56,$tc$$,!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+60,$td$jscomp$7$$,!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+64,$te$$,!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+68,$tf$jscomp$6_vec__53246$$,!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+72,$selrect$jscomp$36_sx1$$,!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+76,$sy1$$,!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+
80,$sx2$$,!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+84,$sy2_vec__53249$$,!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+88,$r1$jscomp$19$$,!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+92,$r2$jscomp$17$$,!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+96,$r3$jscomp$5$$,!0);$dview$jscomp$1$$.setFloat32($offset$jscomp$133$$+100,$r4$jscomp$5$$,!0);$cause53262_53270_fn_53261_53269_id$jscomp$317$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_base_props;try{$cause53262_53270_fn_53261_53269_id$jscomp$317$$()}catch($e53263$$){throw $cause53262_53270_fn_53261_53269_id$jscomp$317$$=
$e53263$$,$code__52999__auto___53273_code_num__52998__auto___53272_parent_id$jscomp$34_read_code_fn__52997__auto___53271$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___53273_code_num__52998__auto___53272_parent_id$jscomp$34_read_code_fn__52997__auto___53271$$=$APP.$cljs$core$truth_$$($code__52999__auto___53273_code_num__52998__auto___53272_parent_id$jscomp$34_read_code_fn__52997__auto___53271$$)?$code__52999__auto___53273_code_num__52998__auto___53272_parent_id$jscomp$34_read_code_fn__52997__auto___53271$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___53273_code_num__52998__auto___53272_parent_id$jscomp$34_read_code_fn__52997__auto___53271$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___53273_code_num__52998__auto___53272_parent_id$jscomp$34_read_code_fn__52997__auto___53271$$():null,$code__52999__auto___53273_code_num__52998__auto___53272_parent_id$jscomp$34_read_code_fn__52997__auto___53271$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___53273_code_num__52998__auto___53272_parent_id$jscomp$34_read_code_fn__52997__auto___53271$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___53274_shape_type$jscomp$3$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___53273_code_num__52998__auto___53272_parent_id$jscomp$34_read_code_fn__52997__auto___53271$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___53274_shape_type$jscomp$3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_base_props",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53000__auto___53274_shape_type$jscomp$3$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___53273_code_num__52998__auto___53272_parent_id$jscomp$34_read_code_fn__52997__auto___53271$$],null),$cause53262_53270_fn_53261_53269_id$jscomp$317$$);}}};$app$render_wasm$api$texts$encode_text$$=function($text$jscomp$25$$){return(new TextEncoder).encode($text$jscomp$25$$)};
$app$render_wasm$api$texts$write_span_fills$$=function($new_ofset_offset$jscomp$134$$,$dview$jscomp$2$$,$fills$jscomp$14$$){$new_ofset_offset$jscomp$134$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($offset__$1$jscomp$4$$,$fill$jscomp$13_image$jscomp$17$$){var $opacity$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($fill$jscomp$13_image$jscomp$17$$,$APP.$cljs$cst$1747$fill_opacity$$,1),$color$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill$jscomp$13_image$jscomp$17$$,
$APP.$cljs$cst$1746$fill_color$$),$gradient$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill$jscomp$13_image$jscomp$17$$,$APP.$cljs$cst$1748$fill_color_gradient$$);$fill$jscomp$13_image$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill$jscomp$13_image$jscomp$17$$,$APP.$cljs$cst$1632$fill_image$$);return $color$jscomp$46$$!=null?$app$common$types$fills$impl$write_solid_fill$$($offset__$1$jscomp$4$$,$dview$jscomp$2$$,$opacity$jscomp$19$$,$color$jscomp$46$$):
$gradient$jscomp$15$$!=null?$app$common$types$fills$impl$write_gradient_fill$$($offset__$1$jscomp$4$$,$dview$jscomp$2$$,$opacity$jscomp$19$$,$gradient$jscomp$15$$):$fill$jscomp$13_image$jscomp$17$$!=null?$app$common$types$fills$impl$write_image_fill$$($offset__$1$jscomp$4$$,$dview$jscomp$2$$,$opacity$jscomp$19$$,$fill$jscomp$13_image$jscomp$17$$):null},$new_ofset_offset$jscomp$134$$,$fills$jscomp$14$$);var $padding_fills$$=function(){var $y__5111__auto__$jscomp$47$$=8-$APP.$cljs$core$count$$($fills$jscomp$14$$);
return 0>$y__5111__auto__$jscomp$47$$?0:$y__5111__auto__$jscomp$47$$}();return $new_ofset_offset$jscomp$134$$+$padding_fills$$*160};
$app$render_wasm$api$texts$write_paragraph$$=function($offset$jscomp$135$$,$dview$jscomp$3$$,$letter_spacing$jscomp$4_paragraph$jscomp$2$$){var $text_align$jscomp$2_text_align$jscomp$inline_5881$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($letter_spacing$jscomp$4_paragraph$jscomp$2$$,$APP.$cljs$cst$1763$text_align$$);var $text_direction$jscomp$1_values$jscomp$inline_5882$$=$app$render_wasm$wasm$serializers$$["text-align"],$default$$jscomp$inline_5883_text_decoration$jscomp$2$$=$text_direction$jscomp$1_values$jscomp$inline_5882$$.left;
$text_align$jscomp$2_text_align$jscomp$inline_5881$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($text_direction$jscomp$1_values$jscomp$inline_5882$$[$APP.$app$common$data$name$$($text_align$jscomp$2_text_align$jscomp$inline_5881$$)],$default$$jscomp$inline_5883_text_decoration$jscomp$2$$);$text_direction$jscomp$1_values$jscomp$inline_5882$$=$app$render_wasm$serializers$translate_text_direction$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($letter_spacing$jscomp$4_paragraph$jscomp$2$$,
$APP.$cljs$cst$1764$text_direction$$));$default$$jscomp$inline_5883_text_decoration$jscomp$2$$=$app$render_wasm$serializers$translate_text_decoration$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($letter_spacing$jscomp$4_paragraph$jscomp$2$$,$APP.$cljs$cst$1768$text_decoration$$));var $text_transform$jscomp$3$$=$app$render_wasm$serializers$translate_text_transform$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($letter_spacing$jscomp$4_paragraph$jscomp$2$$,$APP.$cljs$cst$1769$text_transform$$)),
$line_height$jscomp$4$$=$app$render_wasm$api$fonts$serialize_line_height$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($letter_spacing$jscomp$4_paragraph$jscomp$2$$,$APP.$cljs$cst$1765$line_height$$));$letter_spacing$jscomp$4_paragraph$jscomp$2$$=$app$render_wasm$api$fonts$serialize_letter_spacing$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($letter_spacing$jscomp$4_paragraph$jscomp$2$$,$APP.$cljs$cst$1766$letter_spacing$$));return $app$render_wasm$mem$assert_written$$($app$render_wasm$mem$write_f32$$($app$render_wasm$mem$write_f32$$($app$render_wasm$mem$write_u8$$($app$render_wasm$mem$write_u8$$($app$render_wasm$mem$write_u8$$($app$render_wasm$mem$write_u8$$($offset$jscomp$135$$,
$dview$jscomp$3$$,$text_align$jscomp$2_text_align$jscomp$inline_5881$$),$dview$jscomp$3$$,$text_direction$jscomp$1_values$jscomp$inline_5882$$),$dview$jscomp$3$$,$default$$jscomp$inline_5883_text_decoration$jscomp$2$$),$dview$jscomp$3$$,$text_transform$jscomp$3$$),$dview$jscomp$3$$,$line_height$jscomp$4$$),$dview$jscomp$3$$,$letter_spacing$jscomp$4_paragraph$jscomp$2$$))};
$app$render_wasm$api$texts$write_spans$$=function($offset$jscomp$136$$,$dview$jscomp$4$$,$spans$$,$paragraph$jscomp$3$$){var $paragraph_font_size$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($paragraph$jscomp$3$$,$APP.$cljs$cst$1760$font_size$$),$paragraph_font_weight$$=$app$render_wasm$api$fonts$serialize_font_weight$$($APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$3$$)),$paragraph_line_height$$=$app$render_wasm$api$fonts$serialize_line_height$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($paragraph$jscomp$3$$,
$APP.$cljs$cst$1765$line_height$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($offset__$1$jscomp$5$$,$span$jscomp$1$$){var $font_style$jscomp$8$$=$app$render_wasm$serializers$translate_font_style$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($span$jscomp$1$$,$APP.$cljs$cst$1762$font_style$$,"normal")),$font_size$jscomp$6_font_size__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($span$jscomp$1$$,$APP.$cljs$cst$1760$font_size$$,$paragraph_font_size$$);
$font_size$jscomp$6_font_size__$1$$=$app$render_wasm$api$fonts$serialize_font_size$$($font_size$jscomp$6_font_size__$1$$);var $line_height$jscomp$5$$=$app$render_wasm$api$fonts$serialize_line_height$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($span$jscomp$1$$,$APP.$cljs$cst$1765$line_height$$),$paragraph_line_height$$),$letter_spacing$jscomp$5$$=$app$render_wasm$api$fonts$serialize_letter_spacing$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($span$jscomp$1$$,
$APP.$cljs$cst$1766$letter_spacing$$)),$font_weight$jscomp$8_font_weight__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($span$jscomp$1$$,$APP.$cljs$cst$1761$font_weight$$,$paragraph_font_weight$$);$font_weight$jscomp$8_font_weight__$1$$=$app$render_wasm$api$fonts$serialize_font_weight$$($font_weight$jscomp$8_font_weight__$1$$);var $font_id$jscomp$23$$=$app$render_wasm$api$fonts$normalize_font_id$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($span$jscomp$1$$,$APP.$cljs$cst$1757$font_id$$,
"sourcesanspro")),$font_family$jscomp$4$$=$APP.$cljs$core$hash$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($span$jscomp$1$$,$APP.$cljs$cst$1758$font_family$$,"sourcesanspro")),$text_length$$=$app$render_wasm$api$texts$encode_text$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($span$jscomp$1$$,$APP.$cljs$cst$1588$text$$,"")).byteLength,$fills$jscomp$15$$=$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(8,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($span$jscomp$1$$,
$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$)),$font_variant_id$jscomp$15_font_variant_id__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($span$jscomp$1$$,$APP.$cljs$cst$1759$font_variant_id$$);$font_variant_id$jscomp$15_font_variant_id__$1$$=$APP.$cljs$core$uuid_QMARK_$$($font_variant_id$jscomp$15_font_variant_id__$1$$)?$font_variant_id$jscomp$15_font_variant_id__$1$$:$APP.$app$common$uuid$zero$$;var $text_decoration$jscomp$3$$=function(){var $or__5025__auto__$jscomp$546_or__5025__auto____$1$jscomp$62$$=
$app$render_wasm$serializers$translate_text_decoration$$($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($span$jscomp$1$$));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$546_or__5025__auto____$1$jscomp$62$$))return $or__5025__auto__$jscomp$546_or__5025__auto____$1$jscomp$62$$;$or__5025__auto__$jscomp$546_or__5025__auto____$1$jscomp$62$$=$app$render_wasm$serializers$translate_text_decoration$$($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$3$$));
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$546_or__5025__auto____$1$jscomp$62$$)?$or__5025__auto__$jscomp$546_or__5025__auto____$1$jscomp$62$$:$app$render_wasm$serializers$translate_text_decoration$$("none")}(),$text_transform$jscomp$4$$=function(){var $or__5025__auto__$jscomp$547_or__5025__auto____$1$jscomp$63$$=$app$render_wasm$serializers$translate_text_transform$$($APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($span$jscomp$1$$));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$547_or__5025__auto____$1$jscomp$63$$))return $or__5025__auto__$jscomp$547_or__5025__auto____$1$jscomp$63$$;
$or__5025__auto__$jscomp$547_or__5025__auto____$1$jscomp$63$$=$app$render_wasm$serializers$translate_text_transform$$($APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$3$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$547_or__5025__auto____$1$jscomp$63$$)?$or__5025__auto__$jscomp$547_or__5025__auto____$1$jscomp$63$$:$app$render_wasm$serializers$translate_text_transform$$("none")}(),$text_direction$jscomp$2$$=function(){var $or__5025__auto__$jscomp$548_or__5025__auto____$1$jscomp$64$$=
$app$render_wasm$serializers$translate_text_direction$$($APP.$cljs$cst$1764$text_direction$$.$cljs$core$IFn$_invoke$arity$1$($span$jscomp$1$$));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$548_or__5025__auto____$1$jscomp$64$$))return $or__5025__auto__$jscomp$548_or__5025__auto____$1$jscomp$64$$;$or__5025__auto__$jscomp$548_or__5025__auto____$1$jscomp$64$$=$app$render_wasm$serializers$translate_text_direction$$($APP.$cljs$cst$1764$text_direction$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$3$$));
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$548_or__5025__auto____$1$jscomp$64$$)?$or__5025__auto__$jscomp$548_or__5025__auto____$1$jscomp$64$$:$app$render_wasm$serializers$translate_text_direction$$("ltr")}();return $app$render_wasm$api$texts$write_span_fills$$($app$render_wasm$mem$assert_written$$($app$render_wasm$mem$write_i32$$($app$render_wasm$mem$write_i32$$($app$render_wasm$mem$write_uuid$$($app$render_wasm$mem$write_i32$$($app$render_wasm$mem$write_uuid$$($app$render_wasm$mem$write_u32$$($app$render_wasm$mem$write_f32$$($app$render_wasm$mem$write_f32$$($app$render_wasm$mem$write_f32$$($app$render_wasm$mem$write_u8$$($app$render_wasm$mem$write_u8$$($app$render_wasm$mem$write_u8$$($app$render_wasm$mem$write_u8$$($offset__$1$jscomp$5$$,
$dview$jscomp$4$$,$font_style$jscomp$8$$),$dview$jscomp$4$$,$text_decoration$jscomp$3$$),$dview$jscomp$4$$,$text_transform$jscomp$4$$),$dview$jscomp$4$$,$text_direction$jscomp$2$$),$dview$jscomp$4$$,$font_size$jscomp$6_font_size__$1$$),$dview$jscomp$4$$,$line_height$jscomp$5$$),$dview$jscomp$4$$,$letter_spacing$jscomp$5$$),$dview$jscomp$4$$,$font_weight$jscomp$8_font_weight__$1$$),$dview$jscomp$4$$,$font_id$jscomp$23$$),$dview$jscomp$4$$,$font_family$jscomp$4$$),$dview$jscomp$4$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_id$jscomp$15_font_variant_id__$1$$,
$APP.$app$common$uuid$zero$$)),$dview$jscomp$4$$,$text_length$$),$dview$jscomp$4$$,$APP.$cljs$core$count$$($fills$jscomp$15$$))),$dview$jscomp$4$$,$fills$jscomp$15$$)},$offset$jscomp$136$$,$spans$$)};
$app$render_wasm$api$texts$write_shape_text$$=function($cause53278_fn_53277_normalized_spans_spans$jscomp$1$$,$code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$,$hint__53000__auto__$jscomp$8_text$jscomp$26_text_buffer$jscomp$1$$){var $normalized_paragraph$$=$app$render_wasm$api$fonts$normalize_paragraph_font$$($code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$);
$cause53278_fn_53277_normalized_spans_spans$jscomp$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__53268_SHARP_$$){return $app$render_wasm$api$fonts$normalize_span_font$$($p1__53268_SHARP_$$,$normalized_paragraph$$)},$cause53278_fn_53277_normalized_spans_spans$jscomp$1$$);$code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$=$APP.$cljs$core$count$$($cause53278_fn_53277_normalized_spans_spans$jscomp$1$$);
var $heapu8_metadata_size$$=12+$code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$*1344;$hint__53000__auto__$jscomp$8_text$jscomp$26_text_buffer$jscomp$1$$=$app$render_wasm$api$texts$encode_text$$($hint__53000__auto__$jscomp$8_text$jscomp$26_text_buffer$jscomp$1$$);var $offset$jscomp$137_total_size$$=4+$heapu8_metadata_size$$+$hint__53000__auto__$jscomp$8_text$jscomp$26_text_buffer$jscomp$1$$.byteLength;$heapu8_metadata_size$$=
$APP.$app$render_wasm$mem$get_heap_u8$$();var $dview$jscomp$5$$=$app$common$buffer$wrap$$();$offset$jscomp$137_total_size$$=$APP.$app$render_wasm$mem$alloc$$($offset$jscomp$137_total_size$$);$APP.$app$render_wasm$mem$write_buffer$$($app$render_wasm$api$texts$write_spans$$($app$render_wasm$api$texts$write_paragraph$$($app$render_wasm$mem$write_u32$$($offset$jscomp$137_total_size$$,$dview$jscomp$5$$,$code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$),
$dview$jscomp$5$$,$normalized_paragraph$$),$dview$jscomp$5$$,$cause53278_fn_53277_normalized_spans_spans$jscomp$1$$,$normalized_paragraph$$),$heapu8_metadata_size$$,$hint__53000__auto__$jscomp$8_text$jscomp$26_text_buffer$jscomp$1$$);$cause53278_fn_53277_normalized_spans_spans$jscomp$1$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_text_content;try{$cause53278_fn_53277_normalized_spans_spans$jscomp$1$$()}catch($e53279$$){throw $cause53278_fn_53277_normalized_spans_spans$jscomp$1$$=$e53279$$,
$code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$)?$code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$():null,$code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto__$jscomp$8_text$jscomp$26_text_buffer$jscomp$1$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$8_text$jscomp$26_text_buffer$jscomp$1$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_text_content",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$8_text$jscomp$26_text_buffer$jscomp$1$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$8_code_num__52998__auto__$jscomp$8_num_spans_paragraph$jscomp$4_read_code_fn__52997__auto__$jscomp$8$$],null),$cause53278_fn_53277_normalized_spans_spans$jscomp$1$$);}};
$app$render_wasm$api$texts$contains_emoji_QMARK_$$=function($result$jscomp$242_text$jscomp$27$$){$result$jscomp$242_text$jscomp$27$$=$APP.$cljs$core$re_find$$($app$render_wasm$api$texts$emoji_pattern$$,$result$jscomp$242_text$jscomp$27$$);return $APP.$cljs$core$boolean$0$$($result$jscomp$242_text$jscomp$27$$)};
$app$render_wasm$api$texts$collect_used_languages$$=function($used$jscomp$2$$,$text$jscomp$28$$){return $APP.$cljs$core$reduce_kv$$(function($result$jscomp$243$$,$lang$jscomp$1$$,$pattern$jscomp$7$$){return $APP.$cljs$core$contains_QMARK_$$($result$jscomp$243$$,$lang$jscomp$1$$)?$result$jscomp$243$$:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_find$$($pattern$jscomp$7$$,$text$jscomp$28$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$243$$,$lang$jscomp$1$$):$result$jscomp$243$$},
$used$jscomp$2$$,$app$render_wasm$api$texts$unicode_ranges$$)};
$APP.$app$render_wasm$api$webgl$capture_canvas_snapshot_url$$=function(){var $temp__5823__auto__$jscomp$152$$=$app$render_wasm$wasm$canvas$$;return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$152$$)?$promesa$core$create$cljs$0core$0IFn$0_invoke$0arity$01$$(function($resolve$jscomp$24$$){var $temp__5825__auto___53264$$=$APP.$app$render_wasm$wasm$canvas_snapshot_url$$;$APP.$cljs$core$truth_$$($temp__5825__auto___53264$$)&&$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$333$$=typeof $temp__5825__auto___53264$$===
"string";return $and__5023__auto__$jscomp$333$$?$temp__5825__auto___53264$$.startsWith("blob:"):$and__5023__auto__$jscomp$333$$}())&&URL.revokeObjectURL($temp__5825__auto___53264$$);$APP.$app$render_wasm$wasm$canvas_snapshot_url$$=null;return $temp__5823__auto__$jscomp$152$$.toBlob(function($blob$jscomp$18_url$jscomp$81$$){return $APP.$cljs$core$truth_$$($blob$jscomp$18_url$jscomp$81$$)?($APP.$app$render_wasm$wasm$canvas_snapshot_url$$=$blob$jscomp$18_url$jscomp$81$$=URL.createObjectURL($blob$jscomp$18_url$jscomp$81$$),
$resolve$jscomp$24$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$24$$.$cljs$core$IFn$_invoke$arity$1$($blob$jscomp$18_url$jscomp$81$$):$resolve$jscomp$24$$($blob$jscomp$18_url$jscomp$81$$)):$resolve$jscomp$24$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$24$$.$cljs$core$IFn$_invoke$arity$1$(null):$resolve$jscomp$24$$(null)},"image/png")}):$APP.$promesa$impl$promise$resolved$$(null)};
$app$render_wasm$deserializers$read_selection_rect$$=function($heapf32$jscomp$1$$,$offset$jscomp$139$$){var $a$jscomp$375$$=$heapf32$jscomp$1$$[$offset$jscomp$139$$+4],$b$jscomp$307$$=$heapf32$jscomp$1$$[$offset$jscomp$139$$+5],$c$jscomp$294$$=$heapf32$jscomp$1$$[$offset$jscomp$139$$+6],$d$jscomp$232$$=$heapf32$jscomp$1$$[$offset$jscomp$139$$+7],$e$jscomp$311$$=$heapf32$jscomp$1$$[$offset$jscomp$139$$+8],$f$jscomp$813$$=$heapf32$jscomp$1$$[$offset$jscomp$139$$+9];return new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$290$width$$,$heapf32$jscomp$1$$[$offset$jscomp$139$$+0],$APP.$cljs$cst$1522$height$$,$heapf32$jscomp$1$$[$offset$jscomp$139$$+1],$APP.$cljs$cst$1667$center$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($heapf32$jscomp$1$$[$offset$jscomp$139$$+2],$heapf32$jscomp$1$$[$offset$jscomp$139$$+3]),$APP.$cljs$cst$1289$transform$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$6$($a$jscomp$375$$,$b$jscomp$307$$,$c$jscomp$294$$,$d$jscomp$232$$,$e$jscomp$311$$,
$f$jscomp$813$$)],null)};$app$render_wasm$mem$heap32$write_u32$$=function($offset$jscomp$142$$,$heap$jscomp$5$$,$value$jscomp$494$$){$heap$jscomp$5$$[$offset$jscomp$142$$]=$value$jscomp$494$$;return $offset$jscomp$142$$+1};
$APP.$app$render_wasm$mem$heap32$write_uuid$$=function($offset$jscomp$144$$,$heap$jscomp$7$$,$buffer$jscomp$65_id$jscomp$318$$){$buffer$jscomp$65_id$jscomp$318$$=$APP.$app$common$uuid$get_u32$$($buffer$jscomp$65_id$jscomp$318$$);$heap$jscomp$7$$.set($buffer$jscomp$65_id$jscomp$318$$,$offset$jscomp$144$$);return $offset$jscomp$144$$+4};
$app$render_wasm$mem$heap32$write_matrix$$=function($offset$jscomp$145$$,$heap$jscomp$8$$,$f$jscomp$814_matrix$jscomp$13$$){var $a$jscomp$376$$=$f$jscomp$814_matrix$jscomp$13$$?.a??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$814_matrix$jscomp$13$$,$APP.$cljs$cst$1519$a$$),$b$jscomp$308$$=$f$jscomp$814_matrix$jscomp$13$$?.b??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$814_matrix$jscomp$13$$,$APP.$cljs$cst$1520$b$$),$c$jscomp$295$$=$f$jscomp$814_matrix$jscomp$13$$?.c??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$814_matrix$jscomp$13$$,$cljs$cst$1521$c$$),$d$jscomp$233$$=$f$jscomp$814_matrix$jscomp$13$$?.d??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$814_matrix$jscomp$13$$,$cljs$cst$1447$d$$),$e$jscomp$312$$=$f$jscomp$814_matrix$jscomp$13$$?.e??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$814_matrix$jscomp$13$$,$cljs$cst$1449$e$$);$f$jscomp$814_matrix$jscomp$13$$=$f$jscomp$814_matrix$jscomp$13$$?.f??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$814_matrix$jscomp$13$$,
$cljs$cst$598$f$$);$heap$jscomp$8$$[$offset$jscomp$145$$+0]=$a$jscomp$376$$;$heap$jscomp$8$$[$offset$jscomp$145$$+1]=$b$jscomp$308$$;$heap$jscomp$8$$[$offset$jscomp$145$$+2]=$c$jscomp$295$$;$heap$jscomp$8$$[$offset$jscomp$145$$+3]=$d$jscomp$233$$;$heap$jscomp$8$$[$offset$jscomp$145$$+4]=$e$jscomp$312$$;$heap$jscomp$8$$[$offset$jscomp$145$$+5]=$f$jscomp$814_matrix$jscomp$13$$;return $offset$jscomp$145$$+6};
$APP.$app$render_wasm$serializers$color$hex__GT_u32argb$$=function($hex$jscomp$4_rgb$jscomp$4$$,$opacity$jscomp$20$$){$hex$jscomp$4_rgb$jscomp$4$$=parseInt($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($hex$jscomp$4_rgb$jscomp$4$$,1),16);return($APP.$app$common$math$floor$$(($APP.$cljs$core$truth_$$($opacity$jscomp$20$$)?$opacity$jscomp$20$$:1)*255)<<24|$hex$jscomp$4_rgb$jscomp$4$$)>>>0};
$app$render_wasm$svg_fills$trim_fill_value$$=function($string_value_trimmed_value$jscomp$496$$){$string_value_trimmed_value$jscomp$496$$=typeof $string_value_trimmed_value$jscomp$496$$==="string"?$string_value_trimmed_value$jscomp$496$$:$string_value_trimmed_value$jscomp$496$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$($string_value_trimmed_value$jscomp$496$$):$string_value_trimmed_value$jscomp$496$$ instanceof $APP.$cljs$core$Symbol$$?$APP.$cljs$core$name$$($string_value_trimmed_value$jscomp$496$$):
typeof $string_value_trimmed_value$jscomp$496$$==="number"?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($string_value_trimmed_value$jscomp$496$$):$string_value_trimmed_value$jscomp$496$$!=null?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($string_value_trimmed_value$jscomp$496$$):null;return $string_value_trimmed_value$jscomp$496$$!=null?($string_value_trimmed_value$jscomp$496$$=$goog$string$internal$trim$$($string_value_trimmed_value$jscomp$496$$),$APP.$cljs$core$seq$$($string_value_trimmed_value$jscomp$496$$)?
$string_value_trimmed_value$jscomp$496$$:null):null};
$app$render_wasm$svg_fills$parse_length$$=function($percent_QMARK_$jscomp$2_value$jscomp$497$$){if($percent_QMARK_$jscomp$2_value$jscomp$497$$==null)return null;if(typeof $percent_QMARK_$jscomp$2_value$jscomp$497$$==="number")return $percent_QMARK_$jscomp$2_value$jscomp$497$$;var $numeric_parsed_value__$1$jscomp$14$$=$app$render_wasm$svg_fills$trim_fill_value$$($percent_QMARK_$jscomp$2_value$jscomp$497$$);if($APP.$cljs$core$seq$$($numeric_parsed_value__$1$jscomp$14$$)){$percent_QMARK_$jscomp$2_value$jscomp$497$$=$APP.$goog$string$internal$endsWith$$($numeric_parsed_value__$1$jscomp$14$$,
"%");var $px_QMARK_$$=$APP.$goog$string$internal$endsWith$$($numeric_parsed_value__$1$jscomp$14$$,"px");$numeric_parsed_value__$1$jscomp$14$$=$percent_QMARK_$jscomp$2_value$jscomp$497$$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($numeric_parsed_value__$1$jscomp$14$$,0,$APP.$cljs$core$count$$($numeric_parsed_value__$1$jscomp$14$$)-1):$px_QMARK_$$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($numeric_parsed_value__$1$jscomp$14$$,0,$APP.$cljs$core$count$$($numeric_parsed_value__$1$jscomp$14$$)-
2):$numeric_parsed_value__$1$jscomp$14$$;$numeric_parsed_value__$1$jscomp$14$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($numeric_parsed_value__$1$jscomp$14$$);return $APP.$cljs$core$truth_$$($numeric_parsed_value__$1$jscomp$14$$)?$percent_QMARK_$jscomp$2_value$jscomp$497$$?$numeric_parsed_value__$1$jscomp$14$$/100:$numeric_parsed_value__$1$jscomp$14$$:null}return null};
$app$render_wasm$svg_fills$parse_offset$$=function($length$jscomp$40_value$jscomp$498_x__5110__auto__$jscomp$inline_12198_x__5113__auto__$jscomp$38$$){$length$jscomp$40_value$jscomp$498_x__5110__auto__$jscomp$inline_12198_x__5113__auto__$jscomp$38$$=$app$render_wasm$svg_fills$parse_length$$($APP.$cljs$core$truth_$$($length$jscomp$40_value$jscomp$498_x__5110__auto__$jscomp$inline_12198_x__5113__auto__$jscomp$38$$)?$length$jscomp$40_value$jscomp$498_x__5110__auto__$jscomp$inline_12198_x__5113__auto__$jscomp$38$$:
0);$length$jscomp$40_value$jscomp$498_x__5110__auto__$jscomp$inline_12198_x__5113__auto__$jscomp$38$$=$APP.$cljs$core$truth_$$($length$jscomp$40_value$jscomp$498_x__5110__auto__$jscomp$inline_12198_x__5113__auto__$jscomp$38$$)?$length$jscomp$40_value$jscomp$498_x__5110__auto__$jscomp$inline_12198_x__5113__auto__$jscomp$38$$:0;$length$jscomp$40_value$jscomp$498_x__5110__auto__$jscomp$inline_12198_x__5113__auto__$jscomp$38$$=$length$jscomp$40_value$jscomp$498_x__5110__auto__$jscomp$inline_12198_x__5113__auto__$jscomp$38$$>
0?$length$jscomp$40_value$jscomp$498_x__5110__auto__$jscomp$inline_12198_x__5113__auto__$jscomp$38$$:0;return $length$jscomp$40_value$jscomp$498_x__5110__auto__$jscomp$inline_12198_x__5113__auto__$jscomp$38$$<1?$length$jscomp$40_value$jscomp$498_x__5110__auto__$jscomp$inline_12198_x__5113__auto__$jscomp$38$$:1};
$app$render_wasm$svg_fills$parse_opacity$$=function($parsed$jscomp$1_value$jscomp$499$$){$parsed$jscomp$1_value$jscomp$499$$=$app$render_wasm$svg_fills$parse_length$$($parsed$jscomp$1_value$jscomp$499$$);return $parsed$jscomp$1_value$jscomp$499$$!=null?$parsed$jscomp$1_value$jscomp$499$$:1};
$app$render_wasm$svg_fills$shape__GT_selrect$$=function($shape$jscomp$338$$){var $selrect$jscomp$37$$=$shape$jscomp$338$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$338$$,$APP.$cljs$cst$1605$selrect$$);return $app$common$geom$rect$rect_QMARK_$$($selrect$jscomp$37$$)?$selrect$jscomp$37$$:$APP.$cljs$core$map_QMARK_$$($selrect$jscomp$37$$)?$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$37$$):$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1510$x$$,function(){var $or__5025__auto__$jscomp$552$$=$shape$jscomp$338$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$338$$,$APP.$cljs$cst$1510$x$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$552$$)?$or__5025__auto__$jscomp$552$$:0}(),$APP.$cljs$cst$1511$y$$,function(){var $or__5025__auto__$jscomp$553$$=$shape$jscomp$338$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$338$$,$APP.$cljs$cst$1511$y$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$553$$)?
$or__5025__auto__$jscomp$553$$:0}(),$APP.$cljs$cst$290$width$$,function(){var $or__5025__auto__$jscomp$inline_5888_y__5111__auto__$jscomp$49$$=$shape$jscomp$338$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$338$$,$APP.$cljs$cst$290$width$$);$or__5025__auto__$jscomp$inline_5888_y__5111__auto__$jscomp$49$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_5888_y__5111__auto__$jscomp$49$$)?$or__5025__auto__$jscomp$inline_5888_y__5111__auto__$jscomp$49$$:1;return.01>
$or__5025__auto__$jscomp$inline_5888_y__5111__auto__$jscomp$49$$?.01:$or__5025__auto__$jscomp$inline_5888_y__5111__auto__$jscomp$49$$}(),$APP.$cljs$cst$1522$height$$,function(){var $or__5025__auto__$jscomp$inline_5890_y__5111__auto__$jscomp$50$$=$shape$jscomp$338$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$338$$,$APP.$cljs$cst$1522$height$$);$or__5025__auto__$jscomp$inline_5890_y__5111__auto__$jscomp$50$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_5890_y__5111__auto__$jscomp$50$$)?
$or__5025__auto__$jscomp$inline_5890_y__5111__auto__$jscomp$50$$:1;return.01>$or__5025__auto__$jscomp$inline_5890_y__5111__auto__$jscomp$50$$?.01:$or__5025__auto__$jscomp$inline_5890_y__5111__auto__$jscomp$50$$}()],null))};$app$render_wasm$svg_fills$apply_svg_transform$$=function($pt$jscomp$21$$,$svg_transform$jscomp$1$$){return $APP.$cljs$core$truth_$$($svg_transform$jscomp$1$$)?$APP.$app$common$geom$point$transform$$($pt$jscomp$21$$,$svg_transform$jscomp$1$$):$pt$jscomp$21$$};
$app$render_wasm$svg_fills$apply_viewbox_transform$$=function($pt$jscomp$22_transformed_y$$,$svg_y$jscomp$1_viewbox$jscomp$1$$,$rect$jscomp$26$$){if($APP.$cljs$core$truth_$$($svg_y$jscomp$1_viewbox$jscomp$1$$)){var $map__53329__$1_origin_y$$=$APP.$cljs$core$__destructure_map$$($svg_y$jscomp$1_viewbox$jscomp$1$$),$svg_x$jscomp$1_transformed_x$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53329__$1_origin_y$$,$APP.$cljs$cst$1510$x$$);$svg_y$jscomp$1_viewbox$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53329__$1_origin_y$$,
$APP.$cljs$cst$1511$y$$);var $scale_x$jscomp$2_svg_width$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53329__$1_origin_y$$,$APP.$cljs$cst$290$width$$),$scale_y$jscomp$2_svg_height$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53329__$1_origin_y$$,$APP.$cljs$cst$1522$height$$),$rect_width$$=function(){var $y__5111__auto__$jscomp$51$$=$rect$jscomp$26$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$26$$,$APP.$cljs$cst$290$width$$);
return.01>$y__5111__auto__$jscomp$51$$?.01:$y__5111__auto__$jscomp$51$$}(),$rect_height$$=function(){var $y__5111__auto__$jscomp$52$$=$rect$jscomp$26$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$26$$,$APP.$cljs$cst$1522$height$$);return.01>$y__5111__auto__$jscomp$52$$?.01:$y__5111__auto__$jscomp$52$$}(),$origin_x$$=function(){var $or__5025__auto__$jscomp$556_or__5025__auto____$1$jscomp$65$$=$rect$jscomp$26$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$26$$,
$APP.$cljs$cst$1510$x$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$556_or__5025__auto____$1$jscomp$65$$))return $or__5025__auto__$jscomp$556_or__5025__auto____$1$jscomp$65$$;$or__5025__auto__$jscomp$556_or__5025__auto____$1$jscomp$65$$=$rect$jscomp$26$$?.x1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$26$$,$APP.$cljs$cst$1523$x1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$556_or__5025__auto____$1$jscomp$65$$)?$or__5025__auto__$jscomp$556_or__5025__auto____$1$jscomp$65$$:
0}();$map__53329__$1_origin_y$$=function(){var $or__5025__auto__$jscomp$557_or__5025__auto____$1$jscomp$66$$=$rect$jscomp$26$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$26$$,$APP.$cljs$cst$1511$y$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$557_or__5025__auto____$1$jscomp$66$$))return $or__5025__auto__$jscomp$557_or__5025__auto____$1$jscomp$66$$;$or__5025__auto__$jscomp$557_or__5025__auto____$1$jscomp$66$$=$rect$jscomp$26$$?.y1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$26$$,
$APP.$cljs$cst$1524$y1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$557_or__5025__auto____$1$jscomp$66$$)?$or__5025__auto__$jscomp$557_or__5025__auto____$1$jscomp$66$$:0}();$scale_x$jscomp$2_svg_width$jscomp$1$$=$rect_width$$/$scale_x$jscomp$2_svg_width$jscomp$1$$;$scale_y$jscomp$2_svg_height$jscomp$1$$=$rect_height$$/$scale_y$jscomp$2_svg_height$jscomp$1$$;$svg_x$jscomp$1_transformed_x$$=$origin_x$$+(($pt$jscomp$22_transformed_y$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$22_transformed_y$$,
$APP.$cljs$cst$1510$x$$))-$svg_x$jscomp$1_transformed_x$$)*$scale_x$jscomp$2_svg_width$jscomp$1$$;$pt$jscomp$22_transformed_y$$=$map__53329__$1_origin_y$$+(($pt$jscomp$22_transformed_y$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$22_transformed_y$$,$APP.$cljs$cst$1511$y$$))-$svg_y$jscomp$1_viewbox$jscomp$1$$)*$scale_y$jscomp$2_svg_height$jscomp$1$$;return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($svg_x$jscomp$1_transformed_x$$,$pt$jscomp$22_transformed_y$$)}return $pt$jscomp$22_transformed_y$$};
$app$render_wasm$svg_fills$normalize_point$$=function($pt$jscomp$23_pt_after_svg_transform_transformed_pt$$,$height$jscomp$83_normalized_y_units$jscomp$3$$,$shape$jscomp$339_viewbox$jscomp$2$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$83_normalized_y_units$jscomp$3$$,"userspaceonuse")){var $rect$jscomp$27$$=$app$render_wasm$svg_fills$shape__GT_selrect$$($shape$jscomp$339_viewbox$jscomp$2$$),$normalized_x_width$jscomp$92$$=function(){var $y__5111__auto__$jscomp$53$$=
$rect$jscomp$27$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$27$$,$APP.$cljs$cst$290$width$$);return.01>$y__5111__auto__$jscomp$53$$?.01:$y__5111__auto__$jscomp$53$$}();$height$jscomp$83_normalized_y_units$jscomp$3$$=function(){var $y__5111__auto__$jscomp$54$$=$rect$jscomp$27$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$27$$,$APP.$cljs$cst$1522$height$$);return.01>$y__5111__auto__$jscomp$54$$?.01:$y__5111__auto__$jscomp$54$$}();var $origin_x$jscomp$1$$=
function(){var $or__5025__auto__$jscomp$558_or__5025__auto____$1$jscomp$67$$=$rect$jscomp$27$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$27$$,$APP.$cljs$cst$1510$x$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$558_or__5025__auto____$1$jscomp$67$$))return $or__5025__auto__$jscomp$558_or__5025__auto____$1$jscomp$67$$;$or__5025__auto__$jscomp$558_or__5025__auto____$1$jscomp$67$$=$rect$jscomp$27$$?.x1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$27$$,
$APP.$cljs$cst$1523$x1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$558_or__5025__auto____$1$jscomp$67$$)?$or__5025__auto__$jscomp$558_or__5025__auto____$1$jscomp$67$$:0}(),$origin_y$jscomp$1$$=function(){var $or__5025__auto__$jscomp$559_or__5025__auto____$1$jscomp$68$$=$rect$jscomp$27$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$27$$,$APP.$cljs$cst$1511$y$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$559_or__5025__auto____$1$jscomp$68$$))return $or__5025__auto__$jscomp$559_or__5025__auto____$1$jscomp$68$$;
$or__5025__auto__$jscomp$559_or__5025__auto____$1$jscomp$68$$=$rect$jscomp$27$$?.y1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$27$$,$APP.$cljs$cst$1524$y1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$559_or__5025__auto____$1$jscomp$68$$)?$or__5025__auto__$jscomp$559_or__5025__auto____$1$jscomp$68$$:0}(),$svg_transform$jscomp$2$$=$cljs$cst$2965$svg_transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$339_viewbox$jscomp$2$$);$shape$jscomp$339_viewbox$jscomp$2$$=
$cljs$cst$1893$svg_viewbox$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$339_viewbox$jscomp$2$$);$pt$jscomp$23_pt_after_svg_transform_transformed_pt$$=$app$render_wasm$svg_fills$apply_svg_transform$$($pt$jscomp$23_pt_after_svg_transform_transformed_pt$$,$svg_transform$jscomp$2$$);$pt$jscomp$23_pt_after_svg_transform_transformed_pt$$=$app$render_wasm$svg_fills$apply_viewbox_transform$$($pt$jscomp$23_pt_after_svg_transform_transformed_pt$$,$shape$jscomp$339_viewbox$jscomp$2$$,$rect$jscomp$27$$);$normalized_x_width$jscomp$92$$=
(($pt$jscomp$23_pt_after_svg_transform_transformed_pt$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$23_pt_after_svg_transform_transformed_pt$$,$APP.$cljs$cst$1510$x$$))-$origin_x$jscomp$1$$)/$normalized_x_width$jscomp$92$$;$height$jscomp$83_normalized_y_units$jscomp$3$$=(($pt$jscomp$23_pt_after_svg_transform_transformed_pt$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$23_pt_after_svg_transform_transformed_pt$$,$APP.$cljs$cst$1511$y$$))-$origin_y$jscomp$1$$)/
$height$jscomp$83_normalized_y_units$jscomp$3$$;return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($normalized_x_width$jscomp$92$$,$height$jscomp$83_normalized_y_units$jscomp$3$$)}return $pt$jscomp$23_pt_after_svg_transform_transformed_pt$$};
$app$render_wasm$svg_fills$normalize_attrs$$=function($attrs$jscomp$44$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p__53330_v$jscomp$565$$){var $k$jscomp$622_key$jscomp$351$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__53330_v$jscomp$565$$,0,null);$p__53330_v$jscomp$565$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__53330_v$jscomp$565$$,1,
null);$k$jscomp$622_key$jscomp$351$$=$k$jscomp$622_key$jscomp$351$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$($k$jscomp$622_key$jscomp$351$$):$k$jscomp$622_key$jscomp$351$$ instanceof $APP.$cljs$core$Symbol$$?$APP.$cljs$core$name$$($k$jscomp$622_key$jscomp$351$$):$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$622_key$jscomp$351$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($clojure$string$lower_case$$($k$jscomp$622_key$jscomp$351$$)),
$p__53330_v$jscomp$565$$],null)}),$APP.$cljs$core$truth_$$($attrs$jscomp$44$$)?$attrs$jscomp$44$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$render_wasm$svg_fills$id_candidates$$=function($id$jscomp$319$$){var $base$jscomp$31$$=typeof $id$jscomp$319$$==="string"?$id$jscomp$319$$:$id$jscomp$319$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$($id$jscomp$319$$):$id$jscomp$319$$ instanceof $APP.$cljs$core$Symbol$$?$APP.$cljs$core$name$$($id$jscomp$319$$):$id$jscomp$319$$!=null?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$319$$):null,$lower$jscomp$4$$=$base$jscomp$31$$==null?null:$clojure$string$lower_case$$($base$jscomp$31$$),
$kebab$$=function(){var $G__53336__$1$$=$base$jscomp$31$$==null?null:$APP.$clojure$string$replace$$($base$jscomp$31$$,/([a-z0-9])([A-Z])/,"$1-$2");return $G__53336__$1$$==null?null:$clojure$string$lower_case$$($G__53336__$1$$)}();return $APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__53334_SHARP_$$){return $p1__53334_SHARP_$$==null||typeof $p1__53334_SHARP_$$==="string"&&$goog$string$internal$isEmptyOrWhitespace$$($goog$string$makeSafe$$($p1__53334_SHARP_$$))},
new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[typeof $id$jscomp$319$$==="string"?$id$jscomp$319$$:null,$id$jscomp$319$$ instanceof $APP.$cljs$core$Keyword$$?$id$jscomp$319$$:null,$id$jscomp$319$$ instanceof $APP.$cljs$core$Symbol$$?$id$jscomp$319$$:null,$base$jscomp$31$$,$APP.$cljs$core$truth_$$($base$jscomp$31$$)?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$31$$):null,$APP.$cljs$core$truth_$$($base$jscomp$31$$)?$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$31$$):
null,$lower$jscomp$4$$,$APP.$cljs$core$truth_$$($lower$jscomp$4$$)?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($lower$jscomp$4$$):null,$APP.$cljs$core$truth_$$($lower$jscomp$4$$)?$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($lower$jscomp$4$$):null,$kebab$$,$APP.$cljs$core$truth_$$($kebab$$)?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($kebab$$):null,$APP.$cljs$core$truth_$$($kebab$$)?$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($kebab$$):null],null)))};
$app$render_wasm$svg_fills$svg_def_by_id$$=function($defs$jscomp$4$$,$id$jscomp$320$$){return $APP.$cljs$core$some$$(function($p1__53337_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$4$$,$p1__53337_SHARP_$$)},$app$render_wasm$svg_fills$id_candidates$$($id$jscomp$320$$))};
$app$render_wasm$svg_fills$normalize_gradient_id$$=function($temp__5825__auto__$jscomp$162_value$jscomp$500_without$$){$temp__5825__auto__$jscomp$162_value$jscomp$500_without$$=$app$render_wasm$svg_fills$trim_fill_value$$($temp__5825__auto__$jscomp$162_value$jscomp$500_without$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$162_value$jscomp$500_without$$)?($temp__5825__auto__$jscomp$162_value$jscomp$500_without$$=$APP.$clojure$string$replace$$($temp__5825__auto__$jscomp$162_value$jscomp$500_without$$,
/^#/,""),$APP.$cljs$core$seq$$($temp__5825__auto__$jscomp$162_value$jscomp$500_without$$)?$temp__5825__auto__$jscomp$162_value$jscomp$500_without$$:null):null};$app$render_wasm$svg_fills$attr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($attrs$jscomp$45$$,$keys$jscomp$51$$){return $APP.$cljs$core$some$$(function($p1__53338_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$45$$,$p1__53338_SHARP_$$)},$keys$jscomp$51$$)};
$app$render_wasm$svg_fills$resolve_gradient_node$$=function($chain$jscomp$5_combined$jscomp$1_shape$jscomp$340$$,$gradient_id$$){var $defs$jscomp$5$$=$chain$jscomp$5_combined$jscomp$1_shape$jscomp$340$$?.$svg_defs$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($chain$jscomp$5_combined$jscomp$1_shape$jscomp$340$$,$cljs$cst$2943$svg_defs$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($defs$jscomp$5$$)?$gradient_id$$:$defs$jscomp$5$$)&&($chain$jscomp$5_combined$jscomp$1_shape$jscomp$340$$=
function(){for(var $G__53461_gid_temp__5823__auto__$jscomp$153$$=$gradient_id$$,$G__53462_seen$jscomp$11$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$,$G__53463_acc$jscomp$113$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $normalized$jscomp$2$$=$app$render_wasm$svg_fills$normalize_gradient_id$$($G__53461_gid_temp__5823__auto__$jscomp$153$$);if($normalized$jscomp$2$$==null||$APP.$cljs$core$contains_QMARK_$$($G__53462_seen$jscomp$11$$,$normalized$jscomp$2$$))return $G__53463_acc$jscomp$113$$;$G__53461_gid_temp__5823__auto__$jscomp$153$$=
$app$render_wasm$svg_fills$svg_def_by_id$$($defs$jscomp$5$$,$normalized$jscomp$2$$);if($APP.$cljs$core$truth_$$($G__53461_gid_temp__5823__auto__$jscomp$153$$)){var $node$jscomp$287$$=$G__53461_gid_temp__5823__auto__$jscomp$153$$,$attrs$jscomp$46$$=$app$render_wasm$svg_fills$normalize_attrs$$($APP.$cljs$cst$2645$attrs$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$287$$)),$tag$jscomp$61$$=function(){var $raw$jscomp$5$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$287$$);return $raw$jscomp$5$$ instanceof
$APP.$cljs$core$Keyword$$?$raw$jscomp$5$$:typeof $raw$jscomp$5$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($raw$jscomp$5$$):$raw$jscomp$5$$}(),$content$jscomp$125$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$287$$);$G__53461_gid_temp__5823__auto__$jscomp$153$$=function(){var $or__5025__auto__$jscomp$561_or__5025__auto____$1$jscomp$69_or__5025__auto____$2$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$46$$,
$cljs$cst$3032$xlinkhref$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$561_or__5025__auto____$1$jscomp$69_or__5025__auto____$2$jscomp$17$$))return $or__5025__auto__$jscomp$561_or__5025__auto____$1$jscomp$69_or__5025__auto____$2$jscomp$17$$;$or__5025__auto__$jscomp$561_or__5025__auto____$1$jscomp$69_or__5025__auto____$2$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$46$$,$cljs$cst$3033$xlink_href$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$561_or__5025__auto____$1$jscomp$69_or__5025__auto____$2$jscomp$17$$))return $or__5025__auto__$jscomp$561_or__5025__auto____$1$jscomp$69_or__5025__auto____$2$jscomp$17$$;
$or__5025__auto__$jscomp$561_or__5025__auto____$1$jscomp$69_or__5025__auto____$2$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$46$$,$cljs$cst$2853$xlink_COLON_href$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$561_or__5025__auto____$1$jscomp$69_or__5025__auto____$2$jscomp$17$$)?$or__5025__auto__$jscomp$561_or__5025__auto____$1$jscomp$69_or__5025__auto____$2$jscomp$17$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$46$$,$APP.$cljs$cst$2462$href$$)}();
$G__53462_seen$jscomp$11$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__53462_seen$jscomp$11$$,$normalized$jscomp$2$$);$G__53463_acc$jscomp$113$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__53463_acc$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$tag$jscomp$61$$,$APP.$cljs$cst$2645$attrs$$,$attrs$jscomp$46$$,$APP.$cljs$cst$1637$content$$,$content$jscomp$125$$],null))}else return $G__53463_acc$jscomp$113$$}}(),$APP.$cljs$core$seq$$($chain$jscomp$5_combined$jscomp$1_shape$jscomp$340$$))?
($chain$jscomp$5_combined$jscomp$1_shape$jscomp$340$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$245$$,$node$jscomp$288$$){var $tag$jscomp$62$$=function(){var $or__5025__auto__$jscomp$562$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$288$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$562$$)?$or__5025__auto__$jscomp$562$$:$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$245$$)}(),$attrs$jscomp$47$$=
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2645$attrs$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$245$$),$APP.$cljs$cst$2645$attrs$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$288$$)])),$content$jscomp$126$$=function(){var $own$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$288$$);return $APP.$cljs$core$seq$$($own$$)?$own$$:$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$245$$)}();
return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$tag$jscomp$62$$,$APP.$cljs$cst$2645$attrs$$,$attrs$jscomp$47$$,$APP.$cljs$cst$1637$content$$,$content$jscomp$126$$],null)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$reverse$$($chain$jscomp$5_combined$jscomp$1_shape$jscomp$340$$)),$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$2692$linearGradient$$,null,$cljs$cst$2693$radialGradient$$,
null],null),null),$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($chain$jscomp$5_combined$jscomp$1_shape$jscomp$340$$))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($chain$jscomp$5_combined$jscomp$1_shape$jscomp$340$$,$APP.$cljs$cst$1637$content$$,function($p1__53341_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__53341_SHARP_$$)?$p1__53341_SHARP_$$:$APP.$cljs$core$PersistentVector$EMPTY$$}):null):null};
$app$render_wasm$svg_fills$parse_gradient_stop$$=function($color$jscomp$47_color_value_color_value__$1_color_value__$2_stop_node$$){var $attrs$jscomp$48$$=$app$render_wasm$svg_fills$normalize_attrs$$($APP.$cljs$cst$2645$attrs$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$47_color_value_color_value__$1_color_value__$2_stop_node$$)),$style$jscomp$33$$=function(){var $G__53343$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$48$$,$APP.$cljs$cst$1904$style$$);return $G__53343$$==
null?null:$app$common$svg$parse_style$$($G__53343$$)}();$color$jscomp$47_color_value_color_value__$1_color_value__$2_stop_node$$=function(){var $or__5025__auto__$jscomp$564_or__5025__auto____$1$jscomp$70_or__5025__auto____$2$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$48$$,$cljs$cst$2904$stop_color$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$564_or__5025__auto____$1$jscomp$70_or__5025__auto____$2$jscomp$18$$))return $or__5025__auto__$jscomp$564_or__5025__auto____$1$jscomp$70_or__5025__auto____$2$jscomp$18$$;
$or__5025__auto__$jscomp$564_or__5025__auto____$1$jscomp$70_or__5025__auto____$2$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$48$$,$cljs$cst$3034$stopcolor$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$564_or__5025__auto____$1$jscomp$70_or__5025__auto____$2$jscomp$18$$))return $or__5025__auto__$jscomp$564_or__5025__auto____$1$jscomp$70_or__5025__auto____$2$jscomp$18$$;$or__5025__auto__$jscomp$564_or__5025__auto____$1$jscomp$70_or__5025__auto____$2$jscomp$18$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($style$jscomp$33$$,$cljs$cst$2904$stop_color$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$564_or__5025__auto____$1$jscomp$70_or__5025__auto____$2$jscomp$18$$)?$or__5025__auto__$jscomp$564_or__5025__auto____$1$jscomp$70_or__5025__auto____$2$jscomp$18$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($style$jscomp$33$$,$cljs$cst$3035$stopColor$$)}();$color$jscomp$47_color_value_color_value__$1_color_value__$2_stop_node$$=$app$render_wasm$svg_fills$trim_fill_value$$($color$jscomp$47_color_value_color_value__$1_color_value__$2_stop_node$$);
$color$jscomp$47_color_value_color_value__$1_color_value__$2_stop_node$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$47_color_value_color_value__$1_color_value__$2_stop_node$$,"currentcolor")?"#000000":$color$jscomp$47_color_value_color_value__$1_color_value__$2_stop_node$$;$color$jscomp$47_color_value_color_value__$1_color_value__$2_stop_node$$=$APP.$app$common$types$color$color_string_QMARK_$$($color$jscomp$47_color_value_color_value__$1_color_value__$2_stop_node$$)?$APP.$app$common$types$color$parse$$($color$jscomp$47_color_value_color_value__$1_color_value__$2_stop_node$$):
null;var $opacity$jscomp$21$$=function(){var $or__5025__auto__$jscomp$565_or__5025__auto____$1$jscomp$71_or__5025__auto____$2$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$48$$,$cljs$cst$2915$stop_opacity$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$565_or__5025__auto____$1$jscomp$71_or__5025__auto____$2$jscomp$19$$))return $or__5025__auto__$jscomp$565_or__5025__auto____$1$jscomp$71_or__5025__auto____$2$jscomp$19$$;$or__5025__auto__$jscomp$565_or__5025__auto____$1$jscomp$71_or__5025__auto____$2$jscomp$19$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$48$$,$cljs$cst$3036$stopopacity$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$565_or__5025__auto____$1$jscomp$71_or__5025__auto____$2$jscomp$19$$))return $or__5025__auto__$jscomp$565_or__5025__auto____$1$jscomp$71_or__5025__auto____$2$jscomp$19$$;$or__5025__auto__$jscomp$565_or__5025__auto____$1$jscomp$71_or__5025__auto____$2$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($style$jscomp$33$$,$cljs$cst$2915$stop_opacity$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$565_or__5025__auto____$1$jscomp$71_or__5025__auto____$2$jscomp$19$$)?$or__5025__auto__$jscomp$565_or__5025__auto____$1$jscomp$71_or__5025__auto____$2$jscomp$19$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($style$jscomp$33$$,$cljs$cst$3037$stopOpacity$$)}(),$offset$jscomp$146$$=function(){var $or__5025__auto__$jscomp$566$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$48$$,$APP.$cljs$cst$195$offset$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$566$$)?
$or__5025__auto__$jscomp$566$$:"0"}();return $APP.$cljs$core$truth_$$($color$jscomp$47_color_value_color_value__$1_color_value__$2_stop_node$$)?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1298$color$$,$color$jscomp$47_color_value_color_value__$1_color_value__$2_stop_node$$,$APP.$cljs$cst$1734$opacity$$,$opacity$jscomp$21$$==null?null:$app$render_wasm$svg_fills$parse_opacity$$($opacity$jscomp$21$$),$APP.$cljs$cst$195$offset$$,
$app$render_wasm$svg_fills$parse_offset$$($offset$jscomp$146$$)],null)):null};
$app$render_wasm$svg_fills$apply_gradient_transform$$=function($points$jscomp$55$$,$transform$jscomp$71$$){if($APP.$cljs$core$truth_$$($transform$jscomp$71$$)){var $matrix$jscomp$14$$=$app$common$svg$parse_transform$$($transform$jscomp$71$$);return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__53349_SHARP_$$){return $APP.$app$common$geom$point$transform$$($p1__53349_SHARP_$$,$matrix$jscomp$14$$)},$points$jscomp$55$$)}return $points$jscomp$55$$};
$app$render_wasm$svg_fills$build_linear_gradient$$=function($shape$jscomp$341$$,$content$jscomp$127_map__53358__$1_p__53357_stops$jscomp$5$$){$content$jscomp$127_map__53358__$1_p__53357_stops$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($content$jscomp$127_map__53358__$1_p__53357_stops$jscomp$5$$);var $attrs$jscomp$49$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$127_map__53358__$1_p__53357_stops$jscomp$5$$,$APP.$cljs$cst$2645$attrs$$);$content$jscomp$127_map__53358__$1_p__53357_stops$jscomp$5$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$127_map__53358__$1_p__53357_stops$jscomp$5$$,$APP.$cljs$cst$1637$content$$);var $units$jscomp$4$$=$clojure$string$lower_case$$(function(){var $or__5025__auto__$jscomp$567$$=$app$render_wasm$svg_fills$attr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($attrs$jscomp$49$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3038$gradientunits$$,$cljs$cst$3039$gradient_units$$]));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$567$$)?
$or__5025__auto__$jscomp$567$$:"objectBoundingBox"}()),$points$jscomp$56_start$jscomp$213_transform$jscomp$72$$=$app$render_wasm$svg_fills$attr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($attrs$jscomp$49$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3040$gradienttransform$$,$cljs$cst$3041$gradient_transform$$])),$end$jscomp$81_vec__53374_x1$jscomp$36$$=function(){var $JSCompiler_inline_result$jscomp$1016_or__5025__auto__$jscomp$568_or__5025__auto__$jscomp$inline_5892$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$49$$,$APP.$cljs$cst$1523$x1$$);$JSCompiler_inline_result$jscomp$1016_or__5025__auto__$jscomp$568_or__5025__auto__$jscomp$inline_5892$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1016_or__5025__auto__$jscomp$568_or__5025__auto__$jscomp$inline_5892$$)?$JSCompiler_inline_result$jscomp$1016_or__5025__auto__$jscomp$568_or__5025__auto__$jscomp$inline_5892$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$49$$,
$APP.$cljs$cst$1510$x$$);$JSCompiler_inline_result$jscomp$1016_or__5025__auto__$jscomp$568_or__5025__auto__$jscomp$inline_5892$$=$app$render_wasm$svg_fills$parse_length$$($JSCompiler_inline_result$jscomp$1016_or__5025__auto__$jscomp$568_or__5025__auto__$jscomp$inline_5892$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1016_or__5025__auto__$jscomp$568_or__5025__auto__$jscomp$inline_5892$$)?$JSCompiler_inline_result$jscomp$1016_or__5025__auto__$jscomp$568_or__5025__auto__$jscomp$inline_5892$$:
0}(),$y1$jscomp$38$$=function(){var $JSCompiler_inline_result$jscomp$1017_or__5025__auto__$jscomp$570_or__5025__auto__$jscomp$inline_5894$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$49$$,$APP.$cljs$cst$1524$y1$$);$JSCompiler_inline_result$jscomp$1017_or__5025__auto__$jscomp$570_or__5025__auto__$jscomp$inline_5894$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1017_or__5025__auto__$jscomp$570_or__5025__auto__$jscomp$inline_5894$$)?$JSCompiler_inline_result$jscomp$1017_or__5025__auto__$jscomp$570_or__5025__auto__$jscomp$inline_5894$$:
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$49$$,$APP.$cljs$cst$1511$y$$);$JSCompiler_inline_result$jscomp$1017_or__5025__auto__$jscomp$570_or__5025__auto__$jscomp$inline_5894$$=$app$render_wasm$svg_fills$parse_length$$($JSCompiler_inline_result$jscomp$1017_or__5025__auto__$jscomp$570_or__5025__auto__$jscomp$inline_5894$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1017_or__5025__auto__$jscomp$570_or__5025__auto__$jscomp$inline_5894$$)?$JSCompiler_inline_result$jscomp$1017_or__5025__auto__$jscomp$570_or__5025__auto__$jscomp$inline_5894$$:
0}(),$x2$jscomp$34$$=function(){var $JSCompiler_inline_result$jscomp$1018_or__5025__auto__$jscomp$572_or__5025__auto__$jscomp$inline_5896$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$49$$,$APP.$cljs$cst$1525$x2$$);$JSCompiler_inline_result$jscomp$1018_or__5025__auto__$jscomp$572_or__5025__auto__$jscomp$inline_5896$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1018_or__5025__auto__$jscomp$572_or__5025__auto__$jscomp$inline_5896$$)?$JSCompiler_inline_result$jscomp$1018_or__5025__auto__$jscomp$572_or__5025__auto__$jscomp$inline_5896$$:
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$49$$,$APP.$cljs$cst$1510$x$$);$JSCompiler_inline_result$jscomp$1018_or__5025__auto__$jscomp$572_or__5025__auto__$jscomp$inline_5896$$=$app$render_wasm$svg_fills$parse_length$$($JSCompiler_inline_result$jscomp$1018_or__5025__auto__$jscomp$572_or__5025__auto__$jscomp$inline_5896$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1018_or__5025__auto__$jscomp$572_or__5025__auto__$jscomp$inline_5896$$)?$JSCompiler_inline_result$jscomp$1018_or__5025__auto__$jscomp$572_or__5025__auto__$jscomp$inline_5896$$:
1}(),$y2$jscomp$36$$=function(){var $JSCompiler_inline_result$jscomp$1019_or__5025__auto__$jscomp$574_or__5025__auto__$jscomp$inline_5898$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$49$$,$APP.$cljs$cst$1526$y2$$);$JSCompiler_inline_result$jscomp$1019_or__5025__auto__$jscomp$574_or__5025__auto__$jscomp$inline_5898$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1019_or__5025__auto__$jscomp$574_or__5025__auto__$jscomp$inline_5898$$)?$JSCompiler_inline_result$jscomp$1019_or__5025__auto__$jscomp$574_or__5025__auto__$jscomp$inline_5898$$:
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$49$$,$APP.$cljs$cst$1511$y$$);$JSCompiler_inline_result$jscomp$1019_or__5025__auto__$jscomp$574_or__5025__auto__$jscomp$inline_5898$$=$app$render_wasm$svg_fills$parse_length$$($JSCompiler_inline_result$jscomp$1019_or__5025__auto__$jscomp$574_or__5025__auto__$jscomp$inline_5898$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1019_or__5025__auto__$jscomp$574_or__5025__auto__$jscomp$inline_5898$$)?$JSCompiler_inline_result$jscomp$1019_or__5025__auto__$jscomp$574_or__5025__auto__$jscomp$inline_5898$$:
0}();$content$jscomp$127_map__53358__$1_p__53357_stops$jscomp$5$$=$APP.$cljs$core$vec$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($node$jscomp$289$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$289$$)),$cljs$cst$2721$stop$$)?$app$render_wasm$svg_fills$parse_gradient_stop$$($node$jscomp$289$$):null},$content$jscomp$127_map__53358__$1_p__53357_stops$jscomp$5$$));
return $APP.$cljs$core$seq$$($content$jscomp$127_map__53358__$1_p__53357_stops$jscomp$5$$)?($points$jscomp$56_start$jscomp$213_transform$jscomp$72$$=$app$render_wasm$svg_fills$apply_gradient_transform$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$81_vec__53374_x1$jscomp$36$$,$y1$jscomp$38$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x2$jscomp$34$$,
$y2$jscomp$36$$)],null),$points$jscomp$56_start$jscomp$213_transform$jscomp$72$$),$end$jscomp$81_vec__53374_x1$jscomp$36$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__53356_SHARP_$$){return $app$render_wasm$svg_fills$normalize_point$$($p1__53356_SHARP_$$,$units$jscomp$4$$,$shape$jscomp$341$$)},$points$jscomp$56_start$jscomp$213_transform$jscomp$72$$),$points$jscomp$56_start$jscomp$213_transform$jscomp$72$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$81_vec__53374_x1$jscomp$36$$,
0,null),$end$jscomp$81_vec__53374_x1$jscomp$36$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$81_vec__53374_x1$jscomp$36$$,1,null),new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$287$linear$$,$APP.$cljs$cst$1729$start_x$$,$points$jscomp$56_start$jscomp$213_transform$jscomp$72$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($points$jscomp$56_start$jscomp$213_transform$jscomp$72$$,$APP.$cljs$cst$1510$x$$),$APP.$cljs$cst$1730$start_y$$,
$points$jscomp$56_start$jscomp$213_transform$jscomp$72$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($points$jscomp$56_start$jscomp$213_transform$jscomp$72$$,$APP.$cljs$cst$1511$y$$),$APP.$cljs$cst$1731$end_x$$,$end$jscomp$81_vec__53374_x1$jscomp$36$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$81_vec__53374_x1$jscomp$36$$,$APP.$cljs$cst$1510$x$$),$APP.$cljs$cst$1732$end_y$$,$end$jscomp$81_vec__53374_x1$jscomp$36$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$81_vec__53374_x1$jscomp$36$$,
$APP.$cljs$cst$1511$y$$),$APP.$cljs$cst$290$width$$,1,$APP.$cljs$cst$1733$stops$$,$content$jscomp$127_map__53358__$1_p__53357_stops$jscomp$5$$],null)):null};
$app$render_wasm$svg_fills$build_radial_gradient$$=function($shape$jscomp$342$$,$content$jscomp$128_map__53382__$1_p__53381_stops$jscomp$6$$){$content$jscomp$128_map__53382__$1_p__53381_stops$jscomp$6$$=$APP.$cljs$core$__destructure_map$$($content$jscomp$128_map__53382__$1_p__53381_stops$jscomp$6$$);var $attrs$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$128_map__53382__$1_p__53381_stops$jscomp$6$$,$APP.$cljs$cst$2645$attrs$$);$content$jscomp$128_map__53382__$1_p__53381_stops$jscomp$6$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$128_map__53382__$1_p__53381_stops$jscomp$6$$,$APP.$cljs$cst$1637$content$$);var $units$jscomp$5$$=$clojure$string$lower_case$$(function(){var $or__5025__auto__$jscomp$576$$=$app$render_wasm$svg_fills$attr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($attrs$jscomp$50$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3038$gradientunits$$,$cljs$cst$3039$gradient_units$$]));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$576$$)?
$or__5025__auto__$jscomp$576$$:"objectBoundingBox"}()),$transform$jscomp$73$$=$app$render_wasm$svg_fills$attr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($attrs$jscomp$50$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3040$gradienttransform$$,$cljs$cst$3041$gradient_transform$$])),$cx$jscomp$14$$=function(){var $JSCompiler_inline_result$jscomp$1020_or__5025__auto__$jscomp$577_or__5025__auto__$jscomp$inline_5900$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$50$$,
$APP.$cljs$cst$1897$cx$$);$JSCompiler_inline_result$jscomp$1020_or__5025__auto__$jscomp$577_or__5025__auto__$jscomp$inline_5900$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1020_or__5025__auto__$jscomp$577_or__5025__auto__$jscomp$inline_5900$$)?$JSCompiler_inline_result$jscomp$1020_or__5025__auto__$jscomp$577_or__5025__auto__$jscomp$inline_5900$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$50$$,$cljs$cst$2882$fx$$);$JSCompiler_inline_result$jscomp$1020_or__5025__auto__$jscomp$577_or__5025__auto__$jscomp$inline_5900$$=
$app$render_wasm$svg_fills$parse_length$$($JSCompiler_inline_result$jscomp$1020_or__5025__auto__$jscomp$577_or__5025__auto__$jscomp$inline_5900$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1020_or__5025__auto__$jscomp$577_or__5025__auto__$jscomp$inline_5900$$)?$JSCompiler_inline_result$jscomp$1020_or__5025__auto__$jscomp$577_or__5025__auto__$jscomp$inline_5900$$:.5}(),$cy$jscomp$15$$=function(){var $JSCompiler_inline_result$jscomp$1021_or__5025__auto__$jscomp$579_or__5025__auto__$jscomp$inline_5902$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$50$$,$APP.$cljs$cst$1898$cy$$);$JSCompiler_inline_result$jscomp$1021_or__5025__auto__$jscomp$579_or__5025__auto__$jscomp$inline_5902$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1021_or__5025__auto__$jscomp$579_or__5025__auto__$jscomp$inline_5902$$)?$JSCompiler_inline_result$jscomp$1021_or__5025__auto__$jscomp$579_or__5025__auto__$jscomp$inline_5902$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$50$$,
$cljs$cst$2869$fy$$);$JSCompiler_inline_result$jscomp$1021_or__5025__auto__$jscomp$579_or__5025__auto__$jscomp$inline_5902$$=$app$render_wasm$svg_fills$parse_length$$($JSCompiler_inline_result$jscomp$1021_or__5025__auto__$jscomp$579_or__5025__auto__$jscomp$inline_5902$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1021_or__5025__auto__$jscomp$579_or__5025__auto__$jscomp$inline_5902$$)?$JSCompiler_inline_result$jscomp$1021_or__5025__auto__$jscomp$579_or__5025__auto__$jscomp$inline_5902$$:
.5}(),$r$jscomp$113$$=function(){var $or__5025__auto__$jscomp$581$$=$app$render_wasm$svg_fills$parse_length$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$50$$,$APP.$cljs$cst$1743$r$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$581$$)?$or__5025__auto__$jscomp$581$$:.5}();$content$jscomp$128_map__53382__$1_p__53381_stops$jscomp$6$$=$APP.$cljs$core$vec$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($node$jscomp$290$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$290$$)),
$cljs$cst$2721$stop$$)?$app$render_wasm$svg_fills$parse_gradient_stop$$($node$jscomp$290$$):null},$content$jscomp$128_map__53382__$1_p__53381_stops$jscomp$6$$));if($APP.$cljs$core$seq$$($content$jscomp$128_map__53382__$1_p__53381_stops$jscomp$6$$)){var $radius_x_vec__53393_width$jscomp$93$$=function(){var $points$jscomp$57$$=$app$render_wasm$svg_fills$apply_gradient_transform$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$14$$,
$cy$jscomp$15$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$14$$+$r$jscomp$113$$,$cy$jscomp$15$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$14$$,$cy$jscomp$15$$+$r$jscomp$113$$)],null),$transform$jscomp$73$$);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__53377_SHARP_$$){return $app$render_wasm$svg_fills$normalize_point$$($p1__53377_SHARP_$$,$units$jscomp$5$$,$shape$jscomp$342$$)},$points$jscomp$57$$)}(),
$center$jscomp$32$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($radius_x_vec__53393_width$jscomp$93$$,0,null),$point_x_radius_point$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($radius_x_vec__53393_width$jscomp$93$$,1,null),$point_y$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($radius_x_vec__53393_width$jscomp$93$$,2,null);$radius_x_vec__53393_width$jscomp$93$$=$APP.$app$common$geom$point$distance$$($center$jscomp$32$$,$point_x_radius_point$$);var $radius_y$$=
$APP.$app$common$geom$point$distance$$($center$jscomp$32$$,$point_y$$),$base_radius$$=$radius_y$$>0?$radius_y$$:$radius_x_vec__53393_width$jscomp$93$$;$point_x_radius_point$$=$radius_y$$>0?$point_y$$:$point_x_radius_point$$;$radius_x_vec__53393_width$jscomp$93$$/=$base_radius$$>1E-6?$base_radius$$:1E-6;return new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1728$radial$$,$APP.$cljs$cst$1729$start_x$$,$center$jscomp$32$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$32$$,
$APP.$cljs$cst$1510$x$$),$APP.$cljs$cst$1730$start_y$$,$center$jscomp$32$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$32$$,$APP.$cljs$cst$1511$y$$),$APP.$cljs$cst$1731$end_x$$,$point_x_radius_point$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point_x_radius_point$$,$APP.$cljs$cst$1510$x$$),$APP.$cljs$cst$1732$end_y$$,$point_x_radius_point$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point_x_radius_point$$,$APP.$cljs$cst$1511$y$$),$APP.$cljs$cst$290$width$$,
$radius_x_vec__53393_width$jscomp$93$$,$APP.$cljs$cst$1733$stops$$,$content$jscomp$128_map__53382__$1_p__53381_stops$jscomp$6$$],null)}return null};
$app$render_wasm$svg_fills$svg_gradient__GT_fill$$=function($shape$jscomp$343$$,$G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$){$G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$=$app$render_wasm$svg_fills$trim_fill_value$$($G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$);
$G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$=typeof $G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$==="string"?$G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$:
$G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$!=null?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$):null;typeof $G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$===
"string"?($G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$=$APP.$cljs$core$re_matches$$($app$render_wasm$svg_fills$url_fill_pattern$$,$G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$),$G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$=
$G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$==null?null:$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$,1,null)):$G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$=
null;if($APP.$cljs$core$truth_$$($G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$))if($G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$=$app$render_wasm$svg_fills$resolve_gradient_node$$($shape$jscomp$343$$,$G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$),
$APP.$cljs$core$truth_$$($G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$)){var $G__53406$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$);switch($G__53406$$ instanceof $APP.$cljs$core$Keyword$$?$G__53406$$.$fqn$:
null){case "linearGradient":return $app$render_wasm$svg_fills$build_linear_gradient$$($shape$jscomp$343$$,$G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$);case "radialGradient":return $app$render_wasm$svg_fills$build_radial_gradient$$($shape$jscomp$343$$,$G__53404$jscomp$inline_5904_JSCompiler_temp$jscomp$1022_fill_str_temp__5825__auto__$jscomp$163_temp__5825__auto____$1$jscomp$9_trimmed$jscomp$1_value$jscomp$501$$);
default:return null}}else return null;else return null};
$app$render_wasm$svg_fills$parse_svg_fill$$=function($shape$jscomp$344_temp__5825__auto____$1$jscomp$10$$,$value$jscomp$502$$){var $normalized$jscomp$3_temp__5825__auto__$jscomp$164$$=$app$render_wasm$svg_fills$trim_fill_value$$($value$jscomp$502$$);if($APP.$cljs$core$truth_$$($normalized$jscomp$3_temp__5825__auto__$jscomp$164$$)){$normalized$jscomp$3_temp__5825__auto__$jscomp$164$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($clojure$string$lower_case$$($normalized$jscomp$3_temp__5825__auto__$jscomp$164$$),"currentcolor")?
"#000000":$normalized$jscomp$3_temp__5825__auto__$jscomp$164$$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($normalized$jscomp$3_temp__5825__auto__$jscomp$164$$,"none"))return null;if($APP.$app$common$types$color$color_string_QMARK_$$($normalized$jscomp$3_temp__5825__auto__$jscomp$164$$)||$value$jscomp$502$$ instanceof $APP.$cljs$core$Keyword$$)return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$260$value$$,$APP.$app$common$types$color$parse$$($normalized$jscomp$3_temp__5825__auto__$jscomp$164$$)],
null);if($APP.$goog$string$internal$startsWith$$($normalized$jscomp$3_temp__5825__auto__$jscomp$164$$,"url("))return $shape$jscomp$344_temp__5825__auto____$1$jscomp$10$$=$app$render_wasm$svg_fills$svg_gradient__GT_fill$$($shape$jscomp$344_temp__5825__auto____$1$jscomp$10$$,$normalized$jscomp$3_temp__5825__auto__$jscomp$164$$),$APP.$cljs$core$truth_$$($shape$jscomp$344_temp__5825__auto____$1$jscomp$10$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1724$gradient$$,
$APP.$cljs$cst$260$value$$,$shape$jscomp$344_temp__5825__auto____$1$jscomp$10$$],null):null}return null};
$app$render_wasm$svg_fills$svg_fill__GT_fills$$=function($shape$jscomp$345$$){var $map__53417__$1_opacity$jscomp$22_style_fill$$=$app$render_wasm$svg_fills$parse_svg_fill$$($shape$jscomp$345$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$345$$,$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1904$style$$),$APP.$cljs$cst$1403$fill$$)),$attr_fill_base_fill$$=$app$render_wasm$svg_fills$parse_svg_fill$$($shape$jscomp$345$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$345$$,$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1403$fill$$));$map__53417__$1_opacity$jscomp$22_style_fill$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$truth_$$($map__53417__$1_opacity$jscomp$22_style_fill$$)?$map__53417__$1_opacity$jscomp$22_style_fill$$:$attr_fill_base_fill$$);var $type$jscomp$414$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53417__$1_opacity$jscomp$22_style_fill$$,
$APP.$cljs$cst$139$type$$),$value$jscomp$503$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53417__$1_opacity$jscomp$22_style_fill$$,$APP.$cljs$cst$260$value$$);return $type$jscomp$414$$!=null?($map__53417__$1_opacity$jscomp$22_style_fill$$=function(){var $G__53422$jscomp$inline_5906_G__53423_or__5025__auto__$jscomp$583$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$345$$,
$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1904$style$$),$cljs$cst$3042$fillOpacity$$);$G__53422$jscomp$inline_5906_G__53423_or__5025__auto__$jscomp$583$$=$G__53422$jscomp$inline_5906_G__53423_or__5025__auto__$jscomp$583$$==null?null:$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($G__53422$jscomp$inline_5906_G__53423_or__5025__auto__$jscomp$583$$,1);if($APP.$cljs$core$truth_$$($G__53422$jscomp$inline_5906_G__53423_or__5025__auto__$jscomp$583$$))return $G__53422$jscomp$inline_5906_G__53423_or__5025__auto__$jscomp$583$$;
$G__53422$jscomp$inline_5906_G__53423_or__5025__auto__$jscomp$583$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$345$$,$APP.$cljs$cst$1890$svg_attrs$$),$cljs$cst$3042$fillOpacity$$);return $G__53422$jscomp$inline_5906_G__53423_or__5025__auto__$jscomp$583$$==null?null:$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($G__53422$jscomp$inline_5906_G__53423_or__5025__auto__$jscomp$583$$,1)}(),$attr_fill_base_fill$$=
function(){var $G__53426__$1$$=$type$jscomp$414$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$414$$.$fqn$:null;switch($G__53426__$1$$){case "color":return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1746$fill_color$$,$value$jscomp$503$$],null);case "gradient":return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1748$fill_color_gradient$$,$value$jscomp$503$$],null);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__53426__$1$$)].join(""));
}}(),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$map__53417__$1_opacity$jscomp$22_style_fill$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attr_fill_base_fill$$,$APP.$cljs$cst$1747$fill_opacity$$,$map__53417__$1_opacity$jscomp$22_style_fill$$):$attr_fill_base_fill$$],null)):null};
$app$render_wasm$svg_filters$find_filter_element$$=function($filter_content$$,$tag$jscomp$63$$){return $APP.$cljs$core$some$$(function($p1__53450_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($tag$jscomp$63$$,$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($p1__53450_SHARP_$$))?$p1__53450_SHARP_$$:null},$filter_content$$)};
$app$render_wasm$svg_filters$find_filter_def$$=function($shape$jscomp$347$$){var $filter_attr_filter_ids$$=function(){var $or__5025__auto__$jscomp$584$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$347$$,$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$2691$filter$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$584$$)?$or__5025__auto__$jscomp$584$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$347$$,
$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1904$style$$),$APP.$cljs$cst$2691$filter$$)}(),$svg_defs$jscomp$1$$=$shape$jscomp$347$$?.$svg_defs$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$347$$,$cljs$cst$2943$svg_defs$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($filter_attr_filter_ids$$)?$svg_defs$jscomp$1$$:$filter_attr_filter_ids$$)?($filter_attr_filter_ids$$=$app$common$svg$extract_ids$$($filter_attr_filter_ids$$),$APP.$cljs$core$some$$(function($p1__53454_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($svg_defs$jscomp$1$$,
$p1__53454_SHARP_$$)},$filter_attr_filter_ids$$)):null};
$app$render_wasm$svg_filters$build_blur$$=function($gaussian_blur$$){return $APP.$cljs$core$truth_$$($gaussian_blur$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1908$layer_blur$$,$APP.$cljs$cst$260$value$$,$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gaussian_blur$$,$APP.$cljs$cst$2645$attrs$$),
$cljs$cst$2764$stdDeviation$$),0),$APP.$cljs$cst$1620$hidden$$,!1],null):null};
$app$render_wasm$svg_filters$build_drop_shadow$$=function($dy$jscomp$15_filter_content$jscomp$1_offset_elem$$,$drop_shadow_elements_dx$jscomp$15$$){$dy$jscomp$15_filter_content$jscomp$1_offset_elem$$=$app$render_wasm$svg_filters$find_filter_element$$($dy$jscomp$15_filter_content$jscomp$1_offset_elem$$,$cljs$cst$2736$feOffset$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($dy$jscomp$15_filter_content$jscomp$1_offset_elem$$)?$APP.$cljs$core$seq$$($drop_shadow_elements_dx$jscomp$15$$):$dy$jscomp$15_filter_content$jscomp$1_offset_elem$$)){var $blur_elem_blur_value$jscomp$4$$=
$app$render_wasm$svg_filters$find_filter_element$$($drop_shadow_elements_dx$jscomp$15$$,$cljs$cst$2720$feGaussianBlur$$);$drop_shadow_elements_dx$jscomp$15$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dy$jscomp$15_filter_content$jscomp$1_offset_elem$$,$APP.$cljs$cst$2645$attrs$$),$cljs$cst$2777$dx$$),0);$dy$jscomp$15_filter_content$jscomp$1_offset_elem$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dy$jscomp$15_filter_content$jscomp$1_offset_elem$$,
$APP.$cljs$cst$2645$attrs$$),$cljs$cst$2808$dy$$),0);$blur_elem_blur_value$jscomp$4$$=$APP.$cljs$core$truth_$$($blur_elem_blur_value$jscomp$4$$)?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($blur_elem_blur_value$jscomp$4$$,$APP.$cljs$cst$2645$attrs$$),$cljs$cst$2764$stdDeviation$$),0)*2:0;return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$1904$style$$,$APP.$cljs$cst$1905$drop_shadow$$,$APP.$cljs$cst$1650$offset_x$$,$drop_shadow_elements_dx$jscomp$15$$,$APP.$cljs$cst$1651$offset_y$$,$dy$jscomp$15_filter_content$jscomp$1_offset_elem$$,$APP.$cljs$cst$1653$blur$$,$blur_elem_blur_value$jscomp$4$$,$APP.$cljs$cst$1652$spread$$,0,$APP.$cljs$cst$1620$hidden$$,!1,$APP.$cljs$cst$1298$color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1298$color$$,"#000000",$APP.$cljs$cst$1734$opacity$$,1],null)],null)],null)}return null};
$app$render_wasm$svg_filters$apply_svg_filters$$=function($G__53493__$1_shape$jscomp$348$$){var $blur$jscomp$3_existing_blur$$=$APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($G__53493__$1_shape$jscomp$348$$),$existing_shadow_shadow__$1$jscomp$7$$=$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($G__53493__$1_shape$jscomp$348$$),$content$jscomp$129_temp__5823__auto__$jscomp$154$$=$app$render_wasm$svg_filters$find_filter_def$$($G__53493__$1_shape$jscomp$348$$);if($APP.$cljs$core$truth_$$($content$jscomp$129_temp__5823__auto__$jscomp$154$$)){$content$jscomp$129_temp__5823__auto__$jscomp$154$$=
$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$129_temp__5823__auto__$jscomp$154$$);var $gaussian_blur$jscomp$1$$=$app$render_wasm$svg_filters$find_filter_element$$($content$jscomp$129_temp__5823__auto__$jscomp$154$$,$cljs$cst$2720$feGaussianBlur$$),$drop_shadow_elements$jscomp$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__53489_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($app$render_wasm$svg_filters$drop_shadow_tags$$,$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($p1__53489_SHARP_$$))},
$content$jscomp$129_temp__5823__auto__$jscomp$154$$);$blur$jscomp$3_existing_blur$$=$APP.$cljs$core$truth_$$($blur$jscomp$3_existing_blur$$)?$blur$jscomp$3_existing_blur$$:$app$render_wasm$svg_filters$build_blur$$($gaussian_blur$jscomp$1$$);$existing_shadow_shadow__$1$jscomp$7$$=$APP.$cljs$core$seq$$($existing_shadow_shadow__$1$jscomp$7$$)?$existing_shadow_shadow__$1$jscomp$7$$:$app$render_wasm$svg_filters$build_drop_shadow$$($content$jscomp$129_temp__5823__auto__$jscomp$154$$,$drop_shadow_elements$jscomp$1$$);
$G__53493__$1_shape$jscomp$348$$=$APP.$cljs$core$truth_$$($blur$jscomp$3_existing_blur$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__53493__$1_shape$jscomp$348$$,$APP.$cljs$cst$1653$blur$$,$blur$jscomp$3_existing_blur$$):$G__53493__$1_shape$jscomp$348$$;return $APP.$cljs$core$seq$$($existing_shadow_shadow__$1$jscomp$7$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__53493__$1_shape$jscomp$348$$,$APP.$cljs$cst$1654$shadow$$,$existing_shadow_shadow__$1$jscomp$7$$):$G__53493__$1_shape$jscomp$348$$}return $G__53493__$1_shape$jscomp$348$$};
$app$render_wasm$svg_filters$apply_svg_derived$$=function($shape$jscomp$349_shape_SINGLEQUOTE_$jscomp$2$$){$shape$jscomp$349_shape_SINGLEQUOTE_$jscomp$2$$=$app$render_wasm$svg_filters$apply_svg_filters$$($shape$jscomp$349_shape_SINGLEQUOTE_$jscomp$2$$);var $base_fills$jscomp$inline_12201_or__5025__auto__$jscomp$inline_5908$$=$shape$jscomp$349_shape_SINGLEQUOTE_$jscomp$2$$?.$fills$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$349_shape_SINGLEQUOTE_$jscomp$2$$,$APP.$cljs$cst$1634$fills$$);
var $fallback$jscomp$inline_12202$$=$app$render_wasm$svg_fills$svg_fill__GT_fills$$($shape$jscomp$349_shape_SINGLEQUOTE_$jscomp$2$$),$type$jscomp$inline_12203$$=$shape$jscomp$349_shape_SINGLEQUOTE_$jscomp$2$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$349_shape_SINGLEQUOTE_$jscomp$2$$,$APP.$cljs$cst$139$type$$);$base_fills$jscomp$inline_12201_or__5025__auto__$jscomp$inline_5908$$=$APP.$cljs$core$seq$$($base_fills$jscomp$inline_12201_or__5025__auto__$jscomp$inline_5908$$)?
$base_fills$jscomp$inline_12201_or__5025__auto__$jscomp$inline_5908$$:$APP.$cljs$core$seq$$($fallback$jscomp$inline_12202$$)?$fallback$jscomp$inline_12202$$:$APP.$cljs$core$contains_QMARK_$$($shape$jscomp$349_shape_SINGLEQUOTE_$jscomp$2$$,$APP.$cljs$cst$1890$svg_attrs$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$svg_raw$$,$type$jscomp$inline_12203$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,$type$jscomp$inline_12203$$))?
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1746$fill_color$$,"#000000",$APP.$cljs$cst$1747$fill_opacity$$,1],null)],null):$APP.$cljs$core$PersistentVector$EMPTY$$;return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape$jscomp$349_shape_SINGLEQUOTE_$jscomp$2$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$truth_$$($base_fills$jscomp$inline_12201_or__5025__auto__$jscomp$inline_5908$$)?
$base_fills$jscomp$inline_12201_or__5025__auto__$jscomp$inline_5908$$:$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$349_shape_SINGLEQUOTE_$jscomp$2$$),$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$349_shape_SINGLEQUOTE_$jscomp$2$$)]))};
$app$render_wasm$text_editor$rgba__GT_fill_color$$=function($hex$jscomp$5_rgba$jscomp$2$$){$hex$jscomp$5_rgba$jscomp$2$$=($hex$jscomp$5_rgba$jscomp$2$$&16777215).toString(16);return["#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$5_rgba$jscomp$2$$.padStart(6,"0"))].join("")};$app$render_wasm$text_editor$rgba__GT_opacity$$=function($rgba$jscomp$3$$){return Math.round(($rgba$jscomp$3$$>>24&255)/255*100)/100};
$app$render_wasm$text_editor$read_fill_from_heap$$=function($flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$,$heap_u32$$,$heap_i32_height$jscomp$84$$,$heap_f32$$,$fill_byte_offset$$){var $fill_u32_offset$$=$fill_byte_offset$$>>2;switch($flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$[$fill_byte_offset$$]){case 0:var $alpha$jscomp$11_rgba$jscomp$4$$=$heap_u32$$[$fill_u32_offset$$+1];return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1746$fill_color$$,$app$render_wasm$text_editor$rgba__GT_fill_color$$($alpha$jscomp$11_rgba$jscomp$4$$),
$APP.$cljs$cst$1747$fill_opacity$$,$app$render_wasm$text_editor$rgba__GT_opacity$$($alpha$jscomp$11_rgba$jscomp$4$$)],null);case 1:var $gradient_u32_offset_width$jscomp$94$$=$fill_byte_offset$$+4>>2,$a$jscomp$378_start_x$jscomp$4$$=$heap_f32$$[$gradient_u32_offset_width$jscomp$94$$],$b$jscomp$309_start_y$jscomp$4$$=$heap_f32$$[$gradient_u32_offset_width$jscomp$94$$+1],$c$jscomp$296_end_x$jscomp$4$$=$heap_f32$$[$gradient_u32_offset_width$jscomp$94$$+2],$d$jscomp$234_end_y$jscomp$4$$=$heap_f32$$[$gradient_u32_offset_width$jscomp$94$$+
3];$alpha$jscomp$11_rgba$jscomp$4$$=$flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$[$fill_byte_offset$$+20];$gradient_u32_offset_width$jscomp$94$$=$heap_f32$$[$gradient_u32_offset_width$jscomp$94$$+5];$flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$=$flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$[$fill_byte_offset$$+28];$flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($idx$jscomp$80_rgba$jscomp$5$$){var $offset$jscomp$147_stop_u32_offset$$=
$fill_byte_offset$$+32+$idx$jscomp$80_rgba$jscomp$5$$*8>>2;$idx$jscomp$80_rgba$jscomp$5$$=$heap_u32$$[$offset$jscomp$147_stop_u32_offset$$];$offset$jscomp$147_stop_u32_offset$$=$heap_f32$$[$offset$jscomp$147_stop_u32_offset$$+1];return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1298$color$$,$app$render_wasm$text_editor$rgba__GT_fill_color$$($idx$jscomp$80_rgba$jscomp$5$$),$APP.$cljs$cst$1734$opacity$$,$app$render_wasm$text_editor$rgba__GT_opacity$$($idx$jscomp$80_rgba$jscomp$5$$),
$APP.$cljs$cst$195$offset$$,Math.round($offset$jscomp$147_stop_u32_offset$$*100)/100],null)},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$)));return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1747$fill_opacity$$,Math.round($alpha$jscomp$11_rgba$jscomp$4$$/255*100)/100,$APP.$cljs$cst$1748$fill_color_gradient$$,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1729$start_x$$,$a$jscomp$378_start_x$jscomp$4$$,
$APP.$cljs$cst$1730$start_y$$,$b$jscomp$309_start_y$jscomp$4$$,$APP.$cljs$cst$1731$end_x$$,$c$jscomp$296_end_x$jscomp$4$$,$APP.$cljs$cst$1732$end_y$$,$d$jscomp$234_end_y$jscomp$4$$,$APP.$cljs$cst$290$width$$,$gradient_u32_offset_width$jscomp$94$$,$APP.$cljs$cst$1733$stops$$,$flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$287$linear$$],null)],null);case 2:return $gradient_u32_offset_width$jscomp$94$$=$fill_byte_offset$$+4>>2,$a$jscomp$378_start_x$jscomp$4$$=
$heap_f32$$[$gradient_u32_offset_width$jscomp$94$$],$b$jscomp$309_start_y$jscomp$4$$=$heap_f32$$[$gradient_u32_offset_width$jscomp$94$$+1],$c$jscomp$296_end_x$jscomp$4$$=$heap_f32$$[$gradient_u32_offset_width$jscomp$94$$+2],$d$jscomp$234_end_y$jscomp$4$$=$heap_f32$$[$gradient_u32_offset_width$jscomp$94$$+3],$alpha$jscomp$11_rgba$jscomp$4$$=$flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$[$fill_byte_offset$$+20],$gradient_u32_offset_width$jscomp$94$$=$heap_f32$$[$gradient_u32_offset_width$jscomp$94$$+
5],$flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$=$flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$[$fill_byte_offset$$+28],$flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($idx$jscomp$81_rgba$jscomp$6$$){var $offset$jscomp$148_stop_u32_offset$jscomp$1$$=$fill_byte_offset$$+32+$idx$jscomp$81_rgba$jscomp$6$$*8>>2;$idx$jscomp$81_rgba$jscomp$6$$=
$heap_u32$$[$offset$jscomp$148_stop_u32_offset$jscomp$1$$];$offset$jscomp$148_stop_u32_offset$jscomp$1$$=$heap_f32$$[$offset$jscomp$148_stop_u32_offset$jscomp$1$$+1];return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1298$color$$,$app$render_wasm$text_editor$rgba__GT_fill_color$$($idx$jscomp$81_rgba$jscomp$6$$),$APP.$cljs$cst$1734$opacity$$,$app$render_wasm$text_editor$rgba__GT_opacity$$($idx$jscomp$81_rgba$jscomp$6$$),$APP.$cljs$cst$195$offset$$,Math.round($offset$jscomp$148_stop_u32_offset$jscomp$1$$*
100)/100],null)},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$))),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1747$fill_opacity$$,Math.round($alpha$jscomp$11_rgba$jscomp$4$$/255*100)/100,$APP.$cljs$cst$1748$fill_color_gradient$$,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1729$start_x$$,$a$jscomp$378_start_x$jscomp$4$$,$APP.$cljs$cst$1730$start_y$$,$b$jscomp$309_start_y$jscomp$4$$,$APP.$cljs$cst$1731$end_x$$,
$c$jscomp$296_end_x$jscomp$4$$,$APP.$cljs$cst$1732$end_y$$,$d$jscomp$234_end_y$jscomp$4$$,$APP.$cljs$cst$290$width$$,$gradient_u32_offset_width$jscomp$94$$,$APP.$cljs$cst$1733$stops$$,$flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1728$radial$$],null)],null);case 3:return $a$jscomp$378_start_x$jscomp$4$$=$heap_u32$$[$fill_u32_offset$$+1],$b$jscomp$309_start_y$jscomp$4$$=$heap_u32$$[$fill_u32_offset$$+2],$c$jscomp$296_end_x$jscomp$4$$=$heap_u32$$[$fill_u32_offset$$+
3],$d$jscomp$234_end_y$jscomp$4$$=$heap_u32$$[$fill_u32_offset$$+4],$alpha$jscomp$11_rgba$jscomp$4$$=$flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$[$fill_byte_offset$$+20],$flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$=$flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$[$fill_byte_offset$$+21],$gradient_u32_offset_width$jscomp$94$$=$heap_i32_height$jscomp$84$$[$fill_u32_offset$$+6],$heap_i32_height$jscomp$84$$=$heap_i32_height$jscomp$84$$[$fill_u32_offset$$+7],new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1747$fill_opacity$$,Math.round($alpha$jscomp$11_rgba$jscomp$4$$/255*100)/100,$APP.$cljs$cst$1632$fill_image$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,$app$common$uuid$uuid$$($app$common$uuid_impl$v8$$.$fromUnsignedParts$($a$jscomp$378_start_x$jscomp$4$$,$b$jscomp$309_start_y$jscomp$4$$,$c$jscomp$296_end_x$jscomp$4$$,$d$jscomp$234_end_y$jscomp$4$$)),$APP.$cljs$cst$290$width$$,$gradient_u32_offset_width$jscomp$94$$,$APP.$cljs$cst$1522$height$$,$heap_i32_height$jscomp$84$$,
$APP.$cljs$cst$1727$keep_aspect_ratio$$,($flags$jscomp$26_heap_u8_stop_count_stops$jscomp$7$$&1)!==0,$APP.$cljs$cst$725$name$$,"sample"],null)],null);default:return null}};$app$render_wasm$text_editor$text_editor_get_style_property$cljs$0core$0IFn$0_invoke$0arity$03$$=function($state$jscomp$160$$,$value$jscomp$505$$,$default_value$jscomp$1$$){switch($state$jscomp$160$$){case 0:return $default_value$jscomp$1$$;case 1:return $value$jscomp$505$$;case 2:return $APP.$cljs$cst$1616$multiple$$;default:return 0}};
$app$render_wasm$text_editor$text_editor_translate_text_align$$=function($text_align$jscomp$3$$){switch($text_align$jscomp$3$$){case 0:return"left";case 1:return"center";case 2:return"right";default:return $text_align$jscomp$3$$}};$app$render_wasm$text_editor$text_editor_translate_text_direction$$=function($text_direction$jscomp$3$$){switch($text_direction$jscomp$3$$){case 0:return"ltr";case 1:return"rtl";default:return $text_direction$jscomp$3$$}};
$app$render_wasm$text_editor$text_editor_translate_text_transform$$=function($text_transform$jscomp$5$$){switch($text_transform$jscomp$5$$){case 0:return"none";case 1:return"lowercase";case 2:return"uppercase";case 3:return"capitalize";default:return $text_transform$jscomp$5$$}};
$app$render_wasm$text_editor$text_editor_translate_text_decoration$$=function($text_decoration$jscomp$4$$){switch($text_decoration$jscomp$4$$){case 0:return"none";case 1:return"underline";case 2:return"linethrough";case 3:return"overline";default:return $text_decoration$jscomp$4$$}};$app$render_wasm$text_editor$text_editor_translate_font_style$$=function($font_style$jscomp$9$$){switch($font_style$jscomp$9$$){case 0:return"normal";case 1:return"italic";default:return $font_style$jscomp$9$$}};
$app$render_wasm$text_editor$text_editor_compute_font_variant_id$$=function($font_data$jscomp$9_font_id$jscomp$24$$,$font_weight$jscomp$9_or__5025__auto____$1$jscomp$72_variant$jscomp$11$$,$font_style$jscomp$10_or__5025__auto__$jscomp$587$$){$font_data$jscomp$9_font_id$jscomp$24$$=$APP.$app$main$fonts$get_font_data$$($font_data$jscomp$9_font_id$jscomp$24$$);$font_weight$jscomp$9_or__5025__auto____$1$jscomp$72_variant$jscomp$11$$=$app$main$fonts$find_closest_variant$$($font_data$jscomp$9_font_id$jscomp$24$$,
$font_weight$jscomp$9_or__5025__auto____$1$jscomp$72_variant$jscomp$11$$,$font_style$jscomp$10_or__5025__auto__$jscomp$587$$);$font_style$jscomp$10_or__5025__auto__$jscomp$587$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font_weight$jscomp$9_or__5025__auto____$1$jscomp$72_variant$jscomp$11$$);if($APP.$cljs$core$truth_$$($font_style$jscomp$10_or__5025__auto__$jscomp$587$$))return $font_style$jscomp$10_or__5025__auto__$jscomp$587$$;$font_weight$jscomp$9_or__5025__auto____$1$jscomp$72_variant$jscomp$11$$=
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font_weight$jscomp$9_or__5025__auto____$1$jscomp$72_variant$jscomp$11$$);return $APP.$cljs$core$truth_$$($font_weight$jscomp$9_or__5025__auto____$1$jscomp$72_variant$jscomp$11$$)?$font_weight$jscomp$9_or__5025__auto____$1$jscomp$72_variant$jscomp$11$$:"regular"};
$app$render_wasm$text_editor$text_editor_get_current_styles$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $ptr$jscomp$7$$=function(){var $cause53437_fn_53436$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_get_current_styles;try{return $cause53437_fn_53436$$()}catch($e53438$$){$cause53437_fn_53436$$=$e53438$$;var $code__52999__auto__$jscomp$19_code_num__52998__auto__$jscomp$19_read_code_fn__52997__auto__$jscomp$19$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;
$code__52999__auto__$jscomp$19_code_num__52998__auto__$jscomp$19_read_code_fn__52997__auto__$jscomp$19$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$19_code_num__52998__auto__$jscomp$19_read_code_fn__52997__auto__$jscomp$19$$)?$code__52999__auto__$jscomp$19_code_num__52998__auto__$jscomp$19_read_code_fn__52997__auto__$jscomp$19$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$19_code_num__52998__auto__$jscomp$19_read_code_fn__52997__auto__$jscomp$19$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$19_code_num__52998__auto__$jscomp$19_read_code_fn__52997__auto__$jscomp$19$$():null;$code__52999__auto__$jscomp$19_code_num__52998__auto__$jscomp$19_read_code_fn__52997__auto__$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$19_code_num__52998__auto__$jscomp$19_read_code_fn__52997__auto__$jscomp$19$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$19$$=["WASM Error (",
$APP.$app$common$data$name$$($code__52999__auto__$jscomp$19_code_num__52998__auto__$jscomp$19_read_code_fn__52997__auto__$jscomp$19$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$19$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_get_current_styles",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$19$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$19_code_num__52998__auto__$jscomp$19_read_code_fn__52997__auto__$jscomp$19$$],
null),$cause53437_fn_53436$$);}}();if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($ptr$jscomp$7$$)?$ptr$jscomp$7$$!==0:$ptr$jscomp$7$$)){var $heap_u8$jscomp$1$$=$APP.$app$render_wasm$mem$get_heap_u8$$(),$heap_u32$jscomp$1$$=$APP.$app$render_wasm$mem$get_heap_u32$$(),$heap_i32$jscomp$1$$=$APP.$app$render_wasm$wasm$internal_module$$.HEAP32,$heap_f32$jscomp$1$$=$app$render_wasm$mem$get_heap_f32$$(),$letter_spacing_value_u32_offset$$=$ptr$jscomp$7$$>>2,$JSCompiler_inline_result$jscomp$1027_vertical_align$jscomp$2$$=
$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$],$JSCompiler_temp_const$jscomp$1024_text_align_state$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+1],$result$jscomp$246_text_direction_state$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+2],$text_decoration_state$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+3],$JSCompiler_temp_const$jscomp$1025_text_transform_state$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+4],$font_family_state$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+
5],$font_size_state$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+6],$font_weight_state$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+7],$font_variant_id_state$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+8],$JSCompiler_temp_const$jscomp$1026_line_height_state$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+9],$letter_spacing_state$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+10],$num_fills_selected_colors$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+
11],$fills__$1$jscomp$5_multiple_fills$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+12],$text_align_value$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+13],$text_direction_value$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+14],$text_decoration_value$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+15],$text_transform_value$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+16],$font_family_id_value_font_id$jscomp$25$$=$app$common$uuid$uuid$$($app$common$uuid_impl$v8$$.$fromUnsignedParts$($heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+
17],$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+18],$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+19],$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+20])),$font_family_style_value_font_style_value$$=$heap_u32$jscomp$1$$[$letter_spacing_value_u32_offset$$+21],$font_size_value$$=$heap_f32$jscomp$1$$[$letter_spacing_value_u32_offset$$+23],$font_weight_value$$=$heap_i32$jscomp$1$$[$letter_spacing_value_u32_offset$$+24],$line_height_value$$=$heap_f32$jscomp$1$$[$letter_spacing_value_u32_offset$$+
29];$letter_spacing_value_u32_offset$$=$heap_f32$jscomp$1$$[$letter_spacing_value_u32_offset$$+30];$font_family_id_value_font_id$jscomp$25$$=$app$render_wasm$api$fonts$uuid__GT_font_id$$($font_family_id_value_font_id$jscomp$25$$);$font_family_style_value_font_style_value$$=$app$render_wasm$text_editor$text_editor_translate_font_style$$($app$render_wasm$text_editor$text_editor_get_style_property$cljs$0core$0IFn$0_invoke$0arity$03$$($font_family_state$$,$font_family_style_value_font_style_value$$,$font_family_style_value_font_style_value$$));
var $font_variant_id_computed$$=$app$render_wasm$text_editor$text_editor_compute_font_variant_id$$($font_family_id_value_font_id$jscomp$25$$,$font_weight_value$$,$font_family_style_value_font_style_value$$),$fills$jscomp$17$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$some_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($idx$jscomp$82$$){return $app$render_wasm$text_editor$read_fill_from_heap$$($heap_u8$jscomp$1$$,
$heap_u32$jscomp$1$$,$heap_i32$jscomp$1$$,$heap_f32$jscomp$1$$,$ptr$jscomp$7$$+124+$idx$jscomp$82$$*160)},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($num_fills_selected_colors$$))));$num_fills_selected_colors$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($fills__$1$jscomp$5_multiple_fills$$,1)?$fills$jscomp$17$$:null;$fills__$1$jscomp$5_multiple_fills$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($fills__$1$jscomp$5_multiple_fills$$,1)?$APP.$cljs$cst$1616$multiple$$:
$fills$jscomp$17$$;$JSCompiler_temp_const$jscomp$1026_line_height_state$$=$app$render_wasm$text_editor$text_editor_get_style_property$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1026_line_height_state$$,$line_height_value$$,$line_height_value$$);$JSCompiler_temp_const$jscomp$1025_text_transform_state$$=$app$render_wasm$text_editor$text_editor_translate_text_transform$$($app$render_wasm$text_editor$text_editor_get_style_property$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1025_text_transform_state$$,
$text_transform_value$$,$text_transform_value$$));$JSCompiler_temp_const$jscomp$1024_text_align_state$$=$app$render_wasm$text_editor$text_editor_translate_text_align$$($app$render_wasm$text_editor$text_editor_get_style_property$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1024_text_align_state$$,$text_align_value$$,$text_align_value$$));a:switch($JSCompiler_inline_result$jscomp$1027_vertical_align$jscomp$2$$){case 0:$JSCompiler_inline_result$jscomp$1027_vertical_align$jscomp$2$$=
"top";break a;case 1:$JSCompiler_inline_result$jscomp$1027_vertical_align$jscomp$2$$="center";break a;case 2:$JSCompiler_inline_result$jscomp$1027_vertical_align$jscomp$2$$="bottom";break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1027_vertical_align$jscomp$2$$)].join(""));}$result$jscomp$246_text_direction_state$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1765$line_height$$,$APP.$cljs$cst$1762$font_style$$,
$APP.$cljs$cst$1756$typography_ref_id$$,$APP.$cljs$cst$1769$text_transform$$,$APP.$cljs$cst$1763$text_align$$,$APP.$cljs$cst$1767$vertical_align$$,$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1642$typography_ref_file$$,$APP.$cljs$cst$1764$text_direction$$,$APP.$cljs$cst$1759$font_variant_id$$,$APP.$cljs$cst$1768$text_decoration$$,$cljs$cst$3043$selected_colors$$,$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$cst$1758$font_family$$],
[$JSCompiler_temp_const$jscomp$1026_line_height_state$$,$font_family_style_value_font_style_value$$,null,$JSCompiler_temp_const$jscomp$1025_text_transform_state$$,$JSCompiler_temp_const$jscomp$1024_text_align_state$$,$JSCompiler_inline_result$jscomp$1027_vertical_align$jscomp$2$$,$app$render_wasm$text_editor$text_editor_get_style_property$cljs$0core$0IFn$0_invoke$0arity$03$$($font_family_state$$,$font_family_id_value_font_id$jscomp$25$$,$font_family_id_value_font_id$jscomp$25$$),$app$render_wasm$text_editor$text_editor_get_style_property$cljs$0core$0IFn$0_invoke$0arity$03$$($font_size_state$$,
$font_size_value$$,$font_size_value$$),$app$render_wasm$text_editor$text_editor_get_style_property$cljs$0core$0IFn$0_invoke$0arity$03$$($font_weight_state$$,$font_weight_value$$,$font_weight_value$$),null,$app$render_wasm$text_editor$text_editor_translate_text_direction$$($app$render_wasm$text_editor$text_editor_get_style_property$cljs$0core$0IFn$0_invoke$0arity$03$$($result$jscomp$246_text_direction_state$$,$text_direction_value$$,$text_direction_value$$)),$app$render_wasm$text_editor$text_editor_get_style_property$cljs$0core$0IFn$0_invoke$0arity$03$$($font_variant_id_state$$,
$font_variant_id_computed$$,$font_variant_id_computed$$),$app$render_wasm$text_editor$text_editor_translate_text_decoration$$($app$render_wasm$text_editor$text_editor_get_style_property$cljs$0core$0IFn$0_invoke$0arity$03$$($text_decoration_state$$,$text_decoration_value$$,$text_decoration_value$$)),$num_fills_selected_colors$$,$app$render_wasm$text_editor$text_editor_get_style_property$cljs$0core$0IFn$0_invoke$0arity$03$$($letter_spacing_state$$,$letter_spacing_value_u32_offset$$,$letter_spacing_value_u32_offset$$),
$fills__$1$jscomp$5_multiple_fills$$,$app$render_wasm$text_editor$text_editor_get_style_property$cljs$0core$0IFn$0_invoke$0arity$03$$($font_family_state$$,$font_family_id_value_font_id$jscomp$25$$,$font_family_id_value_font_id$jscomp$25$$)]);$APP.$app$render_wasm$mem$free$$();return $result$jscomp$246_text_direction_state$$}}return null};
$app$render_wasm$text_editor$text_editor_has_selection_QMARK_$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $code__52999__auto__$jscomp$inline_5924_code_num__52998__auto__$jscomp$inline_5923_fn_53534$jscomp$inline_5920_read_code_fn__52997__auto__$jscomp$inline_5922$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_has_selection;try{var $JSCompiler_inline_result$jscomp$1029_JSCompiler_temp$jscomp$1028_cause53535$jscomp$inline_5921$$=$code__52999__auto__$jscomp$inline_5924_code_num__52998__auto__$jscomp$inline_5923_fn_53534$jscomp$inline_5920_read_code_fn__52997__auto__$jscomp$inline_5922$$()}catch($e53536$jscomp$inline_5926$$){$JSCompiler_inline_result$jscomp$1029_JSCompiler_temp$jscomp$1028_cause53535$jscomp$inline_5921$$=
$e53536$jscomp$inline_5926$$;$code__52999__auto__$jscomp$inline_5924_code_num__52998__auto__$jscomp$inline_5923_fn_53534$jscomp$inline_5920_read_code_fn__52997__auto__$jscomp$inline_5922$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$inline_5924_code_num__52998__auto__$jscomp$inline_5923_fn_53534$jscomp$inline_5920_read_code_fn__52997__auto__$jscomp$inline_5922$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_5924_code_num__52998__auto__$jscomp$inline_5923_fn_53534$jscomp$inline_5920_read_code_fn__52997__auto__$jscomp$inline_5922$$)?
$code__52999__auto__$jscomp$inline_5924_code_num__52998__auto__$jscomp$inline_5923_fn_53534$jscomp$inline_5920_read_code_fn__52997__auto__$jscomp$inline_5922$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$inline_5924_code_num__52998__auto__$jscomp$inline_5923_fn_53534$jscomp$inline_5920_read_code_fn__52997__auto__$jscomp$inline_5922$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$inline_5924_code_num__52998__auto__$jscomp$inline_5923_fn_53534$jscomp$inline_5920_read_code_fn__52997__auto__$jscomp$inline_5922$$():
null;$code__52999__auto__$jscomp$inline_5924_code_num__52998__auto__$jscomp$inline_5923_fn_53534$jscomp$inline_5920_read_code_fn__52997__auto__$jscomp$inline_5922$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$inline_5924_code_num__52998__auto__$jscomp$inline_5923_fn_53534$jscomp$inline_5920_read_code_fn__52997__auto__$jscomp$inline_5922$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$inline_5925$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_5924_code_num__52998__auto__$jscomp$inline_5923_fn_53534$jscomp$inline_5920_read_code_fn__52997__auto__$jscomp$inline_5922$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$inline_5925$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_has_selection",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53000__auto__$jscomp$inline_5925$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_5924_code_num__52998__auto__$jscomp$inline_5923_fn_53534$jscomp$inline_5920_read_code_fn__52997__auto__$jscomp$inline_5922$$],null),$JSCompiler_inline_result$jscomp$1029_JSCompiler_temp$jscomp$1028_cause53535$jscomp$inline_5921$$);}$JSCompiler_inline_result$jscomp$1029_JSCompiler_temp$jscomp$1028_cause53535$jscomp$inline_5921$$=$JSCompiler_inline_result$jscomp$1029_JSCompiler_temp$jscomp$1028_cause53535$jscomp$inline_5921$$!==
0}else $JSCompiler_inline_result$jscomp$1029_JSCompiler_temp$jscomp$1028_cause53535$jscomp$inline_5921$$=null;return $JSCompiler_inline_result$jscomp$1029_JSCompiler_temp$jscomp$1028_cause53535$jscomp$inline_5921$$};
$APP.$app$render_wasm$text_editor$text_editor_get_active_shape_id$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$)try{var $byte_offset_cause53568_53737$$=$APP.$app$render_wasm$mem$alloc$$(16),$u32_offset$jscomp$1$$=$byte_offset_cause53568_53737$$>>2,$heap$jscomp$9$$=$APP.$app$render_wasm$mem$get_heap_u32$$(),$fn_53567_53736$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_get_active_shape_id;try{$fn_53567_53736$$($byte_offset_cause53568_53737$$)}catch($e53572$$){$byte_offset_cause53568_53737$$=
$e53572$$;var $read_code_fn__52997__auto___53738$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code_num__52998__auto___53739$$=$APP.$cljs$core$truth_$$($read_code_fn__52997__auto___53738$$)?$read_code_fn__52997__auto___53738$$.$cljs$core$IFn$_invoke$arity$0$?$read_code_fn__52997__auto___53738$$.$cljs$core$IFn$_invoke$arity$0$():$read_code_fn__52997__auto___53738$$():null,$code__52999__auto___53740$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code_num__52998__auto___53739$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___53741$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___53740$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___53741$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_get_active_shape_id",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___53741$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto___53740$$],null),$byte_offset_cause53568_53737$$);}var $a$jscomp$379$$=$heap$jscomp$9$$[$u32_offset$jscomp$1$$],$b$jscomp$310$$=$heap$jscomp$9$$[$u32_offset$jscomp$1$$+1],$c$jscomp$297$$=$heap$jscomp$9$$[$u32_offset$jscomp$1$$+2],$d$jscomp$235$$=$heap$jscomp$9$$[$u32_offset$jscomp$1$$+3],$result$jscomp$247$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$379$$,0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$310$$,
0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$297$$,0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($d$jscomp$235$$,0)?$app$common$uuid$uuid$$($app$common$uuid_impl$v8$$.$fromUnsignedParts$($a$jscomp$379$$,$b$jscomp$310$$,$c$jscomp$297$$,$d$jscomp$235$$)):null;$APP.$app$render_wasm$mem$free$$();return $result$jscomp$247$$}catch($e53566$$){if($e53566$$ instanceof Error)return console.error("[text-editor-get-active-shape-id] Error:",$e53566$$),null;throw $e53566$$;
}else return null};
$APP.$app$render_wasm$text_editor$text_editor_get_selection$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $byte_offset$jscomp$1_cause53583$jscomp$inline_5929_result$jscomp$248$$=$APP.$app$render_wasm$mem$alloc$$(16),$code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$=$byte_offset$jscomp$1_cause53583$jscomp$inline_5929_result$jscomp$248$$>>2,$heap$jscomp$10_hint__53000__auto__$jscomp$inline_5933$$=$APP.$app$render_wasm$mem$get_heap_u32$$();
var $fn_53582$jscomp$inline_5928$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_get_selection;try{var $has_selection_QMARK_$$=$fn_53582$jscomp$inline_5928$$($byte_offset$jscomp$1_cause53583$jscomp$inline_5929_result$jscomp$248$$)}catch($e53584$jscomp$inline_5934$$){throw $byte_offset$jscomp$1_cause53583$jscomp$inline_5929_result$jscomp$248$$=$e53584$jscomp$inline_5934$$,$code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$)?$code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$():null,$code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$,$APP.$cljs$cst$2971$wasm_critical$$),$heap$jscomp$10_hint__53000__auto__$jscomp$inline_5933$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($heap$jscomp$10_hint__53000__auto__$jscomp$inline_5933$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_get_selection",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$heap$jscomp$10_hint__53000__auto__$jscomp$inline_5933$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$],null),$byte_offset$jscomp$1_cause53583$jscomp$inline_5929_result$jscomp$248$$);
}if($APP.$cljs$core$truth_$$($has_selection_QMARK_$$))return $byte_offset$jscomp$1_cause53583$jscomp$inline_5929_result$jscomp$248$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$3044$anchor_para$$,$heap$jscomp$10_hint__53000__auto__$jscomp$inline_5933$$[$code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$],$cljs$cst$3045$anchor_offset$$,$heap$jscomp$10_hint__53000__auto__$jscomp$inline_5933$$[$code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$+
1],$cljs$cst$3046$focus_para$$,$heap$jscomp$10_hint__53000__auto__$jscomp$inline_5933$$[$code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$+2],$cljs$cst$3047$focus_offset$$,$heap$jscomp$10_hint__53000__auto__$jscomp$inline_5933$$[$code__52999__auto__$jscomp$inline_5932_code_num__52998__auto__$jscomp$inline_5931_read_code_fn__52997__auto__$jscomp$inline_5930_u32_offset$jscomp$2$$+3]],null),$APP.$app$render_wasm$mem$free$$(),
$byte_offset$jscomp$1_cause53583$jscomp$inline_5929_result$jscomp$248$$;$APP.$app$render_wasm$mem$free$$()}return null};$APP.$app$render_wasm$text_editor$get_cached_content$$=function($shape_id$jscomp$42$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$text_editor$shape_text_contents$$),$shape_id$jscomp$42$$)};
$app$render_wasm$text_editor$normalize_selection$$=function($anchor_para_p__53611$$){var $focus_offset_map__53612__$1$$=$APP.$cljs$core$__destructure_map$$($anchor_para_p__53611$$);$anchor_para_p__53611$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($focus_offset_map__53612__$1$$,$cljs$cst$3044$anchor_para$$);var $anchor_offset$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($focus_offset_map__53612__$1$$,$cljs$cst$3045$anchor_offset$$),$focus_para$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($focus_offset_map__53612__$1$$,
$cljs$cst$3046$focus_para$$);$focus_offset_map__53612__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($focus_offset_map__53612__$1$$,$cljs$cst$3047$focus_offset$$);return $anchor_para_p__53611$$<$focus_para$$||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($anchor_para_p__53611$$,$focus_para$$)&&$anchor_offset$$<=$focus_offset_map__53612__$1$$?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$3048$start_para$$,$anchor_para_p__53611$$,$cljs$cst$3049$start_offset$$,$anchor_offset$$,
$cljs$cst$3050$end_para$$,$focus_para$$,$cljs$cst$3051$end_offset$$,$focus_offset_map__53612__$1$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$3048$start_para$$,$focus_para$$,$cljs$cst$3049$start_offset$$,$focus_offset_map__53612__$1$$,$cljs$cst$3050$end_para$$,$anchor_para_p__53611$$,$cljs$cst$3051$end_offset$$,$anchor_offset$$],null)};
$app$render_wasm$text_editor$apply_attrs_to_paragraph$$=function($para$$,$sel_start$$,$sel_end$$,$attrs$jscomp$51$$){var $spans$jscomp$2$$=$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($para$$),$result$jscomp$249$$=function(){for(var $G__53744_G__53747_spans__$1$$=$spans$jscomp$2$$,$pos$jscomp$96$$=0,$G__53746_G__53749_acc$jscomp$114$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){if($APP.$cljs$core$empty_QMARK_$$($G__53744_G__53747_spans__$1$$))return $G__53746_G__53749_acc$jscomp$114$$;
var $G__53748_span$jscomp$3$$=$APP.$cljs$core$first$$($G__53744_G__53747_spans__$1$$),$after$jscomp$3_text$jscomp$35$$=$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($G__53748_span$jscomp$3$$),$G__53745_before$jscomp$4_span_len$$=$APP.$cljs$core$count$$($after$jscomp$3_text$jscomp$35$$),$span_end$$=$pos$jscomp$96$$+$G__53745_before$jscomp$4_span_len$$,$ol_start_selected$jscomp$16$$=function(){var $x__5110__auto__$jscomp$56$$=$pos$jscomp$96$$;return $x__5110__auto__$jscomp$56$$>$sel_start$$?
$x__5110__auto__$jscomp$56$$:$sel_start$$}(),$ol_end$$=function(){var $x__5113__auto__$jscomp$39$$=$span_end$$;return $x__5113__auto__$jscomp$39$$<$sel_end$$?$x__5113__auto__$jscomp$39$$:$sel_end$$}();$ol_start_selected$jscomp$16$$<$ol_end$$?($G__53745_before$jscomp$4_span_len$$=$ol_start_selected$jscomp$16$$>$pos$jscomp$96$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__53748_span$jscomp$3$$,$APP.$cljs$cst$1588$text$$,$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($after$jscomp$3_text$jscomp$35$$,
0,$ol_start_selected$jscomp$16$$-$pos$jscomp$96$$)):null,$ol_start_selected$jscomp$16$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__53748_span$jscomp$3$$,$attrs$jscomp$51$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1588$text$$,$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($after$jscomp$3_text$jscomp$35$$,$ol_start_selected$jscomp$16$$-$pos$jscomp$96$$,$ol_end$$-$pos$jscomp$96$$)],null)])),
$after$jscomp$3_text$jscomp$35$$=$ol_end$$<$span_end$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__53748_span$jscomp$3$$,$APP.$cljs$cst$1588$text$$,$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($after$jscomp$3_text$jscomp$35$$,$ol_end$$-$pos$jscomp$96$$)):null,$G__53744_G__53747_spans__$1$$=$APP.$cljs$core$rest$$($G__53744_G__53747_spans__$1$$),$G__53748_span$jscomp$3$$=$span_end$$,$G__53746_G__53749_acc$jscomp$114$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($G__53746_G__53749_acc$jscomp$114$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$identity$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__53745_before$jscomp$4_span_len$$,$ol_start_selected$jscomp$16$$,$after$jscomp$3_text$jscomp$35$$],null))),$pos$jscomp$96$$=$G__53748_span$jscomp$3$$):($G__53744_G__53747_spans__$1$$=$APP.$cljs$core$rest$$($G__53744_G__53747_spans__$1$$),$G__53745_before$jscomp$4_span_len$$=$span_end$$,$G__53746_G__53749_acc$jscomp$114$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__53746_G__53749_acc$jscomp$114$$,$G__53748_span$jscomp$3$$),$pos$jscomp$96$$=$G__53745_before$jscomp$4_span_len$$)}}();return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($para$$,$APP.$cljs$cst$342$children$$,$result$jscomp$249$$)};
$app$render_wasm$text_editor$para_char_count$$=function($para$jscomp$1$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($span$jscomp$4$$){return $APP.$cljs$core$count$$($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($span$jscomp$4$$))},$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($para$jscomp$1$$)))};
$app$render_wasm$text_editor$apply_styles_to_selection$$=function($attrs$jscomp$52$$){var $use_shape_fn$$=$APP.$app$render_wasm$api$use_shape$$,$set_shape_text_content_fn$$=$APP.$app$render_wasm$api$set_shape_text_content$$;if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $shape_id$jscomp$45$$=$APP.$app$render_wasm$text_editor$text_editor_get_active_shape_id$$(),$map__53614_map__53614__$1_paragraph_set$jscomp$1_selection$jscomp$6$$=$APP.$app$render_wasm$text_editor$text_editor_get_selection$$();
if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($shape_id$jscomp$45$$)?$map__53614_map__53614__$1_paragraph_set$jscomp$1_selection$jscomp$6$$:$shape_id$jscomp$45$$)){var $content$jscomp$134_new_content$jscomp$2$$=$APP.$app$render_wasm$text_editor$get_cached_content$$($shape_id$jscomp$45$$);if($APP.$cljs$core$truth_$$($content$jscomp$134_new_content$jscomp$2$$)){$map__53614_map__53614__$1_paragraph_set$jscomp$1_selection$jscomp$6$$=$app$render_wasm$text_editor$normalize_selection$$($map__53614_map__53614__$1_paragraph_set$jscomp$1_selection$jscomp$6$$);
$map__53614_map__53614__$1_paragraph_set$jscomp$1_selection$jscomp$6$$=$APP.$cljs$core$__destructure_map$$($map__53614_map__53614__$1_paragraph_set$jscomp$1_selection$jscomp$6$$);var $start_para$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53614_map__53614__$1_paragraph_set$jscomp$1_selection$jscomp$6$$,$cljs$cst$3048$start_para$$),$start_offset$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53614_map__53614__$1_paragraph_set$jscomp$1_selection$jscomp$6$$,$cljs$cst$3049$start_offset$$),
$end_para$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53614_map__53614__$1_paragraph_set$jscomp$1_selection$jscomp$6$$,$cljs$cst$3050$end_para$$),$end_offset$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53614_map__53614__$1_paragraph_set$jscomp$1_selection$jscomp$6$$,$cljs$cst$3051$end_offset$$),$collapsed_QMARK__new_paragraphs$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($start_para$$,$end_para$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($start_offset$$,
$end_offset$$);$map__53614_map__53614__$1_paragraph_set$jscomp$1_selection$jscomp$6$$=$APP.$cljs$core$first$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$134_new_content$jscomp$2$$));var $paragraphs$jscomp$2$$=$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($map__53614_map__53614__$1_paragraph_set$jscomp$1_selection$jscomp$6$$);$collapsed_QMARK__new_paragraphs$$=$collapsed_QMARK__new_paragraphs$$?null:$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$3$(function($idx$jscomp$83$$,
$para$jscomp$2$$){return $idx$jscomp$83$$<$start_para$$||$idx$jscomp$83$$>$end_para$$?$para$jscomp$2$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($start_para$$,$end_para$$)?$app$render_wasm$text_editor$apply_attrs_to_paragraph$$($para$jscomp$2$$,$start_offset$$,$end_offset$$,$attrs$jscomp$52$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$83$$,$start_para$$)?$app$render_wasm$text_editor$apply_attrs_to_paragraph$$($para$jscomp$2$$,$start_offset$$,$app$render_wasm$text_editor$para_char_count$$($para$jscomp$2$$),
$attrs$jscomp$52$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$83$$,$end_para$$)?$app$render_wasm$text_editor$apply_attrs_to_paragraph$$($para$jscomp$2$$,0,$end_offset$$,$attrs$jscomp$52$$):$app$render_wasm$text_editor$apply_attrs_to_paragraph$$($para$jscomp$2$$,0,$app$render_wasm$text_editor$para_char_count$$($para$jscomp$2$$),$attrs$jscomp$52$$)},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$count$$($paragraphs$jscomp$2$$)),$paragraphs$jscomp$2$$);
$content$jscomp$134_new_content$jscomp$2$$=$APP.$cljs$core$truth_$$($collapsed_QMARK__new_paragraphs$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($content$jscomp$134_new_content$jscomp$2$$,$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__53614_map__53614__$1_paragraph_set$jscomp$1_selection$jscomp$6$$,$APP.$cljs$cst$342$children$$,$collapsed_QMARK__new_paragraphs$$)],
null)):null;if($APP.$cljs$core$truth_$$($content$jscomp$134_new_content$jscomp$2$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$render_wasm$text_editor$shape_text_contents$$,$APP.$cljs$core$assoc$$,$shape_id$jscomp$45$$,$content$jscomp$134_new_content$jscomp$2$$),$use_shape_fn$$.$cljs$core$IFn$_invoke$arity$1$?$use_shape_fn$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$45$$):$use_shape_fn$$($shape_id$jscomp$45$$),$set_shape_text_content_fn$$.$cljs$core$IFn$_invoke$arity$2$?
$set_shape_text_content_fn$$.$cljs$core$IFn$_invoke$arity$2$($shape_id$jscomp$45$$,$content$jscomp$134_new_content$jscomp$2$$):$set_shape_text_content_fn$$($shape_id$jscomp$45$$,$content$jscomp$134_new_content$jscomp$2$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2543$shape_id$$,$shape_id$jscomp$45$$,$APP.$cljs$cst$1637$content$$,$content$jscomp$134_new_content$jscomp$2$$],null)}}}return null};
$app$util$debug$handle_change$$=function(){$app$main$store$_STAR_debug_events_STAR_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$util$debug$state$$),$APP.$cljs$cst$2318$events$$);return $app$main$store$_STAR_debug_events_time_STAR_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$util$debug$state$$),$cljs$cst$3062$events_times$$)};
$APP.$app$util$debug$enabled_QMARK_$$=function($option$jscomp$2$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$util$debug$state$$),$option$jscomp$2$$)};$app$util$text$content$styles$encode$$=function($value$jscomp$506$$){return $APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$506$$,null)};
$app$util$text$content$styles$decode$$=function($value$jscomp$507$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$507$$,"")?null:$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$507$$)};
$APP.$app$util$text$content$styles$normalize_style_value$$=function($JSCompiler_inline_result$jscomp$287_JSCompiler_temp$jscomp$285_JSCompiler_temp$jscomp$286_k$jscomp$623_s$jscomp$inline_5939$$,$v$jscomp$566$$){$JSCompiler_inline_result$jscomp$287_JSCompiler_temp$jscomp$285_JSCompiler_temp$jscomp$286_k$jscomp$623_s$jscomp$inline_5939$$ instanceof $APP.$cljs$core$Keyword$$&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$287_JSCompiler_temp$jscomp$285_JSCompiler_temp$jscomp$286_k$jscomp$623_s$jscomp$inline_5939$$,
$APP.$cljs$cst$1760$font_size$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$287_JSCompiler_temp$jscomp$285_JSCompiler_temp$jscomp$286_k$jscomp$623_s$jscomp$inline_5939$$,$APP.$cljs$cst$1766$letter_spacing$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$566$$,-2),"px")?$JSCompiler_inline_result$jscomp$287_JSCompiler_temp$jscomp$285_JSCompiler_temp$jscomp$286_k$jscomp$623_s$jscomp$inline_5939$$=
[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$566$$),"px"].join(""):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$287_JSCompiler_temp$jscomp$285_JSCompiler_temp$jscomp$286_k$jscomp$623_s$jscomp$inline_5939$$,$APP.$cljs$cst$1758$font_family$$)&&$APP.$cljs$core$seq$$($v$jscomp$566$$)?($JSCompiler_inline_result$jscomp$287_JSCompiler_temp$jscomp$285_JSCompiler_temp$jscomp$286_k$jscomp$623_s$jscomp$inline_5939$$=$APP.$cljs$core$first$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$566$$,
",")),$JSCompiler_inline_result$jscomp$287_JSCompiler_temp$jscomp$285_JSCompiler_temp$jscomp$286_k$jscomp$623_s$jscomp$inline_5939$$=$cuerdas$core$unsurround$$($JSCompiler_inline_result$jscomp$287_JSCompiler_temp$jscomp$285_JSCompiler_temp$jscomp$286_k$jscomp$623_s$jscomp$inline_5939$$),$JSCompiler_inline_result$jscomp$287_JSCompiler_temp$jscomp$285_JSCompiler_temp$jscomp$286_k$jscomp$623_s$jscomp$inline_5939$$=""+($cuerdas$core$quote$cljs$0core$0IFn$0_invoke$0arity$01$$($JSCompiler_inline_result$jscomp$287_JSCompiler_temp$jscomp$285_JSCompiler_temp$jscomp$286_k$jscomp$623_s$jscomp$inline_5939$$)??
"")+", var(--fallback-families)"):$JSCompiler_inline_result$jscomp$287_JSCompiler_temp$jscomp$285_JSCompiler_temp$jscomp$286_k$jscomp$623_s$jscomp$inline_5939$$=$v$jscomp$566$$;return $JSCompiler_inline_result$jscomp$287_JSCompiler_temp$jscomp$285_JSCompiler_temp$jscomp$286_k$jscomp$623_s$jscomp$inline_5939$$};
$app$util$text$content$styles$normalize_attr_value$$=function($JSCompiler_temp$jscomp$288_JSCompiler_temp$jscomp$289_JSCompiler_temp$jscomp$290_k$jscomp$624_s$jscomp$inline_5941$$,$v$jscomp$567$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$567$$,"mixed")?$JSCompiler_temp$jscomp$288_JSCompiler_temp$jscomp$289_JSCompiler_temp$jscomp$290_k$jscomp$624_s$jscomp$inline_5941$$=$APP.$cljs$cst$1616$multiple$$:($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$288_JSCompiler_temp$jscomp$289_JSCompiler_temp$jscomp$290_k$jscomp$624_s$jscomp$inline_5941$$,
$APP.$cljs$cst$1760$font_size$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$288_JSCompiler_temp$jscomp$289_JSCompiler_temp$jscomp$290_k$jscomp$624_s$jscomp$inline_5941$$,$APP.$cljs$cst$1766$letter_spacing$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$567$$,-2),"px")?$JSCompiler_temp$jscomp$288_JSCompiler_temp$jscomp$289_JSCompiler_temp$jscomp$290_k$jscomp$624_s$jscomp$inline_5941$$=
$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$567$$,0,-2):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$288_JSCompiler_temp$jscomp$289_JSCompiler_temp$jscomp$290_k$jscomp$624_s$jscomp$inline_5941$$,$APP.$cljs$cst$1758$font_family$$)?($JSCompiler_temp$jscomp$288_JSCompiler_temp$jscomp$289_JSCompiler_temp$jscomp$290_k$jscomp$624_s$jscomp$inline_5941$$=$APP.$cuerdas$core$replace$$($v$jscomp$567$$,", var(--fallback-families)",""),$JSCompiler_temp$jscomp$288_JSCompiler_temp$jscomp$289_JSCompiler_temp$jscomp$290_k$jscomp$624_s$jscomp$inline_5941$$=
$cuerdas$core$unsurround$$($JSCompiler_temp$jscomp$288_JSCompiler_temp$jscomp$289_JSCompiler_temp$jscomp$290_k$jscomp$624_s$jscomp$inline_5941$$)):$JSCompiler_temp$jscomp$288_JSCompiler_temp$jscomp$289_JSCompiler_temp$jscomp$290_k$jscomp$624_s$jscomp$inline_5941$$=$v$jscomp$567$$;return $JSCompiler_temp$jscomp$288_JSCompiler_temp$jscomp$289_JSCompiler_temp$jscomp$290_k$jscomp$624_s$jscomp$inline_5941$$};
$APP.$app$util$text$content$styles$get_style_name_as_css_variable$$=function($key$jscomp$352$$){return"--"+($APP.$cljs$core$name$$($key$jscomp$352$$)??"")};$APP.$app$util$text$content$styles$get_style_name$$=function($key$jscomp$353$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$353$$,$APP.$cljs$cst$1764$text_direction$$)?"direction":$APP.$cljs$core$name$$($key$jscomp$353$$)};
$app$util$text$content$styles$attr__GT_style$$=function($JSCompiler_temp_const$jscomp$1030_p__53369$$){var $JSCompiler_inline_result$jscomp$10817_key$jscomp$359$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1030_p__53369$$,0,null),$value$jscomp$510$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1030_p__53369$$,1,null);$JSCompiler_temp_const$jscomp$1030_p__53369$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;if($APP.$cljs$core$contains_QMARK_$$($APP.$app$util$text$content$styles$mapping$$,
$JSCompiler_inline_result$jscomp$10817_key$jscomp$359$$)){var $JSCompiler_inline_result$jscomp$1031_JSCompiler_temp_const$jscomp$10816_name$jscomp$inline_5944$$=$APP.$app$util$text$content$styles$get_style_name_as_css_variable$$($JSCompiler_inline_result$jscomp$10817_key$jscomp$359$$);$JSCompiler_inline_result$jscomp$1031_JSCompiler_temp_const$jscomp$10816_name$jscomp$inline_5944$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1031_JSCompiler_temp_const$jscomp$10816_name$jscomp$inline_5944$$)}else $JSCompiler_inline_result$jscomp$1031_JSCompiler_temp_const$jscomp$10816_name$jscomp$inline_5944$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10817_key$jscomp$359$$,$APP.$cljs$cst$1764$text_direction$$)?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$("direction"):$JSCompiler_inline_result$jscomp$10817_key$jscomp$359$$;if($APP.$cljs$core$contains_QMARK_$$($APP.$app$util$text$content$styles$mapping$$,$JSCompiler_inline_result$jscomp$10817_key$jscomp$359$$)){var $encoder$jscomp$inline_12212_vec__53364$jscomp$inline_12211$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$text$content$styles$mapping$$,
$JSCompiler_inline_result$jscomp$10817_key$jscomp$359$$);$encoder$jscomp$inline_12212_vec__53364$jscomp$inline_12211$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($encoder$jscomp$inline_12212_vec__53364$jscomp$inline_12211$$,0,null);$JSCompiler_inline_result$jscomp$10817_key$jscomp$359$$=$APP.$cljs$core$truth_$$(!1)?$APP.$app$util$text$content$styles$normalize_style_value$$($JSCompiler_inline_result$jscomp$10817_key$jscomp$359$$,$encoder$jscomp$inline_12212_vec__53364$jscomp$inline_12211$$.$cljs$core$IFn$_invoke$arity$1$?
$encoder$jscomp$inline_12212_vec__53364$jscomp$inline_12211$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$510$$):$encoder$jscomp$inline_12212_vec__53364$jscomp$inline_12211$$($value$jscomp$510$$)):$encoder$jscomp$inline_12212_vec__53364$jscomp$inline_12211$$.$cljs$core$IFn$_invoke$arity$1$?$encoder$jscomp$inline_12212_vec__53364$jscomp$inline_12211$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$510$$):$encoder$jscomp$inline_12212_vec__53364$jscomp$inline_12211$$($value$jscomp$510$$)}else $JSCompiler_inline_result$jscomp$10817_key$jscomp$359$$=
$APP.$cljs$core$truth_$$(!1)?$APP.$app$util$text$content$styles$normalize_style_value$$($JSCompiler_inline_result$jscomp$10817_key$jscomp$359$$,$value$jscomp$510$$):$value$jscomp$510$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$1030_p__53369$$,[$JSCompiler_inline_result$jscomp$1031_JSCompiler_temp_const$jscomp$10816_name$jscomp$inline_5944$$,$JSCompiler_inline_result$jscomp$10817_key$jscomp$359$$],null)};
$app$util$text$content$styles$attrs__GT_styles$$=function($mapped_styles_styles$jscomp$2$$){$mapped_styles_styles$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p__53380$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__53380$$,0,null);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__53380$$,
1,null)!=null}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$util$text$content$styles$attr__GT_style$$)),$mapped_styles_styles$jscomp$2$$);return $APP.$cljs$core$clj__GT_js$$($mapped_styles_styles$jscomp$2$$)};
$APP.$app$util$text$content$styles$get_styles_from_style_declaration$$=function($var_args$jscomp$1131$$){for(var $args__5755__auto__$jscomp$203$$=[],$len__5749__auto___53557$$=arguments.length,$i__5750__auto___53558$$=0;;)if($i__5750__auto___53558$$<$len__5749__auto___53557$$)$args__5755__auto__$jscomp$203$$.push(arguments[$i__5750__auto___53558$$]),$i__5750__auto___53558$$+=1;else break;return $app$util$text$content$styles$get_styles_from_style_declaration$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
1<$args__5755__auto__$jscomp$203$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$203$$.slice(1),0,null):null)};
$app$util$text$content$styles$get_styles_from_style_declaration$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($style_declaration$$,$map__53449__$1_p__53448$$){$map__53449__$1_p__53448$$=$APP.$cljs$core$__destructure_map$$($map__53449__$1_p__53448$$);var $removed_mixed$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__53449__$1_p__53448$$,$cljs$cst$3078$removed_mixed$$,!1);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$116$$,$k$jscomp$626$$){if($APP.$cljs$core$contains_QMARK_$$($APP.$app$util$text$content$styles$mapping$$,
$k$jscomp$626$$)){var $style_name$jscomp$3_style_value$jscomp$1$$=$APP.$app$util$text$content$styles$get_style_name_as_css_variable$$($k$jscomp$626$$),$style_decode_vec__53469$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$text$content$styles$mapping$$,$k$jscomp$626$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($style_decode_vec__53469$$,0,null);$style_decode_vec__53469$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($style_decode_vec__53469$$,1,null);
$style_name$jscomp$3_style_value$jscomp$1$$=$style_declaration$$.getPropertyValue($style_name$jscomp$3_style_value$jscomp$1$$);return $APP.$cljs$core$not$$($removed_mixed$$)||!$APP.$cljs$core$contains_QMARK_$$($app$util$text$content$styles$mixed_values$$,$style_name$jscomp$3_style_value$jscomp$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$116$$,$k$jscomp$626$$,$style_decode_vec__53469$$.$cljs$core$IFn$_invoke$arity$1$?$style_decode_vec__53469$$.$cljs$core$IFn$_invoke$arity$1$($style_name$jscomp$3_style_value$jscomp$1$$):
$style_decode_vec__53469$$($style_name$jscomp$3_style_value$jscomp$1$$)):$acc$jscomp$116$$}$style_name$jscomp$3_style_value$jscomp$1$$=$APP.$app$util$text$content$styles$get_style_name$$($k$jscomp$626$$);$style_name$jscomp$3_style_value$jscomp$1$$=$app$util$text$content$styles$normalize_attr_value$$($k$jscomp$626$$,$style_declaration$$.getPropertyValue($style_name$jscomp$3_style_value$jscomp$1$$));return $APP.$cljs$core$not$$($removed_mixed$$)||!$APP.$cljs$core$contains_QMARK_$$($app$util$text$content$styles$mixed_values$$,
$style_name$jscomp$3_style_value$jscomp$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$116$$,$k$jscomp$626$$,$style_name$jscomp$3_style_value$jscomp$1$$):$acc$jscomp$116$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$app$common$types$text$text_style_attrs$$)};
$app$util$text$content$from_dom$is_element$$=function($node$jscomp$293$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$293$$.nodeType,Node.ELEMENT_NODE)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$293$$.nodeName,"BR")};
$app$util$text$content$from_dom$get_attrs_from_styles$$=function($element$jscomp$59$$,$attrs$jscomp$53$$,$defaults$jscomp$1$$){function $value_empty_QMARK_$$($v$jscomp$570$$){return $v$jscomp$570$$==null||typeof $v$jscomp$570$$==="string"&&$APP.$cljs$core$empty_QMARK_$$($v$jscomp$570$$)||$APP.$cljs$core$coll_QMARK_$$($v$jscomp$570$$)&&$APP.$cljs$core$empty_QMARK_$$($v$jscomp$570$$)}return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$117$$,$key$jscomp$363$$){var $style$jscomp$34$$=
$element$jscomp$59$$.style,$value$jscomp$514$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$util$text$content$styles$mapping$$,$key$jscomp$363$$)?function(){var $G__53529_style_name$jscomp$4$$=$APP.$app$util$text$content$styles$get_style_name_as_css_variable$$($key$jscomp$363$$),$style_decode$jscomp$1_vec__53523$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$text$content$styles$mapping$$,$key$jscomp$363$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($style_decode$jscomp$1_vec__53523$$,
0,null);$style_decode$jscomp$1_vec__53523$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($style_decode$jscomp$1_vec__53523$$,1,null);$G__53529_style_name$jscomp$4$$=$style$jscomp$34$$.getPropertyValue($G__53529_style_name$jscomp$4$$);return $style_decode$jscomp$1_vec__53523$$.$cljs$core$IFn$_invoke$arity$1$?$style_decode$jscomp$1_vec__53523$$.$cljs$core$IFn$_invoke$arity$1$($G__53529_style_name$jscomp$4$$):$style_decode$jscomp$1_vec__53523$$($G__53529_style_name$jscomp$4$$)}():function(){var $style_name$jscomp$5$$=
$APP.$app$util$text$content$styles$get_style_name$$($key$jscomp$363$$);return $app$util$text$content$styles$normalize_attr_value$$($key$jscomp$363$$,$style$jscomp$34$$.getPropertyValue($style_name$jscomp$5$$))}();return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$117$$,$key$jscomp$363$$,$value_empty_QMARK_$$($value$jscomp$514$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defaults$jscomp$1$$,$key$jscomp$363$$):$value$jscomp$514$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$truth_$$($attrs$jscomp$53$$)?$attrs$jscomp$53$$:$APP.$cljs$core$PersistentVector$EMPTY$$)};
$app$util$text$content$from_dom$create_text_span$$=function($element$jscomp$63$$){var $node$jscomp$inline_12214_text$jscomp$36$$=$element$jscomp$63$$.firstChild;if(!$app$util$text$content$from_dom$is_element$$($node$jscomp$inline_12214_text$jscomp$36$$)&&!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$inline_12214_text$jscomp$36$$.nodeType,Node.TEXT_NODE))throw new TypeError("Invalid text span child");$node$jscomp$inline_12214_text$jscomp$36$$=$app$util$text$content$from_dom$is_element$$($element$jscomp$63$$.firstChild)?
"":$element$jscomp$63$$.textContent;return $APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1588$text$$,$node$jscomp$inline_12214_text$jscomp$36$$,$APP.$cljs$cst$302$key$$,$element$jscomp$63$$.id],null),$app$util$text$content$from_dom$get_attrs_from_styles$$($element$jscomp$63$$,$APP.$app$common$types$text$text_node_attrs$$,$APP.$app$common$types$text$get_default_text_attrs$$())]))};
$app$util$text$content$from_dom$create_paragraph$$=function($element$jscomp$64_saved_font_size$jscomp$inline_5950_saved_font_size__$1$jscomp$inline_5951$$){var $JSCompiler_temp_const$jscomp$1033$$=$APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$,$JSCompiler_temp_const$jscomp$1032$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,"paragraph",$APP.$cljs$cst$302$key$$,$element$jscomp$64_saved_font_size$jscomp$inline_5950_saved_font_size__$1$jscomp$inline_5951$$.id,
$APP.$cljs$cst$342$children$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$util$text$content$from_dom$create_text_span$$,$element$jscomp$64_saved_font_size$jscomp$inline_5950_saved_font_size__$1$jscomp$inline_5951$$.children)],null);var $JSCompiler_inline_result$jscomp$1035_styles$jscomp$inline_5949$$=$app$util$text$content$from_dom$get_attrs_from_styles$$($element$jscomp$64_saved_font_size$jscomp$inline_5950_saved_font_size__$1$jscomp$inline_5951$$,$APP.$app$common$data$concat_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$text$paragraph_attrs$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$text_node_attrs$$])),$APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$types$text$default_paragraph_attrs$$,$APP.$app$common$types$text$default_text_attrs$$])));$element$jscomp$64_saved_font_size$jscomp$inline_5950_saved_font_size__$1$jscomp$inline_5951$$=$APP.$app$util$dom$get_data$$($element$jscomp$64_saved_font_size$jscomp$inline_5950_saved_font_size__$1$jscomp$inline_5951$$,
"saved-font-size");$element$jscomp$64_saved_font_size$jscomp$inline_5950_saved_font_size__$1$jscomp$inline_5951$$=typeof $element$jscomp$64_saved_font_size$jscomp$inline_5950_saved_font_size__$1$jscomp$inline_5951$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($element$jscomp$64_saved_font_size$jscomp$inline_5950_saved_font_size__$1$jscomp$inline_5951$$)?null:$element$jscomp$64_saved_font_size$jscomp$inline_5950_saved_font_size__$1$jscomp$inline_5951$$;$JSCompiler_inline_result$jscomp$1035_styles$jscomp$inline_5949$$=
$element$jscomp$64_saved_font_size$jscomp$inline_5950_saved_font_size__$1$jscomp$inline_5951$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1035_styles$jscomp$inline_5949$$,$APP.$cljs$cst$1760$font_size$$,$element$jscomp$64_saved_font_size$jscomp$inline_5950_saved_font_size__$1$jscomp$inline_5951$$):$JSCompiler_inline_result$jscomp$1035_styles$jscomp$inline_5949$$;return $JSCompiler_temp_const$jscomp$1033$$.call($APP.$app$common$data$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_temp_const$jscomp$1032$$,
$JSCompiler_inline_result$jscomp$1035_styles$jscomp$inline_5949$$]))};
$APP.$app$util$text$content$dom__GT_cljs$$=function($JSCompiler_temp$jscomp$1036_root$jscomp$47$$){if($JSCompiler_temp$jscomp$1036_root$jscomp$47$$!=null){var $root_styles$jscomp$inline_5954$$=$app$util$text$content$from_dom$get_attrs_from_styles$$($JSCompiler_temp$jscomp$1036_root$jscomp$47$$,$APP.$app$common$types$text$text_valign_attrs$$,$APP.$app$common$types$text$default_root_attrs$$);$JSCompiler_temp$jscomp$1036_root$jscomp$47$$=$APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,"root",$APP.$cljs$cst$302$key$$,$JSCompiler_temp$jscomp$1036_root$jscomp$47$$.id,$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"paragraph-set",$APP.$cljs$cst$342$children$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$util$text$content$from_dom$create_paragraph$$,$JSCompiler_temp$jscomp$1036_root$jscomp$47$$.children)],
null)],null)],null),$root_styles$jscomp$inline_5954$$]))}else $JSCompiler_temp$jscomp$1036_root$jscomp$47$$=null;return $JSCompiler_temp$jscomp$1036_root$jscomp$47$$};
$app$util$text$content$v2_default_text_content$$=function(){var $default_font_text_defaults$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$default_font$$);$default_font_text_defaults$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$get_default_text_attrs$$(),$default_font_text_defaults$$]));var $default_paragraph_default_span$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1588$text$$,""],null),$APP.$cljs$core$select_keys$$($default_font_text_defaults$$,$APP.$app$common$types$text$text_node_attrs$$)]));$default_paragraph_default_span$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"paragraph",$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$default_paragraph_default_span$$],null)],null),$APP.$cljs$core$select_keys$$($default_font_text_defaults$$,$APP.$app$common$types$text$paragraph_attrs$$)]));return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"root",$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,"paragraph-set",$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$default_paragraph_default_span$$],null)],null)],null)],null),$APP.$app$common$types$text$default_root_attrs$$,$APP.$cljs$core$select_keys$$($default_font_text_defaults$$,$APP.$app$common$types$text$text_valign_attrs$$)]))};
$APP.$app$render_wasm$api$initialized_QMARK_$$=function(){return $APP.$app$render_wasm$wasm$context_initialized_QMARK_$$&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($app$render_wasm$wasm$context_lost_QMARK_$$))};
$app$render_wasm$api$end_context_loss_overlay_BANG_$$=function(){$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$context_loss_overlay_QMARK_$$,!1);return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$page_transition_QMARK_$$))?null:$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$transition_image_url_STAR_$$,null)};
$app$render_wasm$api$listen_tiles_render_complete_once_BANG_$$=function(){$APP.$app$util$globals$document$$.addEventListener("penpot:wasm:tiles-complete",function(){return $app$render_wasm$api$end_context_loss_overlay_BANG_$$.$cljs$core$IFn$_invoke$arity$0$?$app$render_wasm$api$end_context_loss_overlay_BANG_$$.$cljs$core$IFn$_invoke$arity$0$():$app$render_wasm$api$end_context_loss_overlay_BANG_$$()},{once:!0})};
$app$render_wasm$api$start_canvas_snapshot_listener_BANG_$$=function(){function $handler$jscomp$29$$(){return $app$render_wasm$api$schedule_canvas_snapshot_capture_BANG_$$.$cljs$core$IFn$_invoke$arity$0$?$app$render_wasm$api$schedule_canvas_snapshot_capture_BANG_$$.$cljs$core$IFn$_invoke$arity$0$():$app$render_wasm$api$schedule_canvas_snapshot_capture_BANG_$$()}var $temp__5825__auto___54487$$=$APP.$cljs$core$_deref$$($app$render_wasm$api$snapshot_tiles_handler_STAR_$$);$APP.$cljs$core$truth_$$($temp__5825__auto___54487$$)&&
$APP.$app$util$globals$document$$.removeEventListener("penpot:wasm:tiles-complete",$temp__5825__auto___54487$$);$APP.$cljs$core$reset_BANG_$$($app$render_wasm$api$snapshot_tiles_handler_STAR_$$,$handler$jscomp$29$$);$APP.$app$util$globals$document$$.addEventListener("penpot:wasm:tiles-complete",$handler$jscomp$29$$)};
$app$render_wasm$api$yield_to_browser$$=function(){return $promesa$core$create$cljs$0core$0IFn$0_invoke$0arity$01$$(function($resolve$jscomp$26$$){$ch_54498$$.port1.onmessage=function(){return $resolve$jscomp$26$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$26$$.$cljs$core$IFn$_invoke$arity$1$(null):$resolve$jscomp$26$$(null)};return $ch_54498$$.port2.postMessage(null)})};
$app$render_wasm$api$object_svg$$=function($props_53750_shape$jscomp$350$$){$props_53750_shape$jscomp$350$$=$props_53750_shape$jscomp$350$$.shape;var $objects$jscomp$236$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$shape_wrapper$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($props_53750_shape$jscomp$350$$)],function(){return $app$render_wasm$api$shape_wrapper_factory$$.$cljs$core$IFn$_invoke$arity$1$?$app$render_wasm$api$shape_wrapper_factory$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$236$$):
$app$render_wasm$api$shape_wrapper_factory$$($objects$jscomp$236$$)});return(0,$APP.$rumext$v2$jsx$$)("svg",{version:"1.1",xmlns:"http://www.w3.org/2000/svg",xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",children:(0,$APP.$rumext$v2$jsx$$)($shape_wrapper$$,{shape:$props_53750_shape$jscomp$350$$})})};
$app$render_wasm$api$get_static_markup$$=function($shape$jscomp$351$$){return $shadow$js$shim$module$0react_dom$0server$$.renderToStaticMarkup($rumext$v2$element$cljs$0core$0IFn$0_invoke$0arity$02$$($app$render_wasm$api$object_svg$$,{shape:$shape$jscomp$351$$}))};
$app$render_wasm$api$build_reload_payload$$=function(){var $state$jscomp$162_zoom$$=$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$file_id$jscomp$30_objects$jscomp$237$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$162_zoom$$),$focus$jscomp$5_page_id$jscomp$54$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$162_zoom$$),$background$jscomp$3_page$jscomp$34$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$162_zoom$$,
$file_id$jscomp$30_objects$jscomp$237$$,$focus$jscomp$5_page_id$jscomp$54$$);$file_id$jscomp$30_objects$jscomp$237$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$162_zoom$$,$file_id$jscomp$30_objects$jscomp$237$$,$focus$jscomp$5_page_id$jscomp$54$$);$focus$jscomp$5_page_id$jscomp$54$$=$APP.$cljs$cst$2226$workspace_focus_selected$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$162_zoom$$);var $local_vbox$$=$APP.$cljs$cst$1920$workspace_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$162_zoom$$);
$state$jscomp$162_zoom$$=$APP.$cljs$cst$2196$zoom$$.$cljs$core$IFn$_invoke$arity$1$($local_vbox$$);$local_vbox$$=$APP.$cljs$cst$1925$vbox$$.$cljs$core$IFn$_invoke$arity$1$($local_vbox$$);var $canvas$jscomp$7$$=$app$render_wasm$wasm$canvas$$;$background$jscomp$3_page$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($background$jscomp$3_page$jscomp$34$$,$APP.$cljs$cst$2058$background$$,"#E8E9EA");return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$3083$canvas$$,$canvas$jscomp$7$$,
$cljs$cst$3084$base_objects$$,$APP.$app$common$files$focus$focus_objects$$($file_id$jscomp$30_objects$jscomp$237$$,$focus$jscomp$5_page_id$jscomp$54$$),$APP.$cljs$cst$2196$zoom$$,$state$jscomp$162_zoom$$,$APP.$cljs$cst$1925$vbox$$,$local_vbox$$,$APP.$cljs$cst$2058$background$$,$background$jscomp$3_page$jscomp$34$$],null)};
$app$render_wasm$api$render_sync_shape$$=function($buffer$jscomp$67_cause53763_54523_id$jscomp$323$$){if($APP.$app$render_wasm$api$initialized_QMARK_$$()){$buffer$jscomp$67_cause53763_54523_id$jscomp$323$$=$APP.$app$common$uuid$get_u32$$($buffer$jscomp$67_cause53763_54523_id$jscomp$323$$);var $code__52999__auto___54526_code_num__52998__auto___54525_fn_53762_54522_read_code_fn__52997__auto___54524$$=$APP.$app$render_wasm$wasm$internal_module$$._render_sync_shape;try{$code__52999__auto___54526_code_num__52998__auto___54525_fn_53762_54522_read_code_fn__52997__auto___54524$$($buffer$jscomp$67_cause53763_54523_id$jscomp$323$$[0],
$buffer$jscomp$67_cause53763_54523_id$jscomp$323$$[1],$buffer$jscomp$67_cause53763_54523_id$jscomp$323$$[2],$buffer$jscomp$67_cause53763_54523_id$jscomp$323$$[3])}catch($e53764$$){$buffer$jscomp$67_cause53763_54523_id$jscomp$323$$=$e53764$$;$code__52999__auto___54526_code_num__52998__auto___54525_fn_53762_54522_read_code_fn__52997__auto___54524$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___54526_code_num__52998__auto___54525_fn_53762_54522_read_code_fn__52997__auto___54524$$=
$APP.$cljs$core$truth_$$($code__52999__auto___54526_code_num__52998__auto___54525_fn_53762_54522_read_code_fn__52997__auto___54524$$)?$code__52999__auto___54526_code_num__52998__auto___54525_fn_53762_54522_read_code_fn__52997__auto___54524$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___54526_code_num__52998__auto___54525_fn_53762_54522_read_code_fn__52997__auto___54524$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___54526_code_num__52998__auto___54525_fn_53762_54522_read_code_fn__52997__auto___54524$$():
null;$code__52999__auto___54526_code_num__52998__auto___54525_fn_53762_54522_read_code_fn__52997__auto___54524$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54526_code_num__52998__auto___54525_fn_53762_54522_read_code_fn__52997__auto___54524$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto___54527$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54526_code_num__52998__auto___54525_fn_53762_54522_read_code_fn__52997__auto___54524$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54527$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_render_sync_shape",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54527$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54526_code_num__52998__auto___54525_fn_53762_54522_read_code_fn__52997__auto___54524$$],null),$buffer$jscomp$67_cause53763_54523_id$jscomp$323$$);
}$app$render_wasm$wasm$internal_frame_id$$=null}};
$APP.$app$render_wasm$api$request_render$$=function(){if($APP.$app$render_wasm$api$initialized_QMARK_$$()&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($app$render_wasm$wasm$disable_request_render_QMARK_$$))){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$shapes_loading_QMARK_$$)))return $APP.$cljs$core$reset_BANG_$$($app$render_wasm$api$deferred_render_QMARK_$$,!0);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($app$render_wasm$api$pending_render$$)))return null;$APP.$cljs$core$reset_BANG_$$($app$render_wasm$api$pending_render$$,
!0);return $app$render_wasm$wasm$internal_frame_id$$=(0,$APP.$app$util$timers$request_animation_frame$$)(function($ts$jscomp$10$$){$APP.$cljs$core$reset_BANG_$$($app$render_wasm$api$pending_render$$,!1);$app$render_wasm$wasm$internal_frame_id$$=null;if($APP.$app$render_wasm$api$initialized_QMARK_$$()){var $fn_53754_54499$jscomp$inline_12217$$=$APP.$app$render_wasm$wasm$internal_module$$._render;try{$fn_53754_54499$jscomp$inline_12217$$($ts$jscomp$10$$)}catch($e53756$jscomp$inline_12226$$){var $JSCompiler_inline_result$jscomp$10820_cause53408$jscomp$inline_14303_cause53411$jscomp$inline_14312_cause53755_54500$jscomp$inline_12218_read_code_fn__52997__auto__$jscomp$inline_14296$$=
$e53756$jscomp$inline_12226$$;var $code__52999__auto___54503$jscomp$inline_12221_code_num__52998__auto__$jscomp$inline_14297_code_num__52998__auto___54502$jscomp$inline_12220_read_code_fn__52997__auto___54501$jscomp$inline_12219$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___54503$jscomp$inline_12221_code_num__52998__auto__$jscomp$inline_14297_code_num__52998__auto___54502$jscomp$inline_12220_read_code_fn__52997__auto___54501$jscomp$inline_12219$$=$APP.$cljs$core$truth_$$($code__52999__auto___54503$jscomp$inline_12221_code_num__52998__auto__$jscomp$inline_14297_code_num__52998__auto___54502$jscomp$inline_12220_read_code_fn__52997__auto___54501$jscomp$inline_12219$$)?
$code__52999__auto___54503$jscomp$inline_12221_code_num__52998__auto__$jscomp$inline_14297_code_num__52998__auto___54502$jscomp$inline_12220_read_code_fn__52997__auto___54501$jscomp$inline_12219$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___54503$jscomp$inline_12221_code_num__52998__auto__$jscomp$inline_14297_code_num__52998__auto___54502$jscomp$inline_12220_read_code_fn__52997__auto___54501$jscomp$inline_12219$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___54503$jscomp$inline_12221_code_num__52998__auto__$jscomp$inline_14297_code_num__52998__auto___54502$jscomp$inline_12220_read_code_fn__52997__auto___54501$jscomp$inline_12219$$():
null;$code__52999__auto___54503$jscomp$inline_12221_code_num__52998__auto__$jscomp$inline_14297_code_num__52998__auto___54502$jscomp$inline_12220_read_code_fn__52997__auto___54501$jscomp$inline_12219$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54503$jscomp$inline_12221_code_num__52998__auto__$jscomp$inline_14297_code_num__52998__auto___54502$jscomp$inline_12220_read_code_fn__52997__auto___54501$jscomp$inline_12219$$,$APP.$cljs$cst$2971$wasm_critical$$);
var $code__52999__auto__$jscomp$inline_14298_hint__53000__auto___54504$jscomp$inline_12222$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54503$jscomp$inline_12221_code_num__52998__auto__$jscomp$inline_14297_code_num__52998__auto___54502$jscomp$inline_12220_read_code_fn__52997__auto___54501$jscomp$inline_12219$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($code__52999__auto__$jscomp$inline_14298_hint__53000__auto___54504$jscomp$inline_12222$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_render",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$code__52999__auto__$jscomp$inline_14298_hint__53000__auto___54504$jscomp$inline_12222$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54503$jscomp$inline_12221_code_num__52998__auto__$jscomp$inline_14297_code_num__52998__auto___54502$jscomp$inline_12220_read_code_fn__52997__auto___54501$jscomp$inline_12219$$],null),$JSCompiler_inline_result$jscomp$10820_cause53408$jscomp$inline_14303_cause53411$jscomp$inline_14312_cause53755_54500$jscomp$inline_12218_read_code_fn__52997__auto__$jscomp$inline_14296$$);
}try{var $state$jscomp$inline_14289$$=$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$runtime_features$jscomp$inline_14290$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$inline_14289$$,$APP.$cljs$cst$3082$features_runtime$$),$enabled_features$jscomp$inline_14291$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$inline_14289$$,$APP.$cljs$cst$227$features$$);if($APP.$cljs$core$contains_QMARK_$$($runtime_features$jscomp$inline_14290$$,"text-editor-wasm/v1")||
$APP.$cljs$core$contains_QMARK_$$($enabled_features$jscomp$inline_14291$$,"text-editor-wasm/v1")){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53402$jscomp$inline_14294$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_update_blink;try{$fn_53402$jscomp$inline_14294$$($ts$jscomp$10$$)}catch($e53405$jscomp$inline_14300$$){var $cause53403$jscomp$inline_14295_read_code_fn__52997__auto__$jscomp$inline_14304$$=$e53405$jscomp$inline_14300$$;$JSCompiler_inline_result$jscomp$10820_cause53408$jscomp$inline_14303_cause53411$jscomp$inline_14312_cause53755_54500$jscomp$inline_12218_read_code_fn__52997__auto__$jscomp$inline_14296$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___54503$jscomp$inline_12221_code_num__52998__auto__$jscomp$inline_14297_code_num__52998__auto___54502$jscomp$inline_12220_read_code_fn__52997__auto___54501$jscomp$inline_12219$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10820_cause53408$jscomp$inline_14303_cause53411$jscomp$inline_14312_cause53755_54500$jscomp$inline_12218_read_code_fn__52997__auto__$jscomp$inline_14296$$)?$JSCompiler_inline_result$jscomp$10820_cause53408$jscomp$inline_14303_cause53411$jscomp$inline_14312_cause53755_54500$jscomp$inline_12218_read_code_fn__52997__auto__$jscomp$inline_14296$$.$cljs$core$IFn$_invoke$arity$0$?
$JSCompiler_inline_result$jscomp$10820_cause53408$jscomp$inline_14303_cause53411$jscomp$inline_14312_cause53755_54500$jscomp$inline_12218_read_code_fn__52997__auto__$jscomp$inline_14296$$.$cljs$core$IFn$_invoke$arity$0$():$JSCompiler_inline_result$jscomp$10820_cause53408$jscomp$inline_14303_cause53411$jscomp$inline_14312_cause53755_54500$jscomp$inline_12218_read_code_fn__52997__auto__$jscomp$inline_14296$$():null;$code__52999__auto__$jscomp$inline_14298_hint__53000__auto___54504$jscomp$inline_12222$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54503$jscomp$inline_12221_code_num__52998__auto__$jscomp$inline_14297_code_num__52998__auto___54502$jscomp$inline_12220_read_code_fn__52997__auto___54501$jscomp$inline_12219$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$inline_14299$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_14298_hint__53000__auto___54504$jscomp$inline_12222$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$inline_14299$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_update_blink",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$inline_14299$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_14298_hint__53000__auto___54504$jscomp$inline_12222$$],null),$cause53403$jscomp$inline_14295_read_code_fn__52997__auto__$jscomp$inline_14304$$);
}}if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53407$jscomp$inline_14302$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_render_overlay;try{$fn_53407$jscomp$inline_14302$$()}catch($e53409$jscomp$inline_14308$$){$JSCompiler_inline_result$jscomp$10820_cause53408$jscomp$inline_14303_cause53411$jscomp$inline_14312_cause53755_54500$jscomp$inline_12218_read_code_fn__52997__auto__$jscomp$inline_14296$$=$e53409$jscomp$inline_14308$$;$cause53403$jscomp$inline_14295_read_code_fn__52997__auto__$jscomp$inline_14304$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;var $code_num__52998__auto__$jscomp$inline_14305$$=$APP.$cljs$core$truth_$$($cause53403$jscomp$inline_14295_read_code_fn__52997__auto__$jscomp$inline_14304$$)?$cause53403$jscomp$inline_14295_read_code_fn__52997__auto__$jscomp$inline_14304$$.$cljs$core$IFn$_invoke$arity$0$?$cause53403$jscomp$inline_14295_read_code_fn__52997__auto__$jscomp$inline_14304$$.$cljs$core$IFn$_invoke$arity$0$():$cause53403$jscomp$inline_14295_read_code_fn__52997__auto__$jscomp$inline_14304$$():
null,$code__52999__auto__$jscomp$inline_14306$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code_num__52998__auto__$jscomp$inline_14305$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto__$jscomp$inline_14307$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_14306$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$inline_14307$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$516$fn$$,"_text_editor_render_overlay",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$inline_14307$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_14306$$],null),$JSCompiler_inline_result$jscomp$10820_cause53408$jscomp$inline_14303_cause53411$jscomp$inline_14312_cause53755_54500$jscomp$inline_12218_read_code_fn__52997__auto__$jscomp$inline_14296$$);}}if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53410$jscomp$inline_14311$$=
$APP.$app$render_wasm$wasm$internal_module$$._text_editor_poll_event;try{var $JSCompiler_temp$jscomp$inline_14310$$=$fn_53410$jscomp$inline_14311$$()}catch($e53412$jscomp$inline_14317$$){$JSCompiler_inline_result$jscomp$10820_cause53408$jscomp$inline_14303_cause53411$jscomp$inline_14312_cause53755_54500$jscomp$inline_12218_read_code_fn__52997__auto__$jscomp$inline_14296$$=$e53412$jscomp$inline_14317$$;var $read_code_fn__52997__auto__$jscomp$inline_14313$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,
$code_num__52998__auto__$jscomp$inline_14314$$=$APP.$cljs$core$truth_$$($read_code_fn__52997__auto__$jscomp$inline_14313$$)?$read_code_fn__52997__auto__$jscomp$inline_14313$$.$cljs$core$IFn$_invoke$arity$0$?$read_code_fn__52997__auto__$jscomp$inline_14313$$.$cljs$core$IFn$_invoke$arity$0$():$read_code_fn__52997__auto__$jscomp$inline_14313$$():null,$code__52999__auto__$jscomp$inline_14315$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code_num__52998__auto__$jscomp$inline_14314$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto__$jscomp$inline_14316$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_14315$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$inline_14316$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_poll_event",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$inline_14316$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_14315$$],null),$JSCompiler_inline_result$jscomp$10820_cause53408$jscomp$inline_14303_cause53411$jscomp$inline_14312_cause53755_54500$jscomp$inline_12218_read_code_fn__52997__auto__$jscomp$inline_14296$$);}}else $JSCompiler_temp$jscomp$inline_14310$$=null;var $ev_54507$jscomp$inline_12223$$=$JSCompiler_temp$jscomp$inline_14310$$;if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($ev_54507$jscomp$inline_12223$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ev_54507$jscomp$inline_12223$$,
0):$ev_54507$jscomp$inline_12223$$)){switch($ev_54507$jscomp$inline_12223$$){case 3:var $current_styles_54510$jscomp$inline_12224$$=$app$render_wasm$text_editor$text_editor_get_current_styles$$(),$shape_id_54511$jscomp$inline_12225$$=$APP.$app$render_wasm$text_editor$text_editor_get_active_shape_id$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts_v3$v3_update_text_editor_styles$$($shape_id_54511$jscomp$inline_12225$$,$current_styles_54510$jscomp$inline_12224$$))}$APP.$app$render_wasm$api$request_render$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$app$render_wasm$api$request_render$$.$cljs$core$IFn$_invoke$arity$1$("text-editor-event"):$APP.$app$render_wasm$api$request_render$$("text-editor-event")}}}catch($e53757$jscomp$inline_12227$$){console.error("text-editor overlay/update failed:",$e53757$jscomp$inline_12227$$)}$app$render_wasm$wasm$internal_frame_id$$=null;$JSCompiler_inline_result$jscomp$10820_cause53408$jscomp$inline_14303_cause53411$jscomp$inline_14312_cause53755_54500$jscomp$inline_12218_read_code_fn__52997__auto__$jscomp$inline_14296$$=
$app$util$globals$dispatch_BANG_$$($app$util$globals$event$$("penpot:wasm:render"))}else $JSCompiler_inline_result$jscomp$10820_cause53408$jscomp$inline_14303_cause53411$jscomp$inline_14312_cause53755_54500$jscomp$inline_12218_read_code_fn__52997__auto__$jscomp$inline_14296$$=null;return $JSCompiler_inline_result$jscomp$10820_cause53408$jscomp$inline_14303_cause53411$jscomp$inline_14312_cause53755_54500$jscomp$inline_12218_read_code_fn__52997__auto__$jscomp$inline_14296$$})}return null};
$app$render_wasm$api$begin_shapes_loading_BANG_$$=function(){$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$shapes_loading_QMARK_$$,!0);var $frame_id$jscomp$33$$=$app$render_wasm$wasm$internal_frame_id$$,$was_pending$$=$APP.$cljs$core$_deref$$($app$render_wasm$api$pending_render$$);$APP.$cljs$core$truth_$$($frame_id$jscomp$33$$)&&(cancelAnimationFrame($frame_id$jscomp$33$$),$app$render_wasm$wasm$internal_frame_id$$=null);$APP.$cljs$core$reset_BANG_$$($app$render_wasm$api$pending_render$$,
!1);$APP.$cljs$core$reset_BANG_$$($app$render_wasm$api$deferred_render_QMARK_$$,$was_pending$$)};$app$render_wasm$api$end_shapes_loading_BANG_$$=function(){var $was_loading$$=$APP.$cljs$core$compare_and_set_BANG_$$($APP.$app$render_wasm$api$shapes_loading_QMARK_$$,!0,!1);$APP.$cljs$core$reset_BANG_$$($app$render_wasm$api$deferred_render_QMARK_$$,!1);$was_loading$$&&$APP.$app$render_wasm$api$request_render$$("set-objects:flush")};
$APP.$app$render_wasm$api$use_shape$$=function($buffer$jscomp$68_cause53769_id$jscomp$324$$){if($APP.$app$render_wasm$api$initialized_QMARK_$$()){$buffer$jscomp$68_cause53769_id$jscomp$324$$=$APP.$app$common$uuid$get_u32$$($buffer$jscomp$68_cause53769_id$jscomp$324$$);var $code__52999__auto__$jscomp$37_code_num__52998__auto__$jscomp$37_fn_53768_read_code_fn__52997__auto__$jscomp$37$$=$APP.$app$render_wasm$wasm$internal_module$$._use_shape;try{return $code__52999__auto__$jscomp$37_code_num__52998__auto__$jscomp$37_fn_53768_read_code_fn__52997__auto__$jscomp$37$$($buffer$jscomp$68_cause53769_id$jscomp$324$$[0],
$buffer$jscomp$68_cause53769_id$jscomp$324$$[1],$buffer$jscomp$68_cause53769_id$jscomp$324$$[2],$buffer$jscomp$68_cause53769_id$jscomp$324$$[3])}catch($e53770$$){$buffer$jscomp$68_cause53769_id$jscomp$324$$=$e53770$$;$code__52999__auto__$jscomp$37_code_num__52998__auto__$jscomp$37_fn_53768_read_code_fn__52997__auto__$jscomp$37$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$37_code_num__52998__auto__$jscomp$37_fn_53768_read_code_fn__52997__auto__$jscomp$37$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$37_code_num__52998__auto__$jscomp$37_fn_53768_read_code_fn__52997__auto__$jscomp$37$$)?$code__52999__auto__$jscomp$37_code_num__52998__auto__$jscomp$37_fn_53768_read_code_fn__52997__auto__$jscomp$37$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$37_code_num__52998__auto__$jscomp$37_fn_53768_read_code_fn__52997__auto__$jscomp$37$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$37_code_num__52998__auto__$jscomp$37_fn_53768_read_code_fn__52997__auto__$jscomp$37$$():
null;$code__52999__auto__$jscomp$37_code_num__52998__auto__$jscomp$37_fn_53768_read_code_fn__52997__auto__$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$37_code_num__52998__auto__$jscomp$37_fn_53768_read_code_fn__52997__auto__$jscomp$37$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$37$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$37_code_num__52998__auto__$jscomp$37_fn_53768_read_code_fn__52997__auto__$jscomp$37$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$37$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_use_shape",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$37$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$37_code_num__52998__auto__$jscomp$37_fn_53768_read_code_fn__52997__auto__$jscomp$37$$],null),$buffer$jscomp$68_cause53769_id$jscomp$324$$);
}}else return null};
$APP.$app$render_wasm$api$set_shape_text_content$$=function($G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$,$all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$){$all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$!=null&&
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$render_wasm$text_editor$shape_text_contents$$,$APP.$cljs$core$assoc$$,$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$,
$all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$);if($APP.$app$render_wasm$api$initialized_QMARK_$$()){$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=
$APP.$app$render_wasm$wasm$internal_module$$._clear_shape_text;try{$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$()}catch($e53776$$){$all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$=
$e53776$$;$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=
$APP.$cljs$core$truth_$$($G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$)?$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$.$cljs$core$IFn$_invoke$arity$0$?
$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$.$cljs$core$IFn$_invoke$arity$0$():$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$():
null;$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$=["WASM Error (",$APP.$app$common$data$name$$($G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_clear_shape_text",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$,
$APP.$cljs$cst$273$code$$,$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$],null),$all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$);}$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$,$APP.$cljs$cst$1767$vertical_align$$);$app$render_wasm$api$set_shape_vertical_align$$.$cljs$core$IFn$_invoke$arity$1$?$app$render_wasm$api$set_shape_vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$):
$app$render_wasm$api$set_shape_vertical_align$$($G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$);$G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$=
$app$render_wasm$api$fonts$get_content_fonts$$($all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$);$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=$APP.$app$render_wasm$api$fonts_from_text_content$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$app$render_wasm$api$fonts_from_text_content$$.$cljs$core$IFn$_invoke$arity$2$($all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$,!0):$APP.$app$render_wasm$api$fonts_from_text_content$$($all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$,!0);$all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$,
$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$);$all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$=$app$render_wasm$api$fonts$store_fonts$$($all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$);
a:{$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=$APP.$cljs$core$seq$$($G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$);
$G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$=null;for(var $G__53233$jscomp$inline_5965_count__53166$jscomp$inline_5959$$=0,$i__53167$jscomp$inline_5960$$=0;;)if($i__53167$jscomp$inline_5960$$<$G__53233$jscomp$inline_5965_count__53166$jscomp$inline_5959$$){var $G__53235$jscomp$inline_5967_font$jscomp$inline_5961$$=$G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$i__53167$jscomp$inline_5960$$);$APP.$app$main$fonts$ensure_loaded_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($G__53235$jscomp$inline_5967_font$jscomp$inline_5961$$),$APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($G__53235$jscomp$inline_5967_font$jscomp$inline_5961$$));$i__53167$jscomp$inline_5960$$+=1}else if($G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=
$APP.$cljs$core$seq$$($G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$))$G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$=
$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$)?
($G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=$APP.$cljs$core$_chunked_first$$($G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$),
$G__53233$jscomp$inline_5965_count__53166$jscomp$inline_5959$$=$APP.$cljs$core$_chunked_rest$$($G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$),$G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$=$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$,
$G__53235$jscomp$inline_5967_font$jscomp$inline_5961$$=$APP.$cljs$core$count$$($G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$),$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=
$G__53233$jscomp$inline_5965_count__53166$jscomp$inline_5959$$,$G__53233$jscomp$inline_5965_count__53166$jscomp$inline_5959$$=$G__53235$jscomp$inline_5967_font$jscomp$inline_5961$$):($G__53235$jscomp$inline_5967_font$jscomp$inline_5961$$=$APP.$cljs$core$first$$($G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$),$APP.$app$main$fonts$ensure_loaded_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($G__53235$jscomp$inline_5967_font$jscomp$inline_5961$$),
$APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($G__53235$jscomp$inline_5967_font$jscomp$inline_5961$$)),$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=$APP.$cljs$core$next$$($G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$),
$G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$=null,$G__53233$jscomp$inline_5965_count__53166$jscomp$inline_5959$$=0),$i__53167$jscomp$inline_5960$$=0;else break a}$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=
$APP.$app$render_wasm$wasm$internal_module$$._update_shape_text_layout;try{$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$()}catch($e53780$$){throw $all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$=
$e53780$$,$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=
$APP.$cljs$core$truth_$$($G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$)?$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$.$cljs$core$IFn$_invoke$arity$0$?
$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$.$cljs$core$IFn$_invoke$arity$0$():$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$():
null,$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$,
$APP.$cljs$cst$2971$wasm_critical$$),$G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$=["WASM Error (",$APP.$app$common$data$name$$($G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_update_shape_text_layout",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$G__53234$jscomp$inline_5966_chunk__53165$jscomp$inline_5958_fonts$jscomp$8_hint__53000__auto___54536_hint__53000__auto___54545_seq__53164__$1$jscomp$inline_5963$$,
$APP.$cljs$cst$273$code$$,$G__53777_54539_c__5548__auto__$jscomp$inline_5964_code__52999__auto___54535_code__52999__auto___54544_code_num__52998__auto___54534_code_num__52998__auto___54543_fallback_fonts_fn_53774_54531_fn_53778_54540_read_code_fn__52997__auto___54533_read_code_fn__52997__auto___54542_seq__53164$jscomp$inline_5957_shape_id$jscomp$46_temp__5825__auto__$jscomp$inline_5962$$],null),$all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$);}return $all_fonts_cause53775_54532_cause53779_54541_content$jscomp$135_result$jscomp$251$$}return null};
$app$render_wasm$api$apply_styles_to_selection$$=function($attrs$jscomp$57_result$jscomp$252$$){$attrs$jscomp$57_result$jscomp$252$$=$app$render_wasm$text_editor$apply_styles_to_selection$$($attrs$jscomp$57_result$jscomp$252$$);$APP.$app$render_wasm$api$request_render$$("apply-styles-to-selection");return $attrs$jscomp$57_result$jscomp$252$$};
$app$render_wasm$api$set_parent_id$$=function($buffer$jscomp$70_cause53782_id$jscomp$326$$){$buffer$jscomp$70_cause53782_id$jscomp$326$$=$APP.$app$common$uuid$get_u32$$($buffer$jscomp$70_cause53782_id$jscomp$326$$);var $code__52999__auto__$jscomp$39_code_num__52998__auto__$jscomp$39_fn_53781_read_code_fn__52997__auto__$jscomp$39$$=$APP.$app$render_wasm$wasm$internal_module$$._set_parent;try{return $code__52999__auto__$jscomp$39_code_num__52998__auto__$jscomp$39_fn_53781_read_code_fn__52997__auto__$jscomp$39$$($buffer$jscomp$70_cause53782_id$jscomp$326$$[0],
$buffer$jscomp$70_cause53782_id$jscomp$326$$[1],$buffer$jscomp$70_cause53782_id$jscomp$326$$[2],$buffer$jscomp$70_cause53782_id$jscomp$326$$[3])}catch($e53783$$){$buffer$jscomp$70_cause53782_id$jscomp$326$$=$e53783$$;$code__52999__auto__$jscomp$39_code_num__52998__auto__$jscomp$39_fn_53781_read_code_fn__52997__auto__$jscomp$39$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$39_code_num__52998__auto__$jscomp$39_fn_53781_read_code_fn__52997__auto__$jscomp$39$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$39_code_num__52998__auto__$jscomp$39_fn_53781_read_code_fn__52997__auto__$jscomp$39$$)?$code__52999__auto__$jscomp$39_code_num__52998__auto__$jscomp$39_fn_53781_read_code_fn__52997__auto__$jscomp$39$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$39_code_num__52998__auto__$jscomp$39_fn_53781_read_code_fn__52997__auto__$jscomp$39$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$39_code_num__52998__auto__$jscomp$39_fn_53781_read_code_fn__52997__auto__$jscomp$39$$():
null;$code__52999__auto__$jscomp$39_code_num__52998__auto__$jscomp$39_fn_53781_read_code_fn__52997__auto__$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$39_code_num__52998__auto__$jscomp$39_fn_53781_read_code_fn__52997__auto__$jscomp$39$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$39$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$39_code_num__52998__auto__$jscomp$39_fn_53781_read_code_fn__52997__auto__$jscomp$39$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$39$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_parent",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$39$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$39_code_num__52998__auto__$jscomp$39_fn_53781_read_code_fn__52997__auto__$jscomp$39$$],null),$buffer$jscomp$70_cause53782_id$jscomp$326$$);
}};
$app$render_wasm$api$set_shape_clip_content$$=function($cause53785_clip_content$jscomp$1$$){var $code__52999__auto__$jscomp$40_code_num__52998__auto__$jscomp$40_fn_53784_read_code_fn__52997__auto__$jscomp$40$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_clip_content;try{return $code__52999__auto__$jscomp$40_code_num__52998__auto__$jscomp$40_fn_53784_read_code_fn__52997__auto__$jscomp$40$$($cause53785_clip_content$jscomp$1$$)}catch($e53786$$){$cause53785_clip_content$jscomp$1$$=$e53786$$;$code__52999__auto__$jscomp$40_code_num__52998__auto__$jscomp$40_fn_53784_read_code_fn__52997__auto__$jscomp$40$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$40_code_num__52998__auto__$jscomp$40_fn_53784_read_code_fn__52997__auto__$jscomp$40$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$40_code_num__52998__auto__$jscomp$40_fn_53784_read_code_fn__52997__auto__$jscomp$40$$)?$code__52999__auto__$jscomp$40_code_num__52998__auto__$jscomp$40_fn_53784_read_code_fn__52997__auto__$jscomp$40$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$40_code_num__52998__auto__$jscomp$40_fn_53784_read_code_fn__52997__auto__$jscomp$40$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$40_code_num__52998__auto__$jscomp$40_fn_53784_read_code_fn__52997__auto__$jscomp$40$$():null;$code__52999__auto__$jscomp$40_code_num__52998__auto__$jscomp$40_fn_53784_read_code_fn__52997__auto__$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$40_code_num__52998__auto__$jscomp$40_fn_53784_read_code_fn__52997__auto__$jscomp$40$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$40$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$40_code_num__52998__auto__$jscomp$40_fn_53784_read_code_fn__52997__auto__$jscomp$40$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$40$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_clip_content",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$40$$,$APP.$cljs$cst$273$code$$,
$code__52999__auto__$jscomp$40_code_num__52998__auto__$jscomp$40_fn_53784_read_code_fn__52997__auto__$jscomp$40$$],null),$cause53785_clip_content$jscomp$1$$);}};
$app$render_wasm$api$set_shape_type$$=function($cause53788_type$jscomp$416$$){var $code__52999__auto__$jscomp$41_code_num__52998__auto__$jscomp$41_fn_53787_read_code_fn__52997__auto__$jscomp$41$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_type;try{$code__52999__auto__$jscomp$41_code_num__52998__auto__$jscomp$41_fn_53787_read_code_fn__52997__auto__$jscomp$41$$($app$render_wasm$serializers$translate_shape_type$$($cause53788_type$jscomp$416$$))}catch($e53789$$){$cause53788_type$jscomp$416$$=$e53789$$;
$code__52999__auto__$jscomp$41_code_num__52998__auto__$jscomp$41_fn_53787_read_code_fn__52997__auto__$jscomp$41$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$41_code_num__52998__auto__$jscomp$41_fn_53787_read_code_fn__52997__auto__$jscomp$41$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$41_code_num__52998__auto__$jscomp$41_fn_53787_read_code_fn__52997__auto__$jscomp$41$$)?$code__52999__auto__$jscomp$41_code_num__52998__auto__$jscomp$41_fn_53787_read_code_fn__52997__auto__$jscomp$41$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$41_code_num__52998__auto__$jscomp$41_fn_53787_read_code_fn__52997__auto__$jscomp$41$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$41_code_num__52998__auto__$jscomp$41_fn_53787_read_code_fn__52997__auto__$jscomp$41$$():null;$code__52999__auto__$jscomp$41_code_num__52998__auto__$jscomp$41_fn_53787_read_code_fn__52997__auto__$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$41_code_num__52998__auto__$jscomp$41_fn_53787_read_code_fn__52997__auto__$jscomp$41$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$41$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$41_code_num__52998__auto__$jscomp$41_fn_53787_read_code_fn__52997__auto__$jscomp$41$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$41$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_type",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53000__auto__$jscomp$41$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$41_code_num__52998__auto__$jscomp$41_fn_53787_read_code_fn__52997__auto__$jscomp$41$$],null),$cause53788_type$jscomp$416$$);}};
$app$render_wasm$api$set_masked$$=function($cause53791_masked$$){var $code__52999__auto__$jscomp$42_code_num__52998__auto__$jscomp$42_fn_53790_read_code_fn__52997__auto__$jscomp$42$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_masked_group;try{return $code__52999__auto__$jscomp$42_code_num__52998__auto__$jscomp$42_fn_53790_read_code_fn__52997__auto__$jscomp$42$$($cause53791_masked$$)}catch($e53792$$){$cause53791_masked$$=$e53792$$;$code__52999__auto__$jscomp$42_code_num__52998__auto__$jscomp$42_fn_53790_read_code_fn__52997__auto__$jscomp$42$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$42_code_num__52998__auto__$jscomp$42_fn_53790_read_code_fn__52997__auto__$jscomp$42$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$42_code_num__52998__auto__$jscomp$42_fn_53790_read_code_fn__52997__auto__$jscomp$42$$)?$code__52999__auto__$jscomp$42_code_num__52998__auto__$jscomp$42_fn_53790_read_code_fn__52997__auto__$jscomp$42$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$42_code_num__52998__auto__$jscomp$42_fn_53790_read_code_fn__52997__auto__$jscomp$42$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$42_code_num__52998__auto__$jscomp$42_fn_53790_read_code_fn__52997__auto__$jscomp$42$$():null;$code__52999__auto__$jscomp$42_code_num__52998__auto__$jscomp$42_fn_53790_read_code_fn__52997__auto__$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$42_code_num__52998__auto__$jscomp$42_fn_53790_read_code_fn__52997__auto__$jscomp$42$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$42$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$42_code_num__52998__auto__$jscomp$42_fn_53790_read_code_fn__52997__auto__$jscomp$42$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$42$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_masked_group",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$42$$,$APP.$cljs$cst$273$code$$,
$code__52999__auto__$jscomp$42_code_num__52998__auto__$jscomp$42_fn_53790_read_code_fn__52997__auto__$jscomp$42$$],null),$cause53791_masked$$);}};
$app$render_wasm$api$set_shape_selrect$$=function($cause53794_selrect$jscomp$38$$){var $code__52999__auto__$jscomp$43_code_num__52998__auto__$jscomp$43_fn_53793_read_code_fn__52997__auto__$jscomp$43$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_selrect;try{$code__52999__auto__$jscomp$43_code_num__52998__auto__$jscomp$43_fn_53793_read_code_fn__52997__auto__$jscomp$43$$($cause53794_selrect$jscomp$38$$?.x1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause53794_selrect$jscomp$38$$,
$APP.$cljs$cst$1523$x1$$),$cause53794_selrect$jscomp$38$$?.y1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause53794_selrect$jscomp$38$$,$APP.$cljs$cst$1524$y1$$),$cause53794_selrect$jscomp$38$$?.x2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause53794_selrect$jscomp$38$$,$APP.$cljs$cst$1525$x2$$),$cause53794_selrect$jscomp$38$$?.y2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause53794_selrect$jscomp$38$$,$APP.$cljs$cst$1526$y2$$))}catch($e53795$$){$cause53794_selrect$jscomp$38$$=
$e53795$$;$code__52999__auto__$jscomp$43_code_num__52998__auto__$jscomp$43_fn_53793_read_code_fn__52997__auto__$jscomp$43$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$43_code_num__52998__auto__$jscomp$43_fn_53793_read_code_fn__52997__auto__$jscomp$43$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$43_code_num__52998__auto__$jscomp$43_fn_53793_read_code_fn__52997__auto__$jscomp$43$$)?$code__52999__auto__$jscomp$43_code_num__52998__auto__$jscomp$43_fn_53793_read_code_fn__52997__auto__$jscomp$43$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$43_code_num__52998__auto__$jscomp$43_fn_53793_read_code_fn__52997__auto__$jscomp$43$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$43_code_num__52998__auto__$jscomp$43_fn_53793_read_code_fn__52997__auto__$jscomp$43$$():null;$code__52999__auto__$jscomp$43_code_num__52998__auto__$jscomp$43_fn_53793_read_code_fn__52997__auto__$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$43_code_num__52998__auto__$jscomp$43_fn_53793_read_code_fn__52997__auto__$jscomp$43$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$43$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$43_code_num__52998__auto__$jscomp$43_fn_53793_read_code_fn__52997__auto__$jscomp$43$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$43$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_selrect",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$43$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$43_code_num__52998__auto__$jscomp$43_fn_53793_read_code_fn__52997__auto__$jscomp$43$$],null),$cause53794_selrect$jscomp$38$$);}};
$app$render_wasm$api$set_shape_transform$$=function($cause53799_transform$jscomp$74$$){var $code__52999__auto__$jscomp$44_code_num__52998__auto__$jscomp$44_fn_53798_read_code_fn__52997__auto__$jscomp$44$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_transform;try{return $code__52999__auto__$jscomp$44_code_num__52998__auto__$jscomp$44_fn_53798_read_code_fn__52997__auto__$jscomp$44$$($cause53799_transform$jscomp$74$$?.a??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause53799_transform$jscomp$74$$,
$APP.$cljs$cst$1519$a$$),$cause53799_transform$jscomp$74$$?.b??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause53799_transform$jscomp$74$$,$APP.$cljs$cst$1520$b$$),$cause53799_transform$jscomp$74$$?.c??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause53799_transform$jscomp$74$$,$cljs$cst$1521$c$$),$cause53799_transform$jscomp$74$$?.d??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause53799_transform$jscomp$74$$,$cljs$cst$1447$d$$),$cause53799_transform$jscomp$74$$?.e??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause53799_transform$jscomp$74$$,$cljs$cst$1449$e$$),$cause53799_transform$jscomp$74$$?.f??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause53799_transform$jscomp$74$$,$cljs$cst$598$f$$))}catch($e53800$$){$cause53799_transform$jscomp$74$$=$e53800$$;$code__52999__auto__$jscomp$44_code_num__52998__auto__$jscomp$44_fn_53798_read_code_fn__52997__auto__$jscomp$44$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$44_code_num__52998__auto__$jscomp$44_fn_53798_read_code_fn__52997__auto__$jscomp$44$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$44_code_num__52998__auto__$jscomp$44_fn_53798_read_code_fn__52997__auto__$jscomp$44$$)?$code__52999__auto__$jscomp$44_code_num__52998__auto__$jscomp$44_fn_53798_read_code_fn__52997__auto__$jscomp$44$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$44_code_num__52998__auto__$jscomp$44_fn_53798_read_code_fn__52997__auto__$jscomp$44$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$44_code_num__52998__auto__$jscomp$44_fn_53798_read_code_fn__52997__auto__$jscomp$44$$():
null;$code__52999__auto__$jscomp$44_code_num__52998__auto__$jscomp$44_fn_53798_read_code_fn__52997__auto__$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$44_code_num__52998__auto__$jscomp$44_fn_53798_read_code_fn__52997__auto__$jscomp$44$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$44$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$44_code_num__52998__auto__$jscomp$44_fn_53798_read_code_fn__52997__auto__$jscomp$44$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$44$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_transform",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$44$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$44_code_num__52998__auto__$jscomp$44_fn_53798_read_code_fn__52997__auto__$jscomp$44$$],null),$cause53799_transform$jscomp$74$$);
}};
$app$render_wasm$api$set_shape_rotation$$=function($cause53802_rotation$jscomp$12$$){var $code__52999__auto__$jscomp$45_code_num__52998__auto__$jscomp$45_fn_53801_read_code_fn__52997__auto__$jscomp$45$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_rotation;try{return $code__52999__auto__$jscomp$45_code_num__52998__auto__$jscomp$45_fn_53801_read_code_fn__52997__auto__$jscomp$45$$($cause53802_rotation$jscomp$12$$)}catch($e53803$$){$cause53802_rotation$jscomp$12$$=$e53803$$;$code__52999__auto__$jscomp$45_code_num__52998__auto__$jscomp$45_fn_53801_read_code_fn__52997__auto__$jscomp$45$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;
$code__52999__auto__$jscomp$45_code_num__52998__auto__$jscomp$45_fn_53801_read_code_fn__52997__auto__$jscomp$45$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$45_code_num__52998__auto__$jscomp$45_fn_53801_read_code_fn__52997__auto__$jscomp$45$$)?$code__52999__auto__$jscomp$45_code_num__52998__auto__$jscomp$45_fn_53801_read_code_fn__52997__auto__$jscomp$45$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$45_code_num__52998__auto__$jscomp$45_fn_53801_read_code_fn__52997__auto__$jscomp$45$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$45_code_num__52998__auto__$jscomp$45_fn_53801_read_code_fn__52997__auto__$jscomp$45$$():null;$code__52999__auto__$jscomp$45_code_num__52998__auto__$jscomp$45_fn_53801_read_code_fn__52997__auto__$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$45_code_num__52998__auto__$jscomp$45_fn_53801_read_code_fn__52997__auto__$jscomp$45$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$45$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$45_code_num__52998__auto__$jscomp$45_fn_53801_read_code_fn__52997__auto__$jscomp$45$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$45$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_rotation",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$45$$,$APP.$cljs$cst$273$code$$,
$code__52999__auto__$jscomp$45_code_num__52998__auto__$jscomp$45_fn_53801_read_code_fn__52997__auto__$jscomp$45$$],null),$cause53802_rotation$jscomp$12$$);}};
$app$render_wasm$api$set_shape_children$$=function($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$){performance.mark("set-shape-children::begin");$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$uuid_QMARK_$$),$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$);switch($APP.$cljs$core$count$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$)){case 0:$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$APP.$app$render_wasm$wasm$internal_module$$._set_children_0;try{$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$()}catch($e53812$$){$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$e53812$$;var $c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$truth_$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$)?
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$.$cljs$core$IFn$_invoke$arity$0$?
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$.$cljs$core$IFn$_invoke$arity$0$():
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$():
null;$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=["WASM Error (",$APP.$app$common$data$name$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_children_0",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$,$APP.$cljs$cst$273$code$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$],
null),$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$);}break;case 1:$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,0,null);$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$APP.$app$common$uuid$get_u32$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$);$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$app$render_wasm$wasm$internal_module$$._set_children_1;try{$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[0],
$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[1],$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[2],
$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[3])}catch($e53819$$){throw $c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$e53819$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$truth_$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$)?
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$.$cljs$core$IFn$_invoke$arity$0$?
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$.$cljs$core$IFn$_invoke$arity$0$():
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$():
null,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$,
$APP.$cljs$cst$2971$wasm_critical$$),$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=["WASM Error (",$APP.$app$common$data$name$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_children_1",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$,$APP.$cljs$cst$273$code$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$],
null),$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$);}break;case 2:$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,0,null);$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,1,null);$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$APP.$app$common$uuid$get_u32$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$);
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$app$common$uuid$get_u32$$($c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$);$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=
$APP.$app$render_wasm$wasm$internal_module$$._set_children_2;try{$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[0],
$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[1],$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[2],
$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[3],$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[0],
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[1],
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[2],
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[3])}catch($e53829$$){throw $c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$e53829$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$truth_$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$)?
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$.$cljs$core$IFn$_invoke$arity$0$?
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$.$cljs$core$IFn$_invoke$arity$0$():
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$():
null,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$,
$APP.$cljs$cst$2971$wasm_critical$$),$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=["WASM Error (",$APP.$app$common$data$name$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_children_2",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$,$APP.$cljs$cst$273$code$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$],
null),$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$);}break;case 3:var $c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,
0,null);$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,1,null);$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,2,null);$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$APP.$app$common$uuid$get_u32$$($c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$);$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$app$common$uuid$get_u32$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$);
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=$APP.$app$common$uuid$get_u32$$($c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$);
$c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$=$APP.$app$render_wasm$wasm$internal_module$$._set_children_3;try{$c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[0],$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[1],
$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[2],$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[3],
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[0],
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[1],
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[2],
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[3],
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$[0],$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$[1],
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$[2],$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$[3])}catch($e53835$$){throw $c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$e53835$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$truth_$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$)?
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$.$cljs$core$IFn$_invoke$arity$0$?
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$.$cljs$core$IFn$_invoke$arity$0$():
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$():
null,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$,
$APP.$cljs$cst$2971$wasm_critical$$),$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=["WASM Error (",$APP.$app$common$data$name$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_children_3",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$,$APP.$cljs$cst$273$code$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$],
null),$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$);}break;case 4:var $c1_54602_c3_54621_c3_54626__$1_fn_53839_54610$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,
0,null);$c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,1,null);$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,2,null);$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,3,null);$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$APP.$app$common$uuid$get_u32$$($c1_54602_c3_54621_c3_54626__$1_fn_53839_54610$$);$c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$=$APP.$app$common$uuid$get_u32$$($c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$);$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$app$common$uuid$get_u32$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$);
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=$APP.$app$common$uuid$get_u32$$($c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$);
$c1_54602_c3_54621_c3_54626__$1_fn_53839_54610$$=$APP.$app$render_wasm$wasm$internal_module$$._set_children_4;try{$c1_54602_c3_54621_c3_54626__$1_fn_53839_54610$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[0],$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[1],
$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[2],$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[3],
$c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$[0],$c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$[1],$c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$[2],$c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$[3],$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[0],
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[1],
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[2],
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[3],
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$[0],$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$[1],
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$[2],$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$[3])}catch($e53841$$){throw $c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$e53841$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$truth_$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$)?
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$.$cljs$core$IFn$_invoke$arity$0$?
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$.$cljs$core$IFn$_invoke$arity$0$():
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$():
null,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$,
$APP.$cljs$cst$2971$wasm_critical$$),$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=["WASM Error (",$APP.$app$common$data$name$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_children_4",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$,$APP.$cljs$cst$273$code$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$],
null),$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$);}break;case 5:var $c1_54619_fn_53849_54629$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,
0,null);$c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,1,null);$c1_54602_c3_54621_c3_54626__$1_fn_53839_54610$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,
2,null);$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,3,null);$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$,4,null);$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$APP.$app$common$uuid$get_u32$$($c1_54619_fn_53849_54629$$);$c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$=$APP.$app$common$uuid$get_u32$$($c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$);$c1_54602_c3_54621_c3_54626__$1_fn_53839_54610$$=$APP.$app$common$uuid$get_u32$$($c1_54602_c3_54621_c3_54626__$1_fn_53839_54610$$);$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$app$common$uuid$get_u32$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$);
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=$APP.$app$common$uuid$get_u32$$($c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$);
$c1_54619_fn_53849_54629$$=$APP.$app$render_wasm$wasm$internal_module$$._set_children_5;try{$c1_54619_fn_53849_54629$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[0],$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[1],
$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[2],$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$[3],
$c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$[0],$c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$[1],$c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$[2],$c1_54586_c2_54603_c2_54607__$1_c2_54620_c2_54625__$1_fn_53833_54592$$[3],$c1_54602_c3_54621_c3_54626__$1_fn_53839_54610$$[0],$c1_54602_c3_54621_c3_54626__$1_fn_53839_54610$$[1],$c1_54602_c3_54621_c3_54626__$1_fn_53839_54610$$[2],$c1_54602_c3_54621_c3_54626__$1_fn_53839_54610$$[3],
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[0],
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[1],
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[2],
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$[3],
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$[0],$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$[1],
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$[2],$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$[3])}catch($e53851$$){throw $c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$e53851$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$truth_$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$)?
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$.$cljs$core$IFn$_invoke$arity$0$?
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$.$cljs$core$IFn$_invoke$arity$0$():
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$():
null,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$,
$APP.$cljs$cst$2971$wasm_critical$$),$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=["WASM Error (",$APP.$app$common$data$name$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_children_5",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$,$APP.$cljs$cst$273$code$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$],
null),$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$);}break;default:var $heap_54645$$=$APP.$app$render_wasm$mem$get_heap_u32$$();$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
16*$APP.$cljs$core$count$$($c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$);$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$app$render_wasm$mem$alloc__GT_offset_32$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$);
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($offset__$1$jscomp$6$$,$id$jscomp$327$$){return $APP.$app$render_wasm$mem$heap32$write_uuid$$($offset__$1$jscomp$6$$,$heap_54645$$,$id$jscomp$327$$)},$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$,
$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$);$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$APP.$app$render_wasm$wasm$internal_module$$._set_children;try{$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$()}catch($e53854$$){throw $c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$=
$e53854$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$truth_$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$)?
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$.$cljs$core$IFn$_invoke$arity$0$?
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$.$cljs$core$IFn$_invoke$arity$0$():
$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$():
null,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$,
$APP.$cljs$cst$2971$wasm_critical$$),$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$=["WASM Error (",$APP.$app$common$data$name$$($c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_children",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$c2_54574_c3_54588_c3_54591__$1_c4_54605_c4_54609__$1_c5_54623_c5_54628__$1_fn_53827_54577_hint__53000__auto___54558_hint__53000__auto___54569_hint__53000__auto___54582_hint__53000__auto___54597_hint__53000__auto___54615_hint__53000__auto___54638_hint__53000__auto___54653$$,$APP.$cljs$cst$273$code$$,$c1_54573_c2_54576__$1_c2_54587_c2_54590__$1_c3_54604_c3_54608__$1_c4_54622_c4_54627__$1_code__52999__auto___54557_code__52999__auto___54568_code__52999__auto___54581_code__52999__auto___54596_code__52999__auto___54614_code__52999__auto___54637_code__52999__auto___54652_code_num__52998__auto___54556_code_num__52998__auto___54567_code_num__52998__auto___54580_code_num__52998__auto___54595_code_num__52998__auto___54613_code_num__52998__auto___54636_code_num__52998__auto___54651_fn_53817_54564_offset_54647_read_code_fn__52997__auto___54555_read_code_fn__52997__auto___54566_read_code_fn__52997__auto___54579_read_code_fn__52997__auto___54594_read_code_fn__52997__auto___54612_read_code_fn__52997__auto___54635_read_code_fn__52997__auto___54650_size_54646$$],
null),$c1_54562_c1_54563__$1_c1_54575__$1_c1_54589__$1_c1_54606__$1_c1_54624__$1_cause53811_54554_cause53818_54565_cause53828_54578_cause53834_54593_cause53840_54611_cause53850_54634_cause53853_54649_children$jscomp$201_children_54550__$1_fn_53810_54553_fn_53852_54648$$);}}performance.mark("set-shape-children::end");performance.measure("set-shape-children",{start:"set-shape-children::begin",end:"set-shape-children::end",detail:{}});return null};
$app$render_wasm$api$retrieve_image$$=function($url$jscomp$82$$){return $APP.$beicon$v2$core$from$$($APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$(fetch($url$jscomp$82$$),function($response$jscomp$10$$){return $response$jscomp$10$$.blob()}),function($image$jscomp$18$$){return createImageBitmap($image$jscomp$18$$)}))};
$app$render_wasm$api$fetch_image$$=function($shape_id$jscomp$47$$,$image_id$jscomp$1$$,$thumbnail_QMARK_$jscomp$1$$){var $url$jscomp$83$$=$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$image_id$jscomp$1$$],null),$thumbnail_QMARK_$jscomp$1$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$302$key$$,$url$jscomp$83$$,$cljs$cst$3085$thumbnail_QMARK_$$,$thumbnail_QMARK_$jscomp$1$$,$APP.$cljs$cst$2354$callback$$,
function(){return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$42$$){$APP.$app$common$logging$enabled_QMARK_$$("app.render-wasm.api",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,
"Could not fetch image"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3086$image_id$$,$image_id$jscomp$1$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3085$thumbnail_QMARK_$$,$thumbnail_QMARK_$jscomp$1$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1975$url$$,$url$jscomp$83$$],null)],null)}),$cause$jscomp$42$$,
"app.render-wasm.api",$APP.$cljs$cst$849$error$$,!1);return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$map$$(function($cause53874_54658_fn_53873_54657_height$jscomp$85_img$jscomp$5$$){a:{if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$=
$APP.$app$render_wasm$wasm$internal_module$$.GL;if($APP.$cljs$core$truth_$$($code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$)){$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$=
$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.currentContext;$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$=
$APP.$cljs$core$truth_$$($code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$)?$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.GLctx:
null;break a}}$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$=null}if($APP.$cljs$core$truth_$$($code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$)){var $hint__53000__auto___54662_texture$jscomp$inline_5974_width$jscomp$95$$=
$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.createTexture();$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.bindTexture($code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.TEXTURE_2D,
$hint__53000__auto___54662_texture$jscomp$inline_5974_width$jscomp$95$$);$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.texParameteri($code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.TEXTURE_2D,
$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.TEXTURE_WRAP_S,$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.CLAMP_TO_EDGE);
$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.texParameteri($code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.TEXTURE_2D,
$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.TEXTURE_WRAP_T,$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.CLAMP_TO_EDGE);
$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.texParameteri($code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.TEXTURE_2D,
$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.TEXTURE_MIN_FILTER,$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.LINEAR);
$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.texParameteri($code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.TEXTURE_2D,
$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.TEXTURE_MAG_FILTER,$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.LINEAR);
$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.texImage2D($code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.TEXTURE_2D,
0,$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.RGBA,$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.RGBA,
$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.UNSIGNED_BYTE,$cause53874_54658_fn_53873_54657_height$jscomp$85_img$jscomp$5$$);$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.bindTexture($code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.TEXTURE_2D,
null);$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$=$APP.$app$render_wasm$wasm$internal_module$$.GL;var $offset$jscomp$150_textures$jscomp$inline_5978$$=$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.textures;
$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$=$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.getNewId($offset$jscomp$150_textures$jscomp$inline_5978$$);
$offset$jscomp$150_textures$jscomp$inline_5978$$[$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$]=$hint__53000__auto___54662_texture$jscomp$inline_5974_width$jscomp$95$$;$hint__53000__auto___54662_texture$jscomp$inline_5974_width$jscomp$95$$=$cause53874_54658_fn_53873_54657_height$jscomp$85_img$jscomp$5$$.width;
$cause53874_54658_fn_53873_54657_height$jscomp$85_img$jscomp$5$$=$cause53874_54658_fn_53873_54657_height$jscomp$85_img$jscomp$5$$.height;$offset$jscomp$150_textures$jscomp$inline_5978$$=$APP.$app$render_wasm$mem$alloc__GT_offset_32$$(48);var $heap32$$=$APP.$app$render_wasm$mem$get_heap_u32$$();$APP.$app$render_wasm$mem$heap32$write_uuid$$($offset$jscomp$150_textures$jscomp$inline_5978$$,$heap32$$,$shape_id$jscomp$47$$);$APP.$app$render_wasm$mem$heap32$write_uuid$$($offset$jscomp$150_textures$jscomp$inline_5978$$+
4,$heap32$$,$image_id$jscomp$1$$);$heap32$$[$offset$jscomp$150_textures$jscomp$inline_5978$$+8]=$APP.$cljs$core$truth_$$($thumbnail_QMARK_$jscomp$1$$)?1:0;$heap32$$[$offset$jscomp$150_textures$jscomp$inline_5978$$+9]=$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$;$heap32$$[$offset$jscomp$150_textures$jscomp$inline_5978$$+
10]=$hint__53000__auto___54662_texture$jscomp$inline_5974_width$jscomp$95$$;$heap32$$[$offset$jscomp$150_textures$jscomp$inline_5978$$+11]=$cause53874_54658_fn_53873_54657_height$jscomp$85_img$jscomp$5$$;$cause53874_54658_fn_53873_54657_height$jscomp$85_img$jscomp$5$$=$APP.$app$render_wasm$wasm$internal_module$$._store_image_from_texture;try{$cause53874_54658_fn_53873_54657_height$jscomp$85_img$jscomp$5$$()}catch($e53876$$){throw $cause53874_54658_fn_53873_54657_height$jscomp$85_img$jscomp$5$$=$e53876$$,
$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$=
$APP.$cljs$core$truth_$$($code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$)?$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$():
null,$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___54662_texture$jscomp$inline_5974_width$jscomp$95$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54662_texture$jscomp$inline_5974_width$jscomp$95$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_store_image_from_texture",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54662_texture$jscomp$inline_5974_width$jscomp$95$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54661_code_num__52998__auto___54660_current_ctx$jscomp$inline_5970_gl$jscomp$inline_5972_gl_obj$jscomp$inline_5969_gl_obj$jscomp$inline_5977_new_id$jscomp$inline_5979_read_code_fn__52997__auto___54659_temp__5825__auto__$jscomp$168$$],
null),$cause53874_54658_fn_53873_54657_height$jscomp$85_img$jscomp$5$$);}return!0}return null},$app$render_wasm$api$retrieve_image$$($url$jscomp$83$$)))}],null)};$app$render_wasm$api$get_fill_images$$=function($leaf$jscomp$1$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1632$fill_image$$,$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($leaf$jscomp$1$$))};
$app$render_wasm$api$set_shape_text_images$cljs$0core$0IFn$0_invoke$0arity$03$$=function($shape_id$jscomp$50$$,$content$jscomp$137_paragraph_set$jscomp$2_paragraphs$jscomp$4$$,$thumbnail_QMARK_$jscomp$3$$){$content$jscomp$137_paragraph_set$jscomp$2_paragraphs$jscomp$4$$=$APP.$cljs$core$first$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$137_paragraph_set$jscomp$2_paragraphs$jscomp$4$$,$APP.$cljs$cst$342$children$$));$content$jscomp$137_paragraph_set$jscomp$2_paragraphs$jscomp$4$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$137_paragraph_set$jscomp$2_paragraphs$jscomp$4$$,$APP.$cljs$cst$342$children$$);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$){$code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$=
$APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$);if($APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$)){$code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$,$APP.$cljs$cst$266$id$$);var $buffer$jscomp$inline_12237_hint__53000__auto__$jscomp$inline_12244$$=$APP.$app$common$uuid$get_u32$$($code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$);
var $fn_53880$jscomp$inline_12239$$=$APP.$app$render_wasm$wasm$internal_module$$._is_image_cached;try{var $JSCompiler_inline_result$jscomp$10821_JSCompiler_inline_result$jscomp$inline_12238_cause53881$jscomp$inline_12240$$=$fn_53880$jscomp$inline_12239$$($buffer$jscomp$inline_12237_hint__53000__auto__$jscomp$inline_12244$$[0],$buffer$jscomp$inline_12237_hint__53000__auto__$jscomp$inline_12244$$[1],$buffer$jscomp$inline_12237_hint__53000__auto__$jscomp$inline_12244$$[2],$buffer$jscomp$inline_12237_hint__53000__auto__$jscomp$inline_12244$$[3],
$thumbnail_QMARK_$jscomp$3$$)}catch($e53882$jscomp$inline_12245$$){throw $JSCompiler_inline_result$jscomp$10821_JSCompiler_inline_result$jscomp$inline_12238_cause53881$jscomp$inline_12240$$=$e53882$jscomp$inline_12245$$,$code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$)?$code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$():null,$code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$,$APP.$cljs$cst$2971$wasm_critical$$),$buffer$jscomp$inline_12237_hint__53000__auto__$jscomp$inline_12244$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($buffer$jscomp$inline_12237_hint__53000__auto__$jscomp$inline_12244$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_is_image_cached",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$buffer$jscomp$inline_12237_hint__53000__auto__$jscomp$inline_12244$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$],
null),$JSCompiler_inline_result$jscomp$10821_JSCompiler_inline_result$jscomp$inline_12238_cause53881$jscomp$inline_12240$$);}$JSCompiler_inline_result$jscomp$10821_JSCompiler_inline_result$jscomp$inline_12238_cause53881$jscomp$inline_12240$$=$JSCompiler_inline_result$jscomp$10821_JSCompiler_inline_result$jscomp$inline_12238_cause53881$jscomp$inline_12240$$===0?$app$render_wasm$api$fetch_image$$($shape_id$jscomp$50$$,$code__52999__auto__$jscomp$inline_12243_code_num__52998__auto__$jscomp$inline_12242_id$jscomp$inline_12236_p1__53886_SHARP__read_code_fn__52997__auto__$jscomp$inline_12241_temp__5825__auto__$jscomp$inline_12235$$,
$thumbnail_QMARK_$jscomp$3$$):null}else $JSCompiler_inline_result$jscomp$10821_JSCompiler_inline_result$jscomp$inline_12238_cause53881$jscomp$inline_12240$$=null;return $JSCompiler_inline_result$jscomp$10821_JSCompiler_inline_result$jscomp$inline_12238_cause53881$jscomp$inline_12240$$},$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$render_wasm$api$get_fill_images$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$342$children$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$content$jscomp$137_paragraph_set$jscomp$2_paragraphs$jscomp$4$$]))])))};
$app$render_wasm$api$set_shape_fills$$=function($shape_id$jscomp$51$$,$cause53894_cause53898_54669_fills$jscomp$19_fn_53893_image_ids$jscomp$3$$,$thumbnail_QMARK_$jscomp$4$$){if($APP.$cljs$core$empty_QMARK_$$($cause53894_cause53898_54669_fills$jscomp$19_fn_53893_image_ids$jscomp$3$$)){$cause53894_cause53898_54669_fills$jscomp$19_fn_53893_image_ids$jscomp$3$$=$APP.$app$render_wasm$wasm$internal_module$$._clear_shape_fills;try{return $cause53894_cause53898_54669_fills$jscomp$19_fn_53893_image_ids$jscomp$3$$()}catch($e53896$$){$cause53894_cause53898_54669_fills$jscomp$19_fn_53893_image_ids$jscomp$3$$=
$e53896$$;var $code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$)?$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$():null;$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$47_hint__53000__auto___54673_offset$jscomp$151$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$47_hint__53000__auto___54673_offset$jscomp$151$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_clear_shape_fills",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$47_hint__53000__auto___54673_offset$jscomp$151$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$],
null),$cause53894_cause53898_54669_fills$jscomp$19_fn_53893_image_ids$jscomp$3$$);}}else{$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$=$app$common$types$fills$coerce$$($cause53894_cause53898_54669_fills$jscomp$19_fn_53893_image_ids$jscomp$3$$);$cause53894_cause53898_54669_fills$jscomp$19_fn_53893_image_ids$jscomp$3$$=
$app$common$types$fills$get_image_ids$$($code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$);$hint__53000__auto__$jscomp$47_hint__53000__auto___54673_offset$jscomp$151$$=$APP.$app$render_wasm$mem$alloc__GT_offset_32$$($app$common$types$fills$impl$_get_byte_size$$($code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$));
$app$common$types$fills$impl$_write_to$$($code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$,$hint__53000__auto__$jscomp$47_hint__53000__auto___54673_offset$jscomp$151$$);$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$=
$APP.$app$render_wasm$wasm$internal_module$$._set_shape_fills;try{$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$()}catch($e53899$$){throw $cause53894_cause53898_54669_fills$jscomp$19_fn_53893_image_ids$jscomp$3$$=$e53899$$,$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$)?
$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$():null,$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto__$jscomp$47_hint__53000__auto___54673_offset$jscomp$151$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$47_hint__53000__auto___54673_offset$jscomp$151$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_fills",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$47_hint__53000__auto___54673_offset$jscomp$151$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$47_code__52999__auto___54672_code_num__52998__auto__$jscomp$47_code_num__52998__auto___54671_fills__$1$jscomp$6_fn_53897_54668_read_code_fn__52997__auto__$jscomp$47_read_code_fn__52997__auto___54670$$],
null),$cause53894_cause53898_54669_fills$jscomp$19_fn_53893_image_ids$jscomp$3$$);}return $APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause53910$jscomp$inline_5990_id$jscomp$329$$){var $buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$=$APP.$app$common$uuid$get_u32$$($cause53910$jscomp$inline_5990_id$jscomp$329$$);var $fn_53909$jscomp$inline_5989$$=$APP.$app$render_wasm$wasm$internal_module$$._is_image_cached;
try{var $JSCompiler_inline_result$jscomp$1038_hint__53000__auto__$jscomp$inline_5994$$=$fn_53909$jscomp$inline_5989$$($buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$[0],$buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$[1],$buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$[2],
$buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$[3],$thumbnail_QMARK_$jscomp$4$$)}catch($e53911$jscomp$inline_5995$$){throw $cause53910$jscomp$inline_5990_id$jscomp$329$$=$e53911$jscomp$inline_5995$$,$buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,
$buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$=$APP.$cljs$core$truth_$$($buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$)?$buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$.$cljs$core$IFn$_invoke$arity$0$?
$buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$.$cljs$core$IFn$_invoke$arity$0$():$buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$():null,$buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$,$APP.$cljs$cst$2971$wasm_critical$$),$JSCompiler_inline_result$jscomp$1038_hint__53000__auto__$jscomp$inline_5994$$=["WASM Error (",$APP.$app$common$data$name$$($buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1038_hint__53000__auto__$jscomp$inline_5994$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_is_image_cached",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$JSCompiler_inline_result$jscomp$1038_hint__53000__auto__$jscomp$inline_5994$$,$APP.$cljs$cst$273$code$$,$buffer$jscomp$72_code__52999__auto__$jscomp$inline_5993_code_num__52998__auto__$jscomp$inline_5992_read_code_fn__52997__auto__$jscomp$inline_5991$$],null),$cause53910$jscomp$inline_5990_id$jscomp$329$$);}return $JSCompiler_inline_result$jscomp$1038_hint__53000__auto__$jscomp$inline_5994$$===
0?$app$render_wasm$api$fetch_image$$($shape_id$jscomp$51$$,$cause53910$jscomp$inline_5990_id$jscomp$329$$,$thumbnail_QMARK_$jscomp$4$$):null},$cause53894_cause53898_54669_fills$jscomp$19_fn_53893_image_ids$jscomp$3$$)}};
$app$render_wasm$api$set_shape_strokes$$=function($shape_id$jscomp$52$$,$cause53913_54677_strokes$jscomp$5$$,$thumbnail_QMARK_$jscomp$5$$){var $code__52999__auto___54680_code_num__52998__auto___54679_fn_53912_54676_read_code_fn__52997__auto___54678$$=$APP.$app$render_wasm$wasm$internal_module$$._clear_shape_strokes;try{$code__52999__auto___54680_code_num__52998__auto___54679_fn_53912_54676_read_code_fn__52997__auto___54678$$()}catch($e53914$$){$cause53913_54677_strokes$jscomp$5$$=$e53914$$;$code__52999__auto___54680_code_num__52998__auto___54679_fn_53912_54676_read_code_fn__52997__auto___54678$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___54680_code_num__52998__auto___54679_fn_53912_54676_read_code_fn__52997__auto___54678$$=$APP.$cljs$core$truth_$$($code__52999__auto___54680_code_num__52998__auto___54679_fn_53912_54676_read_code_fn__52997__auto___54678$$)?$code__52999__auto___54680_code_num__52998__auto___54679_fn_53912_54676_read_code_fn__52997__auto___54678$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___54680_code_num__52998__auto___54679_fn_53912_54676_read_code_fn__52997__auto___54678$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto___54680_code_num__52998__auto___54679_fn_53912_54676_read_code_fn__52997__auto___54678$$():null;$code__52999__auto___54680_code_num__52998__auto___54679_fn_53912_54676_read_code_fn__52997__auto___54678$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54680_code_num__52998__auto___54679_fn_53912_54676_read_code_fn__52997__auto___54678$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto___54681$$=["WASM Error (",
$APP.$app$common$data$name$$($code__52999__auto___54680_code_num__52998__auto___54679_fn_53912_54676_read_code_fn__52997__auto___54678$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54681$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_clear_shape_strokes",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54681$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54680_code_num__52998__auto___54679_fn_53912_54676_read_code_fn__52997__auto___54678$$],
null),$cause53913_54677_strokes$jscomp$5$$);}return $APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($stroke$jscomp$12$$){if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$12$$)))return null;var $cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$=function(){var $or__5025__auto__$jscomp$594$$=$APP.$cljs$cst$1740$stroke_opacity$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$12$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$594$$)?$or__5025__auto__$jscomp$594$$:1}(),$color$jscomp$48_image_id$jscomp$2$$=$APP.$cljs$cst$1739$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$12$$),$cached_image_QMARK_$jscomp$2_gradient$jscomp$17$$=$APP.$cljs$cst$1741$stroke_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$12$$),$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$cljs$cst$1635$stroke_image$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$12$$),$width$jscomp$96$$=$APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$12$$),$align_fn_53916_54688_fn_53921_54698_fn_53924_54706$$=$APP.$cljs$cst$1868$stroke_alignment$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$12$$),$style$jscomp$35$$=$app$render_wasm$serializers$translate_stroke_style$$($APP.$cljs$cst$1866$stroke_style$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$12$$)),
$cap_start$jscomp$1$$=$app$render_wasm$serializers$translate_stroke_cap$$($APP.$cljs$cst$1865$stroke_cap_start$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$12$$)),$cap_end$jscomp$1$$=$app$render_wasm$serializers$translate_stroke_cap$$($APP.$cljs$cst$1869$stroke_cap_end$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$12$$)),$hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$=
$APP.$app$render_wasm$mem$alloc$$(160),$dview$jscomp$6$$=new DataView($APP.$app$render_wasm$mem$get_heap_u8$$().buffer);switch($align_fn_53916_54688_fn_53921_54698_fn_53924_54706$$ instanceof $APP.$cljs$core$Keyword$$?$align_fn_53916_54688_fn_53921_54698_fn_53924_54706$$.$fqn$:null){case "inner":$align_fn_53916_54688_fn_53921_54698_fn_53924_54706$$=$APP.$app$render_wasm$wasm$internal_module$$._add_shape_inner_stroke;try{$align_fn_53916_54688_fn_53921_54698_fn_53924_54706$$($width$jscomp$96$$,$style$jscomp$35$$,
$cap_start$jscomp$1$$,$cap_end$jscomp$1$$)}catch($e53918$$){throw $cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$=$e53918$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$cljs$core$truth_$$($code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$)?
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$():
null,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_add_shape_inner_stroke",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$],
null),$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$);}break;case "outer":$align_fn_53916_54688_fn_53921_54698_fn_53924_54706$$=$APP.$app$render_wasm$wasm$internal_module$$._add_shape_outer_stroke;try{$align_fn_53916_54688_fn_53921_54698_fn_53924_54706$$($width$jscomp$96$$,$style$jscomp$35$$,$cap_start$jscomp$1$$,$cap_end$jscomp$1$$)}catch($e53923$$){throw $cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$=
$e53923$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$cljs$core$truth_$$($code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$)?
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$():
null,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_add_shape_outer_stroke",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$],
null),$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$);}break;default:$align_fn_53916_54688_fn_53921_54698_fn_53924_54706$$=$APP.$app$render_wasm$wasm$internal_module$$._add_shape_center_stroke;try{$align_fn_53916_54688_fn_53921_54698_fn_53924_54706$$($width$jscomp$96$$,$style$jscomp$35$$,$cap_start$jscomp$1$$,$cap_end$jscomp$1$$)}catch($e53926$$){throw $cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$=
$e53926$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$cljs$core$truth_$$($code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$)?
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$():
null,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_add_shape_center_stroke",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$],
null),$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$);}}if($cached_image_QMARK_$jscomp$2_gradient$jscomp$17$$!=null){$app$common$types$fills$impl$write_gradient_fill$$($hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,$dview$jscomp$6$$,$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$,
$cached_image_QMARK_$jscomp$2_gradient$jscomp$17$$);$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$=$APP.$app$render_wasm$wasm$internal_module$$._add_shape_stroke_fill;try{$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$()}catch($e53929$$){throw $cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$=
$e53929$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$cljs$core$truth_$$($code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$)?
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$():
null,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_add_shape_stroke_fill",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$],
null),$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$);}return null}if($code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$!=
null){$color$jscomp$48_image_id$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$,
$APP.$cljs$cst$266$id$$);var $buffer$jscomp$73$$=$APP.$app$common$uuid$get_u32$$($color$jscomp$48_image_id$jscomp$2$$);$cached_image_QMARK_$jscomp$2_gradient$jscomp$17$$=function(){var $cause53933_fn_53932$$=$APP.$app$render_wasm$wasm$internal_module$$._is_image_cached;try{return $cause53933_fn_53932$$($buffer$jscomp$73$$[0],$buffer$jscomp$73$$[1],$buffer$jscomp$73$$[2],$buffer$jscomp$73$$[3],$thumbnail_QMARK_$jscomp$5$$)}catch($e53934$$){$cause53933_fn_53932$$=$e53934$$;var $code__52999__auto__$jscomp$49_code_num__52998__auto__$jscomp$49_read_code_fn__52997__auto__$jscomp$49$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$49_code_num__52998__auto__$jscomp$49_read_code_fn__52997__auto__$jscomp$49$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$49_code_num__52998__auto__$jscomp$49_read_code_fn__52997__auto__$jscomp$49$$)?$code__52999__auto__$jscomp$49_code_num__52998__auto__$jscomp$49_read_code_fn__52997__auto__$jscomp$49$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$49_code_num__52998__auto__$jscomp$49_read_code_fn__52997__auto__$jscomp$49$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$49_code_num__52998__auto__$jscomp$49_read_code_fn__52997__auto__$jscomp$49$$():null;$code__52999__auto__$jscomp$49_code_num__52998__auto__$jscomp$49_read_code_fn__52997__auto__$jscomp$49$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$49_code_num__52998__auto__$jscomp$49_read_code_fn__52997__auto__$jscomp$49$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$49$$=["WASM Error (",
$APP.$app$common$data$name$$($code__52999__auto__$jscomp$49_code_num__52998__auto__$jscomp$49_read_code_fn__52997__auto__$jscomp$49$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$49$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_is_image_cached",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$49$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$49_code_num__52998__auto__$jscomp$49_read_code_fn__52997__auto__$jscomp$49$$],
null),$cause53933_fn_53932$$);}}();$app$common$types$fills$impl$write_image_fill$$($hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,$dview$jscomp$6$$,$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$);
$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$=$APP.$app$render_wasm$wasm$internal_module$$._add_shape_stroke_fill;try{$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$()}catch($e53937$$){throw $cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$=
$e53937$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$cljs$core$truth_$$($code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$)?
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$():
null,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_add_shape_stroke_fill",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$],
null),$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$);}return $cached_image_QMARK_$jscomp$2_gradient$jscomp$17$$===0?$app$render_wasm$api$fetch_image$$($shape_id$jscomp$52$$,$color$jscomp$48_image_id$jscomp$2$$,$thumbnail_QMARK_$jscomp$5$$):null}if($color$jscomp$48_image_id$jscomp$2$$!=null){$app$common$types$fills$impl$write_solid_fill$$($hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,
$dview$jscomp$6$$,$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$,$color$jscomp$48_image_id$jscomp$2$$);$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$=$APP.$app$render_wasm$wasm$internal_module$$._add_shape_stroke_fill;try{$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$()}catch($e53940$$){throw $cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$=
$e53940$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$cljs$core$truth_$$($code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$)?
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$():
null,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_add_shape_stroke_fill",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54693_hint__53000__auto___54703_hint__53000__auto___54711_hint__53000__auto___54719_hint__53000__auto___54729_hint__53000__auto___54738_offset$jscomp$152$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto___54692_code__52999__auto___54702_code__52999__auto___54710_code__52999__auto___54718_code__52999__auto___54728_code__52999__auto___54737_code_num__52998__auto___54691_code_num__52998__auto___54701_code_num__52998__auto___54709_code_num__52998__auto___54717_code_num__52998__auto___54727_code_num__52998__auto___54736_image$jscomp$20_read_code_fn__52997__auto___54690_read_code_fn__52997__auto___54700_read_code_fn__52997__auto___54708_read_code_fn__52997__auto___54716_read_code_fn__52997__auto___54726_read_code_fn__52997__auto___54735$$],
null),$cause53917_54689_cause53922_54699_cause53925_54707_cause53928_54715_cause53936_54725_cause53939_54734_fn_53927_54714_fn_53935_54724_fn_53938_54733_opacity$jscomp$23$$);}}return null},$cause53913_54677_strokes$jscomp$5$$)};
$app$render_wasm$api$set_shape_svg_attrs$$=function($attrs$jscomp$58$$){var $style$jscomp$36$$=$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$58$$),$cause53947_fill_rule$jscomp$1$$=$app$render_wasm$serializers$translate_fill_rule$$(function(){var $or__5025__auto__$jscomp$595$$=$cljs$cst$3087$fillRule$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$36$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$595$$)?$or__5025__auto__$jscomp$595$$:$cljs$cst$3087$fillRule$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$58$$)}()),
$code__52999__auto__$jscomp$50_code_num__52998__auto__$jscomp$50_read_code_fn__52997__auto__$jscomp$50_stroke_linecap$jscomp$1$$=$app$render_wasm$serializers$translate_stroke_linecap$$(function(){var $or__5025__auto__$jscomp$596$$=$cljs$cst$3088$strokeLinecap$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$36$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$596$$)?$or__5025__auto__$jscomp$596$$:$cljs$cst$3088$strokeLinecap$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$58$$)}()),$hint__53000__auto__$jscomp$50_stroke_linejoin$jscomp$1$$=
$app$render_wasm$serializers$translate_stroke_linejoin$$(function(){var $or__5025__auto__$jscomp$597$$=$cljs$cst$3089$strokeLinejoin$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$36$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$597$$)?$or__5025__auto__$jscomp$597$$:$cljs$cst$3089$strokeLinejoin$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$58$$)}()),$fill_none$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("none",function(){var $or__5025__auto__$jscomp$598$$=$APP.$cljs$cst$1403$fill$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$36$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$598$$)?$or__5025__auto__$jscomp$598$$:$APP.$cljs$cst$1403$fill$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$58$$)}()),$fn_53946$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_svg_attrs;try{$fn_53946$$($cause53947_fill_rule$jscomp$1$$,$code__52999__auto__$jscomp$50_code_num__52998__auto__$jscomp$50_read_code_fn__52997__auto__$jscomp$50_stroke_linecap$jscomp$1$$,$hint__53000__auto__$jscomp$50_stroke_linejoin$jscomp$1$$,$fill_none$$)}catch($e53948$$){throw $cause53947_fill_rule$jscomp$1$$=
$e53948$$,$code__52999__auto__$jscomp$50_code_num__52998__auto__$jscomp$50_read_code_fn__52997__auto__$jscomp$50_stroke_linecap$jscomp$1$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$50_code_num__52998__auto__$jscomp$50_read_code_fn__52997__auto__$jscomp$50_stroke_linecap$jscomp$1$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$50_code_num__52998__auto__$jscomp$50_read_code_fn__52997__auto__$jscomp$50_stroke_linecap$jscomp$1$$)?$code__52999__auto__$jscomp$50_code_num__52998__auto__$jscomp$50_read_code_fn__52997__auto__$jscomp$50_stroke_linecap$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$50_code_num__52998__auto__$jscomp$50_read_code_fn__52997__auto__$jscomp$50_stroke_linecap$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$50_code_num__52998__auto__$jscomp$50_read_code_fn__52997__auto__$jscomp$50_stroke_linecap$jscomp$1$$():null,$code__52999__auto__$jscomp$50_code_num__52998__auto__$jscomp$50_read_code_fn__52997__auto__$jscomp$50_stroke_linecap$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code__52999__auto__$jscomp$50_code_num__52998__auto__$jscomp$50_read_code_fn__52997__auto__$jscomp$50_stroke_linecap$jscomp$1$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto__$jscomp$50_stroke_linejoin$jscomp$1$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$50_code_num__52998__auto__$jscomp$50_read_code_fn__52997__auto__$jscomp$50_stroke_linecap$jscomp$1$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$50_stroke_linejoin$jscomp$1$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_svg_attrs",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$50_stroke_linejoin$jscomp$1$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$50_code_num__52998__auto__$jscomp$50_read_code_fn__52997__auto__$jscomp$50_stroke_linecap$jscomp$1$$],null),$cause53947_fill_rule$jscomp$1$$);}};
$app$render_wasm$api$set_shape_path_content$$=function($content$jscomp$138_fn_53950_54741_heapu32_54749$$){var $cause53951_54742_cause53959_54758_cause53962_chunk_size_fn_53961$$=$APP.$cljs$core$quot$$(262144,4),$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$=
$app$common$types$path$impl$_get_byte_size$$($content$jscomp$138_fn_53950_54741_heapu32_54749$$);$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$=4*$APP.$app$common$math$ceil$$($buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$/
4);var $buffer$jscomp$74_hint__53000__auto__$jscomp$51_hint__53000__auto___54746_hint__53000__auto___54762$$=new Uint8Array($buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$);$app$common$types$path$impl$_write_to$$($content$jscomp$138_fn_53950_54741_heapu32_54749$$,
$buffer$jscomp$74_hint__53000__auto__$jscomp$51_hint__53000__auto___54746_hint__53000__auto___54762$$.buffer);$content$jscomp$138_fn_53950_54741_heapu32_54749$$=$APP.$app$render_wasm$wasm$internal_module$$._start_shape_path_buffer;try{$content$jscomp$138_fn_53950_54741_heapu32_54749$$()}catch($e53952$$){throw $cause53951_54742_cause53959_54758_cause53962_chunk_size_fn_53961$$=$e53952$$,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$=$APP.$cljs$core$truth_$$($buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$)?
$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$.$cljs$core$IFn$_invoke$arity$0$?$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$.$cljs$core$IFn$_invoke$arity$0$():
$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$():null,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$,$APP.$cljs$cst$2971$wasm_critical$$),$buffer$jscomp$74_hint__53000__auto__$jscomp$51_hint__53000__auto___54746_hint__53000__auto___54762$$=
["WASM Error (",$APP.$app$common$data$name$$($buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($buffer$jscomp$74_hint__53000__auto__$jscomp$51_hint__53000__auto___54746_hint__53000__auto___54762$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_start_shape_path_buffer",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$buffer$jscomp$74_hint__53000__auto__$jscomp$51_hint__53000__auto___54746_hint__53000__auto___54762$$,$APP.$cljs$cst$273$code$$,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$],
null),$cause53951_54742_cause53959_54758_cause53962_chunk_size_fn_53961$$);}$content$jscomp$138_fn_53950_54741_heapu32_54749$$=$APP.$app$render_wasm$mem$get_heap_u32$$();for(var $chunk_54752_chunk_u32_54753_fn_53958_54756_offset_54750$$=0;;)if($chunk_54752_chunk_u32_54753_fn_53958_54756_offset_54750$$<$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$){var $end_54751_y__5114__auto__$jscomp$inline_5997$$=
$chunk_54752_chunk_u32_54753_fn_53958_54756_offset_54750$$+$cause53951_54742_cause53959_54758_cause53962_chunk_size_fn_53961$$*4;$end_54751_y__5114__auto__$jscomp$inline_5997$$=$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$<$end_54751_y__5114__auto__$jscomp$inline_5997$$?
$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$:$end_54751_y__5114__auto__$jscomp$inline_5997$$;$chunk_54752_chunk_u32_54753_fn_53958_54756_offset_54750$$=$buffer$jscomp$74_hint__53000__auto__$jscomp$51_hint__53000__auto___54746_hint__53000__auto___54762$$.subarray($chunk_54752_chunk_u32_54753_fn_53958_54756_offset_54750$$,
$end_54751_y__5114__auto__$jscomp$inline_5997$$);$chunk_54752_chunk_u32_54753_fn_53958_54756_offset_54750$$=new Uint32Array($chunk_54752_chunk_u32_54753_fn_53958_54756_offset_54750$$.buffer,$chunk_54752_chunk_u32_54753_fn_53958_54756_offset_54750$$.byteOffset,$APP.$cljs$core$quot$$($chunk_54752_chunk_u32_54753_fn_53958_54756_offset_54750$$.length,4));var $heap_offset_54755$$=$APP.$app$render_wasm$mem$alloc__GT_offset_32$$(4*$chunk_54752_chunk_u32_54753_fn_53958_54756_offset_54750$$.length);$content$jscomp$138_fn_53950_54741_heapu32_54749$$.set($chunk_54752_chunk_u32_54753_fn_53958_54756_offset_54750$$,
$heap_offset_54755$$);$chunk_54752_chunk_u32_54753_fn_53958_54756_offset_54750$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_path_chunk_buffer;try{$chunk_54752_chunk_u32_54753_fn_53958_54756_offset_54750$$()}catch($e53960$$){throw $cause53951_54742_cause53959_54758_cause53962_chunk_size_fn_53961$$=$e53960$$,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$=$APP.$cljs$core$truth_$$($buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$)?
$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$.$cljs$core$IFn$_invoke$arity$0$?$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$.$cljs$core$IFn$_invoke$arity$0$():
$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$():null,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$,$APP.$cljs$cst$2971$wasm_critical$$),$buffer$jscomp$74_hint__53000__auto__$jscomp$51_hint__53000__auto___54746_hint__53000__auto___54762$$=
["WASM Error (",$APP.$app$common$data$name$$($buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($buffer$jscomp$74_hint__53000__auto__$jscomp$51_hint__53000__auto___54746_hint__53000__auto___54762$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_path_chunk_buffer",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$buffer$jscomp$74_hint__53000__auto__$jscomp$51_hint__53000__auto___54746_hint__53000__auto___54762$$,$APP.$cljs$cst$273$code$$,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$],
null),$cause53951_54742_cause53959_54758_cause53962_chunk_size_fn_53961$$);}$chunk_54752_chunk_u32_54753_fn_53958_54756_offset_54750$$=$end_54751_y__5114__auto__$jscomp$inline_5997$$}else break;$cause53951_54742_cause53959_54758_cause53962_chunk_size_fn_53961$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_path_buffer;try{return $cause53951_54742_cause53959_54758_cause53962_chunk_size_fn_53961$$()}catch($e53963$$){throw $cause53951_54742_cause53959_54758_cause53962_chunk_size_fn_53961$$=
$e53963$$,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$=
$APP.$cljs$core$truth_$$($buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$)?$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$.$cljs$core$IFn$_invoke$arity$0$?
$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$.$cljs$core$IFn$_invoke$arity$0$():$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$():
null,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$,
$APP.$cljs$cst$2971$wasm_critical$$),$buffer$jscomp$74_hint__53000__auto__$jscomp$51_hint__53000__auto___54746_hint__53000__auto___54762$$=["WASM Error (",$APP.$app$common$data$name$$($buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$),")"].join(""),
$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($buffer$jscomp$74_hint__53000__auto__$jscomp$51_hint__53000__auto___54746_hint__53000__auto___54762$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_path_buffer",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$buffer$jscomp$74_hint__53000__auto__$jscomp$51_hint__53000__auto___54746_hint__53000__auto___54762$$,$APP.$cljs$cst$273$code$$,$buffer_size_code__52999__auto__$jscomp$51_code__52999__auto___54745_code__52999__auto___54761_code_num__52998__auto__$jscomp$51_code_num__52998__auto___54744_code_num__52998__auto___54760_padded_size_read_code_fn__52997__auto__$jscomp$51_read_code_fn__52997__auto___54743_read_code_fn__52997__auto___54759$$],
null),$cause53951_54742_cause53959_54758_cause53962_chunk_size_fn_53961$$);}};
$app$render_wasm$api$set_shape_svg_raw_content$$=function($cause53965_54770_cause53968_content$jscomp$139_fn_53967$$){var $code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$=$APP.$cljs$core$count$$($cause53965_54770_cause53968_content$jscomp$139_fn_53967$$)+1,$hint__53000__auto__$jscomp$52_hint__53000__auto___54774_offset$jscomp$153$$=$APP.$app$render_wasm$mem$alloc$$($code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$),
$fn_53964_54767$$=$APP.$app$render_wasm$wasm$internal_module$$.stringToUTF8;try{$fn_53964_54767$$($cause53965_54770_cause53968_content$jscomp$139_fn_53967$$,$hint__53000__auto__$jscomp$52_hint__53000__auto___54774_offset$jscomp$153$$,$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$)}catch($e53966$$){throw $cause53965_54770_cause53968_content$jscomp$139_fn_53967$$=
$e53966$$,$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$)?
$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$():
null,$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto__$jscomp$52_hint__53000__auto___54774_offset$jscomp$153$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$52_hint__53000__auto___54774_offset$jscomp$153$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"stringToUTF8",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$52_hint__53000__auto___54774_offset$jscomp$153$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$],null),$cause53965_54770_cause53968_content$jscomp$139_fn_53967$$);
}$cause53965_54770_cause53968_content$jscomp$139_fn_53967$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_svg_raw_content;try{return $cause53965_54770_cause53968_content$jscomp$139_fn_53967$$()}catch($e53969$$){throw $cause53965_54770_cause53968_content$jscomp$139_fn_53967$$=$e53969$$,$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$)?
$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$():
null,$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto__$jscomp$52_hint__53000__auto___54774_offset$jscomp$153$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$52_hint__53000__auto___54774_offset$jscomp$153$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_svg_raw_content",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$52_hint__53000__auto___54774_offset$jscomp$153$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$52_code__52999__auto___54773_code_num__52998__auto__$jscomp$52_code_num__52998__auto___54772_read_code_fn__52997__auto__$jscomp$52_read_code_fn__52997__auto___54771_size$jscomp$108$$],
null),$cause53965_54770_cause53968_content$jscomp$139_fn_53967$$);}};
$APP.$app$render_wasm$api$set_shape_blend_mode$$=function($blend_mode$jscomp$2_cause53971$$){var $code__52999__auto__$jscomp$53_code_num__52998__auto__$jscomp$53_fn_53970_read_code_fn__52997__auto__$jscomp$53$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_blend_mode;try{return $code__52999__auto__$jscomp$53_code_num__52998__auto__$jscomp$53_fn_53970_read_code_fn__52997__auto__$jscomp$53$$($app$render_wasm$serializers$translate_blend_mode$$($blend_mode$jscomp$2_cause53971$$))}catch($e53972$$){$blend_mode$jscomp$2_cause53971$$=$e53972$$;
$code__52999__auto__$jscomp$53_code_num__52998__auto__$jscomp$53_fn_53970_read_code_fn__52997__auto__$jscomp$53$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$53_code_num__52998__auto__$jscomp$53_fn_53970_read_code_fn__52997__auto__$jscomp$53$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$53_code_num__52998__auto__$jscomp$53_fn_53970_read_code_fn__52997__auto__$jscomp$53$$)?$code__52999__auto__$jscomp$53_code_num__52998__auto__$jscomp$53_fn_53970_read_code_fn__52997__auto__$jscomp$53$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$53_code_num__52998__auto__$jscomp$53_fn_53970_read_code_fn__52997__auto__$jscomp$53$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$53_code_num__52998__auto__$jscomp$53_fn_53970_read_code_fn__52997__auto__$jscomp$53$$():null;$code__52999__auto__$jscomp$53_code_num__52998__auto__$jscomp$53_fn_53970_read_code_fn__52997__auto__$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$53_code_num__52998__auto__$jscomp$53_fn_53970_read_code_fn__52997__auto__$jscomp$53$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$53$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$53_code_num__52998__auto__$jscomp$53_fn_53970_read_code_fn__52997__auto__$jscomp$53$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$53$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_blend_mode",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$53$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$53_code_num__52998__auto__$jscomp$53_fn_53970_read_code_fn__52997__auto__$jscomp$53$$],null),$blend_mode$jscomp$2_cause53971$$);}};
$app$render_wasm$api$set_shape_vertical_align$$=function($cause53974_vertical_align$jscomp$3$$){var $code__52999__auto__$jscomp$54_code_num__52998__auto__$jscomp$54_fn_53973_read_code_fn__52997__auto__$jscomp$54$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_vertical_align;try{var $values$jscomp$inline_6000$$=$app$render_wasm$wasm$serializers$$["vertical-align"],$default$$jscomp$inline_6001$$=$values$jscomp$inline_6000$$.top;var $JSCompiler_inline_result$jscomp$998_hint__53000__auto__$jscomp$54$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$inline_6000$$[$APP.$app$common$data$name$$($cause53974_vertical_align$jscomp$3$$)],$default$$jscomp$inline_6001$$);return $code__52999__auto__$jscomp$54_code_num__52998__auto__$jscomp$54_fn_53973_read_code_fn__52997__auto__$jscomp$54$$($JSCompiler_inline_result$jscomp$998_hint__53000__auto__$jscomp$54$$)}catch($e53975$$){throw $cause53974_vertical_align$jscomp$3$$=$e53975$$,$code__52999__auto__$jscomp$54_code_num__52998__auto__$jscomp$54_fn_53973_read_code_fn__52997__auto__$jscomp$54$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$54_code_num__52998__auto__$jscomp$54_fn_53973_read_code_fn__52997__auto__$jscomp$54$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$54_code_num__52998__auto__$jscomp$54_fn_53973_read_code_fn__52997__auto__$jscomp$54$$)?$code__52999__auto__$jscomp$54_code_num__52998__auto__$jscomp$54_fn_53973_read_code_fn__52997__auto__$jscomp$54$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$54_code_num__52998__auto__$jscomp$54_fn_53973_read_code_fn__52997__auto__$jscomp$54$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$54_code_num__52998__auto__$jscomp$54_fn_53973_read_code_fn__52997__auto__$jscomp$54$$():null,$code__52999__auto__$jscomp$54_code_num__52998__auto__$jscomp$54_fn_53973_read_code_fn__52997__auto__$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$54_code_num__52998__auto__$jscomp$54_fn_53973_read_code_fn__52997__auto__$jscomp$54$$,$APP.$cljs$cst$2971$wasm_critical$$),$JSCompiler_inline_result$jscomp$998_hint__53000__auto__$jscomp$54$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$54_code_num__52998__auto__$jscomp$54_fn_53973_read_code_fn__52997__auto__$jscomp$54$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$998_hint__53000__auto__$jscomp$54$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_vertical_align",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$JSCompiler_inline_result$jscomp$998_hint__53000__auto__$jscomp$54$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$54_code_num__52998__auto__$jscomp$54_fn_53973_read_code_fn__52997__auto__$jscomp$54$$],null),$cause53974_vertical_align$jscomp$3$$);}};
$app$render_wasm$api$set_shape_opacity$$=function($cause53978_opacity$jscomp$24$$){var $code__52999__auto__$jscomp$55_code_num__52998__auto__$jscomp$55_fn_53977_read_code_fn__52997__auto__$jscomp$55$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_opacity;try{return $code__52999__auto__$jscomp$55_code_num__52998__auto__$jscomp$55_fn_53977_read_code_fn__52997__auto__$jscomp$55$$($APP.$cljs$core$truth_$$($cause53978_opacity$jscomp$24$$)?$cause53978_opacity$jscomp$24$$:1)}catch($e53979$$){$cause53978_opacity$jscomp$24$$=
$e53979$$;$code__52999__auto__$jscomp$55_code_num__52998__auto__$jscomp$55_fn_53977_read_code_fn__52997__auto__$jscomp$55$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$55_code_num__52998__auto__$jscomp$55_fn_53977_read_code_fn__52997__auto__$jscomp$55$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$55_code_num__52998__auto__$jscomp$55_fn_53977_read_code_fn__52997__auto__$jscomp$55$$)?$code__52999__auto__$jscomp$55_code_num__52998__auto__$jscomp$55_fn_53977_read_code_fn__52997__auto__$jscomp$55$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$55_code_num__52998__auto__$jscomp$55_fn_53977_read_code_fn__52997__auto__$jscomp$55$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$55_code_num__52998__auto__$jscomp$55_fn_53977_read_code_fn__52997__auto__$jscomp$55$$():null;$code__52999__auto__$jscomp$55_code_num__52998__auto__$jscomp$55_fn_53977_read_code_fn__52997__auto__$jscomp$55$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$55_code_num__52998__auto__$jscomp$55_fn_53977_read_code_fn__52997__auto__$jscomp$55$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$55$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$55_code_num__52998__auto__$jscomp$55_fn_53977_read_code_fn__52997__auto__$jscomp$55$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$55$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_opacity",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$55$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$55_code_num__52998__auto__$jscomp$55_fn_53977_read_code_fn__52997__auto__$jscomp$55$$],null),$cause53978_opacity$jscomp$24$$);}};
$app$render_wasm$api$set_constraints_h$$=function($cause53983_constraint$jscomp$1$$){if($APP.$cljs$core$truth_$$($cause53983_constraint$jscomp$1$$)){var $code__52999__auto__$jscomp$56_code_num__52998__auto__$jscomp$56_fn_53982_read_code_fn__52997__auto__$jscomp$56$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_constraint_h;try{return $code__52999__auto__$jscomp$56_code_num__52998__auto__$jscomp$56_fn_53982_read_code_fn__52997__auto__$jscomp$56$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($app$render_wasm$wasm$serializers$$["constraint-h"][$APP.$app$common$data$name$$($cause53983_constraint$jscomp$1$$)],
5))}catch($e53984$$){$cause53983_constraint$jscomp$1$$=$e53984$$;$code__52999__auto__$jscomp$56_code_num__52998__auto__$jscomp$56_fn_53982_read_code_fn__52997__auto__$jscomp$56$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$56_code_num__52998__auto__$jscomp$56_fn_53982_read_code_fn__52997__auto__$jscomp$56$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$56_code_num__52998__auto__$jscomp$56_fn_53982_read_code_fn__52997__auto__$jscomp$56$$)?$code__52999__auto__$jscomp$56_code_num__52998__auto__$jscomp$56_fn_53982_read_code_fn__52997__auto__$jscomp$56$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$56_code_num__52998__auto__$jscomp$56_fn_53982_read_code_fn__52997__auto__$jscomp$56$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$56_code_num__52998__auto__$jscomp$56_fn_53982_read_code_fn__52997__auto__$jscomp$56$$():null;$code__52999__auto__$jscomp$56_code_num__52998__auto__$jscomp$56_fn_53982_read_code_fn__52997__auto__$jscomp$56$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$56_code_num__52998__auto__$jscomp$56_fn_53982_read_code_fn__52997__auto__$jscomp$56$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$56$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$56_code_num__52998__auto__$jscomp$56_fn_53982_read_code_fn__52997__auto__$jscomp$56$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$56$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_constraint_h",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$56$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$56_code_num__52998__auto__$jscomp$56_fn_53982_read_code_fn__52997__auto__$jscomp$56$$],null),$cause53983_constraint$jscomp$1$$);}}else return null};
$app$render_wasm$api$set_constraints_v$$=function($cause53987_constraint$jscomp$2$$){if($APP.$cljs$core$truth_$$($cause53987_constraint$jscomp$2$$)){var $code__52999__auto__$jscomp$57_code_num__52998__auto__$jscomp$57_fn_53986_read_code_fn__52997__auto__$jscomp$57$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_constraint_v;try{return $code__52999__auto__$jscomp$57_code_num__52998__auto__$jscomp$57_fn_53986_read_code_fn__52997__auto__$jscomp$57$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($app$render_wasm$wasm$serializers$$["constraint-v"][$APP.$app$common$data$name$$($cause53987_constraint$jscomp$2$$)],
5))}catch($e53988$$){$cause53987_constraint$jscomp$2$$=$e53988$$;$code__52999__auto__$jscomp$57_code_num__52998__auto__$jscomp$57_fn_53986_read_code_fn__52997__auto__$jscomp$57$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$57_code_num__52998__auto__$jscomp$57_fn_53986_read_code_fn__52997__auto__$jscomp$57$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$57_code_num__52998__auto__$jscomp$57_fn_53986_read_code_fn__52997__auto__$jscomp$57$$)?$code__52999__auto__$jscomp$57_code_num__52998__auto__$jscomp$57_fn_53986_read_code_fn__52997__auto__$jscomp$57$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$57_code_num__52998__auto__$jscomp$57_fn_53986_read_code_fn__52997__auto__$jscomp$57$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$57_code_num__52998__auto__$jscomp$57_fn_53986_read_code_fn__52997__auto__$jscomp$57$$():null;$code__52999__auto__$jscomp$57_code_num__52998__auto__$jscomp$57_fn_53986_read_code_fn__52997__auto__$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$57_code_num__52998__auto__$jscomp$57_fn_53986_read_code_fn__52997__auto__$jscomp$57$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$57$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$57_code_num__52998__auto__$jscomp$57_fn_53986_read_code_fn__52997__auto__$jscomp$57$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$57$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_constraint_v",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$57$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$57_code_num__52998__auto__$jscomp$57_fn_53986_read_code_fn__52997__auto__$jscomp$57$$],null),$cause53987_constraint$jscomp$2$$);}}else return null};
$app$render_wasm$api$set_shape_hidden$$=function($cause53993_hidden$jscomp$3$$){var $code__52999__auto__$jscomp$58_code_num__52998__auto__$jscomp$58_fn_53992_read_code_fn__52997__auto__$jscomp$58$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_hidden;try{return $code__52999__auto__$jscomp$58_code_num__52998__auto__$jscomp$58_fn_53992_read_code_fn__52997__auto__$jscomp$58$$($cause53993_hidden$jscomp$3$$)}catch($e53994$$){$cause53993_hidden$jscomp$3$$=$e53994$$;$code__52999__auto__$jscomp$58_code_num__52998__auto__$jscomp$58_fn_53992_read_code_fn__52997__auto__$jscomp$58$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$58_code_num__52998__auto__$jscomp$58_fn_53992_read_code_fn__52997__auto__$jscomp$58$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$58_code_num__52998__auto__$jscomp$58_fn_53992_read_code_fn__52997__auto__$jscomp$58$$)?$code__52999__auto__$jscomp$58_code_num__52998__auto__$jscomp$58_fn_53992_read_code_fn__52997__auto__$jscomp$58$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$58_code_num__52998__auto__$jscomp$58_fn_53992_read_code_fn__52997__auto__$jscomp$58$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$58_code_num__52998__auto__$jscomp$58_fn_53992_read_code_fn__52997__auto__$jscomp$58$$():null;$code__52999__auto__$jscomp$58_code_num__52998__auto__$jscomp$58_fn_53992_read_code_fn__52997__auto__$jscomp$58$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$58_code_num__52998__auto__$jscomp$58_fn_53992_read_code_fn__52997__auto__$jscomp$58$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$58$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$58_code_num__52998__auto__$jscomp$58_fn_53992_read_code_fn__52997__auto__$jscomp$58$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$58$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_hidden",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$58$$,$APP.$cljs$cst$273$code$$,
$code__52999__auto__$jscomp$58_code_num__52998__auto__$jscomp$58_fn_53992_read_code_fn__52997__auto__$jscomp$58$$],null),$cause53993_hidden$jscomp$3$$);}};
$app$render_wasm$api$set_shape_bool_type$$=function($bool_type$jscomp$4_cause53996$$){var $code__52999__auto__$jscomp$59_code_num__52998__auto__$jscomp$59_fn_53995_read_code_fn__52997__auto__$jscomp$59$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_bool_type;try{return $code__52999__auto__$jscomp$59_code_num__52998__auto__$jscomp$59_fn_53995_read_code_fn__52997__auto__$jscomp$59$$($app$render_wasm$serializers$translate_bool_type$$($bool_type$jscomp$4_cause53996$$))}catch($e53997$$){$bool_type$jscomp$4_cause53996$$=$e53997$$;
$code__52999__auto__$jscomp$59_code_num__52998__auto__$jscomp$59_fn_53995_read_code_fn__52997__auto__$jscomp$59$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$59_code_num__52998__auto__$jscomp$59_fn_53995_read_code_fn__52997__auto__$jscomp$59$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$59_code_num__52998__auto__$jscomp$59_fn_53995_read_code_fn__52997__auto__$jscomp$59$$)?$code__52999__auto__$jscomp$59_code_num__52998__auto__$jscomp$59_fn_53995_read_code_fn__52997__auto__$jscomp$59$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$59_code_num__52998__auto__$jscomp$59_fn_53995_read_code_fn__52997__auto__$jscomp$59$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$59_code_num__52998__auto__$jscomp$59_fn_53995_read_code_fn__52997__auto__$jscomp$59$$():null;$code__52999__auto__$jscomp$59_code_num__52998__auto__$jscomp$59_fn_53995_read_code_fn__52997__auto__$jscomp$59$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$59_code_num__52998__auto__$jscomp$59_fn_53995_read_code_fn__52997__auto__$jscomp$59$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$59$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$59_code_num__52998__auto__$jscomp$59_fn_53995_read_code_fn__52997__auto__$jscomp$59$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$59$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_bool_type",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$59$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$59_code_num__52998__auto__$jscomp$59_fn_53995_read_code_fn__52997__auto__$jscomp$59$$],null),$bool_type$jscomp$4_cause53996$$);}};
$app$render_wasm$api$set_shape_blur$$=function($blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$){if($blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$!=null){var $blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$);
var $code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$=$app$render_wasm$wasm$serializers$$["blur-type"],$default$$jscomp$inline_6005_fn_53998$$=$code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$["layer-blur"];$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$[$APP.$app$common$data$name$$($blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$)],
$default$$jscomp$inline_6005_fn_53998$$);$code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$=$APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$);$blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$);
$default$$jscomp$inline_6005_fn_53998$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_blur;try{return $default$$jscomp$inline_6005_fn_53998$$($blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$,$code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$,$blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$)}catch($e54000$$){throw $blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$=
$e54000$$,$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$=$APP.$cljs$core$truth_$$($blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$)?
$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$.$cljs$core$IFn$_invoke$arity$0$?$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$.$cljs$core$IFn$_invoke$arity$0$():$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$():
null,$code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$,$APP.$cljs$cst$2971$wasm_critical$$),$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$),")"].join(""),$code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_blur",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$],null),$blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$=$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$,$code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$,
$blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$),$blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$;}}else{$blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$=$APP.$app$render_wasm$wasm$internal_module$$._clear_shape_blur;try{return $blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$()}catch($e54004$$){throw $blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$=
$e54004$$,$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$=$APP.$cljs$core$truth_$$($blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$)?
$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$.$cljs$core$IFn$_invoke$arity$0$?$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$.$cljs$core$IFn$_invoke$arity$0$():$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$():
null,$code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$,$APP.$cljs$cst$2971$wasm_critical$$),$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$),")"].join(""),$code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_clear_shape_blur",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$],null),$blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$=$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($blur_type$jscomp$inline_6003_code_num__52998__auto__$jscomp$60_hint__53000__auto__$jscomp$60_read_code_fn__52997__auto__$jscomp$60_type$jscomp$417$$,$code__52999__auto__$jscomp$60_context__53001__auto__$jscomp$60_hidden$jscomp$4_values$jscomp$inline_6004$$,
$blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$),$blur$jscomp$4_cause53999_cause54003_cause__53002__auto__$jscomp$60_fn_54002_value$jscomp$515$$;}}};
$app$render_wasm$api$set_shape_corners$$=function($cause54012_corners_r1$jscomp$20$$){var $r4$jscomp$6_vec__54008$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__54007_SHARP_$$){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($p1__54007_SHARP_$$,0)},$cause54012_corners_r1$jscomp$20$$);$cause54012_corners_r1$jscomp$20$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r4$jscomp$6_vec__54008$$,0,null);var $code__52999__auto__$jscomp$61_code_num__52998__auto__$jscomp$61_r2$jscomp$18_read_code_fn__52997__auto__$jscomp$61$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r4$jscomp$6_vec__54008$$,1,null),$hint__53000__auto__$jscomp$61_r3$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r4$jscomp$6_vec__54008$$,2,null);$r4$jscomp$6_vec__54008$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r4$jscomp$6_vec__54008$$,3,null);var $fn_54011$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_corners;try{return $fn_54011$$($cause54012_corners_r1$jscomp$20$$,$code__52999__auto__$jscomp$61_code_num__52998__auto__$jscomp$61_r2$jscomp$18_read_code_fn__52997__auto__$jscomp$61$$,
$hint__53000__auto__$jscomp$61_r3$jscomp$6$$,$r4$jscomp$6_vec__54008$$)}catch($e54013$$){throw $cause54012_corners_r1$jscomp$20$$=$e54013$$,$code__52999__auto__$jscomp$61_code_num__52998__auto__$jscomp$61_r2$jscomp$18_read_code_fn__52997__auto__$jscomp$61$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$61_code_num__52998__auto__$jscomp$61_r2$jscomp$18_read_code_fn__52997__auto__$jscomp$61$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$61_code_num__52998__auto__$jscomp$61_r2$jscomp$18_read_code_fn__52997__auto__$jscomp$61$$)?
$code__52999__auto__$jscomp$61_code_num__52998__auto__$jscomp$61_r2$jscomp$18_read_code_fn__52997__auto__$jscomp$61$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$61_code_num__52998__auto__$jscomp$61_r2$jscomp$18_read_code_fn__52997__auto__$jscomp$61$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$61_code_num__52998__auto__$jscomp$61_r2$jscomp$18_read_code_fn__52997__auto__$jscomp$61$$():null,$code__52999__auto__$jscomp$61_code_num__52998__auto__$jscomp$61_r2$jscomp$18_read_code_fn__52997__auto__$jscomp$61$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$61_code_num__52998__auto__$jscomp$61_r2$jscomp$18_read_code_fn__52997__auto__$jscomp$61$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto__$jscomp$61_r3$jscomp$6$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$61_code_num__52998__auto__$jscomp$61_r2$jscomp$18_read_code_fn__52997__auto__$jscomp$61$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$61_r3$jscomp$6$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_corners",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$61_r3$jscomp$6$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$61_code_num__52998__auto__$jscomp$61_r2$jscomp$18_read_code_fn__52997__auto__$jscomp$61$$],null),$cause54012_corners_r1$jscomp$20$$);}};
$app$render_wasm$api$set_flex_layout$$=function($padding_top_shape$jscomp$352$$){var $cause54015_dir$jscomp$3_flex_dir$jscomp$inline_6007$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($padding_top_shape$jscomp$352$$,$APP.$cljs$cst$1679$layout_flex_dir$$,$APP.$cljs$cst$1656$row$$);$cause54015_dir$jscomp$3_flex_dir$jscomp$inline_6007$$=$app$render_wasm$wasm$serializers$$["flex-direction"][$APP.$app$common$data$name$$($cause54015_dir$jscomp$3_flex_dir$jscomp$inline_6007$$)];var $column_gap$jscomp$1_gap$jscomp$1_hint__53000__auto__$jscomp$62$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding_top_shape$jscomp$352$$,$APP.$cljs$cst$1680$layout_gap$$),$code__52999__auto__$jscomp$62_code_num__52998__auto__$jscomp$62_read_code_fn__52997__auto__$jscomp$62_row_gap$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($column_gap$jscomp$1_gap$jscomp$1_hint__53000__auto__$jscomp$62$$,$APP.$cljs$cst$1681$row_gap$$,0);$column_gap$jscomp$1_gap$jscomp$1_hint__53000__auto__$jscomp$62$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($column_gap$jscomp$1_gap$jscomp$1_hint__53000__auto__$jscomp$62$$,
$APP.$cljs$cst$1682$column_gap$$,0);var $align_items$jscomp$1$$=$app$render_wasm$serializers$translate_layout_align_items$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding_top_shape$jscomp$352$$,$APP.$cljs$cst$1692$layout_align_items$$)),$align_content$jscomp$1$$=$app$render_wasm$serializers$translate_layout_align_content$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding_top_shape$jscomp$352$$,$APP.$cljs$cst$1691$layout_align_content$$)),$justify_items$jscomp$1$$=$app$render_wasm$serializers$translate_layout_justify_items$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding_top_shape$jscomp$352$$,
$APP.$cljs$cst$1690$layout_justify_items$$)),$justify_content$jscomp$1$$=$app$render_wasm$serializers$translate_layout_justify_content$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding_top_shape$jscomp$352$$,$APP.$cljs$cst$1689$layout_justify_content$$));var $wrap_type$jscomp$1_wrap_type$jscomp$inline_6009$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding_top_shape$jscomp$352$$,$APP.$cljs$cst$1684$layout_wrap_type$$);var $padding_right_values$jscomp$inline_6010$$=$app$render_wasm$wasm$serializers$$["wrap-type"],
$default$$jscomp$inline_6011_padding_bottom$$=$padding_right_values$jscomp$inline_6010$$.nowrap;$wrap_type$jscomp$1_wrap_type$jscomp$inline_6009$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($padding_right_values$jscomp$inline_6010$$[$APP.$app$common$data$name$$($wrap_type$jscomp$1_wrap_type$jscomp$inline_6009$$)],$default$$jscomp$inline_6011_padding_bottom$$);var $padding$jscomp$3_padding_left$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding_top_shape$jscomp$352$$,
$APP.$cljs$cst$1686$layout_padding$$);$padding_top_shape$jscomp$352$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($padding$jscomp$3_padding_left$$,$APP.$cljs$cst$1093$p1$$,0);$padding_right_values$jscomp$inline_6010$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($padding$jscomp$3_padding_left$$,$APP.$cljs$cst$1091$p2$$,0);$default$$jscomp$inline_6011_padding_bottom$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($padding$jscomp$3_padding_left$$,$APP.$cljs$cst$1687$p3$$,
0);$padding$jscomp$3_padding_left$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($padding$jscomp$3_padding_left$$,$APP.$cljs$cst$1688$p4$$,0);var $fn_54014$$=$APP.$app$render_wasm$wasm$internal_module$$._set_flex_layout_data;try{return $fn_54014$$($cause54015_dir$jscomp$3_flex_dir$jscomp$inline_6007$$,$code__52999__auto__$jscomp$62_code_num__52998__auto__$jscomp$62_read_code_fn__52997__auto__$jscomp$62_row_gap$jscomp$1$$,$column_gap$jscomp$1_gap$jscomp$1_hint__53000__auto__$jscomp$62$$,$align_items$jscomp$1$$,
$align_content$jscomp$1$$,$justify_items$jscomp$1$$,$justify_content$jscomp$1$$,$wrap_type$jscomp$1_wrap_type$jscomp$inline_6009$$,$padding_top_shape$jscomp$352$$,$padding_right_values$jscomp$inline_6010$$,$default$$jscomp$inline_6011_padding_bottom$$,$padding$jscomp$3_padding_left$$)}catch($e54016$$){throw $cause54015_dir$jscomp$3_flex_dir$jscomp$inline_6007$$=$e54016$$,$code__52999__auto__$jscomp$62_code_num__52998__auto__$jscomp$62_read_code_fn__52997__auto__$jscomp$62_row_gap$jscomp$1$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,
$code__52999__auto__$jscomp$62_code_num__52998__auto__$jscomp$62_read_code_fn__52997__auto__$jscomp$62_row_gap$jscomp$1$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$62_code_num__52998__auto__$jscomp$62_read_code_fn__52997__auto__$jscomp$62_row_gap$jscomp$1$$)?$code__52999__auto__$jscomp$62_code_num__52998__auto__$jscomp$62_read_code_fn__52997__auto__$jscomp$62_row_gap$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$62_code_num__52998__auto__$jscomp$62_read_code_fn__52997__auto__$jscomp$62_row_gap$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$62_code_num__52998__auto__$jscomp$62_read_code_fn__52997__auto__$jscomp$62_row_gap$jscomp$1$$():null,$code__52999__auto__$jscomp$62_code_num__52998__auto__$jscomp$62_read_code_fn__52997__auto__$jscomp$62_row_gap$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$62_code_num__52998__auto__$jscomp$62_read_code_fn__52997__auto__$jscomp$62_row_gap$jscomp$1$$,$APP.$cljs$cst$2971$wasm_critical$$),
$column_gap$jscomp$1_gap$jscomp$1_hint__53000__auto__$jscomp$62$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$62_code_num__52998__auto__$jscomp$62_read_code_fn__52997__auto__$jscomp$62_row_gap$jscomp$1$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($column_gap$jscomp$1_gap$jscomp$1_hint__53000__auto__$jscomp$62$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_flex_layout_data",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$column_gap$jscomp$1_gap$jscomp$1_hint__53000__auto__$jscomp$62$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$62_code_num__52998__auto__$jscomp$62_read_code_fn__52997__auto__$jscomp$62_row_gap$jscomp$1$$],null),$cause54015_dir$jscomp$3_flex_dir$jscomp$inline_6007$$);}};
$app$render_wasm$api$set_grid_layout_data$$=function($padding_top$jscomp$1_shape$jscomp$353$$){var $cause54020_dir$jscomp$4_grid_dir$jscomp$inline_6013$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($padding_top$jscomp$1_shape$jscomp$353$$,$APP.$cljs$cst$1693$layout_grid_dir$$,$APP.$cljs$cst$1656$row$$);$cause54020_dir$jscomp$4_grid_dir$jscomp$inline_6013$$=$app$render_wasm$wasm$serializers$$["grid-direction"][$APP.$app$common$data$name$$($cause54020_dir$jscomp$4_grid_dir$jscomp$inline_6013$$)];
var $column_gap$jscomp$2_gap$jscomp$2_hint__53000__auto__$jscomp$63$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding_top$jscomp$1_shape$jscomp$353$$,$APP.$cljs$cst$1680$layout_gap$$),$code__52999__auto__$jscomp$63_code_num__52998__auto__$jscomp$63_read_code_fn__52997__auto__$jscomp$63_row_gap$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($column_gap$jscomp$2_gap$jscomp$2_hint__53000__auto__$jscomp$63$$,$APP.$cljs$cst$1681$row_gap$$,0);$column_gap$jscomp$2_gap$jscomp$2_hint__53000__auto__$jscomp$63$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($column_gap$jscomp$2_gap$jscomp$2_hint__53000__auto__$jscomp$63$$,$APP.$cljs$cst$1682$column_gap$$,0);var $align_items$jscomp$2$$=$app$render_wasm$serializers$translate_layout_align_items$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding_top$jscomp$1_shape$jscomp$353$$,$APP.$cljs$cst$1692$layout_align_items$$)),$align_content$jscomp$2$$=$app$render_wasm$serializers$translate_layout_align_content$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding_top$jscomp$1_shape$jscomp$353$$,
$APP.$cljs$cst$1691$layout_align_content$$)),$justify_items$jscomp$2$$=$app$render_wasm$serializers$translate_layout_justify_items$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding_top$jscomp$1_shape$jscomp$353$$,$APP.$cljs$cst$1690$layout_justify_items$$)),$justify_content$jscomp$2$$=$app$render_wasm$serializers$translate_layout_justify_content$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding_top$jscomp$1_shape$jscomp$353$$,$APP.$cljs$cst$1689$layout_justify_content$$)),
$padding$jscomp$4_padding_left$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding_top$jscomp$1_shape$jscomp$353$$,$APP.$cljs$cst$1686$layout_padding$$);$padding_top$jscomp$1_shape$jscomp$353$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($padding$jscomp$4_padding_left$jscomp$1$$,$APP.$cljs$cst$1093$p1$$,0);var $padding_right$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($padding$jscomp$4_padding_left$jscomp$1$$,$APP.$cljs$cst$1091$p2$$,0),$padding_bottom$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($padding$jscomp$4_padding_left$jscomp$1$$,$APP.$cljs$cst$1687$p3$$,0);$padding$jscomp$4_padding_left$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($padding$jscomp$4_padding_left$jscomp$1$$,$APP.$cljs$cst$1688$p4$$,0);var $fn_54019$$=$APP.$app$render_wasm$wasm$internal_module$$._set_grid_layout_data;try{return $fn_54019$$($cause54020_dir$jscomp$4_grid_dir$jscomp$inline_6013$$,$code__52999__auto__$jscomp$63_code_num__52998__auto__$jscomp$63_read_code_fn__52997__auto__$jscomp$63_row_gap$jscomp$2$$,
$column_gap$jscomp$2_gap$jscomp$2_hint__53000__auto__$jscomp$63$$,$align_items$jscomp$2$$,$align_content$jscomp$2$$,$justify_items$jscomp$2$$,$justify_content$jscomp$2$$,$padding_top$jscomp$1_shape$jscomp$353$$,$padding_right$jscomp$1$$,$padding_bottom$jscomp$1$$,$padding$jscomp$4_padding_left$jscomp$1$$)}catch($e54021$$){throw $cause54020_dir$jscomp$4_grid_dir$jscomp$inline_6013$$=$e54021$$,$code__52999__auto__$jscomp$63_code_num__52998__auto__$jscomp$63_read_code_fn__52997__auto__$jscomp$63_row_gap$jscomp$2$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$63_code_num__52998__auto__$jscomp$63_read_code_fn__52997__auto__$jscomp$63_row_gap$jscomp$2$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$63_code_num__52998__auto__$jscomp$63_read_code_fn__52997__auto__$jscomp$63_row_gap$jscomp$2$$)?$code__52999__auto__$jscomp$63_code_num__52998__auto__$jscomp$63_read_code_fn__52997__auto__$jscomp$63_row_gap$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$63_code_num__52998__auto__$jscomp$63_read_code_fn__52997__auto__$jscomp$63_row_gap$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$63_code_num__52998__auto__$jscomp$63_read_code_fn__52997__auto__$jscomp$63_row_gap$jscomp$2$$():null,$code__52999__auto__$jscomp$63_code_num__52998__auto__$jscomp$63_read_code_fn__52997__auto__$jscomp$63_row_gap$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$63_code_num__52998__auto__$jscomp$63_read_code_fn__52997__auto__$jscomp$63_row_gap$jscomp$2$$,$APP.$cljs$cst$2971$wasm_critical$$),
$column_gap$jscomp$2_gap$jscomp$2_hint__53000__auto__$jscomp$63$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$63_code_num__52998__auto__$jscomp$63_read_code_fn__52997__auto__$jscomp$63_row_gap$jscomp$2$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($column_gap$jscomp$2_gap$jscomp$2_hint__53000__auto__$jscomp$63$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_grid_layout_data",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$column_gap$jscomp$2_gap$jscomp$2_hint__53000__auto__$jscomp$63$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$63_code_num__52998__auto__$jscomp$63_read_code_fn__52997__auto__$jscomp$63_row_gap$jscomp$2$$],null),$cause54020_dir$jscomp$4_grid_dir$jscomp$inline_6013$$);}};
$app$render_wasm$api$set_grid_layout_rows$$=function($cause54025_entries$jscomp$13_fn_54024$$){var $code__52999__auto__$jscomp$64_code_num__52998__auto__$jscomp$64_offset$jscomp$154_read_code_fn__52997__auto__$jscomp$64_size$jscomp$109$$=8*$APP.$cljs$core$count$$($cause54025_entries$jscomp$13_fn_54024$$);$code__52999__auto__$jscomp$64_code_num__52998__auto__$jscomp$64_offset$jscomp$154_read_code_fn__52997__auto__$jscomp$64_size$jscomp$109$$=$APP.$app$render_wasm$mem$alloc$$($code__52999__auto__$jscomp$64_code_num__52998__auto__$jscomp$64_offset$jscomp$154_read_code_fn__52997__auto__$jscomp$64_size$jscomp$109$$);
var $dview$jscomp$7$$=$app$common$buffer$wrap$$();$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($offset__$1$jscomp$7$$,$p__54022_type$jscomp$418$$){var $map__54023__$1_value$jscomp$516$$=$APP.$cljs$core$__destructure_map$$($p__54022_type$jscomp$418$$);$p__54022_type$jscomp$418$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54023__$1_value$jscomp$516$$,$APP.$cljs$cst$139$type$$);$map__54023__$1_value$jscomp$516$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54023__$1_value$jscomp$516$$,
$APP.$cljs$cst$260$value$$);return $app$render_wasm$mem$assert_written$$($app$render_wasm$mem$write_f32$$($app$render_wasm$mem$write_u8$$($offset__$1$jscomp$7$$,$dview$jscomp$7$$,$app$render_wasm$wasm$serializers$$["grid-track-type"][$APP.$app$common$data$name$$($p__54022_type$jscomp$418$$)])+3,$dview$jscomp$7$$,$map__54023__$1_value$jscomp$516$$))},$code__52999__auto__$jscomp$64_code_num__52998__auto__$jscomp$64_offset$jscomp$154_read_code_fn__52997__auto__$jscomp$64_size$jscomp$109$$,$cause54025_entries$jscomp$13_fn_54024$$);
$cause54025_entries$jscomp$13_fn_54024$$=$APP.$app$render_wasm$wasm$internal_module$$._set_grid_rows;try{return $cause54025_entries$jscomp$13_fn_54024$$()}catch($e54026$$){$cause54025_entries$jscomp$13_fn_54024$$=$e54026$$;$code__52999__auto__$jscomp$64_code_num__52998__auto__$jscomp$64_offset$jscomp$154_read_code_fn__52997__auto__$jscomp$64_size$jscomp$109$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$64_code_num__52998__auto__$jscomp$64_offset$jscomp$154_read_code_fn__52997__auto__$jscomp$64_size$jscomp$109$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$64_code_num__52998__auto__$jscomp$64_offset$jscomp$154_read_code_fn__52997__auto__$jscomp$64_size$jscomp$109$$)?$code__52999__auto__$jscomp$64_code_num__52998__auto__$jscomp$64_offset$jscomp$154_read_code_fn__52997__auto__$jscomp$64_size$jscomp$109$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$64_code_num__52998__auto__$jscomp$64_offset$jscomp$154_read_code_fn__52997__auto__$jscomp$64_size$jscomp$109$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$64_code_num__52998__auto__$jscomp$64_offset$jscomp$154_read_code_fn__52997__auto__$jscomp$64_size$jscomp$109$$():null;$code__52999__auto__$jscomp$64_code_num__52998__auto__$jscomp$64_offset$jscomp$154_read_code_fn__52997__auto__$jscomp$64_size$jscomp$109$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$64_code_num__52998__auto__$jscomp$64_offset$jscomp$154_read_code_fn__52997__auto__$jscomp$64_size$jscomp$109$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$64$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$64_code_num__52998__auto__$jscomp$64_offset$jscomp$154_read_code_fn__52997__auto__$jscomp$64_size$jscomp$109$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$64$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_grid_rows",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$64$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$64_code_num__52998__auto__$jscomp$64_offset$jscomp$154_read_code_fn__52997__auto__$jscomp$64_size$jscomp$109$$],null),$cause54025_entries$jscomp$13_fn_54024$$);}};
$app$render_wasm$api$set_grid_layout_columns$$=function($cause54032_entries$jscomp$14_fn_54031$$){var $code__52999__auto__$jscomp$65_code_num__52998__auto__$jscomp$65_offset$jscomp$155_read_code_fn__52997__auto__$jscomp$65_size$jscomp$110$$=8*$APP.$cljs$core$count$$($cause54032_entries$jscomp$14_fn_54031$$);$code__52999__auto__$jscomp$65_code_num__52998__auto__$jscomp$65_offset$jscomp$155_read_code_fn__52997__auto__$jscomp$65_size$jscomp$110$$=$APP.$app$render_wasm$mem$alloc$$($code__52999__auto__$jscomp$65_code_num__52998__auto__$jscomp$65_offset$jscomp$155_read_code_fn__52997__auto__$jscomp$65_size$jscomp$110$$);
var $dview$jscomp$8$$=$app$common$buffer$wrap$$();$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($offset__$1$jscomp$8$$,$p__54028_type$jscomp$419$$){var $map__54029__$1_value$jscomp$517$$=$APP.$cljs$core$__destructure_map$$($p__54028_type$jscomp$419$$);$p__54028_type$jscomp$419$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54029__$1_value$jscomp$517$$,$APP.$cljs$cst$139$type$$);$map__54029__$1_value$jscomp$517$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54029__$1_value$jscomp$517$$,
$APP.$cljs$cst$260$value$$);return $app$render_wasm$mem$assert_written$$($app$render_wasm$mem$write_f32$$($app$render_wasm$mem$write_u8$$($offset__$1$jscomp$8$$,$dview$jscomp$8$$,$app$render_wasm$wasm$serializers$$["grid-track-type"][$APP.$app$common$data$name$$($p__54028_type$jscomp$419$$)])+3,$dview$jscomp$8$$,$map__54029__$1_value$jscomp$517$$))},$code__52999__auto__$jscomp$65_code_num__52998__auto__$jscomp$65_offset$jscomp$155_read_code_fn__52997__auto__$jscomp$65_size$jscomp$110$$,$cause54032_entries$jscomp$14_fn_54031$$);
$cause54032_entries$jscomp$14_fn_54031$$=$APP.$app$render_wasm$wasm$internal_module$$._set_grid_columns;try{return $cause54032_entries$jscomp$14_fn_54031$$()}catch($e54033$$){$cause54032_entries$jscomp$14_fn_54031$$=$e54033$$;$code__52999__auto__$jscomp$65_code_num__52998__auto__$jscomp$65_offset$jscomp$155_read_code_fn__52997__auto__$jscomp$65_size$jscomp$110$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$65_code_num__52998__auto__$jscomp$65_offset$jscomp$155_read_code_fn__52997__auto__$jscomp$65_size$jscomp$110$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$65_code_num__52998__auto__$jscomp$65_offset$jscomp$155_read_code_fn__52997__auto__$jscomp$65_size$jscomp$110$$)?$code__52999__auto__$jscomp$65_code_num__52998__auto__$jscomp$65_offset$jscomp$155_read_code_fn__52997__auto__$jscomp$65_size$jscomp$110$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$65_code_num__52998__auto__$jscomp$65_offset$jscomp$155_read_code_fn__52997__auto__$jscomp$65_size$jscomp$110$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$65_code_num__52998__auto__$jscomp$65_offset$jscomp$155_read_code_fn__52997__auto__$jscomp$65_size$jscomp$110$$():null;$code__52999__auto__$jscomp$65_code_num__52998__auto__$jscomp$65_offset$jscomp$155_read_code_fn__52997__auto__$jscomp$65_size$jscomp$110$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$65_code_num__52998__auto__$jscomp$65_offset$jscomp$155_read_code_fn__52997__auto__$jscomp$65_size$jscomp$110$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$65$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$65_code_num__52998__auto__$jscomp$65_offset$jscomp$155_read_code_fn__52997__auto__$jscomp$65_size$jscomp$110$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$65$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_grid_columns",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$65$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$65_code_num__52998__auto__$jscomp$65_offset$jscomp$155_read_code_fn__52997__auto__$jscomp$65_size$jscomp$110$$],null),$cause54032_entries$jscomp$14_fn_54031$$);}};
$app$render_wasm$api$set_grid_layout_cells$$=function($cause54038_cells$jscomp$19_fn_54037$$){var $code__52999__auto__$jscomp$66_code_num__52998__auto__$jscomp$66_offset$jscomp$156_read_code_fn__52997__auto__$jscomp$66_size$jscomp$111$$=36*$APP.$cljs$core$count$$($cause54038_cells$jscomp$19_fn_54037$$);$code__52999__auto__$jscomp$66_code_num__52998__auto__$jscomp$66_offset$jscomp$156_read_code_fn__52997__auto__$jscomp$66_size$jscomp$111$$=$APP.$app$render_wasm$mem$alloc$$($code__52999__auto__$jscomp$66_code_num__52998__auto__$jscomp$66_offset$jscomp$156_read_code_fn__52997__auto__$jscomp$66_size$jscomp$111$$);
var $dview$jscomp$9$$=$app$common$buffer$wrap$$();$APP.$cljs$core$reduce_kv$$(function($JSCompiler_temp_const$jscomp$993_offset__$1$jscomp$9$$,$_$jscomp$1615_shape_id$jscomp$53$$,$JSCompiler_inline_result$jscomp$994_cell$jscomp$20_justify_self$jscomp$inline_6015$$){$_$jscomp$1615_shape_id$jscomp$53$$=$APP.$cljs$core$first$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$994_cell$jscomp$20_justify_self$jscomp$inline_6015$$,$APP.$cljs$cst$1614$shapes$$));$JSCompiler_temp_const$jscomp$993_offset__$1$jscomp$9$$=
$app$render_wasm$mem$write_u8$$($app$render_wasm$mem$write_i32$$($app$render_wasm$mem$write_i32$$($app$render_wasm$mem$write_i32$$($app$render_wasm$mem$write_i32$$($JSCompiler_temp_const$jscomp$993_offset__$1$jscomp$9$$,$dview$jscomp$9$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$994_cell$jscomp$20_justify_self$jscomp$inline_6015$$,$APP.$cljs$cst$1656$row$$)),$dview$jscomp$9$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$994_cell$jscomp$20_justify_self$jscomp$inline_6015$$,
$APP.$cljs$cst$1657$row_span$$)),$dview$jscomp$9$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$994_cell$jscomp$20_justify_self$jscomp$inline_6015$$,$APP.$cljs$cst$216$column$$)),$dview$jscomp$9$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$994_cell$jscomp$20_justify_self$jscomp$inline_6015$$,$APP.$cljs$cst$1658$column_span$$)),$dview$jscomp$9$$,$app$render_wasm$serializers$translate_align_self$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$994_cell$jscomp$20_justify_self$jscomp$inline_6015$$,
$APP.$cljs$cst$1677$align_self$$)));$JSCompiler_inline_result$jscomp$994_cell$jscomp$20_justify_self$jscomp$inline_6015$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$994_cell$jscomp$20_justify_self$jscomp$inline_6015$$,$APP.$cljs$cst$1678$justify_self$$);var $values$jscomp$inline_6016$$=$app$render_wasm$wasm$serializers$$["justify-self"],$default$$jscomp$inline_6017$$=$values$jscomp$inline_6016$$.none;$JSCompiler_inline_result$jscomp$994_cell$jscomp$20_justify_self$jscomp$inline_6015$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$inline_6016$$[$APP.$app$common$data$name$$($JSCompiler_inline_result$jscomp$994_cell$jscomp$20_justify_self$jscomp$inline_6015$$)],$default$$jscomp$inline_6017$$);return $app$render_wasm$mem$assert_written$$($app$render_wasm$mem$write_uuid$$($app$render_wasm$mem$write_u8$$($JSCompiler_temp_const$jscomp$993_offset__$1$jscomp$9$$,$dview$jscomp$9$$,$JSCompiler_inline_result$jscomp$994_cell$jscomp$20_justify_self$jscomp$inline_6015$$)+
2,$dview$jscomp$9$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1615_shape_id$jscomp$53$$,$APP.$app$common$uuid$zero$$)))},$code__52999__auto__$jscomp$66_code_num__52998__auto__$jscomp$66_offset$jscomp$156_read_code_fn__52997__auto__$jscomp$66_size$jscomp$111$$,$cause54038_cells$jscomp$19_fn_54037$$);$cause54038_cells$jscomp$19_fn_54037$$=$APP.$app$render_wasm$wasm$internal_module$$._set_grid_cells;try{return $cause54038_cells$jscomp$19_fn_54037$$()}catch($e54040$$){$cause54038_cells$jscomp$19_fn_54037$$=
$e54040$$;$code__52999__auto__$jscomp$66_code_num__52998__auto__$jscomp$66_offset$jscomp$156_read_code_fn__52997__auto__$jscomp$66_size$jscomp$111$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$66_code_num__52998__auto__$jscomp$66_offset$jscomp$156_read_code_fn__52997__auto__$jscomp$66_size$jscomp$111$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$66_code_num__52998__auto__$jscomp$66_offset$jscomp$156_read_code_fn__52997__auto__$jscomp$66_size$jscomp$111$$)?
$code__52999__auto__$jscomp$66_code_num__52998__auto__$jscomp$66_offset$jscomp$156_read_code_fn__52997__auto__$jscomp$66_size$jscomp$111$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$66_code_num__52998__auto__$jscomp$66_offset$jscomp$156_read_code_fn__52997__auto__$jscomp$66_size$jscomp$111$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$66_code_num__52998__auto__$jscomp$66_offset$jscomp$156_read_code_fn__52997__auto__$jscomp$66_size$jscomp$111$$():null;$code__52999__auto__$jscomp$66_code_num__52998__auto__$jscomp$66_offset$jscomp$156_read_code_fn__52997__auto__$jscomp$66_size$jscomp$111$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$66_code_num__52998__auto__$jscomp$66_offset$jscomp$156_read_code_fn__52997__auto__$jscomp$66_size$jscomp$111$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$66$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$66_code_num__52998__auto__$jscomp$66_offset$jscomp$156_read_code_fn__52997__auto__$jscomp$66_size$jscomp$111$$),")"].join("");
throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$66$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_grid_cells",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$66$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$66_code_num__52998__auto__$jscomp$66_offset$jscomp$156_read_code_fn__52997__auto__$jscomp$66_size$jscomp$111$$],null),$cause54038_cells$jscomp$19_fn_54037$$);
}};
$app$render_wasm$api$set_grid_layout$$=function($shape$jscomp$354$$){$app$render_wasm$api$set_grid_layout_data$$($shape$jscomp$354$$);$app$render_wasm$api$set_grid_layout_rows$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$354$$,$APP.$cljs$cst$1694$layout_grid_rows$$));$app$render_wasm$api$set_grid_layout_columns$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$354$$,$APP.$cljs$cst$1695$layout_grid_columns$$));$app$render_wasm$api$set_grid_layout_cells$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$354$$,$APP.$cljs$cst$1696$layout_grid_cells$$))};
$app$render_wasm$api$set_layout_data$$=function($shape$jscomp$355_z_index$$){var $margin_left_margins$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$355_z_index$$,$APP.$cljs$cst$1699$layout_item_margin$$),$cause54044_margin_top$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($margin_left_margins$$,$APP.$cljs$cst$1700$m1$$,0),$code__52999__auto__$jscomp$67_code_num__52998__auto__$jscomp$67_margin_right_read_code_fn__52997__auto__$jscomp$67$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($margin_left_margins$$,
$APP.$cljs$cst$1701$m2$$,0),$hint__53000__auto__$jscomp$67_margin_bottom$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($margin_left_margins$$,$APP.$cljs$cst$1702$m3$$,0);$margin_left_margins$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($margin_left_margins$$,$APP.$cljs$cst$1703$m4$$,0);var $h_sizing$$=$app$render_wasm$serializers$translate_layout_sizing$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$355_z_index$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$)),
$v_sizing$$=$app$render_wasm$serializers$translate_layout_sizing$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$355_z_index$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$)),$align_self$jscomp$2$$=$app$render_wasm$serializers$translate_align_self$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$355_z_index$$,$APP.$cljs$cst$1710$layout_item_align_self$$)),$max_h$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$355_z_index$$,$APP.$cljs$cst$1704$layout_item_max_h$$),
$has_max_h$$=$max_h$$!=null,$min_h$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$355_z_index$$,$APP.$cljs$cst$1705$layout_item_min_h$$),$has_min_h$$=$min_h$$!=null,$max_w$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$355_z_index$$,$APP.$cljs$cst$1706$layout_item_max_w$$),$has_max_w$$=$max_w$$!=null,$min_w$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$355_z_index$$,$APP.$cljs$cst$1707$layout_item_min_w$$),$has_min_w$$=$min_w$$!=
null,$is_absolute$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$355_z_index$$,$APP.$cljs$cst$1711$layout_item_absolute$$));$shape$jscomp$355_z_index$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$355_z_index$$,$APP.$cljs$cst$1712$layout_item_z_index$$);var $fn_54043$$=$APP.$app$render_wasm$wasm$internal_module$$._set_layout_data;try{return $fn_54043$$($cause54044_margin_top$$,$code__52999__auto__$jscomp$67_code_num__52998__auto__$jscomp$67_margin_right_read_code_fn__52997__auto__$jscomp$67$$,
$hint__53000__auto__$jscomp$67_margin_bottom$$,$margin_left_margins$$,$h_sizing$$,$v_sizing$$,$has_max_h$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($max_h$$,0),$has_min_h$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($min_h$$,0),$has_max_w$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($max_w$$,0),$has_min_w$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($min_w$$,0),$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($align_self$jscomp$2$$,
0),$is_absolute$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$355_z_index$$,0))}catch($e54045$$){throw $cause54044_margin_top$$=$e54045$$,$code__52999__auto__$jscomp$67_code_num__52998__auto__$jscomp$67_margin_right_read_code_fn__52997__auto__$jscomp$67$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$67_code_num__52998__auto__$jscomp$67_margin_right_read_code_fn__52997__auto__$jscomp$67$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$67_code_num__52998__auto__$jscomp$67_margin_right_read_code_fn__52997__auto__$jscomp$67$$)?
$code__52999__auto__$jscomp$67_code_num__52998__auto__$jscomp$67_margin_right_read_code_fn__52997__auto__$jscomp$67$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$67_code_num__52998__auto__$jscomp$67_margin_right_read_code_fn__52997__auto__$jscomp$67$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$67_code_num__52998__auto__$jscomp$67_margin_right_read_code_fn__52997__auto__$jscomp$67$$():null,$code__52999__auto__$jscomp$67_code_num__52998__auto__$jscomp$67_margin_right_read_code_fn__52997__auto__$jscomp$67$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$67_code_num__52998__auto__$jscomp$67_margin_right_read_code_fn__52997__auto__$jscomp$67$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto__$jscomp$67_margin_bottom$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$67_code_num__52998__auto__$jscomp$67_margin_right_read_code_fn__52997__auto__$jscomp$67$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$67_margin_bottom$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_layout_data",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$67_margin_bottom$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$67_code_num__52998__auto__$jscomp$67_margin_right_read_code_fn__52997__auto__$jscomp$67$$],null),$cause54044_margin_top$$);}};
$app$render_wasm$api$clear_layout$$=function(){var $cause54049_fn_54048$$=$APP.$app$render_wasm$wasm$internal_module$$._clear_shape_layout;try{$cause54049_fn_54048$$()}catch($e54050$$){$cause54049_fn_54048$$=$e54050$$;var $code__52999__auto__$jscomp$68_code_num__52998__auto__$jscomp$68_read_code_fn__52997__auto__$jscomp$68$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$68_code_num__52998__auto__$jscomp$68_read_code_fn__52997__auto__$jscomp$68$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$68_code_num__52998__auto__$jscomp$68_read_code_fn__52997__auto__$jscomp$68$$)?
$code__52999__auto__$jscomp$68_code_num__52998__auto__$jscomp$68_read_code_fn__52997__auto__$jscomp$68$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$68_code_num__52998__auto__$jscomp$68_read_code_fn__52997__auto__$jscomp$68$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$68_code_num__52998__auto__$jscomp$68_read_code_fn__52997__auto__$jscomp$68$$():null;$code__52999__auto__$jscomp$68_code_num__52998__auto__$jscomp$68_read_code_fn__52997__auto__$jscomp$68$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code__52999__auto__$jscomp$68_code_num__52998__auto__$jscomp$68_read_code_fn__52997__auto__$jscomp$68$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$68$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$68_code_num__52998__auto__$jscomp$68_read_code_fn__52997__auto__$jscomp$68$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$68$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,
"_clear_shape_layout",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$68$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$68_code_num__52998__auto__$jscomp$68_read_code_fn__52997__auto__$jscomp$68$$],null),$cause54049_fn_54048$$);}};
$app$render_wasm$api$set_shape_shadows$$=function($cause54052_54794_shadows$$){var $code__52999__auto___54797_code_num__52998__auto___54796_fn_54051_54793_read_code_fn__52997__auto___54795$$=$APP.$app$render_wasm$wasm$internal_module$$._clear_shape_shadows;try{$code__52999__auto___54797_code_num__52998__auto___54796_fn_54051_54793_read_code_fn__52997__auto___54795$$()}catch($e54053$$){$cause54052_54794_shadows$$=$e54053$$;$code__52999__auto___54797_code_num__52998__auto___54796_fn_54051_54793_read_code_fn__52997__auto___54795$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___54797_code_num__52998__auto___54796_fn_54051_54793_read_code_fn__52997__auto___54795$$=$APP.$cljs$core$truth_$$($code__52999__auto___54797_code_num__52998__auto___54796_fn_54051_54793_read_code_fn__52997__auto___54795$$)?$code__52999__auto___54797_code_num__52998__auto___54796_fn_54051_54793_read_code_fn__52997__auto___54795$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___54797_code_num__52998__auto___54796_fn_54051_54793_read_code_fn__52997__auto___54795$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto___54797_code_num__52998__auto___54796_fn_54051_54793_read_code_fn__52997__auto___54795$$():null;$code__52999__auto___54797_code_num__52998__auto___54796_fn_54051_54793_read_code_fn__52997__auto___54795$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54797_code_num__52998__auto___54796_fn_54051_54793_read_code_fn__52997__auto___54795$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto___54798$$=["WASM Error (",
$APP.$app$common$data$name$$($code__52999__auto___54797_code_num__52998__auto___54796_fn_54051_54793_read_code_fn__52997__auto___54795$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54798$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_clear_shape_shadows",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54798$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54797_code_num__52998__auto___54796_fn_54051_54793_read_code_fn__52997__auto___54795$$],
null),$cause54052_54794_shadows$$);}return $APP.$cljs$core$run_BANG_$$(function($shadow__$1$jscomp$8_style$jscomp$37$$){var $color$jscomp$49_rgba$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadow__$1$jscomp$8_style$jscomp$37$$,$APP.$cljs$cst$1298$color$$),$blur$jscomp$5_cause54057$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadow__$1$jscomp$8_style$jscomp$37$$,$APP.$cljs$cst$1653$blur$$);$color$jscomp$49_rgba$jscomp$7$$=$APP.$app$render_wasm$serializers$color$hex__GT_u32argb$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$49_rgba$jscomp$7$$,
$APP.$cljs$cst$1298$color$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$49_rgba$jscomp$7$$,$APP.$cljs$cst$1734$opacity$$));var $hidden$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadow__$1$jscomp$8_style$jscomp$37$$,$APP.$cljs$cst$1620$hidden$$),$x$jscomp$1162$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadow__$1$jscomp$8_style$jscomp$37$$,$APP.$cljs$cst$1650$offset_x$$),$y$jscomp$400$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadow__$1$jscomp$8_style$jscomp$37$$,
$APP.$cljs$cst$1651$offset_y$$),$spread$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadow__$1$jscomp$8_style$jscomp$37$$,$APP.$cljs$cst$1652$spread$$);$shadow__$1$jscomp$8_style$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadow__$1$jscomp$8_style$jscomp$37$$,$APP.$cljs$cst$1904$style$$);var $fn_54056$$=$APP.$app$render_wasm$wasm$internal_module$$._add_shape_shadow;try{var $hint__53000__auto__$jscomp$69_values$jscomp$inline_6020$$=$app$render_wasm$wasm$serializers$$["shadow-style"],
$default$$jscomp$inline_6021$$=$hint__53000__auto__$jscomp$69_values$jscomp$inline_6020$$["drop-shadow"];var $JSCompiler_inline_result$jscomp$995_code__52999__auto__$jscomp$69_code_num__52998__auto__$jscomp$69_read_code_fn__52997__auto__$jscomp$69$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($hint__53000__auto__$jscomp$69_values$jscomp$inline_6020$$[$APP.$app$common$data$name$$($shadow__$1$jscomp$8_style$jscomp$37$$)],$default$$jscomp$inline_6021$$);return $fn_54056$$($color$jscomp$49_rgba$jscomp$7$$,
$blur$jscomp$5_cause54057$$,$spread$jscomp$2$$,$x$jscomp$1162$$,$y$jscomp$400$$,$JSCompiler_inline_result$jscomp$995_code__52999__auto__$jscomp$69_code_num__52998__auto__$jscomp$69_read_code_fn__52997__auto__$jscomp$69$$,$hidden$jscomp$5$$)}catch($e54058$$){throw $blur$jscomp$5_cause54057$$=$e54058$$,$JSCompiler_inline_result$jscomp$995_code__52999__auto__$jscomp$69_code_num__52998__auto__$jscomp$69_read_code_fn__52997__auto__$jscomp$69$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,
$JSCompiler_inline_result$jscomp$995_code__52999__auto__$jscomp$69_code_num__52998__auto__$jscomp$69_read_code_fn__52997__auto__$jscomp$69$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$995_code__52999__auto__$jscomp$69_code_num__52998__auto__$jscomp$69_read_code_fn__52997__auto__$jscomp$69$$)?$JSCompiler_inline_result$jscomp$995_code__52999__auto__$jscomp$69_code_num__52998__auto__$jscomp$69_read_code_fn__52997__auto__$jscomp$69$$.$cljs$core$IFn$_invoke$arity$0$?$JSCompiler_inline_result$jscomp$995_code__52999__auto__$jscomp$69_code_num__52998__auto__$jscomp$69_read_code_fn__52997__auto__$jscomp$69$$.$cljs$core$IFn$_invoke$arity$0$():
$JSCompiler_inline_result$jscomp$995_code__52999__auto__$jscomp$69_code_num__52998__auto__$jscomp$69_read_code_fn__52997__auto__$jscomp$69$$():null,$JSCompiler_inline_result$jscomp$995_code__52999__auto__$jscomp$69_code_num__52998__auto__$jscomp$69_read_code_fn__52997__auto__$jscomp$69$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$JSCompiler_inline_result$jscomp$995_code__52999__auto__$jscomp$69_code_num__52998__auto__$jscomp$69_read_code_fn__52997__auto__$jscomp$69$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto__$jscomp$69_values$jscomp$inline_6020$$=["WASM Error (",$APP.$app$common$data$name$$($JSCompiler_inline_result$jscomp$995_code__52999__auto__$jscomp$69_code_num__52998__auto__$jscomp$69_read_code_fn__52997__auto__$jscomp$69$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$69_values$jscomp$inline_6020$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_add_shape_shadow",
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$69_values$jscomp$inline_6020$$,$APP.$cljs$cst$273$code$$,$JSCompiler_inline_result$jscomp$995_code__52999__auto__$jscomp$69_code_num__52998__auto__$jscomp$69_read_code_fn__52997__auto__$jscomp$69$$],null),$blur$jscomp$5_cause54057$$);}},$cause54052_54794_shadows$$)};
$APP.$app$render_wasm$api$fonts_from_text_content$$=function($content$jscomp$140_fallback_fonts$jscomp$1_paragraph_set$jscomp$3$$,$fallback_fonts_only_QMARK_$$){$content$jscomp$140_fallback_fonts$jscomp$1_paragraph_set$jscomp$3$$=$APP.$cljs$core$first$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$140_fallback_fonts$jscomp$1_paragraph_set$jscomp$3$$,$APP.$cljs$cst$342$children$$));for(var $paragraphs$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$140_fallback_fonts$jscomp$1_paragraph_set$jscomp$3$$,
$APP.$cljs$cst$342$children$$),$total$jscomp$10$$=$APP.$cljs$core$count$$($paragraphs$jscomp$5$$),$index$jscomp$242$$=0,$G__54802_G__54808_emoji_QMARK_$jscomp$6_emoji_QMARK___$1$$=!1,$G__54803_G__54809_langs_langs__$1$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$;;)if($index$jscomp$242$$<$total$jscomp$10$$){var $paragraph$jscomp$12_updated_fonts$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($paragraphs$jscomp$5$$,$index$jscomp$242$$),$spans$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($paragraph$jscomp$12_updated_fonts$$,
$APP.$cljs$cst$342$children$$);if($APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$seq$$($spans$jscomp$3$$)))$index$jscomp$242$$+=1;else{var $text$jscomp$38$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$spans$jscomp$3$$));$G__54802_G__54808_emoji_QMARK_$jscomp$6_emoji_QMARK___$1$$=$APP.$cljs$core$truth_$$($G__54802_G__54808_emoji_QMARK_$jscomp$6_emoji_QMARK___$1$$)?$G__54802_G__54808_emoji_QMARK_$jscomp$6_emoji_QMARK___$1$$:
$app$render_wasm$api$texts$contains_emoji_QMARK_$$($text$jscomp$38$$);$G__54803_G__54809_langs_langs__$1$$=$app$render_wasm$api$texts$collect_used_languages$$($G__54803_G__54809_langs_langs__$1$$,$text$jscomp$38$$);$APP.$cljs$core$truth_$$($fallback_fonts_only_QMARK_$$)&&$app$render_wasm$api$texts$write_shape_text$$($spans$jscomp$3$$,$paragraph$jscomp$12_updated_fonts$$,$text$jscomp$38$$);$index$jscomp$242$$+=1}}else return $paragraph$jscomp$12_updated_fonts$$=$app$render_wasm$api$fonts$add_noto_fonts$$($G__54802_G__54808_emoji_QMARK_$jscomp$6_emoji_QMARK___$1$$?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-color-emoji",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2978$is_emoji$$,!0,$cljs$cst$2979$is_fallback$$,!0],null)):$APP.$cljs$core$PersistentHashSet$EMPTY$$,$G__54803_G__54809_langs_langs__$1$$),$content$jscomp$140_fallback_fonts$jscomp$1_paragraph_set$jscomp$3$$=
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function(){return function($p1__54059_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__54059_SHARP_$$,$cljs$cst$2979$is_fallback$$)}}($index$jscomp$242$$,$G__54802_G__54808_emoji_QMARK_$jscomp$6_emoji_QMARK___$1$$,$G__54803_G__54809_langs_langs__$1$$,$paragraph$jscomp$12_updated_fonts$$,$content$jscomp$140_fallback_fonts$jscomp$1_paragraph_set$jscomp$3$$,$paragraphs$jscomp$5$$,$total$jscomp$10$$),$paragraph$jscomp$12_updated_fonts$$),
$APP.$cljs$core$truth_$$($fallback_fonts_only_QMARK_$$)?$paragraph$jscomp$12_updated_fonts$$:$content$jscomp$140_fallback_fonts$jscomp$1_paragraph_set$jscomp$3$$};
$app$render_wasm$api$set_shape_grow_type$$=function($cause54063_grow_type$jscomp$4$$){var $code__52999__auto__$jscomp$70_code_num__52998__auto__$jscomp$70_fn_54062_read_code_fn__52997__auto__$jscomp$70$$=$APP.$app$render_wasm$wasm$internal_module$$._set_shape_grow_type;try{var $values$jscomp$inline_6024$$=$app$render_wasm$wasm$serializers$$["grow-type"],$default$$jscomp$inline_6025$$=$values$jscomp$inline_6024$$.fixed;var $JSCompiler_inline_result$jscomp$997_hint__53000__auto__$jscomp$70$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$inline_6024$$[$APP.$app$common$data$name$$($cause54063_grow_type$jscomp$4$$)],
$default$$jscomp$inline_6025$$);return $code__52999__auto__$jscomp$70_code_num__52998__auto__$jscomp$70_fn_54062_read_code_fn__52997__auto__$jscomp$70$$($JSCompiler_inline_result$jscomp$997_hint__53000__auto__$jscomp$70$$)}catch($e54064$$){throw $cause54063_grow_type$jscomp$4$$=$e54064$$,$code__52999__auto__$jscomp$70_code_num__52998__auto__$jscomp$70_fn_54062_read_code_fn__52997__auto__$jscomp$70$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$70_code_num__52998__auto__$jscomp$70_fn_54062_read_code_fn__52997__auto__$jscomp$70$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$70_code_num__52998__auto__$jscomp$70_fn_54062_read_code_fn__52997__auto__$jscomp$70$$)?$code__52999__auto__$jscomp$70_code_num__52998__auto__$jscomp$70_fn_54062_read_code_fn__52997__auto__$jscomp$70$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$70_code_num__52998__auto__$jscomp$70_fn_54062_read_code_fn__52997__auto__$jscomp$70$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$70_code_num__52998__auto__$jscomp$70_fn_54062_read_code_fn__52997__auto__$jscomp$70$$():
null,$code__52999__auto__$jscomp$70_code_num__52998__auto__$jscomp$70_fn_54062_read_code_fn__52997__auto__$jscomp$70$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$70_code_num__52998__auto__$jscomp$70_fn_54062_read_code_fn__52997__auto__$jscomp$70$$,$APP.$cljs$cst$2971$wasm_critical$$),$JSCompiler_inline_result$jscomp$997_hint__53000__auto__$jscomp$70$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$70_code_num__52998__auto__$jscomp$70_fn_54062_read_code_fn__52997__auto__$jscomp$70$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$997_hint__53000__auto__$jscomp$70$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_shape_grow_type",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$JSCompiler_inline_result$jscomp$997_hint__53000__auto__$jscomp$70$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$70_code_num__52998__auto__$jscomp$70_fn_54062_read_code_fn__52997__auto__$jscomp$70$$],
null),$cause54063_grow_type$jscomp$4$$);}};
$APP.$app$render_wasm$api$get_text_dimensions$cljs$0core$0IFn$0_invoke$0arity$00$$=function(){if($APP.$app$render_wasm$api$initialized_QMARK_$$()){var $code__52999__auto__$jscomp$inline_6031_code_num__52998__auto__$jscomp$inline_6030_fn_54069$jscomp$inline_6027_height$jscomp$86_read_code_fn__52997__auto__$jscomp$inline_6029$$=$APP.$app$render_wasm$wasm$internal_module$$._get_text_dimensions;try{var $JSCompiler_inline_result$jscomp$1039_cause54070$jscomp$inline_6028_width$jscomp$97$$=$code__52999__auto__$jscomp$inline_6031_code_num__52998__auto__$jscomp$inline_6030_fn_54069$jscomp$inline_6027_height$jscomp$86_read_code_fn__52997__auto__$jscomp$inline_6029$$()}catch($e54071$jscomp$inline_6033$$){$JSCompiler_inline_result$jscomp$1039_cause54070$jscomp$inline_6028_width$jscomp$97$$=
$e54071$jscomp$inline_6033$$;$code__52999__auto__$jscomp$inline_6031_code_num__52998__auto__$jscomp$inline_6030_fn_54069$jscomp$inline_6027_height$jscomp$86_read_code_fn__52997__auto__$jscomp$inline_6029$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$inline_6031_code_num__52998__auto__$jscomp$inline_6030_fn_54069$jscomp$inline_6027_height$jscomp$86_read_code_fn__52997__auto__$jscomp$inline_6029$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_6031_code_num__52998__auto__$jscomp$inline_6030_fn_54069$jscomp$inline_6027_height$jscomp$86_read_code_fn__52997__auto__$jscomp$inline_6029$$)?
$code__52999__auto__$jscomp$inline_6031_code_num__52998__auto__$jscomp$inline_6030_fn_54069$jscomp$inline_6027_height$jscomp$86_read_code_fn__52997__auto__$jscomp$inline_6029$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$inline_6031_code_num__52998__auto__$jscomp$inline_6030_fn_54069$jscomp$inline_6027_height$jscomp$86_read_code_fn__52997__auto__$jscomp$inline_6029$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$inline_6031_code_num__52998__auto__$jscomp$inline_6030_fn_54069$jscomp$inline_6027_height$jscomp$86_read_code_fn__52997__auto__$jscomp$inline_6029$$():
null;$code__52999__auto__$jscomp$inline_6031_code_num__52998__auto__$jscomp$inline_6030_fn_54069$jscomp$inline_6027_height$jscomp$86_read_code_fn__52997__auto__$jscomp$inline_6029$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$inline_6031_code_num__52998__auto__$jscomp$inline_6030_fn_54069$jscomp$inline_6027_height$jscomp$86_read_code_fn__52997__auto__$jscomp$inline_6029$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$inline_6032_max_width$jscomp$4$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_6031_code_num__52998__auto__$jscomp$inline_6030_fn_54069$jscomp$inline_6027_height$jscomp$86_read_code_fn__52997__auto__$jscomp$inline_6029$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$inline_6032_max_width$jscomp$4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_get_text_dimensions",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$inline_6032_max_width$jscomp$4$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_6031_code_num__52998__auto__$jscomp$inline_6030_fn_54069$jscomp$inline_6027_height$jscomp$86_read_code_fn__52997__auto__$jscomp$inline_6029$$],null),$JSCompiler_inline_result$jscomp$1039_cause54070$jscomp$inline_6028_width$jscomp$97$$);}var $offset$jscomp$157_y$jscomp$401$$=$JSCompiler_inline_result$jscomp$1039_cause54070$jscomp$inline_6028_width$jscomp$97$$>>
2,$heapf32$jscomp$3$$=$app$render_wasm$mem$get_heap_f32$$();$JSCompiler_inline_result$jscomp$1039_cause54070$jscomp$inline_6028_width$jscomp$97$$=$heapf32$jscomp$3$$[$offset$jscomp$157_y$jscomp$401$$+0];$code__52999__auto__$jscomp$inline_6031_code_num__52998__auto__$jscomp$inline_6030_fn_54069$jscomp$inline_6027_height$jscomp$86_read_code_fn__52997__auto__$jscomp$inline_6029$$=$heapf32$jscomp$3$$[$offset$jscomp$157_y$jscomp$401$$+1];$hint__53000__auto__$jscomp$inline_6032_max_width$jscomp$4$$=$heapf32$jscomp$3$$[$offset$jscomp$157_y$jscomp$401$$+
2];var $x$jscomp$1163$$=$heapf32$jscomp$3$$[$offset$jscomp$157_y$jscomp$401$$+3];$offset$jscomp$157_y$jscomp$401$$=$heapf32$jscomp$3$$[$offset$jscomp$157_y$jscomp$401$$+4];$APP.$app$render_wasm$mem$free$$();return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1510$x$$,$x$jscomp$1163$$,$APP.$cljs$cst$1511$y$$,$offset$jscomp$157_y$jscomp$401$$,$APP.$cljs$cst$290$width$$,$JSCompiler_inline_result$jscomp$1039_cause54070$jscomp$inline_6028_width$jscomp$97$$,$APP.$cljs$cst$1522$height$$,
$code__52999__auto__$jscomp$inline_6031_code_num__52998__auto__$jscomp$inline_6030_fn_54069$jscomp$inline_6027_height$jscomp$86_read_code_fn__52997__auto__$jscomp$inline_6029$$,$APP.$cljs$cst$281$max_width$$,$hint__53000__auto__$jscomp$inline_6032_max_width$jscomp$4$$],null)}return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1510$x$$,0,$APP.$cljs$cst$1511$y$$,0,$APP.$cljs$cst$290$width$$,0,$APP.$cljs$cst$1522$height$$,0,$APP.$cljs$cst$281$max_width$$,0],null)};
$APP.$app$render_wasm$api$view_interaction_start_BANG_$$=function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($app$render_wasm$api$view_interaction_active_QMARK_$$)))return null;var $cause54078_54812_fn_54077_54811$$=$APP.$app$render_wasm$wasm$internal_module$$._set_view_start;try{$cause54078_54812_fn_54077_54811$$()}catch($e54079$$){$cause54078_54812_fn_54077_54811$$=$e54079$$;var $code__52999__auto___54815_code_num__52998__auto___54814_read_code_fn__52997__auto___54813$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;
$code__52999__auto___54815_code_num__52998__auto___54814_read_code_fn__52997__auto___54813$$=$APP.$cljs$core$truth_$$($code__52999__auto___54815_code_num__52998__auto___54814_read_code_fn__52997__auto___54813$$)?$code__52999__auto___54815_code_num__52998__auto___54814_read_code_fn__52997__auto___54813$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___54815_code_num__52998__auto___54814_read_code_fn__52997__auto___54813$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___54815_code_num__52998__auto___54814_read_code_fn__52997__auto___54813$$():
null;$code__52999__auto___54815_code_num__52998__auto___54814_read_code_fn__52997__auto___54813$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54815_code_num__52998__auto___54814_read_code_fn__52997__auto___54813$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto___54816$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54815_code_num__52998__auto___54814_read_code_fn__52997__auto___54813$$),")"].join("");
throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54816$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_view_start",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54816$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54815_code_num__52998__auto___54814_read_code_fn__52997__auto___54813$$],null),$cause54078_54812_fn_54077_54811$$);}return $APP.$cljs$core$reset_BANG_$$($app$render_wasm$api$view_interaction_active_QMARK_$$,
!0)};
$APP.$app$render_wasm$api$view_interaction_end_BANG_$$=function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($app$render_wasm$api$view_interaction_active_QMARK_$$))){performance.mark("render-finish::begin");var $cause54081_54823_fn_54080_54822$$=$APP.$app$render_wasm$wasm$internal_module$$._set_view_end;try{$cause54081_54823_fn_54080_54822$$()}catch($e54082$$){$cause54081_54823_fn_54080_54822$$=$e54082$$;var $code__52999__auto___54826_code_num__52998__auto___54825_read_code_fn__52997__auto___54824$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;
$code__52999__auto___54826_code_num__52998__auto___54825_read_code_fn__52997__auto___54824$$=$APP.$cljs$core$truth_$$($code__52999__auto___54826_code_num__52998__auto___54825_read_code_fn__52997__auto___54824$$)?$code__52999__auto___54826_code_num__52998__auto___54825_read_code_fn__52997__auto___54824$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___54826_code_num__52998__auto___54825_read_code_fn__52997__auto___54824$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___54826_code_num__52998__auto___54825_read_code_fn__52997__auto___54824$$():
null;$code__52999__auto___54826_code_num__52998__auto___54825_read_code_fn__52997__auto___54824$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54826_code_num__52998__auto___54825_read_code_fn__52997__auto___54824$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto___54827$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54826_code_num__52998__auto___54825_read_code_fn__52997__auto___54824$$),")"].join("");
throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54827$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_view_end",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54827$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54826_code_num__52998__auto___54825_read_code_fn__52997__auto___54824$$],null),$cause54081_54823_fn_54080_54822$$);}performance.mark("render-finish::end");
performance.measure("render-finish",{start:"render-finish::begin",end:"render-finish::end",detail:{}});return $APP.$cljs$core$reset_BANG_$$($app$render_wasm$api$view_interaction_active_QMARK_$$,!1)}return null};
$APP.$app$render_wasm$api$set_view_box$$=function($cause54099_54831_cause54107_54839_fn_54106_54838_zoom$jscomp$1$$,$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$){performance.mark("set-view-box::begin");$APP.$app$render_wasm$api$view_interaction_start_BANG_$$();var $fn_54098_54830_hint__53000__auto___54835_hint__53000__auto___54843$$=$APP.$app$render_wasm$wasm$internal_module$$._set_view;
try{$fn_54098_54830_hint__53000__auto___54835_hint__53000__auto___54843$$($cause54099_54831_cause54107_54839_fn_54106_54838_zoom$jscomp$1$$,-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$),-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$))}catch($e54100$$){throw $cause54099_54831_cause54107_54839_fn_54106_54838_zoom$jscomp$1$$=
$e54100$$,$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$=$APP.$cljs$core$truth_$$($code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$)?
$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$():
null,$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$,$APP.$cljs$cst$2971$wasm_critical$$),
$fn_54098_54830_hint__53000__auto___54835_hint__53000__auto___54843$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_54098_54830_hint__53000__auto___54835_hint__53000__auto___54843$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$516$fn$$,"_set_view",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_54098_54830_hint__53000__auto___54835_hint__53000__auto___54843$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$],null),$cause54099_54831_cause54107_54839_fn_54106_54838_zoom$jscomp$1$$);}performance.mark("set-view-box::end");
performance.measure("set-view-box",{start:"set-view-box::begin",end:"set-view-box::end",detail:{}});performance.mark("render-from-cache::begin");$cause54099_54831_cause54107_54839_fn_54106_54838_zoom$jscomp$1$$=$APP.$app$render_wasm$wasm$internal_module$$._render_from_cache;try{$cause54099_54831_cause54107_54839_fn_54106_54838_zoom$jscomp$1$$(0)}catch($e54108$$){throw $cause54099_54831_cause54107_54839_fn_54106_54838_zoom$jscomp$1$$=$e54108$$,$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$=$APP.$cljs$core$truth_$$($code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$)?$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$():null,$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$,$APP.$cljs$cst$2971$wasm_critical$$),$fn_54098_54830_hint__53000__auto___54835_hint__53000__auto___54843$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_54098_54830_hint__53000__auto___54835_hint__53000__auto___54843$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_render_from_cache",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_54098_54830_hint__53000__auto___54835_hint__53000__auto___54843$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54834_code__52999__auto___54842_code_num__52998__auto___54833_code_num__52998__auto___54841_read_code_fn__52997__auto___54832_read_code_fn__52997__auto___54840_vbox$jscomp$1$$],
null),$cause54099_54831_cause54107_54839_fn_54106_54838_zoom$jscomp$1$$);}$app$render_wasm$api$render_finish$$.$cljs$core$IFn$_invoke$arity$0$?$app$render_wasm$api$render_finish$$.$cljs$core$IFn$_invoke$arity$0$():$app$render_wasm$api$render_finish$$();performance.mark("render-from-cache::end");return performance.measure("render-from-cache",{start:"render-from-cache::begin",end:"render-from-cache::end",detail:{}})};
$APP.$app$render_wasm$api$set_object$$=function($id$jscomp$332_pending_full_shape$jscomp$358$$){performance.mark("set-object::begin");if($APP.$cljs$core$truth_$$($id$jscomp$332_pending_full_shape$jscomp$358$$)){var $pending_thumbnails_shape__$1$jscomp$29$$=$app$render_wasm$svg_filters$apply_svg_derived$$($id$jscomp$332_pending_full_shape$jscomp$358$$);$id$jscomp$332_pending_full_shape$jscomp$358$$=$pending_thumbnails_shape__$1$jscomp$29$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pending_thumbnails_shape__$1$jscomp$29$$,
$APP.$cljs$cst$266$id$$);var $is_text_QMARK__type$jscomp$420$$=$pending_thumbnails_shape__$1$jscomp$29$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pending_thumbnails_shape__$1$jscomp$29$$,$APP.$cljs$cst$139$type$$),$masked$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pending_thumbnails_shape__$1$jscomp$29$$,$APP.$cljs$cst$1609$masked_group$$),$fills$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pending_thumbnails_shape__$1$jscomp$29$$,
$APP.$cljs$cst$1634$fills$$),$strokes$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($is_text_QMARK__type$jscomp$420$$,$APP.$cljs$cst$1608$group$$)?$APP.$cljs$core$PersistentVector$EMPTY$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pending_thumbnails_shape__$1$jscomp$29$$,$APP.$cljs$cst$1636$strokes$$),$children$jscomp$202$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pending_thumbnails_shape__$1$jscomp$29$$,$APP.$cljs$cst$1614$shapes$$);var $content$jscomp$142_content$jscomp$inline_12254$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pending_thumbnails_shape__$1$jscomp$29$$,$APP.$cljs$cst$1637$content$$);$content$jscomp$142_content$jscomp$inline_12254$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($is_text_QMARK__type$jscomp$420$$,$APP.$cljs$cst$1588$text$$)?$APP.$cljs$core$truth_$$($content$jscomp$142_content$jscomp$inline_12254$$)?$content$jscomp$142_content$jscomp$inline_12254$$:$app$util$text$content$v2_default_text_content$$():$content$jscomp$142_content$jscomp$inline_12254$$;
var $bool_type$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pending_thumbnails_shape__$1$jscomp$29$$,$APP.$cljs$cst$1888$bool_type$$),$grow_type$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pending_thumbnails_shape__$1$jscomp$29$$,$APP.$cljs$cst$1770$grow_type$$),$blur$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pending_thumbnails_shape__$1$jscomp$29$$,$APP.$cljs$cst$1653$blur$$),$svg_attrs$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pending_thumbnails_shape__$1$jscomp$29$$,
$APP.$cljs$cst$1890$svg_attrs$$),$shadows$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pending_thumbnails_shape__$1$jscomp$29$$,$APP.$cljs$cst$1654$shadow$$);$app$render_wasm$api$shapes$set_shape_base_props$$($pending_thumbnails_shape__$1$jscomp$29$$);$app$render_wasm$api$set_shape_children$$($children$jscomp$202$$);$app$render_wasm$api$set_shape_blur$$($blur$jscomp$6$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($is_text_QMARK__type$jscomp$420$$,$APP.$cljs$cst$1608$group$$)&&
$app$render_wasm$api$set_masked$$($APP.$cljs$core$boolean$0$$($masked$jscomp$1$$));$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($is_text_QMARK__type$jscomp$420$$,$APP.$cljs$cst$1610$bool$$)&&$app$render_wasm$api$set_shape_bool_type$$($bool_type$jscomp$5$$);$content$jscomp$142_content$jscomp$inline_12254$$!=null&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($is_text_QMARK__type$jscomp$420$$,$APP.$cljs$cst$296$path$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($is_text_QMARK__type$jscomp$420$$,
$APP.$cljs$cst$1610$bool$$))&&$app$render_wasm$api$set_shape_path_content$$($content$jscomp$142_content$jscomp$inline_12254$$);$svg_attrs$jscomp$4$$!=null&&$app$render_wasm$api$set_shape_svg_attrs$$($svg_attrs$jscomp$4$$);$content$jscomp$142_content$jscomp$inline_12254$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($is_text_QMARK__type$jscomp$420$$,$APP.$cljs$cst$1613$svg_raw$$)&&$app$render_wasm$api$set_shape_svg_raw_content$$($app$render_wasm$api$get_static_markup$$($pending_thumbnails_shape__$1$jscomp$29$$));
$app$render_wasm$api$set_shape_shadows$$($shadows$jscomp$1$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($is_text_QMARK__type$jscomp$420$$,$APP.$cljs$cst$1588$text$$)&&$app$render_wasm$api$set_shape_grow_type$$($grow_type$jscomp$5$$);$app$render_wasm$api$clear_layout$$();$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($pending_thumbnails_shape__$1$jscomp$29$$)&&$app$render_wasm$api$set_flex_layout$$($pending_thumbnails_shape__$1$jscomp$29$$);$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($pending_thumbnails_shape__$1$jscomp$29$$)&&
$app$render_wasm$api$set_grid_layout$$($pending_thumbnails_shape__$1$jscomp$29$$);$app$render_wasm$api$set_layout_data$$($pending_thumbnails_shape__$1$jscomp$29$$);$is_text_QMARK__type$jscomp$420$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($is_text_QMARK__type$jscomp$420$$,$APP.$cljs$cst$1588$text$$);$pending_thumbnails_shape__$1$jscomp$29$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($is_text_QMARK__type$jscomp$420$$?
$APP.$app$render_wasm$api$set_shape_text_content$$($id$jscomp$332_pending_full_shape$jscomp$358$$,$content$jscomp$142_content$jscomp$inline_12254$$):null,$is_text_QMARK__type$jscomp$420$$?$app$render_wasm$api$set_shape_text_images$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$332_pending_full_shape$jscomp$358$$,$content$jscomp$142_content$jscomp$inline_12254$$,!0):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$render_wasm$api$set_shape_fills$$($id$jscomp$332_pending_full_shape$jscomp$358$$,
$fills$jscomp$20$$,!0),$app$render_wasm$api$set_shape_strokes$$($id$jscomp$332_pending_full_shape$jscomp$358$$,$strokes$jscomp$6$$,!0)])));$id$jscomp$332_pending_full_shape$jscomp$358$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($is_text_QMARK__type$jscomp$420$$?$app$render_wasm$api$set_shape_text_images$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$332_pending_full_shape$jscomp$358$$,
$content$jscomp$142_content$jscomp$inline_12254$$,!1):null,$app$render_wasm$api$set_shape_fills$$($id$jscomp$332_pending_full_shape$jscomp$358$$,$fills$jscomp$20$$,!1),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$render_wasm$api$set_shape_strokes$$($id$jscomp$332_pending_full_shape$jscomp$358$$,$strokes$jscomp$6$$,!1)])));performance.mark("set-object::end");performance.measure("set-object",{start:"set-object::begin",end:"set-object::end",detail:{}});return new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2229$thumbnails$$,$pending_thumbnails_shape__$1$jscomp$29$$,$APP.$cljs$cst$1273$full$$,$id$jscomp$332_pending_full_shape$jscomp$358$$],null)}return null};
$app$render_wasm$api$process_pending$$=function($shapes$jscomp$25$$,$pending_thumbnails$jscomp$1_thumbnails$$,$full_pending_full$jscomp$1$$,$on_complete$jscomp$1$$){$pending_thumbnails$jscomp$1_thumbnails$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$302$key$$,$APP.$cljs$cst$2354$callback$$,$pending_thumbnails$jscomp$1_thumbnails$$);$full_pending_full$jscomp$1$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$302$key$$,$APP.$cljs$cst$2354$callback$$,
$full_pending_full$jscomp$1$$);var $text_ids_54852$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$text_shape_QMARK_$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$)),$shapes$jscomp$25$$);$APP.$cljs$core$seq$$($text_ids_54852$$)&&$APP.$cljs$core$run_BANG_$$($app$render_wasm$api$fonts$update_text_layout$$,
$text_ids_54852$$);return $APP.$cljs$core$seq$$($pending_thumbnails$jscomp$1_thumbnails$$)||$APP.$cljs$core$seq$$($full_pending_full$jscomp$1$$)?$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$(function(){var $text_ids_54853$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$text_shape_QMARK_$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$)),$shapes$jscomp$25$$);$APP.$cljs$core$seq$$($text_ids_54853$$)&&$APP.$cljs$core$run_BANG_$$($app$render_wasm$api$fonts$update_text_layout$$,$text_ids_54853$$);return $APP.$app$render_wasm$api$request_render$$("images-loaded")},$APP.$app$render_wasm$api$noop_fn$$,function(){return $APP.$cljs$core$fn_QMARK_$$($on_complete$jscomp$1$$)?$on_complete$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$on_complete$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():
$on_complete$jscomp$1$$():null},$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$merge_map$$(function($callback$jscomp$83$$){return $APP.$cljs$core$fn_QMARK_$$($callback$jscomp$83$$)?$callback$jscomp$83$$.$cljs$core$IFn$_invoke$arity$0$?$callback$jscomp$83$$.$cljs$core$IFn$_invoke$arity$0$():
$callback$jscomp$83$$():$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$from$$($APP.$cljs$core$vals$$($pending_thumbnails$jscomp$1_thumbnails$$))))),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$mapcat$$(function($callback$jscomp$84$$){return $APP.$cljs$core$fn_QMARK_$$($callback$jscomp$84$$)?
$callback$jscomp$84$$.$cljs$core$IFn$_invoke$arity$0$?$callback$jscomp$84$$.$cljs$core$IFn$_invoke$arity$0$():$callback$jscomp$84$$():$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$from$$($APP.$cljs$core$vals$$($full_pending_full$jscomp$1$$))))))):$APP.$cljs$core$truth_$$($on_complete$jscomp$1$$)?$on_complete$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$on_complete$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_complete$jscomp$1$$():null};
$app$render_wasm$api$process_object$$=function($shape$jscomp$359$$){var $map__54149_thumbnails$jscomp$1$$=$APP.$app$render_wasm$api$set_object$$($shape$jscomp$359$$),$full$jscomp$1_map__54149__$1$$=$APP.$cljs$core$__destructure_map$$($map__54149_thumbnails$jscomp$1$$);$map__54149_thumbnails$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$1_map__54149__$1$$,$APP.$cljs$cst$2229$thumbnails$$);$full$jscomp$1_map__54149__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$1_map__54149__$1$$,
$APP.$cljs$cst$1273$full$$);$app$render_wasm$api$process_pending$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$359$$],null),$map__54149_thumbnails$jscomp$1$$,$full$jscomp$1_map__54149__$1$$,$APP.$app$render_wasm$api$noop_fn$$)};
$app$render_wasm$api$process_shapes_chunk$$=function($shapes$jscomp$26$$,$start_index$jscomp$1$$,$G__54855_t_acc_thumbnails_acc$$,$G__54856_f_acc_full_acc$$){var $total$jscomp$12$$=$APP.$cljs$core$count$$($shapes$jscomp$26$$),$deadline$$=performance.now()+8,$G__54854_index$jscomp$244$$=$start_index$jscomp$1$$;$G__54855_t_acc_thumbnails_acc$$=$APP.$cljs$core$_as_transient$$($G__54855_t_acc_thumbnails_acc$$);for($G__54856_f_acc_full_acc$$=$APP.$cljs$core$_as_transient$$($G__54856_f_acc_full_acc$$);;)if($G__54854_index$jscomp$244$$<
$total$jscomp$12$$&&(($G__54854_index$jscomp$244$$-$start_index$jscomp$1$$&7)>0||performance.now()<=$deadline$$)){var $map__54162_shape$jscomp$360_thumbnails$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($shapes$jscomp$26$$,$G__54854_index$jscomp$244$$);$map__54162_shape$jscomp$360_thumbnails$jscomp$2$$=$APP.$app$render_wasm$api$set_object$$($map__54162_shape$jscomp$360_thumbnails$jscomp$2$$);var $full$jscomp$2_map__54162__$1$$=$APP.$cljs$core$__destructure_map$$($map__54162_shape$jscomp$360_thumbnails$jscomp$2$$);
$map__54162_shape$jscomp$360_thumbnails$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$2_map__54162__$1$$,$APP.$cljs$cst$2229$thumbnails$$);$full$jscomp$2_map__54162__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$2_map__54162__$1$$,$APP.$cljs$cst$1273$full$$);$G__54854_index$jscomp$244$$+=1;$G__54855_t_acc_thumbnails_acc$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj_BANG_$$,$G__54855_t_acc_thumbnails_acc$$,
$map__54162_shape$jscomp$360_thumbnails$jscomp$2$$);$G__54856_f_acc_full_acc$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj_BANG_$$,$G__54856_f_acc_full_acc$$,$full$jscomp$2_map__54162__$1$$)}else return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2229$thumbnails$$,$APP.$cljs$core$_persistent_BANG_$$($G__54855_t_acc_thumbnails_acc$$),$APP.$cljs$cst$1273$full$$,$APP.$cljs$core$_persistent_BANG_$$($G__54856_f_acc_full_acc$$),$cljs$cst$3090$next_index$$,
$G__54854_index$jscomp$244$$],null)};
$app$render_wasm$api$set_objects_async$$=function($shapes$jscomp$27$$,$render_callback$$,$on_shapes_ready$$){var $total_shapes$$=$APP.$cljs$core$count$$($shapes$jscomp$27$$);return $promesa$core$create$cljs$0core$0IFn$0_invoke$0arity$01$$(function($resolve$jscomp$27$$){return function $app$render_wasm$api$set_objects_async_$_process_next_chunk$$($fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$,$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$,
$cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$){if($fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$<$total_shapes$$){$cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$=$app$render_wasm$api$process_shapes_chunk$$($shapes$jscomp$27$$,$fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$,
$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$,$cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$);$cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$);
var $thumbnails$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$,$APP.$cljs$cst$2229$thumbnails$$),$full$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$,$APP.$cljs$cst$1273$full$$),$next_index$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$,
$cljs$cst$3090$next_index$$);return $APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($app$render_wasm$api$yield_to_browser$$(),function(){return $app$render_wasm$api$set_objects_async_$_process_next_chunk$$($next_index$$,$thumbnails$jscomp$3$$,$full$jscomp$3$$)})}performance.mark("set-objects::end");performance.measure("set-objects",{start:"set-objects::begin",end:"set-objects::end",detail:{}});$APP.$cljs$core$truth_$$($on_shapes_ready$$)&&($on_shapes_ready$$.$cljs$core$IFn$_invoke$arity$0$?
$on_shapes_ready$$.$cljs$core$IFn$_invoke$arity$0$():$on_shapes_ready$$());$fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$=$APP.$app$render_wasm$wasm$internal_module$$._end_loading;try{$fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$()}catch($e54189$$){throw $cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$=$e54189$$,
$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$=
$APP.$cljs$core$truth_$$($code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$)?$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$():
null,$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$,
$APP.$cljs$cst$2971$wasm_critical$$),$fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_end_loading",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$],
null),$cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$);}$app$render_wasm$api$end_shapes_loading_BANG_$$();$fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$=$APP.$app$render_wasm$wasm$internal_module$$._set_view_end;try{$fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$()}catch($e54192$$){throw $cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$=
$e54192$$,$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$=
$APP.$cljs$core$truth_$$($code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$)?$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$():
null,$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$,
$APP.$cljs$cst$2971$wasm_critical$$),$fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_view_end",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$],
null),$cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$);}$APP.$cljs$core$reset_BANG_$$($app$render_wasm$api$view_interaction_active_QMARK_$$,!1);$fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$text_shape_QMARK_$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$)),$shapes$jscomp$27$$);$APP.$cljs$core$seq$$($fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$)&&$APP.$cljs$core$run_BANG_$$($app$render_wasm$api$fonts$update_text_layout$$,$fn_54186_54857_fn_54190_54865_hint__53000__auto___54862_hint__53000__auto___54870_index$jscomp$245_text_ids_54873$$);$APP.$cljs$core$truth_$$($render_callback$$)?$render_callback$$.$cljs$core$IFn$_invoke$arity$0$?
$render_callback$$.$cljs$core$IFn$_invoke$arity$0$():$render_callback$$():$APP.$app$render_wasm$api$request_render$$("set-objects-complete");$app$util$globals$dispatch_BANG_$$($app$util$globals$event$$("penpot:wasm:set-objects"));$resolve$jscomp$27$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$27$$.$cljs$core$IFn$_invoke$arity$1$(null):$resolve$jscomp$27$$(null);$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$=
$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$302$key$$,$APP.$cljs$cst$2354$callback$$,$code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$);$cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$302$key$$,
$APP.$cljs$cst$2354$callback$$,$cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$);return $APP.$cljs$core$seq$$($code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$)||$APP.$cljs$core$seq$$($cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$)?
$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$(function(){var $text_ids_54878$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$text_shape_QMARK_$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$)),$shapes$jscomp$27$$);$APP.$cljs$core$seq$$($text_ids_54878$$)&&
$APP.$cljs$core$run_BANG_$$($app$render_wasm$api$fonts$update_text_layout$$,$text_ids_54878$$);return $APP.$app$render_wasm$api$request_render$$("images-loaded")},$APP.$app$render_wasm$api$noop_fn$$,$APP.$app$render_wasm$api$noop_fn$$,$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$merge_map$$(function($callback$jscomp$85$$){return $APP.$cljs$core$fn_QMARK_$$($callback$jscomp$85$$)?
$callback$jscomp$85$$.$cljs$core$IFn$_invoke$arity$0$?$callback$jscomp$85$$.$cljs$core$IFn$_invoke$arity$0$():$callback$jscomp$85$$():$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$from$$($APP.$cljs$core$vals$$($code__52999__auto___54861_code__52999__auto___54869_code_num__52998__auto___54860_code_num__52998__auto___54868_pending_thumbnails$jscomp$2_read_code_fn__52997__auto___54859_read_code_fn__52997__auto___54867_thumbnails_acc$jscomp$1$$)))),$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,
$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$mapcat$$(function($callback$jscomp$86$$){return $APP.$cljs$core$fn_QMARK_$$($callback$jscomp$86$$)?$callback$jscomp$86$$.$cljs$core$IFn$_invoke$arity$0$?$callback$jscomp$86$$.$cljs$core$IFn$_invoke$arity$0$():$callback$jscomp$86$$():$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$from$$($APP.$cljs$core$vals$$($cause54187_54858_cause54191_54866_full_acc$jscomp$1_map__54181_map__54181__$1_pending_full$jscomp$2$$)))))):null}(0,$APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$PersistentVector$EMPTY$$)})};
$app$render_wasm$api$set_objects_sync$$=function($shapes$jscomp$29$$,$render_callback$jscomp$1$$,$cause54214_54886_fn_54213_54885_on_shapes_ready$jscomp$1$$){var $total_shapes$jscomp$2$$=$APP.$cljs$core$count$$($shapes$jscomp$29$$),$code__52999__auto___54889_code_num__52998__auto___54888_map__54204_read_code_fn__52997__auto___54887_thumbnails$jscomp$7$$=function(){for(var $G__54882_index$jscomp$247$$=0,$G__54883_thumbnails_acc$jscomp$3$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$G__54884_full_acc$jscomp$3$$=
$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;)if($G__54882_index$jscomp$247$$<$total_shapes$jscomp$2$$){var $map__54208_shape$jscomp$362_thumbnails$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($shapes$jscomp$29$$,$G__54882_index$jscomp$247$$);$map__54208_shape$jscomp$362_thumbnails$jscomp$8$$=$APP.$app$render_wasm$api$set_object$$($map__54208_shape$jscomp$362_thumbnails$jscomp$8$$);var $full$jscomp$8_map__54208__$1$$=$APP.$cljs$core$__destructure_map$$($map__54208_shape$jscomp$362_thumbnails$jscomp$8$$);
$map__54208_shape$jscomp$362_thumbnails$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$8_map__54208__$1$$,$APP.$cljs$cst$2229$thumbnails$$);$full$jscomp$8_map__54208__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$8_map__54208__$1$$,$APP.$cljs$cst$1273$full$$);$G__54882_index$jscomp$247$$+=1;$G__54883_thumbnails_acc$jscomp$3$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj_BANG_$$,$G__54883_thumbnails_acc$jscomp$3$$,
$map__54208_shape$jscomp$362_thumbnails$jscomp$8$$);$G__54884_full_acc$jscomp$3$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj_BANG_$$,$G__54884_full_acc$jscomp$3$$,$full$jscomp$8_map__54208__$1$$)}else return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2229$thumbnails$$,$APP.$cljs$core$_persistent_BANG_$$($G__54883_thumbnails_acc$jscomp$3$$),$APP.$cljs$cst$1273$full$$,$APP.$cljs$core$_persistent_BANG_$$($G__54884_full_acc$jscomp$3$$)],null)}(),
$full$jscomp$7_hint__53000__auto___54890_map__54204__$1$$=$APP.$cljs$core$__destructure_map$$($code__52999__auto___54889_code_num__52998__auto___54888_map__54204_read_code_fn__52997__auto___54887_thumbnails$jscomp$7$$);$code__52999__auto___54889_code_num__52998__auto___54888_map__54204_read_code_fn__52997__auto___54887_thumbnails$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$7_hint__53000__auto___54890_map__54204__$1$$,$APP.$cljs$cst$2229$thumbnails$$);$full$jscomp$7_hint__53000__auto___54890_map__54204__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$7_hint__53000__auto___54890_map__54204__$1$$,$APP.$cljs$cst$1273$full$$);performance.mark("set-objects::end");performance.measure("set-objects",{start:"set-objects::begin",end:"set-objects::end",detail:{}});$APP.$cljs$core$truth_$$($cause54214_54886_fn_54213_54885_on_shapes_ready$jscomp$1$$)&&($cause54214_54886_fn_54213_54885_on_shapes_ready$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$cause54214_54886_fn_54213_54885_on_shapes_ready$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():
$cause54214_54886_fn_54213_54885_on_shapes_ready$jscomp$1$$());$cause54214_54886_fn_54213_54885_on_shapes_ready$jscomp$1$$=$APP.$app$render_wasm$wasm$internal_module$$._set_view_end;try{$cause54214_54886_fn_54213_54885_on_shapes_ready$jscomp$1$$()}catch($e54215$$){throw $cause54214_54886_fn_54213_54885_on_shapes_ready$jscomp$1$$=$e54215$$,$code__52999__auto___54889_code_num__52998__auto___54888_map__54204_read_code_fn__52997__auto___54887_thumbnails$jscomp$7$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,
$code__52999__auto___54889_code_num__52998__auto___54888_map__54204_read_code_fn__52997__auto___54887_thumbnails$jscomp$7$$=$APP.$cljs$core$truth_$$($code__52999__auto___54889_code_num__52998__auto___54888_map__54204_read_code_fn__52997__auto___54887_thumbnails$jscomp$7$$)?$code__52999__auto___54889_code_num__52998__auto___54888_map__54204_read_code_fn__52997__auto___54887_thumbnails$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___54889_code_num__52998__auto___54888_map__54204_read_code_fn__52997__auto___54887_thumbnails$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto___54889_code_num__52998__auto___54888_map__54204_read_code_fn__52997__auto___54887_thumbnails$jscomp$7$$():null,$code__52999__auto___54889_code_num__52998__auto___54888_map__54204_read_code_fn__52997__auto___54887_thumbnails$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54889_code_num__52998__auto___54888_map__54204_read_code_fn__52997__auto___54887_thumbnails$jscomp$7$$,$APP.$cljs$cst$2971$wasm_critical$$),
$full$jscomp$7_hint__53000__auto___54890_map__54204__$1$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54889_code_num__52998__auto___54888_map__54204_read_code_fn__52997__auto___54887_thumbnails$jscomp$7$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($full$jscomp$7_hint__53000__auto___54890_map__54204__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_view_end",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$full$jscomp$7_hint__53000__auto___54890_map__54204__$1$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54889_code_num__52998__auto___54888_map__54204_read_code_fn__52997__auto___54887_thumbnails$jscomp$7$$],null),$cause54214_54886_fn_54213_54885_on_shapes_ready$jscomp$1$$);}$APP.$cljs$core$reset_BANG_$$($app$render_wasm$api$view_interaction_active_QMARK_$$,!1);return $app$render_wasm$api$process_pending$$($shapes$jscomp$29$$,$code__52999__auto___54889_code_num__52998__auto___54888_map__54204_read_code_fn__52997__auto___54887_thumbnails$jscomp$7$$,
$full$jscomp$7_hint__53000__auto___54890_map__54204__$1$$,function(){$APP.$cljs$core$truth_$$($render_callback$jscomp$1$$)?$render_callback$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$render_callback$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$render_callback$jscomp$1$$():$APP.$app$render_wasm$api$request_render$$("set-objects-sync-complete");return $app$util$globals$dispatch_BANG_$$($app$util$globals$event$$("penpot:wasm:set-objects"))})};
$app$render_wasm$api$shapes_in_tree_order$$=function($objects$jscomp$238$$){if($APP.$cljs$core$contains_QMARK_$$($objects$jscomp$238$$,$APP.$app$common$uuid$zero$$)){var $all_ordered_ids_ordered_ids_top_level_ids$$=$app$common$files$helpers$get_children_ids_with_self$$($objects$jscomp$238$$,$APP.$app$common$uuid$zero$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__54218_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$238$$,
$p1__54218_SHARP_$$)}),$all_ordered_ids_ordered_ids_top_level_ids$$)}$all_ordered_ids_ordered_ids_top_level_ids$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($shape$jscomp$363$$){return!$APP.$cljs$core$contains_QMARK_$$($objects$jscomp$238$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$363$$))},$APP.$cljs$core$vals$$($objects$jscomp$238$$)));$all_ordered_ids_ordered_ids_top_level_ids$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__54219_SHARP_$$){return $app$common$files$helpers$get_children_ids_with_self$$($objects$jscomp$238$$,$p1__54219_SHARP_$$)}),$all_ordered_ids_ordered_ids_top_level_ids$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__54220_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$238$$,
$p1__54220_SHARP_$$)}),$all_ordered_ids_ordered_ids_top_level_ids$$)};$app$render_wasm$api$set_objects$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objects$jscomp$240$$,$render_callback$jscomp$2$$){return $app$render_wasm$api$set_objects$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$240$$,$render_callback$jscomp$2$$,null,!1)};
$app$render_wasm$api$set_objects$cljs$0core$0IFn$0_invoke$0arity$04$$=function($objects$jscomp$241_shapes$jscomp$30$$,$cause54224_54908_cause54229_54925_error_54923_render_callback$jscomp$3$$,$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$,$fn_54223_54904_force_sync_hint__53000__auto___54912_hint__53000__auto___54929$$){performance.mark("set-objects::begin");
$objects$jscomp$241_shapes$jscomp$30$$=$app$render_wasm$api$shapes_in_tree_order$$($objects$jscomp$241_shapes$jscomp$30$$);var $total_shapes$jscomp$3$$=$APP.$cljs$core$count$$($objects$jscomp$241_shapes$jscomp$30$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($fn_54223_54904_force_sync_hint__53000__auto___54912_hint__53000__auto___54929$$)?$fn_54223_54904_force_sync_hint__53000__auto___54912_hint__53000__auto___54929$$:$total_shapes$jscomp$3$$<100))return $app$render_wasm$api$set_objects_sync$$($objects$jscomp$241_shapes$jscomp$30$$,
$cause54224_54908_cause54229_54925_error_54923_render_callback$jscomp$3$$,$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$);$app$render_wasm$api$begin_shapes_loading_BANG_$$();$fn_54223_54904_force_sync_hint__53000__auto___54912_hint__53000__auto___54929$$=$APP.$app$render_wasm$wasm$internal_module$$._begin_loading;try{$fn_54223_54904_force_sync_hint__53000__auto___54912_hint__53000__auto___54929$$()}catch($e54225$$){throw $cause54224_54908_cause54229_54925_error_54923_render_callback$jscomp$3$$=
$e54225$$,$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$=
$APP.$cljs$core$truth_$$($code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$)?$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$():null,$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$,$APP.$cljs$cst$2971$wasm_critical$$),$fn_54223_54904_force_sync_hint__53000__auto___54912_hint__53000__auto___54929$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_54223_54904_force_sync_hint__53000__auto___54912_hint__53000__auto___54929$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_begin_loading",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_54223_54904_force_sync_hint__53000__auto___54912_hint__53000__auto___54929$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$],
null),$cause54224_54908_cause54229_54925_error_54923_render_callback$jscomp$3$$);}try{$promesa$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($app$render_wasm$api$set_objects_async$$($objects$jscomp$241_shapes$jscomp$30$$,$cause54224_54908_cause54229_54925_error_54923_render_callback$jscomp$3$$,$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$),
function($cause54234_54916_error$jscomp$50$$){var $code__52999__auto___54919_code_num__52998__auto___54918_fn_54233_54915_read_code_fn__52997__auto___54917$$=$APP.$app$render_wasm$wasm$internal_module$$._end_loading;try{$code__52999__auto___54919_code_num__52998__auto___54918_fn_54233_54915_read_code_fn__52997__auto___54917$$()}catch($e54235$$){$cause54234_54916_error$jscomp$50$$=$e54235$$;$code__52999__auto___54919_code_num__52998__auto___54918_fn_54233_54915_read_code_fn__52997__auto___54917$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___54919_code_num__52998__auto___54918_fn_54233_54915_read_code_fn__52997__auto___54917$$=$APP.$cljs$core$truth_$$($code__52999__auto___54919_code_num__52998__auto___54918_fn_54233_54915_read_code_fn__52997__auto___54917$$)?$code__52999__auto___54919_code_num__52998__auto___54918_fn_54233_54915_read_code_fn__52997__auto___54917$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___54919_code_num__52998__auto___54918_fn_54233_54915_read_code_fn__52997__auto___54917$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto___54919_code_num__52998__auto___54918_fn_54233_54915_read_code_fn__52997__auto___54917$$():null;$code__52999__auto___54919_code_num__52998__auto___54918_fn_54233_54915_read_code_fn__52997__auto___54917$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54919_code_num__52998__auto___54918_fn_54233_54915_read_code_fn__52997__auto___54917$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto___54920$$=["WASM Error (",
$APP.$app$common$data$name$$($code__52999__auto___54919_code_num__52998__auto___54918_fn_54233_54915_read_code_fn__52997__auto___54917$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54920$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_end_loading",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54920$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54919_code_num__52998__auto___54918_fn_54233_54915_read_code_fn__52997__auto___54917$$],
null),$cause54234_54916_error$jscomp$50$$);}$app$render_wasm$api$end_shapes_loading_BANG_$$();return console.error("Async WASM shape loading failed",$cause54234_54916_error$jscomp$50$$)})}catch($e54227$$){$cause54224_54908_cause54229_54925_error_54923_render_callback$jscomp$3$$=$e54227$$;$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$=
$APP.$app$render_wasm$wasm$internal_module$$._end_loading;try{$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$()}catch($e54231$$){throw $cause54224_54908_cause54229_54925_error_54923_render_callback$jscomp$3$$=$e54231$$,$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$=$APP.$cljs$core$truth_$$($code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$)?
$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$():null,$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$,$APP.$cljs$cst$2971$wasm_critical$$),$fn_54223_54904_force_sync_hint__53000__auto___54912_hint__53000__auto___54929$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_54223_54904_force_sync_hint__53000__auto___54912_hint__53000__auto___54929$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_end_loading",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_54223_54904_force_sync_hint__53000__auto___54912_hint__53000__auto___54929$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54911_code__52999__auto___54928_code_num__52998__auto___54910_code_num__52998__auto___54927_fn_54228_54924_on_shapes_ready$jscomp$2_read_code_fn__52997__auto___54909_read_code_fn__52997__auto___54926$$],
null),$cause54224_54908_cause54229_54925_error_54923_render_callback$jscomp$3$$);}$app$render_wasm$api$end_shapes_loading_BANG_$$();console.error("Async WASM shape loading failed",$cause54224_54908_cause54229_54925_error_54923_render_callback$jscomp$3$$);throw $cause54224_54908_cause54229_54925_error_54923_render_callback$jscomp$3$$;}return null};
$app$render_wasm$api$set_structure_modifiers$$=function($cause54261_entries$jscomp$16_fn_54260$$){if(!$APP.$cljs$core$empty_QMARK_$$($cause54261_entries$jscomp$16_fn_54260$$)){var $code__52999__auto__$jscomp$74_code_num__52998__auto__$jscomp$74_offset$jscomp$159_read_code_fn__52997__auto__$jscomp$74_size$jscomp$113$$=44*$APP.$cljs$core$count$$($cause54261_entries$jscomp$16_fn_54260$$);$code__52999__auto__$jscomp$74_code_num__52998__auto__$jscomp$74_offset$jscomp$159_read_code_fn__52997__auto__$jscomp$74_size$jscomp$113$$=
$APP.$app$render_wasm$mem$alloc__GT_offset_32$$($code__52999__auto__$jscomp$74_code_num__52998__auto__$jscomp$74_offset$jscomp$159_read_code_fn__52997__auto__$jscomp$74_size$jscomp$113$$);var $heapu32$jscomp$2$$=$APP.$app$render_wasm$mem$get_heap_u32$$(),$heapf32$jscomp$4$$=$app$render_wasm$mem$get_heap_f32$$();$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($offset$jscomp$inline_6038_offset__$1$jscomp$11$$,$p__54256_parent$jscomp$203$$){var $map__54257__$1_value$jscomp$518$$=
$APP.$cljs$core$__destructure_map$$($p__54256_parent$jscomp$203$$),$G__53228__$1$jscomp$inline_6036_JSCompiler_inline_result$jscomp$996_type$jscomp$421$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54257__$1_value$jscomp$518$$,$APP.$cljs$cst$139$type$$);$p__54256_parent$jscomp$203$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54257__$1_value$jscomp$518$$,$APP.$cljs$cst$1365$parent$$);var $id$jscomp$334$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54257__$1_value$jscomp$518$$,
$APP.$cljs$cst$266$id$$),$index$jscomp$248$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54257__$1_value$jscomp$518$$,$APP.$cljs$cst$1795$index$$);$map__54257__$1_value$jscomp$518$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54257__$1_value$jscomp$518$$,$APP.$cljs$cst$260$value$$);a:switch($G__53228__$1$jscomp$inline_6036_JSCompiler_inline_result$jscomp$996_type$jscomp$421$$=$G__53228__$1$jscomp$inline_6036_JSCompiler_inline_result$jscomp$996_type$jscomp$421$$ instanceof
$APP.$cljs$core$Keyword$$?$G__53228__$1$jscomp$inline_6036_JSCompiler_inline_result$jscomp$996_type$jscomp$421$$.$fqn$:null,$G__53228__$1$jscomp$inline_6036_JSCompiler_inline_result$jscomp$996_type$jscomp$421$$){case "remove-children":$G__53228__$1$jscomp$inline_6036_JSCompiler_inline_result$jscomp$996_type$jscomp$421$$=1;break a;case "add-children":$G__53228__$1$jscomp$inline_6036_JSCompiler_inline_result$jscomp$996_type$jscomp$421$$=2;break a;case "scale-content":$G__53228__$1$jscomp$inline_6036_JSCompiler_inline_result$jscomp$996_type$jscomp$421$$=
3;break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__53228__$1$jscomp$inline_6036_JSCompiler_inline_result$jscomp$996_type$jscomp$421$$)].join(""));}$offset$jscomp$inline_6038_offset__$1$jscomp$11$$=$APP.$app$render_wasm$mem$heap32$write_uuid$$($APP.$app$render_wasm$mem$heap32$write_uuid$$($app$render_wasm$mem$heap32$write_u32$$($app$render_wasm$mem$heap32$write_u32$$($offset$jscomp$inline_6038_offset__$1$jscomp$11$$,$heapu32$jscomp$2$$,$G__53228__$1$jscomp$inline_6036_JSCompiler_inline_result$jscomp$996_type$jscomp$421$$),
$heapu32$jscomp$2$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$248$$,0)),$heapu32$jscomp$2$$,$p__54256_parent$jscomp$203$$),$heapu32$jscomp$2$$,$id$jscomp$334$$);$heapf32$jscomp$4$$[$offset$jscomp$inline_6038_offset__$1$jscomp$11$$]=$map__54257__$1_value$jscomp$518$$;return $offset$jscomp$inline_6038_offset__$1$jscomp$11$$+1},$code__52999__auto__$jscomp$74_code_num__52998__auto__$jscomp$74_offset$jscomp$159_read_code_fn__52997__auto__$jscomp$74_size$jscomp$113$$,$cause54261_entries$jscomp$16_fn_54260$$);
$cause54261_entries$jscomp$16_fn_54260$$=$APP.$app$render_wasm$wasm$internal_module$$._set_structure_modifiers;try{$cause54261_entries$jscomp$16_fn_54260$$()}catch($e54262$$){$cause54261_entries$jscomp$16_fn_54260$$=$e54262$$;$code__52999__auto__$jscomp$74_code_num__52998__auto__$jscomp$74_offset$jscomp$159_read_code_fn__52997__auto__$jscomp$74_size$jscomp$113$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$74_code_num__52998__auto__$jscomp$74_offset$jscomp$159_read_code_fn__52997__auto__$jscomp$74_size$jscomp$113$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$74_code_num__52998__auto__$jscomp$74_offset$jscomp$159_read_code_fn__52997__auto__$jscomp$74_size$jscomp$113$$)?$code__52999__auto__$jscomp$74_code_num__52998__auto__$jscomp$74_offset$jscomp$159_read_code_fn__52997__auto__$jscomp$74_size$jscomp$113$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$74_code_num__52998__auto__$jscomp$74_offset$jscomp$159_read_code_fn__52997__auto__$jscomp$74_size$jscomp$113$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$74_code_num__52998__auto__$jscomp$74_offset$jscomp$159_read_code_fn__52997__auto__$jscomp$74_size$jscomp$113$$():null;$code__52999__auto__$jscomp$74_code_num__52998__auto__$jscomp$74_offset$jscomp$159_read_code_fn__52997__auto__$jscomp$74_size$jscomp$113$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$74_code_num__52998__auto__$jscomp$74_offset$jscomp$159_read_code_fn__52997__auto__$jscomp$74_size$jscomp$113$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$74$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$74_code_num__52998__auto__$jscomp$74_offset$jscomp$159_read_code_fn__52997__auto__$jscomp$74_size$jscomp$113$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$74$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_structure_modifiers",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$74$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$74_code_num__52998__auto__$jscomp$74_offset$jscomp$159_read_code_fn__52997__auto__$jscomp$74_size$jscomp$113$$],null),$cause54261_entries$jscomp$16_fn_54260$$);}}};
$app$render_wasm$api$propagate_modifiers$$=function($entries$jscomp$17_result$jscomp$254$$,$pixel_precision$$){if($APP.$cljs$core$empty_QMARK_$$($entries$jscomp$17_result$jscomp$254$$))return null;var $heapf32$jscomp$5$$=$app$render_wasm$mem$get_heap_f32$$(),$heapu32$jscomp$3$$=$APP.$app$render_wasm$mem$get_heap_u32$$(),$offset$jscomp$160_size$jscomp$114$$=44*$APP.$cljs$core$count$$($entries$jscomp$17_result$jscomp$254$$);$offset$jscomp$160_size$jscomp$114$$=$APP.$app$render_wasm$mem$alloc__GT_offset_32$$($offset$jscomp$160_size$jscomp$114$$);
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($JSCompiler_temp_const$jscomp$999_offset__$1$jscomp$13$$,$JSCompiler_inline_result$jscomp$1000_data$jscomp$256_kind$jscomp$26_p__54264$$){var $id$jscomp$335_values$jscomp$inline_6043$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1000_data$jscomp$256_kind$jscomp$26_p__54264$$,0,null);$JSCompiler_inline_result$jscomp$1000_data$jscomp$256_kind$jscomp$26_p__54264$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1000_data$jscomp$256_kind$jscomp$26_p__54264$$,
1,null);var $default$$jscomp$inline_6044_transform$jscomp$75$$=$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1000_data$jscomp$256_kind$jscomp$26_p__54264$$);$JSCompiler_inline_result$jscomp$1000_data$jscomp$256_kind$jscomp$26_p__54264$$=$APP.$cljs$cst$947$kind$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1000_data$jscomp$256_kind$jscomp$26_p__54264$$);$JSCompiler_temp_const$jscomp$999_offset__$1$jscomp$13$$=$app$render_wasm$mem$heap32$write_matrix$$($APP.$app$render_wasm$mem$heap32$write_uuid$$($JSCompiler_temp_const$jscomp$999_offset__$1$jscomp$13$$,
$heapu32$jscomp$3$$,$id$jscomp$335_values$jscomp$inline_6043$$),$heapf32$jscomp$5$$,$default$$jscomp$inline_6044_transform$jscomp$75$$);$id$jscomp$335_values$jscomp$inline_6043$$=$app$render_wasm$wasm$serializers$$["transform-entry-kind"];$default$$jscomp$inline_6044_transform$jscomp$75$$=$id$jscomp$335_values$jscomp$inline_6043$$.parent;$JSCompiler_inline_result$jscomp$1000_data$jscomp$256_kind$jscomp$26_p__54264$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$335_values$jscomp$inline_6043$$[$APP.$app$common$data$name$$($JSCompiler_inline_result$jscomp$1000_data$jscomp$256_kind$jscomp$26_p__54264$$)],
$default$$jscomp$inline_6044_transform$jscomp$75$$);return $app$render_wasm$mem$heap32$write_u32$$($JSCompiler_temp_const$jscomp$999_offset__$1$jscomp$13$$,$heapu32$jscomp$3$$,$JSCompiler_inline_result$jscomp$1000_data$jscomp$256_kind$jscomp$26_p__54264$$)},$offset$jscomp$160_size$jscomp$114$$,$entries$jscomp$17_result$jscomp$254$$);var $offset__$1$jscomp$12$$=$app$render_wasm$mem$__GT_offset_32$$(function(){var $cause54269_fn_54268$$=$APP.$app$render_wasm$wasm$internal_module$$._propagate_modifiers;
try{return $cause54269_fn_54268$$($pixel_precision$$)}catch($e54270$$){$cause54269_fn_54268$$=$e54270$$;var $code__52999__auto__$jscomp$75_code_num__52998__auto__$jscomp$75_read_code_fn__52997__auto__$jscomp$75$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$75_code_num__52998__auto__$jscomp$75_read_code_fn__52997__auto__$jscomp$75$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$75_code_num__52998__auto__$jscomp$75_read_code_fn__52997__auto__$jscomp$75$$)?
$code__52999__auto__$jscomp$75_code_num__52998__auto__$jscomp$75_read_code_fn__52997__auto__$jscomp$75$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$75_code_num__52998__auto__$jscomp$75_read_code_fn__52997__auto__$jscomp$75$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$75_code_num__52998__auto__$jscomp$75_read_code_fn__52997__auto__$jscomp$75$$():null;$code__52999__auto__$jscomp$75_code_num__52998__auto__$jscomp$75_read_code_fn__52997__auto__$jscomp$75$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code__52999__auto__$jscomp$75_code_num__52998__auto__$jscomp$75_read_code_fn__52997__auto__$jscomp$75$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$75$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$75_code_num__52998__auto__$jscomp$75_read_code_fn__52997__auto__$jscomp$75$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$75$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,
"_propagate_modifiers",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$75$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$75_code_num__52998__auto__$jscomp$75_read_code_fn__52997__auto__$jscomp$75$$],null),$cause54269_fn_54268$$);}}()),$max_offset$$=$offset__$1$jscomp$12$$+1+$heapu32$jscomp$3$$[$offset__$1$jscomp$12$$]*10;$entries$jscomp$17_result$jscomp$254$$=function(){for(var $G__54962_result$jscomp$255$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),
$G__54963_offset__$2$jscomp$1$$=$offset__$1$jscomp$12$$+1;;)if($G__54963_offset__$2$jscomp$1$$<$max_offset$$){var $a$jscomp$inline_6049_entry$jscomp$43$$=$heapf32$jscomp$5$$[$G__54963_offset__$2$jscomp$1$$+4];var $b$jscomp$inline_6050$$=$heapf32$jscomp$5$$[$G__54963_offset__$2$jscomp$1$$+5],$c$jscomp$inline_6051$$=$heapf32$jscomp$5$$[$G__54963_offset__$2$jscomp$1$$+6],$d$jscomp$inline_6052$$=$heapf32$jscomp$5$$[$G__54963_offset__$2$jscomp$1$$+7],$e$jscomp$inline_6053$$=$heapf32$jscomp$5$$[$G__54963_offset__$2$jscomp$1$$+
8],$f$jscomp$inline_6054$$=$heapf32$jscomp$5$$[$G__54963_offset__$2$jscomp$1$$+9];$a$jscomp$inline_6049_entry$jscomp$43$$=$app$common$data$vec2$$($app$common$uuid$uuid$$($app$common$uuid_impl$v8$$.$fromUnsignedParts$($heapu32$jscomp$3$$[$G__54963_offset__$2$jscomp$1$$+0],$heapu32$jscomp$3$$[$G__54963_offset__$2$jscomp$1$$+1],$heapu32$jscomp$3$$[$G__54963_offset__$2$jscomp$1$$+2],$heapu32$jscomp$3$$[$G__54963_offset__$2$jscomp$1$$+3])),$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$6$($a$jscomp$inline_6049_entry$jscomp$43$$,
$b$jscomp$inline_6050$$,$c$jscomp$inline_6051$$,$d$jscomp$inline_6052$$,$e$jscomp$inline_6053$$,$f$jscomp$inline_6054$$));$G__54962_result$jscomp$255$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__54962_result$jscomp$255$$,$a$jscomp$inline_6049_entry$jscomp$43$$);$G__54963_offset__$2$jscomp$1$$+=10}else return $APP.$cljs$core$_persistent_BANG_$$($G__54962_result$jscomp$255$$)}();$APP.$app$render_wasm$mem$free$$();return $entries$jscomp$17_result$jscomp$254$$};
$app$render_wasm$api$get_selection_rect$$=function($entries$jscomp$18_offset__$1$jscomp$14_result$jscomp$256$$){if($APP.$cljs$core$empty_QMARK_$$($entries$jscomp$18_offset__$1$jscomp$14_result$jscomp$256$$))return null;var $heapf32$jscomp$6_size$jscomp$115$$=16*$APP.$cljs$core$count$$($entries$jscomp$18_offset__$1$jscomp$14_result$jscomp$256$$),$offset$jscomp$161$$=$APP.$app$render_wasm$mem$alloc__GT_offset_32$$($heapf32$jscomp$6_size$jscomp$115$$),$heapu32$jscomp$4$$=$APP.$app$render_wasm$mem$get_heap_u32$$();
$heapf32$jscomp$6_size$jscomp$115$$=$app$render_wasm$mem$get_heap_f32$$();$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($offset__$1$jscomp$15$$,$id$jscomp$336$$){return $APP.$app$render_wasm$mem$heap32$write_uuid$$($offset__$1$jscomp$15$$,$heapu32$jscomp$4$$,$id$jscomp$336$$)},$offset$jscomp$161$$,$entries$jscomp$18_offset__$1$jscomp$14_result$jscomp$256$$);$entries$jscomp$18_offset__$1$jscomp$14_result$jscomp$256$$=$app$render_wasm$mem$__GT_offset_32$$(function(){var $cause54272_fn_54271$$=
$APP.$app$render_wasm$wasm$internal_module$$._get_selection_rect;try{return $cause54272_fn_54271$$()}catch($e54273$$){$cause54272_fn_54271$$=$e54273$$;var $code__52999__auto__$jscomp$76_code_num__52998__auto__$jscomp$76_read_code_fn__52997__auto__$jscomp$76$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$76_code_num__52998__auto__$jscomp$76_read_code_fn__52997__auto__$jscomp$76$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$76_code_num__52998__auto__$jscomp$76_read_code_fn__52997__auto__$jscomp$76$$)?
$code__52999__auto__$jscomp$76_code_num__52998__auto__$jscomp$76_read_code_fn__52997__auto__$jscomp$76$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$76_code_num__52998__auto__$jscomp$76_read_code_fn__52997__auto__$jscomp$76$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$76_code_num__52998__auto__$jscomp$76_read_code_fn__52997__auto__$jscomp$76$$():null;$code__52999__auto__$jscomp$76_code_num__52998__auto__$jscomp$76_read_code_fn__52997__auto__$jscomp$76$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code__52999__auto__$jscomp$76_code_num__52998__auto__$jscomp$76_read_code_fn__52997__auto__$jscomp$76$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$76$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$76_code_num__52998__auto__$jscomp$76_read_code_fn__52997__auto__$jscomp$76$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$76$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,
"_get_selection_rect",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$76$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$76_code_num__52998__auto__$jscomp$76_read_code_fn__52997__auto__$jscomp$76$$],null),$cause54272_fn_54271$$);}}());$entries$jscomp$18_offset__$1$jscomp$14_result$jscomp$256$$=$app$render_wasm$deserializers$read_selection_rect$$($heapf32$jscomp$6_size$jscomp$115$$,$entries$jscomp$18_offset__$1$jscomp$14_result$jscomp$256$$);
$APP.$app$render_wasm$mem$free$$();return $entries$jscomp$18_offset__$1$jscomp$14_result$jscomp$256$$};
$app$render_wasm$api$clean_modifiers$$=function(){if($APP.$app$render_wasm$api$initialized_QMARK_$$()){var $cause54284_fn_54283$$=$APP.$app$render_wasm$wasm$internal_module$$._clean_modifiers;try{$cause54284_fn_54283$$()}catch($e54286$$){$cause54284_fn_54283$$=$e54286$$;var $code__52999__auto__$jscomp$77_code_num__52998__auto__$jscomp$77_read_code_fn__52997__auto__$jscomp$77$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$77_code_num__52998__auto__$jscomp$77_read_code_fn__52997__auto__$jscomp$77$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$77_code_num__52998__auto__$jscomp$77_read_code_fn__52997__auto__$jscomp$77$$)?$code__52999__auto__$jscomp$77_code_num__52998__auto__$jscomp$77_read_code_fn__52997__auto__$jscomp$77$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$77_code_num__52998__auto__$jscomp$77_read_code_fn__52997__auto__$jscomp$77$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$77_code_num__52998__auto__$jscomp$77_read_code_fn__52997__auto__$jscomp$77$$():
null;$code__52999__auto__$jscomp$77_code_num__52998__auto__$jscomp$77_read_code_fn__52997__auto__$jscomp$77$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$77_code_num__52998__auto__$jscomp$77_read_code_fn__52997__auto__$jscomp$77$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$77$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$77_code_num__52998__auto__$jscomp$77_read_code_fn__52997__auto__$jscomp$77$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$77$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_clean_modifiers",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$77$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$77_code_num__52998__auto__$jscomp$77_read_code_fn__52997__auto__$jscomp$77$$],null),$cause54284_fn_54283$$);}}};
$app$render_wasm$api$set_modifiers_start$$=function(){if($APP.$app$render_wasm$api$initialized_QMARK_$$()){var $cause54289_fn_54288$$=$APP.$app$render_wasm$wasm$internal_module$$._set_modifiers_start;try{$cause54289_fn_54288$$()}catch($e54290$$){$cause54289_fn_54288$$=$e54290$$;var $code__52999__auto__$jscomp$78_code_num__52998__auto__$jscomp$78_read_code_fn__52997__auto__$jscomp$78$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$78_code_num__52998__auto__$jscomp$78_read_code_fn__52997__auto__$jscomp$78$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$78_code_num__52998__auto__$jscomp$78_read_code_fn__52997__auto__$jscomp$78$$)?$code__52999__auto__$jscomp$78_code_num__52998__auto__$jscomp$78_read_code_fn__52997__auto__$jscomp$78$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$78_code_num__52998__auto__$jscomp$78_read_code_fn__52997__auto__$jscomp$78$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$78_code_num__52998__auto__$jscomp$78_read_code_fn__52997__auto__$jscomp$78$$():
null;$code__52999__auto__$jscomp$78_code_num__52998__auto__$jscomp$78_read_code_fn__52997__auto__$jscomp$78$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$78_code_num__52998__auto__$jscomp$78_read_code_fn__52997__auto__$jscomp$78$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$78$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$78_code_num__52998__auto__$jscomp$78_read_code_fn__52997__auto__$jscomp$78$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$78$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_modifiers_start",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$78$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$78_code_num__52998__auto__$jscomp$78_read_code_fn__52997__auto__$jscomp$78$$],null),$cause54289_fn_54288$$);}}};
$app$render_wasm$api$set_modifiers$$=function($cause54300_54991_fn_54299_54989_modifiers$jscomp$43$$){var $code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$=$APP.$cljs$core$count$$($cause54300_54991_fn_54299_54989_modifiers$jscomp$43$$);if($code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$>0){$code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$=
$APP.$app$render_wasm$mem$alloc__GT_offset_32$$(40*$code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$);var $heapu32$jscomp$5$$=$APP.$app$render_wasm$mem$get_heap_u32$$(),$heapf32$jscomp$7$$=$app$render_wasm$mem$get_heap_f32$$();$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($offset__$1$jscomp$16$$,$p__54295_transform$jscomp$76$$){var $id$jscomp$337$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__54295_transform$jscomp$76$$,
0,null);$p__54295_transform$jscomp$76$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__54295_transform$jscomp$76$$,1,null);return $app$render_wasm$mem$heap32$write_matrix$$($APP.$app$render_wasm$mem$heap32$write_uuid$$($offset__$1$jscomp$16$$,$heapu32$jscomp$5$$,$id$jscomp$337$$),$heapf32$jscomp$7$$,$p__54295_transform$jscomp$76$$)},$code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$,$cause54300_54991_fn_54299_54989_modifiers$jscomp$43$$);
$cause54300_54991_fn_54299_54989_modifiers$jscomp$43$$=$APP.$app$render_wasm$wasm$internal_module$$._set_modifiers;try{$cause54300_54991_fn_54299_54989_modifiers$jscomp$43$$()}catch($e54301$$){$cause54300_54991_fn_54299_54989_modifiers$jscomp$43$$=$e54301$$;$code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$=
$APP.$cljs$core$truth_$$($code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$)?$code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$():
null;$code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto___54995$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___54995$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_modifiers",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___54995$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___54994_code_num__52998__auto___54993_length$jscomp$42_offset$jscomp$162_read_code_fn__52997__auto___54992$$],null),$cause54300_54991_fn_54299_54989_modifiers$jscomp$43$$);
}$APP.$app$render_wasm$api$request_render$$("set-modifiers")}};
$APP.$app$render_wasm$api$initialize_viewport$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($base_objects_cause54309_55003_cause54313_55013_cause54316_55026$$,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$,$hint__53000__auto___55007_hint__53000__auto___55019_hint__53000__auto___55030_vbox$jscomp$3$$,
$on_render$jscomp$1_p__54306$$){var $force_sync$jscomp$1_map__54307__$1$$=$APP.$cljs$core$__destructure_map$$($on_render$jscomp$1_p__54306$$),$background$jscomp$5_total_shapes$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($force_sync$jscomp$1_map__54307__$1$$,$APP.$cljs$cst$2058$background$$),$background_opacity_fn_54312_55011_rgba$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($force_sync$jscomp$1_map__54307__$1$$,$cljs$cst$3091$background_opacity$$,1);$on_render$jscomp$1_p__54306$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($force_sync$jscomp$1_map__54307__$1$$,$cljs$cst$3092$on_render$$);var $on_shapes_ready$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($force_sync$jscomp$1_map__54307__$1$$,$APP.$cljs$cst$3093$on_shapes_ready$$);$force_sync$jscomp$1_map__54307__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($force_sync$jscomp$1_map__54307__$1$$,$cljs$cst$3094$force_sync$$);$background_opacity_fn_54312_55011_rgba$jscomp$9$$=$APP.$cljs$core$truth_$$($background$jscomp$5_total_shapes$jscomp$4$$)?
$APP.$app$render_wasm$serializers$color$hex__GT_u32argb$$($background$jscomp$5_total_shapes$jscomp$4$$,$background_opacity_fn_54312_55011_rgba$jscomp$9$$):null;$background$jscomp$5_total_shapes$jscomp$4$$=$APP.$cljs$core$count$$($APP.$cljs$core$vals$$($base_objects_cause54309_55003_cause54313_55013_cause54316_55026$$));if($APP.$cljs$core$truth_$$($background_opacity_fn_54312_55011_rgba$jscomp$9$$)){var $fn_54308_55002$$=$APP.$app$render_wasm$wasm$internal_module$$._set_canvas_background;try{$fn_54308_55002$$($background_opacity_fn_54312_55011_rgba$jscomp$9$$)}catch($e54310$$){throw $base_objects_cause54309_55003_cause54313_55013_cause54316_55026$$=
$e54310$$,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$=
$APP.$cljs$core$truth_$$($code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$)?$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$():
null,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___55007_hint__53000__auto___55019_hint__53000__auto___55030_vbox$jscomp$3$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55007_hint__53000__auto___55019_hint__53000__auto___55030_vbox$jscomp$3$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_canvas_background",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55007_hint__53000__auto___55019_hint__53000__auto___55030_vbox$jscomp$3$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$],
null),$base_objects_cause54309_55003_cause54313_55013_cause54316_55026$$);}}$background_opacity_fn_54312_55011_rgba$jscomp$9$$=$APP.$app$render_wasm$wasm$internal_module$$._set_view;try{$background_opacity_fn_54312_55011_rgba$jscomp$9$$($code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$,
-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($hint__53000__auto___55007_hint__53000__auto___55019_hint__53000__auto___55030_vbox$jscomp$3$$),-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($hint__53000__auto___55007_hint__53000__auto___55019_hint__53000__auto___55030_vbox$jscomp$3$$))}catch($e54314$$){throw $base_objects_cause54309_55003_cause54313_55013_cause54316_55026$$=$e54314$$,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$=$APP.$cljs$core$truth_$$($code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$)?
$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$():null,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___55007_hint__53000__auto___55019_hint__53000__auto___55030_vbox$jscomp$3$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55007_hint__53000__auto___55019_hint__53000__auto___55030_vbox$jscomp$3$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_view",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55007_hint__53000__auto___55019_hint__53000__auto___55030_vbox$jscomp$3$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$],
null),$base_objects_cause54309_55003_cause54313_55013_cause54316_55026$$);}$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$=$APP.$app$render_wasm$wasm$internal_module$$._init_shapes_pool;try{$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$($background$jscomp$5_total_shapes$jscomp$4$$)}catch($e54317$$){throw $base_objects_cause54309_55003_cause54313_55013_cause54316_55026$$=
$e54317$$,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$=
$APP.$cljs$core$truth_$$($code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$)?$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$():
null,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___55007_hint__53000__auto___55019_hint__53000__auto___55030_vbox$jscomp$3$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55007_hint__53000__auto___55019_hint__53000__auto___55030_vbox$jscomp$3$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_init_shapes_pool",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55007_hint__53000__auto___55019_hint__53000__auto___55030_vbox$jscomp$3$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___55006_code__52999__auto___55018_code__52999__auto___55029_code_num__52998__auto___55005_code_num__52998__auto___55017_code_num__52998__auto___55028_fn_54315_55025_read_code_fn__52997__auto___55004_read_code_fn__52997__auto___55016_read_code_fn__52997__auto___55027_zoom$jscomp$3$$],
null),$base_objects_cause54309_55003_cause54313_55013_cause54316_55026$$);}return $app$render_wasm$api$set_objects$cljs$0core$0IFn$0_invoke$0arity$04$$($base_objects_cause54309_55003_cause54313_55013_cause54316_55026$$,$on_render$jscomp$1_p__54306$$,$on_shapes_ready$jscomp$3$$,$force_sync$jscomp$1_map__54307__$1$$)};
$app$render_wasm$api$run_resource_callbacks_BANG_$$=function($entries$jscomp$19$$){return $APP.$cljs$core$seq$$($entries$jscomp$19$$)?$promesa$core$create$cljs$0core$0IFn$0_invoke$0arity$01$$(function($resolve$jscomp$28$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$(function(){return $resolve$jscomp$28$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$28$$.$cljs$core$IFn$_invoke$arity$1$(null):$resolve$jscomp$28$$(null)},function(){return $resolve$jscomp$28$$.$cljs$core$IFn$_invoke$arity$1$?
$resolve$jscomp$28$$.$cljs$core$IFn$_invoke$arity$1$(null):$resolve$jscomp$28$$(null)},function(){return $resolve$jscomp$28$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$28$$.$cljs$core$IFn$_invoke$arity$1$(null):$resolve$jscomp$28$$(null)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$merge_map$$(function($callback$jscomp$89$$){return $APP.$cljs$core$fn_QMARK_$$($callback$jscomp$89$$)?$callback$jscomp$89$$.$cljs$core$IFn$_invoke$arity$0$?
$callback$jscomp$89$$.$cljs$core$IFn$_invoke$arity$0$():$callback$jscomp$89$$():$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$from$$($APP.$cljs$core$vals$$($APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$302$key$$,$APP.$cljs$cst$2354$callback$$,$entries$jscomp$19$$))))))}):$APP.$promesa$impl$promise$resolved$$(null)};
$app$render_wasm$api$derive_font_resources$$=function($base_objects$jscomp$1_object_fonts$$,$payload_fonts$$){$base_objects$jscomp$1_object_fonts$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($content$jscomp$inline_6056_direct_fonts_shape$jscomp$364$$){$content$jscomp$inline_6056_direct_fonts_shape$jscomp$364$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$inline_6056_direct_fonts_shape$jscomp$364$$);
var $content$jscomp$144_fallback_fonts$jscomp$2$$=$APP.$cljs$core$truth_$$($content$jscomp$inline_6056_direct_fonts_shape$jscomp$364$$)?$content$jscomp$inline_6056_direct_fonts_shape$jscomp$364$$:$app$util$text$content$v2_default_text_content$$();$content$jscomp$inline_6056_direct_fonts_shape$jscomp$364$$=$app$render_wasm$api$fonts$get_content_fonts$$($content$jscomp$144_fallback_fonts$jscomp$2$$);$content$jscomp$144_fallback_fonts$jscomp$2$$=$APP.$app$render_wasm$api$fonts_from_text_content$$($content$jscomp$144_fallback_fonts$jscomp$2$$,
!1);return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$inline_6056_direct_fonts_shape$jscomp$364$$,$content$jscomp$144_fallback_fonts$jscomp$2$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$text_shape_QMARK_$$,$APP.$cljs$core$vals$$($base_objects$jscomp$1_object_fonts$$))])));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$set$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($payload_fonts$$,$base_objects$jscomp$1_object_fonts$$)))};
$app$render_wasm$api$replay_image_resources_BANG_$$=function($image_resources_pending$jscomp$11$$){$image_resources_pending$jscomp$11$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p__54322_shape_id$jscomp$54$$){var $map__54323__$1_thumbnail_QMARK_$jscomp$6$$=$APP.$cljs$core$__destructure_map$$($p__54322_shape_id$jscomp$54$$);$p__54322_shape_id$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54323__$1_thumbnail_QMARK_$jscomp$6$$,
$APP.$cljs$cst$2543$shape_id$$);var $image_id$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54323__$1_thumbnail_QMARK_$jscomp$6$$,$cljs$cst$3086$image_id$$);$map__54323__$1_thumbnail_QMARK_$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54323__$1_thumbnail_QMARK_$jscomp$6$$,$cljs$cst$3085$thumbnail_QMARK_$$);return $APP.$cljs$core$uuid_QMARK_$$($image_id$jscomp$3$$)&&($p__54322_shape_id$jscomp$54$$==null||$APP.$cljs$core$uuid_QMARK_$$($p__54322_shape_id$jscomp$54$$))?
$app$render_wasm$api$fetch_image$$($APP.$cljs$core$truth_$$($p__54322_shape_id$jscomp$54$$)?$p__54322_shape_id$jscomp$54$$:$APP.$app$common$uuid$zero$$,$image_id$jscomp$3$$,$APP.$cljs$core$boolean$0$$($map__54323__$1_thumbnail_QMARK_$jscomp$6$$)):null}),$image_resources_pending$jscomp$11$$);return $app$render_wasm$api$run_resource_callbacks_BANG_$$($image_resources_pending$jscomp$11$$)};
$app$render_wasm$api$wait_next_frame_BANG_$$=function(){return $promesa$core$create$cljs$0core$0IFn$0_invoke$0arity$01$$(function($resolve$jscomp$29$$){return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){return $resolve$jscomp$29$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$29$$.$cljs$core$IFn$_invoke$arity$1$(null):$resolve$jscomp$29$$(null)})})};
$app$render_wasm$api$set_canvas_size$$=function($canvas$jscomp$8$$){var $height$jscomp$88$$=function(){var $or__5025__auto__$jscomp$604$$=$canvas$jscomp$8$$.clientHeight;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$604$$)?$or__5025__auto__$jscomp$604$$:$canvas$jscomp$8$$.height}();$canvas$jscomp$8$$.width=$APP.$app$render_wasm$api$dpr$$*function(){var $or__5025__auto__$jscomp$603$$=$canvas$jscomp$8$$.clientWidth;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$603$$)?$or__5025__auto__$jscomp$603$$:
$canvas$jscomp$8$$.width}();$canvas$jscomp$8$$.height=$APP.$app$render_wasm$api$dpr$$*$height$jscomp$88$$};
$app$render_wasm$api$on_webgl_context_lost$$=function($event$jscomp$77_temp__5825__auto___55050$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$77_temp__5825__auto___55050$$);$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$context_loss_overlay_QMARK_$$,!0);$event$jscomp$77_temp__5825__auto___55050$$=$APP.$app$render_wasm$wasm$canvas_snapshot_url$$;$APP.$cljs$core$truth_$$($event$jscomp$77_temp__5825__auto___55050$$)&&typeof $event$jscomp$77_temp__5825__auto___55050$$==="string"&&$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$transition_image_url_STAR_$$,
$event$jscomp$77_temp__5825__auto___55050$$);$APP.$cljs$core$reset_BANG_$$($app$render_wasm$wasm$context_lost_QMARK_$$,!0);$app$main$store$async_emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.webgl-context-lost.toast"),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,
$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$2343$warning$$,$APP.$cljs$cst$2353$timeout$$,5E3],null))]));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$render_wasm$context_lost$$())};
$app$render_wasm$api$on_webgl_context_restored$$=function($event$jscomp$78_payload$jscomp$1$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$78_payload$jscomp$1$$);$APP.$cljs$core$reset_BANG_$$($app$render_wasm$wasm$context_lost_QMARK_$$,!1);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$render_wasm$context_restored$$());$event$jscomp$78_payload$jscomp$1$$=$app$render_wasm$api$build_reload_payload$$();return $promesa$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($app$render_wasm$api$reload_renderer_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?
$app$render_wasm$api$reload_renderer_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$78_payload$jscomp$1$$):$app$render_wasm$api$reload_renderer_BANG_$$($event$jscomp$78_payload$jscomp$1$$),function(){$app$render_wasm$api$listen_tiles_render_complete_once_BANG_$$();return $app$main$store$async_emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.webgl-context-recovered.toast"),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$2344$success$$,$APP.$cljs$cst$2353$timeout$$,3E3],null))]))}),function($cause$jscomp$43$$){$app$render_wasm$api$end_context_loss_overlay_BANG_$$();$APP.$app$common$logging$enabled_QMARK_$$("app.render-wasm.api",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"wasm reload after context restore failed"],null)],null)}),$cause$jscomp$43$$,"app.render-wasm.api",$APP.$cljs$cst$849$error$$,!1);return null})};
$APP.$app$render_wasm$api$init_canvas_context$$=function($canvas$jscomp$9$$){if($APP.$cljs$core$not$$($app$render_wasm$wasm$module_ready_QMARK_$$()))return!1;var $gl$jscomp$5$$=$APP.$app$render_wasm$wasm$internal_module$$.GL,$G__54329__$1$jscomp$inline_6069$$=$APP.$app$util$debug$enabled_QMARK_$$($cljs$cst$3063$wasm_viewbox$$)?1:0;var $or__5025__auto__$jscomp$inline_12264$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$3081$feature_text_editor_wasm$$);if($or__5025__auto__$jscomp$inline_12264$$)var $JSCompiler_inline_result$jscomp$10819$$=
$or__5025__auto__$jscomp$inline_12264$$;else{var $runtime_features$jscomp$inline_12265$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$3082$features_runtime$$),$enabled_features$jscomp$inline_12266$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$227$features$$);$JSCompiler_inline_result$jscomp$10819$$=$APP.$cljs$core$contains_QMARK_$$($runtime_features$jscomp$inline_12265$$,
"text-editor-wasm/v1")||$APP.$cljs$core$contains_QMARK_$$($enabled_features$jscomp$inline_12266$$,"text-editor-wasm/v1")}var $G__54329__$2$jscomp$inline_6070$$=$JSCompiler_inline_result$jscomp$10819$$?$G__54329__$1$jscomp$inline_6069$$|4:$G__54329__$1$jscomp$inline_6069$$;var $flags$jscomp$27$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1205$render_wasm_info$$)?$G__54329__$2$jscomp$inline_6070$$|8:$G__54329__$2$jscomp$inline_6070$$;var $context_id$$=$APP.$app$util$debug$enabled_QMARK_$$($cljs$cst$3066$wasm_gl_context_init_error$$)?
"fail":"webgl2",$context$jscomp$28$$=$canvas$jscomp$9$$.getContext($context_id$$,$app$render_wasm$api$default_context_options$$),$context_init_QMARK_$$=$context$jscomp$28$$!=null,$browser$jscomp$6$$=$app$render_wasm$serializers$translate_browser$$();if($context$jscomp$28$$!=null){var $handle_55053$$=$gl$jscomp$5$$.registerContext($context$jscomp$28$$,{majorVersion:2});$gl$jscomp$5$$.makeContextCurrent($handle_55053$$);$app$render_wasm$wasm$gl_context_handle$$=$handle_55053$$;$app$render_wasm$wasm$gl_context$$=
$context$jscomp$28$$;$context$jscomp$28$$.getExtension("WEBGL_debug_renderer_info");var $fn_54334_55054$$=$APP.$app$render_wasm$wasm$internal_module$$._init;try{$fn_54334_55054$$($canvas$jscomp$9$$.width/$APP.$app$render_wasm$api$dpr$$,$canvas$jscomp$9$$.height/$APP.$app$render_wasm$api$dpr$$)}catch($e54336$$){var $cause54335_55055$$=$e54336$$,$read_code_fn__52997__auto___55056$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code_num__52998__auto___55057$$=$APP.$cljs$core$truth_$$($read_code_fn__52997__auto___55056$$)?
$read_code_fn__52997__auto___55056$$.$cljs$core$IFn$_invoke$arity$0$?$read_code_fn__52997__auto___55056$$.$cljs$core$IFn$_invoke$arity$0$():$read_code_fn__52997__auto___55056$$():null,$code__52999__auto___55058$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code_num__52998__auto___55057$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___55059$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55058$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55059$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_init",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55059$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___55058$$],null),$cause54335_55055$$);}var $fn_54337_55064$$=$APP.$app$render_wasm$wasm$internal_module$$._set_render_options;try{$fn_54337_55064$$($flags$jscomp$27$$,$APP.$app$render_wasm$api$dpr$$)}catch($e54339$$){var $cause54338_55065$$=$e54339$$,$read_code_fn__52997__auto___55066$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code_num__52998__auto___55067$$=$APP.$cljs$core$truth_$$($read_code_fn__52997__auto___55066$$)?$read_code_fn__52997__auto___55066$$.$cljs$core$IFn$_invoke$arity$0$?$read_code_fn__52997__auto___55066$$.$cljs$core$IFn$_invoke$arity$0$():$read_code_fn__52997__auto___55066$$():null,$code__52999__auto___55068$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code_num__52998__auto___55067$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___55069$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55068$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55069$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_render_options",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55069$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___55068$$],
null),$cause54338_55065$$);}var $p$jscomp$inline_12269$$=$APP.$app$main$router$get_params$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));var $temp__5825__auto__$jscomp$inline_12268$$=$cljs$cst$3095$aa_threshold$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$inline_12269$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_12268$$)){var $n$jscomp$inline_12270$$=typeof $temp__5825__auto__$jscomp$inline_12268$$==="string"?parseFloat($temp__5825__auto__$jscomp$inline_12268$$):$temp__5825__auto__$jscomp$inline_12268$$;
var $temp__5825__auto___55077$$=typeof $n$jscomp$inline_12270$$==="number"&&$APP.$cljs$core$not$$(isNaN($n$jscomp$inline_12270$$))&&$n$jscomp$inline_12270$$>0?$n$jscomp$inline_12270$$:null}else $temp__5825__auto___55077$$=null;if($APP.$cljs$core$truth_$$($temp__5825__auto___55077$$)){var $fn_54340_55079$$=$APP.$app$render_wasm$wasm$internal_module$$._set_antialias_threshold;try{$fn_54340_55079$$($temp__5825__auto___55077$$)}catch($e54342$$){var $cause54341_55080$$=$e54342$$,$read_code_fn__52997__auto___55081$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code_num__52998__auto___55082$$=$APP.$cljs$core$truth_$$($read_code_fn__52997__auto___55081$$)?$read_code_fn__52997__auto___55081$$.$cljs$core$IFn$_invoke$arity$0$?$read_code_fn__52997__auto___55081$$.$cljs$core$IFn$_invoke$arity$0$():$read_code_fn__52997__auto___55081$$():null,$code__52999__auto___55083$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code_num__52998__auto___55082$$,
$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___55084$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55083$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55084$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_antialias_threshold",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55084$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___55083$$],
null),$cause54341_55080$$);}}var $p$jscomp$inline_12273$$=$APP.$app$main$router$get_params$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));var $temp__5825__auto__$jscomp$inline_12272$$=$cljs$cst$3099$viewport_interest_area_threshold$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$inline_12273$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_12272$$)){var $n$jscomp$inline_12274$$=typeof $temp__5825__auto__$jscomp$inline_12272$$==="string"?parseInt($temp__5825__auto__$jscomp$inline_12272$$,
10):$temp__5825__auto__$jscomp$inline_12272$$;var $temp__5825__auto___55087$$=typeof $n$jscomp$inline_12274$$==="number"&&$APP.$cljs$core$not$$(isNaN($n$jscomp$inline_12274$$))&&$n$jscomp$inline_12274$$>0?$n$jscomp$inline_12274$$:null}else $temp__5825__auto___55087$$=null;if($APP.$cljs$core$truth_$$($temp__5825__auto___55087$$)){var $fn_54343_55089$$=$APP.$app$render_wasm$wasm$internal_module$$._set_viewport_interest_area_threshold;try{$fn_54343_55089$$($temp__5825__auto___55087$$)}catch($e54345$$){var $cause54344_55090$$=
$e54345$$,$read_code_fn__52997__auto___55091$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code_num__52998__auto___55092$$=$APP.$cljs$core$truth_$$($read_code_fn__52997__auto___55091$$)?$read_code_fn__52997__auto___55091$$.$cljs$core$IFn$_invoke$arity$0$?$read_code_fn__52997__auto___55091$$.$cljs$core$IFn$_invoke$arity$0$():$read_code_fn__52997__auto___55091$$():null,$code__52999__auto___55093$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code_num__52998__auto___55092$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___55094$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55093$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55094$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_viewport_interest_area_threshold",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55094$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto___55093$$],null),$cause54344_55090$$);}}var $p$jscomp$inline_12277$$=$APP.$app$main$router$get_params$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));var $temp__5825__auto__$jscomp$inline_12276$$=$cljs$cst$3097$max_blocking_time_ms$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$inline_12277$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_12276$$)){var $n$jscomp$inline_12278$$=typeof $temp__5825__auto__$jscomp$inline_12276$$==="string"?
parseInt($temp__5825__auto__$jscomp$inline_12276$$,10):$temp__5825__auto__$jscomp$inline_12276$$;var $temp__5825__auto___55097$$=typeof $n$jscomp$inline_12278$$==="number"&&$APP.$cljs$core$not$$(isNaN($n$jscomp$inline_12278$$))&&$n$jscomp$inline_12278$$>0?$n$jscomp$inline_12278$$:null}else $temp__5825__auto___55097$$=null;if($APP.$cljs$core$truth_$$($temp__5825__auto___55097$$)){var $fn_54349_55099$$=$APP.$app$render_wasm$wasm$internal_module$$._set_max_blocking_time_ms;try{$fn_54349_55099$$($temp__5825__auto___55097$$)}catch($e54351$$){var $cause54350_55100$$=
$e54351$$,$read_code_fn__52997__auto___55101$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code_num__52998__auto___55102$$=$APP.$cljs$core$truth_$$($read_code_fn__52997__auto___55101$$)?$read_code_fn__52997__auto___55101$$.$cljs$core$IFn$_invoke$arity$0$?$read_code_fn__52997__auto___55101$$.$cljs$core$IFn$_invoke$arity$0$():$read_code_fn__52997__auto___55101$$():null,$code__52999__auto___55103$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code_num__52998__auto___55102$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___55104$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55103$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55104$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_max_blocking_time_ms",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55104$$,$APP.$cljs$cst$273$code$$,
$code__52999__auto___55103$$],null),$cause54350_55100$$);}}var $p$jscomp$inline_12281$$=$APP.$app$main$router$get_params$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));var $temp__5825__auto__$jscomp$inline_12280$$=$cljs$cst$3098$node_batch_threshold$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$inline_12281$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_12280$$)){var $n$jscomp$inline_12282$$=typeof $temp__5825__auto__$jscomp$inline_12280$$==="string"?parseInt($temp__5825__auto__$jscomp$inline_12280$$,
10):$temp__5825__auto__$jscomp$inline_12280$$;var $temp__5825__auto___55109$$=typeof $n$jscomp$inline_12282$$==="number"&&$APP.$cljs$core$not$$(isNaN($n$jscomp$inline_12282$$))&&$n$jscomp$inline_12282$$>0?$n$jscomp$inline_12282$$:null}else $temp__5825__auto___55109$$=null;if($APP.$cljs$core$truth_$$($temp__5825__auto___55109$$)){var $fn_54352_55111$$=$APP.$app$render_wasm$wasm$internal_module$$._set_node_batch_threshold;try{$fn_54352_55111$$($temp__5825__auto___55109$$)}catch($e54354$$){var $cause54353_55112$$=
$e54354$$,$read_code_fn__52997__auto___55113$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code_num__52998__auto___55114$$=$APP.$cljs$core$truth_$$($read_code_fn__52997__auto___55113$$)?$read_code_fn__52997__auto___55113$$.$cljs$core$IFn$_invoke$arity$0$?$read_code_fn__52997__auto___55113$$.$cljs$core$IFn$_invoke$arity$0$():$read_code_fn__52997__auto___55113$$():null,$code__52999__auto___55115$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code_num__52998__auto___55114$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___55116$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55115$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55116$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_node_batch_threshold",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55116$$,$APP.$cljs$cst$273$code$$,
$code__52999__auto___55115$$],null),$cause54353_55112$$);}}var $p$jscomp$inline_12285$$=$APP.$app$main$router$get_params$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));var $temp__5825__auto__$jscomp$inline_12284$$=$cljs$cst$3096$blur_downscale_threshold$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$inline_12285$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_12284$$)){var $n$jscomp$inline_12286$$=typeof $temp__5825__auto__$jscomp$inline_12284$$==="string"?parseFloat($temp__5825__auto__$jscomp$inline_12284$$):
$temp__5825__auto__$jscomp$inline_12284$$;var $temp__5825__auto___55120$$=typeof $n$jscomp$inline_12286$$==="number"&&$APP.$cljs$core$not$$(isNaN($n$jscomp$inline_12286$$))&&$n$jscomp$inline_12286$$>0?$n$jscomp$inline_12286$$:null}else $temp__5825__auto___55120$$=null;if($APP.$cljs$core$truth_$$($temp__5825__auto___55120$$)){var $fn_54355_55122$$=$APP.$app$render_wasm$wasm$internal_module$$._set_blur_downscale_threshold;try{$fn_54355_55122$$($temp__5825__auto___55120$$)}catch($e54357$$){var $cause54356_55123$$=
$e54357$$,$read_code_fn__52997__auto___55127$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code_num__52998__auto___55128$$=$APP.$cljs$core$truth_$$($read_code_fn__52997__auto___55127$$)?$read_code_fn__52997__auto___55127$$.$cljs$core$IFn$_invoke$arity$0$?$read_code_fn__52997__auto___55127$$.$cljs$core$IFn$_invoke$arity$0$():$read_code_fn__52997__auto___55127$$():null,$code__52999__auto___55129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code_num__52998__auto___55128$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___55130$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55129$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55130$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_blur_downscale_threshold",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55130$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto___55129$$],null),$cause54356_55123$$);}}if($APP.$cljs$core$truth_$$($context$jscomp$28$$)){var $n$jscomp$inline_12289$$=$context$jscomp$28$$.getParameter($context$jscomp$28$$.MAX_TEXTURE_SIZE);var $and__5023__auto__$jscomp$inline_12291$$=typeof $n$jscomp$inline_12289$$==="number";if($and__5023__auto__$jscomp$inline_12291$$){var $and__5023__auto____$1$jscomp$inline_12292$$=$n$jscomp$inline_12289$$>0;var $JSCompiler_inline_result$jscomp$inline_12290$$=$and__5023__auto____$1$jscomp$inline_12292$$?
isFinite($n$jscomp$inline_12289$$):$and__5023__auto____$1$jscomp$inline_12292$$}else $JSCompiler_inline_result$jscomp$inline_12290$$=$and__5023__auto__$jscomp$inline_12291$$;var $temp__5825__auto___55136$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_12290$$)?Math.floor($n$jscomp$inline_12289$$):null}else $temp__5825__auto___55136$$=null;if($APP.$cljs$core$truth_$$($temp__5825__auto___55136$$)){var $fn_54359_55138$$=$APP.$app$render_wasm$wasm$internal_module$$._set_max_atlas_texture_size;
try{$fn_54359_55138$$($temp__5825__auto___55136$$)}catch($e54361$$){var $cause54360_55139$$=$e54361$$,$read_code_fn__52997__auto___55140$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code_num__52998__auto___55141$$=$APP.$cljs$core$truth_$$($read_code_fn__52997__auto___55140$$)?$read_code_fn__52997__auto___55140$$.$cljs$core$IFn$_invoke$arity$0$?$read_code_fn__52997__auto___55140$$.$cljs$core$IFn$_invoke$arity$0$():$read_code_fn__52997__auto___55140$$():null,$code__52999__auto___55142$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code_num__52998__auto___55141$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___55143$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55142$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55143$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_max_atlas_texture_size",$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55143$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___55142$$],null),$cause54360_55139$$);}}var $fn_54362_55146$$=$APP.$app$render_wasm$wasm$internal_module$$._set_browser;try{$fn_54362_55146$$($browser$jscomp$6$$)}catch($e54364$$){var $cause54363_55147$$=$e54364$$,$read_code_fn__52997__auto___55148$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code_num__52998__auto___55149$$=$APP.$cljs$core$truth_$$($read_code_fn__52997__auto___55148$$)?
$read_code_fn__52997__auto___55148$$.$cljs$core$IFn$_invoke$arity$0$?$read_code_fn__52997__auto___55148$$.$cljs$core$IFn$_invoke$arity$0$():$read_code_fn__52997__auto___55148$$():null,$code__52999__auto___55150$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code_num__52998__auto___55149$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___55151$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55150$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55151$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_browser",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55151$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___55150$$],null),$cause54363_55147$$);}$app$render_wasm$api$set_canvas_size$$($canvas$jscomp$9$$);$app$render_wasm$wasm$canvas$$=$canvas$jscomp$9$$;$canvas$jscomp$9$$.addEventListener("webglcontextlost",$app$render_wasm$api$on_webgl_context_lost$$);$canvas$jscomp$9$$.addEventListener("webglcontextrestored",
$app$render_wasm$api$on_webgl_context_restored$$);$app$render_wasm$api$start_canvas_snapshot_listener_BANG_$$();$APP.$cljs$core$reset_BANG_$$($app$render_wasm$wasm$context_lost_QMARK_$$,!1);$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$=!0}return $context_init_QMARK_$$};
$APP.$app$render_wasm$api$clear_canvas$cljs$0core$0IFn$0_invoke$0arity$01$$=function($lose_browser_context_QMARK__map__54370__$1_p__54369$$){$lose_browser_context_QMARK__map__54370__$1_p__54369$$=$APP.$cljs$core$__destructure_map$$($lose_browser_context_QMARK__map__54370__$1_p__54369$$);$lose_browser_context_QMARK__map__54370__$1_p__54369$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($lose_browser_context_QMARK__map__54370__$1_p__54369$$,$cljs$cst$3100$lose_browser_context_QMARK_$$,!0);
try{$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$=!1;$APP.$cljs$core$truth_$$($app$render_wasm$wasm$internal_frame_id$$)&&$app$util$timers$cancel_animation_frame$$($app$render_wasm$wasm$internal_frame_id$$);$APP.$cljs$core$reset_BANG_$$($app$render_wasm$api$pending_render$$,!1);$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$shapes_loading_QMARK_$$,!1);$APP.$cljs$core$reset_BANG_$$($app$render_wasm$api$deferred_render_QMARK_$$,!1);$APP.$cljs$core$truth_$$($app$render_wasm$wasm$canvas$$)&&
($app$render_wasm$wasm$canvas$$.removeEventListener("webglcontextlost",$app$render_wasm$api$on_webgl_context_lost$$),$app$render_wasm$wasm$canvas$$.removeEventListener("webglcontextrestored",$app$render_wasm$api$on_webgl_context_restored$$));var $temp__5825__auto___54492$jscomp$inline_6072$$=$APP.$cljs$core$_deref$$($app$render_wasm$api$snapshot_tiles_handler_STAR_$$);$APP.$cljs$core$truth_$$($temp__5825__auto___54492$jscomp$inline_6072$$)&&$APP.$app$util$globals$document$$.removeEventListener("penpot:wasm:tiles-complete",
$temp__5825__auto___54492$jscomp$inline_6072$$);$APP.$cljs$core$reset_BANG_$$($app$render_wasm$api$snapshot_tiles_handler_STAR_$$,null);var $temp__5825__auto__$jscomp$inline_6073$$=$app$render_wasm$api$schedule_canvas_snapshot_capture_BANG_$$.cancel;$APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_6073$$)&&($temp__5825__auto__$jscomp$inline_6073$$.$cljs$core$IFn$_invoke$arity$0$?$temp__5825__auto__$jscomp$inline_6073$$.$cljs$core$IFn$_invoke$arity$0$():$temp__5825__auto__$jscomp$inline_6073$$());
if($APP.$cljs$core$truth_$$($app$render_wasm$wasm$module_ready_QMARK_$$())){if($APP.$app$render_wasm$api$initialized_QMARK_$$()){var $fn_53751$jscomp$inline_6075$$=$APP.$app$render_wasm$wasm$internal_module$$._free_gpu_resources;try{$fn_53751$jscomp$inline_6075$$()}catch($e53753$jscomp$inline_6081$$){var $cause53752$jscomp$inline_6076_cause54373_55156_temp__5825__auto___55166$$=$e53753$jscomp$inline_6081$$,$read_code_fn__52997__auto__$jscomp$inline_6077_temp__5825__auto___55168__$1$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,
$code_num__52998__auto__$jscomp$inline_6078_temp__5825__auto___55170__$2$$=$APP.$cljs$core$truth_$$($read_code_fn__52997__auto__$jscomp$inline_6077_temp__5825__auto___55168__$1$$)?$read_code_fn__52997__auto__$jscomp$inline_6077_temp__5825__auto___55168__$1$$.$cljs$core$IFn$_invoke$arity$0$?$read_code_fn__52997__auto__$jscomp$inline_6077_temp__5825__auto___55168__$1$$.$cljs$core$IFn$_invoke$arity$0$():$read_code_fn__52997__auto__$jscomp$inline_6077_temp__5825__auto___55168__$1$$():null,$code__52999__auto__$jscomp$inline_6079$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code_num__52998__auto__$jscomp$inline_6078_temp__5825__auto___55170__$2$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto__$jscomp$inline_6080$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_6079$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$inline_6080$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$516$fn$$,"_free_gpu_resources",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$inline_6080$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_6079$$],null),$cause53752$jscomp$inline_6076_cause54373_55156_temp__5825__auto___55166$$);}}var $fn_54372_55155$$=$APP.$app$render_wasm$wasm$internal_module$$._clean_up;try{$fn_54372_55155$$()}catch($e54374$$){$cause53752$jscomp$inline_6076_cause54373_55156_temp__5825__auto___55166$$=
$e54374$$;var $read_code_fn__52997__auto___55157$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code_num__52998__auto___55158$$=$APP.$cljs$core$truth_$$($read_code_fn__52997__auto___55157$$)?$read_code_fn__52997__auto___55157$$.$cljs$core$IFn$_invoke$arity$0$?$read_code_fn__52997__auto___55157$$.$cljs$core$IFn$_invoke$arity$0$():$read_code_fn__52997__auto___55157$$():null,$code__52999__auto___55159$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code_num__52998__auto___55158$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto___55160$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55159$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto___55160$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_clean_up",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto___55160$$,$APP.$cljs$cst$273$code$$,
$code__52999__auto___55159$$],null),$cause53752$jscomp$inline_6076_cause54373_55156_temp__5825__auto___55166$$);}}$cause53752$jscomp$inline_6076_cause54373_55156_temp__5825__auto___55166$$=$APP.$app$render_wasm$wasm$internal_module$$.GL;if($APP.$cljs$core$truth_$$($cause53752$jscomp$inline_6076_cause54373_55156_temp__5825__auto___55166$$)&&($read_code_fn__52997__auto__$jscomp$inline_6077_temp__5825__auto___55168__$1$$=$app$render_wasm$wasm$gl_context_handle$$,$APP.$cljs$core$truth_$$($read_code_fn__52997__auto__$jscomp$inline_6077_temp__5825__auto___55168__$1$$)))try{if($APP.$cljs$core$truth_$$($lose_browser_context_QMARK__map__54370__$1_p__54369$$)&&
($code_num__52998__auto__$jscomp$inline_6078_temp__5825__auto___55170__$2$$=$app$render_wasm$wasm$gl_context$$,$APP.$cljs$core$truth_$$($code_num__52998__auto__$jscomp$inline_6078_temp__5825__auto___55170__$2$$))){var $temp__5825__auto___55172__$3$$=$code_num__52998__auto__$jscomp$inline_6078_temp__5825__auto___55170__$2$$.getExtension("WEBGL_lose_context");$APP.$cljs$core$truth_$$($temp__5825__auto___55172__$3$$)&&$temp__5825__auto___55172__$3$$.loseContext()}$cause53752$jscomp$inline_6076_cause54373_55156_temp__5825__auto___55166$$.deleteContext($read_code_fn__52997__auto__$jscomp$inline_6077_temp__5825__auto___55168__$1$$)}catch($e54375$$){console.error($e54375$$)}$APP.$cljs$core$reset_BANG_$$($app$render_wasm$gesture$interactive_transform_active_QMARK_$$,
!1);$app$render_wasm$wasm$reset_context_state_BANG_$$();return!0}catch($e54371$$){return console.error($e54371$$),$APP.$cljs$core$reset_BANG_$$($app$render_wasm$gesture$interactive_transform_active_QMARK_$$,!1),$app$render_wasm$wasm$reset_context_state_BANG_$$(),!1}};
$app$render_wasm$api$reload_renderer_BANG_$$=function($fonts$jscomp$10_p__54376$$){var $map__54377__$1$$=$APP.$cljs$core$__destructure_map$$($fonts$jscomp$10_p__54376$$),$force_sync$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__54377__$1$$,$cljs$cst$3094$force_sync$$,!1),$image_resources$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__54377__$1$$,$cljs$cst$3101$image_resources$$,$APP.$cljs$core$PersistentVector$EMPTY$$);$fonts$jscomp$10_p__54376$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__54377__$1$$,
$APP.$cljs$cst$2969$fonts$$,$APP.$cljs$core$PersistentVector$EMPTY$$);var $zoom$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54377__$1$$,$APP.$cljs$cst$2196$zoom$$),$on_shapes_ready$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54377__$1$$,$APP.$cljs$cst$3093$on_shapes_ready$$),$base_objects$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54377__$1$$,$cljs$cst$3084$base_objects$$),$vbox$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54377__$1$$,
$APP.$cljs$cst$1925$vbox$$),$background$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54377__$1$$,$APP.$cljs$cst$2058$background$$),$background_opacity$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__54377__$1$$,$cljs$cst$3091$background_opacity$$,1),$on_render$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54377__$1$$,$cljs$cst$3092$on_render$$),$canvas$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54377__$1$$,
$APP.$cljs$cst$3083$canvas$$);$app$util$globals$dispatch_BANG_$$($app$util$globals$event$$("penpot:wasm:reload-start"));var $fonts__$1$jscomp$1$$=$app$render_wasm$api$derive_font_resources$$($base_objects$jscomp$2$$,$fonts$jscomp$10_p__54376$$);return $promesa$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($APP.$promesa$impl$promise$resolved$$(null),
function(){var $was_cleared_QMARK_$$=$APP.$app$render_wasm$api$clear_canvas$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3100$lose_browser_context_QMARK_$$,!1],null));if($APP.$cljs$core$truth_$$($was_cleared_QMARK_$$))return null;throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("WASM renderer cleanup failed",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$273$code$$,$cljs$cst$3102$wasm_reload_context_failure$$,$APP.$cljs$cst$275$hint$$,"WASM renderer cleanup failed"],null),null])),null);}),function(){return $app$render_wasm$api$wait_next_frame_BANG_$$()}),function(){if(!$APP.$app$render_wasm$api$init_canvas_context$$($canvas$jscomp$10$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("WASM renderer could not create a new WebGL context",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$273$code$$,$cljs$cst$3102$wasm_reload_context_failure$$,$APP.$cljs$cst$275$hint$$,"WASM renderer could not create a new WebGL context"],null),null])),null);return $APP.$cljs$core$reset_BANG_$$($app$render_wasm$gesture$interactive_transform_active_QMARK_$$,!1)}),function(){var $cause54380_fn_54379$$=$APP.$app$render_wasm$wasm$internal_module$$._reset_canvas;try{return $cause54380_fn_54379$$()}catch($e54381$$){$cause54380_fn_54379$$=
$e54381$$;var $code__52999__auto__$jscomp$81_code_num__52998__auto__$jscomp$81_read_code_fn__52997__auto__$jscomp$81$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$81_code_num__52998__auto__$jscomp$81_read_code_fn__52997__auto__$jscomp$81$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$81_code_num__52998__auto__$jscomp$81_read_code_fn__52997__auto__$jscomp$81$$)?$code__52999__auto__$jscomp$81_code_num__52998__auto__$jscomp$81_read_code_fn__52997__auto__$jscomp$81$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$81_code_num__52998__auto__$jscomp$81_read_code_fn__52997__auto__$jscomp$81$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$81_code_num__52998__auto__$jscomp$81_read_code_fn__52997__auto__$jscomp$81$$():null;$code__52999__auto__$jscomp$81_code_num__52998__auto__$jscomp$81_read_code_fn__52997__auto__$jscomp$81$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$81_code_num__52998__auto__$jscomp$81_read_code_fn__52997__auto__$jscomp$81$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$81$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$81_code_num__52998__auto__$jscomp$81_read_code_fn__52997__auto__$jscomp$81$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$81$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_reset_canvas",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53000__auto__$jscomp$81$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$81_code_num__52998__auto__$jscomp$81_read_code_fn__52997__auto__$jscomp$81$$],null),$cause54380_fn_54379$$);}}),function(){var $pending$jscomp$inline_6084$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$render_wasm$api$fonts$store_fonts$$($fonts__$1$jscomp$1$$));return $app$render_wasm$api$run_resource_callbacks_BANG_$$($pending$jscomp$inline_6084$$)}),function(){return $app$render_wasm$api$replay_image_resources_BANG_$$($image_resources$jscomp$1$$)}),
function(){$APP.$app$render_wasm$api$initialize_viewport$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($base_objects$jscomp$2$$,$zoom$jscomp$4$$,$vbox$jscomp$4$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2058$background$$,$background$jscomp$6$$,$cljs$cst$3091$background_opacity$$,$background_opacity$jscomp$1$$,$cljs$cst$3092$on_render$$,$on_render$jscomp$2$$,$APP.$cljs$cst$3093$on_shapes_ready$$,$on_shapes_ready$jscomp$4$$,$cljs$cst$3094$force_sync$$,$force_sync$jscomp$2$$]));
$APP.$app$render_wasm$api$request_render$$("reload-renderer");$app$util$globals$dispatch_BANG_$$($app$util$globals$event$$("penpot:wasm:reload-complete"));return $map__54377__$1$$}),function($cause$jscomp$44$$){$app$util$globals$dispatch_BANG_$$($app$util$globals$event$$("penpot:wasm:reload-failed"));$APP.$app$render_wasm$api$clear_canvas$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);return $promesa$impl$promise$rejected$$($cause$jscomp$44$$)})};
$app$render_wasm$api$calculate_bool_STAR_$$=function($bool_type$jscomp$6$$,$cause$jscomp$47_ids$jscomp$36$$){var $offset$jscomp$166_size$jscomp$116$$=16*$APP.$cljs$core$count$$($cause$jscomp$47_ids$jscomp$36$$),$heap$jscomp$16$$=$APP.$app$render_wasm$mem$get_heap_u32$$();$offset$jscomp$166_size$jscomp$116$$=$APP.$app$render_wasm$mem$alloc__GT_offset_32$$($offset$jscomp$166_size$jscomp$116$$);$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($offset__$1$jscomp$18$$,$id$jscomp$341$$){return $APP.$app$render_wasm$mem$heap32$write_uuid$$($offset__$1$jscomp$18$$,
$heap$jscomp$16$$,$id$jscomp$341$$)},$offset$jscomp$166_size$jscomp$116$$,$APP.$cljs$core$_rseq$$($cause$jscomp$47_ids$jscomp$36$$));try{var $offset__$1$jscomp$17$$=$app$render_wasm$mem$__GT_offset_32$$(function(){var $cause54408_fn_54407$$=$APP.$app$render_wasm$wasm$internal_module$$._calculate_bool;try{return $cause54408_fn_54407$$($app$render_wasm$serializers$translate_bool_type$$($bool_type$jscomp$6$$))}catch($e54409$$){$cause54408_fn_54407$$=$e54409$$;var $code__52999__auto__$jscomp$85_code_num__52998__auto__$jscomp$85_read_code_fn__52997__auto__$jscomp$85$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$85_code_num__52998__auto__$jscomp$85_read_code_fn__52997__auto__$jscomp$85$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$85_code_num__52998__auto__$jscomp$85_read_code_fn__52997__auto__$jscomp$85$$)?$code__52999__auto__$jscomp$85_code_num__52998__auto__$jscomp$85_read_code_fn__52997__auto__$jscomp$85$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$85_code_num__52998__auto__$jscomp$85_read_code_fn__52997__auto__$jscomp$85$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$85_code_num__52998__auto__$jscomp$85_read_code_fn__52997__auto__$jscomp$85$$():null;$code__52999__auto__$jscomp$85_code_num__52998__auto__$jscomp$85_read_code_fn__52997__auto__$jscomp$85$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$85_code_num__52998__auto__$jscomp$85_read_code_fn__52997__auto__$jscomp$85$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$85$$=["WASM Error (",
$APP.$app$common$data$name$$($code__52999__auto__$jscomp$85_code_num__52998__auto__$jscomp$85_read_code_fn__52997__auto__$jscomp$85$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$85$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_calculate_bool",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$85$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$85_code_num__52998__auto__$jscomp$85_read_code_fn__52997__auto__$jscomp$85$$],
null),$cause54408_fn_54407$$);}}()),$content$jscomp$147$$=$app$common$types$path$impl$from_bytes$$($app$render_wasm$mem$slice$$($heap$jscomp$16$$,$offset__$1$jscomp$17$$+1,$heap$jscomp$16$$[$offset__$1$jscomp$17$$]*7));$APP.$app$render_wasm$mem$free$$();return $content$jscomp$147$$}catch($e54406$$){throw $cause$jscomp$47_ids$jscomp$36$$=$e54406$$,$APP.$app$render_wasm$mem$free$$(),$cause$jscomp$47_ids$jscomp$36$$;}};
$app$render_wasm$api$calculate_bool$$=function($code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$,$objects$jscomp$242$$){var $bool_type$jscomp$7_cause54412_55199_cause54415_55210_cause54421_55218_content$jscomp$148_fn_54411_55198$$=$APP.$app$render_wasm$wasm$internal_module$$._start_temp_objects;
try{$bool_type$jscomp$7_cause54412_55199_cause54415_55210_cause54421_55218_content$jscomp$148_fn_54411_55198$$()}catch($e54413$$){$bool_type$jscomp$7_cause54412_55199_cause54415_55210_cause54421_55218_content$jscomp$148_fn_54411_55198$$=$e54413$$;$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$=$APP.$cljs$core$truth_$$($code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$)?
$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$():null;$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$,$APP.$cljs$cst$2971$wasm_critical$$);var $all_children_hint__53000__auto___55203_hint__53000__auto___55214_hint__53000__auto___55222$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($all_children_hint__53000__auto___55203_hint__53000__auto___55214_hint__53000__auto___55222$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_start_temp_objects",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$all_children_hint__53000__auto___55203_hint__53000__auto___55214_hint__53000__auto___55222$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$],
null),$bool_type$jscomp$7_cause54412_55199_cause54415_55210_cause54421_55218_content$jscomp$148_fn_54411_55198$$);}$bool_type$jscomp$7_cause54412_55199_cause54415_55210_cause54421_55218_content$jscomp$148_fn_54411_55198$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$,
$APP.$cljs$cst$1888$bool_type$$);$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$,
$APP.$cljs$cst$1614$shapes$$);$all_children_hint__53000__auto___55203_hint__53000__auto___55214_hint__53000__auto___55222$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__54410_SHARP_$$){return $APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$242$$,$p1__54410_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$]));
var $fn_54414_55209$$=$APP.$app$render_wasm$wasm$internal_module$$._init_shapes_pool;try{$fn_54414_55209$$($APP.$cljs$core$count$$($all_children_hint__53000__auto___55203_hint__53000__auto___55214_hint__53000__auto___55222$$))}catch($e54416$$){throw $bool_type$jscomp$7_cause54412_55199_cause54415_55210_cause54421_55218_content$jscomp$148_fn_54411_55198$$=$e54416$$,$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$=$APP.$cljs$core$truth_$$($code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$)?
$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$():null,$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$,$APP.$cljs$cst$2971$wasm_critical$$),$all_children_hint__53000__auto___55203_hint__53000__auto___55214_hint__53000__auto___55222$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($all_children_hint__53000__auto___55203_hint__53000__auto___55214_hint__53000__auto___55222$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_init_shapes_pool",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$all_children_hint__53000__auto___55203_hint__53000__auto___55214_hint__53000__auto___55222$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$],
null),$bool_type$jscomp$7_cause54412_55199_cause54415_55210_cause54421_55218_content$jscomp$148_fn_54411_55198$$);}$APP.$cljs$core$run_BANG_$$($APP.$app$render_wasm$api$set_object$$,$all_children_hint__53000__auto___55203_hint__53000__auto___55214_hint__53000__auto___55222$$);$bool_type$jscomp$7_cause54412_55199_cause54415_55210_cause54421_55218_content$jscomp$148_fn_54411_55198$$=$APP.$app$common$types$path$impl$path_data$$($app$render_wasm$api$calculate_bool_STAR_$$($bool_type$jscomp$7_cause54412_55199_cause54415_55210_cause54421_55218_content$jscomp$148_fn_54411_55198$$,
$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$));$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$=
$APP.$app$render_wasm$wasm$internal_module$$._end_temp_objects;try{$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$()}catch($e54422$$){throw $bool_type$jscomp$7_cause54412_55199_cause54415_55210_cause54421_55218_content$jscomp$148_fn_54411_55198$$=
$e54422$$,$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$=
$APP.$cljs$core$truth_$$($code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$)?$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$():
null,$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$,
$APP.$cljs$cst$2971$wasm_critical$$),$all_children_hint__53000__auto___55203_hint__53000__auto___55214_hint__53000__auto___55222$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$),")"].join(""),
$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($all_children_hint__53000__auto___55203_hint__53000__auto___55214_hint__53000__auto___55222$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_end_temp_objects",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$all_children_hint__53000__auto___55203_hint__53000__auto___55214_hint__53000__auto___55222$$,$APP.$cljs$cst$273$code$$,$code__52999__auto___55202_code__52999__auto___55213_code__52999__auto___55221_code_num__52998__auto___55201_code_num__52998__auto___55212_code_num__52998__auto___55220_fn_54420_55217_ids$jscomp$37_read_code_fn__52997__auto___55200_read_code_fn__52997__auto___55211_read_code_fn__52997__auto___55219_shape$jscomp$365$$],
null),$bool_type$jscomp$7_cause54412_55199_cause54415_55210_cause54421_55218_content$jscomp$148_fn_54411_55198$$);}return $bool_type$jscomp$7_cause54412_55199_cause54415_55210_cause54421_55218_content$jscomp$148_fn_54411_55198$$};
$APP.$app$render_wasm$api$calculate_position_data$$=function($shape$jscomp$366$$){if($APP.$app$render_wasm$api$initialized_QMARK_$$()){$APP.$app$render_wasm$api$use_shape$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$366$$));var $heapf32$jscomp$8$$=$app$render_wasm$mem$get_heap_f32$$(),$heapu32$jscomp$6$$=$APP.$app$render_wasm$mem$get_heap_u32$$(),$offset$jscomp$167$$=$app$render_wasm$mem$__GT_offset_32$$(function(){var $cause54427_fn_54426$$=$APP.$app$render_wasm$wasm$internal_module$$._calculate_position_data;
try{return $cause54427_fn_54426$$()}catch($e54428$$){$cause54427_fn_54426$$=$e54428$$;var $code__52999__auto__$jscomp$86_code_num__52998__auto__$jscomp$86_read_code_fn__52997__auto__$jscomp$86$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$86_code_num__52998__auto__$jscomp$86_read_code_fn__52997__auto__$jscomp$86$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$86_code_num__52998__auto__$jscomp$86_read_code_fn__52997__auto__$jscomp$86$$)?$code__52999__auto__$jscomp$86_code_num__52998__auto__$jscomp$86_read_code_fn__52997__auto__$jscomp$86$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$86_code_num__52998__auto__$jscomp$86_read_code_fn__52997__auto__$jscomp$86$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$86_code_num__52998__auto__$jscomp$86_read_code_fn__52997__auto__$jscomp$86$$():null;$code__52999__auto__$jscomp$86_code_num__52998__auto__$jscomp$86_read_code_fn__52997__auto__$jscomp$86$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$86_code_num__52998__auto__$jscomp$86_read_code_fn__52997__auto__$jscomp$86$$,
$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$86$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$86_code_num__52998__auto__$jscomp$86_read_code_fn__52997__auto__$jscomp$86$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$86$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_calculate_position_data",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53000__auto__$jscomp$86$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$86_code_num__52998__auto__$jscomp$86_read_code_fn__52997__auto__$jscomp$86$$],null),$cause54427_fn_54426$$);}}()),$max_offset$jscomp$1$$=$offset$jscomp$167$$+1+$heapu32$jscomp$6$$[$offset$jscomp$167$$]*9,$result$jscomp$257$$=function(){for(var $G__55237_result$jscomp$258$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$G__55238_offset__$1$jscomp$19$$=$offset$jscomp$167$$+1;;)if($G__55238_offset__$1$jscomp$19$$<
$max_offset$jscomp$1$$){var $entry$jscomp$44$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$cljs$cst$1381$end_pos$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1510$x$$,$cljs$cst$3030$paragraph$$,$APP.$cljs$cst$1963$direction$$,$cljs$cst$1382$start_pos$$,$APP.$cljs$cst$1522$height$$,$cljs$cst$3031$span$$],[$heapf32$jscomp$8$$[$G__55238_offset__$1$jscomp$19$$+5],$heapu32$jscomp$6$$[$G__55238_offset__$1$jscomp$19$$+3],$heapf32$jscomp$8$$[$G__55238_offset__$1$jscomp$19$$+6],
$heapf32$jscomp$8$$[$G__55238_offset__$1$jscomp$19$$+4],$heapu32$jscomp$6$$[$G__55238_offset__$1$jscomp$19$$+0],$heapu32$jscomp$6$$[$G__55238_offset__$1$jscomp$19$$+8],$heapu32$jscomp$6$$[$G__55238_offset__$1$jscomp$19$$+2],$heapf32$jscomp$8$$[$G__55238_offset__$1$jscomp$19$$+7],$heapu32$jscomp$6$$[$G__55238_offset__$1$jscomp$19$$+1]]);$G__55237_result$jscomp$258$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__55237_result$jscomp$258$$,$entry$jscomp$44$$);$G__55238_offset__$1$jscomp$19$$+=
9}else return $APP.$cljs$core$_persistent_BANG_$$($G__55237_result$jscomp$258$$)}(),$content$jscomp$149$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$366$$);$APP.$app$render_wasm$mem$free$$();return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p__54433_x$jscomp$1164$$){var $map__54434__$1_width$jscomp$100$$=$APP.$cljs$core$__destructure_map$$($p__54433_x$jscomp$1164$$);
$p__54433_x$jscomp$1164$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54434__$1_width$jscomp$100$$,$APP.$cljs$cst$1510$x$$);var $element$jscomp$69_paragraph$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54434__$1_width$jscomp$100$$,$cljs$cst$3030$paragraph$$),$JSCompiler_inline_result$jscomp$1014_direction$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54434__$1_width$jscomp$100$$,$APP.$cljs$cst$1963$direction$$),$height$jscomp$89$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54434__$1_width$jscomp$100$$,$APP.$cljs$cst$1522$height$$),$start_pos$jscomp$17_text$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54434__$1_width$jscomp$100$$,$cljs$cst$1382$start_pos$$),$JSCompiler_temp_const$jscomp$1010_element_text_span$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54434__$1_width$jscomp$100$$,$cljs$cst$3031$span$$),$y$jscomp$402$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54434__$1_width$jscomp$100$$,
$APP.$cljs$cst$1511$y$$),$JSCompiler_temp_const$jscomp$1012_end_pos$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54434__$1_width$jscomp$100$$,$cljs$cst$1381$end_pos$$);$map__54434__$1_width$jscomp$100$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54434__$1_width$jscomp$100$$,$APP.$cljs$cst$290$width$$);$element$jscomp$69_paragraph$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$149$$),
0)),$element$jscomp$69_paragraph$jscomp$13$$)),$JSCompiler_temp_const$jscomp$1010_element_text_span$jscomp$5$$);$JSCompiler_temp_const$jscomp$1010_element_text_span$jscomp$5$$=$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($element$jscomp$69_paragraph$jscomp$13$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($element$jscomp$69_paragraph$jscomp$13$$)?$JSCompiler_temp_const$jscomp$1010_element_text_span$jscomp$5$$:$element$jscomp$69_paragraph$jscomp$13$$)){$start_pos$jscomp$17_text$jscomp$39$$=
$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp_const$jscomp$1010_element_text_span$jscomp$5$$,$start_pos$jscomp$17_text$jscomp$39$$,$JSCompiler_temp_const$jscomp$1012_end_pos$jscomp$16$$);$JSCompiler_temp_const$jscomp$1012_end_pos$jscomp$16$$=$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$;$JSCompiler_temp_const$jscomp$1010_element_text_span$jscomp$5$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_temp_const$jscomp$1009$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$69_paragraph$jscomp$13$$,$APP.$cljs$cst$1762$font_style$$),$JSCompiler_temp_const$jscomp$1008$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$69_paragraph$jscomp$13$$,$APP.$cljs$cst$1769$text_transform$$),$JSCompiler_temp_const$jscomp$1007$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$69_paragraph$jscomp$13$$,$APP.$cljs$cst$1757$font_id$$),$JSCompiler_temp_const$jscomp$1006$$=""+
($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$69_paragraph$jscomp$13$$,$APP.$cljs$cst$1760$font_size$$)??"")+"px",$JSCompiler_temp_const$jscomp$1005$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$69_paragraph$jscomp$13$$,$APP.$cljs$cst$1761$font_weight$$),$JSCompiler_temp_const$jscomp$1004$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$69_paragraph$jscomp$13$$,$APP.$cljs$cst$1768$text_decoration$$),$JSCompiler_temp_const$jscomp$1003$$=
""+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$69_paragraph$jscomp$13$$,$APP.$cljs$cst$1766$letter_spacing$$)??"")+"px",$JSCompiler_temp_const$jscomp$1002$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$69_paragraph$jscomp$13$$,$APP.$cljs$cst$1634$fills$$);a:switch($JSCompiler_inline_result$jscomp$1014_direction$jscomp$13$$){case 0:$JSCompiler_inline_result$jscomp$1014_direction$jscomp$13$$="rtl";break a;default:$JSCompiler_inline_result$jscomp$1014_direction$jscomp$13$$=
"ltr"}return $JSCompiler_temp_const$jscomp$1012_end_pos$jscomp$16$$.call($APP.$app$common$data$patch_object$$,$APP.$app$common$types$text$default_text_attrs$$,$JSCompiler_temp_const$jscomp$1010_element_text_span$jscomp$5$$.call($APP.$app$common$data$without_nils$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1762$font_style$$,$APP.$cljs$cst$1769$text_transform$$,$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$1761$font_weight$$,
$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1768$text_decoration$$,$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$cst$1963$direction$$,$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1588$text$$],[$y$jscomp$402$$+$height$jscomp$89$$,$JSCompiler_temp_const$jscomp$1009$$,$JSCompiler_temp_const$jscomp$1008$$,$JSCompiler_temp_const$jscomp$1007$$,$JSCompiler_temp_const$jscomp$1006$$,$JSCompiler_temp_const$jscomp$1005$$,$map__54434__$1_width$jscomp$100$$,
$JSCompiler_temp_const$jscomp$1004$$,$JSCompiler_temp_const$jscomp$1003$$,$p__54433_x$jscomp$1164$$,$JSCompiler_temp_const$jscomp$1002$$,$JSCompiler_inline_result$jscomp$1014_direction$jscomp$13$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$69_paragraph$jscomp$13$$,$APP.$cljs$cst$1758$font_family$$),$height$jscomp$89$$,$start_pos$jscomp$17_text$jscomp$39$$])))}return null}),$result$jscomp$257$$)}return null};
$app$render_wasm$api$render_shape_pixels$$=function($buffer$jscomp$76_hint__53000__auto__$jscomp$inline_6117_shape_id$jscomp$55$$,$code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$){$buffer$jscomp$76_hint__53000__auto__$jscomp$inline_6117_shape_id$jscomp$55$$=$APP.$app$common$uuid$get_u32$$($buffer$jscomp$76_hint__53000__auto__$jscomp$inline_6117_shape_id$jscomp$55$$);var $fn_54441$jscomp$inline_6112$$=
$APP.$app$render_wasm$wasm$internal_module$$._render_shape_pixels;try{var $cause54442$jscomp$inline_6113_offset$jscomp$168_result$jscomp$259$$=$fn_54441$jscomp$inline_6112$$($buffer$jscomp$76_hint__53000__auto__$jscomp$inline_6117_shape_id$jscomp$55$$[0],$buffer$jscomp$76_hint__53000__auto__$jscomp$inline_6117_shape_id$jscomp$55$$[1],$buffer$jscomp$76_hint__53000__auto__$jscomp$inline_6117_shape_id$jscomp$55$$[2],$buffer$jscomp$76_hint__53000__auto__$jscomp$inline_6117_shape_id$jscomp$55$$[3],$code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$)}catch($e54443$jscomp$inline_6118$$){throw $cause54442$jscomp$inline_6113_offset$jscomp$168_result$jscomp$259$$=
$e54443$jscomp$inline_6118$$,$code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$)?
$code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$():
null,$code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$,$APP.$cljs$cst$2971$wasm_critical$$),$buffer$jscomp$76_hint__53000__auto__$jscomp$inline_6117_shape_id$jscomp$55$$=
["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($buffer$jscomp$76_hint__53000__auto__$jscomp$inline_6117_shape_id$jscomp$55$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_render_shape_pixels",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$buffer$jscomp$76_hint__53000__auto__$jscomp$inline_6117_shape_id$jscomp$55$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$],null),$cause54442$jscomp$inline_6113_offset$jscomp$168_result$jscomp$259$$);}$code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$=
$cause54442$jscomp$inline_6113_offset$jscomp$168_result$jscomp$259$$+12;$cause54442$jscomp$inline_6113_offset$jscomp$168_result$jscomp$259$$=$APP.$app$render_wasm$mem$get_heap_u8$$().slice($code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$,$code__52999__auto__$jscomp$inline_6116_code_num__52998__auto__$jscomp$inline_6115_offset$jscomp$inline_12295_read_code_fn__52997__auto__$jscomp$inline_6114_scale$jscomp$20$$+
$APP.$app$render_wasm$mem$get_heap_u32$$()[$cause54442$jscomp$inline_6113_offset$jscomp$168_result$jscomp$259$$>>2]);$APP.$app$render_wasm$mem$free$$();return $cause54442$jscomp$inline_6113_offset$jscomp$168_result$jscomp$259$$};
$app$render_wasm$api$get_shape_extrect$$=function($buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$){$buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$=$APP.$app$common$uuid$get_u32$$($buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$);var $fn_54444$jscomp$inline_6120_hint__53000__auto__$jscomp$inline_6125_y$jscomp$403$$=$APP.$app$render_wasm$wasm$internal_module$$._get_shape_extrect;
try{var $code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$=$fn_54444$jscomp$inline_6120_hint__53000__auto__$jscomp$inline_6125_y$jscomp$403$$($buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$[0],$buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$[1],$buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$[2],
$buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$[3])}catch($e54446$jscomp$inline_6126$$){throw $buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$=$e54446$jscomp$inline_6126$$,$code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$=
$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$)?$code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$():null,$code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$,
$APP.$cljs$cst$2971$wasm_critical$$),$fn_54444$jscomp$inline_6120_hint__53000__auto__$jscomp$inline_6125_y$jscomp$403$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_54444$jscomp$inline_6120_hint__53000__auto__$jscomp$inline_6125_y$jscomp$403$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$516$fn$$,"_get_shape_extrect",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_54444$jscomp$inline_6120_hint__53000__auto__$jscomp$inline_6125_y$jscomp$403$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$],null),$buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$);
}if(typeof $code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$==="number"&&$code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$>0){$buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$=$app$render_wasm$mem$get_heap_f32$$();var $base$jscomp$32$$=
$code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$>>2;$code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$=$buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$[$base$jscomp$32$$];$fn_54444$jscomp$inline_6120_hint__53000__auto__$jscomp$inline_6125_y$jscomp$403$$=
$buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$[$base$jscomp$32$$+1];var $w$jscomp$33$$=$buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$[$base$jscomp$32$$+2];$buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$=$buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$[$base$jscomp$32$$+3];$APP.$app$render_wasm$mem$free$$();
return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1510$x$$,$code__52999__auto__$jscomp$inline_6124_code_num__52998__auto__$jscomp$inline_6123_offset$jscomp$169_read_code_fn__52997__auto__$jscomp$inline_6122_x$jscomp$1165$$,$APP.$cljs$cst$1511$y$$,$fn_54444$jscomp$inline_6120_hint__53000__auto__$jscomp$inline_6125_y$jscomp$403$$,$APP.$cljs$cst$290$width$$,$w$jscomp$33$$,$APP.$cljs$cst$1522$height$$,$buffer$jscomp$77_cause54445$jscomp$inline_6121_h$jscomp$155_heapf32$jscomp$9_shape_id$jscomp$56$$],
null)}return null};
$app$render_wasm$api$init_wasm_module$$=function($default_fn$jscomp$1_module$jscomp$5$$){$default_fn$jscomp$1_module$jscomp$5$$=$default_fn$jscomp$1_module$jscomp$5$$["default"];var $G__54448_href$jscomp$8$$=$app$config$resolve_href$$("js/render-wasm.wasm");$G__54448_href$jscomp$8$$={locateFile:$APP.$cljs$core$constantly$$($G__54448_href$jscomp$8$$)};return $default_fn$jscomp$1_module$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$default_fn$jscomp$1_module$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($G__54448_href$jscomp$8$$):$default_fn$jscomp$1_module$jscomp$5$$($G__54448_href$jscomp$8$$)};
$app$render_wasm$shape$shape_in_current_page_QMARK_$$=function($shape_id$jscomp$57$$){var $objects$jscomp$243$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$);return $APP.$cljs$core$contains_QMARK_$$($objects$jscomp$243$$,$shape_id$jscomp$57$$)};
$app$render_wasm$shape$ShapeProxy$$=function($id$jscomp$342$$,$type$jscomp$422$$,$delegate$$){this.id=$id$jscomp$342$$;this.type=$type$jscomp$422$$;this.$delegate$=$delegate$$;this.$cljs$lang$protocol_mask$partition0$$=2179335951;this.$cljs$lang$protocol_mask$partition1$$=0};
$app$render_wasm$shape$set_wasm_attr_BANG_$$=function($shape$jscomp$367$$,$k$jscomp$638$$){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $shape__$1$jscomp$30$$=function(){switch($k$jscomp$638$$ instanceof $APP.$cljs$core$Keyword$$?$k$jscomp$638$$.$fqn$:null){case "svg-attrs":return $app$render_wasm$svg_filters$apply_svg_derived$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$367$$,$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$367$$,
$APP.$cljs$cst$1890$svg_attrs$$)));case "fills":case "blur":case "shadow":return $app$render_wasm$svg_filters$apply_svg_derived$$($shape$jscomp$367$$);default:return $shape$jscomp$367$$}}(),$pending_full$jscomp$4_v$jscomp$575$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$30$$,$k$jscomp$638$$),$id$jscomp$344$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$30$$,$APP.$cljs$cst$266$id$$);switch($k$jscomp$638$$ instanceof $APP.$cljs$core$Keyword$$?
$k$jscomp$638$$.$fqn$:null){case "parent-id":return $app$render_wasm$api$set_parent_id$$($pending_full$jscomp$4_v$jscomp$575$$);case "type":return $app$render_wasm$api$set_shape_type$$($pending_full$jscomp$4_v$jscomp$575$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($pending_full$jscomp$4_v$jscomp$575$$,$APP.$cljs$cst$296$path$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($pending_full$jscomp$4_v$jscomp$575$$,$APP.$cljs$cst$1610$bool$$)?$app$render_wasm$api$set_shape_path_content$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$)):
null;case "bool-type":return $app$render_wasm$api$set_shape_bool_type$$($pending_full$jscomp$4_v$jscomp$575$$);case "selrect":return $app$render_wasm$api$set_shape_selrect$$($pending_full$jscomp$4_v$jscomp$575$$),$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$)?$app$render_wasm$api$set_shape_svg_raw_content$$($app$render_wasm$api$get_static_markup$$($shape__$1$jscomp$30$$)):null;case "show-content":return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$)?
$app$render_wasm$api$set_shape_clip_content$$($APP.$cljs$core$not$$($pending_full$jscomp$4_v$jscomp$575$$)):$app$render_wasm$api$set_shape_clip_content$$(!1);case "rotation":return $app$render_wasm$api$set_shape_rotation$$($pending_full$jscomp$4_v$jscomp$575$$);case "transform":return $app$render_wasm$api$set_shape_transform$$($pending_full$jscomp$4_v$jscomp$575$$);case "fills":return $app$render_wasm$api$set_shape_fills$$($id$jscomp$344$$,$pending_full$jscomp$4_v$jscomp$575$$,!1);case "strokes":return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,
$app$render_wasm$api$set_shape_strokes$$($id$jscomp$344$$,$pending_full$jscomp$4_v$jscomp$575$$,!1));case "blend-mode":return $APP.$app$render_wasm$api$set_shape_blend_mode$$($pending_full$jscomp$4_v$jscomp$575$$);case "opacity":return $app$render_wasm$api$set_shape_opacity$$($pending_full$jscomp$4_v$jscomp$575$$);case "hidden":return $app$render_wasm$api$set_shape_hidden$$($pending_full$jscomp$4_v$jscomp$575$$);case "shapes":return $app$render_wasm$api$set_shape_children$$($pending_full$jscomp$4_v$jscomp$575$$);
case "blur":return $app$render_wasm$api$set_shape_blur$$($pending_full$jscomp$4_v$jscomp$575$$);case "shadow":return $app$render_wasm$api$set_shape_shadows$$($pending_full$jscomp$4_v$jscomp$575$$);case "constraints-h":return $app$render_wasm$api$set_constraints_h$$($pending_full$jscomp$4_v$jscomp$575$$);case "constraints-v":return $app$render_wasm$api$set_constraints_v$$($pending_full$jscomp$4_v$jscomp$575$$);case "r1":return $app$render_wasm$api$set_shape_corners$$(new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$pending_full$jscomp$4_v$jscomp$575$$,$shape__$1$jscomp$30$$?.r2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$30$$,$APP.$cljs$cst$1647$r2$$),$shape__$1$jscomp$30$$?.r3??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$30$$,$APP.$cljs$cst$1648$r3$$),$shape__$1$jscomp$30$$?.r4??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$30$$,$APP.$cljs$cst$1649$r4$$)],null));case "r2":return $app$render_wasm$api$set_shape_corners$$(new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape__$1$jscomp$30$$?.r1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$30$$,$APP.$cljs$cst$1646$r1$$),$pending_full$jscomp$4_v$jscomp$575$$,$shape__$1$jscomp$30$$?.r3??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$30$$,$APP.$cljs$cst$1648$r3$$),$shape__$1$jscomp$30$$?.r4??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$30$$,$APP.$cljs$cst$1649$r4$$)],null));case "r3":return $app$render_wasm$api$set_shape_corners$$(new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape__$1$jscomp$30$$?.r1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$30$$,$APP.$cljs$cst$1646$r1$$),$shape__$1$jscomp$30$$?.r2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$30$$,$APP.$cljs$cst$1647$r2$$),$pending_full$jscomp$4_v$jscomp$575$$,$shape__$1$jscomp$30$$?.r4??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$30$$,$APP.$cljs$cst$1649$r4$$)],null));case "r4":return $app$render_wasm$api$set_shape_corners$$(new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape__$1$jscomp$30$$?.r1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$30$$,$APP.$cljs$cst$1646$r1$$),$shape__$1$jscomp$30$$?.r2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$30$$,$APP.$cljs$cst$1647$r2$$),$shape__$1$jscomp$30$$?.r3??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$30$$,$APP.$cljs$cst$1648$r3$$),$pending_full$jscomp$4_v$jscomp$575$$],null));case "svg-attrs":return $app$render_wasm$api$set_shape_svg_attrs$$($pending_full$jscomp$4_v$jscomp$575$$),
$app$render_wasm$api$set_shape_fills$$($id$jscomp$344$$,$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$),!1),$app$render_wasm$api$set_shape_blur$$($APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$)),$app$render_wasm$api$set_shape_shadows$$($APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$));case "masked-group":return $APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$)?
$app$render_wasm$api$set_masked$$($APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1609$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$))):null;case "content":if($APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape__$1$jscomp$30$$))return $app$render_wasm$api$set_shape_path_content$$($pending_full$jscomp$4_v$jscomp$575$$);if($APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$))return $app$render_wasm$api$set_shape_svg_raw_content$$($app$render_wasm$api$get_static_markup$$($shape__$1$jscomp$30$$));
if($APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$)){var $pending_thumbnails$jscomp$4$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$render_wasm$api$set_shape_text_content$$($id$jscomp$344$$,$pending_full$jscomp$4_v$jscomp$575$$)));$pending_full$jscomp$4_v$jscomp$575$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$1$($app$render_wasm$api$set_shape_text_images$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$344$$,$pending_full$jscomp$4_v$jscomp$575$$,!1)));$app$render_wasm$api$process_pending$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape__$1$jscomp$30$$],null),$pending_thumbnails$jscomp$4$$,$pending_full$jscomp$4_v$jscomp$575$$,$APP.$app$render_wasm$api$noop_fn$$)}return null;case "grow-type":return $app$render_wasm$api$set_shape_grow_type$$($pending_full$jscomp$4_v$jscomp$575$$);
case "layout-item-align-self":case "layout-item-margin":case "layout-item-margin-type":case "layout-item-h-sizing":case "layout-item-v-sizing":case "layout-item-max-h":case "layout-item-min-h":case "layout-item-max-w":case "layout-item-min-w":case "layout-item-absolute":case "layout-item-z-index":return $app$render_wasm$api$set_layout_data$$($shape__$1$jscomp$30$$);case "layout-grid-rows":return $app$render_wasm$api$set_grid_layout_rows$$($pending_full$jscomp$4_v$jscomp$575$$);case "layout-grid-columns":return $app$render_wasm$api$set_grid_layout_columns$$($pending_full$jscomp$4_v$jscomp$575$$);
case "layout-grid-cells":return $app$render_wasm$api$set_grid_layout_cells$$($pending_full$jscomp$4_v$jscomp$575$$);case "layout":return $app$render_wasm$api$clear_layout$$(),$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$)?$app$render_wasm$api$set_grid_layout$$($shape__$1$jscomp$30$$):$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$)&&$app$render_wasm$api$set_flex_layout$$($shape__$1$jscomp$30$$),
$app$render_wasm$api$set_layout_data$$($shape__$1$jscomp$30$$);case "layout-flex-dir":case "layout-gap-type":case "layout-gap":case "layout-align-items":case "layout-align-content":case "layout-justify-items":case "layout-justify-content":case "layout-wrap-type":case "layout-padding-type":case "layout-padding":return $APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$)?$app$render_wasm$api$set_grid_layout_data$$($shape__$1$jscomp$30$$):$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$30$$)?
$app$render_wasm$api$set_flex_layout$$($shape__$1$jscomp$30$$):null;default:return null}}else return null};
$app$render_wasm$shape$process_shape_BANG_$$=function($shape$jscomp$368$$,$properties$jscomp$94$$){var $shape_id$jscomp$58$$=$shape$jscomp$368$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$368$$,$APP.$cljs$cst$266$id$$);return $app$render_wasm$shape$shape_in_current_page_QMARK_$$($shape_id$jscomp$58$$)?($APP.$app$render_wasm$api$use_shape$$($shape_id$jscomp$58$$),$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$beicon$v2$core$mapcat$$(function($callback$jscomp$90$$){return $callback$jscomp$90$$.$cljs$core$IFn$_invoke$arity$0$?$callback$jscomp$90$$.$cljs$core$IFn$_invoke$arity$0$():$callback$jscomp$90$$()},$APP.$beicon$v2$core$from$$($APP.$cljs$core$vals$$($APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$302$key$$,$APP.$cljs$cst$2354$callback$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__54600_SHARP_$$){return $app$render_wasm$shape$set_wasm_attr_BANG_$$($shape$jscomp$368$$,
$p1__54600_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$properties$jscomp$94$$])))))))):$APP.$beicon$v2$core$empty$$()};
$app$render_wasm$shape$process_shape_changes_BANG_$$=function($objects$jscomp$244$$,$shape_changes_shape_changes__$1$$){$shape_changes_shape_changes__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__54630$$){var $shape_id$jscomp$59$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__54630$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__54630$$,1,null);return $app$render_wasm$shape$shape_in_current_page_QMARK_$$($shape_id$jscomp$59$$)},$shape_changes_shape_changes__$1$$);
return $APP.$app$common$data$not_empty_QMARK_$$($shape_changes_shape_changes__$1$$)?$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$render_wasm$api$request_render$$("set-wasm-attrs")},$APP.$beicon$v2$core$mapcat$$(function($p__54641_props$jscomp$131$$){var $shape_id$jscomp$60$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__54641_props$jscomp$131$$,0,null);$p__54641_props$jscomp$131$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__54641_props$jscomp$131$$,
1,null);return $app$render_wasm$shape$process_shape_BANG_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$244$$,$shape_id$jscomp$60$$),$p__54641_props$jscomp$131$$)},$APP.$beicon$v2$core$from$$($shape_changes_shape_changes__$1$$))):null};
$app$render_wasm$shape$impl_assoc$$=function($self$jscomp$71$$,$delegate_SINGLEQUOTE__k$jscomp$639$$,$v$jscomp$576$$){$APP.$cljs$core$truth_$$($app$common$types$shape$_STAR_shape_changes_STAR_$$)&&$APP.$cljs$core$_vreset_BANG_$$($app$common$types$shape$_STAR_shape_changes_STAR_$$,$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($app$common$types$shape$_STAR_shape_changes_STAR_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self$jscomp$71$$),$app$render_wasm$shape$conj_STAR_$$,
$delegate_SINGLEQUOTE__k$jscomp$639$$));switch($delegate_SINGLEQUOTE__k$jscomp$639$$ instanceof $APP.$cljs$core$Keyword$$?$delegate_SINGLEQUOTE__k$jscomp$639$$.$fqn$:null){case "id":return new $app$render_wasm$shape$ShapeProxy$$($v$jscomp$576$$,$self$jscomp$71$$.type,$self$jscomp$71$$.$delegate$);case "type":return new $app$render_wasm$shape$ShapeProxy$$($self$jscomp$71$$.id,$v$jscomp$576$$,$self$jscomp$71$$.$delegate$);default:var $delegate$jscomp$2$$=$self$jscomp$71$$.$delegate$;$delegate_SINGLEQUOTE__k$jscomp$639$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($delegate$jscomp$2$$,$delegate_SINGLEQUOTE__k$jscomp$639$$,$v$jscomp$576$$);return $delegate_SINGLEQUOTE__k$jscomp$639$$===$delegate$jscomp$2$$?$self$jscomp$71$$:new $app$render_wasm$shape$ShapeProxy$$($self$jscomp$71$$.id,$self$jscomp$71$$.type,$delegate_SINGLEQUOTE__k$jscomp$639$$)}};
$app$render_wasm$shape$impl_dissoc$$=function($self$jscomp$72$$,$delegate_SINGLEQUOTE_$jscomp$1_k$jscomp$640$$){$APP.$cljs$core$truth_$$($app$common$types$shape$_STAR_shape_changes_STAR_$$)&&$APP.$cljs$core$_vreset_BANG_$$($app$common$types$shape$_STAR_shape_changes_STAR_$$,$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($app$common$types$shape$_STAR_shape_changes_STAR_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self$jscomp$72$$),$app$render_wasm$shape$conj_STAR_$$,
$delegate_SINGLEQUOTE_$jscomp$1_k$jscomp$640$$));switch($delegate_SINGLEQUOTE_$jscomp$1_k$jscomp$640$$ instanceof $APP.$cljs$core$Keyword$$?$delegate_SINGLEQUOTE_$jscomp$1_k$jscomp$640$$.$fqn$:null){case "id":return new $app$render_wasm$shape$ShapeProxy$$(null,$self$jscomp$72$$.type,$self$jscomp$72$$.$delegate$);case "type":return new $app$render_wasm$shape$ShapeProxy$$($self$jscomp$72$$.id,null,$self$jscomp$72$$.$delegate$);default:var $delegate$jscomp$3$$=$self$jscomp$72$$.$delegate$;$delegate_SINGLEQUOTE_$jscomp$1_k$jscomp$640$$=
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($delegate$jscomp$3$$,$delegate_SINGLEQUOTE_$jscomp$1_k$jscomp$640$$);return $delegate$jscomp$3$$===$delegate_SINGLEQUOTE_$jscomp$1_k$jscomp$640$$?$self$jscomp$72$$:new $app$render_wasm$shape$ShapeProxy$$($self$jscomp$72$$.id,$self$jscomp$72$$.type,$delegate_SINGLEQUOTE_$jscomp$1_k$jscomp$640$$)}};
$app$render_wasm$shape$impl_conj$$=function($G__54768_ret$jscomp$145_self$jscomp$73$$,$G__54769_entry$jscomp$46_es$jscomp$10$$){if($APP.$cljs$core$vector_QMARK_$$($G__54769_entry$jscomp$46_es$jscomp$10$$))return $APP.$cljs$core$_assoc$$($G__54768_ret$jscomp$145_self$jscomp$73$$,$APP.$cljs$core$_nth$$($G__54769_entry$jscomp$46_es$jscomp$10$$,0),$APP.$cljs$core$_nth$$($G__54769_entry$jscomp$46_es$jscomp$10$$,1));for($G__54769_entry$jscomp$46_es$jscomp$10$$=$APP.$cljs$core$seq$$($G__54769_entry$jscomp$46_es$jscomp$10$$);;){if($G__54769_entry$jscomp$46_es$jscomp$10$$==
null)return $G__54768_ret$jscomp$145_self$jscomp$73$$;var $e$jscomp$315$$=$APP.$cljs$core$first$$($G__54769_entry$jscomp$46_es$jscomp$10$$);if($APP.$cljs$core$vector_QMARK_$$($e$jscomp$315$$))$G__54768_ret$jscomp$145_self$jscomp$73$$=$APP.$cljs$core$_assoc$$($G__54768_ret$jscomp$145_self$jscomp$73$$,$APP.$cljs$core$_nth$$($e$jscomp$315$$,0),$APP.$cljs$core$_nth$$($e$jscomp$315$$,1)),$G__54769_entry$jscomp$46_es$jscomp$10$$=$APP.$cljs$core$next$$($G__54769_entry$jscomp$46_es$jscomp$10$$);else throw Error("conj on a map takes map entries or seqables of map entries");
}};$app$render_wasm$shape$create_shape$$=function($attrs$jscomp$59$$){return new $app$render_wasm$shape$ShapeProxy$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$59$$),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$59$$),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$app$render_wasm$shape$xf_COLON_without_id_and_type$$,$attrs$jscomp$59$$))};
$app$render_wasm$initialize$$=function($enabled_QMARK_$jscomp$1$$){$app$common$types$path$wasm_COLON_calc_bool_content$$=$APP.$cljs$core$truth_$$($enabled_QMARK_$jscomp$1$$)?$app$render_wasm$api$calculate_bool$$:null;$app$common$types$shape$wasm_enabled_QMARK_$$=$enabled_QMARK_$jscomp$1$$;$app$common$types$shape$wasm_create_shape$$=$app$render_wasm$shape$create_shape$$};
$app$main$features$setup_wasm_features$$=function($features__$1$jscomp$4_features__$2$jscomp$1$$,$renderer_state$jscomp$164$$){var $wasm_override$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$router$get_params$$($renderer_state$jscomp$164$$),$APP.$cljs$cst$3104$wasm$$);$renderer_state$jscomp$164$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1198$render_switch$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($renderer_state$jscomp$164$$,
$APP.$cljs$cst$1914$profile$$),$APP.$cljs$cst$575$props$$),$APP.$cljs$cst$3105$renderer$$,$APP.$cljs$cst$1538$svg$$):null;$features__$1$jscomp$4_features__$2$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("true",$wasm_override$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($features__$1$jscomp$4_features__$2$jscomp$1$$,"render-wasm/v1"):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("false",$wasm_override$$)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($features__$1$jscomp$4_features__$2$jscomp$1$$,
"render-wasm/v1"):$renderer_state$jscomp$164$$!=null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3104$wasm$$,$renderer_state$jscomp$164$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($features__$1$jscomp$4_features__$2$jscomp$1$$,"render-wasm/v1"):$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($features__$1$jscomp$4_features__$2$jscomp$1$$,"render-wasm/v1"):$features__$1$jscomp$4_features__$2$jscomp$1$$;return $APP.$cljs$core$contains_QMARK_$$($features__$1$jscomp$4_features__$2$jscomp$1$$,
"render-wasm/v1")?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($features__$1$jscomp$4_features__$2$jscomp$1$$,"text-editor/v2"):$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$variadic$($features__$1$jscomp$4_features__$2$jscomp$1$$,"text-editor/v2",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["text-editor-wasm/v1"]))};
$APP.$app$main$features$get_enabled_features$$=function($state$jscomp$165$$,$team$jscomp$2_team_id$jscomp$25$$){$team$jscomp$2_team_id$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$165$$,$APP.$cljs$cst$2173$teams$$),$team$jscomp$2_team_id$jscomp$25$$);return $app$main$features$setup_wasm_features$$($APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$features$global_enabled_features$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$165$$,$APP.$cljs$cst$3082$features_runtime$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$)),$APP.$app$common$features$no_migration_features$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$2_team_id$jscomp$25$$,$APP.$cljs$cst$227$features$$)),$state$jscomp$165$$)};
$APP.$app$main$features$active_feature_QMARK_$$=function($state$jscomp$166$$,$feature$jscomp$7$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$227$features$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$166$$),$feature$jscomp$7$$)};
$APP.$app$main$features$initialize$$=function($features__$1$jscomp$6$$){typeof $app$main$features$initialize_54846$$==="undefined"&&($app$main$features$initialize_54846$$=function($features$jscomp$3$$,$meta54847$$){this.features=$features$jscomp$3$$;this.$meta54847$=$meta54847$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$features$initialize_54846$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$features$initialize_54846$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3108$app_DOT_main_DOT_features_SLASH_initialize$$},$app$main$features$initialize_54846$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_54848$$,$meta54847__$1$$){return new $app$main$features$initialize_54846$$(this.features,$meta54847__$1$$)},$app$main$features$initialize_54846$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta54847$},$app$main$features$initialize_54846$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$features$initialize_54846$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1639_features__$2$jscomp$2$$,$state$jscomp$173$$){$_$jscomp$1639_features__$2$jscomp$2$$=$app$main$features$setup_wasm_features$$($APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$features$global_enabled_features$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$173$$,$APP.$cljs$cst$3082$features_runtime$$,
$APP.$cljs$core$PersistentHashSet$EMPTY$$)),this.features),$state$jscomp$173$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$173$$,$APP.$cljs$cst$227$features$$,$_$jscomp$1639_features__$2$jscomp$2$$)},$app$main$features$initialize_54846$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$features$initialize_54846$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1640$$,$state$jscomp$174$$){var $features__$2$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$174$$,$APP.$cljs$cst$227$features$$);$APP.$cljs$core$contains_QMARK_$$($features__$2$jscomp$3$$,"render-wasm/v1")?$app$render_wasm$initialize$$(!0):$app$render_wasm$initialize$$(!1);$APP.$app$common$logging$enabled_QMARK_$$("app.main.features",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"initialized"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3109$enabled$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$features__$2$jscomp$3$$)],null)],null)}),null,"app.main.features",$APP.$cljs$cst$1161$info$$,!1);return null});return new $app$main$features$initialize_54846$$($features__$1$jscomp$6$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$features$recompute_features$$=function(){typeof $app$main$features$recompute_features_54849$$==="undefined"&&($app$main$features$recompute_features_54849$$=function($meta54850$$){this.$meta54850$=$meta54850$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$features$recompute_features_54849$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$features$recompute_features_54849$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3110$app_DOT_main_DOT_features_SLASH_recompute_features$$},
$app$main$features$recompute_features_54849$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_54851$$,$meta54850__$1$$){return new $app$main$features$recompute_features_54849$$($meta54850__$1$$)},$app$main$features$recompute_features_54849$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta54850$},$app$main$features$recompute_features_54849$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$features$recompute_features_54849$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$1641_or__5025__auto__$jscomp$inline_6133_previous$jscomp$3$$,$state$jscomp$175$$){$_$jscomp$1641_or__5025__auto__$jscomp$inline_6133_previous$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$175$$,$APP.$cljs$cst$227$features$$);$_$jscomp$1641_or__5025__auto__$jscomp$inline_6133_previous$jscomp$3$$=$APP.$cljs$core$truth_$$($_$jscomp$1641_or__5025__auto__$jscomp$inline_6133_previous$jscomp$3$$)?$_$jscomp$1641_or__5025__auto__$jscomp$inline_6133_previous$jscomp$3$$:
$APP.$cljs$core$PersistentHashSet$EMPTY$$;var $features__$1$jscomp$7$$=$app$main$features$setup_wasm_features$$($_$jscomp$1641_or__5025__auto__$jscomp$inline_6133_previous$jscomp$3$$,$state$jscomp$175$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1641_or__5025__auto__$jscomp$inline_6133_previous$jscomp$3$$,$features__$1$jscomp$7$$)?$state$jscomp$175$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$175$$,$APP.$cljs$cst$227$features$$,$features__$1$jscomp$7$$)},
$app$main$features$recompute_features_54849$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$features$recompute_features_54849$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1642$$,$state$jscomp$176$$){var $features__$1$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$176$$,$APP.$cljs$cst$227$features$$);$APP.$cljs$core$contains_QMARK_$$($features__$1$jscomp$8$$,"render-wasm/v1")?$app$render_wasm$initialize$$(!0):
$app$render_wasm$initialize$$(!1);$APP.$app$common$logging$enabled_QMARK_$$("app.main.features",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"recomputed features"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3109$enabled$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$features__$1$jscomp$8$$)],null)],null)}),null,"app.main.features",$APP.$cljs$cst$1161$info$$,!1);return null});return new $app$main$features$recompute_features_54849$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$util$worker$send_message_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($worker$jscomp$1$$,$ignore_response_QMARK__map__53867__$1_p__53864$$,$data$jscomp$261_p__53865$$){function $take_messages$$($ob$jscomp$94$$){return $APP.$cljs$core$truth_$$($many_QMARK_$$)?$beicon$v2$core$take_while$$(function($p1__53856_SHARP_$$){return $APP.$cljs$core$not$$($cljs$cst$3123$completed$$.$cljs$core$IFn$_invoke$arity$1$($p1__53856_SHARP_$$))},$ob$jscomp$94$$):$APP.$beicon$v2$core$take$$($ob$jscomp$94$$)}
var $map__53866__$1$$=$APP.$cljs$core$__destructure_map$$($ignore_response_QMARK__map__53867__$1_p__53864$$),$sender_id$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53866__$1$$,$APP.$cljs$cst$3111$sender_id$$);$ignore_response_QMARK__map__53867__$1_p__53864$$=$APP.$cljs$core$__destructure_map$$($data$jscomp$261_p__53865$$);var $many_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($ignore_response_QMARK__map__53867__$1_p__53864$$,$cljs$cst$3121$many_QMARK_$$,
!1);$ignore_response_QMARK__map__53867__$1_p__53864$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($ignore_response_QMARK__map__53867__$1_p__53864$$,$cljs$cst$3122$ignore_response_QMARK_$$,!1);var $transfer$jscomp$4$$=$APP.$cljs$cst$3124$transfer$$.$cljs$core$IFn$_invoke$arity$1$($map__53866__$1$$);$data$jscomp$261_p__53865$$=function(){var $G__53868_p__53796$jscomp$inline_6135_sender_id$jscomp$inline_6137$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($map__53866__$1$$,$APP.$cljs$cst$3124$transfer$$);
var $buffer_QMARK_$jscomp$inline_6140_map__53797__$1$jscomp$inline_6136$$=$APP.$cljs$core$__destructure_map$$($G__53868_p__53796$jscomp$inline_6135_sender_id$jscomp$inline_6137$$);$G__53868_p__53796$jscomp$inline_6135_sender_id$jscomp$inline_6137$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($buffer_QMARK_$jscomp$inline_6140_map__53797__$1$jscomp$inline_6136$$,$APP.$cljs$cst$3111$sender_id$$);var $reply_to$jscomp$inline_6138$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($buffer_QMARK_$jscomp$inline_6140_map__53797__$1$jscomp$inline_6136$$,
$APP.$cljs$cst$3112$reply_to$$),$payload$jscomp$inline_6139$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($buffer_QMARK_$jscomp$inline_6140_map__53797__$1$jscomp$inline_6136$$,$APP.$cljs$cst$3113$payload$$);$buffer_QMARK_$jscomp$inline_6140_map__53797__$1$jscomp$inline_6136$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($buffer_QMARK_$jscomp$inline_6140_map__53797__$1$jscomp$inline_6136$$,$APP.$cljs$cst$3114$buffer_QMARK_$$);$G__53868_p__53796$jscomp$inline_6135_sender_id$jscomp$inline_6137$$=
{cmd:$APP.$app$common$data$name$$($APP.$cljs$cst$3115$cmd$$.$cljs$core$IFn$_invoke$arity$1$($payload$jscomp$inline_6139$$)),senderId:$APP.$cljs$core$truth_$$($G__53868_p__53796$jscomp$inline_6135_sender_id$jscomp$inline_6137$$)?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__53868_p__53796$jscomp$inline_6135_sender_id$jscomp$inline_6137$$):null,replyTo:$APP.$cljs$core$truth_$$($reply_to$jscomp$inline_6138$$)?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($reply_to$jscomp$inline_6138$$):
null,payload:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3116$initialize_indices$$,$APP.$cljs$cst$3115$cmd$$.$cljs$core$IFn$_invoke$arity$1$($payload$jscomp$inline_6139$$))?$APP.$cljs$cst$3117$file_raw$$.$cljs$core$IFn$_invoke$arity$1$($payload$jscomp$inline_6139$$):$payload$jscomp$inline_6139$$!=null?$APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($payload$jscomp$inline_6139$$,null):null,buffer:$buffer_QMARK_$jscomp$inline_6140_map__53797__$1$jscomp$inline_6136$$!=
null?$buffer_QMARK_$jscomp$inline_6140_map__53797__$1$jscomp$inline_6136$$:null};return $transfer$jscomp$4$$!=null?$APP.$app$util$object$set_BANG_$$($G__53868_p__53796$jscomp$inline_6135_sender_id$jscomp$inline_6137$$,"transfer",$transfer$jscomp$4$$):$G__53868_p__53796$jscomp$inline_6135_sender_id$jscomp$inline_6137$$}();var $instance$jscomp$8$$=$APP.$cljs$cst$3118$instance$$.$cljs$core$IFn$_invoke$arity$1$($worker$jscomp$1$$);return $instance$jscomp$8$$!=null?($instance$jscomp$8$$.postMessage($data$jscomp$261_p__53865$$,
$transfer$jscomp$4$$),$APP.$cljs$core$not$$($ignore_response_QMARK__map__53867__$1_p__53864$$)?$APP.$beicon$v2$core$map$$($app$util$worker$handle_response$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$complement$$($cljs$cst$3125$dropped$$),$take_messages$$($APP.$beicon$v2$core$filter$$(function($p1__53857_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3112$reply_to$$.$cljs$core$IFn$_invoke$arity$1$($p1__53857_SHARP_$$),$sender_id$jscomp$2$$)},$APP.$cljs$cst$1416$stream$$.$cljs$core$IFn$_invoke$arity$1$($worker$jscomp$1$$))))):
$APP.$beicon$v2$core$empty$$()):$APP.$beicon$v2$core$empty$$()};
$APP.$app$util$worker$ask_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($worker$jscomp$3$$,$message$jscomp$64_message$jscomp$inline_6143$$,$transfer$jscomp$5$$){$message$jscomp$64_message$jscomp$inline_6143$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3111$sender_id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$3113$payload$$,$message$jscomp$64_message$jscomp$inline_6143$$,$APP.$cljs$cst$3124$transfer$$,$transfer$jscomp$5$$],null);return $APP.$app$util$worker$send_message_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($worker$jscomp$3$$,
$message$jscomp$64_message$jscomp$inline_6143$$,null)};
$app$util$worker$handle_response$$=function($data$jscomp$262_p__53887_payload$jscomp$5$$){var $map__53888__$1_map__53891__$1_message$jscomp$72_temp__5823__auto__$jscomp$155$$=$APP.$cljs$core$__destructure_map$$($data$jscomp$262_p__53887_payload$jscomp$5$$);$data$jscomp$262_p__53887_payload$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53888__$1_map__53891__$1_message$jscomp$72_temp__5823__auto__$jscomp$155$$,$APP.$cljs$cst$3113$payload$$);$map__53888__$1_map__53891__$1_message$jscomp$72_temp__5823__auto__$jscomp$155$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53888__$1_map__53891__$1_message$jscomp$72_temp__5823__auto__$jscomp$155$$,$APP.$cljs$cst$849$error$$);if($APP.$cljs$core$truth_$$($map__53888__$1_map__53891__$1_message$jscomp$72_temp__5823__auto__$jscomp$155$$))throw $map__53888__$1_map__53891__$1_message$jscomp$72_temp__5823__auto__$jscomp$155$$=$APP.$cljs$core$__destructure_map$$($map__53888__$1_map__53891__$1_message$jscomp$72_temp__5823__auto__$jscomp$155$$),$data$jscomp$262_p__53887_payload$jscomp$5$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53888__$1_map__53891__$1_message$jscomp$72_temp__5823__auto__$jscomp$155$$,$APP.$cljs$cst$142$data$$),$map__53888__$1_map__53891__$1_message$jscomp$72_temp__5823__auto__$jscomp$155$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53888__$1_map__53891__$1_message$jscomp$72_temp__5823__auto__$jscomp$155$$,$APP.$cljs$cst$141$message$$),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$($map__53888__$1_map__53891__$1_message$jscomp$72_temp__5823__auto__$jscomp$155$$,
$data$jscomp$262_p__53887_payload$jscomp$5$$);return $data$jscomp$262_p__53887_payload$jscomp$5$$};
$APP.$app$main$worker$ask_many_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($message$jscomp$79$$){return $APP.$cljs$core$truth_$$($APP.$app$main$worker$instance$$)?$APP.$app$util$worker$send_message_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$main$worker$instance$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3111$sender_id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$3113$payload$$,$message$jscomp$79$$,$APP.$cljs$cst$3124$transfer$$,null],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$3121$many_QMARK_$$,!0],null)):$APP.$beicon$v2$core$empty$$()};
$app$main$data$changes$fix_page_id$$=function($map__54894__$1_p__54893$$){$map__54894__$1_p__54893$$=$APP.$cljs$core$__destructure_map$$($map__54894__$1_p__54893$$);var $id$jscomp$345$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54894__$1_p__54893$$,$APP.$cljs$cst$266$id$$),$JSCompiler_inline_result$jscomp$10829_and__5023__auto__$jscomp$inline_12304_type$jscomp$424$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54894__$1_p__54893$$,$APP.$cljs$cst$139$type$$),$page$jscomp$35$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54894__$1_p__54893$$,$APP.$cljs$cst$1624$page$$);$JSCompiler_inline_result$jscomp$10829_and__5023__auto__$jscomp$inline_12304_type$jscomp$424$$=$app$main$data$changes$page_change_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$changes$page_change_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10829_and__5023__auto__$jscomp$inline_12304_type$jscomp$424$$):$app$main$data$changes$page_change_QMARK_$$($JSCompiler_inline_result$jscomp$10829_and__5023__auto__$jscomp$inline_12304_type$jscomp$424$$);
$JSCompiler_inline_result$jscomp$10829_and__5023__auto__$jscomp$inline_12304_type$jscomp$424$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10829_and__5023__auto__$jscomp$inline_12304_type$jscomp$424$$)?$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($map__54894__$1_p__54893$$)==null:$JSCompiler_inline_result$jscomp$10829_and__5023__auto__$jscomp$inline_12304_type$jscomp$424$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10829_and__5023__auto__$jscomp$inline_12304_type$jscomp$424$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__54894__$1_p__54893$$,$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$core$truth_$$($id$jscomp$345$$)?$id$jscomp$345$$:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$35$$)):$map__54894__$1_p__54893$$};
$app$main$data$changes$update_indexes$$=function($commit$$,$attr$jscomp$27$$){typeof $app$main$data$changes$update_indexes_54901$$==="undefined"&&($app$main$data$changes$update_indexes_54901$$=function($commit$jscomp$1$$,$attr$jscomp$28$$,$meta54902$$){this.commit=$commit$jscomp$1$$;this.attr=$attr$jscomp$28$$;this.$meta54902$=$meta54902$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$changes$update_indexes_54901$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$changes$update_indexes_54901$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3130$app_DOT_main_DOT_data_DOT_changes_SLASH_update_indexes$$},$app$main$data$changes$update_indexes_54901$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_54903$$,$meta54902__$1$$){return new $app$main$data$changes$update_indexes_54901$$(this.commit,this.attr,$meta54902__$1$$)},$app$main$data$changes$update_indexes_54901$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta54902$},$app$main$data$changes$update_indexes_54901$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$changes$update_indexes_54901$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $changes$jscomp$4$$=$APP.$cljs$core$group_by$$($APP.$cljs$cst$2043$page_id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2043$page_id$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$changes$fix_page_id$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this.commit,this.attr))));return $APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$49$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.changes",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"unable to update index"],null)],null)}),$cause$jscomp$49$$,"app.main.data.changes",$APP.$cljs$cst$1162$warn$$,!1);return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$merge_map$$(function($p__54940$$){var $page_id$jscomp$55$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__54940$$,0,null),$changes__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__54940$$,1,null);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.changes",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"update-indexes"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$55$$],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3131$changes$$,$APP.$cljs$core$count$$($changes__$1$$)],null)],null)}),null,"app.main.data.changes",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3115$cmd$$,$cljs$cst$3132$index_SLASH_update$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$55$$,$APP.$cljs$cst$3131$changes$$,
$changes__$1$$],null))},$APP.$beicon$v2$core$from$$($changes$jscomp$4$$))))});return new $app$main$data$changes$update_indexes_54901$$($commit$$,$attr$jscomp$27$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$changes$get_pending_commits$$=function($map__54953__$1_p__54952_persistence$$){$map__54953__$1_p__54952_persistence$$=$APP.$cljs$core$__destructure_map$$($map__54953__$1_p__54952_persistence$$);$map__54953__$1_p__54952_persistence$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54953__$1_p__54952_persistence$$,$APP.$cljs$cst$2178$persistence$$);return $APP.$cljs$core$not_empty$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($map__54953__$1_p__54952_persistence$$)),
$APP.$cljs$cst$1484$queue$$.$cljs$core$IFn$_invoke$arity$1$($map__54953__$1_p__54952_persistence$$)))};$app$main$data$changes$redo_changes_need_wasm_object_sync_QMARK_$$=function($redo_changes$$){return $APP.$cljs$core$some$$(function($p1__54954_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($app$main$data$changes$wasm_structural_change_types$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__54954_SHARP_$$))},$redo_changes$$)};
$app$main$data$changes$sync_wasm_structural_changes$$=function($p__54960$$){var $map__54961__$1$$=$APP.$cljs$core$__destructure_map$$($p__54960$$),$redo_changes$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54961__$1$$,$APP.$cljs$cst$3133$redo_changes$$);typeof $app$main$data$changes$sync_wasm_structural_changes_54972$$==="undefined"&&($app$main$data$changes$sync_wasm_structural_changes_54972$$=function($p__54960$jscomp$1$$,$map__54961$jscomp$1$$,$redo_changes$jscomp$2$$,
$meta54973$$){this.$p__54960$=$p__54960$jscomp$1$$;this.$map__54961$=$map__54961$jscomp$1$$;this.$redo_changes$=$redo_changes$jscomp$2$$;this.$meta54973$=$meta54973$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$changes$sync_wasm_structural_changes_54972$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$changes$sync_wasm_structural_changes_54972$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3134$app_DOT_main_DOT_data_DOT_changes_SLASH_sync_wasm_structural_changes$$},
$app$main$data$changes$sync_wasm_structural_changes_54972$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_54974$$,$meta54973__$1$$){return new $app$main$data$changes$sync_wasm_structural_changes_54972$$(this.$p__54960$,this.$map__54961$,this.$redo_changes$,$meta54973__$1$$)},$app$main$data$changes$sync_wasm_structural_changes_54972$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta54973$},$app$main$data$changes$sync_wasm_structural_changes_54972$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$changes$sync_wasm_structural_changes_54972$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1644_objects$jscomp$245$$,$G__55254_seq__54978_55225_seq__54978_55252__$1_state$jscomp$177_temp__5825__auto___55251$$){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($app$render_wasm$wasm$context_lost_QMARK_$$))){$_$jscomp$1644_objects$jscomp$245$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($G__55254_seq__54978_55225_seq__54978_55252__$1_state$jscomp$177_temp__5825__auto___55251$$);
$G__55254_seq__54978_55225_seq__54978_55252__$1_state$jscomp$177_temp__5825__auto___55251$$=$APP.$cljs$core$seq$$(this.$redo_changes$);for(var $G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$=null,$G__55256_c__5548__auto___55253_count__54983_55227$$=0,$i__54984_55228$$=0;;)if($i__54984_55228$$<$G__55256_c__5548__auto___55253_count__54983_55227$$){var $map__55033_55229_map__55033_55230__$1_shape_55235_shape_id_55234$$=$G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$i__54984_55228$$);$map__55033_55229_map__55033_55230__$1_shape_55235_shape_id_55234$$=$APP.$cljs$core$__destructure_map$$($map__55033_55229_map__55033_55230__$1_shape_55235_shape_id_55234$$);var $type_55231$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55033_55229_map__55033_55230__$1_shape_55235_shape_id_55234$$,$APP.$cljs$cst$139$type$$),$id_55232$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55033_55229_map__55033_55230__$1_shape_55235_shape_id_55234$$,$APP.$cljs$cst$266$id$$),
$parent_id_55233$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55033_55229_map__55033_55230__$1_shape_55235_shape_id_55234$$,$APP.$cljs$cst$1619$parent_id$$);$APP.$cljs$core$contains_QMARK_$$($app$main$data$changes$wasm_structural_change_types$$,$type_55231$$)&&($map__55033_55229_map__55033_55230__$1_shape_55235_shape_id_55234$$=function(){var $G__55034_G__55034__$1$$=$type_55231$$;$G__55034_G__55034__$1$$=$G__55034_G__55034__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__55034_G__55034__$1$$.$fqn$:
null;switch($G__55034_G__55034__$1$$){case "add-obj":return $id_55232$$;case "mov-objects":return $parent_id_55233$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__55034_G__55034__$1$$)].join(""));}}(),$map__55033_55229_map__55033_55230__$1_shape_55235_shape_id_55234$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1644_objects$jscomp$245$$,$map__55033_55229_map__55033_55230__$1_shape_55235_shape_id_55234$$),$APP.$cljs$core$truth_$$($map__55033_55229_map__55033_55230__$1_shape_55235_shape_id_55234$$)&&
$app$render_wasm$api$process_object$$($map__55033_55229_map__55033_55230__$1_shape_55235_shape_id_55234$$));$i__54984_55228$$+=1}else if($G__55254_seq__54978_55225_seq__54978_55252__$1_state$jscomp$177_temp__5825__auto___55251$$=$APP.$cljs$core$seq$$($G__55254_seq__54978_55225_seq__54978_55252__$1_state$jscomp$177_temp__5825__auto___55251$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($G__55254_seq__54978_55225_seq__54978_55252__$1_state$jscomp$177_temp__5825__auto___55251$$))$G__55256_c__5548__auto___55253_count__54983_55227$$=
$APP.$cljs$core$_chunked_first$$($G__55254_seq__54978_55225_seq__54978_55252__$1_state$jscomp$177_temp__5825__auto___55251$$),$G__55254_seq__54978_55225_seq__54978_55252__$1_state$jscomp$177_temp__5825__auto___55251$$=$APP.$cljs$core$_chunked_rest$$($G__55254_seq__54978_55225_seq__54978_55252__$1_state$jscomp$177_temp__5825__auto___55251$$),$G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$=$G__55256_c__5548__auto___55253_count__54983_55227$$,$G__55256_c__5548__auto___55253_count__54983_55227$$=
$APP.$cljs$core$count$$($G__55256_c__5548__auto___55253_count__54983_55227$$);else{$G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$=$APP.$cljs$core$first$$($G__55254_seq__54978_55225_seq__54978_55252__$1_state$jscomp$177_temp__5825__auto___55251$$);$G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$=$APP.$cljs$core$__destructure_map$$($G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$);
var $type_55260$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$,$APP.$cljs$cst$139$type$$),$id_55261$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$,$APP.$cljs$cst$266$id$$),$parent_id_55262$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$,
$APP.$cljs$cst$1619$parent_id$$);$APP.$cljs$core$contains_QMARK_$$($app$main$data$changes$wasm_structural_change_types$$,$type_55260$$)&&($G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$=function(){var $G__55036_G__55036__$1$$=$type_55260$$;$G__55036_G__55036__$1$$=$G__55036_G__55036__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__55036_G__55036__$1$$.$fqn$:null;switch($G__55036_G__55036__$1$$){case "add-obj":return $id_55261$$;case "mov-objects":return $parent_id_55262$$;
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__55036_G__55036__$1$$)].join(""));}}(),$G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1644_objects$jscomp$245$$,$G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$),$APP.$cljs$core$truth_$$($G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$)&&
$app$render_wasm$api$process_object$$($G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$));$G__55254_seq__54978_55225_seq__54978_55252__$1_state$jscomp$177_temp__5825__auto___55251$$=$APP.$cljs$core$next$$($G__55254_seq__54978_55225_seq__54978_55252__$1_state$jscomp$177_temp__5825__auto___55251$$);$G__55255_chunk__54982_55226_map__55035_55258_map__55035_55259__$1_shape_55264_shape_id_55263$$=null;$G__55256_c__5548__auto___55253_count__54983_55227$$=0}$i__54984_55228$$=
0}else break;return $APP.$app$render_wasm$api$request_render$$("sync-wasm-structural-changes")}return null});return new $app$main$data$changes$sync_wasm_structural_changes_54972$$($p__54960$$,$map__54961__$1$$,$redo_changes$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$changes$apply_changes_localy$$=function($p__55042$$,$pending$jscomp$12$$){var $map__55043__$1$$=$APP.$cljs$core$__destructure_map$$($p__55042$$),$file_id$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55043__$1$$,$APP.$cljs$cst$1644$file_id$$),$redo_changes$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55043__$1$$,$APP.$cljs$cst$3133$redo_changes$$),$ignore_wasm_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55043__$1$$,
$cljs$cst$3135$ignore_wasm_QMARK_$$);typeof $app$main$data$changes$apply_changes_localy_55044$$==="undefined"&&($app$main$data$changes$apply_changes_localy_55044$$=function($p__55042$jscomp$1$$,$pending$jscomp$13$$,$map__55043$jscomp$1$$,$commit$jscomp$3$$,$file_id$jscomp$32$$,$redo_changes$jscomp$4$$,$ignore_wasm_QMARK_$jscomp$1$$,$meta55045$$){this.$p__55042$=$p__55042$jscomp$1$$;this.pending=$pending$jscomp$13$$;this.$map__55043$=$map__55043$jscomp$1$$;this.commit=$commit$jscomp$3$$;this.$file_id$=
$file_id$jscomp$32$$;this.$redo_changes$=$redo_changes$jscomp$4$$;this.$ignore_wasm_QMARK_$=$ignore_wasm_QMARK_$jscomp$1$$;this.$meta55045$=$meta55045$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$changes$apply_changes_localy_55044$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$changes$apply_changes_localy_55044$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3136$app_DOT_main_DOT_data_DOT_changes_SLASH_apply_changes_localy$$},
$app$main$data$changes$apply_changes_localy_55044$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55046$$,$meta55045__$1$$){return new $app$main$data$changes$apply_changes_localy_55044$$(this.$p__55042$,this.pending,this.$map__55043$,this.commit,this.$file_id$,this.$redo_changes$,this.$ignore_wasm_QMARK_$,$meta55045__$1$$)},$app$main$data$changes$apply_changes_localy_55044$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55045$},$app$main$data$changes$apply_changes_localy_55044$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$changes$apply_changes_localy_55044$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1645_state__$1$jscomp$14$$,$state$jscomp$178$$){function $apply_changes$$($fdata$jscomp$3_fdata__$1$jscomp$1_fdata__$2$$){$fdata$jscomp$3_fdata__$1$jscomp$1_fdata__$2$$=$APP.$app$common$files$changes$process_changes$$.$cljs$core$IFn$_invoke$arity$3$($fdata$jscomp$3_fdata__$1$jscomp$1_fdata__$2$$,$undo_changes$$,!1);$fdata$jscomp$3_fdata__$1$jscomp$1_fdata__$2$$=
$APP.$app$common$files$changes$process_changes$$.$cljs$core$IFn$_invoke$arity$3$($fdata$jscomp$3_fdata__$1$jscomp$1_fdata__$2$$,$redo_changes__$1$$,!1);var $pids$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$app$main$data$changes$xf_COLON_map_page_id$$,$redo_changes__$1$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__55040_SHARP_$$,$p2__55041_SHARP_$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($p1__55040_SHARP_$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$p2__55041_SHARP_$$,$APP.$cljs$cst$1631$objects$$],null),$app$common$types$shape_tree$update_page_index$$)},$fdata$jscomp$3_fdata__$1$jscomp$1_fdata__$2$$,$pids$$)}var $self__$jscomp$3492$$=this,$undo_changes$$=$APP.$cljs$core$truth_$$($self__$jscomp$3492$$.pending)?$APP.$cljs$core$vec$$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$identity$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$reverse$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3137$undo_changes$$,$self__$jscomp$3492$$.pending))]))):null,$redo_changes__$1$$=$APP.$cljs$core$truth_$$($self__$jscomp$3492$$.pending)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$3492$$.$redo_changes$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3133$redo_changes$$),$self__$jscomp$3492$$.pending):
$self__$jscomp$3492$$.$redo_changes$;if($APP.$cljs$core$not$$($self__$jscomp$3492$$.$ignore_wasm_QMARK_$)&&$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$178$$,"render-wasm/v1")){var $shape_changes$jscomp$1$$=$APP.$cljs$core$volatile_BANG_$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$_$jscomp$1645_state__$1$jscomp$14$$=function(){var $_STAR_shape_changes_STAR__orig_val__55062$$=$app$common$types$shape$_STAR_shape_changes_STAR_$$;$app$common$types$shape$_STAR_shape_changes_STAR_$$=
$shape_changes$jscomp$1$$;try{return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$178$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,$self__$jscomp$3492$$.$file_id$,$APP.$cljs$cst$142$data$$],null),$apply_changes$$)}finally{$app$common$types$shape$_STAR_shape_changes_STAR_$$=$_STAR_shape_changes_STAR__orig_val__55062$$}}();var $objects_55281$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1645_state__$1$jscomp$14$$,
$APP.$cljs$cst$1916$files$$),$self__$jscomp$3492$$.$file_id$),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1630$pages_index$$),$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1645_state__$1$jscomp$14$$)),$APP.$cljs$cst$1631$objects$$);$app$render_wasm$shape$process_shape_changes_BANG_$$($objects_55281$$,$APP.$cljs$core$_deref$$($shape_changes$jscomp$1$$));return $_$jscomp$1645_state__$1$jscomp$14$$}return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$178$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,$self__$jscomp$3492$$.$file_id$,$APP.$cljs$cst$142$data$$],null),$apply_changes$$)},$app$main$data$changes$apply_changes_localy_55044$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$changes$apply_changes_localy_55044$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1646_and__5023__auto__$jscomp$inline_6148$$,$JSCompiler_inline_result$jscomp$1047_and__5023__auto____$1$jscomp$inline_6149_state$jscomp$179$$){$JSCompiler_inline_result$jscomp$1047_and__5023__auto____$1$jscomp$inline_6149_state$jscomp$179$$=
($_$jscomp$1646_and__5023__auto__$jscomp$inline_6148$$=$APP.$cljs$core$not$$(this.$ignore_wasm_QMARK_$))?($JSCompiler_inline_result$jscomp$1047_and__5023__auto____$1$jscomp$inline_6149_state$jscomp$179$$=$APP.$app$main$features$active_feature_QMARK_$$($JSCompiler_inline_result$jscomp$1047_and__5023__auto____$1$jscomp$inline_6149_state$jscomp$179$$,"render-wasm/v1"))?$app$main$data$changes$redo_changes_need_wasm_object_sync_QMARK_$$(this.$redo_changes$):$JSCompiler_inline_result$jscomp$1047_and__5023__auto____$1$jscomp$inline_6149_state$jscomp$179$$:
$_$jscomp$1646_and__5023__auto__$jscomp$inline_6148$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1047_and__5023__auto____$1$jscomp$inline_6149_state$jscomp$179$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$changes$sync_wasm_structural_changes$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3133$redo_changes$$,this.$redo_changes$],null))):null});return new $app$main$data$changes$apply_changes_localy_55044$$($p__55042$$,$pending$jscomp$12$$,$map__55043__$1$$,
$map__55043__$1$$,$file_id$jscomp$31$$,$redo_changes$jscomp$3$$,$ignore_wasm_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$changes$commit$$=function($p__55107$$){var $map__55108__$1$$=$APP.$cljs$core$__destructure_map$$($p__55107$$),$undo_group$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$APP.$cljs$cst$3138$undo_group$$),$file_revn$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$APP.$cljs$cst$3139$file_revn$$),$save_undo_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$),$undo_changes$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$APP.$cljs$cst$3137$undo_changes$$),$stack_undo_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$APP.$cljs$cst$3141$stack_undo_QMARK_$$),$features__$1$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$APP.$cljs$cst$227$features$$),$tags$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$APP.$cljs$cst$3142$tags$$),$file_id$jscomp$33$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$APP.$cljs$cst$1644$file_id$$),$file_vern$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$APP.$cljs$cst$3143$file_vern$$),$selected_before$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$cljs$cst$3144$selected_before$$),$translation_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$cljs$cst$3145$translation_QMARK_$$),$ignore_wasm_QMARK_$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$cljs$cst$3135$ignore_wasm_QMARK_$$),$source$jscomp$43_source__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$APP.$cljs$cst$193$source$$),$redo_changes$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$APP.$cljs$cst$3133$redo_changes$$),$commit_id_commit_id__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$APP.$cljs$cst$3146$commit_id$$),
$origin$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55108__$1$$,$APP.$cljs$cst$1786$origin$$);$commit_id_commit_id__$1$$=$APP.$cljs$core$truth_$$($commit_id_commit_id__$1$$)?$commit_id_commit_id__$1$$:$APP.$app$common$uuid$next$$();$source$jscomp$43_source__$1$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($source$jscomp$43_source__$1$jscomp$1$$,$APP.$cljs$cst$2883$local$$);var $local_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($source$jscomp$43_source__$1$jscomp$1$$,
$APP.$cljs$cst$2883$local$$),$commit$jscomp$4$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$227$features$$,$APP.$cljs$cst$3142$tags$$,$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$3143$file_vern$$,$cljs$cst$3144$selected_before$$,$cljs$cst$3145$translation_QMARK_$$,$cljs$cst$3135$ignore_wasm_QMARK_$$,$APP.$cljs$cst$193$source$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$3131$changes$$,$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$3139$file_revn$$,$APP.$cljs$cst$3138$undo_group$$,
$APP.$cljs$cst$3140$save_undo_QMARK_$$,$APP.$cljs$cst$1569$created_at$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$cst$3141$stack_undo_QMARK_$$],[$features__$1$jscomp$9$$,$tags$jscomp$5$$,$file_id$jscomp$33$$,$file_vern$$,$selected_before$$,$translation_QMARK_$$,$ignore_wasm_QMARK_$jscomp$2$$,$source$jscomp$43_source__$1$jscomp$1$$,$redo_changes$jscomp$5$$,$commit_id_commit_id__$1$$,$redo_changes$jscomp$5$$,$APP.$potok$v2$core$type$$($origin$jscomp$19$$),$file_revn$$,$undo_group$$,$save_undo_QMARK_$$,
$APP.$app$common$time$now$$(),$undo_changes$jscomp$1$$,$stack_undo_QMARK_$$]);typeof $app$main$data$changes$commit_55124$$==="undefined"&&($app$main$data$changes$commit_55124$$=function($undo_group$jscomp$1$$,$file_revn$jscomp$1$$,$save_undo_QMARK_$jscomp$1$$,$undo_changes$jscomp$2$$,$stack_undo_QMARK_$jscomp$1$$,$features$jscomp$4$$,$tags$jscomp$6$$,$file_id$jscomp$34$$,$file_vern$jscomp$1$$,$selected_before$jscomp$1$$,$local_QMARK_$jscomp$1$$,$translation_QMARK_$jscomp$1$$,$p__55107$jscomp$1$$,
$ignore_wasm_QMARK_$jscomp$3$$,$source$jscomp$44$$,$redo_changes$jscomp$6$$,$map__55108$jscomp$1$$,$commit_id$jscomp$1$$,$commit$jscomp$5$$,$origin$jscomp$20$$,$meta55125$$){this.$undo_group$=$undo_group$jscomp$1$$;this.$file_revn$=$file_revn$jscomp$1$$;this.$save_undo_QMARK_$=$save_undo_QMARK_$jscomp$1$$;this.$undo_changes$=$undo_changes$jscomp$2$$;this.$stack_undo_QMARK_$=$stack_undo_QMARK_$jscomp$1$$;this.features=$features$jscomp$4$$;this.$tags$=$tags$jscomp$6$$;this.$file_id$=$file_id$jscomp$34$$;
this.$file_vern$=$file_vern$jscomp$1$$;this.$selected_before$=$selected_before$jscomp$1$$;this.$local_QMARK_$=$local_QMARK_$jscomp$1$$;this.$translation_QMARK_$=$translation_QMARK_$jscomp$1$$;this.$p__55107$=$p__55107$jscomp$1$$;this.$ignore_wasm_QMARK_$=$ignore_wasm_QMARK_$jscomp$3$$;this.source=$source$jscomp$44$$;this.$redo_changes$=$redo_changes$jscomp$6$$;this.$map__55108$=$map__55108$jscomp$1$$;this.$commit_id$=$commit_id$jscomp$1$$;this.commit=$commit$jscomp$5$$;this.origin=$origin$jscomp$20$$;
this.$meta55125$=$meta55125$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$changes$commit_55124$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$changes$commit_55124$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2147$app_DOT_main_DOT_data_DOT_changes_SLASH_commit$$},$app$main$data$changes$commit_55124$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55126$$,
$meta55125__$1$$){return new $app$main$data$changes$commit_55124$$(this.$undo_group$,this.$file_revn$,this.$save_undo_QMARK_$,this.$undo_changes$,this.$stack_undo_QMARK_$,this.features,this.$tags$,this.$file_id$,this.$file_vern$,this.$selected_before$,this.$local_QMARK_$,this.$translation_QMARK_$,this.$p__55107$,this.$ignore_wasm_QMARK_$,this.source,this.$redo_changes$,this.$map__55108$,this.$commit_id$,this.commit,this.origin,$meta55125__$1$$)},$app$main$data$changes$commit_55124$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55125$},$app$main$data$changes$commit_55124$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.commit},$app$main$data$changes$commit_55124$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$changes$commit_55124$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1648_pending$jscomp$14$$,$state$jscomp$180$$){$_$jscomp$1648_pending$jscomp$14$$=$APP.$cljs$core$truth_$$(this.$local_QMARK_$)?null:
$app$main$data$changes$get_pending_commits$$($state$jscomp$180$$);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$changes$apply_changes_localy$$(this.commit,$_$jscomp$1648_pending$jscomp$14$$)),$APP.$cljs$core$truth_$$($_$jscomp$1648_pending$jscomp$14$$)?$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$map$$(function($commit__$1$$){return $app$main$data$changes$update_indexes$$($commit__$1$$,$APP.$cljs$cst$3137$undo_changes$$)},$APP.$beicon$v2$core$from$$($APP.$cljs$core$reverse$$($_$jscomp$1648_pending$jscomp$14$$))),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$changes$update_indexes$$(this.commit,$APP.$cljs$cst$3133$redo_changes$$)),$APP.$beicon$v2$core$map$$(function($commit__$1$jscomp$1$$){return $app$main$data$changes$update_indexes$$($commit__$1$jscomp$1$$,$APP.$cljs$cst$3133$redo_changes$$)},$APP.$beicon$v2$core$from$$($_$jscomp$1648_pending$jscomp$14$$))):(0,$APP.$beicon$v2$core$of$$)($app$main$data$changes$update_indexes$$(this.commit,$APP.$cljs$cst$3133$redo_changes$$)))});return new $app$main$data$changes$commit_55124$$($undo_group$$,
$file_revn$$,$save_undo_QMARK_$$,$undo_changes$jscomp$1$$,$stack_undo_QMARK_$$,$features__$1$jscomp$9$$,$tags$jscomp$5$$,$file_id$jscomp$33$$,$file_vern$$,$selected_before$$,$local_QMARK_$$,$translation_QMARK_$$,$p__55107$$,$ignore_wasm_QMARK_$jscomp$2$$,$source$jscomp$43_source__$1$jscomp$1$$,$redo_changes$jscomp$5$$,$map__55108__$1$$,$commit_id_commit_id__$1$$,$commit$jscomp$4$$,$origin$jscomp$19$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$changes$commit_changes$$=function($p__55175$$){var $map__55176__$1$$=$APP.$cljs$core$__destructure_map$$($p__55175$$),$redo_changes$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55176__$1$$,$APP.$cljs$cst$3133$redo_changes$$),$undo_changes$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55176__$1$$,$APP.$cljs$cst$3137$undo_changes$$),$save_undo_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55176__$1$$,
$APP.$cljs$cst$3140$save_undo_QMARK_$$,!0),$undo_group$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55176__$1$$,$APP.$cljs$cst$3138$undo_group$$,$APP.$app$common$uuid$next$$()),$tags$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55176__$1$$,$APP.$cljs$cst$3142$tags$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$stack_undo_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55176__$1$$,$APP.$cljs$cst$3141$stack_undo_QMARK_$$,
!1),$file_id$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55176__$1$$,$APP.$cljs$cst$1644$file_id$$),$translation_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55176__$1$$,$cljs$cst$3145$translation_QMARK_$$);typeof $app$main$data$changes$commit_changes_55177$$==="undefined"&&($app$main$data$changes$commit_changes_55177$$=function($undo_group$jscomp$3$$,$save_undo_QMARK_$jscomp$3$$,$undo_changes$jscomp$4$$,$stack_undo_QMARK_$jscomp$3$$,$tags$jscomp$8$$,
$map__55176$jscomp$1$$,$file_id$jscomp$38$$,$params$jscomp$181$$,$translation_QMARK_$jscomp$3$$,$p__55175$jscomp$1$$,$redo_changes$jscomp$8$$,$meta55178$$){this.$undo_group$=$undo_group$jscomp$3$$;this.$save_undo_QMARK_$=$save_undo_QMARK_$jscomp$3$$;this.$undo_changes$=$undo_changes$jscomp$4$$;this.$stack_undo_QMARK_$=$stack_undo_QMARK_$jscomp$3$$;this.$tags$=$tags$jscomp$8$$;this.$map__55176$=$map__55176$jscomp$1$$;this.$file_id$=$file_id$jscomp$38$$;this.params=$params$jscomp$181$$;this.$translation_QMARK_$=
$translation_QMARK_$jscomp$3$$;this.$p__55175$=$p__55175$jscomp$1$$;this.$redo_changes$=$redo_changes$jscomp$8$$;this.$meta55178$=$meta55178$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$changes$commit_changes_55177$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$changes$commit_changes_55177$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3147$app_DOT_main_DOT_data_DOT_changes_SLASH_commit_changes$$},
$app$main$data$changes$commit_changes_55177$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55179$$,$meta55178__$1$$){return new $app$main$data$changes$commit_changes_55177$$(this.$undo_group$,this.$save_undo_QMARK_$,this.$undo_changes$,this.$stack_undo_QMARK_$,this.$tags$,this.$map__55176$,this.$file_id$,this.params,this.$translation_QMARK_$,this.$p__55175$,this.$redo_changes$,$meta55178__$1$$)},$app$main$data$changes$commit_changes_55177$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55178$},$app$main$data$changes$commit_changes_55177$$.prototype.$app$main$data$event$PerformanceEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$changes$commit_changes_55177$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$changes$commit_changes_55177$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1649_file_id__$1$jscomp$2$$,$state$jscomp$183$$){var $self__$jscomp$3502$$=this;$_$jscomp$1649_file_id__$1$jscomp$2$$=
function(){var $or__5025__auto__$jscomp$608$$=$self__$jscomp$3502$$.$file_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$608$$)?$or__5025__auto__$jscomp$608$$:$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$183$$)}();var $uchg$$=$APP.$cljs$core$vec$$($self__$jscomp$3502$$.$undo_changes$),$rchg$$=$APP.$cljs$core$vec$$($self__$jscomp$3502$$.$redo_changes$),$features__$1$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$183$$,
$APP.$cljs$cst$227$features$$),$permissions$jscomp$1_selected$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$183$$,$APP.$cljs$cst$1722$permissions$$);return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$1_selected$jscomp$17$$))?($APP.$app$common$logging$enabled_QMARK_$$("app.main.data.changes",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"commit-changes"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3133$redo_changes$$,$self__$jscomp$3502$$.$redo_changes$],null)],null)}),null,"app.main.data.changes",$APP.$cljs$cst$144$trace$$,!1),$permissions$jscomp$1_selected$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$183$$,
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1921$selected$$),(0,$APP.$beicon$v2$core$of$$)($app$main$data$changes$commit$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$3502$$.params,
$APP.$cljs$cst$3138$undo_group$$,$self__$jscomp$3502$$.$undo_group$),$APP.$cljs$cst$227$features$$,$features__$1$jscomp$10$$),$APP.$cljs$cst$3142$tags$$,$self__$jscomp$3502$$.$tags$),$APP.$cljs$cst$3141$stack_undo_QMARK_$$,$self__$jscomp$3502$$.$stack_undo_QMARK_$),$APP.$cljs$cst$3140$save_undo_QMARK_$$,$self__$jscomp$3502$$.$save_undo_QMARK_$),$APP.$cljs$cst$1644$file_id$$,$_$jscomp$1649_file_id__$1$jscomp$2$$),$APP.$cljs$cst$3139$file_revn$$,$APP.$cljs$cst$2270$revn$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$183$$,
$_$jscomp$1649_file_id__$1$jscomp$2$$))),$APP.$cljs$cst$3143$file_vern$$,$APP.$cljs$cst$2577$vern$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$183$$,$_$jscomp$1649_file_id__$1$jscomp$2$$))),$APP.$cljs$cst$3137$undo_changes$$,$uchg$$),$APP.$cljs$cst$3133$redo_changes$$,$rchg$$),$cljs$cst$3144$selected_before$$,$permissions$jscomp$1_selected$jscomp$17$$),$cljs$cst$3145$translation_QMARK_$$,$self__$jscomp$3502$$.$translation_QMARK_$)))):
null});return new $app$main$data$changes$commit_changes_55177$$($undo_group$jscomp$2$$,$save_undo_QMARK_$jscomp$2$$,$undo_changes$jscomp$3$$,$stack_undo_QMARK_$jscomp$2$$,$tags$jscomp$7$$,$map__55176__$1$$,$file_id$jscomp$37$$,$map__55176__$1$$,$translation_QMARK_$jscomp$2$$,$p__55175$$,$redo_changes$jscomp$7$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$persistence$force_persist_QMARK_$$=function($p1__55284_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__55284_SHARP_$$,$APP.$cljs$cst$2534$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$)};
$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$=function($origin$jscomp$21$$,$page_id$jscomp$56$$){return $APP.$cljs$core$with_meta$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$($origin$jscomp$21$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$,$page_id$jscomp$56$$],null))};
$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$List$EMPTY$$],null)};
$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$=function($origin$jscomp$22$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$List$EMPTY$$,$APP.$cljs$cst$1786$origin$$,$origin$jscomp$22$$],null)};
$app$common$files$changes_builder$set_stack_undo_QMARK_$$=function($changes$jscomp$8$$,$stack_undo_QMARK_$jscomp$4$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$8$$,$APP.$cljs$cst$3141$stack_undo_QMARK_$$,$stack_undo_QMARK_$jscomp$4$$)};
$APP.$app$common$files$changes_builder$set_undo_group$$=function($changes$jscomp$9$$,$undo_group$jscomp$4$$){return $undo_group$jscomp$4$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$9$$,$APP.$cljs$cst$3138$undo_group$$,$undo_group$jscomp$4$$):$changes$jscomp$9$$};
$app$common$files$changes_builder$set_translation_QMARK_$$=function($changes$jscomp$10$$,$translation_QMARK_$jscomp$4$$){return $APP.$cljs$core$truth_$$($translation_QMARK_$jscomp$4$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$10$$,$cljs$cst$3145$translation_QMARK_$$,!0):$changes$jscomp$10$$};
$APP.$app$common$files$changes_builder$with_page$$=function($changes$jscomp$11$$,$page$jscomp$36$$){return $APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$06$$($changes$jscomp$11$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3167$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page$$,$page$jscomp$36$$,$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$36$$))};
$APP.$app$common$files$changes_builder$with_container$$=function($changes$jscomp$13$$,$container$jscomp$37$$){return $app$common$files$helpers$page_QMARK_$$($container$jscomp$37$$)?$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$13$$,$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$37$$)):$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$13$$,
$cljs$cst$3168$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_component_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$37$$))};
$APP.$app$common$files$changes_builder$with_objects$$=function($changes$jscomp$14$$,$fdata__$1$jscomp$2_objects$jscomp$246$$){var $G__51688$jscomp$inline_6154_file_id$jscomp$inline_6151$$=$APP.$app$common$uuid$next$$();var $G__51688__$1$jscomp$inline_6155_fdata$jscomp$4_page$jscomp$inline_6153$$=$APP.$app$common$uuid$zero$$!=null?$app$common$types$page$make_empty_page$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$zero$$,$APP.$cljs$cst$725$name$$,
"Page 1"],null)):null;$G__51688$jscomp$inline_6154_file_id$jscomp$inline_6151$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$file$empty_file_data$$,$APP.$cljs$cst$266$id$$,$G__51688$jscomp$inline_6154_file_id$jscomp$inline_6151$$);$G__51688__$1$jscomp$inline_6155_fdata$jscomp$4_page$jscomp$inline_6153$$=$G__51688__$1$jscomp$inline_6155_fdata$jscomp$4_page$jscomp$inline_6153$$!=null?$app$common$types$pages_list$add_page$$($G__51688$jscomp$inline_6154_file_id$jscomp$inline_6151$$,
$G__51688__$1$jscomp$inline_6155_fdata$jscomp$4_page$jscomp$inline_6153$$):$G__51688$jscomp$inline_6154_file_id$jscomp$inline_6151$$;$G__51688__$1$jscomp$inline_6155_fdata$jscomp$4_page$jscomp$inline_6153$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__51688__$1$jscomp$inline_6155_fdata$jscomp$4_page$jscomp$inline_6153$$,$APP.$cljs$cst$873$options$$,$APP.$cljs$core$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$2575$components_v2$$,!0,$APP.$cljs$cst$2576$base_font_size$$,
"16px"],null));$fdata__$1$jscomp$2_objects$jscomp$246$$=$APP.$cljs$core$assoc_in$$($G__51688__$1$jscomp$inline_6155_fdata$jscomp$4_page$jscomp$inline_6153$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$APP.$app$common$uuid$zero$$,$APP.$cljs$cst$1631$objects$$],null),$fdata__$1$jscomp$2_objects$jscomp$246$$);return $APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$06$$($changes$jscomp$14$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$3169$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_file_data$$,$fdata__$1$jscomp$2_objects$jscomp$246$$,$cljs$cst$3170$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_applied_changes_count$$,0)};
$APP.$app$common$files$changes_builder$with_file_data$$=function($changes$jscomp$15$$,$fdata$jscomp$5_fdata__$1$jscomp$3$$){var $page_id$jscomp$58$$=$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$15$$));$fdata$jscomp$5_fdata__$1$jscomp$3$$=$APP.$cljs$core$assoc_in$$($fdata$jscomp$5_fdata__$1$jscomp$3$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1630$pages_index$$,$APP.$app$common$uuid$zero$$],null),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($fdata$jscomp$5_fdata__$1$jscomp$3$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$page_id$jscomp$58$$],null)));return $APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$06$$($changes$jscomp$15$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3169$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_file_data$$,
$fdata$jscomp$5_fdata__$1$jscomp$3$$,$cljs$cst$3170$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_applied_changes_count$$,0)};$APP.$app$common$files$changes_builder$with_library_data$$=function($changes$jscomp$16$$,$data$jscomp$263$$){return $APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$16$$,$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$,$data$jscomp$263$$)};
$app$common$files$changes_builder$amend_last_change$$=function($changes$jscomp$17$$,$f$jscomp$817$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$17$$,$APP.$cljs$cst$3133$redo_changes$$,function($G__53980$jscomp$inline_6157_JSCompiler_inline_result$jscomp$1052_p1__53976_SHARP_$$){var $JSCompiler_temp_const$jscomp$1050$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$,$JSCompiler_temp_const$jscomp$1049$$=$APP.$cljs$core$pop$$($G__53980$jscomp$inline_6157_JSCompiler_inline_result$jscomp$1052_p1__53976_SHARP_$$);
$G__53980$jscomp$inline_6157_JSCompiler_inline_result$jscomp$1052_p1__53976_SHARP_$$=$APP.$cljs$core$peek$$($G__53980$jscomp$inline_6157_JSCompiler_inline_result$jscomp$1052_p1__53976_SHARP_$$);$G__53980$jscomp$inline_6157_JSCompiler_inline_result$jscomp$1052_p1__53976_SHARP_$$=$f$jscomp$817$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$817$$.$cljs$core$IFn$_invoke$arity$1$($G__53980$jscomp$inline_6157_JSCompiler_inline_result$jscomp$1052_p1__53976_SHARP_$$):$f$jscomp$817$$($G__53980$jscomp$inline_6157_JSCompiler_inline_result$jscomp$1052_p1__53976_SHARP_$$);
return $JSCompiler_temp_const$jscomp$1050$$.call($APP.$cljs$core$conj$$,$JSCompiler_temp_const$jscomp$1049$$,$G__53980$jscomp$inline_6157_JSCompiler_inline_result$jscomp$1052_p1__53976_SHARP_$$)})};
$app$common$files$changes_builder$amend_changes$$=function($changes$jscomp$18$$,$f$jscomp$818$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$18$$,$APP.$cljs$cst$3133$redo_changes$$,function($p1__53981_SHARP_$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$818$$,$p1__53981_SHARP_$$)})};
$APP.$app$common$files$changes_builder$concat_changes$$=function($changes1$$,$changes2$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes1$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$app$common$data$concat_vec$$,$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes2$$)),$APP.$cljs$cst$3137$undo_changes$$,function($p1__53985_SHARP_$$){return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3137$undo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes2$$),
$p1__53985_SHARP_$$)})};
$app$common$files$changes_builder$lookup_objects$$=function($changes$jscomp$25_data$jscomp$264$$){$changes$jscomp$25_data$jscomp$264$$=$APP.$cljs$cst$3169$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_file_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$25_data$jscomp$264$$));return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$25_data$jscomp$264$$,$APP.$cljs$cst$1630$pages_index$$),
$APP.$app$common$uuid$zero$$),$APP.$cljs$cst$1631$objects$$)};
$APP.$app$common$files$changes_builder$apply_changes_local$$=function($var_args$jscomp$1149$$){for(var $args__5755__auto__$jscomp$205$$=[],$len__5749__auto___54346$$=arguments.length,$i__5750__auto___54347$$=0;;)if($i__5750__auto___54347$$<$len__5749__auto___54346$$)$args__5755__auto__$jscomp$205$$.push(arguments[$i__5750__auto___54347$$]),$i__5750__auto___54347$$+=1;else break;return $app$common$files$changes_builder$apply_changes_local$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<
$args__5755__auto__$jscomp$205$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$205$$.slice(1),0,null):null)};
$app$common$files$changes_builder$apply_changes_local$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($changes$jscomp$26$$,$map__54018__$1_p__54017_redo_changes$jscomp$9$$){$map__54018__$1_p__54017_redo_changes$jscomp$9$$=$APP.$cljs$core$__destructure_map$$($map__54018__$1_p__54017_redo_changes$jscomp$9$$);var $apply_to_library_QMARK__new_library_data$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54018__$1_p__54017_redo_changes$jscomp$9$$,$cljs$cst$3172$apply_to_library_QMARK_$$),
$new_file_data_temp__5823__auto__$jscomp$157$$=$APP.$cljs$cst$3169$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_file_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$26$$));if($APP.$cljs$core$truth_$$($new_file_data_temp__5823__auto__$jscomp$157$$)){var $library_data$jscomp$8$$=$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$26$$)),$index$jscomp$249_new_changes$$=
$cljs$cst$3170$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_applied_changes_count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$26$$));$map__54018__$1_p__54017_redo_changes$jscomp$9$$=$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$26$$);$index$jscomp$249_new_changes$$=$index$jscomp$249_new_changes$$<$APP.$cljs$core$count$$($map__54018__$1_p__54017_redo_changes$jscomp$9$$)?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__54001_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__54001_SHARP_$$,
$APP.$cljs$cst$2043$page_id$$,$APP.$app$common$uuid$zero$$),$APP.$cljs$cst$1627$component_id$$)},$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$26$$),$index$jscomp$249_new_changes$$)):$APP.$cljs$core$PersistentVector$EMPTY$$;$new_file_data_temp__5823__auto__$jscomp$157$$=$APP.$app$common$files$changes$process_changes$$.$cljs$core$IFn$_invoke$arity$2$($new_file_data_temp__5823__auto__$jscomp$157$$,$index$jscomp$249_new_changes$$);
$apply_to_library_QMARK__new_library_data$$=$APP.$cljs$core$truth_$$($apply_to_library_QMARK__new_library_data$$)?$APP.$app$common$files$changes$process_changes$$.$cljs$core$IFn$_invoke$arity$2$($library_data$jscomp$8$$,$index$jscomp$249_new_changes$$):$library_data$jscomp$8$$;return $cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($changes$jscomp$26$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3169$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_file_data$$,$new_file_data_temp__5823__auto__$jscomp$157$$,
$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$,$apply_to_library_QMARK__new_library_data$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3170$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_applied_changes_count$$,$APP.$cljs$core$count$$($map__54018__$1_p__54017_redo_changes$jscomp$9$$)]))}return $changes$jscomp$26$$};
$APP.$app$common$files$changes_builder$mod_page$cljs$0core$0IFn$0_invoke$0arity$02$$=function($changes$jscomp$29$$,$options$jscomp$487$$){var $page$jscomp$38$$=$APP.$cljs$cst$3167$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$29$$));return $app$common$files$changes_builder$mod_page$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$29$$,$page$jscomp$38$$,$options$jscomp$487$$)};
$app$common$files$changes_builder$mod_page$cljs$0core$0IFn$0_invoke$0arity$03$$=function($changes$jscomp$30$$,$page$jscomp$39$$,$map__54035__$1_p__54034_redo$$){$map__54035__$1_p__54034_redo$$=$APP.$cljs$core$__destructure_map$$($map__54035__$1_p__54034_redo$$);var $name$jscomp$266$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54035__$1_p__54034_redo$$,$APP.$cljs$cst$725$name$$),$background$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54035__$1_p__54034_redo$$,
$APP.$cljs$cst$2058$background$$),$pixel_grid_color$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54035__$1_p__54034_redo$$,$APP.$cljs$cst$2059$pixel_grid_color$$),$pixel_grid_opacity$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54035__$1_p__54034_redo$$,$APP.$cljs$cst$2060$pixel_grid_opacity$$),$change$jscomp$20$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2621$mod_page$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$39$$)],
null);$map__54035__$1_p__54034_redo$$=function(){var $G__54036__$1_G__54036__$2_G__54036__$3$$=$name$jscomp$266$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($change$jscomp$20$$,$APP.$cljs$cst$725$name$$,$name$jscomp$266$$):$change$jscomp$20$$;$G__54036__$1_G__54036__$2_G__54036__$3$$=$background$jscomp$7$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54036__$1_G__54036__$2_G__54036__$3$$,$APP.$cljs$cst$2058$background$$,$background$jscomp$7$$):$G__54036__$1_G__54036__$2_G__54036__$3$$;
$G__54036__$1_G__54036__$2_G__54036__$3$$=$pixel_grid_color$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54036__$1_G__54036__$2_G__54036__$3$$,$APP.$cljs$cst$2059$pixel_grid_color$$,$pixel_grid_color$$):$G__54036__$1_G__54036__$2_G__54036__$3$$;return $pixel_grid_opacity$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54036__$1_G__54036__$2_G__54036__$3$$,$APP.$cljs$cst$2060$pixel_grid_opacity$$,$pixel_grid_opacity$$):$G__54036__$1_G__54036__$2_G__54036__$3$$}();
var $undo$$=function(){var $G__54039__$1_G__54039__$2_G__54039__$3$$=$name$jscomp$266$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($change$jscomp$20$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$39$$)):$change$jscomp$20$$;$G__54039__$1_G__54039__$2_G__54039__$3$$=$background$jscomp$7$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54039__$1_G__54039__$2_G__54039__$3$$,$APP.$cljs$cst$2058$background$$,$APP.$cljs$cst$2058$background$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$39$$)):
$G__54039__$1_G__54039__$2_G__54039__$3$$;$G__54039__$1_G__54039__$2_G__54039__$3$$=$pixel_grid_color$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54039__$1_G__54039__$2_G__54039__$3$$,$APP.$cljs$cst$2059$pixel_grid_color$$,$APP.$cljs$cst$2059$pixel_grid_color$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$39$$)):$G__54039__$1_G__54039__$2_G__54039__$3$$;return $pixel_grid_opacity$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54039__$1_G__54039__$2_G__54039__$3$$,
$APP.$cljs$cst$2060$pixel_grid_opacity$$,$APP.$cljs$cst$2060$pixel_grid_opacity$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$39$$)):$G__54039__$1_G__54039__$2_G__54039__$3$$}();return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$30$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,$map__54035__$1_p__54034_redo$$),$APP.$cljs$cst$3137$undo_changes$$,
$APP.$cljs$core$conj$$,$undo$$))};
$APP.$app$common$files$changes_builder$set_guide$$=function($changes$jscomp$36$$,$id$jscomp$352$$,$guide$$){var $page_id$jscomp$62$$=$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$36$$)),$old_val$jscomp$2_page$jscomp$41$$=$APP.$cljs$cst$3167$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$36$$));$old_val$jscomp$2_page$jscomp$41$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_val$jscomp$2_page$jscomp$41$$,$APP.$cljs$cst$2057$guides$$),$id$jscomp$352$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$36$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$2604$set_guide$$,$APP.$cljs$cst$2043$page_id$$,
$page_id$jscomp$62$$,$APP.$cljs$cst$266$id$$,$id$jscomp$352$$,$APP.$cljs$cst$1430$params$$,$guide$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$2604$set_guide$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$62$$,$APP.$cljs$cst$266$id$$,$id$jscomp$352$$,$APP.$cljs$cst$1430$params$$,$old_val$jscomp$2_page$jscomp$41$$],null))};
$app$common$files$changes_builder$set_flow$$=function($changes$jscomp$37_changes__$1$jscomp$1$$,$id$jscomp$353$$,$flow$$){var $page_id$jscomp$63$$=$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$37_changes__$1$jscomp$1$$)),$old_val$jscomp$3_page$jscomp$42$$=$APP.$cljs$cst$3167$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$37_changes__$1$jscomp$1$$));
$old_val$jscomp$3_page$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_val$jscomp$3_page$jscomp$42$$,$APP.$cljs$cst$2056$flows$$),$id$jscomp$353$$);$changes$jscomp$37_changes__$1$jscomp$1$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$37_changes__$1$jscomp$1$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$139$type$$,$cljs$cst$2605$set_flow$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$63$$,$APP.$cljs$cst$266$id$$,$id$jscomp$353$$,$APP.$cljs$cst$1430$params$$,$flow$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$2605$set_flow$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$63$$,$APP.$cljs$cst$266$id$$,$id$jscomp$353$$,$APP.$cljs$cst$1430$params$$,$old_val$jscomp$3_page$jscomp$42$$],
null));return $APP.$app$common$files$changes_builder$apply_changes_local$$($changes$jscomp$37_changes__$1$jscomp$1$$)};$APP.$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$02$$=function($changes$jscomp$40$$,$obj$jscomp$193$$){return $app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$40$$,$obj$jscomp$193$$,null)};
$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$=function($G__54101$jscomp$inline_12306_JSCompiler_inline_result$jscomp$10832_changes$jscomp$41$$,$obj$jscomp$194_objects$jscomp$247_parent$jscomp$204$$,$ignore_touched$jscomp$5_map__54096__$1_p__54095$$){$ignore_touched$jscomp$5_map__54096__$1_p__54095$$=$APP.$cljs$core$__destructure_map$$($ignore_touched$jscomp$5_map__54096__$1_p__54095$$);var $del_change_index$jscomp$251_obj__$1$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($ignore_touched$jscomp$5_map__54096__$1_p__54095$$,
$APP.$cljs$cst$1795$index$$,$cljs$cst$3173$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_undefined$$);$ignore_touched$jscomp$5_map__54096__$1_p__54095$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($ignore_touched$jscomp$5_map__54096__$1_p__54095$$,$APP.$cljs$cst$2556$ignore_touched$$,!1);$del_change_index$jscomp$251_obj__$1$jscomp$2$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($del_change_index$jscomp$251_obj__$1$jscomp$2$$,$cljs$cst$3173$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_undefined$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($obj$jscomp$194_objects$jscomp$247_parent$jscomp$204$$,$cljs$cst$3174$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_index$$,$del_change_index$jscomp$251_obj__$1$jscomp$2$$):$obj$jscomp$194_objects$jscomp$247_parent$jscomp$204$$;$obj$jscomp$194_objects$jscomp$247_parent$jscomp$204$$=$app$common$files$changes_builder$lookup_objects$$($G__54101$jscomp$inline_12306_JSCompiler_inline_result$jscomp$10832_changes$jscomp$41$$);$obj$jscomp$194_objects$jscomp$247_parent$jscomp$204$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($obj$jscomp$194_objects$jscomp$247_parent$jscomp$204$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($del_change_index$jscomp$251_obj__$1$jscomp$2$$));var $add_change$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2610$add_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($del_change_index$jscomp$251_obj__$1$jscomp$2$$),$APP.$cljs$cst$2043$page_id$$,
$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($G__54101$jscomp$inline_12306_JSCompiler_inline_result$jscomp$10832_changes$jscomp$41$$)),$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($del_change_index$jscomp$251_obj__$1$jscomp$2$$),$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($del_change_index$jscomp$251_obj__$1$jscomp$2$$),
$APP.$cljs$cst$1795$index$$,$cljs$cst$3174$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_index$$.$cljs$core$IFn$_invoke$arity$1$($del_change_index$jscomp$251_obj__$1$jscomp$2$$),$APP.$cljs$cst$2556$ignore_touched$$,$ignore_touched$jscomp$5_map__54096__$1_p__54095$$,$APP.$cljs$cst$2611$obj$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($del_change_index$jscomp$251_obj__$1$jscomp$2$$,$cljs$cst$3174$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_index$$)],null);$del_change_index$jscomp$251_obj__$1$jscomp$2$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2614$del_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($del_change_index$jscomp$251_obj__$1$jscomp$2$$),$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($G__54101$jscomp$inline_12306_JSCompiler_inline_result$jscomp$10832_changes$jscomp$41$$))],null);var $restore_touched_change$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($G__54101$jscomp$inline_12306_JSCompiler_inline_result$jscomp$10832_changes$jscomp$41$$)),$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$194_objects$jscomp$247_parent$jscomp$204$$),$APP.$cljs$cst$2613$operations$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2600$set_touched$$,$APP.$cljs$cst$1626$touched$$,$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$194_objects$jscomp$247_parent$jscomp$204$$)],null)],null)],null),$JSCompiler_temp_const$jscomp$10830$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$;$G__54101$jscomp$inline_12306_JSCompiler_inline_result$jscomp$10832_changes$jscomp$41$$=
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__54101$jscomp$inline_12306_JSCompiler_inline_result$jscomp$10832_changes$jscomp$41$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,$add_change$$);$G__54101$jscomp$inline_12306_JSCompiler_inline_result$jscomp$10832_changes$jscomp$41$$=$APP.$app$common$types$component$in_component_copy_QMARK_$$($obj$jscomp$194_objects$jscomp$247_parent$jscomp$204$$)&&$APP.$cljs$core$not$$($ignore_touched$jscomp$5_map__54096__$1_p__54095$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__54101$jscomp$inline_12306_JSCompiler_inline_result$jscomp$10832_changes$jscomp$41$$,
$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,$restore_touched_change$$):$G__54101$jscomp$inline_12306_JSCompiler_inline_result$jscomp$10832_changes$jscomp$41$$;return $APP.$app$common$files$changes_builder$apply_changes_local$$($JSCompiler_temp_const$jscomp$10830$$.call($APP.$cljs$core$update$$,$G__54101$jscomp$inline_12306_JSCompiler_inline_result$jscomp$10832_changes$jscomp$41$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,$del_change_index$jscomp$251_obj__$1$jscomp$2$$))};
$APP.$app$common$files$changes_builder$add_objects$cljs$0core$0IFn$0_invoke$0arity$03$$=function($changes$jscomp$43$$,$objects$jscomp$249$$,$params$jscomp$184$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__54109_SHARP_$$,$p2__54110_SHARP_$$){return $app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__54109_SHARP_$$,$p2__54110_SHARP_$$,$params$jscomp$184$$)},$changes$jscomp$43$$,$objects$jscomp$249$$)};
$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$03$$=function($changes$jscomp$44$$,$parent_id$jscomp$35$$,$shapes$jscomp$31$$){return $app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$05$$($changes$jscomp$44$$,$parent_id$jscomp$35$$,$shapes$jscomp$31$$,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$04$$=function($changes$jscomp$45$$,$parent_id$jscomp$36$$,$shapes$jscomp$32$$,$index$jscomp$252$$){return $app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$05$$($changes$jscomp$45$$,$parent_id$jscomp$36$$,$shapes$jscomp$32$$,$index$jscomp$252$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$05$$=function($changes$jscomp$46$$,$parent_id$jscomp$37$$,$shapes$jscomp$33$$,$index$jscomp$253$$,$options$jscomp$488$$){function $mk_undo_change$$($undo_changes$jscomp$5$$,$G__54121$jscomp$inline_6159_JSCompiler_inline_result$jscomp$1055_shape$jscomp$369$$){var $prev_sibling$$=$app$common$files$helpers$get_prev_sibling$$($objects$jscomp$250$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__54121$jscomp$inline_6159_JSCompiler_inline_result$jscomp$1055_shape$jscomp$369$$)),
$JSCompiler_temp_const$jscomp$1053$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$;$G__54121$jscomp$inline_6159_JSCompiler_inline_result$jscomp$1055_shape$jscomp$369$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$cljs$cst$2616$mov_objects$$,$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$46$$)),$APP.$cljs$cst$1619$parent_id$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($G__54121$jscomp$inline_6159_JSCompiler_inline_result$jscomp$1055_shape$jscomp$369$$),$APP.$cljs$cst$1614$shapes$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__54121$jscomp$inline_6159_JSCompiler_inline_result$jscomp$1055_shape$jscomp$369$$)],null),$cljs$cst$2617$after_shape$$,$prev_sibling$$,$APP.$cljs$cst$1795$index$$,0],null);
$G__54121$jscomp$inline_6159_JSCompiler_inline_result$jscomp$1055_shape$jscomp$369$$=$APP.$cljs$core$truth_$$($cljs$cst$2618$allow_altering_copies$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$488$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54121$jscomp$inline_6159_JSCompiler_inline_result$jscomp$1055_shape$jscomp$369$$,$cljs$cst$2618$allow_altering_copies$$,!0):$G__54121$jscomp$inline_6159_JSCompiler_inline_result$jscomp$1055_shape$jscomp$369$$;return $JSCompiler_temp_const$jscomp$1053$$.call($APP.$cljs$core$conj$$,
$undo_changes$jscomp$5$$,$G__54121$jscomp$inline_6159_JSCompiler_inline_result$jscomp$1055_shape$jscomp$369$$)}var $objects$jscomp$250$$=$app$common$files$changes_builder$lookup_objects$$($changes$jscomp$46$$),$parent$jscomp$205$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$250$$,$parent_id$jscomp$37$$),$set_parent_change$$=function(){var $G__54120_G__54120__$1_G__54120__$2$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$2616$mov_objects$$,
$APP.$cljs$cst$1619$parent_id$$,$parent_id$jscomp$37$$,$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$46$$)),$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$reverse$$($shapes$jscomp$33$$))],null);$G__54120_G__54120__$1_G__54120__$2$$=$index$jscomp$253$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54120_G__54120__$1_G__54120__$2$$,
$APP.$cljs$cst$1795$index$$,$index$jscomp$253$$):$G__54120_G__54120__$1_G__54120__$2$$;$G__54120_G__54120__$1_G__54120__$2$$=$APP.$cljs$core$truth_$$($cljs$cst$2618$allow_altering_copies$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$488$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54120_G__54120__$1_G__54120__$2$$,$cljs$cst$2618$allow_altering_copies$$,!0):$G__54120_G__54120__$1_G__54120__$2$$;return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2556$ignore_touched$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$488$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54120_G__54120__$1_G__54120__$2$$,$APP.$cljs$cst$2556$ignore_touched$$,!0):$G__54120_G__54120__$1_G__54120__$2$$}(),$restore_touched_change$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$46$$)),
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$205$$),$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2600$set_touched$$,$APP.$cljs$cst$1626$touched$$,$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$205$$)],null)],null)],null);return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$(function(){var $G__54122$$=
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$46$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,$set_parent_change$$);return $APP.$app$common$types$component$in_component_copy_QMARK_$$($parent$jscomp$205$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__54122$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,$restore_touched_change$jscomp$1$$):$G__54122$$}(),$APP.$cljs$cst$3137$undo_changes$$,function($p1__54117_SHARP_$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($mk_undo_change$$,
$p1__54117_SHARP_$$,$shapes$jscomp$33$$)}))};
$app$common$files$changes_builder$changed_attrs$$=function($object$jscomp$21$$,$new_obj$jscomp$1_objects$jscomp$251$$,$attrs__$1$jscomp$6_update_fn$jscomp$9$$,$attrs$jscomp$60_p__54123$$){var $map__54124__$1_with_objects_QMARK_$$=$APP.$cljs$core$__destructure_map$$($attrs$jscomp$60_p__54123$$);$attrs$jscomp$60_p__54123$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54124__$1_with_objects_QMARK_$$,$APP.$cljs$cst$2645$attrs$$);$map__54124__$1_with_objects_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54124__$1_with_objects_QMARK_$$,
$APP.$cljs$cst$3175$with_objects_QMARK_$$);$new_obj$jscomp$1_objects$jscomp$251$$=$APP.$cljs$core$truth_$$($map__54124__$1_with_objects_QMARK_$$)?$attrs__$1$jscomp$6_update_fn$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$?$attrs__$1$jscomp$6_update_fn$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$($object$jscomp$21$$,$new_obj$jscomp$1_objects$jscomp$251$$):$attrs__$1$jscomp$6_update_fn$jscomp$9$$($object$jscomp$21$$,$new_obj$jscomp$1_objects$jscomp$251$$):$attrs__$1$jscomp$6_update_fn$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$?
$attrs__$1$jscomp$6_update_fn$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$21$$):$attrs__$1$jscomp$6_update_fn$jscomp$9$$($object$jscomp$21$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($object$jscomp$21$$,$new_obj$jscomp$1_objects$jscomp$251$$))return null;$attrs__$1$jscomp$6_update_fn$jscomp$9$$=$APP.$cljs$core$truth_$$($attrs$jscomp$60_p__54123$$)?$attrs$jscomp$60_p__54123$$:$APP.$app$common$data$concat_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$keys$$($object$jscomp$21$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$keys$$($new_obj$jscomp$1_objects$jscomp$251$$)]));return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$(function($old$jscomp$2_old_val$jscomp$6$$,$new$$jscomp$1_new_val$jscomp$2$$,$attr$jscomp$29$$){$old$jscomp$2_old_val$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old$jscomp$2_old_val$jscomp$6$$,$attr$jscomp$29$$);$new$$jscomp$1_new_val$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new$$jscomp$1_new_val$jscomp$2$$,$attr$jscomp$29$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($old$jscomp$2_old_val$jscomp$6$$,$new$$jscomp$1_new_val$jscomp$2$$)},$object$jscomp$21$$,$new_obj$jscomp$1_objects$jscomp$251$$),$attrs__$1$jscomp$6_update_fn$jscomp$9$$)};
$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$=function($changes$jscomp$47$$,$ids$jscomp$38$$,$update_fn$jscomp$10$$){return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$47$$,$ids$jscomp$38$$,$update_fn$jscomp$10$$,null)};
$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$=function($changes$jscomp$48$$,$ids$jscomp$39$$,$update_fn$jscomp$11$$,$map__54133__$1_p__54132$$){function $generate_operations$$($G__54400_attrs__$1$jscomp$7_attrs__$2$jscomp$2$$,$old$jscomp$3$$,$new$$jscomp$2$$){var $rops$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$uops$$=$APP.$cljs$core$List$EMPTY$$;for($G__54400_attrs__$1$jscomp$7_attrs__$2$jscomp$2$$=$APP.$cljs$core$seq$$($G__54400_attrs__$1$jscomp$7_attrs__$2$jscomp$2$$);;){var $G__54398_rops__$1_temp__5823__auto__$jscomp$158$$=
$APP.$cljs$core$first$$($G__54400_attrs__$1$jscomp$7_attrs__$2$jscomp$2$$);if($APP.$cljs$core$truth_$$($G__54398_rops__$1_temp__5823__auto__$jscomp$158$$)){var $attr$jscomp$30$$=$G__54398_rops__$1_temp__5823__auto__$jscomp$158$$,$old_val$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old$jscomp$3$$,$attr$jscomp$30$$),$new_val$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new$$jscomp$2$$,$attr$jscomp$30$$),$changed_QMARK_$jscomp$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($old_val$jscomp$7$$,
$new_val$jscomp$3$$);$G__54398_rops__$1_temp__5823__auto__$jscomp$158$$=function(){var $G__54137$$=$rops$$;return $changed_QMARK_$jscomp$1$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__54137$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$attr$jscomp$30$$,$APP.$cljs$cst$108$val$$,$new_val$jscomp$3$$,$APP.$cljs$cst$2557$ignore_geometry$$,$ignore_geometry_QMARK_$$,$APP.$cljs$cst$2556$ignore_touched$$,$ignore_touched$jscomp$6$$],
null)):$G__54137$$}();var $G__54399_uops__$1$$=function(){var $G__54138$$=$uops$$;return $changed_QMARK_$jscomp$1$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__54138$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$attr$jscomp$30$$,$APP.$cljs$cst$108$val$$,$old_val$jscomp$7$$,$APP.$cljs$cst$2556$ignore_touched$$,!0],null)):$G__54138$$}();$G__54400_attrs__$1$jscomp$7_attrs__$2$jscomp$2$$=$APP.$cljs$core$rest$$($G__54400_attrs__$1$jscomp$7_attrs__$2$jscomp$2$$);
$rops$$=$G__54398_rops__$1_temp__5823__auto__$jscomp$158$$;$uops$$=$G__54399_uops__$1$$}else return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$rops$$,$uops$$],null)}}$map__54133__$1_p__54132$$=$APP.$cljs$core$__destructure_map$$($map__54133__$1_p__54132$$);var $attrs$jscomp$61$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54133__$1_p__54132$$,$APP.$cljs$cst$2645$attrs$$),$ignore_geometry_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__54133__$1_p__54132$$,
$cljs$cst$3176$ignore_geometry_QMARK_$$,!1),$ignore_touched$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__54133__$1_p__54132$$,$APP.$cljs$cst$2556$ignore_touched$$,!1),$with_objects_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__54133__$1_p__54132$$,$APP.$cljs$cst$3175$with_objects_QMARK_$$,!1),$page_id$jscomp$66$$=$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$48$$)),
$component_id$jscomp$31$$=$cljs$cst$3168$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_component_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$48$$)),$objects$jscomp$252$$=$app$common$files$changes_builder$lookup_objects$$($changes$jscomp$48$$);return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($G__54144__$1_changes__$1$jscomp$4$$,$G__54143$jscomp$inline_12308_G__54143__$1$jscomp$inline_12309_change$jscomp$21_id$jscomp$355$$){var $old_obj_uops__$1$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$252$$,$G__54143$jscomp$inline_12308_G__54143__$1$jscomp$inline_12309_change$jscomp$21_id$jscomp$355$$),$new_obj$jscomp$2_rops$jscomp$1$$=$APP.$cljs$core$truth_$$($with_objects_QMARK_$jscomp$1$$)?$update_fn$jscomp$11$$.$cljs$core$IFn$_invoke$arity$2$?$update_fn$jscomp$11$$.$cljs$core$IFn$_invoke$arity$2$($old_obj_uops__$1$jscomp$1$$,$objects$jscomp$252$$):$update_fn$jscomp$11$$($old_obj_uops__$1$jscomp$1$$,$objects$jscomp$252$$):
$update_fn$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$?$update_fn$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$($old_obj_uops__$1$jscomp$1$$):$update_fn$jscomp$11$$($old_obj_uops__$1$jscomp$1$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($old_obj_uops__$1$jscomp$1$$,$new_obj$jscomp$2_rops$jscomp$1$$))return $G__54144__$1_changes__$1$jscomp$4$$;var $uops$jscomp$1_vec__54139$$=$generate_operations$$($APP.$cljs$core$truth_$$($attrs$jscomp$61$$)?$attrs$jscomp$61$$:$APP.$app$common$data$concat_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$keys$$($old_obj_uops__$1$jscomp$1$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$keys$$($new_obj$jscomp$2_rops$jscomp$1$$)])),$old_obj_uops__$1$jscomp$1$$,$new_obj$jscomp$2_rops$jscomp$1$$);$new_obj$jscomp$2_rops$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($uops$jscomp$1_vec__54139$$,0,null);$uops$jscomp$1_vec__54139$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($uops$jscomp$1_vec__54139$$,1,null);$old_obj_uops__$1$jscomp$1$$=$APP.$cljs$core$seq$$($uops$jscomp$1_vec__54139$$)?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($uops$jscomp$1_vec__54139$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2600$set_touched$$,$APP.$cljs$cst$1626$touched$$,$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($old_obj_uops__$1$jscomp$1$$)],null)):$uops$jscomp$1_vec__54139$$;$G__54143$jscomp$inline_12308_G__54143__$1$jscomp$inline_12309_change$jscomp$21_id$jscomp$355$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$G__54143$jscomp$inline_12308_G__54143__$1$jscomp$inline_12309_change$jscomp$21_id$jscomp$355$$],null);$G__54143$jscomp$inline_12308_G__54143__$1$jscomp$inline_12309_change$jscomp$21_id$jscomp$355$$=$page_id$jscomp$66$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54143$jscomp$inline_12308_G__54143__$1$jscomp$inline_12309_change$jscomp$21_id$jscomp$355$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$66$$):$G__54143$jscomp$inline_12308_G__54143__$1$jscomp$inline_12309_change$jscomp$21_id$jscomp$355$$;
$G__54143$jscomp$inline_12308_G__54143__$1$jscomp$inline_12309_change$jscomp$21_id$jscomp$355$$=$component_id$jscomp$31$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54143$jscomp$inline_12308_G__54143__$1$jscomp$inline_12309_change$jscomp$21_id$jscomp$355$$,$APP.$cljs$cst$1627$component_id$$,$component_id$jscomp$31$$):$G__54143$jscomp$inline_12308_G__54143__$1$jscomp$inline_12309_change$jscomp$21_id$jscomp$355$$;$G__54144__$1_changes__$1$jscomp$4$$=$APP.$cljs$core$seq$$($new_obj$jscomp$2_rops$jscomp$1$$)?
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__54144__$1_changes__$1$jscomp$4$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54143$jscomp$inline_12308_G__54143__$1$jscomp$inline_12309_change$jscomp$21_id$jscomp$355$$,$APP.$cljs$cst$2613$operations$$,$new_obj$jscomp$2_rops$jscomp$1$$)):$G__54144__$1_changes__$1$jscomp$4$$;return $APP.$cljs$core$seq$$($old_obj_uops__$1$jscomp$1$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__54144__$1_changes__$1$jscomp$4$$,
$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54143$jscomp$inline_12308_G__54143__$1$jscomp$inline_12309_change$jscomp$21_id$jscomp$355$$,$APP.$cljs$cst$2613$operations$$,$APP.$cljs$core$vec$$($old_obj_uops__$1$jscomp$1$$))):$G__54144__$1_changes__$1$jscomp$4$$},$changes$jscomp$48$$,$ids$jscomp$39$$))};
$app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$02$$=function($changes$jscomp$49$$,$ids$jscomp$40$$){return $app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$49$$,$ids$jscomp$40$$,null)};
$app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$03$$=function($changes$jscomp$50$$,$ids$jscomp$41$$,$map__54157__$1_p__54156$$){function $add_undo_change_parent$$($change_set$jscomp$2$$,$id$jscomp$358$$){var $shape$jscomp$371$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$253$$,$id$jscomp$358$$),$prev_sibling$jscomp$1$$=$app$common$files$helpers$get_prev_sibling$$($objects$jscomp$253$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$371$$));
return $shape$jscomp$371$$!=null?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($change_set$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$139$type$$,$cljs$cst$2616$mov_objects$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$67$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$371$$),$APP.$cljs$cst$1614$shapes$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$id$jscomp$358$$],null),$cljs$cst$2617$after_shape$$,$prev_sibling$jscomp$1$$,$APP.$cljs$cst$1795$index$$,0,$APP.$cljs$cst$2556$ignore_touched$$,!0],null)):$change_set$jscomp$2$$}function $add_undo_change_shape$$($change_set$jscomp$1$$,$id$jscomp$357$$){var $shape$jscomp$370$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$253$$,$id$jscomp$357$$);return $shape$jscomp$370$$!=null?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($change_set$jscomp$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
7,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2610$add_obj$$,$APP.$cljs$cst$266$id$$,$id$jscomp$357$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$67$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$370$$),$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$370$$),$APP.$cljs$cst$1795$index$$,$app$common$files$helpers$get_position_on_parent$$($objects$jscomp$253$$,$id$jscomp$357$$),
$APP.$cljs$cst$2611$obj$$,$APP.$cljs$core$contains_QMARK_$$($shape$jscomp$370$$,$APP.$cljs$cst$1614$shapes$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$370$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$):$shape$jscomp$370$$],null)):$change_set$jscomp$1$$}function $add_redo_change$$($change_set$$,$G__54159$jscomp$inline_6161_JSCompiler_inline_result$jscomp$1058_id$jscomp$356$$){var $JSCompiler_temp_const$jscomp$1056$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$;
$G__54159$jscomp$inline_6161_JSCompiler_inline_result$jscomp$1058_id$jscomp$356$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2614$del_obj$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$67$$,$APP.$cljs$cst$266$id$$,$G__54159$jscomp$inline_6161_JSCompiler_inline_result$jscomp$1058_id$jscomp$356$$],null);$G__54159$jscomp$inline_6161_JSCompiler_inline_result$jscomp$1058_id$jscomp$356$$=$APP.$cljs$core$truth_$$($ignore_touched$jscomp$7$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54159$jscomp$inline_6161_JSCompiler_inline_result$jscomp$1058_id$jscomp$356$$,
$APP.$cljs$cst$2556$ignore_touched$$,!0):$G__54159$jscomp$inline_6161_JSCompiler_inline_result$jscomp$1058_id$jscomp$356$$;return $JSCompiler_temp_const$jscomp$1056$$.call($APP.$cljs$core$conj$$,$change_set$$,$G__54159$jscomp$inline_6161_JSCompiler_inline_result$jscomp$1058_id$jscomp$356$$)}$map__54157__$1_p__54156$$=$APP.$cljs$core$__destructure_map$$($map__54157__$1_p__54156$$);var $ignore_touched$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__54157__$1_p__54156$$,$APP.$cljs$cst$2556$ignore_touched$$,
!1),$page_id$jscomp$67$$=$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$50$$)),$objects$jscomp$253$$=$app$common$files$changes_builder$lookup_objects$$($changes$jscomp$50$$);return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$50$$,$APP.$cljs$cst$3133$redo_changes$$,
function($p1__54147_SHARP_$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($add_redo_change$$,$p1__54147_SHARP_$$,$ids$jscomp$41$$)}),$APP.$cljs$cst$3137$undo_changes$$,function($$__$1$jscomp$13_p1__54148_SHARP_$$){$$__$1$jscomp$13_p1__54148_SHARP_$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($add_undo_change_parent$$,$$__$1$jscomp$13_p1__54148_SHARP_$$,$ids$jscomp$41$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($add_undo_change_shape$$,
$$__$1$jscomp$13_p1__54148_SHARP_$$,$ids$jscomp$41$$)}))};
$APP.$app$common$files$changes_builder$resize_parents$$=function($changes$jscomp$51$$,$all_parents$jscomp$1_ids$jscomp$42$$){function $generate_operation$$($operations$jscomp$8$$,$attr$jscomp$31$$,$old$jscomp$4_old_val$jscomp$8$$,$new$$jscomp$3_new_val$jscomp$4$$){$old$jscomp$4_old_val$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old$jscomp$4_old_val$jscomp$8$$,$attr$jscomp$31$$);$new$$jscomp$3_new_val$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new$$jscomp$3_new_val$jscomp$4$$,$attr$jscomp$31$$);
var $equal_QMARK_$jscomp$1$$=typeof $old$jscomp$4_old_val$jscomp$8$$==="number"&&typeof $new$$jscomp$3_new_val$jscomp$4$$==="number"?$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($old$jscomp$4_old_val$jscomp$8$$,$new$$jscomp$3_new_val$jscomp$4$$):$app$common$geom$matrix$matrix_QMARK_$$($old$jscomp$4_old_val$jscomp$8$$)&&$app$common$geom$matrix$matrix_QMARK_$$($new$$jscomp$3_new_val$jscomp$4$$)?$app$common$geom$matrix$close_QMARK_$$($old$jscomp$4_old_val$jscomp$8$$,$new$$jscomp$3_new_val$jscomp$4$$):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$31$$,$APP.$cljs$cst$1604$points$$)?$APP.$cljs$core$every_QMARK_$$(function($p1__54167_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($app$common$geom$point$close_QMARK_$$,$p1__54167_SHARP_$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vector$$,$old$jscomp$4_old_val$jscomp$8$$,$new$$jscomp$3_new_val$jscomp$4$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$31$$,
$APP.$cljs$cst$1605$selrect$$)?$app$common$geom$rect$close_rect_QMARK_$$($old$jscomp$4_old_val$jscomp$8$$,$new$$jscomp$3_new_val$jscomp$4$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($old$jscomp$4_old_val$jscomp$8$$,$new$$jscomp$3_new_val$jscomp$4$$);return $APP.$cljs$core$truth_$$($equal_QMARK_$jscomp$1$$)?$operations$jscomp$8$$:$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($operations$jscomp$8$$,$cljs$cst$3177$rops$$,
$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$attr$jscomp$31$$,$APP.$cljs$cst$108$val$$,$new$$jscomp$3_new_val$jscomp$4$$,$APP.$cljs$cst$2556$ignore_touched$$,!0],null)),$cljs$cst$3178$uops$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$attr$jscomp$31$$,$APP.$cljs$cst$108$val$$,$old$jscomp$4_old_val$jscomp$8$$,
$APP.$cljs$cst$2556$ignore_touched$$,!0],null))}var $page_id$jscomp$68$$=$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$51$$)),$objects$jscomp$254$$=$app$common$files$changes_builder$lookup_objects$$($changes$jscomp$51$$),$xform$jscomp$31$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__54165_SHARP_$$){return $APP.$cljs$core$cons$$($p1__54165_SHARP_$$,
$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$254$$,$p1__54165_SHARP_$$))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$getf$$($objects$jscomp$254$$)),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__54166_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1608$group$$,null,$APP.$cljs$cst$1610$bool$$,null],null),null),
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__54166_SHARP_$$))}),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$0$()]));$all_parents$jscomp$1_ids$jscomp$42$$=$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($xform$jscomp$31$$,$all_parents$jscomp$1_ids$jscomp$42$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$5$$,$parent$jscomp$206$$){var $map__54188_objects__$1$jscomp$4_rops$jscomp$2$$=
$app$common$files$changes_builder$lookup_objects$$($changes__$1$jscomp$5$$),$children$jscomp$203_map__54188__$1_uops$jscomp$2$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($map__54188_objects__$1$jscomp$4_rops$jscomp$2$$),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$206$$)),$resized_parent$$=$APP.$cljs$core$empty_QMARK_$$($children$jscomp$203_map__54188__$1_uops$jscomp$2$$)?null:$APP.$app$common$files$helpers$bool_shape_QMARK_$$($parent$jscomp$206$$)?
$APP.$app$common$types$path$update_bool_shape$$($parent$jscomp$206$$,$map__54188_objects__$1$jscomp$4_rops$jscomp$2$$):$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$206$$)?$APP.$cljs$core$truth_$$($APP.$cljs$cst$1609$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$206$$))?$APP.$app$common$geom$shapes$transforms$update_mask_selrect$$($parent$jscomp$206$$,$children$jscomp$203_map__54188__$1_uops$jscomp$2$$):$APP.$app$common$geom$shapes$transforms$update_group_selrect$$($parent$jscomp$206$$,
$children$jscomp$203_map__54188__$1_uops$jscomp$2$$):null;if($APP.$cljs$core$truth_$$($resized_parent$$)){$map__54188_objects__$1$jscomp$4_rops$jscomp$2$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__54169_SHARP_$$,$p2__54170_SHARP_$$){return $generate_operation$$($p1__54169_SHARP_$$,$p2__54170_SHARP_$$,$parent$jscomp$206$$,$resized_parent$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$3177$rops$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$cljs$cst$3178$uops$$,
$APP.$cljs$core$PersistentVector$EMPTY$$],null),$APP.$cljs$core$keys$$($parent$jscomp$206$$));$children$jscomp$203_map__54188__$1_uops$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__54188_objects__$1$jscomp$4_rops$jscomp$2$$);$map__54188_objects__$1$jscomp$4_rops$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$203_map__54188__$1_uops$jscomp$2$$,$cljs$cst$3177$rops$$);$children$jscomp$203_map__54188__$1_uops$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$203_map__54188__$1_uops$jscomp$2$$,
$cljs$cst$3178$uops$$);var $change$jscomp$22$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$68$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$206$$)],null);return $APP.$cljs$core$seq$$($map__54188_objects__$1$jscomp$4_rops$jscomp$2$$)?$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes__$1$jscomp$5$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($change$jscomp$22$$,$APP.$cljs$cst$2613$operations$$,$map__54188_objects__$1$jscomp$4_rops$jscomp$2$$)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($change$jscomp$22$$,$APP.$cljs$cst$2613$operations$$,$children$jscomp$203_map__54188__$1_uops$jscomp$2$$))):$changes__$1$jscomp$5$$}return $changes__$1$jscomp$5$$},$changes$jscomp$51$$,
$all_parents$jscomp$1_ids$jscomp$42$$)};
$APP.$app$common$files$changes_builder$add_color$$=function($changes$jscomp$52$$,$color$jscomp$50$$){return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$52$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2625$add_color$$,$APP.$cljs$cst$1298$color$$,$color$jscomp$50$$],
null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2627$del_color$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$50$$)],null)))};
$APP.$app$common$files$changes_builder$add_typography$$=function($changes$jscomp$58$$,$typography$jscomp$9$$){return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$58$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2638$add_typography$$,$APP.$cljs$cst$1981$typography$$,
$typography$jscomp$9$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2640$del_typography$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$9$$)],null)))};
$APP.$app$common$files$changes_builder$add_component$$=function($var_args$jscomp$1157$$){switch(arguments.length){case 7:return $APP.$app$common$files$changes_builder$add_component$$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],null,null,null);case 8:return $APP.$app$common$files$changes_builder$add_component$$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],null,null);default:for(var $args_arr__5774__auto__$jscomp$103$$=
[],$len__5749__auto___54430$$=arguments.length,$i__5750__auto___54431$$=0;;)if($i__5750__auto___54431$$<$len__5749__auto___54430$$)$args_arr__5774__auto__$jscomp$103$$.push(arguments[$i__5750__auto___54431$$]),$i__5750__auto___54431$$+=1;else break;return $app$common$files$changes_builder$add_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],10<$args_arr__5774__auto__$jscomp$103$$.length?
new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$103$$.slice(10),0,null):null)}};
$app$common$files$changes_builder$add_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($changes$jscomp$63$$,$id$jscomp$362$$,$path$jscomp$231$$,$name$jscomp$269$$,$updated_shapes$jscomp$3$$,$main_instance_id$jscomp$4$$,$main_instance_page$jscomp$5$$,$annotation$jscomp$3$$,$variant_id$jscomp$5$$,$variant_properties$jscomp$2$$,$apply_changes_local_library_QMARK__map__54259__$1_p__54258$$){function $mk_change$$($shape$jscomp$372$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,
[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$69$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$372$$),$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$cst$108$val$$,
$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$372$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1643$component_file$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$372$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,
$APP.$cljs$cst$2044$component_root$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$372$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$2045$main_instance$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$2045$main_instance$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$372$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$2047$shape_ref$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$372$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1626$touched$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$372$$)],null)],null)],null)}$apply_changes_local_library_QMARK__map__54259__$1_p__54258$$=
$APP.$cljs$core$__destructure_map$$($apply_changes_local_library_QMARK__map__54259__$1_p__54258$$);$apply_changes_local_library_QMARK__map__54259__$1_p__54258$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($apply_changes_local_library_QMARK__map__54259__$1_p__54258$$,$APP.$cljs$cst$3179$apply_changes_local_library_QMARK_$$);var $page_id$jscomp$69$$=$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$63$$)),
$objects$jscomp$255$$=$app$common$files$changes_builder$lookup_objects$$($changes$jscomp$63$$),$lookupf$$=$APP.$app$common$data$getf$$($objects$jscomp$255$$);return $app$common$files$changes_builder$apply_changes_local$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$63$$,$APP.$cljs$cst$3133$redo_changes$$,function($redo_changes$jscomp$10$$){var $JSCompiler_temp_const$jscomp$1061$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1059$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$;var $G__54263$jscomp$inline_6163_G__54263__$1$jscomp$inline_6164_JSCompiler_inline_result$jscomp$1063$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$139$type$$,$cljs$cst$2631$add_component$$,$APP.$cljs$cst$266$id$$,$id$jscomp$362$$,$APP.$cljs$cst$296$path$$,$path$jscomp$231$$,$APP.$cljs$cst$725$name$$,$name$jscomp$269$$,$APP.$cljs$cst$2062$main_instance_id$$,
$main_instance_id$jscomp$4$$,$APP.$cljs$cst$2063$main_instance_page$$,$main_instance_page$jscomp$5$$,$APP.$cljs$cst$2542$annotation$$,$annotation$jscomp$3$$],null);$G__54263$jscomp$inline_6163_G__54263__$1$jscomp$inline_6164_JSCompiler_inline_result$jscomp$1063$$=$variant_id$jscomp$5$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54263$jscomp$inline_6163_G__54263__$1$jscomp$inline_6164_JSCompiler_inline_result$jscomp$1063$$,$APP.$cljs$cst$2000$variant_id$$,$variant_id$jscomp$5$$):
$G__54263$jscomp$inline_6163_G__54263__$1$jscomp$inline_6164_JSCompiler_inline_result$jscomp$1063$$;$G__54263$jscomp$inline_6163_G__54263__$1$jscomp$inline_6164_JSCompiler_inline_result$jscomp$1063$$=$APP.$cljs$core$seq$$($variant_properties$jscomp$2$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54263$jscomp$inline_6163_G__54263__$1$jscomp$inline_6164_JSCompiler_inline_result$jscomp$1063$$,$APP.$cljs$cst$2001$variant_properties$$,$variant_properties$jscomp$2$$):$G__54263$jscomp$inline_6163_G__54263__$1$jscomp$inline_6164_JSCompiler_inline_result$jscomp$1063$$;
return $JSCompiler_temp_const$jscomp$1061$$.call($APP.$cljs$core$into$$,$JSCompiler_temp_const$jscomp$1059$$.call($APP.$cljs$core$conj$$,$redo_changes$jscomp$10$$,$G__54263$jscomp$inline_6163_G__54263__$1$jscomp$inline_6164_JSCompiler_inline_result$jscomp$1063$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($mk_change$$),$updated_shapes$jscomp$3$$)}),$APP.$cljs$cst$3137$undo_changes$$,function($undo_changes$jscomp$6$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($undo_changes$jscomp$6$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$2633$del_component$$,$APP.$cljs$cst$266$id$$,$id$jscomp$362$$,$cljs$cst$2635$skip_undelete_QMARK_$$,!0],null)),$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($lookupf$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($mk_change$$)),$updated_shapes$jscomp$3$$)}),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$3172$apply_to_library_QMARK_$$,$apply_changes_local_library_QMARK__map__54259__$1_p__54258$$],null)]))};
$APP.$app$common$files$changes_builder$update_component$$=function($var_args$jscomp$1158$$){for(var $args__5755__auto__$jscomp$206$$=[],$len__5749__auto___54438$$=arguments.length,$i__5750__auto___54439$$=0;;)if($i__5750__auto___54439$$<$len__5749__auto___54438$$)$args__5755__auto__$jscomp$206$$.push(arguments[$i__5750__auto___54439$$]),$i__5750__auto___54439$$+=1;else break;return $APP.$app$common$files$changes_builder$update_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],
arguments[2],3<$args__5755__auto__$jscomp$206$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$206$$.slice(3),0,null):null)};
$APP.$app$common$files$changes_builder$update_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($G__54285_changes$jscomp$64$$,$id$jscomp$363$$,$update_fn$jscomp$12$$,$apply_changes_local_library_QMARK_$jscomp$1_map__54282__$1_p__54281$$){$apply_changes_local_library_QMARK_$jscomp$1_map__54282__$1_p__54281$$=$APP.$cljs$core$__destructure_map$$($apply_changes_local_library_QMARK_$jscomp$1_map__54282__$1_p__54281$$);$apply_changes_local_library_QMARK_$jscomp$1_map__54282__$1_p__54281$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($apply_changes_local_library_QMARK_$jscomp$1_map__54282__$1_p__54281$$,$APP.$cljs$cst$3179$apply_changes_local_library_QMARK_$$);var $library_data$jscomp$15$$=$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($G__54285_changes$jscomp$64$$)),$prev_component$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($library_data$jscomp$15$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$id$jscomp$363$$],null)),$new_component$$=$update_fn$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$update_fn$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($prev_component$$):$update_fn$jscomp$12$$($prev_component$$);return $APP.$cljs$core$truth_$$($prev_component$$)?($G__54285_changes$jscomp$64$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__54285_changes$jscomp$64$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,function(){var $G__54287_G__54287__$1_G__54287__$2_G__54287__$3$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$2062$main_instance_id$$,$APP.$cljs$cst$1631$objects$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1737$modified_at$$,$APP.$cljs$cst$2063$main_instance_page$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$2542$annotation$$],[$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($new_component$$),
$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($new_component$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($new_component$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($new_component$$),$cljs$cst$2632$mod_component$$,$APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($new_component$$),$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($new_component$$),$id$jscomp$363$$,$APP.$cljs$cst$2542$annotation$$.$cljs$core$IFn$_invoke$arity$1$($new_component$$)]);
$G__54287_G__54287__$1_G__54287__$2_G__54287__$3$$=$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($new_component$$)!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54287_G__54287__$1_G__54287__$2_G__54287__$3$$,$APP.$cljs$cst$2000$variant_id$$,$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($new_component$$)):$G__54287_G__54287__$1_G__54287__$2_G__54287__$3$$;$G__54287_G__54287__$1_G__54287__$2_G__54287__$3$$=$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($new_component$$)==
null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__54287_G__54287__$1_G__54287__$2_G__54287__$3$$,$APP.$cljs$cst$2000$variant_id$$):$G__54287_G__54287__$1_G__54287__$2_G__54287__$3$$;$G__54287_G__54287__$1_G__54287__$2_G__54287__$3$$=$APP.$cljs$core$seq$$($APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($new_component$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54287_G__54287__$1_G__54287__$2_G__54287__$3$$,$APP.$cljs$cst$2001$variant_properties$$,
$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($new_component$$)):$G__54287_G__54287__$1_G__54287__$2_G__54287__$3$$;return $APP.$cljs$core$not$$($APP.$cljs$core$seq$$($APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($new_component$$)))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__54287_G__54287__$1_G__54287__$2_G__54287__$3$$,$APP.$cljs$cst$2001$variant_properties$$):$G__54287_G__54287__$1_G__54287__$2_G__54287__$3$$}()),$APP.$cljs$cst$3137$undo_changes$$,
$APP.$cljs$core$conj$$,function(){var $G__54291_G__54291__$1_G__54291__$2_G__54291__$3$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$139$type$$,$cljs$cst$2632$mod_component$$,$APP.$cljs$cst$266$id$$,$id$jscomp$363$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prev_component$$),$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($prev_component$$),$APP.$cljs$cst$2062$main_instance_id$$,$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($prev_component$$),
$APP.$cljs$cst$2063$main_instance_page$$,$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($prev_component$$),$APP.$cljs$cst$2542$annotation$$,$APP.$cljs$cst$2542$annotation$$.$cljs$core$IFn$_invoke$arity$1$($prev_component$$),$APP.$cljs$cst$1631$objects$$,$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($prev_component$$)],null);$G__54291_G__54291__$1_G__54291__$2_G__54291__$3$$=$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($prev_component$$)!=
null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54291_G__54291__$1_G__54291__$2_G__54291__$3$$,$APP.$cljs$cst$2000$variant_id$$,$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($prev_component$$)):$G__54291_G__54291__$1_G__54291__$2_G__54291__$3$$;$G__54291_G__54291__$1_G__54291__$2_G__54291__$3$$=$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($prev_component$$)==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__54291_G__54291__$1_G__54291__$2_G__54291__$3$$,
$APP.$cljs$cst$2000$variant_id$$):$G__54291_G__54291__$1_G__54291__$2_G__54291__$3$$;$G__54291_G__54291__$1_G__54291__$2_G__54291__$3$$=$APP.$cljs$core$seq$$($APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($prev_component$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54291_G__54291__$1_G__54291__$2_G__54291__$3$$,$APP.$cljs$cst$2001$variant_properties$$,$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($prev_component$$)):$G__54291_G__54291__$1_G__54291__$2_G__54291__$3$$;
return $APP.$cljs$core$not$$($APP.$cljs$core$seq$$($APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($prev_component$$)))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__54291_G__54291__$1_G__54291__$2_G__54291__$3$$,$APP.$cljs$cst$2001$variant_properties$$):$G__54291_G__54291__$1_G__54291__$2_G__54291__$3$$}()),$APP.$cljs$core$truth_$$($apply_changes_local_library_QMARK_$jscomp$1_map__54282__$1_p__54281$$)?$app$common$files$changes_builder$apply_changes_local$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__54285_changes$jscomp$64$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3172$apply_to_library_QMARK_$$,!0],null)])):$G__54285_changes$jscomp$64$$):$G__54285_changes$jscomp$64$$};
$APP.$app$common$files$changes_builder$delete_component$$=function($changes$jscomp$65$$,$id$jscomp$364$$,$page_id$jscomp$70$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$65$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2633$del_component$$,$APP.$cljs$cst$266$id$$,$id$jscomp$364$$],null)),$APP.$cljs$cst$3137$undo_changes$$,
$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$2636$restore_component$$,$APP.$cljs$cst$266$id$$,$id$jscomp$364$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$70$$],null))};
$app$common$files$changes_builder$restore_component$$=function($changes$jscomp$66$$,$id$jscomp$365$$,$page_id$jscomp$71$$,$delta$jscomp$15$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$66$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$2636$restore_component$$,$APP.$cljs$cst$266$id$$,$id$jscomp$365$$,$APP.$cljs$cst$2043$page_id$$,
$page_id$jscomp$71$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$2633$del_component$$,$APP.$cljs$cst$266$id$$,$id$jscomp$365$$,$cljs$cst$2634$delta$$,$delta$jscomp$15$$],null))};
$APP.$app$common$files$changes_builder$set_token$$=function($changes$jscomp$68$$,$set_id$jscomp$20$$,$token_id$jscomp$15$$,$token$jscomp$65$$){var $G__54311$jscomp$inline_6166_library_data$jscomp$17_prev_token$jscomp$1$$=$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$68$$));$G__54311$jscomp$inline_6166_library_data$jscomp$17_prev_token$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__54311$jscomp$inline_6166_library_data$jscomp$17_prev_token$jscomp$1$$,
$APP.$cljs$cst$2139$tokens_lib$$);$G__54311$jscomp$inline_6166_library_data$jscomp$17_prev_token$jscomp$1$$=$G__54311$jscomp$inline_6166_library_data$jscomp$17_prev_token$jscomp$1$$==null?null:$APP.$app$common$types$tokens_lib$get_token$$($G__54311$jscomp$inline_6166_library_data$jscomp$17_prev_token$jscomp$1$$,$set_id$jscomp$20$$,$token_id$jscomp$15$$);return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$68$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$2642$set_token$$,$APP.$cljs$cst$2643$set_id$$,$set_id$jscomp$20$$,$APP.$cljs$cst$2644$token_id$$,$token_id$jscomp$15$$,$APP.$cljs$cst$2645$attrs$$,$APP.$clojure$datafy$datafy$$($token$jscomp$65$$)],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$2642$set_token$$,
$APP.$cljs$cst$2643$set_id$$,$set_id$jscomp$20$$,$APP.$cljs$cst$2644$token_id$$,$token_id$jscomp$15$$,$APP.$cljs$cst$2645$attrs$$,$APP.$clojure$datafy$datafy$$($G__54311$jscomp$inline_6166_library_data$jscomp$17_prev_token$jscomp$1$$)],null)))};
$APP.$app$common$files$changes_builder$set_token_set$$=function($changes$jscomp$69$$,$id$jscomp$366$$,$token_set$jscomp$7$$){var $G__54318$jscomp$inline_6168_library_data$jscomp$18_prev_token_set$$=$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$69$$));$G__54318$jscomp$inline_6168_library_data$jscomp$18_prev_token_set$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__54318$jscomp$inline_6168_library_data$jscomp$18_prev_token_set$$,
$APP.$cljs$cst$2139$tokens_lib$$);$G__54318$jscomp$inline_6168_library_data$jscomp$18_prev_token_set$$=$G__54318$jscomp$inline_6168_library_data$jscomp$18_prev_token_set$$==null?null:$APP.$app$common$types$tokens_lib$get_set$$($G__54318$jscomp$inline_6168_library_data$jscomp$18_prev_token_set$$,$id$jscomp$366$$);return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$69$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$2646$set_token_set$$,$APP.$cljs$cst$266$id$$,$id$jscomp$366$$,$APP.$cljs$cst$2645$attrs$$,$APP.$clojure$datafy$datafy$$($token_set$jscomp$7$$)],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$2646$set_token_set$$,$APP.$cljs$cst$266$id$$,$id$jscomp$366$$,$APP.$cljs$cst$2645$attrs$$,
$APP.$clojure$datafy$datafy$$($G__54318$jscomp$inline_6168_library_data$jscomp$18_prev_token_set$$)],null)))};
$app$common$files$changes_builder$set_token_theme$$=function($changes$jscomp$71$$,$id$jscomp$368$$,$theme$jscomp$9$$){var $G__54320$jscomp$inline_6172_library_data$jscomp$20_prev_theme$$=$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$71$$));$G__54320$jscomp$inline_6172_library_data$jscomp$20_prev_theme$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__54320$jscomp$inline_6172_library_data$jscomp$20_prev_theme$$,
$APP.$cljs$cst$2139$tokens_lib$$);$G__54320$jscomp$inline_6172_library_data$jscomp$20_prev_theme$$=$G__54320$jscomp$inline_6172_library_data$jscomp$20_prev_theme$$==null?null:$APP.$app$common$types$tokens_lib$get_theme$$($G__54320$jscomp$inline_6172_library_data$jscomp$20_prev_theme$$,$id$jscomp$368$$);return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$71$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$2647$set_token_theme$$,$APP.$cljs$cst$266$id$$,$id$jscomp$368$$,$APP.$cljs$cst$2645$attrs$$,$APP.$clojure$datafy$datafy$$($theme$jscomp$9$$)],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$2647$set_token_theme$$,$APP.$cljs$cst$266$id$$,$id$jscomp$368$$,$APP.$cljs$cst$2645$attrs$$,
$APP.$clojure$datafy$datafy$$($G__54320$jscomp$inline_6172_library_data$jscomp$20_prev_theme$$)],null)))};
$app$common$files$changes_builder$set_active_token_themes$$=function($changes$jscomp$72$$,$active_theme_paths$$){var $G__54321$jscomp$inline_6174_JSCompiler_inline_result$jscomp$1066_library_data$jscomp$21$$=$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$72$$)),$JSCompiler_temp_const$jscomp$1064_prev_active_theme_paths$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$;$G__54321$jscomp$inline_6174_JSCompiler_inline_result$jscomp$1066_library_data$jscomp$21$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__54321$jscomp$inline_6174_JSCompiler_inline_result$jscomp$1066_library_data$jscomp$21$$,$APP.$cljs$cst$2139$tokens_lib$$);$G__54321$jscomp$inline_6174_JSCompiler_inline_result$jscomp$1066_library_data$jscomp$21$$=$G__54321$jscomp$inline_6174_JSCompiler_inline_result$jscomp$1066_library_data$jscomp$21$$==null?null:$app$common$types$tokens_lib$get_active_theme_paths$$($G__54321$jscomp$inline_6174_JSCompiler_inline_result$jscomp$1066_library_data$jscomp$21$$);
$JSCompiler_temp_const$jscomp$1064_prev_active_theme_paths$$=$JSCompiler_temp_const$jscomp$1064_prev_active_theme_paths$$.call($APP.$app$common$data$nilv$$,$G__54321$jscomp$inline_6174_JSCompiler_inline_result$jscomp$1066_library_data$jscomp$21$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$72$$,$APP.$cljs$cst$3133$redo_changes$$,
$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2648$set_active_token_themes$$,$cljs$cst$2649$theme_paths$$,$active_theme_paths$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2648$set_active_token_themes$$,$cljs$cst$2649$theme_paths$$,$JSCompiler_temp_const$jscomp$1064_prev_active_theme_paths$$],null)))};
$APP.$app$common$files$changes_builder$reorder_children$$=function($changes$jscomp$77$$,$id$jscomp$369_shape$jscomp$373$$,$children$jscomp$204_redo_change$jscomp$1$$){var $page_id$jscomp$72_undo_change$jscomp$1$$=$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$77$$)),$objects$jscomp$256_old_children$$=$app$common$files$changes_builder$lookup_objects$$($changes$jscomp$77$$);$id$jscomp$369_shape$jscomp$373$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$256_old_children$$,$id$jscomp$369_shape$jscomp$373$$);$objects$jscomp$256_old_children$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$369_shape$jscomp$373$$);$children$jscomp$204_redo_change$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$2619$reorder_children$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$369_shape$jscomp$373$$),
$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$72_undo_change$jscomp$1$$,$APP.$cljs$cst$1614$shapes$$,$children$jscomp$204_redo_change$jscomp$1$$],null);$page_id$jscomp$72_undo_change$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$2619$reorder_children$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$369_shape$jscomp$373$$),$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$72_undo_change$jscomp$1$$,$APP.$cljs$cst$1614$shapes$$,
$objects$jscomp$256_old_children$$],null);return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$77$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,$children$jscomp$204_redo_change$jscomp$1$$),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,$page_id$jscomp$72_undo_change$jscomp$1$$))};
$APP.$app$common$files$changes_builder$reorder_grid_children$$=function($changes$jscomp$78$$,$ids$jscomp$43$$){var $page_id$jscomp$73$$=$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$78$$)),$objects$jscomp$257$$=$app$common$files$changes_builder$lookup_objects$$($changes$jscomp$78$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$7$$,$grid$jscomp$2_grid__$1$$){var $old_shapes$jscomp$1_undo_change$jscomp$2$$=
$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$2_grid__$1$$);$grid$jscomp$2_grid__$1$$=$app$common$types$shape$layout$reorder_grid_children$$($grid$jscomp$2_grid__$1$$);var $new_shapes$jscomp$4_redo_change$jscomp$2$$=$APP.$cljs$core$filterv$$(function($p1__54332_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($objects$jscomp$257$$,$p1__54332_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$2_grid__$1$$));$new_shapes$jscomp$4_redo_change$jscomp$2$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$2619$reorder_children$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$2_grid__$1$$),$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$73$$,$APP.$cljs$cst$1614$shapes$$,$new_shapes$jscomp$4_redo_change$jscomp$2$$],null);$old_shapes$jscomp$1_undo_change$jscomp$2$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$2619$reorder_children$$,
$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$2_grid__$1$$),$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$73$$,$APP.$cljs$cst$1614$shapes$$,$old_shapes$jscomp$1_undo_change$jscomp$2$$],null);return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes__$1$jscomp$7$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,
$new_shapes$jscomp$4_redo_change$jscomp$2$$),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,$old_shapes$jscomp$1_undo_change$jscomp$2$$))},$changes$jscomp$78$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$257$$),$ids$jscomp$43$$)))};$APP.$app$common$files$changes_builder$get_library_data$$=function($changes$jscomp$79$$){return $APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$79$$))};
$APP.$app$common$files$changes_builder$get_objects$$=function($changes$jscomp$80$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3169$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_file_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$80$$)),$APP.$cljs$cst$1630$pages_index$$),$APP.$app$common$uuid$zero$$),$APP.$cljs$cst$1631$objects$$)};
$app$common$files$changes_builder$set_text_content$$=function($changes$jscomp$83$$,$id$jscomp$370$$,$content$jscomp$150$$,$prev_content_undo_change$jscomp$3$$){var $page_id$jscomp$74$$=$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$83$$));$prev_content_undo_change$jscomp$3$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$2043$page_id$$,
$page_id$jscomp$74$$,$APP.$cljs$cst$266$id$$,$id$jscomp$370$$,$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$108$val$$,$prev_content_undo_change$jscomp$3$$],null)],null)],null);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$83$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$74$$,$APP.$cljs$cst$266$id$$,$id$jscomp$370$$,$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,
$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$108$val$$,$content$jscomp$150$$],null)],null)],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,$prev_content_undo_change$jscomp$3$$)};$APP.$app$main$data$media$file_QMARK_$$=function($o$jscomp$264$$){return $o$jscomp$264$$ instanceof File};
$APP.$app$main$data$media$validate_file$$=function($file$jscomp$38$$){if(!$APP.$cljs$core$contains_QMARK_$$($app$common$media$image_types$$,$file$jscomp$38$$.type))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("media type "+($file$jscomp$38$$.type??"")+" is not supported",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2252$validation$$,
$APP.$cljs$cst$273$code$$,$cljs$cst$3193$media_type_not_allowed$$,$APP.$cljs$cst$275$hint$$,"media type "+($file$jscomp$38$$.type??"")+" is not supported"],null),null])),null);return $file$jscomp$38$$};
$APP.$app$main$data$media$notify_start_loading$$=function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.loading"),$APP.$cljs$cst$78$tag$$,$cljs$cst$3194$app_DOT_main_DOT_data_DOT_media_SLASH_media_upload$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,
$APP.$cljs$cst$2353$timeout$$,null],null)))};$APP.$app$main$data$media$notify_finished_loading$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$hide$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$78$tag$$,$cljs$cst$3194$app_DOT_main_DOT_data_DOT_media_SLASH_media_upload$$])))};
$APP.$app$main$data$media$process_error$$=function($error$jscomp$53_msg$jscomp$23$$){$error$jscomp$53_msg$jscomp$23$$=$APP.$cljs$core$truth_$$($error$jscomp$53_msg$jscomp$23$$.message)?$error$jscomp$53_msg$jscomp$23$$.message:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$53_msg$jscomp$23$$),$cljs$cst$3193$media_type_not_allowed$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.media-type-not-allowed"):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$53_msg$jscomp$23$$),$cljs$cst$3195$media_type_mismatch$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.media-type-mismatch"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.unexpected-error");return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($error$jscomp$53_msg$jscomp$23$$))};
$APP.$app$plugins$register$plugins_list$$=function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__54125_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$plugins$register$registry$$),$APP.$cljs$cst$142$data$$),$p1__54125_SHARP_$$)},$APP.$cljs$cst$1723$ids$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$plugins$register$registry$$)))};
$app$plugins$register$get_plugin$$=function($id$jscomp$371$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$plugins$register$registry$$),$APP.$cljs$cst$142$data$$),$id$jscomp$371$$)};
$app$plugins$register$parse_manifest$$=function($plugin_url_plugin_url__$1$$,$manifest_permissions__$1$$){var $name$jscomp$270$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($manifest_permissions__$1$$,"name"),$desc_manifest__$1$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($manifest_permissions__$1$$,"description"),$code$jscomp$24$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($manifest_permissions__$1$$,"code"),$icon$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($manifest_permissions__$1$$,
"icon"),$vers$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($manifest_permissions__$1$$,"version"),1),$permissions$jscomp$3$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($manifest_permissions__$1$$,"permissions",$APP.$cljs$core$PersistentVector$EMPTY$$));$manifest_permissions__$1$$=function(){var $G__54136__$1_G__54136__$2_G__54136__$3$$=
$APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$3$$,"content:write")?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($permissions$jscomp$3$$,"content:read"):$permissions$jscomp$3$$;$G__54136__$1_G__54136__$2_G__54136__$3$$=$APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$3$$,"library:write")?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__54136__$1_G__54136__$2_G__54136__$3$$,"library:read"):$G__54136__$1_G__54136__$2_G__54136__$3$$;$G__54136__$1_G__54136__$2_G__54136__$3$$=
$APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$3$$,"comment:write")?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__54136__$1_G__54136__$2_G__54136__$3$$,"comment:read"):$G__54136__$1_G__54136__$2_G__54136__$3$$;return $APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$3$$,"clipboard:write")?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__54136__$1_G__54136__$2_G__54136__$3$$,"clipboard:read"):$G__54136__$1_G__54136__$2_G__54136__$3$$}();$plugin_url_plugin_url__$1$$=
$APP.$app$common$uri$uri$$($plugin_url_plugin_url__$1$$);var $origin$jscomp$23$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($vers$$,1)?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($plugin_url_plugin_url__$1$$,$APP.$cljs$cst$296$path$$,"")):$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$plugin_url_plugin_url__$1$$,
"."]))),$plugin_id_prev_plugin$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($plugin$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$270$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($plugin$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$23$$,$APP.$cljs$cst$744$host$$.$cljs$core$IFn$_invoke$arity$1$($plugin$$))},$APP.$cljs$core$vals$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$plugins$register$registry$$))));
$plugin_id_prev_plugin$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1720$plugin_id$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id_prev_plugin$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$uuid$next$$()));$desc_manifest__$1$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$936$description$$,$APP.$cljs$cst$1722$permissions$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$1721$icon$$,
$APP.$cljs$cst$1720$plugin_id$$,$APP.$cljs$cst$744$host$$,$APP.$cljs$cst$1975$url$$,$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$2289$version$$],[$desc_manifest__$1$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$str$$),$manifest_permissions__$1$$),$name$jscomp$270$$,$icon$$,$plugin_id_prev_plugin$$,$origin$jscomp$23$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_url_plugin_url__$1$$),
$code$jscomp$24$$,$vers$$]));return $APP.$cljs$core$truth_$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$plugins$schema_COLON_registry_entry$$,$desc_manifest__$1$$))?$desc_manifest__$1$$:console.error($APP.$cljs$core$clj__GT_js$$($malli$core$explain$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$plugins$schema_COLON_registry_entry$$,$desc_manifest__$1$$)))};
$app$plugins$register$save_to_store$$=function(){var $registry$jscomp$10$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($APP.$app$plugins$register$registry$$),$APP.$cljs$cst$142$data$$,$APP.$app$common$data$update_vals$$,$APP.$app$common$data$without_nils$$);$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$identity$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3196$update_profile_props$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$575$props$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3197$plugins$$,$registry$jscomp$10$$],null)],null)))};
$APP.$app$plugins$register$install_plugin_BANG_$$=function($plugin$jscomp$1$$){function $update_ids$jscomp$1$$($ids$jscomp$44$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__54145_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__54145_SHARP_$$,$APP.$cljs$cst$1720$plugin_id$$.$cljs$core$IFn$_invoke$arity$1$($plugin$jscomp$1$$))},$ids$jscomp$44$$),$APP.$cljs$cst$1720$plugin_id$$.$cljs$core$IFn$_invoke$arity$1$($plugin$jscomp$1$$))}
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$plugins$register$registry$$,function($p1__54146_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__54146_SHARP_$$,$APP.$cljs$cst$1723$ids$$,$update_ids$jscomp$1$$),$APP.$cljs$cst$142$data$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1720$plugin_id$$.$cljs$core$IFn$_invoke$arity$1$($plugin$jscomp$1$$),$plugin$jscomp$1$$)});$app$plugins$register$save_to_store$$()};
$app$plugins$register$remove_plugin_BANG_$$=function($map__54155__$1_p__54154$$){function $update_ids$jscomp$2$$($ids$jscomp$45$$){return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__54151_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__54151_SHARP_$$,$plugin_id$jscomp$1$$)},$ids$jscomp$45$$)}$map__54155__$1_p__54154$$=$APP.$cljs$core$__destructure_map$$($map__54155__$1_p__54154$$);var $plugin_id$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54155__$1_p__54154$$,
$APP.$cljs$cst$1720$plugin_id$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$plugins$register$registry$$,function($p1__54152_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__54152_SHARP_$$,$APP.$cljs$cst$1723$ids$$,$update_ids$jscomp$2$$),$APP.$cljs$cst$142$data$$,$APP.$cljs$core$dissoc$$,$plugin_id$jscomp$1$$)});$app$plugins$register$save_to_store$$()};
$APP.$app$main$data$profile$is_authenticated_QMARK_$$=function($id$jscomp$372_map__54896__$1_p__54895$$){$id$jscomp$372_map__54896__$1_p__54895$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$372_map__54896__$1_p__54895$$);$id$jscomp$372_map__54896__$1_p__54895$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$372_map__54896__$1_p__54895$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$uuid_QMARK_$$($id$jscomp$372_map__54896__$1_p__54895$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$372_map__54896__$1_p__54895$$,
$APP.$app$common$uuid$zero$$)};
$APP.$app$main$data$profile$set_profile$$=function($p__54899$$){var $map__54900__$1$$=$APP.$cljs$core$__destructure_map$$($p__54899$$),$id$jscomp$373$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54900__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$profile$set_profile_54905$$==="undefined"&&($app$main$data$profile$set_profile_54905$$=function($p__54899$jscomp$1$$,$map__54900$jscomp$1$$,$profile$jscomp$6$$,$id$jscomp$374$$,$meta54906$$){this.$p__54899$=$p__54899$jscomp$1$$;this.$map__54900$=
$map__54900$jscomp$1$$;this.profile=$profile$jscomp$6$$;this.id=$id$jscomp$374$$;this.$meta54906$=$meta54906$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$set_profile_54905$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$set_profile_54905$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3198$app_DOT_main_DOT_data_DOT_profile_SLASH_set_profile$$},$app$main$data$profile$set_profile_54905$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_54907$$,$meta54906__$1$$){return new $app$main$data$profile$set_profile_54905$$(this.$p__54899$,this.$map__54900$,this.profile,this.id,$meta54906__$1$$)},$app$main$data$profile$set_profile_54905$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta54906$},$app$main$data$profile$set_profile_54905$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.profile},$app$main$data$profile$set_profile_54905$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$profile$set_profile_54905$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1662$$,$state$jscomp$193$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$193$$,$APP.$cljs$cst$2313$profile_id$$,this.id),$APP.$cljs$cst$1914$profile$$,this.profile)},$app$main$data$profile$set_profile_54905$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$set_profile_54905$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1663_profile__$1$$,$state$jscomp$194$$){$_$jscomp$1663_profile__$1$$=$APP.$cljs$cst$1914$profile$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$194$$);return $APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$from$$($app$util$i18n$set_locale$$($APP.$cljs$cst$2828$lang$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1663_profile__$1$$))))},$app$main$data$profile$set_profile_54905$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$set_profile_54905$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=
function($_$jscomp$1664_profile__$1$jscomp$1$$,$state$jscomp$195$$){$_$jscomp$1664_profile__$1$jscomp$1$$=$APP.$cljs$cst$1914$profile$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$195$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1914$profile$$,$_$jscomp$1664_profile__$1$jscomp$1$$);return $APP.$cljs$core$reset_BANG_$$($APP.$app$plugins$register$registry$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1914$profile$$,$APP.$cljs$cst$575$props$$,$APP.$cljs$cst$3197$plugins$$],null),$APP.$cljs$core$PersistentArrayMap$EMPTY$$))});return new $app$main$data$profile$set_profile_54905$$($p__54899$$,$map__54900__$1$$,$map__54900__$1$$,$id$jscomp$373$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$profile$on_fetch_profile_exception$$=function($cause$jscomp$51_hash$jscomp$inline_6176_href$jscomp$9_path$jscomp$232$$){var $data$jscomp$266$$=$APP.$cljs$core$ex_data$$($cause$jscomp$51_hash$jscomp$inline_6176_href$jscomp$9_path$jscomp$232$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2254$authorization$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$266$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2255$challenge_required$$,
$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$266$$))?($cause$jscomp$51_hash$jscomp$inline_6176_href$jscomp$9_path$jscomp$232$$=$APP.$app$util$globals$location$$.hash,$cause$jscomp$51_hash$jscomp$inline_6176_href$jscomp$9_path$jscomp$232$$=$APP.$cuerdas$core$starts_with_QMARK_$$($cause$jscomp$51_hash$jscomp$inline_6176_href$jscomp$9_path$jscomp$232$$,"#")?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($cause$jscomp$51_hash$jscomp$inline_6176_href$jscomp$9_path$jscomp$232$$,
1):$cause$jscomp$51_hash$jscomp$inline_6176_href$jscomp$9_path$jscomp$232$$,$cause$jscomp$51_hash$jscomp$inline_6176_href$jscomp$9_path$jscomp$232$$=["/challenge.html?redirect\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(encodeURIComponent($cause$jscomp$51_hash$jscomp$inline_6176_href$jscomp$9_path$jscomp$232$$))].join(""),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2462$href$$,
$cause$jscomp$51_hash$jscomp$inline_6176_href$jscomp$9_path$jscomp$232$$])))):$APP.$beicon$v2$core$throw$0$$($cause$jscomp$51_hash$jscomp$inline_6176_href$jscomp$9_path$jscomp$232$$)};
$APP.$app$main$data$profile$on_fetch_profile_success$$=function($profile$jscomp$7$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1223$subscriptions$$)&&$APP.$app$main$data$profile$is_authenticated_QMARK_$$($profile$jscomp$7$$)?$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$52$$){console.error("unexpected error on obtaining subscription usage",$cause$jscomp$52$$);return(0,$APP.$beicon$v2$core$of$$)($profile$jscomp$7$$)},
$APP.$beicon$v2$core$map$$(function($editors_map__54956__$1_p__54955$$){$editors_map__54956__$1_p__54955$$=$APP.$cljs$core$__destructure_map$$($editors_map__54956__$1_p__54955$$);$editors_map__54956__$1_p__54955$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($editors_map__54956__$1_p__54955$$,$APP.$cljs$cst$3200$editors$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($profile$jscomp$7$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$575$props$$,$APP.$cljs$cst$3201$subscription$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3200$editors$$,$editors_map__54956__$1_p__54955$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3202$get_subscription_usage$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$))):(0,$APP.$beicon$v2$core$of$$)($profile$jscomp$7$$)};
$app$main$data$profile$fetch_profile$$=function(){typeof $app$main$data$profile$fetch_profile_54957$$==="undefined"&&($app$main$data$profile$fetch_profile_54957$$=function($meta54958$$){this.$meta54958$=$meta54958$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$fetch_profile_54957$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$fetch_profile_54957$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3203$app_DOT_main_DOT_data_DOT_profile_SLASH_fetch_profile$$},$app$main$data$profile$fetch_profile_54957$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_54959$$,$meta54958__$1$$){return new $app$main$data$profile$fetch_profile_54957$$($meta54958__$1$$)},$app$main$data$profile$fetch_profile_54957$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta54958$},$app$main$data$profile$fetch_profile_54957$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$fetch_profile_54957$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$profile$on_fetch_profile_exception$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$potok$v2$core$data_event$$,$cljs$cst$3199$app_DOT_main_DOT_data_DOT_profile_SLASH_profile_fetched$$),$APP.$beicon$v2$core$mapcat$$($APP.$app$main$data$profile$on_fetch_profile_success$$,
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3204$get_profile$$))))});return new $app$main$data$profile$fetch_profile_54957$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$profile$refresh_profile$$=function(){typeof $app$main$data$profile$refresh_profile_54975$$==="undefined"&&($app$main$data$profile$refresh_profile_54975$$=function($meta54976$$){this.$meta54976$=$meta54976$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$refresh_profile_54975$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$refresh_profile_54975$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3205$app_DOT_main_DOT_data_DOT_profile_SLASH_refresh_profile$$},$app$main$data$profile$refresh_profile_54975$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_54977$$,$meta54976__$1$$){return new $app$main$data$profile$refresh_profile_54975$$($meta54976__$1$$)},$app$main$data$profile$refresh_profile_54975$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta54976$},$app$main$data$profile$refresh_profile_54975$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$refresh_profile_54975$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1666$$,$___$1$jscomp$1002$$,$stream$jscomp$30$$){return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$profile$fetch_profile$$()),$APP.$beicon$v2$core$map$$($APP.$app$main$data$profile$set_profile$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$app$main$data$profile$is_authenticated_QMARK_$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,
$APP.$beicon$v2$core$filter$$($APP.$app$main$data$profile$profile_fetched_QMARK_$$,$stream$jscomp$30$$))))))});return new $app$main$data$profile$refresh_profile_54975$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$profile$persist_profile$$=function($var_args$jscomp$1159$$){for(var $args__5755__auto__$jscomp$207$$=[],$len__5749__auto___55403$$=arguments.length,$i__5750__auto___55404$$=0;;)if($i__5750__auto___55404$$<$len__5749__auto___55403$$)$args__5755__auto__$jscomp$207$$.push(arguments[$i__5750__auto___55404$$]),$i__5750__auto___55404$$+=1;else break;return $APP.$app$main$data$profile$persist_profile$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$207$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$207$$.slice(0),
0,null):null)};
$APP.$app$main$data$profile$persist_profile$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__55012$$){var $map__55014__$1$$=$APP.$cljs$core$__destructure_map$$($p__55012$$);typeof $app$main$data$profile$persist_profile_55022$$==="undefined"&&($app$main$data$profile$persist_profile_55022$$=function($p__55012$jscomp$1$$,$map__55014$jscomp$1$$,$opts$jscomp$295$$,$meta55023$$){this.$p__55012$=$p__55012$jscomp$1$$;this.$map__55014$=$map__55014$jscomp$1$$;this.$opts$=$opts$jscomp$295$$;this.$meta55023$=
$meta55023$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$persist_profile_55022$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$persist_profile_55022$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3206$app_DOT_main_DOT_data_DOT_profile_SLASH_persist_profile$$},$app$main$data$profile$persist_profile_55022$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55024$$,$meta55023__$1$$){return new $app$main$data$profile$persist_profile_55022$$(this.$p__55012$,this.$map__55014$,this.$opts$,$meta55023__$1$$)},$app$main$data$profile$persist_profile_55022$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55023$},$app$main$data$profile$persist_profile_55022$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$persist_profile_55022$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1667_on_success$jscomp$1$$,$params$jscomp$185_profile$jscomp$8_state$jscomp$196$$){$_$jscomp$1667_on_success$jscomp$1$$=$APP.$cljs$cst$2488$on_success$$.$cljs$core$IFn$_invoke$arity$2$(this.$opts$,$APP.$cljs$core$identity$$);var $on_error$jscomp$5$$=$APP.$cljs$cst$1295$on_error$$.$cljs$core$IFn$_invoke$arity$2$(this.$opts$,$APP.$beicon$v2$core$throw$0$$);$params$jscomp$185_profile$jscomp$8_state$jscomp$196$$=$APP.$cljs$cst$1914$profile$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$185_profile$jscomp$8_state$jscomp$196$$);
$params$jscomp$185_profile$jscomp$8_state$jscomp$196$$=$APP.$cljs$core$select_keys$$($params$jscomp$185_profile$jscomp$8_state$jscomp$196$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1360$fullname$$,$APP.$cljs$cst$2828$lang$$,$APP.$cljs$cst$3184$theme$$],null));return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($on_error$jscomp$5$$,$APP.$beicon$v2$core$map$$($APP.$app$main$data$profile$set_profile$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$1667_on_success$jscomp$1$$,
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3207$update_profile$$,$params$jscomp$185_profile$jscomp$8_state$jscomp$196$$))))});return new $app$main$data$profile$persist_profile_55022$$($p__55012$$,$map__55014__$1$$,$map__55014__$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$profile$toggle_theme$$=function(){typeof $app$main$data$profile$toggle_theme_55047$$==="undefined"&&($app$main$data$profile$toggle_theme_55047$$=function($meta55048$$){this.$meta55048$=$meta55048$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$toggle_theme_55047$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$toggle_theme_55047$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3209$app_DOT_main_DOT_data_DOT_profile_SLASH_toggle_theme$$},$app$main$data$profile$toggle_theme_55047$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55049$$,$meta55048__$1$$){return new $app$main$data$profile$toggle_theme_55047$$($meta55048__$1$$)},$app$main$data$profile$toggle_theme_55047$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55048$},$app$main$data$profile$toggle_theme_55047$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$profile$toggle_theme_55047$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1669$$,$state$jscomp$198$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$198$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1914$profile$$,$APP.$cljs$cst$3184$theme$$],null),function($current$jscomp$34$$){switch($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$34$$,
"default")?"dark":$current$jscomp$34$$){case "dark":return"light";case "light":return"system";case "system":return"dark";default:return"dark"}})},$app$main$data$profile$toggle_theme_55047$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$toggle_theme_55047$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$139_profile$jscomp$11$$,$origin$jscomp$24_state$jscomp$199$$){$it$jscomp$139_profile$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$24_state$jscomp$199$$,
$APP.$cljs$cst$1914$profile$$);$origin$jscomp$24_state$jscomp$199$$=$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$(this));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3184$theme$$,$APP.$cljs$cst$3184$theme$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$139_profile$jscomp$11$$),$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"activate-theme",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$origin$jscomp$24_state$jscomp$199$$],null)),$app$main$data$profile$persist_profile$$())});return new $app$main$data$profile$toggle_theme_55047$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$profile$update_profile_props$$=function($props$jscomp$132$$){typeof $app$main$data$profile$update_profile_props_55278$$==="undefined"&&($app$main$data$profile$update_profile_props_55278$$=function($props$jscomp$133$$,$meta55279$$){this.props=$props$jscomp$133$$;this.$meta55279$=$meta55279$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$update_profile_props_55278$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$profile$update_profile_props_55278$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3225$app_DOT_main_DOT_data_DOT_profile_SLASH_update_profile_props$$},$app$main$data$profile$update_profile_props_55278$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55280$$,$meta55279__$1$$){return new $app$main$data$profile$update_profile_props_55278$$(this.props,$meta55279__$1$$)},$app$main$data$profile$update_profile_props_55278$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55279$},$app$main$data$profile$update_profile_props_55278$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$update_profile_props_55278$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1679$$,$state$jscomp$201$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$201$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1914$profile$$,
$APP.$cljs$cst$575$props$$],null),$APP.$cljs$core$merge$$,this.props)},$app$main$data$profile$update_profile_props_55278$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$update_profile_props_55278$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $refresh_profile$$=$APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$($APP.$app$main$data$profile$refresh_profile$$()),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3196$update_profile_props$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$575$props$$,this.props],null))),$recompute$$=$APP.$cljs$core$contains_QMARK_$$(this.props,$APP.$cljs$cst$3105$renderer$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$features$recompute_features$$()):null;return $APP.$cljs$core$truth_$$($recompute$$)?$APP.$beicon$v2$core$concat$$($recompute$$,$refresh_profile$$):$refresh_profile$$});return new $app$main$data$profile$update_profile_props_55278$$($props$jscomp$132$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$profile$request_profile_recovery$$=function($data$jscomp$271_data__$1$jscomp$10$$){$data$jscomp$271_data__$1$jscomp$10$$=$app$main$data$profile$check_request_profile_recovery$$($data$jscomp$271_data__$1$jscomp$10$$);typeof $app$main$data$profile$request_profile_recovery_55333$$==="undefined"&&($app$main$data$profile$request_profile_recovery_55333$$=function($data$jscomp$272$$,$meta55334$$){this.data=$data$jscomp$272$$;this.$meta55334$=$meta55334$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$request_profile_recovery_55333$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$request_profile_recovery_55333$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3242$app_DOT_main_DOT_data_DOT_profile_SLASH_request_profile_recovery$$},$app$main$data$profile$request_profile_recovery_55333$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55335$$,
$meta55334__$1$$){return new $app$main$data$profile$request_profile_recovery_55333$$(this.data,$meta55334__$1$$)},$app$main$data$profile$request_profile_recovery_55333$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55334$},$app$main$data$profile$request_profile_recovery_55333$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$request_profile_recovery_55333$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__55340_on_error$jscomp$10$$=
$APP.$cljs$core$meta$$(this.data),$map__55340__$1_on_success$jscomp$6$$=$APP.$cljs$core$__destructure_map$$($map__55340_on_error$jscomp$10$$);$map__55340_on_error$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55340__$1_on_success$jscomp$6$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);$map__55340__$1_on_success$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55340__$1_on_success$jscomp$6$$,$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);
return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55340_on_error$jscomp$10$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55340__$1_on_success$jscomp$6$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3243$request_profile_recovery$$,this.data)))});return new $app$main$data$profile$request_profile_recovery_55333$$($data$jscomp$271_data__$1$jscomp$10$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$profile$access_tokens_fetched$$=function($access_tokens$$){typeof $app$main$data$profile$access_tokens_fetched_55348$$==="undefined"&&($app$main$data$profile$access_tokens_fetched_55348$$=function($access_tokens$jscomp$1$$,$meta55349$$){this.$access_tokens$=$access_tokens$jscomp$1$$;this.$meta55349$=$meta55349$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$access_tokens_fetched_55348$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$access_tokens_fetched_55348$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3246$app_DOT_main_DOT_data_DOT_profile_SLASH_access_tokens_fetched$$},$app$main$data$profile$access_tokens_fetched_55348$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55350$$,$meta55349__$1$$){return new $app$main$data$profile$access_tokens_fetched_55348$$(this.$access_tokens$,$meta55349__$1$$)},$app$main$data$profile$access_tokens_fetched_55348$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55349$},$app$main$data$profile$access_tokens_fetched_55348$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$access_tokens_fetched_55348$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1693$$,$state$jscomp$206$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$206$$,$APP.$cljs$cst$1177$access_tokens$$,this.$access_tokens$)});return new $app$main$data$profile$access_tokens_fetched_55348$$($access_tokens$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$profile$fetch_access_tokens$$=function(){typeof $app$main$data$profile$fetch_access_tokens_55353$$==="undefined"&&($app$main$data$profile$fetch_access_tokens_55353$$=function($meta55354$$){this.$meta55354$=$meta55354$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$fetch_access_tokens_55353$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$fetch_access_tokens_55353$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3247$app_DOT_main_DOT_data_DOT_profile_SLASH_fetch_access_tokens$$},
$app$main$data$profile$fetch_access_tokens_55353$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55355$$,$meta55354__$1$$){return new $app$main$data$profile$fetch_access_tokens_55353$$($meta55354__$1$$)},$app$main$data$profile$fetch_access_tokens_55353$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55354$},$app$main$data$profile$fetch_access_tokens_55353$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$fetch_access_tokens_55353$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){return $APP.$beicon$v2$core$map$$($app$main$data$profile$access_tokens_fetched$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$3248$get_access_tokens$$))});return new $app$main$data$profile$fetch_access_tokens_55353$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$hasSvgItem$$module$app$util$clipboard$$=function($items$jscomp$28$$){return $items$jscomp$28$$.some($item$jscomp$57$$=>$item$jscomp$57$$?.type==="image/svg+xml")};
$parseText$$module$app$util$clipboard$$=function($text$jscomp$40$$,$decodeTransit_options$jscomp$491$$){$decodeTransit_options$jscomp$491$$=$decodeTransit_options$jscomp$491$$||{};$decodeTransit_options$jscomp$491$$=$decodeTransit_options$jscomp$491$$.decodeTransit;var $JSCompiler_temp$jscomp$1067_trimmed$jscomp$inline_6190$$;if($JSCompiler_temp$jscomp$1067_trimmed$jscomp$inline_6190$$=$decodeTransit_options$jscomp$491$$)typeof $text$jscomp$40$$!=="string"?$JSCompiler_temp$jscomp$1067_trimmed$jscomp$inline_6190$$=
!1:($JSCompiler_temp$jscomp$1067_trimmed$jscomp$inline_6190$$=$text$jscomp$40$$.trim(),$JSCompiler_temp$jscomp$1067_trimmed$jscomp$inline_6190$$=$JSCompiler_temp$jscomp$1067_trimmed$jscomp$inline_6190$$.startsWith("{")&&$JSCompiler_temp$jscomp$1067_trimmed$jscomp$inline_6190$$.endsWith("}")||$JSCompiler_temp$jscomp$1067_trimmed$jscomp$inline_6190$$.startsWith("[")&&$JSCompiler_temp$jscomp$1067_trimmed$jscomp$inline_6190$$.endsWith("]"));if($JSCompiler_temp$jscomp$1067_trimmed$jscomp$inline_6190$$)try{return $decodeTransit_options$jscomp$491$$($text$jscomp$40$$),
new Blob([$text$jscomp$40$$],{type:"application/transit+json"})}catch($_error$$){return new Blob([$text$jscomp$40$$],{type:"text/plain"})}return $svgTextPattern$$module$app$util$clipboard$$.test($text$jscomp$40$$)?new Blob([$text$jscomp$40$$],{type:"image/svg+xml"}):new Blob([$text$jscomp$40$$],{type:"text/plain"})};
$filterAllowedTypes$$module$app$util$clipboard$$=function($options$jscomp$492$$){return function($type$jscomp$428$$){return"allowHTMLPaste"in $options$jscomp$492$$&&$options$jscomp$492$$.allowHTMLPaste||$type$jscomp$428$$!=="text/html"?$allowedTypes$$module$app$util$clipboard$$.includes($type$jscomp$428$$):!1}};
$filterAllowedItems$$module$app$util$clipboard$$=function($options$jscomp$493$$){return function($item$jscomp$58$$){return"allowHTMLPaste"in $options$jscomp$493$$&&$options$jscomp$493$$.allowHTMLPaste||$item$jscomp$58$$.type!=="text/html"?$allowedTypes$$module$app$util$clipboard$$.includes($item$jscomp$58$$.type):!1}};$sortTypes$$module$app$util$clipboard$$=function($a$jscomp$384$$,$b$jscomp$314$$){return $allowedTypes$$module$app$util$clipboard$$.indexOf($a$jscomp$384$$)-$allowedTypes$$module$app$util$clipboard$$.indexOf($b$jscomp$314$$)};
$sortItems$$module$app$util$clipboard$$=function($a$jscomp$385$$,$b$jscomp$315$$){return $allowedTypes$$module$app$util$clipboard$$.indexOf($a$jscomp$385$$.type)-$allowedTypes$$module$app$util$clipboard$$.indexOf($b$jscomp$315$$.type)};
$fromDataTransfer$$module$app$util$clipboard$$=async function($dataTransfer$$,$options$jscomp$495$$){$options$jscomp$495$$=$options$jscomp$495$$||{};return(await Promise.all(Array.from($dataTransfer$$.items).filter($filterAllowedItems$$module$app$util$clipboard$$($options$jscomp$495$$)).sort($sortItems$$module$app$util$clipboard$$).map(async $item$jscomp$61$$=>$item$jscomp$61$$.kind==="file"?Promise.resolve($item$jscomp$61$$.getAsFile()):$item$jscomp$61$$.kind==="string"?new Promise($resolve$jscomp$30$$=>
{const $type$jscomp$430$$=$item$jscomp$61$$.type;$item$jscomp$61$$.getAsString($text$jscomp$42$$=>$type$jscomp$430$$==="text/plain"?$resolve$jscomp$30$$($parseText$$module$app$util$clipboard$$($text$jscomp$42$$,$options$jscomp$495$$)):$resolve$jscomp$30$$(new Blob([$text$jscomp$42$$],{type:$type$jscomp$430$$})))}):Promise.resolve(null)))).filter($item$jscomp$62$$=>!!$item$jscomp$62$$&&$item$jscomp$62$$.size>0).reduce(($filtered$$,$item$jscomp$63$$,$_index$$,$all$jscomp$4$$)=>{if($exclusiveTypes$$module$app$util$clipboard$$.includes($item$jscomp$63$$.type)&&
$filtered$$.find($filteredItem$$=>$exclusiveTypes$$module$app$util$clipboard$$.includes($filteredItem$$.type))||$item$jscomp$63$$.type!=="image/svg+xml"&&$item$jscomp$63$$.type.startsWith("image/")&&$hasSvgItem$$module$app$util$clipboard$$($all$jscomp$4$$))return $filtered$$;$filtered$$.push($item$jscomp$63$$);return $filtered$$},[])};
$APP.$app$util$clipboard$from_data_transfer$cljs$0core$0IFn$0_invoke$0arity$02$$=function($data_transfer$jscomp$1$$,$options$jscomp$498$$){return $APP.$beicon$v2$core$mapcat$$(function($p1__54193_SHARP_$$){return $APP.$beicon$v2$core$from$$($p1__54193_SHARP_$$)},$APP.$beicon$v2$core$from$$($module$app$util$clipboard$$.$fromDataTransfer$($data_transfer$jscomp$1$$,$options$jscomp$498$$)))};
$APP.$app$util$clipboard$from_navigator$cljs$0core$0IFn$0_invoke$0arity$01$$=function($options$jscomp$499$$){return $APP.$beicon$v2$core$mapcat$$(function($p1__54196_SHARP_$$){return $APP.$beicon$v2$core$from$$($p1__54196_SHARP_$$)},$APP.$beicon$v2$core$from$$($module$app$util$clipboard$$.$fromNavigator$($options$jscomp$499$$)))};$APP.$app$util$clipboard$to_clipboard$$=function($data$jscomp$275$$){return navigator.clipboard.writeText($data$jscomp$275$$)};
$APP.$app$util$clipboard$to_clipboard_promise$$=function($data$jscomp$276_mimetype$jscomp$1$$,$promise$jscomp$15$$){var $clipboard$jscomp$1$$=navigator.clipboard,$obj54217$jscomp$inline_12313$$={};$obj54217$jscomp$inline_12313$$[$data$jscomp$276_mimetype$jscomp$1$$]=$promise$jscomp$15$$;$data$jscomp$276_mimetype$jscomp$1$$=new ClipboardItem($obj54217$jscomp$inline_12313$$);return $clipboard$jscomp$1$$.write([$data$jscomp$276_mimetype$jscomp$1$$])};
$app$main$data$team$teams_fetched$$=function($teams$jscomp$1$$){typeof $app$main$data$team$teams_fetched_55394$$==="undefined"&&($app$main$data$team$teams_fetched_55394$$=function($teams$jscomp$2$$,$meta55395$$){this.teams=$teams$jscomp$2$$;this.$meta55395$=$meta55395$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$teams_fetched_55394$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$teams_fetched_55394$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3255$app_DOT_main_DOT_data_DOT_team_SLASH_teams_fetched$$},$app$main$data$team$teams_fetched_55394$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55396$$,$meta55395__$1$$){return new $app$main$data$team$teams_fetched_55394$$(this.teams,$meta55395__$1$$)},$app$main$data$team$teams_fetched_55394$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55395$},$app$main$data$team$teams_fetched_55394$$.prototype.$cljs$core$IDeref$_deref$arity$1$=
function(){return this.teams},$app$main$data$team$teams_fetched_55394$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$teams_fetched_55394$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1699_state__$1$jscomp$15$$,$state$jscomp$208$$){var $team_ids$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,this.teams);$_$jscomp$1699_state__$1$jscomp$15$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$208$$,
$APP.$cljs$cst$2173$teams$$,function($p1__55393_SHARP_$$){return $APP.$cljs$core$select_keys$$($p1__55393_SHARP_$$,$team_ids$$)});return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($state__$2$$,$id$jscomp$377_p__55397$$){var $G__55399$jscomp$inline_6194_map__55398__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$377_p__55397$$);$id$jscomp$377_p__55397$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__55399$jscomp$inline_6194_map__55398__$1$$,$APP.$cljs$cst$266$id$$);
var $organization_id_team_updated$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__55399$jscomp$inline_6194_map__55398__$1$$,$APP.$cljs$cst$3256$organization_id$$);$G__55399$jscomp$inline_6194_map__55398__$1$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state__$2$$,$APP.$cljs$cst$2173$teams$$),$id$jscomp$377_p__55397$$),
$G__55399$jscomp$inline_6194_map__55398__$1$$]));$organization_id_team_updated$$=$APP.$cljs$core$not$$($organization_id_team_updated$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__55399$jscomp$inline_6194_map__55398__$1$$,$APP.$cljs$cst$3256$organization_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3257$organization_name$$,$cljs$cst$3258$organization_slug$$,$cljs$cst$3259$organization_owner_id$$,$cljs$cst$3260$organization_avatar_bg_url$$])):
$G__55399$jscomp$inline_6194_map__55398__$1$$;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state__$2$$,$APP.$cljs$cst$2173$teams$$,$APP.$cljs$core$assoc$$,$id$jscomp$377_p__55397$$,$organization_id_team_updated$$)},$_$jscomp$1699_state__$1$jscomp$15$$,this.teams)});return new $app$main$data$team$teams_fetched_55394$$($teams$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$team$fetch_teams$$=function(){typeof $app$main$data$team$fetch_teams_55400$$==="undefined"&&($app$main$data$team$fetch_teams_55400$$=function($meta55401$$){this.$meta55401$=$meta55401$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$fetch_teams_55400$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$fetch_teams_55400$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3261$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_teams$$},
$app$main$data$team$fetch_teams_55400$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55402$$,$meta55401__$1$$){return new $app$main$data$team$fetch_teams_55400$$($meta55401__$1$$)},$app$main$data$team$fetch_teams_55400$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55401$},$app$main$data$team$fetch_teams_55400$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$fetch_teams_55400$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){return $APP.$beicon$v2$core$map$$($app$main$data$team$teams_fetched$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3262$get_teams$$))});return new $app$main$data$team$fetch_teams_55400$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$members_fetched$$=function($team_id$jscomp$28$$,$members$$){typeof $app$main$data$team$members_fetched_55407$$==="undefined"&&($app$main$data$team$members_fetched_55407$$=function($team_id$jscomp$29$$,$members$jscomp$1$$,$meta55408$$){this.$team_id$=$team_id$jscomp$29$$;this.$members$=$members$jscomp$1$$;this.$meta55408$=$meta55408$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$members_fetched_55407$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$members_fetched_55407$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3263$app_DOT_main_DOT_data_DOT_team_SLASH_members_fetched$$},$app$main$data$team$members_fetched_55407$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55409$$,$meta55408__$1$$){return new $app$main$data$team$members_fetched_55407$$(this.$team_id$,this.$members$,$meta55408__$1$$)},$app$main$data$team$members_fetched_55407$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55408$},$app$main$data$team$members_fetched_55407$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$members_fetched_55407$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1701$$,$state$jscomp$209$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$209$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2173$teams$$,this.$team_id$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3264$members$$,this.$members$),$APP.$cljs$cst$1915$profiles$$,$APP.$cljs$core$merge$$,$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,this.$members$))});return new $app$main$data$team$members_fetched_55407$$($team_id$jscomp$28$$,$members$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$=function($team_id$jscomp$30$$){typeof $app$main$data$team$fetch_members_55416$$==="undefined"&&($app$main$data$team$fetch_members_55416$$=function($team_id$jscomp$31$$,$meta55417$$){this.$team_id$=$team_id$jscomp$31$$;this.$meta55417$=$meta55417$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$fetch_members_55416$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$team$fetch_members_55416$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3265$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_members$$},$app$main$data$team$fetch_members_55416$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55418$$,$meta55417__$1$$){return new $app$main$data$team$fetch_members_55416$$(this.$team_id$,$meta55417__$1$$)},$app$main$data$team$fetch_members_55416$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55417$},
$app$main$data$team$fetch_members_55416$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$fetch_members_55416$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1702$$,$state$jscomp$210$$){var $self__$jscomp$3662$$=this,$temp__5825__auto__$jscomp$179$$=function(){var $or__5025__auto__$jscomp$615$$=$self__$jscomp$3662$$.$team_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$615$$)?$or__5025__auto__$jscomp$615$$:$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$210$$)}();
return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$179$$)?$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$54$$){var $map__55423__$1_type$jscomp$431$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$ex_data$$($cause$jscomp$54$$));$map__55423__$1_type$jscomp$431$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55423__$1_type$jscomp$431$$,$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2665$not_found$$,
$map__55423__$1_type$jscomp$431$$)?($APP.$app$common$logging$enabled_QMARK_$$("app.main.data.team",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"fetch-members: team not found, skipping"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1927$team_id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto__$jscomp$179$$)],null)],null)}),null,"app.main.data.team",$APP.$cljs$cst$1162$warn$$,!1),$APP.$beicon$v2$core$empty$$()):$APP.$beicon$v2$core$throw$0$$($cause$jscomp$54$$)},$APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$team$members_fetched$$,$temp__5825__auto__$jscomp$179$$),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3266$get_team_members$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$temp__5825__auto__$jscomp$179$$],null)))):null});return new $app$main$data$team$fetch_members_55416$$($team_id$jscomp$30$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$invitations_fetched$$=function($team_id$jscomp$32$$,$invitations$$){typeof $app$main$data$team$invitations_fetched_55424$$==="undefined"&&($app$main$data$team$invitations_fetched_55424$$=function($team_id$jscomp$33$$,$invitations$jscomp$1$$,$meta55425$$){this.$team_id$=$team_id$jscomp$33$$;this.$invitations$=$invitations$jscomp$1$$;this.$meta55425$=$meta55425$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$invitations_fetched_55424$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$invitations_fetched_55424$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3267$app_DOT_main_DOT_data_DOT_team_SLASH_invitations_fetched$$},$app$main$data$team$invitations_fetched_55424$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55426$$,$meta55425__$1$$){return new $app$main$data$team$invitations_fetched_55424$$(this.$team_id$,this.$invitations$,$meta55425__$1$$)},$app$main$data$team$invitations_fetched_55424$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55425$},$app$main$data$team$invitations_fetched_55424$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$invitations_fetched_55424$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1703$$,$state$jscomp$211$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$211$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2173$teams$$,
this.$team_id$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3268$invitations$$,this.$invitations$)});return new $app$main$data$team$invitations_fetched_55424$$($team_id$jscomp$32$$,$invitations$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$team$fetch_invitations$$=function(){typeof $app$main$data$team$fetch_invitations_55429$$==="undefined"&&($app$main$data$team$fetch_invitations_55429$$=function($meta55430$$){this.$meta55430$=$meta55430$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$fetch_invitations_55429$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$fetch_invitations_55429$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3269$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_invitations$$},$app$main$data$team$fetch_invitations_55429$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55431$$,$meta55430__$1$$){return new $app$main$data$team$fetch_invitations_55429$$($meta55430__$1$$)},$app$main$data$team$fetch_invitations_55429$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55430$},$app$main$data$team$fetch_invitations_55429$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$fetch_invitations_55429$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1704_team_id$jscomp$34$$,$state$jscomp$212$$){$_$jscomp$1704_team_id$jscomp$34$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$212$$);return $APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$team$invitations_fetched$$,$_$jscomp$1704_team_id$jscomp$34$$),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3270$get_team_invitations$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1704_team_id$jscomp$34$$],null)))});return new $app$main$data$team$fetch_invitations_55429$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$update_member_role$$=function($p__55448$$){var $map__55449__$1$$=$APP.$cljs$core$__destructure_map$$($p__55448$$),$role$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55449__$1$$,$APP.$cljs$cst$2490$role$$),$member_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55449__$1$$,$cljs$cst$3274$member_id$$);typeof $app$main$data$team$update_member_role_55450$$==="undefined"&&($app$main$data$team$update_member_role_55450$$=function($p__55448$jscomp$1$$,
$map__55449$jscomp$1$$,$params$jscomp$194$$,$role$jscomp$4$$,$member_id$jscomp$1$$,$meta55451$$){this.$p__55448$=$p__55448$jscomp$1$$;this.$map__55449$=$map__55449$jscomp$1$$;this.params=$params$jscomp$194$$;this.role=$role$jscomp$4$$;this.$member_id$=$member_id$jscomp$1$$;this.$meta55451$=$meta55451$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$update_member_role_55450$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$team$update_member_role_55450$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3275$app_DOT_main_DOT_data_DOT_team_SLASH_update_member_role$$},$app$main$data$team$update_member_role_55450$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55452$$,$meta55451__$1$$){return new $app$main$data$team$update_member_role_55450$$(this.$p__55448$,this.$map__55449$,this.params,this.role,this.$member_id$,$meta55451__$1$$)},$app$main$data$team$update_member_role_55450$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55451$},$app$main$data$team$update_member_role_55450$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$update_member_role_55450$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1710_params__$1$jscomp$22$$,$state$jscomp$216$$){var $self__$jscomp$3688$$=this,$team_id$jscomp$41$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$216$$);$_$jscomp$1710_params__$1$jscomp$22$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$3688$$.params,$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$41$$);return $APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$profile$refresh_profile$$(),$APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$41$$),$APP.$app$main$data$team$fetch_teams$$(),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"update-team-member-role",$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$41$$,$APP.$cljs$cst$2490$role$$,$self__$jscomp$3688$$.role,$cljs$cst$3274$member_id$$,$self__$jscomp$3688$$.$member_id$],null)))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3276$update_team_member_role$$,$_$jscomp$1710_params__$1$jscomp$22$$))});return new $app$main$data$team$update_member_role_55450$$($p__55448$$,$map__55449__$1$$,$map__55449__$1$$,$role$jscomp$3$$,$member_id$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$delete_member$$=function($p__55453$$){var $map__55454__$1$$=$APP.$cljs$core$__destructure_map$$($p__55453$$),$member_id$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55454__$1$$,$cljs$cst$3274$member_id$$);typeof $app$main$data$team$delete_member_55455$$==="undefined"&&($app$main$data$team$delete_member_55455$$=function($p__55453$jscomp$1$$,$map__55454$jscomp$1$$,$params$jscomp$196$$,$member_id$jscomp$3$$,$meta55456$$){this.$p__55453$=$p__55453$jscomp$1$$;
this.$map__55454$=$map__55454$jscomp$1$$;this.params=$params$jscomp$196$$;this.$member_id$=$member_id$jscomp$3$$;this.$meta55456$=$meta55456$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$delete_member_55455$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$delete_member_55455$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3277$app_DOT_main_DOT_data_DOT_team_SLASH_delete_member$$},
$app$main$data$team$delete_member_55455$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55457$$,$meta55456__$1$$){return new $app$main$data$team$delete_member_55455$$(this.$p__55453$,this.$map__55454$,this.params,this.$member_id$,$meta55456__$1$$)},$app$main$data$team$delete_member_55455$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55456$},$app$main$data$team$delete_member_55455$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$team$delete_member_55455$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1711_params__$1$jscomp$23$$,$state$jscomp$217$$){var $self__$jscomp$3692$$=this,$team_id$jscomp$42$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$217$$);$_$jscomp$1711_params__$1$jscomp$23$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$3692$$.params,$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$42$$);return $APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$profile$refresh_profile$$(),
$APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$42$$),$APP.$app$main$data$team$fetch_teams$$(),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-team-member",$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$42$$,$cljs$cst$3274$member_id$$,$self__$jscomp$3692$$.$member_id$],null)))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3278$delete_team_member$$,
$_$jscomp$1711_params__$1$jscomp$23$$))});return new $app$main$data$team$delete_member_55455$$($p__55453$$,$map__55454__$1$$,$map__55454__$1$$,$member_id$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$webhooks_fetched$$=function($team_id$jscomp$46$$,$webhooks$$){typeof $app$main$data$team$webhooks_fetched_55475$$==="undefined"&&($app$main$data$team$webhooks_fetched_55475$$=function($team_id$jscomp$47$$,$webhooks$jscomp$1$$,$meta55476$$){this.$team_id$=$team_id$jscomp$47$$;this.webhooks=$webhooks$jscomp$1$$;this.$meta55476$=$meta55476$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$webhooks_fetched_55475$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$webhooks_fetched_55475$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3283$app_DOT_main_DOT_data_DOT_team_SLASH_webhooks_fetched$$},$app$main$data$team$webhooks_fetched_55475$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55477$$,$meta55476__$1$$){return new $app$main$data$team$webhooks_fetched_55475$$(this.$team_id$,this.webhooks,$meta55476__$1$$)},$app$main$data$team$webhooks_fetched_55475$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55476$},$app$main$data$team$webhooks_fetched_55475$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$webhooks_fetched_55475$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1714$$,$state$jscomp$220$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$220$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2173$teams$$,
this.$team_id$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1215$webhooks$$,this.webhooks)});return new $app$main$data$team$webhooks_fetched_55475$$($team_id$jscomp$46$$,$webhooks$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$team$fetch_webhooks$$=function(){typeof $app$main$data$team$fetch_webhooks_55480$$==="undefined"&&($app$main$data$team$fetch_webhooks_55480$$=function($meta55481$$){this.$meta55481$=$meta55481$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$fetch_webhooks_55480$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$fetch_webhooks_55480$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3284$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_webhooks$$},$app$main$data$team$fetch_webhooks_55480$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55482$$,$meta55481__$1$$){return new $app$main$data$team$fetch_webhooks_55480$$($meta55481__$1$$)},$app$main$data$team$fetch_webhooks_55480$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55481$},$app$main$data$team$fetch_webhooks_55480$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$team$fetch_webhooks_55480$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1715_team_id$jscomp$48$$,$state$jscomp$221$$){$_$jscomp$1715_team_id$jscomp$48$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$221$$);return $APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$team$webhooks_fetched$$,$_$jscomp$1715_team_id$jscomp$48$$),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3285$get_webhooks$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1715_team_id$jscomp$48$$],null)))});return new $app$main$data$team$fetch_webhooks_55480$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$team$team_created$$=function($team$jscomp$5$$){typeof $app$main$data$team$team_created_55529$$==="undefined"&&($app$main$data$team$team_created_55529$$=function($team$jscomp$6$$,$meta55530$$){this.team=$team$jscomp$6$$;this.$meta55530$=$meta55530$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$team_created_55529$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$team_created_55529$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3287$app_DOT_main_DOT_data_DOT_team_SLASH_team_created$$},$app$main$data$team$team_created_55529$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55531$$,$meta55530__$1$$){return new $app$main$data$team$team_created_55529$$(this.team,$meta55530__$1$$)},$app$main$data$team$team_created_55529$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55530$},$app$main$data$team$team_created_55529$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.team});
return new $app$main$data$team$team_created_55529$$($team$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$team$create_team$$=function($p__55540$$){var $map__55541__$1$$=$APP.$cljs$core$__destructure_map$$($p__55540$$),$name$jscomp$271$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55541__$1$$,$APP.$cljs$cst$725$name$$),$organization_id$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55541__$1$$,$APP.$cljs$cst$3256$organization_id$$);typeof $app$main$data$team$create_team_55543$$==="undefined"&&($app$main$data$team$create_team_55543$$=function($p__55540$jscomp$1$$,
$map__55541$jscomp$1$$,$params$jscomp$198$$,$name$jscomp$272$$,$organization_id$jscomp$2$$,$meta55544$$){this.$p__55540$=$p__55540$jscomp$1$$;this.$map__55541$=$map__55541$jscomp$1$$;this.params=$params$jscomp$198$$;this.name=$name$jscomp$272$$;this.$organization_id$=$organization_id$jscomp$2$$;this.$meta55544$=$meta55544$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$create_team_55543$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$team$create_team_55543$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3288$app_DOT_main_DOT_data_DOT_team_SLASH_create_team$$},$app$main$data$team$create_team_55543$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55545$$,$meta55544__$1$$){return new $app$main$data$team$create_team_55543$$(this.$p__55540$,this.$map__55541$,this.params,this.name,this.$organization_id$,$meta55544__$1$$)},$app$main$data$team$create_team_55543$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55544$},$app$main$data$team$create_team_55543$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$create_team_55543$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__55565_on_success$jscomp$11$$=$APP.$cljs$core$meta$$(this.params),$map__55565__$1_on_error$jscomp$15$$=$APP.$cljs$core$__destructure_map$$($map__55565_on_success$jscomp$11$$);$map__55565_on_success$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55565__$1_on_error$jscomp$15$$,
$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);$map__55565__$1_on_error$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55565__$1_on_error$jscomp$15$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);var $G__55566$jscomp$inline_6196_params__$1$jscomp$24$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,this.name,$APP.$cljs$cst$227$features$$,$APP.$app$main$features$global_enabled_features$$],null);$G__55566$jscomp$inline_6196_params__$1$jscomp$24$$=
$APP.$cljs$core$truth_$$(this.$organization_id$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__55566$jscomp$inline_6196_params__$1$jscomp$24$$,$APP.$cljs$cst$3256$organization_id$$,this.$organization_id$):$G__55566$jscomp$inline_6196_params__$1$jscomp$24$$;return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55565__$1_on_error$jscomp$15$$,$APP.$beicon$v2$core$map$$($APP.$app$main$data$team$team_created$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55565_on_success$jscomp$11$$,
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3289$create_team$$,$APP.$cljs$core$with_meta$$($G__55566$jscomp$inline_6196_params__$1$jscomp$24$$,$APP.$cljs$core$meta$$(this))))))});return new $app$main$data$team$create_team_55543$$($p__55540$$,$map__55541__$1$$,$map__55541__$1$$,$name$jscomp$271$$,$organization_id$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$update_team$$=function($p__55573$$){var $map__55574__$1$$=$APP.$cljs$core$__destructure_map$$($p__55573$$),$id$jscomp$378$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55574__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$275$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55574__$1$$,$APP.$cljs$cst$725$name$$);typeof $app$main$data$team$update_team_55575$$==="undefined"&&($app$main$data$team$update_team_55575$$=function($p__55573$jscomp$1$$,$map__55574$jscomp$1$$,
$params$jscomp$202$$,$id$jscomp$379$$,$name$jscomp$276$$,$meta55576$$){this.$p__55573$=$p__55573$jscomp$1$$;this.$map__55574$=$map__55574$jscomp$1$$;this.params=$params$jscomp$202$$;this.id=$id$jscomp$379$$;this.name=$name$jscomp$276$$;this.$meta55576$=$meta55576$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$update_team_55575$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$update_team_55575$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3293$app_DOT_main_DOT_data_DOT_team_SLASH_update_team$$},$app$main$data$team$update_team_55575$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55577$$,$meta55576__$1$$){return new $app$main$data$team$update_team_55575$$(this.$p__55573$,this.$map__55574$,this.params,this.id,this.name,$meta55576__$1$$)},$app$main$data$team$update_team_55575$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55576$},$app$main$data$team$update_team_55575$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$update_team_55575$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1720$$,$state$jscomp$223$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$223$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2173$teams$$,this.id,$APP.$cljs$cst$725$name$$],null),this.name)},$app$main$data$team$update_team_55575$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$team$update_team_55575$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3294$update_team$$,this.params))});return new $app$main$data$team$update_team_55575$$($p__55573$$,$map__55574__$1$$,$map__55574__$1$$,$id$jscomp$378$$,$name$jscomp$275$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$team_leaved$$=function($p__55578$$){var $map__55579__$1$$=$APP.$cljs$core$__destructure_map$$($p__55578$$),$id$jscomp$380$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55579__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$team$team_leaved_55580$$==="undefined"&&($app$main$data$team$team_leaved_55580$$=function($p__55578$jscomp$1$$,$map__55579$jscomp$1$$,$params$jscomp$204$$,$id$jscomp$381$$,$meta55581$$){this.$p__55578$=$p__55578$jscomp$1$$;this.$map__55579$=
$map__55579$jscomp$1$$;this.params=$params$jscomp$204$$;this.id=$id$jscomp$381$$;this.$meta55581$=$meta55581$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$team_leaved_55580$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$team_leaved_55580$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3295$app_DOT_main_DOT_data_DOT_team_SLASH_team_leaved$$},$app$main$data$team$team_leaved_55580$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55582$$,$meta55581__$1$$){return new $app$main$data$team$team_leaved_55580$$(this.$p__55578$,this.$map__55579$,this.params,this.id,$meta55581__$1$$)},$app$main$data$team$team_leaved_55580$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55581$},$app$main$data$team$team_leaved_55580$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.params},$app$main$data$team$team_leaved_55580$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$team$team_leaved_55580$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1723$$,$state$jscomp$224$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$224$$,$APP.$cljs$cst$2173$teams$$,$APP.$cljs$core$dissoc$$,this.id)},$app$main$data$team$team_leaved_55580$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$team_leaved_55580$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1724_teams$jscomp$4$$,
$state$jscomp$225_temp__5825__auto__$jscomp$180$$){$_$jscomp$1724_teams$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$225_temp__5825__auto__$jscomp$180$$,$APP.$cljs$cst$2173$teams$$);$state$jscomp$225_temp__5825__auto__$jscomp$180$$=$APP.$cljs$cst$3254$app_DOT_main_DOT_data_DOT_team_SLASH_current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$user$$);return $APP.$cljs$core$truth_$$($state$jscomp$225_temp__5825__auto__$jscomp$180$$)?$APP.$cljs$core$contains_QMARK_$$($_$jscomp$1724_teams$jscomp$4$$,
$state$jscomp$225_temp__5825__auto__$jscomp$180$$)?null:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$user$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3254$app_DOT_main_DOT_data_DOT_team_SLASH_current_team_id$$):null});return new $app$main$data$team$team_leaved_55580$$($p__55578$$,$map__55579__$1$$,$map__55579__$1$$,$id$jscomp$380$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$leave_current_team$$=function($p__55593$$){var $map__55594__$1$$=$APP.$cljs$core$__destructure_map$$($p__55593$$),$reassign_to$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55594__$1$$,$cljs$cst$3296$reassign_to$$);typeof $app$main$data$team$leave_current_team_55595$$==="undefined"&&($app$main$data$team$leave_current_team_55595$$=function($p__55593$jscomp$1$$,$map__55594$jscomp$1$$,$params$jscomp$206$$,$reassign_to$jscomp$1$$,$meta55596$$){this.$p__55593$=$p__55593$jscomp$1$$;
this.$map__55594$=$map__55594$jscomp$1$$;this.params=$params$jscomp$206$$;this.$reassign_to$=$reassign_to$jscomp$1$$;this.$meta55596$=$meta55596$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$leave_current_team_55595$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$leave_current_team_55595$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3297$app_DOT_main_DOT_data_DOT_team_SLASH_leave_current_team$$},
$app$main$data$team$leave_current_team_55595$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55597$$,$meta55596__$1$$){return new $app$main$data$team$leave_current_team_55595$$(this.$p__55593$,this.$map__55594$,this.params,this.$reassign_to$,$meta55596__$1$$)},$app$main$data$team$leave_current_team_55595$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55596$},$app$main$data$team$leave_current_team_55595$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$team$leave_current_team_55595$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1725_map__55599_map__55599__$1$$,$on_error$jscomp$17_state$jscomp$226$$){var $self__$jscomp$3739$$=this,$team_id$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($on_error$jscomp$17_state$jscomp$226$$,$APP.$cljs$cst$1926$current_team_id$$),$params__$1$jscomp$26$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$3739$$.params,$APP.$cljs$cst$266$id$$,
$team_id$jscomp$50$$);$_$jscomp$1725_map__55599_map__55599__$1$$=$APP.$cljs$core$meta$$($params__$1$jscomp$26$$);$_$jscomp$1725_map__55599_map__55599__$1$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$1725_map__55599_map__55599__$1$$);$on_error$jscomp$17_state$jscomp$226$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$1725_map__55599_map__55599__$1$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);var $on_success$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$1725_map__55599_map__55599__$1$$,
$APP.$cljs$cst$2488$on_success$$,$APP.$beicon$v2$core$empty$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($on_error$jscomp$17_state$jscomp$226$$,$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$team$team_leaved$$($params__$1$jscomp$26$$),$APP.$app$main$data$team$fetch_teams$$(),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"leave-team",$cljs$cst$3296$reassign_to$$,$self__$jscomp$3739$$.$reassign_to$,$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$50$$],null))),$on_success$jscomp$13$$.$cljs$core$IFn$_invoke$arity$0$?$on_success$jscomp$13$$.$cljs$core$IFn$_invoke$arity$0$():$on_success$jscomp$13$$())},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3298$leave_team$$,$params__$1$jscomp$26$$)))});return new $app$main$data$team$leave_current_team_55595$$($p__55593$$,$map__55594__$1$$,$map__55594__$1$$,
$reassign_to$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$team$create_invitations$$=function($p__55600$$){var $map__55601__$1$$=$APP.$cljs$core$__destructure_map$$($p__55600$$),$emails$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55601__$1$$,$APP.$cljs$cst$3290$emails$$),$role$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55601__$1$$,$APP.$cljs$cst$2490$role$$),$team_id$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55601__$1$$,$APP.$cljs$cst$1927$team_id$$),
$invitations$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55601__$1$$,$APP.$cljs$cst$3268$invitations$$),$resend_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55601__$1$$,$APP.$cljs$cst$3299$resend_QMARK_$$);$app$main$data$team$check_create_invitations_params$$($map__55601__$1$$);typeof $app$main$data$team$create_invitations_55602$$==="undefined"&&($app$main$data$team$create_invitations_55602$$=function($p__55600$jscomp$1$$,$map__55601$jscomp$1$$,$params$jscomp$208$$,
$emails$jscomp$3$$,$role$jscomp$8$$,$team_id$jscomp$52$$,$invitations$jscomp$3$$,$resend_QMARK_$jscomp$1$$,$meta55603$$){this.$p__55600$=$p__55600$jscomp$1$$;this.$map__55601$=$map__55601$jscomp$1$$;this.params=$params$jscomp$208$$;this.$emails$=$emails$jscomp$3$$;this.role=$role$jscomp$8$$;this.$team_id$=$team_id$jscomp$52$$;this.$invitations$=$invitations$jscomp$3$$;this.$resend_QMARK_$=$resend_QMARK_$jscomp$1$$;this.$meta55603$=$meta55603$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$team$create_invitations_55602$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$create_invitations_55602$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3300$app_DOT_main_DOT_data_DOT_team_SLASH_create_invitations$$},$app$main$data$team$create_invitations_55602$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55604$$,$meta55603__$1$$){return new $app$main$data$team$create_invitations_55602$$(this.$p__55600$,
this.$map__55601$,this.params,this.$emails$,this.role,this.$team_id$,this.$invitations$,this.$resend_QMARK_$,$meta55603__$1$$)},$app$main$data$team$create_invitations_55602$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55603$},$app$main$data$team$create_invitations_55602$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$create_invitations_55602$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2490$role$$,$APP.$cljs$core$truth_$$(this.$invitations$)?$APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$name$$,$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2490$role$$,this.$invitations$)))):$APP.$cljs$core$name$$(this.role),$APP.$cljs$cst$1927$team_id$$,this.$team_id$,$cljs$cst$3301$resend$$,$APP.$cljs$core$boolean$0$$(this.$resend_QMARK_$)],
null)},$app$main$data$team$create_invitations_55602$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$create_invitations_55602$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__55605_on_success$jscomp$14$$=$APP.$cljs$core$meta$$(this.params),$map__55605__$1_on_error$jscomp$18$$=$APP.$cljs$core$__destructure_map$$($map__55605_on_success$jscomp$14$$);$map__55605_on_success$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55605__$1_on_error$jscomp$18$$,
$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);$map__55605__$1_on_error$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55605__$1_on_error$jscomp$18$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);var $JSCompiler_temp$jscomp$1069_JSCompiler_temp$jscomp$1070_and__5023__auto__$jscomp$inline_12315$$=this.$emails$;if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1069_JSCompiler_temp$jscomp$1070_and__5023__auto__$jscomp$inline_12315$$)?
this.role:$JSCompiler_temp$jscomp$1069_JSCompiler_temp$jscomp$1070_and__5023__auto__$jscomp$inline_12315$$))$JSCompiler_temp$jscomp$1069_JSCompiler_temp$jscomp$1070_and__5023__auto__$jscomp$inline_12315$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3290$emails$$,this.$emails$,$APP.$cljs$cst$2490$role$$,this.role,$APP.$cljs$cst$1927$team_id$$,this.$team_id$],null);else if($APP.$cljs$core$truth_$$(this.$invitations$))$JSCompiler_temp$jscomp$1069_JSCompiler_temp$jscomp$1070_and__5023__auto__$jscomp$inline_12315$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3268$invitations$$,this.$invitations$,$APP.$cljs$cst$1927$team_id$$,this.$team_id$],null);else throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$(" Invalid parameters ",this.params);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55605__$1_on_error$jscomp$18$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55605_on_success$jscomp$14$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3302$create_team_invitations$$,
$APP.$cljs$core$with_meta$$($JSCompiler_temp$jscomp$1069_JSCompiler_temp$jscomp$1070_and__5023__auto__$jscomp$inline_12315$$,$APP.$cljs$core$meta$$(this)))))});return new $app$main$data$team$create_invitations_55602$$($p__55600$$,$map__55601__$1$$,$map__55601__$1$$,$emails$jscomp$2$$,$role$jscomp$7$$,$team_id$jscomp$51$$,$invitations$jscomp$2$$,$resend_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$copy_invitation_link$$=function($p__55606$$){var $map__55607__$1$$=$APP.$cljs$core$__destructure_map$$($p__55606$$),$email$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55607__$1$$,$APP.$cljs$cst$3183$email$$),$team_id$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55607__$1$$,$APP.$cljs$cst$1927$team_id$$);typeof $app$main$data$team$copy_invitation_link_55608$$==="undefined"&&($app$main$data$team$copy_invitation_link_55608$$=function($p__55606$jscomp$1$$,
$map__55607$jscomp$1$$,$params$jscomp$210$$,$email$jscomp$3$$,$team_id$jscomp$54$$,$meta55609$$){this.$p__55606$=$p__55606$jscomp$1$$;this.$map__55607$=$map__55607$jscomp$1$$;this.params=$params$jscomp$210$$;this.email=$email$jscomp$3$$;this.$team_id$=$team_id$jscomp$54$$;this.$meta55609$=$meta55609$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$copy_invitation_link_55608$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$team$copy_invitation_link_55608$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3303$app_DOT_main_DOT_data_DOT_team_SLASH_copy_invitation_link$$},$app$main$data$team$copy_invitation_link_55608$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55610$$,$meta55609__$1$$){return new $app$main$data$team$copy_invitation_link_55608$$(this.$p__55606$,this.$map__55607$,this.params,this.email,this.$team_id$,$meta55609__$1$$)},$app$main$data$team$copy_invitation_link_55608$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55609$},$app$main$data$team$copy_invitation_link_55608$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3183$email$$,this.email,$APP.$cljs$cst$1927$team_id$$,this.$team_id$],null)},$app$main$data$team$copy_invitation_link_55608$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$copy_invitation_link_55608$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1729_map__55611_on_success$jscomp$15$$,$state$jscomp$227$$){$_$jscomp$1729_map__55611_on_success$jscomp$15$$=$APP.$cljs$core$meta$$(this.params);var $map__55611__$1_on_error$jscomp$19$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$1729_map__55611_on_success$jscomp$15$$);$_$jscomp$1729_map__55611_on_success$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55611__$1_on_error$jscomp$19$$,$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);$map__55611__$1_on_error$jscomp$19$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55611__$1_on_error$jscomp$19$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);var $router$jscomp$6$$=$APP.$cljs$cst$2172$router$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$227$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55611__$1_on_error$jscomp$19$$,$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$1729_map__55611_on_success$jscomp$15$$,
$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($uri$jscomp$80$$){return $APP.$app$util$clipboard$to_clipboard$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($uri$jscomp$80$$))},$APP.$beicon$v2$core$map$$(function($fragment$jscomp$11$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$config$public_uri$$,$APP.$cljs$cst$738$fragment$$,$fragment$jscomp$11$$)},$APP.$beicon$v2$core$map$$(function($params__$1$jscomp$27$$){return $APP.$app$main$router$resolve$cljs$0core$0IFn$0_invoke$0arity$03$$($router$jscomp$6$$,
$APP.$cljs$cst$3304$auth_verify_token$$,$params__$1$jscomp$27$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3305$get_team_invitation_token$$,this.params)))))))});return new $app$main$data$team$copy_invitation_link_55608$$($p__55606$$,$map__55607__$1$$,$map__55607__$1$$,$email$jscomp$2$$,$team_id$jscomp$53$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$update_invitation_role$$=function($p__55612$$){var $map__55613__$1$$=$APP.$cljs$core$__destructure_map$$($p__55612$$),$email$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55613__$1$$,$APP.$cljs$cst$3183$email$$),$team_id$jscomp$55$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55613__$1$$,$APP.$cljs$cst$1927$team_id$$),$role$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55613__$1$$,$APP.$cljs$cst$2490$role$$);typeof $app$main$data$team$update_invitation_role_55614$$===
"undefined"&&($app$main$data$team$update_invitation_role_55614$$=function($p__55612$jscomp$1$$,$map__55613$jscomp$1$$,$params$jscomp$212$$,$email$jscomp$5$$,$team_id$jscomp$56$$,$role$jscomp$10$$,$meta55615$$){this.$p__55612$=$p__55612$jscomp$1$$;this.$map__55613$=$map__55613$jscomp$1$$;this.params=$params$jscomp$212$$;this.email=$email$jscomp$5$$;this.$team_id$=$team_id$jscomp$56$$;this.role=$role$jscomp$10$$;this.$meta55615$=$meta55615$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$team$update_invitation_role_55614$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$update_invitation_role_55614$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3306$app_DOT_main_DOT_data_DOT_team_SLASH_update_invitation_role$$},$app$main$data$team$update_invitation_role_55614$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55616$$,$meta55615__$1$$){return new $app$main$data$team$update_invitation_role_55614$$(this.$p__55612$,
this.$map__55613$,this.params,this.email,this.$team_id$,this.role,$meta55615__$1$$)},$app$main$data$team$update_invitation_role_55614$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55615$},$app$main$data$team$update_invitation_role_55614$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2490$role$$,this.role],null)},$app$main$data$team$update_invitation_role_55614$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$update_invitation_role_55614$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__55617_on_success$jscomp$16$$=$APP.$cljs$core$meta$$(this.params),$map__55617__$1_on_error$jscomp$20$$=$APP.$cljs$core$__destructure_map$$($map__55617_on_success$jscomp$16$$);$map__55617_on_success$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55617__$1_on_error$jscomp$20$$,$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);
$map__55617__$1_on_error$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55617__$1_on_error$jscomp$20$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55617__$1_on_error$jscomp$20$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55617_on_success$jscomp$16$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3307$update_team_invitation_role$$,
this.params)))});return new $app$main$data$team$update_invitation_role_55614$$($p__55612$$,$map__55613__$1$$,$map__55613__$1$$,$email$jscomp$4$$,$team_id$jscomp$55$$,$role$jscomp$9$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$team_deleted$$=function($id$jscomp$382$$){typeof $app$main$data$team$team_deleted_55624$$==="undefined"&&($app$main$data$team$team_deleted_55624$$=function($id$jscomp$383$$,$meta55625$$){this.id=$id$jscomp$383$$;this.$meta55625$=$meta55625$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$team_deleted_55624$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$team_deleted_55624$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3310$app_DOT_main_DOT_data_DOT_team_SLASH_team_deleted$$},$app$main$data$team$team_deleted_55624$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55626$$,$meta55625__$1$$){return new $app$main$data$team$team_deleted_55624$$(this.id,$meta55625__$1$$)},$app$main$data$team$team_deleted_55624$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55625$},$app$main$data$team$team_deleted_55624$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$team$team_deleted_55624$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1733$$,$state$jscomp$228$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$228$$,$APP.$cljs$cst$2173$teams$$,$APP.$cljs$core$dissoc$$,this.id)});return new $app$main$data$team$team_deleted_55624$$($id$jscomp$382$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$delete_team$$=function($p__55627$$){var $map__55628__$1$$=$APP.$cljs$core$__destructure_map$$($p__55627$$),$id$jscomp$384$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55628__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$team$delete_team_55629$$==="undefined"&&($app$main$data$team$delete_team_55629$$=function($p__55627$jscomp$1$$,$map__55628$jscomp$1$$,$params$jscomp$216$$,$id$jscomp$385$$,$meta55630$$){this.$p__55627$=$p__55627$jscomp$1$$;this.$map__55628$=
$map__55628$jscomp$1$$;this.params=$params$jscomp$216$$;this.id=$id$jscomp$385$$;this.$meta55630$=$meta55630$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$delete_team_55629$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$delete_team_55629$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3311$app_DOT_main_DOT_data_DOT_team_SLASH_delete_team$$},$app$main$data$team$delete_team_55629$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55631$$,$meta55630__$1$$){return new $app$main$data$team$delete_team_55629$$(this.$p__55627$,this.$map__55628$,this.params,this.id,$meta55630__$1$$)},$app$main$data$team$delete_team_55629$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55630$},$app$main$data$team$delete_team_55629$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$delete_team_55629$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$3766$$=
this,$map__55632_map__55632__$1_on_error$jscomp$22$$=$APP.$cljs$core$meta$$($self__$jscomp$3766$$.params);$map__55632_map__55632__$1_on_error$jscomp$22$$=$APP.$cljs$core$__destructure_map$$($map__55632_map__55632__$1_on_error$jscomp$22$$);var $on_success$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55632_map__55632__$1_on_error$jscomp$22$$,$APP.$cljs$cst$2488$on_success$$,$APP.$beicon$v2$core$empty$$);$map__55632_map__55632__$1_on_error$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55632_map__55632__$1_on_error$jscomp$22$$,
$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55632_map__55632__$1_on_error$jscomp$22$$,$APP.$beicon$v2$core$mapcat$$(function($result$jscomp$261$$){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$team$team_deleted$$($self__$jscomp$3766$$.id)),$on_success$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$?$on_success$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$261$$):
$on_success$jscomp$18$$($result$jscomp$261$$))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3312$delete_team$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$self__$jscomp$3766$$.id],null))))});return new $app$main$data$team$delete_team_55629$$($p__55627$$,$map__55628__$1$$,$map__55628__$1$$,$id$jscomp$384$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$delete_webhook$$=function($p__55633$$){var $map__55634__$1$$=$APP.$cljs$core$__destructure_map$$($p__55633$$),$id$jscomp$386$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55634__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$team$delete_webhook_55635$$==="undefined"&&($app$main$data$team$delete_webhook_55635$$=function($p__55633$jscomp$1$$,$map__55634$jscomp$1$$,$params$jscomp$218$$,$id$jscomp$387$$,$meta55636$$){this.$p__55633$=$p__55633$jscomp$1$$;this.$map__55634$=
$map__55634$jscomp$1$$;this.params=$params$jscomp$218$$;this.id=$id$jscomp$387$$;this.$meta55636$=$meta55636$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$delete_webhook_55635$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$delete_webhook_55635$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3313$app_DOT_main_DOT_data_DOT_team_SLASH_delete_webhook$$},$app$main$data$team$delete_webhook_55635$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55637$$,$meta55636__$1$$){return new $app$main$data$team$delete_webhook_55635$$(this.$p__55633$,this.$map__55634$,this.params,this.id,$meta55636__$1$$)},$app$main$data$team$delete_webhook_55635$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55636$},$app$main$data$team$delete_webhook_55635$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$delete_webhook_55635$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1735_params__$1$jscomp$28_team_id$jscomp$59$$,
$map__55638_on_success$jscomp$19_state$jscomp$229$$){$_$jscomp$1735_params__$1$jscomp$28_team_id$jscomp$59$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($map__55638_on_success$jscomp$19_state$jscomp$229$$);$_$jscomp$1735_params__$1$jscomp$28_team_id$jscomp$59$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.params,$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1735_params__$1$jscomp$28_team_id$jscomp$59$$);$map__55638_on_success$jscomp$19_state$jscomp$229$$=$APP.$cljs$core$meta$$($_$jscomp$1735_params__$1$jscomp$28_team_id$jscomp$59$$);
var $map__55638__$1_on_error$jscomp$23$$=$APP.$cljs$core$__destructure_map$$($map__55638_on_success$jscomp$19_state$jscomp$229$$);$map__55638_on_success$jscomp$19_state$jscomp$229$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55638__$1_on_error$jscomp$23$$,$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);$map__55638__$1_on_error$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55638__$1_on_error$jscomp$23$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);
return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55638__$1_on_error$jscomp$23$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55638_on_success$jscomp$19_state$jscomp$229$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3314$delete_webhook$$,$_$jscomp$1735_params__$1$jscomp$28_team_id$jscomp$59$$)))});return new $app$main$data$team$delete_webhook_55635$$($p__55633$$,$map__55634__$1$$,$map__55634__$1$$,$id$jscomp$386$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$update_webhook$$=function($p__55644$$){var $map__55645__$1$$=$APP.$cljs$core$__destructure_map$$($p__55644$$),$id$jscomp$388$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55645__$1$$,$APP.$cljs$cst$266$id$$),$uri$jscomp$81$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55645__$1$$,$APP.$cljs$cst$1579$uri$$),$mtype$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55645__$1$$,$APP.$cljs$cst$1726$mtype$$),$is_active$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55645__$1$$,
$APP.$cljs$cst$3315$is_active$$);typeof $app$main$data$team$update_webhook_55647$$==="undefined"&&($app$main$data$team$update_webhook_55647$$=function($p__55644$jscomp$1$$,$map__55645$jscomp$1$$,$params$jscomp$220$$,$id$jscomp$389$$,$uri$jscomp$82$$,$mtype$jscomp$9$$,$is_active$jscomp$1$$,$meta55648$$){this.$p__55644$=$p__55644$jscomp$1$$;this.$map__55645$=$map__55645$jscomp$1$$;this.params=$params$jscomp$220$$;this.id=$id$jscomp$389$$;this.uri=$uri$jscomp$82$$;this.$mtype$=$mtype$jscomp$9$$;this.$is_active$=
$is_active$jscomp$1$$;this.$meta55648$=$meta55648$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$update_webhook_55647$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$update_webhook_55647$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3316$app_DOT_main_DOT_data_DOT_team_SLASH_update_webhook$$},$app$main$data$team$update_webhook_55647$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55649$$,$meta55648__$1$$){return new $app$main$data$team$update_webhook_55647$$(this.$p__55644$,this.$map__55645$,this.params,this.id,this.uri,this.$mtype$,this.$is_active$,$meta55648__$1$$)},$app$main$data$team$update_webhook_55647$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55648$},$app$main$data$team$update_webhook_55647$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$update_webhook_55647$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1736_params__$1$jscomp$29_team_id$jscomp$60$$,$map__55650_map__55650__$1_on_error$jscomp$24_state$jscomp$230$$){$_$jscomp$1736_params__$1$jscomp$29_team_id$jscomp$60$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($map__55650_map__55650__$1_on_error$jscomp$24_state$jscomp$230$$);$_$jscomp$1736_params__$1$jscomp$29_team_id$jscomp$60$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.params,$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1736_params__$1$jscomp$29_team_id$jscomp$60$$);
$map__55650_map__55650__$1_on_error$jscomp$24_state$jscomp$230$$=$APP.$cljs$core$meta$$($_$jscomp$1736_params__$1$jscomp$29_team_id$jscomp$60$$);$map__55650_map__55650__$1_on_error$jscomp$24_state$jscomp$230$$=$APP.$cljs$core$__destructure_map$$($map__55650_map__55650__$1_on_error$jscomp$24_state$jscomp$230$$);var $on_success$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55650_map__55650__$1_on_error$jscomp$24_state$jscomp$230$$,$APP.$cljs$cst$2488$on_success$$,$APP.$beicon$v2$core$empty$$);
$map__55650_map__55650__$1_on_error$jscomp$24_state$jscomp$230$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55650_map__55650__$1_on_error$jscomp$24_state$jscomp$230$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55650_map__55650__$1_on_error$jscomp$24_state$jscomp$230$$,$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$beicon$v2$core$concat$$($on_success$jscomp$20$$.$cljs$core$IFn$_invoke$arity$0$?
$on_success$jscomp$20$$.$cljs$core$IFn$_invoke$arity$0$():$on_success$jscomp$20$$(),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$fetch_webhooks$$()))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3317$update_webhook$$,$_$jscomp$1736_params__$1$jscomp$29_team_id$jscomp$60$$)))});return new $app$main$data$team$update_webhook_55647$$($p__55644$$,$map__55645__$1$$,$map__55645__$1$$,$id$jscomp$388$$,$uri$jscomp$81$$,$mtype$jscomp$8$$,$is_active$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$create_webhook$$=function($p__55655$$){var $map__55656__$1$$=$APP.$cljs$core$__destructure_map$$($p__55655$$),$uri$jscomp$83$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55656__$1$$,$APP.$cljs$cst$1579$uri$$),$mtype$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55656__$1$$,$APP.$cljs$cst$1726$mtype$$),$is_active$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55656__$1$$,$APP.$cljs$cst$3315$is_active$$);typeof $app$main$data$team$create_webhook_55657$$===
"undefined"&&($app$main$data$team$create_webhook_55657$$=function($p__55655$jscomp$1$$,$map__55656$jscomp$1$$,$params$jscomp$222$$,$uri$jscomp$84$$,$mtype$jscomp$11$$,$is_active$jscomp$3$$,$meta55658$$){this.$p__55655$=$p__55655$jscomp$1$$;this.$map__55656$=$map__55656$jscomp$1$$;this.params=$params$jscomp$222$$;this.uri=$uri$jscomp$84$$;this.$mtype$=$mtype$jscomp$11$$;this.$is_active$=$is_active$jscomp$3$$;this.$meta55658$=$meta55658$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$team$create_webhook_55657$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$create_webhook_55657$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3318$app_DOT_main_DOT_data_DOT_team_SLASH_create_webhook$$},$app$main$data$team$create_webhook_55657$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55659$$,$meta55658__$1$$){return new $app$main$data$team$create_webhook_55657$$(this.$p__55655$,this.$map__55656$,
this.params,this.uri,this.$mtype$,this.$is_active$,$meta55658__$1$$)},$app$main$data$team$create_webhook_55657$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55658$},$app$main$data$team$create_webhook_55657$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$create_webhook_55657$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1737_params__$1$jscomp$30_team_id$jscomp$61$$,$map__55666_map__55666__$1_on_error$jscomp$25_state$jscomp$231$$){$_$jscomp$1737_params__$1$jscomp$30_team_id$jscomp$61$$=
$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($map__55666_map__55666__$1_on_error$jscomp$25_state$jscomp$231$$);$_$jscomp$1737_params__$1$jscomp$30_team_id$jscomp$61$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.params,$APP.$cljs$cst$1927$team_id$$,$_$jscomp$1737_params__$1$jscomp$30_team_id$jscomp$61$$),$APP.$cljs$cst$1579$uri$$,$APP.$cljs$core$str$$);$map__55666_map__55666__$1_on_error$jscomp$25_state$jscomp$231$$=
$APP.$cljs$core$meta$$($_$jscomp$1737_params__$1$jscomp$30_team_id$jscomp$61$$);$map__55666_map__55666__$1_on_error$jscomp$25_state$jscomp$231$$=$APP.$cljs$core$__destructure_map$$($map__55666_map__55666__$1_on_error$jscomp$25_state$jscomp$231$$);var $on_success$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55666_map__55666__$1_on_error$jscomp$25_state$jscomp$231$$,$APP.$cljs$cst$2488$on_success$$,$APP.$beicon$v2$core$empty$$);$map__55666_map__55666__$1_on_error$jscomp$25_state$jscomp$231$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55666_map__55666__$1_on_error$jscomp$25_state$jscomp$231$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55666_map__55666__$1_on_error$jscomp$25_state$jscomp$231$$,$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$beicon$v2$core$concat$$($on_success$jscomp$21$$.$cljs$core$IFn$_invoke$arity$0$?$on_success$jscomp$21$$.$cljs$core$IFn$_invoke$arity$0$():
$on_success$jscomp$21$$(),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$fetch_webhooks$$()))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3319$create_webhook$$,$_$jscomp$1737_params__$1$jscomp$30_team_id$jscomp$61$$)))});return new $app$main$data$team$create_webhook_55657$$($p__55655$$,$map__55656__$1$$,$map__55656__$1$$,$uri$jscomp$83$$,$mtype$jscomp$10$$,$is_active$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$shared_files_fetched$$=function($files$jscomp$9$$){typeof $app$main$data$team$shared_files_fetched_55671$$==="undefined"&&($app$main$data$team$shared_files_fetched_55671$$=function($files$jscomp$10$$,$meta55672$$){this.files=$files$jscomp$10$$;this.$meta55672$=$meta55672$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$shared_files_fetched_55671$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$team$shared_files_fetched_55671$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3320$app_DOT_main_DOT_data_DOT_team_SLASH_shared_files_fetched$$},$app$main$data$team$shared_files_fetched_55671$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55673$$,$meta55672__$1$$){return new $app$main$data$team$shared_files_fetched_55671$$(this.files,$meta55672__$1$$)},$app$main$data$team$shared_files_fetched_55671$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55672$},$app$main$data$team$shared_files_fetched_55671$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$shared_files_fetched_55671$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1738_files__$1$jscomp$1$$,$state$jscomp$232$$){$_$jscomp$1738_files__$1$jscomp$1$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,this.files);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$232$$,
$APP.$cljs$cst$2179$shared_files$$,$APP.$cljs$core$merge$$,$_$jscomp$1738_files__$1$jscomp$1$$)});return new $app$main$data$team$shared_files_fetched_55671$$($files$jscomp$9$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$team$fetch_shared_files$cljs$0core$0IFn$0_invoke$0arity$01$$=function($team_id$jscomp$62$$){typeof $app$main$data$team$fetch_shared_files_55676$$==="undefined"&&($app$main$data$team$fetch_shared_files_55676$$=function($team_id$jscomp$63$$,$meta55677$$){this.$team_id$=$team_id$jscomp$63$$;this.$meta55677$=$meta55677$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$fetch_shared_files_55676$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$fetch_shared_files_55676$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3321$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_shared_files$$},$app$main$data$team$fetch_shared_files_55676$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55678$$,$meta55677__$1$$){return new $app$main$data$team$fetch_shared_files_55676$$(this.$team_id$,$meta55677__$1$$)},$app$main$data$team$fetch_shared_files_55676$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55677$},$app$main$data$team$fetch_shared_files_55676$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$fetch_shared_files_55676$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1739_or__5025__auto__$jscomp$inline_6199$$,$state$jscomp$233_temp__5825__auto__$jscomp$181$$){$_$jscomp$1739_or__5025__auto__$jscomp$inline_6199$$=this.$team_id$;$state$jscomp$233_temp__5825__auto__$jscomp$181$$=$APP.$cljs$core$truth_$$($_$jscomp$1739_or__5025__auto__$jscomp$inline_6199$$)?
$_$jscomp$1739_or__5025__auto__$jscomp$inline_6199$$:$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$233_temp__5825__auto__$jscomp$181$$);return $APP.$cljs$core$truth_$$($state$jscomp$233_temp__5825__auto__$jscomp$181$$)?$APP.$beicon$v2$core$map$$($app$main$data$team$shared_files_fetched$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3322$get_team_shared_files$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,
$state$jscomp$233_temp__5825__auto__$jscomp$181$$],null))):null});return new $app$main$data$team$fetch_shared_files_55676$$($team_id$jscomp$62$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$team$team__GT_organization$$=function($team$jscomp$7$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$3256$organization_id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$7$$),$cljs$cst$3323$slug$$,$cljs$cst$3258$organization_slug$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$7$$),$APP.$cljs$cst$3324$owner_id$$,$cljs$cst$3259$organization_owner_id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$7$$),$cljs$cst$3325$avatar_bg_url$$,
$cljs$cst$3260$organization_avatar_bg_url$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$7$$),$cljs$cst$3326$custom_photo$$,$cljs$cst$3327$organization_custom_photo$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$7$$),$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$3257$organization_name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$7$$),$APP.$cljs$cst$2496$default_team_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$7$$)],null)};
$goog$net$WebSocket$$=function($opt_params$$){$APP.$goog$events$EventTarget$$.call(this);$opt_params$$||($opt_params$$={});this.$autoReconnect_$=$opt_params$$.$autoReconnect$!=0;this.$getNextReconnect_$=$opt_params$$.$getNextReconnect$||$goog$net$WebSocket$EXPONENTIAL_BACKOFF_$$;this.$binaryType_$=$opt_params$$.binaryType||$goog$net$WebSocket$BinaryType$BLOB$$;this.$nextReconnect_$=this.$getNextReconnect_$(this.$reconnectAttempt_$)};
$goog$net$WebSocket$EXPONENTIAL_BACKOFF_$$=function($attempt$jscomp$1$$){return Math.min(Math.pow(2,$attempt$jscomp$1$$)*1E3,6E4)};$goog$net$WebSocket$ClosedEvent$$=function($code$jscomp$25$$,$reason$jscomp$24$$,$wasClean$$){$APP.$goog$events$Event$$.call(this,"closed$3");this.code=$code$jscomp$25$$;this.reason=$reason$jscomp$24$$;this.wasClean=$wasClean$$};$goog$net$WebSocket$MessageEvent$$=function($message$jscomp$82$$){$APP.$goog$events$Event$$.call(this,"message$5");this.message=$message$jscomp$82$$};
$goog$net$WebSocket$ErrorEvent$$=function($data$jscomp$278$$){$APP.$goog$events$Event$$.call(this,"error$4");this.data=$data$jscomp$278$$};
$app$util$websocket$_stream$$=function($JSCompiler_temp$jscomp$1071__$jscomp$1741$$){if($JSCompiler_temp$jscomp$1071__$jscomp$1741$$!=null&&$JSCompiler_temp$jscomp$1071__$jscomp$1741$$.$app$util$websocket$IWebSocket$_stream$arity$1$!=null)$JSCompiler_temp$jscomp$1071__$jscomp$1741$$=$JSCompiler_temp$jscomp$1071__$jscomp$1741$$.$app$util$websocket$IWebSocket$_stream$arity$1$($JSCompiler_temp$jscomp$1071__$jscomp$1741$$);else{var $m__5372__auto__$jscomp$inline_6207_m__5374__auto__$jscomp$inline_6206$$=
$app$util$websocket$_stream$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1071__$jscomp$1741$$==null?null:$JSCompiler_temp$jscomp$1071__$jscomp$1741$$)];if($m__5372__auto__$jscomp$inline_6207_m__5374__auto__$jscomp$inline_6206$$!=null)$JSCompiler_temp$jscomp$1071__$jscomp$1741$$=$m__5372__auto__$jscomp$inline_6207_m__5374__auto__$jscomp$inline_6206$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_6207_m__5374__auto__$jscomp$inline_6206$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1071__$jscomp$1741$$):
$m__5372__auto__$jscomp$inline_6207_m__5374__auto__$jscomp$inline_6206$$($JSCompiler_temp$jscomp$1071__$jscomp$1741$$);else if($m__5372__auto__$jscomp$inline_6207_m__5374__auto__$jscomp$inline_6206$$=$app$util$websocket$_stream$$._,$m__5372__auto__$jscomp$inline_6207_m__5374__auto__$jscomp$inline_6206$$!=null)$JSCompiler_temp$jscomp$1071__$jscomp$1741$$=$m__5372__auto__$jscomp$inline_6207_m__5374__auto__$jscomp$inline_6206$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_6207_m__5374__auto__$jscomp$inline_6206$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1071__$jscomp$1741$$):
$m__5372__auto__$jscomp$inline_6207_m__5374__auto__$jscomp$inline_6206$$($JSCompiler_temp$jscomp$1071__$jscomp$1741$$);else throw $APP.$cljs$core$missing_protocol$$("IWebSocket.-stream",$JSCompiler_temp$jscomp$1071__$jscomp$1741$$);}return $JSCompiler_temp$jscomp$1071__$jscomp$1741$$};
$app$util$websocket$_send$$=function($JSCompiler_temp$jscomp$1072__$jscomp$1743$$,$message$jscomp$84$$){if($JSCompiler_temp$jscomp$1072__$jscomp$1743$$!=null&&$JSCompiler_temp$jscomp$1072__$jscomp$1743$$.$app$util$websocket$IWebSocket$_send$arity$2$!=null)$JSCompiler_temp$jscomp$1072__$jscomp$1743$$=$JSCompiler_temp$jscomp$1072__$jscomp$1743$$.$app$util$websocket$IWebSocket$_send$arity$2$($JSCompiler_temp$jscomp$1072__$jscomp$1743$$,$message$jscomp$84$$);else{var $m__5372__auto__$jscomp$inline_6212_m__5374__auto__$jscomp$inline_6211$$=
$app$util$websocket$_send$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1072__$jscomp$1743$$==null?null:$JSCompiler_temp$jscomp$1072__$jscomp$1743$$)];if($m__5372__auto__$jscomp$inline_6212_m__5374__auto__$jscomp$inline_6211$$!=null)$JSCompiler_temp$jscomp$1072__$jscomp$1743$$=$m__5372__auto__$jscomp$inline_6212_m__5374__auto__$jscomp$inline_6211$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_6212_m__5374__auto__$jscomp$inline_6211$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1072__$jscomp$1743$$,
$message$jscomp$84$$):$m__5372__auto__$jscomp$inline_6212_m__5374__auto__$jscomp$inline_6211$$($JSCompiler_temp$jscomp$1072__$jscomp$1743$$,$message$jscomp$84$$);else if($m__5372__auto__$jscomp$inline_6212_m__5374__auto__$jscomp$inline_6211$$=$app$util$websocket$_send$$._,$m__5372__auto__$jscomp$inline_6212_m__5374__auto__$jscomp$inline_6211$$!=null)$JSCompiler_temp$jscomp$1072__$jscomp$1743$$=$m__5372__auto__$jscomp$inline_6212_m__5374__auto__$jscomp$inline_6211$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_6212_m__5374__auto__$jscomp$inline_6211$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1072__$jscomp$1743$$,$message$jscomp$84$$):$m__5372__auto__$jscomp$inline_6212_m__5374__auto__$jscomp$inline_6211$$($JSCompiler_temp$jscomp$1072__$jscomp$1743$$,$message$jscomp$84$$);else throw $APP.$cljs$core$missing_protocol$$("IWebSocket.-send",$JSCompiler_temp$jscomp$1072__$jscomp$1743$$);}return $JSCompiler_temp$jscomp$1072__$jscomp$1743$$};
$app$util$websocket$_close$$=function($JSCompiler_temp$jscomp$1073__$jscomp$1745$$){if($JSCompiler_temp$jscomp$1073__$jscomp$1745$$!=null&&$JSCompiler_temp$jscomp$1073__$jscomp$1745$$.$app$util$websocket$IWebSocket$_close$arity$1$!=null)$JSCompiler_temp$jscomp$1073__$jscomp$1745$$=$JSCompiler_temp$jscomp$1073__$jscomp$1745$$.$app$util$websocket$IWebSocket$_close$arity$1$($JSCompiler_temp$jscomp$1073__$jscomp$1745$$);else{var $m__5372__auto__$jscomp$inline_6216_m__5374__auto__$jscomp$inline_6215$$=
$app$util$websocket$_close$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1073__$jscomp$1745$$==null?null:$JSCompiler_temp$jscomp$1073__$jscomp$1745$$)];if($m__5372__auto__$jscomp$inline_6216_m__5374__auto__$jscomp$inline_6215$$!=null)$JSCompiler_temp$jscomp$1073__$jscomp$1745$$=$m__5372__auto__$jscomp$inline_6216_m__5374__auto__$jscomp$inline_6215$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_6216_m__5374__auto__$jscomp$inline_6215$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1073__$jscomp$1745$$):
$m__5372__auto__$jscomp$inline_6216_m__5374__auto__$jscomp$inline_6215$$($JSCompiler_temp$jscomp$1073__$jscomp$1745$$);else if($m__5372__auto__$jscomp$inline_6216_m__5374__auto__$jscomp$inline_6215$$=$app$util$websocket$_close$$._,$m__5372__auto__$jscomp$inline_6216_m__5374__auto__$jscomp$inline_6215$$!=null)$JSCompiler_temp$jscomp$1073__$jscomp$1745$$=$m__5372__auto__$jscomp$inline_6216_m__5374__auto__$jscomp$inline_6215$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_6216_m__5374__auto__$jscomp$inline_6215$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1073__$jscomp$1745$$):
$m__5372__auto__$jscomp$inline_6216_m__5374__auto__$jscomp$inline_6215$$($JSCompiler_temp$jscomp$1073__$jscomp$1745$$);else throw $APP.$cljs$core$missing_protocol$$("IWebSocket.-close",$JSCompiler_temp$jscomp$1073__$jscomp$1745$$);}return $JSCompiler_temp$jscomp$1073__$jscomp$1745$$};
$app$util$websocket$t_app$0util$0websocket54423$$=function($uri$jscomp$85$$,$sb$jscomp$34$$,$ws$$,$data$jscomp$279$$,$lk1$$,$lk2$$,$lk3$$,$meta54424$$){this.uri=$uri$jscomp$85$$;this.sb=$sb$jscomp$34$$;this.ws=$ws$$;this.data=$data$jscomp$279$$;this.$lk1$=$lk1$$;this.$lk2$=$lk2$$;this.$lk3$=$lk3$$;this.$meta54424$=$meta54424$$;this.$cljs$lang$protocol_mask$partition0$$=4620288;this.$cljs$lang$protocol_mask$partition1$$=98306};
$app$util$websocket$create$$=function($uri$jscomp$87$$){var $sb$jscomp$36$$=$APP.$beicon$v2$core$subject$$(),$ws$jscomp$2$$=new $goog$net$WebSocket$$({autoReconnect:!0}),$data$jscomp$281$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$lk1$jscomp$2$$=$APP.$goog$events$listen$$($ws$jscomp$2$$,"message$5",function($p1__54417_SHARP_$$){return $sb$jscomp$36$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$141$message$$,
$APP.$cljs$cst$3113$payload$$,$p1__54417_SHARP_$$.message],null))}),$lk2$jscomp$2$$=$APP.$goog$events$listen$$($ws$jscomp$2$$,"error$4",function($p1__54418_SHARP_$$){return $sb$jscomp$36$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$3113$payload$$,$p1__54418_SHARP_$$],null))}),$lk3$jscomp$2$$=$APP.$goog$events$listen$$($ws$jscomp$2$$,"opened$6",function($p1__54419_SHARP_$$){return $sb$jscomp$36$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$cljs$cst$3334$opened$$,$APP.$cljs$cst$3113$payload$$,$p1__54419_SHARP_$$],null))});$ws$jscomp$2$$.open($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($uri$jscomp$87$$));return new $app$util$websocket$t_app$0util$0websocket54423$$($uri$jscomp$87$$,$sb$jscomp$36$$,$ws$jscomp$2$$,$data$jscomp$281$$,$lk1$jscomp$2$$,$lk2$jscomp$2$$,$lk3$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$util$websocket$message_event_QMARK_$$=function($msg$jscomp$25$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($msg$jscomp$25$$),$APP.$cljs$cst$141$message$$)};$app$util$websocket$opened_event_QMARK_$$=function($msg$jscomp$27$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($msg$jscomp$27$$),$cljs$cst$3334$opened$$)};
$app$main$data$websocket$prepare_uri$$=function($base$jscomp$33_params$jscomp$223$$){$base$jscomp$33_params$jscomp$223$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"ws/notifications"])),$APP.$cljs$cst$747$query$$,$APP.$app$common$uri$map__GT_query_string$cljs$0core$0IFn$0_invoke$0arity$02$$($base$jscomp$33_params$jscomp$223$$));
var $G__54454__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("https",$cljs$cst$748$scheme$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$33_params$jscomp$223$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($base$jscomp$33_params$jscomp$223$$,$cljs$cst$748$scheme$$,"wss"):$base$jscomp$33_params$jscomp$223$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("http",$cljs$cst$748$scheme$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$33_params$jscomp$223$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54454__$1$$,
$cljs$cst$748$scheme$$,"ws"):$G__54454__$1$$};
$app$main$data$websocket$send$$=function($message$jscomp$86$$){typeof $app$main$data$websocket$send_message_54455$$==="undefined"&&($app$main$data$websocket$send_message_54455$$=function($message$jscomp$87$$,$meta54456$$){this.message=$message$jscomp$87$$;this.$meta54456$=$meta54456$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$websocket$send_message_54455$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$websocket$send_message_54455$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$2143$app_DOT_main_DOT_data_DOT_websocket_SLASH_send_message$$},$app$main$data$websocket$send_message_54455$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_54457$$,$meta54456__$1$$){return new $app$main$data$websocket$send_message_54455$$(this.message,$meta54456__$1$$)},$app$main$data$websocket$send_message_54455$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta54456$},$app$main$data$websocket$send_message_54455$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$websocket$send_message_54455$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){var $G__54458_JSCompiler_temp$jscomp$1074$$=$APP.$cljs$core$_deref$$($app$main$data$websocket$ws_conn$$);if($G__54458_JSCompiler_temp$jscomp$1074$$==null)$G__54458_JSCompiler_temp$jscomp$1074$$=null;else{var $msg$jscomp$inline_6219$$=this.message;$G__54458_JSCompiler_temp$jscomp$1074$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?$app$util$websocket$_send$$($G__54458_JSCompiler_temp$jscomp$1074$$,
$APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($msg$jscomp$inline_6219$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$1589$json_verbose$$],null))):$app$util$websocket$_send$$($G__54458_JSCompiler_temp$jscomp$1074$$,$APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($msg$jscomp$inline_6219$$,null))}return $G__54458_JSCompiler_temp$jscomp$1074$$});return new $app$main$data$websocket$send_message_54455$$($message$jscomp$86$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$websocket$initialize$$=function(){typeof $app$main$data$websocket$initialize_54461$$==="undefined"&&($app$main$data$websocket$initialize_54461$$=function($meta54462$$){this.$meta54462$=$meta54462$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$websocket$initialize_54461$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$websocket$initialize_54461$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3335$app_DOT_main_DOT_data_DOT_websocket_SLASH_initialize$$},
$app$main$data$websocket$initialize_54461$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_54463$$,$meta54462__$1$$){return new $app$main$data$websocket$initialize_54461$$($meta54462__$1$$)},$app$main$data$websocket$initialize_54461$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta54462$},$app$main$data$websocket$initialize_54461$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$websocket$initialize_54461$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1763_sid$jscomp$1_uri$jscomp$88$$,$state$jscomp$234$$,$stopper$jscomp$5_stream$jscomp$32$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.websocket",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,
"initialize"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,"watch"],null)],null)}),null,"app.main.data.websocket",$APP.$cljs$cst$144$trace$$,!1);$_$jscomp$1763_sid$jscomp$1_uri$jscomp$88$$=$APP.$cljs$cst$2332$session_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$234$$);$_$jscomp$1763_sid$jscomp$1_uri$jscomp$88$$=$app$main$data$websocket$prepare_uri$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2332$session_id$$,
$_$jscomp$1763_sid$jscomp$1_uri$jscomp$88$$],null));var $ws$jscomp$7$$=$app$util$websocket$create$$($_$jscomp$1763_sid$jscomp$1_uri$jscomp$88$$);$APP.$cljs$core$_vreset_BANG_$$($app$main$data$websocket$ws_conn$$,$ws$jscomp$7$$);$stopper$jscomp$5_stream$jscomp$32$$=$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3336$app_DOT_main_DOT_data_DOT_websocket_SLASH_finalize$$),$stopper$jscomp$5_stream$jscomp$32$$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3335$app_DOT_main_DOT_data_DOT_websocket_SLASH_initialize$$),
$stopper$jscomp$5_stream$jscomp$32$$));return $APP.$beicon$v2$core$take_until$$($stopper$jscomp$5_stream$jscomp$32$$,$APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)(function($p1__54459_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__54459_SHARP_$$,$cljs$cst$3337$ws_conn$$,$ws$jscomp$7$$)}),$APP.$beicon$v2$core$map$$(function($p1__54460_SHARP_$$){return $APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3338$app_DOT_main_DOT_data_DOT_websocket_SLASH_message$$,
$p1__54460_SHARP_$$)},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$3113$payload$$,$APP.$beicon$v2$core$filter$$($app$util$websocket$message_event_QMARK_$$,$app$util$websocket$_stream$$($ws$jscomp$7$$)))),$APP.$beicon$v2$core$map$$(function(){return $APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3339$app_DOT_main_DOT_data_DOT_websocket_SLASH_opened$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$APP.$beicon$v2$core$filter$$($app$util$websocket$opened_event_QMARK_$$,$app$util$websocket$_stream$$($ws$jscomp$7$$)))))});
return new $app$main$data$websocket$initialize_54461$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$websocket$finalize$$=function(){typeof $app$main$data$websocket$finalize_54464$$==="undefined"&&($app$main$data$websocket$finalize_54464$$=function($meta54465$$){this.$meta54465$=$meta54465$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$websocket$finalize_54464$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$websocket$finalize_54464$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3336$app_DOT_main_DOT_data_DOT_websocket_SLASH_finalize$$},$app$main$data$websocket$finalize_54464$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_54466$$,$meta54465__$1$$){return new $app$main$data$websocket$finalize_54464$$($meta54465__$1$$)},$app$main$data$websocket$finalize_54464$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta54465$},$app$main$data$websocket$finalize_54464$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$websocket$finalize_54464$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1764$$,$state$jscomp$235$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$235$$,$cljs$cst$3337$ws_conn$$)},$app$main$data$websocket$finalize_54464$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$websocket$finalize_54464$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.websocket",
$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"event:finalize"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,"effect"],null)],null)}),null,"app.main.data.websocket",
$APP.$cljs$cst$144$trace$$,!1);var $G__54472$$=$APP.$cljs$core$_deref$$($app$main$data$websocket$ws_conn$$);return $G__54472$$==null?null:$app$util$websocket$_close$$($G__54472$$)});return new $app$main$data$websocket$finalize_54464$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$auth$is_authenticated_QMARK_$$=function($id$jscomp$390_map__55686__$1_p__55685$$){$id$jscomp$390_map__55686__$1_p__55685$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$390_map__55686__$1_p__55685$$);$id$jscomp$390_map__55686__$1_p__55685$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$390_map__55686__$1_p__55685$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$uuid_QMARK_$$($id$jscomp$390_map__55686__$1_p__55685$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$390_map__55686__$1_p__55685$$,
$APP.$app$common$uuid$zero$$)};
$APP.$app$main$data$auth$logged_in$$=function($p__55708$$){var $map__55709__$1$$=$APP.$cljs$core$__destructure_map$$($p__55708$$),$props$jscomp$136$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55709__$1$$,$APP.$cljs$cst$575$props$$);typeof $app$main$data$auth$logged_in_55750$$==="undefined"&&($app$main$data$auth$logged_in_55750$$=function($p__55708$jscomp$1$$,$map__55709$jscomp$1$$,$profile$jscomp$13$$,$props$jscomp$137$$,$get_redirect_events$jscomp$1$$,$meta55751$$){this.$p__55708$=
$p__55708$jscomp$1$$;this.$map__55709$=$map__55709$jscomp$1$$;this.profile=$profile$jscomp$13$$;this.props=$props$jscomp$137$$;this.$get_redirect_events$=$get_redirect_events$jscomp$1$$;this.$meta55751$=$meta55751$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$auth$logged_in_55750$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$logged_in_55750$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3342$app_DOT_main_DOT_data_DOT_auth_SLASH_logged_in$$},$app$main$data$auth$logged_in_55750$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55752$$,$meta55751__$1$$){return new $app$main$data$auth$logged_in_55750$$(this.$p__55708$,this.$map__55709$,this.profile,this.props,this.$get_redirect_events$,$meta55751__$1$$)},$app$main$data$auth$logged_in_55750$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55751$},$app$main$data$auth$logged_in_55750$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$logged_in_55750$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1766_f$jscomp$inline_6221$$,$___$1$jscomp$1093$$,$stream$jscomp$33$$){$_$jscomp$1766_f$jscomp$inline_6221$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"initializeExternalConfigInfo");$APP.$cljs$core$fn_QMARK_$$($_$jscomp$1766_f$jscomp$inline_6221$$)&&($_$jscomp$1766_f$jscomp$inline_6221$$.$cljs$core$IFn$_invoke$arity$0$?
$_$jscomp$1766_f$jscomp$inline_6221$$.$cljs$core$IFn$_invoke$arity$0$():$_$jscomp$1766_f$jscomp$inline_6221$$());return $APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,$APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$profile$set_profile$$(this.profile),$APP.$app$main$data$websocket$initialize$$(),$APP.$app$main$data$team$fetch_teams$$()),$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$3183$email$$,
$cljs$cst$3343$auth_backend$$,$APP.$cljs$cst$2310$app_DOT_main_DOT_data_DOT_event_SLASH_type$$,$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,$APP.$cljs$cst$1360$fullname$$,$APP.$cljs$cst$2511$default_project_id$$,$APP.$cljs$cst$266$id$$,$cljs$cst$3344$is_muted$$,$APP.$cljs$cst$2496$default_team_id$$],[$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$(this.profile),$cljs$cst$3343$auth_backend$$.$cljs$core$IFn$_invoke$arity$1$(this.profile),"identify","signin",$APP.$cljs$cst$1360$fullname$$.$cljs$core$IFn$_invoke$arity$1$(this.profile),
$APP.$cljs$cst$2511$default_project_id$$.$cljs$core$IFn$_invoke$arity$1$(this.profile),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.profile),$cljs$cst$3344$is_muted$$.$cljs$core$IFn$_invoke$arity$1$(this.profile),$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$(this.profile)])))),$APP.$beicon$v2$core$mapcat$$(this.$get_redirect_events$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3255$app_DOT_main_DOT_data_DOT_team_SLASH_teams_fetched$$),
$stream$jscomp$33$$))))))});return new $app$main$data$auth$logged_in_55750$$($p__55708$$,$map__55709__$1$$,$map__55709__$1$$,$props$jscomp$136$$,function($_STAR_sync_STAR__orig_val__55724_team_id__$1$jscomp$9_teams$jscomp$5_teams__$1$$){var $team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$=$APP.$cljs$cst$1134$invitation_token$$.$cljs$core$IFn$_invoke$arity$1$($map__55709__$1$$);if($APP.$cljs$core$truth_$$($team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$))return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3304$auth_verify_token$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1136$token$$,$team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$],null)));$team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$=$cljs$cst$3340$login_redirect$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$session$$);if($APP.$cljs$core$truth_$$($team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$)){$_STAR_sync_STAR__orig_val__55724_team_id__$1$jscomp$9_teams$jscomp$5_teams__$1$$=
$APP.$app$util$storage$_STAR_sync_STAR_$$;$APP.$app$util$storage$_STAR_sync_STAR_$$=!0;try{return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$session$$,$APP.$cljs$core$dissoc$$,$cljs$cst$3340$login_redirect$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$,$APP.$app$util$globals$location$$.href)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$reload$$()):
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2462$href$$,$team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$])))}finally{$APP.$app$util$storage$_STAR_sync_STAR_$$=$_STAR_sync_STAR__orig_val__55724_team_id__$1$jscomp$9_teams$jscomp$5_teams__$1$$}}else{$team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$136$$,$cljs$cst$3341$welcome_file_id$$);if($APP.$cljs$core$truth_$$($team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$))return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1644$file_id$$,$team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$,
$APP.$cljs$cst$1927$team_id$$,$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($map__55709__$1$$)])),$APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3341$welcome_file_id$$,null],null)));$_STAR_sync_STAR__orig_val__55724_team_id__$1$jscomp$9_teams$jscomp$5_teams__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),
$_STAR_sync_STAR__orig_val__55724_team_id__$1$jscomp$9_teams$jscomp$5_teams__$1$$);$team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$=$APP.$cljs$cst$3254$app_DOT_main_DOT_data_DOT_team_SLASH_current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$global$$);$_STAR_sync_STAR__orig_val__55724_team_id__$1$jscomp$9_teams$jscomp$5_teams__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$)?
$APP.$cljs$core$contains_QMARK_$$($_STAR_sync_STAR__orig_val__55724_team_id__$1$jscomp$9_teams$jscomp$5_teams__$1$$,$team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$):$team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$)?$team_id$jscomp$64_temp__5823__auto__$jscomp$159_temp__5823__auto____$1$jscomp$11_temp__5823__auto____$2$jscomp$1$$:$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($map__55709__$1$$);
return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$_STAR_sync_STAR__orig_val__55724_team_id__$1$jscomp$9_teams$jscomp$5_teams__$1$$],null)])))}},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$auth$login$$=function($p__55778$$){var $map__55779__$1$$=$APP.$cljs$core$__destructure_map$$($p__55778$$),$email$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55779__$1$$,$APP.$cljs$cst$3183$email$$),$password$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55779__$1$$,$APP.$cljs$cst$751$password$$),$invitation_token$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55779__$1$$,$APP.$cljs$cst$1134$invitation_token$$);
typeof $app$main$data$auth$login_55780$$==="undefined"&&($app$main$data$auth$login_55780$$=function($p__55778$jscomp$1$$,$map__55779$jscomp$1$$,$data$jscomp$283$$,$email$jscomp$9$$,$password$jscomp$7$$,$invitation_token$jscomp$1$$,$meta55781$$){this.$p__55778$=$p__55778$jscomp$1$$;this.$map__55779$=$map__55779$jscomp$1$$;this.data=$data$jscomp$283$$;this.email=$email$jscomp$9$$;this.password=$password$jscomp$7$$;this.$invitation_token$=$invitation_token$jscomp$1$$;this.$meta55781$=$meta55781$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$auth$login_55780$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$login_55780$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3345$app_DOT_main_DOT_data_DOT_auth_SLASH_login$$},$app$main$data$auth$login_55780$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55782$$,$meta55781__$1$$){return new $app$main$data$auth$login_55780$$(this.$p__55778$,this.$map__55779$,
this.data,this.email,this.password,this.$invitation_token$,$meta55781__$1$$)},$app$main$data$auth$login_55780$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55781$},$app$main$data$auth$login_55780$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$login_55780$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1767_map__55797_map__55797__$1$$,$___$1$jscomp$1094$$,$stream$jscomp$34$$){$_$jscomp$1767_map__55797_map__55797__$1$$=
$APP.$cljs$core$meta$$(this.data);$_$jscomp$1767_map__55797_map__55797__$1$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$1767_map__55797_map__55797__$1$$);var $on_error$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$1767_map__55797_map__55797__$1$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$),$on_success$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$1767_map__55797_map__55797__$1$$,$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);
return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($on_error$jscomp$26$$,$APP.$beicon$v2$core$merge_map$$(function($data__$1$jscomp$12$$){return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$profile$fetch_profile$$()),$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,$APP.$beicon$v2$core$map$$(function(){throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("authentication",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3157$authentication$$],null),null])),null);},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($on_error$jscomp$26$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$complement$$($APP.$app$main$data$auth$is_authenticated_QMARK_$$),$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$app$main$data$profile$profile_fetched_QMARK_$$,$stream$jscomp$34$$))))))),$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,
$APP.$beicon$v2$core$map$$($APP.$app$main$data$auth$logged_in$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($on_success$jscomp$22$$,$APP.$beicon$v2$core$map$$(function($profile$jscomp$14$$){return $APP.$cljs$core$with_meta$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$data__$1$jscomp$12$$,$profile$jscomp$14$$])),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3346$app_DOT_main_DOT_data_DOT_event_SLASH_source$$,
"login"],null))},$APP.$beicon$v2$core$filter$$($APP.$app$main$data$auth$is_authenticated_QMARK_$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$app$main$data$profile$profile_fetched_QMARK_$$,$stream$jscomp$34$$)))))))))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1168$login_with_password$$,$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$3183$email$$,this.email,$APP.$cljs$cst$751$password$$,this.password,$APP.$cljs$cst$1134$invitation_token$$,this.$invitation_token$],null)))))});return new $app$main$data$auth$login_55780$$($p__55778$$,$map__55779__$1$$,$map__55779__$1$$,$email$jscomp$8$$,$password$jscomp$6$$,$invitation_token$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$auth$login_with_ldap$$=function($params$jscomp$225$$){typeof $app$main$data$auth$login_with_ldap_55808$$==="undefined"&&($app$main$data$auth$login_with_ldap_55808$$=function($params$jscomp$226$$,$meta55809$$){this.params=$params$jscomp$226$$;this.$meta55809$=$meta55809$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$auth$login_with_ldap_55808$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$login_with_ldap_55808$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3347$app_DOT_main_DOT_data_DOT_auth_SLASH_login_with_ldap$$},$app$main$data$auth$login_with_ldap_55808$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55810$$,$meta55809__$1$$){return new $app$main$data$auth$login_with_ldap_55808$$(this.params,$meta55809__$1$$)},$app$main$data$auth$login_with_ldap_55808$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55809$},$app$main$data$auth$login_with_ldap_55808$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$login_with_ldap_55808$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__55814_on_error$jscomp$27$$=$APP.$cljs$core$meta$$(this.params),$map__55814__$1_on_success$jscomp$23$$=$APP.$cljs$core$__destructure_map$$($map__55814_on_error$jscomp$27$$);$map__55814_on_error$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55814__$1_on_success$jscomp$23$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);
$map__55814__$1_on_success$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55814__$1_on_success$jscomp$23$$,$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55814_on_error$jscomp$27$$,$APP.$beicon$v2$core$map$$(function($profile$jscomp$15$$){return $APP.$app$main$data$auth$logged_in$$($APP.$cljs$core$with_meta$$($profile$jscomp$15$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3346$app_DOT_main_DOT_data_DOT_event_SLASH_source$$,
"login-with-ldap"],null)))},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55814__$1_on_success$jscomp$23$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1179$login_with_ldap$$,this.params))))});return new $app$main$data$auth$login_with_ldap_55808$$($params$jscomp$225$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$auth$login_with_sso$$=function($params$jscomp$227$$){typeof $app$main$data$auth$login_with_sso_55820$$==="undefined"&&($app$main$data$auth$login_with_sso_55820$$=function($params$jscomp$228$$,$meta55821$$){this.params=$params$jscomp$228$$;this.$meta55821$=$meta55821$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$auth$login_with_sso_55820$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$login_with_sso_55820$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3349$app_DOT_main_DOT_data_DOT_auth_SLASH_login_with_sso$$},$app$main$data$auth$login_with_sso_55820$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55822$$,$meta55821__$1$$){return new $app$main$data$auth$login_with_sso_55820$$(this.params,$meta55821__$1$$)},$app$main$data$auth$login_with_sso_55820$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55821$},$app$main$data$auth$login_with_sso_55820$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$login_with_sso_55820$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$55$$){var $code$jscomp$26_map__55829__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$ex_data$$($cause$jscomp$55$$)),$type$jscomp$433$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$26_map__55829__$1$$,$APP.$cljs$cst$139$type$$);$code$jscomp$26_map__55829__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$26_map__55829__$1$$,$APP.$cljs$cst$273$code$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$433$$,$APP.$cljs$cst$2561$restriction$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$26_map__55829__$1$$,$cljs$cst$3350$provider_not_configured$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.auth-provider-not-configured"))):
$APP.$beicon$v2$core$throw$0$$($cause$jscomp$55$$)},$APP.$beicon$v2$core$map$$(function($map__55831__$1_p__55830$$){$map__55831__$1_p__55830$$=$APP.$cljs$core$__destructure_map$$($map__55831__$1_p__55830$$);var $redirect_uri$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55831__$1_p__55830$$,$cljs$cst$3351$redirect_uri$$);if($APP.$cljs$core$truth_$$($redirect_uri$$))return $APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1579$uri$$,
$redirect_uri$$]));throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("unexpected response from OIDC method",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$272$assertion$$,$APP.$cljs$cst$273$code$$,$cljs$cst$2279$unexpected_response$$,$APP.$cljs$cst$275$hint$$,"unexpected response from OIDC method",$cljs$cst$3352$resp$$,
$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__55831__$1_p__55830$$]))],null),null])),null);},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1175$login_with_oidc$$,this.params)))});return new $app$main$data$auth$login_with_sso_55820$$($params$jscomp$227$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$auth$login_from_register$$=function(){typeof $app$main$data$auth$login_from_register_55851$$==="undefined"&&($app$main$data$auth$login_from_register_55851$$=function($meta55852$$){this.$meta55852$=$meta55852$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$auth$login_from_register_55851$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$login_from_register_55851$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3354$app_DOT_main_DOT_data_DOT_auth_SLASH_login_from_register$$},$app$main$data$auth$login_from_register_55851$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55853$$,$meta55852__$1$$){return new $app$main$data$auth$login_from_register_55851$$($meta55852__$1$$)},$app$main$data$auth$login_from_register_55851$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55852$},$app$main$data$auth$login_from_register_55851$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$login_from_register_55851$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1771$$,$___$1$jscomp$1098$$,$stream$jscomp$35$$){return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$profile$fetch_profile$$()),$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,$APP.$beicon$v2$core$map$$($APP.$app$main$data$auth$logged_in$$,$APP.$beicon$v2$core$map$$(function($profile$jscomp$18$$){return $APP.$cljs$core$with_meta$$($profile$jscomp$18$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3346$app_DOT_main_DOT_data_DOT_event_SLASH_source$$,"register"],null))},$APP.$beicon$v2$core$filter$$($APP.$app$main$data$auth$is_authenticated_QMARK_$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$app$main$data$profile$profile_fetched_QMARK_$$,$stream$jscomp$35$$))))))))});return new $app$main$data$auth$login_from_register_55851$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$auth$logged_out$$=function($p__55868$$){var $map__55869__$1$$=$APP.$cljs$core$__destructure_map$$($p__55868$$),$redirect_uri$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55869__$1$$,$cljs$cst$3351$redirect_uri$$);typeof $app$main$data$auth$logged_out_55870$$==="undefined"&&($app$main$data$auth$logged_out_55870$$=function($p__55868$jscomp$1$$,$map__55869$jscomp$1$$,$redirect_uri$jscomp$2$$,$meta55871$$){this.$p__55868$=$p__55868$jscomp$1$$;this.$map__55869$=
$map__55869$jscomp$1$$;this.$redirect_uri$=$redirect_uri$jscomp$2$$;this.$meta55871$=$meta55871$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$auth$logged_out_55870$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$logged_out_55870$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3355$app_DOT_main_DOT_data_DOT_auth_SLASH_logged_out$$},$app$main$data$auth$logged_out_55870$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55872$$,$meta55871__$1$$){return new $app$main$data$auth$logged_out_55870$$(this.$p__55868$,this.$map__55869$,this.$redirect_uri$,$meta55871__$1$$)},$app$main$data$auth$logged_out_55870$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55871$},$app$main$data$auth$logged_out_55870$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$logged_out_55870$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1772$$,
$state$jscomp$236$$){return $APP.$cljs$core$select_keys$$($state$jscomp$236$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2171$route$$,$APP.$cljs$cst$2172$router$$,$APP.$cljs$cst$2332$session_id$$,$APP.$cljs$cst$2457$history$$],null))},$app$main$data$auth$logged_out_55870$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$logged_out_55870$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){return $APP.$cljs$core$truth_$$(this.$redirect_uri$)?$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1579$uri$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.$redirect_uri$)])))):$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3356$auth_login$$))),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$websocket$finalize$$()))},$app$main$data$auth$logged_out_55870$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$logged_out_55870$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$storage$user$$,$APP.$cljs$core$constantly$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$))});return new $app$main$data$auth$logged_out_55870$$($p__55868$$,
$map__55869__$1$$,$redirect_uri$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$auth$logout$$=function(){typeof $app$main$data$auth$logout_55886$$==="undefined"&&($app$main$data$auth$logout_55886$$=function($meta55887$$){this.$meta55887$=$meta55887$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$auth$logout_55886$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$logout_55886$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3357$app_DOT_main_DOT_data_DOT_auth_SLASH_logout$$},
$app$main$data$auth$logout_55886$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55888$$,$meta55887__$1$$){return new $app$main$data$auth$logout_55886$$($meta55887__$1$$)},$app$main$data$auth$logout_55886$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55887$},$app$main$data$auth$logout_55886$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$logout_55886$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return $APP.$cljs$core$PersistentArrayMap$EMPTY$$},
$app$main$data$auth$logout_55886$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$auth$logout_55886$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1776$$,$state$jscomp$237$$){var $profile_id$jscomp$8$$=$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$237$$);return $APP.$beicon$v2$core$map$$($APP.$app$main$data$auth$logged_out$$,$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$constantly$$((0,$APP.$beicon$v2$core$of$$)(null)),
$APP.$beicon$v2$core$delay_at_least$$(300,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3358$logout$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2313$profile_id$$,$profile_id$jscomp$8$$],null))))},$APP.$beicon$v2$core$take$$($APP.$shadow$js$shim$module$0rxjs$$.interval(500))))});return new $app$main$data$auth$logout_55886$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$main$errors$is_plugin_error_QMARK_$$=function(){return!1};
$APP.$app$main$errors$stale_asset_error_QMARK_$$=function($cause$jscomp$56_message$jscomp$88$$){if($cause$jscomp$56_message$jscomp$88$$!=null){$cause$jscomp$56_message$jscomp$88$$=$APP.$cljs$core$ex_message$$($cause$jscomp$56_message$jscomp$88$$);var $and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$=typeof $cause$jscomp$56_message$jscomp$88$$==="string";if($and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$){$and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$=
$APP.$cuerdas$core$includes_QMARK_$$($cause$jscomp$56_message$jscomp$88$$,"$cljs$cst$");$and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$)?$and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$:
$APP.$cuerdas$core$includes_QMARK_$$($cause$jscomp$56_message$jscomp$88$$,"$cljs$core$I");if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$)){$and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$=$APP.$cuerdas$core$includes_QMARK_$$($cause$jscomp$56_message$jscomp$88$$,
"is undefined");if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$))return $and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$;$and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$=
$APP.$cuerdas$core$includes_QMARK_$$($cause$jscomp$56_message$jscomp$88$$,"is null");if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$))return $and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$;
$and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$=$APP.$cuerdas$core$includes_QMARK_$$($cause$jscomp$56_message$jscomp$88$$,"is not a function");return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$)?
$and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$:$APP.$cuerdas$core$includes_QMARK_$$($cause$jscomp$56_message$jscomp$88$$,"Cannot read properties of undefined")}return $and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$}return $and__5023__auto__$jscomp$353_and__5023__auto____$1$jscomp$64_or__5025__auto__$jscomp$617_or__5025__auto__$jscomp$inline_6223_or__5025__auto____$1$jscomp$74_or__5025__auto____$2$jscomp$20$$}return null};
$APP.$app$main$errors$exception__GT_error_data$$=function($cause$jscomp$57$$){var $data$jscomp$288$$=$APP.$cljs$core$ex_data$$($cause$jscomp$57$$),$JSCompiler_temp_const$jscomp$1079$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1077$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1075$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$or__5025__auto__$jscomp$inline_6225$$=$APP.$cljs$cst$275$hint$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$288$$);
return $JSCompiler_temp_const$jscomp$1079$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp_const$jscomp$1077$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp_const$jscomp$1075$$.call($APP.$cljs$core$assoc$$,$data$jscomp$288$$,$APP.$cljs$cst$275$hint$$,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_6225$$)?$or__5025__auto__$jscomp$inline_6225$$:$APP.$cljs$core$ex_message$$($cause$jscomp$57$$)),$APP.$cljs$cst$3364$app_DOT_main_DOT_errors_SLASH_instance$$,$cause$jscomp$57$$),$cljs$cst$3365$app_DOT_main_DOT_errors_SLASH_trace$$,
$cause$jscomp$57$$.stack)};
$APP.$app$main$errors$on_error$$=function($error$jscomp$57$$){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($app$main$errors$handling_error_QMARK_$$)))return console.error("[on-error] re-entrant call suppressed",$error$jscomp$57$$);$APP.$cljs$core$_vreset_BANG_$$($app$main$errors$handling_error_QMARK_$$,!0);try{if($APP.$cljs$core$map_QMARK_$$($error$jscomp$57$$))return $potok$v2$core$handle_error$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$57$$);var $data$jscomp$289$$=$APP.$app$main$errors$exception__GT_error_data$$($error$jscomp$57$$);
return $potok$v2$core$handle_error$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$289$$)}finally{$APP.$cljs$core$_vreset_BANG_$$($app$main$errors$handling_error_QMARK_$$,!1)}};
$APP.$app$main$errors$generate_report$$=function($cause$jscomp$58$$){try{var $team_id$jscomp$65$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$file_id$jscomp$44$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$profile_id$jscomp$9$$=$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),
$data$jscomp$290$$=$APP.$cljs$core$ex_data$$($cause$jscomp$58$$),$sb__5670__auto__$jscomp$6$$=new $APP.$goog$string$StringBuffer$$,$_STAR_print_newline_STAR__orig_val__55992_56215$$=$APP.$cljs$core$_STAR_print_newline_STAR_$$,$_STAR_print_fn_STAR__orig_val__55993_56216$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$6$$){return $sb__5670__auto__$jscomp$6$$.append($x__5671__auto__$jscomp$6$$)};
try{$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Context:"]));$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["--------------------"]));$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Hint:    ",function(){var $or__5025__auto__$jscomp$620_or__5025__auto____$1$jscomp$75$$=
$APP.$cljs$cst$275$hint$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$290$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$620_or__5025__auto____$1$jscomp$75$$))return $or__5025__auto__$jscomp$620_or__5025__auto____$1$jscomp$75$$;$or__5025__auto__$jscomp$620_or__5025__auto____$1$jscomp$75$$=$APP.$cljs$core$ex_message$$($cause$jscomp$58$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$620_or__5025__auto____$1$jscomp$75$$)?$or__5025__auto__$jscomp$620_or__5025__auto____$1$jscomp$75$$:
"--"}()]));$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Prof ID: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($profile_id$jscomp$9$$)?$profile_id$jscomp$9$$:"--")]));$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Team ID: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($team_id$jscomp$65$$)?
$team_id$jscomp$65$$:"--")]));var $temp__5825__auto___56219$$=function(){var $or__5025__auto__$jscomp$623$$=$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$290$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$623$$)?$or__5025__auto__$jscomp$623$$:$file_id$jscomp$44$$}();$APP.$cljs$core$truth_$$($temp__5825__auto___56219$$)&&$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["File ID: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto___56219$$)]));$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Version: ",$APP.$cljs$cst$1273$full$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$)]));$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["HREF:    ",$APP.$app$util$globals$location$$.href]));
$APP.$cljs$core$println$$();$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$exceptions$format_throwable$$($cause$jscomp$58$$)]));$APP.$cljs$core$println$$();$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Last events:"]));$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["--------------------"]));
$app$common$pprint$pprint$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$_deref$$($app$main$store$last_events$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$255$length$$,200],null)]));$APP.$cljs$core$println$$()}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=$_STAR_print_fn_STAR__orig_val__55993_56216$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__55992_56215$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$6$$)}catch($e55991$$){return console.error("error on generating report",
$e55991$$),null}};
$APP.$app$main$errors$submit_report$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($event_name_p__56009$$){var $hint$jscomp$9_map__56010__$1$$=$APP.$cljs$core$__destructure_map$$($event_name_p__56009$$);$event_name_p__56009$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($hint$jscomp$9_map__56010__$1$$,$APP.$cljs$cst$2317$event_name$$,"unhandled-exception");var $report$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$9_map__56010__$1$$,$APP.$cljs$cst$572$report$$);
$hint$jscomp$9_map__56010__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$9_map__56010__$1$$,$APP.$cljs$cst$275$hint$$);return $APP.$cuerdas$core$empty_QMARK_$$($hint$jscomp$9_map__56010__$1$$)||typeof $report$jscomp$2$$!=="string"||typeof $event_name_p__56009$$!=="string"?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
$event_name_p__56009$$,$APP.$cljs$cst$275$hint$$,$hint$jscomp$9_map__56010__$1$$,$APP.$cljs$cst$2462$href$$,$APP.$app$util$globals$location$$.href,$APP.$cljs$cst$572$report$$,$report$jscomp$2$$],null)))};
$app$main$errors$flash$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($cause$jscomp$59_map__56042__$1_p__56041$$){$cause$jscomp$59_map__56042__$1_p__56041$$=$APP.$cljs$core$__destructure_map$$($cause$jscomp$59_map__56042__$1_p__56041$$);var $type$jscomp$434$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($cause$jscomp$59_map__56042__$1_p__56041$$,$APP.$cljs$cst$139$type$$,$cljs$cst$3366$handled$$),$hint$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause$jscomp$59_map__56042__$1_p__56041$$,
$APP.$cljs$cst$275$hint$$);$cause$jscomp$59_map__56042__$1_p__56041$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause$jscomp$59_map__56042__$1_p__56041$$,$cljs$cst$145$cause$$);if($APP.$app$common$exceptions$exception_QMARK_$$($cause$jscomp$59_map__56042__$1_p__56041$$)){var $temp__5825__auto___56231$$=function(){var $G__56048__$1$$=$type$jscomp$434$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$434$$.$fqn$:null;switch($G__56048__$1$$){case "handled":return"handled-exception";case "unhandled":return"unhandled-exception";
case "silent":return null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__56048__$1$$)].join(""));}}();if($APP.$cljs$core$truth_$$($temp__5825__auto___56231$$)){var $report_56234$$=$APP.$app$main$errors$generate_report$$($cause$jscomp$59_map__56042__$1_p__56041$$);$APP.$app$main$errors$submit_report$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2317$event_name$$,$temp__5825__auto___56231$$,
$APP.$cljs$cst$572$report$$,$report_56234$$,$APP.$cljs$cst$275$hint$$,$APP.$app$common$exceptions$get_hint$$($cause$jscomp$59_map__56042__$1_p__56041$$)]))}}return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$hint$jscomp$10$$?$hint$jscomp$10$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.generic"),
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2353$timeout$$,5E3],null)))})};
$app$main$errors$redirect_to_dashboard$$=function(){var $team_id$jscomp$66$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$project_id$jscomp$4$$=$APP.$cljs$cst$2174$current_project_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($project_id$jscomp$4$$)?$team_id$jscomp$66$$:$project_id$jscomp$4$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2512$dashboard_files$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$66$$,$APP.$cljs$cst$2181$project_id$$,$project_id$jscomp$4$$],null))):$APP.$app$util$globals$location$$.href=""};
$app$main$errors$is_ignorable_exception_QMARK_$$=function($and__5023__auto__$jscomp$357_cause$jscomp$67$$){var $message$jscomp$92$$=$APP.$cljs$core$ex_message$$($and__5023__auto__$jscomp$357_cause$jscomp$67$$);var $or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$=$and__5023__auto__$jscomp$357_cause$jscomp$67$$.stack;
var $and__5023__auto__$jscomp$inline_6229_and__5023__auto__$jscomp$inline_6235_or__5025__auto__$jscomp$inline_6230_or__5025__auto____$1$jscomp$inline_6231$$=typeof $or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$==="string";$and__5023__auto__$jscomp$inline_6229_and__5023__auto__$jscomp$inline_6235_or__5025__auto__$jscomp$inline_6230_or__5025__auto____$1$jscomp$inline_6231$$?
($and__5023__auto__$jscomp$inline_6229_and__5023__auto__$jscomp$inline_6235_or__5025__auto__$jscomp$inline_6230_or__5025__auto____$1$jscomp$inline_6231$$=$APP.$cuerdas$core$includes_QMARK_$$($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$,
"chrome-extension://"),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_6229_and__5023__auto__$jscomp$inline_6235_or__5025__auto__$jscomp$inline_6230_or__5025__auto____$1$jscomp$inline_6231$$)?$or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$=
$and__5023__auto__$jscomp$inline_6229_and__5023__auto__$jscomp$inline_6235_or__5025__auto__$jscomp$inline_6230_or__5025__auto____$1$jscomp$inline_6231$$:($and__5023__auto__$jscomp$inline_6229_and__5023__auto__$jscomp$inline_6235_or__5025__auto__$jscomp$inline_6230_or__5025__auto____$1$jscomp$inline_6231$$=$APP.$cuerdas$core$includes_QMARK_$$($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$,
"moz-extension://"),$or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_6229_and__5023__auto__$jscomp$inline_6235_or__5025__auto__$jscomp$inline_6230_or__5025__auto____$1$jscomp$inline_6231$$)?
$and__5023__auto__$jscomp$inline_6229_and__5023__auto__$jscomp$inline_6235_or__5025__auto__$jscomp$inline_6230_or__5025__auto____$1$jscomp$inline_6231$$:$APP.$cuerdas$core$includes_QMARK_$$($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$,
"webkit-masked-url://"))):$or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$=$and__5023__auto__$jscomp$inline_6229_and__5023__auto__$jscomp$inline_6235_or__5025__auto__$jscomp$inline_6230_or__5025__auto____$1$jscomp$inline_6231$$;
if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$))return $or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$;
$or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$=$and__5023__auto__$jscomp$357_cause$jscomp$67$$.stack;$or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$=
($and__5023__auto__$jscomp$inline_6229_and__5023__auto__$jscomp$inline_6235_or__5025__auto__$jscomp$inline_6230_or__5025__auto____$1$jscomp$inline_6231$$=typeof $or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$==="string")?$APP.$cuerdas$core$includes_QMARK_$$($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$,
"posthog"):$and__5023__auto__$jscomp$inline_6229_and__5023__auto__$jscomp$inline_6235_or__5025__auto__$jscomp$inline_6230_or__5025__auto____$1$jscomp$inline_6231$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$)||
($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($message$jscomp$92$$,"Possible side-effect in debug-evaluate"))||($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($message$jscomp$92$$,"Unexpected end of input"))||($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$=$APP.$cuerdas$core$starts_with_QMARK_$$($message$jscomp$92$$,"invalid props on component"))||
($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$=$APP.$cuerdas$core$starts_with_QMARK_$$($message$jscomp$92$$,"Unexpected token "))||($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$357_cause$jscomp$67$$.name,"AbortError"))||($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$=$APP.$cuerdas$core$starts_with_QMARK_$$($message$jscomp$92$$,
"Cannot assign to read only property 'toString'"))||($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$357_cause$jscomp$67$$.name,"TypeError")&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($message$jscomp$92$$,
"Attempting to change value of a readonly property"))?$or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$78_or__5025__auto____$2$jscomp$22_or__5025__auto____$3$jscomp$8_or__5025__auto____$4$jscomp$5_or__5025__auto____$5$jscomp$3_or__5025__auto____$6$jscomp$3_or__5025__auto____$7$jscomp$3_or__5025__auto____$8$jscomp$2_stack$jscomp$inline_6228_stack$jscomp$inline_6234$$:($and__5023__auto__$jscomp$357_cause$jscomp$67$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$357_cause$jscomp$67$$.name,
"NotFoundError"))?$APP.$cuerdas$core$includes_QMARK_$$($message$jscomp$92$$,"removeChild"):$and__5023__auto__$jscomp$357_cause$jscomp$67$$};$app$main$errors$from_plugin_QMARK_$$=function($cause$jscomp$68$$){try{return(0,$APP.$app$main$errors$is_plugin_error_QMARK_$$)($cause$jscomp$68$$)}catch($e56193$$){return!1}};
$app$common$schema$messages$translate_code$$=function($code$jscomp$30$$){return $APP.$cljs$core$vector_QMARK_$$($code$jscomp$30$$)?$APP.$app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($code$jscomp$30$$,0),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$i18n$c$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($code$jscomp$30$$,1))])):(0,$APP.$app$common$i18n$tr$$)($code$jscomp$30$$)};
$app$common$schema$messages$handle_error_fn$$=function($JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$,$JSCompiler_temp$jscomp$10834_JSCompiler_temp_const$jscomp$10835_problem$$){$JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$=$APP.$cljs$cst$884$error_SLASH_fn$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$);
$JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$=$JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10834_JSCompiler_temp_const$jscomp$10835_problem$$):
$JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$($JSCompiler_temp$jscomp$10834_JSCompiler_temp_const$jscomp$10835_problem$$);if(typeof $JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$==="string")$JSCompiler_temp$jscomp$10834_JSCompiler_temp_const$jscomp$10835_problem$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$],
null);else{$JSCompiler_temp$jscomp$10834_JSCompiler_temp_const$jscomp$10835_problem$$=$APP.$cljs$cst$141$message$$;var $G__55324$jscomp$inline_12322_or__5025__auto__$jscomp$inline_12321$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$,$APP.$cljs$cst$273$code$$);$G__55324$jscomp$inline_12322_or__5025__auto__$jscomp$inline_12321$$=$G__55324$jscomp$inline_12322_or__5025__auto__$jscomp$inline_12321$$==
null?null:$app$common$schema$messages$translate_code$$($G__55324$jscomp$inline_12322_or__5025__auto__$jscomp$inline_12321$$);$APP.$cljs$core$truth_$$($G__55324$jscomp$inline_12322_or__5025__auto__$jscomp$inline_12321$$)?$JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$=$G__55324$jscomp$inline_12322_or__5025__auto__$jscomp$inline_12321$$:($JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$,$APP.$cljs$cst$141$message$$),$JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$)?$JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$:
(0,$APP.$app$common$i18n$tr$$)("errors.invalid-data"));$JSCompiler_temp$jscomp$10834_JSCompiler_temp_const$jscomp$10835_problem$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$JSCompiler_temp$jscomp$10834_JSCompiler_temp_const$jscomp$10835_problem$$,$JSCompiler_inline_result$jscomp$10836_or__5025__auto____$1$jscomp$inline_12323_props$jscomp$138_result$jscomp$262_v_fn$$],null)}return $JSCompiler_temp$jscomp$10834_JSCompiler_temp_const$jscomp$10835_problem$$};
$app$common$schema$messages$handle_error_code$$=function($code$jscomp$31_props$jscomp$140$$){$code$jscomp$31_props$jscomp$140$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$31_props$jscomp$140$$,$APP.$cljs$cst$945$error_SLASH_code$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$app$common$schema$messages$translate_code$$($code$jscomp$31_props$jscomp$140$$)],null)};
$APP.$app$common$schema$messages$interpret_schema_problem$$=function($acc$jscomp$120$$,$map__55336__$1_p__55332$$){$map__55336__$1_p__55332$$=$APP.$cljs$core$__destructure_map$$($map__55336__$1_p__55332$$);var $schema$jscomp$238_tprops$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55336__$1_p__55332$$,$APP.$cljs$cst$298$schema$$),$field_field__$1_in$$jscomp$61$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55336__$1_p__55332$$,$APP.$cljs$cst$297$in$$),$value$jscomp$522$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55336__$1_p__55332$$,$APP.$cljs$cst$260$value$$),$type$jscomp$437$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55336__$1_p__55332$$,$APP.$cljs$cst$139$type$$),$props$jscomp$141$$=$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$238_tprops$$);$schema$jscomp$238_tprops$$=$malli$core$type_properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$238_tprops$$);var $or__5025__auto__$jscomp$inline_6239$$=
$APP.$cljs$cst$3388$error_SLASH_field$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$141$$);$field_field__$1_in$$jscomp$61$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_6239$$)?$or__5025__auto__$jscomp$inline_6239$$:$field_field__$1_in$$jscomp$61$$;$field_field__$1_in$$jscomp$61$$=$APP.$cljs$core$vector_QMARK_$$($field_field__$1_in$$jscomp$61$$)?$field_field__$1_in$$jscomp$61$$:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$field_field__$1_in$$jscomp$61$$],
null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($field_field__$1_in$$jscomp$61$$))&&$APP.$cljs$core$contains_QMARK_$$($acc$jscomp$120$$,$APP.$cljs$core$first$$($field_field__$1_in$$jscomp$61$$))?$acc$jscomp$120$$:$field_field__$1_in$$jscomp$61$$==null||$APP.$cljs$core$empty_QMARK_$$($field_field__$1_in$$jscomp$61$$)?$acc$jscomp$120$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$437$$,$cljs$cst$451$malli_DOT_core_SLASH_missing_key$$)||
$value$jscomp$522$$==null?$APP.$cljs$core$assoc_in$$($acc$jscomp$120$$,$field_field__$1_in$$jscomp$61$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,(0,$APP.$app$common$i18n$tr$$)("errors.field-missing")],null)):$APP.$cljs$core$contains_QMARK_$$($props$jscomp$141$$,$APP.$cljs$cst$884$error_SLASH_fn$$)?$APP.$cljs$core$assoc_in$$($acc$jscomp$120$$,$field_field__$1_in$$jscomp$61$$,$app$common$schema$messages$handle_error_fn$$($props$jscomp$141$$,$map__55336__$1_p__55332$$)):
$APP.$cljs$core$contains_QMARK_$$($props$jscomp$141$$,$APP.$cljs$cst$882$error_SLASH_message$$)?$APP.$cljs$core$assoc_in$$($acc$jscomp$120$$,$field_field__$1_in$$jscomp$61$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$141$$,$APP.$cljs$cst$882$error_SLASH_message$$)],null)):$APP.$cljs$core$contains_QMARK_$$($props$jscomp$141$$,$APP.$cljs$cst$945$error_SLASH_code$$)?$APP.$cljs$core$assoc_in$$($acc$jscomp$120$$,
$field_field__$1_in$$jscomp$61$$,$app$common$schema$messages$handle_error_code$$($props$jscomp$141$$)):$APP.$cljs$core$contains_QMARK_$$($schema$jscomp$238_tprops$$,$APP.$cljs$cst$884$error_SLASH_fn$$)?$APP.$cljs$core$assoc_in$$($acc$jscomp$120$$,$field_field__$1_in$$jscomp$61$$,$app$common$schema$messages$handle_error_fn$$($schema$jscomp$238_tprops$$,$map__55336__$1_p__55332$$)):$APP.$cljs$core$contains_QMARK_$$($schema$jscomp$238_tprops$$,$APP.$cljs$cst$882$error_SLASH_message$$)?$APP.$cljs$core$assoc_in$$($acc$jscomp$120$$,
$field_field__$1_in$$jscomp$61$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$238_tprops$$,$APP.$cljs$cst$882$error_SLASH_message$$)],null)):$APP.$cljs$core$contains_QMARK_$$($schema$jscomp$238_tprops$$,$APP.$cljs$cst$945$error_SLASH_code$$)?$APP.$cljs$core$assoc_in$$($acc$jscomp$120$$,$field_field__$1_in$$jscomp$61$$,$app$common$schema$messages$handle_error_code$$($schema$jscomp$238_tprops$$)):$APP.$cljs$core$assoc_in$$($acc$jscomp$120$$,
$field_field__$1_in$$jscomp$61$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,(0,$APP.$app$common$i18n$tr$$)("errors.invalid-data")],null))};
$app$common$schema$messages$apply_validators$$=function($validators$jscomp$5$$,$state$jscomp$238$$,$errors$jscomp$14$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($errors__$1$jscomp$1$$,$JSCompiler_inline_result$jscomp$1084_validator_fn$$){var $JSCompiler_temp_const$jscomp$1082$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$,$G__55347$jscomp$inline_6241$$=$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$238$$);$JSCompiler_inline_result$jscomp$1084_validator_fn$$=
$JSCompiler_inline_result$jscomp$1084_validator_fn$$.$cljs$core$IFn$_invoke$arity$2$?$JSCompiler_inline_result$jscomp$1084_validator_fn$$.$cljs$core$IFn$_invoke$arity$2$($errors__$1$jscomp$1$$,$G__55347$jscomp$inline_6241$$):$JSCompiler_inline_result$jscomp$1084_validator_fn$$($errors__$1$jscomp$1$$,$G__55347$jscomp$inline_6241$$);return $JSCompiler_temp_const$jscomp$1082$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$errors__$1$jscomp$1$$,$JSCompiler_inline_result$jscomp$1084_validator_fn$$]))},
$errors$jscomp$14$$,$validators$jscomp$5$$)};
$app$plugins$flags$clear$$=function($id$jscomp$405$$){typeof $app$plugins$flags$reset_55464$$==="undefined"&&($app$plugins$flags$reset_55464$$=function($id$jscomp$406$$,$meta55465$$){this.id=$id$jscomp$406$$;this.$meta55465$=$meta55465$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$plugins$flags$reset_55464$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$plugins$flags$reset_55464$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3392$app_DOT_plugins_DOT_flags_SLASH_reset$$},
$app$plugins$flags$reset_55464$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55466$$,$meta55465__$1$$){return new $app$plugins$flags$reset_55464$$(this.id,$meta55465__$1$$)},$app$plugins$flags$reset_55464$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55465$},$app$plugins$flags$reset_55464$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$plugins$flags$reset_55464$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1786$$,
$state$jscomp$242$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$242$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3197$plugins$$,$APP.$cljs$cst$1467$flags$$],null),$APP.$cljs$core$assoc$$,this.id,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)});return new $app$plugins$flags$reset_55464$$($id$jscomp$405$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$plugins$save_plugin_permissions_peek$$=function($id$jscomp$409$$,$permissions$jscomp$6$$){typeof $app$main$data$plugins$save_plugin_permissions_peek_66063$$==="undefined"&&($app$main$data$plugins$save_plugin_permissions_peek_66063$$=function($id$jscomp$410$$,$permissions$jscomp$7$$,$meta66064$$){this.id=$id$jscomp$410$$;this.permissions=$permissions$jscomp$7$$;this.$meta66064$=$meta66064$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$plugins$save_plugin_permissions_peek_66063$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$save_plugin_permissions_peek_66063$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3396$app_DOT_main_DOT_data_DOT_plugins_SLASH_save_plugin_permissions_peek$$},$app$main$data$plugins$save_plugin_permissions_peek_66063$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66065$$,$meta66064__$1$$){return new $app$main$data$plugins$save_plugin_permissions_peek_66063$$(this.id,
this.permissions,$meta66064__$1$$)},$app$main$data$plugins$save_plugin_permissions_peek_66063$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66064$},$app$main$data$plugins$save_plugin_permissions_peek_66063$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$save_plugin_permissions_peek_66063$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1788$$,$state$jscomp$244$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$244$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2227$plugins_permissions_peek$$,$APP.$cljs$cst$142$data$$,this.id],null),this.permissions)});return new $app$main$data$plugins$save_plugin_permissions_peek_66063$$($id$jscomp$409$$,$permissions$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$plugins$fetch_manifest$$=function($plugin_url$jscomp$1$$){return $APP.$beicon$v2$core$map$$(function($p1__66068_SHARP_$$){return $app$plugins$register$parse_manifest$$($plugin_url$jscomp$1$$,$p1__66068_SHARP_$$)},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1581$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$,$APP.$cljs$cst$1579$uri$$,$plugin_url$jscomp$1$$,$APP.$cljs$cst$1582$omit_default_headers$$,
!0,$APP.$cljs$cst$1587$response_type$$,$cljs$cst$923$json$$],null))))};
$app$main$data$plugins$save_current_plugin$$=function($id$jscomp$411$$){typeof $app$main$data$plugins$save_current_plugin_66070$$==="undefined"&&($app$main$data$plugins$save_current_plugin_66070$$=function($id$jscomp$412$$,$meta66071$$){this.id=$id$jscomp$412$$;this.$meta66071$=$meta66071$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$plugins$save_current_plugin_66070$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$plugins$save_current_plugin_66070$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3397$app_DOT_main_DOT_data_DOT_plugins_SLASH_save_current_plugin$$},$app$main$data$plugins$save_current_plugin_66070$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66072$$,$meta66071__$1$$){return new $app$main$data$plugins$save_current_plugin_66070$$(this.id,$meta66071__$1$$)},$app$main$data$plugins$save_current_plugin_66070$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66071$},$app$main$data$plugins$save_current_plugin_66070$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$save_current_plugin_66070$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1789$$,$state$jscomp$245$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$245$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$cljs$cst$3398$open_plugins$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),this.id)});return new $app$main$data$plugins$save_current_plugin_66070$$($id$jscomp$411$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$plugins$remove_current_plugin$$=function($id$jscomp$413$$){typeof $app$main$data$plugins$remove_current_plugin_66120$$==="undefined"&&($app$main$data$plugins$remove_current_plugin_66120$$=function($id$jscomp$414$$,$meta66121$$){this.id=$id$jscomp$414$$;this.$meta66121$=$meta66121$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$plugins$remove_current_plugin_66120$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$plugins$remove_current_plugin_66120$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3399$app_DOT_main_DOT_data_DOT_plugins_SLASH_remove_current_plugin$$},$app$main$data$plugins$remove_current_plugin_66120$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66122$$,$meta66121__$1$$){return new $app$main$data$plugins$remove_current_plugin_66120$$(this.id,$meta66121__$1$$)},$app$main$data$plugins$remove_current_plugin_66120$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66121$},$app$main$data$plugins$remove_current_plugin_66120$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$remove_current_plugin_66120$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1790$$,$state$jscomp$246$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$246$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$cljs$cst$3398$open_plugins$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$disj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),this.id)});return new $app$main$data$plugins$remove_current_plugin_66120$$($id$jscomp$413$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$plugins$start_plugin_BANG_$$=function($p__66167_plugin_id$jscomp$9$$,$extensions$$){var $allow_background_map__66168__$1$$=$APP.$cljs$core$__destructure_map$$($p__66167_plugin_id$jscomp$9$$);$p__66167_plugin_id$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allow_background_map__66168__$1$$,$APP.$cljs$cst$1720$plugin_id$$);var $name$jscomp$277$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allow_background_map__66168__$1$$,$APP.$cljs$cst$725$name$$),$version$jscomp$15$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allow_background_map__66168__$1$$,$APP.$cljs$cst$2289$version$$),$description$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allow_background_map__66168__$1$$,$APP.$cljs$cst$936$description$$),$host$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allow_background_map__66168__$1$$,$APP.$cljs$cst$744$host$$),$code$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allow_background_map__66168__$1$$,
$APP.$cljs$cst$273$code$$),$permissions$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allow_background_map__66168__$1$$,$APP.$cljs$cst$1722$permissions$$);$allow_background_map__66168__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allow_background_map__66168__$1$$,$cljs$cst$3400$allow_background$$);return $promesa$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$.\u0275loadPlugin({pluginId:$p__66167_plugin_id$jscomp$9$$,name:$name$jscomp$277$$,
version:$version$jscomp$15$$,description:$description$jscomp$13$$,host:$host$jscomp$8$$,code:$code$jscomp$36$$,allowBackground:$APP.$cljs$core$boolean$0$$($allow_background_map__66168__$1$$),permissions:$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$permissions$jscomp$8$$)},null,$extensions$$),function($cause$jscomp$72$$){$app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cause$jscomp$72$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,
"Plugin Error"]));return $app$main$errors$flash$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$145$cause$$,$cause$jscomp$72$$,$APP.$cljs$cst$139$type$$,$cljs$cst$3366$handled$$]))})};
$app$main$data$plugins$load_plugin_BANG_$$=function($name$jscomp$278_p__66178$$){var $map__66179__$1_permissions$jscomp$9$$=$APP.$cljs$core$__destructure_map$$($name$jscomp$278_p__66178$$),$plugin_id$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66179__$1_permissions$jscomp$9$$,$APP.$cljs$cst$1720$plugin_id$$);$name$jscomp$278_p__66178$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66179__$1_permissions$jscomp$9$$,$APP.$cljs$cst$725$name$$);var $version$jscomp$16$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66179__$1_permissions$jscomp$9$$,$APP.$cljs$cst$2289$version$$),$description$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66179__$1_permissions$jscomp$9$$,$APP.$cljs$cst$936$description$$),$host$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66179__$1_permissions$jscomp$9$$,$APP.$cljs$cst$744$host$$),$code$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66179__$1_permissions$jscomp$9$$,
$APP.$cljs$cst$273$code$$),$icon$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66179__$1_permissions$jscomp$9$$,$APP.$cljs$cst$1721$icon$$);$map__66179__$1_permissions$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66179__$1_permissions$jscomp$9$$,$APP.$cljs$cst$1722$permissions$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$flags$clear$$($plugin_id$jscomp$10$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$plugins$save_current_plugin$$($plugin_id$jscomp$10$$)]));
return $promesa$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$.\u0275loadPlugin({pluginId:$plugin_id$jscomp$10$$,name:$name$jscomp$278_p__66178$$,description:$description$jscomp$14$$,version:$version$jscomp$16$$,host:$host$jscomp$9$$,code:$code$jscomp$37$$,icon:$icon$jscomp$1$$,permissions:$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$map__66179__$1_permissions$jscomp$9$$)},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$remove_current_plugin$$($plugin_id$jscomp$10$$))}),
function($cause$jscomp$73$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$remove_current_plugin$$($plugin_id$jscomp$10$$));$app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cause$jscomp$73$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,"Plugin Error"]));return $app$main$errors$flash$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$145$cause$$,
$cause$jscomp$73$$,$APP.$cljs$cst$139$type$$,$cljs$cst$3366$handled$$]))})};
$APP.$app$main$data$plugins$open_plugin_BANG_$$=function($p__66198_url$jscomp$86$$,$user_can_edit_QMARK_$$){var $map__66199__$1$$=$APP.$cljs$core$__destructure_map$$($p__66198_url$jscomp$86$$);$p__66198_url$jscomp$86$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66199__$1$$,$APP.$cljs$cst$1975$url$$);return $APP.$cljs$core$truth_$$($p__66198_url$jscomp$86$$)?$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($new_manifest_permissions$jscomp$10$$){var $new_manifest__$1$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$new_manifest_permissions$jscomp$10$$,
$APP.$cljs$core$select_keys$$($map__66199__$1$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1720$plugin_id$$],null))]));$new_manifest_permissions$jscomp$10$$=$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($new_manifest__$1$$);var $is_edition_plugin_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($new_manifest_permissions$jscomp$10$$,"content:write")||$APP.$cljs$core$contains_QMARK_$$($new_manifest_permissions$jscomp$10$$,
"library:write");$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$plugins$save_plugin_permissions_peek$$($APP.$cljs$cst$1720$plugin_id$$.$cljs$core$IFn$_invoke$arity$1$($new_manifest__$1$$),$new_manifest_permissions$jscomp$10$$));if($is_edition_plugin_QMARK_$$&&$APP.$cljs$core$not$$($user_can_edit_QMARK_$$))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$warn$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.error.need-editor")));
if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($new_manifest__$1$$),$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($map__66199__$1$$)))return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$3401$plugin_permissions_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3402$plugin$$,$new_manifest__$1$$,$APP.$cljs$cst$2479$on_accept$$,function(){$APP.$app$plugins$register$install_plugin_BANG_$$($new_manifest__$1$$);
return $app$main$data$plugins$load_plugin_BANG_$$($new_manifest__$1$$)}],null));$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_manifest__$1$$,$map__66199__$1$$)&&$APP.$app$plugins$register$install_plugin_BANG_$$($new_manifest__$1$$);return $app$main$data$plugins$load_plugin_BANG_$$($map__66199__$1$$)},function(){return $app$main$data$plugins$load_plugin_BANG_$$($map__66199__$1$$)},$APP.$app$main$data$plugins$fetch_manifest$$($p__66198_url$jscomp$86$$)):$app$main$data$plugins$load_plugin_BANG_$$($map__66199__$1$$)};
$app$main$data$plugins$close_plugin_BANG_$$=function($map__66220__$1_p__66219_plugin_id$jscomp$11$$){$map__66220__$1_p__66219_plugin_id$jscomp$11$$=$APP.$cljs$core$__destructure_map$$($map__66220__$1_p__66219_plugin_id$jscomp$11$$);$map__66220__$1_p__66219_plugin_id$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66220__$1_p__66219_plugin_id$jscomp$11$$,$APP.$cljs$cst$1720$plugin_id$$);try{$APP.$app$util$globals$global$$.\u0275unloadPlugin($map__66220__$1_p__66219_plugin_id$jscomp$11$$)}catch($e66221$$){console.error("Error",
$e66221$$)}};
$app$main$data$plugins$close_current_plugin$$=function($var_args$jscomp$1173$$){for(var $args__5755__auto__$jscomp$210$$=[],$len__5749__auto___66372$$=arguments.length,$i__5750__auto___66373$$=0;;)if($i__5750__auto___66373$$<$len__5749__auto___66372$$)$args__5755__auto__$jscomp$210$$.push(arguments[$i__5750__auto___66373$$]),$i__5750__auto___66373$$+=1;else break;return $app$main$data$plugins$close_current_plugin$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$210$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$210$$.slice(0),
0,null):null)};
$app$main$data$plugins$close_current_plugin$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__66230$$){var $map__66231__$1$$=$APP.$cljs$core$__destructure_map$$($p__66230$$),$close_only_edition_plugins_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66231__$1$$,$cljs$cst$3403$close_only_edition_plugins_QMARK_$$);typeof $app$main$data$plugins$close_current_plugin_66232$$==="undefined"&&($app$main$data$plugins$close_current_plugin_66232$$=function($p__66230$jscomp$1$$,$map__66231$jscomp$1$$,
$close_only_edition_plugins_QMARK_$jscomp$1$$,$meta66233$$){this.$p__66230$=$p__66230$jscomp$1$$;this.$map__66231$=$map__66231$jscomp$1$$;this.$close_only_edition_plugins_QMARK_$=$close_only_edition_plugins_QMARK_$jscomp$1$$;this.$meta66233$=$meta66233$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$plugins$close_current_plugin_66232$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$close_current_plugin_66232$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3404$app_DOT_main_DOT_data_DOT_plugins_SLASH_close_current_plugin$$},$app$main$data$plugins$close_current_plugin_66232$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66234$$,$meta66233__$1$$){return new $app$main$data$plugins$close_current_plugin_66232$$(this.$p__66230$,this.$map__66231$,this.$close_only_edition_plugins_QMARK_$,$meta66233__$1$$)},$app$main$data$plugins$close_current_plugin_66232$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66233$},
$app$main$data$plugins$close_current_plugin_66232$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$close_current_plugin_66232$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($G__66391__$jscomp$1791_ids$jscomp$46_seq__66246_seq__66246__$1_temp__5825__auto__$jscomp$192$$,$state$jscomp$247$$){$G__66391__$jscomp$1791_ids$jscomp$46_seq__66246_seq__66246__$1_temp__5825__auto__$jscomp$192$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$247$$,
$APP.$cljs$cst$1920$workspace_local$$),$cljs$cst$3398$open_plugins$$);$G__66391__$jscomp$1791_ids$jscomp$46_seq__66246_seq__66246__$1_temp__5825__auto__$jscomp$192$$=$APP.$cljs$core$seq$$($G__66391__$jscomp$1791_ids$jscomp$46_seq__66246_seq__66246__$1_temp__5825__auto__$jscomp$192$$);for(var $G__66392_chunk__66247_is_edition_plugin_QMARK__66397_permissions_66396$$=null,$G__66393_c__5548__auto__$jscomp$18_count__66248$$=0,$i__66249$$=0;;)if($i__66249$$<$G__66393_c__5548__auto__$jscomp$18_count__66248$$){var $id$jscomp$415$$=
$G__66392_chunk__66247_is_edition_plugin_QMARK__66397_permissions_66396$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__66249$$),$plugin_66384$$=$app$plugins$register$get_plugin$$($id$jscomp$415$$),$is_edition_plugin_QMARK__66386_permissions_66385$$=function(){var $or__5025__auto__$jscomp$631$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$247$$,$APP.$cljs$cst$2227$plugins_permissions_peek$$),
$APP.$cljs$cst$142$data$$),$id$jscomp$415$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$631$$)?$or__5025__auto__$jscomp$631$$:$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($plugin_66384$$)}();$is_edition_plugin_QMARK__66386_permissions_66385$$=$APP.$cljs$core$contains_QMARK_$$($is_edition_plugin_QMARK__66386_permissions_66385$$,"content:write")||$APP.$cljs$core$contains_QMARK_$$($is_edition_plugin_QMARK__66386_permissions_66385$$,"library:write");($APP.$cljs$core$not$$(this.$close_only_edition_plugins_QMARK_$)||
$is_edition_plugin_QMARK__66386_permissions_66385$$)&&$app$main$data$plugins$close_plugin_BANG_$$($plugin_66384$$);$i__66249$$+=1}else if($G__66391__$jscomp$1791_ids$jscomp$46_seq__66246_seq__66246__$1_temp__5825__auto__$jscomp$192$$=$APP.$cljs$core$seq$$($G__66391__$jscomp$1791_ids$jscomp$46_seq__66246_seq__66246__$1_temp__5825__auto__$jscomp$192$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($G__66391__$jscomp$1791_ids$jscomp$46_seq__66246_seq__66246__$1_temp__5825__auto__$jscomp$192$$))$G__66393_c__5548__auto__$jscomp$18_count__66248$$=
$APP.$cljs$core$_chunked_first$$($G__66391__$jscomp$1791_ids$jscomp$46_seq__66246_seq__66246__$1_temp__5825__auto__$jscomp$192$$),$G__66391__$jscomp$1791_ids$jscomp$46_seq__66246_seq__66246__$1_temp__5825__auto__$jscomp$192$$=$APP.$cljs$core$_chunked_rest$$($G__66391__$jscomp$1791_ids$jscomp$46_seq__66246_seq__66246__$1_temp__5825__auto__$jscomp$192$$),$G__66392_chunk__66247_is_edition_plugin_QMARK__66397_permissions_66396$$=$G__66393_c__5548__auto__$jscomp$18_count__66248$$,$G__66393_c__5548__auto__$jscomp$18_count__66248$$=
$APP.$cljs$core$count$$($G__66393_c__5548__auto__$jscomp$18_count__66248$$);else{$id$jscomp$415$$=$APP.$cljs$core$first$$($G__66391__$jscomp$1791_ids$jscomp$46_seq__66246_seq__66246__$1_temp__5825__auto__$jscomp$192$$);var $plugin_66395$$=$app$plugins$register$get_plugin$$($id$jscomp$415$$);$G__66392_chunk__66247_is_edition_plugin_QMARK__66397_permissions_66396$$=function(){var $or__5025__auto__$jscomp$632$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$247$$,
$APP.$cljs$cst$2227$plugins_permissions_peek$$),$APP.$cljs$cst$142$data$$),$id$jscomp$415$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$632$$)?$or__5025__auto__$jscomp$632$$:$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($plugin_66395$$)}();$G__66392_chunk__66247_is_edition_plugin_QMARK__66397_permissions_66396$$=$APP.$cljs$core$contains_QMARK_$$($G__66392_chunk__66247_is_edition_plugin_QMARK__66397_permissions_66396$$,"content:write")||$APP.$cljs$core$contains_QMARK_$$($G__66392_chunk__66247_is_edition_plugin_QMARK__66397_permissions_66396$$,
"library:write");($APP.$cljs$core$not$$(this.$close_only_edition_plugins_QMARK_$)||$G__66392_chunk__66247_is_edition_plugin_QMARK__66397_permissions_66396$$)&&$app$main$data$plugins$close_plugin_BANG_$$($plugin_66395$$);$G__66391__$jscomp$1791_ids$jscomp$46_seq__66246_seq__66246__$1_temp__5825__auto__$jscomp$192$$=$APP.$cljs$core$next$$($G__66391__$jscomp$1791_ids$jscomp$46_seq__66246_seq__66246__$1_temp__5825__auto__$jscomp$192$$);$G__66392_chunk__66247_is_edition_plugin_QMARK__66397_permissions_66396$$=
null;$G__66393_c__5548__auto__$jscomp$18_count__66248$$=0}$i__66249$$=0}else return null});return new $app$main$data$plugins$close_current_plugin_66232$$($p__66230$$,$map__66231__$1$$,$close_only_edition_plugins_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$plugins$check_open_plugin$$=function(){typeof $app$main$data$plugins$check_open_plugin_66285$$==="undefined"&&($app$main$data$plugins$check_open_plugin_66285$$=function($meta66286$$){this.$meta66286$=$meta66286$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$plugins$check_open_plugin_66285$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$check_open_plugin_66285$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3407$app_DOT_main_DOT_data_DOT_plugins_SLASH_check_open_plugin$$},$app$main$data$plugins$check_open_plugin_66285$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66287$$,$meta66286__$1$$){return new $app$main$data$plugins$check_open_plugin_66285$$($meta66286__$1$$)},$app$main$data$plugins$check_open_plugin_66285$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66286$},$app$main$data$plugins$check_open_plugin_66285$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$check_open_plugin_66285$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1793_user_can_edit_QMARK_$jscomp$1$$,$plugin$jscomp$4_state$jscomp$249_temp__5825__auto__$jscomp$193$$){$_$jscomp$1793_user_can_edit_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($plugin$jscomp$4_state$jscomp$249_temp__5825__auto__$jscomp$193$$,$APP.$cljs$cst$1722$permissions$$),
$APP.$cljs$cst$1596$can_edit$$);$plugin$jscomp$4_state$jscomp$249_temp__5825__auto__$jscomp$193$$=$APP.$cljs$cst$3406$app_DOT_main_DOT_data_DOT_plugins_SLASH_open_plugin$$.$cljs$core$IFn$_invoke$arity$1$($plugin$jscomp$4_state$jscomp$249_temp__5825__auto__$jscomp$193$$);return $APP.$cljs$core$truth_$$($plugin$jscomp$4_state$jscomp$249_temp__5825__auto__$jscomp$193$$)?($plugin$jscomp$4_state$jscomp$249_temp__5825__auto__$jscomp$193$$=$app$plugins$register$get_plugin$$($plugin$jscomp$4_state$jscomp$249_temp__5825__auto__$jscomp$193$$),
$APP.$app$main$data$plugins$open_plugin_BANG_$$($plugin$jscomp$4_state$jscomp$249_temp__5825__auto__$jscomp$193$$,$_$jscomp$1793_user_can_edit_QMARK_$jscomp$1$$),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"start-plugin",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace",$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($plugin$jscomp$4_state$jscomp$249_temp__5825__auto__$jscomp$193$$),
$APP.$cljs$cst$744$host$$,$APP.$cljs$cst$744$host$$.$cljs$core$IFn$_invoke$arity$1$($plugin$jscomp$4_state$jscomp$249_temp__5825__auto__$jscomp$193$$)],null)),function($p1__66283_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__66283_SHARP_$$,$APP.$cljs$cst$3406$app_DOT_main_DOT_data_DOT_plugins_SLASH_open_plugin$$)})):null});return new $app$main$data$plugins$check_open_plugin_66285$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$attrs$get_attr$$=function($obj$jscomp$196_rect$jscomp$28$$,$attr$jscomp$38$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($obj$jscomp$196_rect$jscomp$28$$,$attr$jscomp$38$$),$APP.$cljs$cst$1616$multiple$$))return $APP.$cljs$cst$1616$multiple$$;if($APP.$cljs$core$truth_$$(function(){var $fexpr__55470$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3412$ox$$,
null,$APP.$cljs$cst$3413$oy$$,null],null),null);return $fexpr__55470$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__55470$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$38$$):$fexpr__55470$$($attr$jscomp$38$$)}())){var $temp__5823__auto__$jscomp$161_temp__5823__auto____$1$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($obj$jscomp$196_rect$jscomp$28$$,$attr$jscomp$38$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$161_temp__5823__auto____$1$jscomp$12$$))return $temp__5823__auto__$jscomp$161_temp__5823__auto____$1$jscomp$12$$;
$temp__5823__auto__$jscomp$161_temp__5823__auto____$1$jscomp$12$$=$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$196_rect$jscomp$28$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$161_temp__5823__auto____$1$jscomp$12$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$161_temp__5823__auto____$1$jscomp$12$$,$APP.$cljs$cst$1616$multiple$$)?($obj$jscomp$196_rect$jscomp$28$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$obj$jscomp$196_rect$jscomp$28$$],null)),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$38$$,$APP.$cljs$cst$3412$ox$$)?$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$196_rect$jscomp$28$$):$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$196_rect$jscomp$28$$)):$APP.$cljs$cst$1616$multiple$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($obj$jscomp$196_rect$jscomp$28$$,$attr$jscomp$38$$,
$cljs$cst$3414$app_DOT_common_DOT_attrs_SLASH_unset$$)}if($APP.$cljs$core$truth_$$(function(){var $fexpr__55471$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1522$height$$,null],null),null);return $fexpr__55471$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__55471$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$38$$):$fexpr__55471$$($attr$jscomp$38$$)}())){$temp__5823__auto__$jscomp$161_temp__5823__auto____$1$jscomp$12$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($obj$jscomp$196_rect$jscomp$28$$,$attr$jscomp$38$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$161_temp__5823__auto____$1$jscomp$12$$))return $temp__5823__auto__$jscomp$161_temp__5823__auto____$1$jscomp$12$$;$temp__5823__auto__$jscomp$161_temp__5823__auto____$1$jscomp$12$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$196_rect$jscomp$28$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$161_temp__5823__auto____$1$jscomp$12$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$161_temp__5823__auto____$1$jscomp$12$$,$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$196_rect$jscomp$28$$),$attr$jscomp$38$$):$APP.$cljs$cst$1616$multiple$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($obj$jscomp$196_rect$jscomp$28$$,$attr$jscomp$38$$,$cljs$cst$3414$app_DOT_common_DOT_attrs_SLASH_unset$$)}return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($obj$jscomp$196_rect$jscomp$28$$,
$attr$jscomp$38$$,$cljs$cst$3414$app_DOT_common_DOT_attrs_SLASH_unset$$)};$app$common$attrs$default_equal$$=function($val1$jscomp$6$$,$val2$jscomp$6$$){return typeof $val1$jscomp$6$$==="number"&&typeof $val2$jscomp$6$$==="number"?$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($val1$jscomp$6$$,$val2$jscomp$6$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($val1$jscomp$6$$,$val2$jscomp$6$$)};
$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objs$jscomp$15$$,$attrs$jscomp$63$$){return $APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$04$$($objs$jscomp$15$$,$attrs$jscomp$63$$,$app$common$attrs$default_equal$$,$APP.$cljs$core$identity$$)};
$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$04$$=function($objs$jscomp$16$$,$G__55549_attrs$jscomp$64$$,$eqfn$jscomp$1$$,$sel$jscomp$4$$){for(var $attr$jscomp$39$$=$APP.$cljs$core$first$$($G__55549_attrs$jscomp$64$$),$G__55550_attrs__$1$jscomp$8$$=$APP.$cljs$core$rest$$($G__55549_attrs$jscomp$64$$),$result$jscomp$263$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);;)if($APP.$cljs$core$truth_$$($attr$jscomp$39$$)){var $value$jscomp$537$$=function(){for(var $G__55546_curr$jscomp$2_new_val$jscomp$5$$=
$APP.$cljs$core$first$$($objs$jscomp$16$$),$G__55547_objs__$1$$=$APP.$cljs$core$rest$$($objs$jscomp$16$$),$G__55548_value$jscomp$538_value__$1$jscomp$15$$=$cljs$cst$3414$app_DOT_common_DOT_attrs_SLASH_unset$$;;){var $JSCompiler_inline_result$jscomp$1085_and__5023__auto__$jscomp$inline_6246$$=$G__55546_curr$jscomp$2_new_val$jscomp$5$$;$JSCompiler_inline_result$jscomp$1085_and__5023__auto__$jscomp$inline_6246$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1085_and__5023__auto__$jscomp$inline_6246$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__55548_value$jscomp$538_value__$1$jscomp$15$$,$APP.$cljs$cst$1616$multiple$$):$JSCompiler_inline_result$jscomp$1085_and__5023__auto__$jscomp$inline_6246$$;if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1085_and__5023__auto__$jscomp$inline_6246$$))$G__55546_curr$jscomp$2_new_val$jscomp$5$$=$app$common$attrs$get_attr$$($G__55546_curr$jscomp$2_new_val$jscomp$5$$,$attr$jscomp$39$$),$G__55548_value$jscomp$538_value__$1$jscomp$15$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__55546_curr$jscomp$2_new_val$jscomp$5$$,$cljs$cst$3414$app_DOT_common_DOT_attrs_SLASH_unset$$)?$G__55548_value$jscomp$538_value__$1$jscomp$15$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__55546_curr$jscomp$2_new_val$jscomp$5$$,$APP.$cljs$cst$1616$multiple$$)?$APP.$cljs$cst$1616$multiple$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__55548_value$jscomp$538_value__$1$jscomp$15$$,$cljs$cst$3414$app_DOT_common_DOT_attrs_SLASH_unset$$)?
$sel$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$sel$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($G__55546_curr$jscomp$2_new_val$jscomp$5$$):$sel$jscomp$4$$($G__55546_curr$jscomp$2_new_val$jscomp$5$$):$APP.$cljs$core$truth_$$($eqfn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$eqfn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($G__55546_curr$jscomp$2_new_val$jscomp$5$$,$G__55548_value$jscomp$538_value__$1$jscomp$15$$):$eqfn$jscomp$1$$($G__55546_curr$jscomp$2_new_val$jscomp$5$$,$G__55548_value$jscomp$538_value__$1$jscomp$15$$))?
$G__55548_value$jscomp$538_value__$1$jscomp$15$$:$APP.$cljs$cst$1616$multiple$$,$G__55546_curr$jscomp$2_new_val$jscomp$5$$=$APP.$cljs$core$first$$($G__55547_objs__$1$$),$G__55547_objs__$1$$=$APP.$cljs$core$rest$$($G__55547_objs__$1$$);else return $G__55548_value$jscomp$538_value__$1$jscomp$15$$}}();$G__55549_attrs$jscomp$64$$=$APP.$cljs$core$first$$($G__55550_attrs__$1$jscomp$8$$);$G__55550_attrs__$1$jscomp$8$$=$APP.$cljs$core$rest$$($G__55550_attrs__$1$jscomp$8$$);var $G__55551$$=function(){var $G__55526$$=
$result$jscomp$263$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$537$$,$cljs$cst$3414$app_DOT_common_DOT_attrs_SLASH_unset$$)?$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($G__55526$$,$attr$jscomp$39$$,$value$jscomp$537$$):$G__55526$$}();$attr$jscomp$39$$=$G__55549_attrs$jscomp$64$$;$result$jscomp$263$$=$G__55551$$}else return $APP.$cljs$core$_persistent_BANG_$$($result$jscomp$263$$)};
$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$=function($data$jscomp$294$$,$objects$jscomp$261$$,$variant_id$jscomp$7$$){return $APP.$cljs$core$reverse$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__55585_SHARP_$$){return $app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$294$$,$p1__55585_SHARP_$$,!0)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__55584_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$261$$,
$p1__55584_SHARP_$$),$APP.$cljs$cst$1627$component_id$$)},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$261$$,$variant_id$jscomp$7$$),$APP.$cljs$cst$1614$shapes$$))))};
$APP.$app$common$files$variant$extract_properties_values$$=function($data$jscomp$296$$,$objects$jscomp$262$$,$variant_id$jscomp$8$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__55589_v$jscomp$577$$){var $k$jscomp$642$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55589_v$jscomp$577$$,0,null);$p__55589_v$jscomp$577$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55589_v$jscomp$577$$,1,null);var $mdata$jscomp$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$merge$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$meta$$,$p__55589_v$jscomp$577$$));return $APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,$k$jscomp$642$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$p__55589_v$jscomp$577$$))],null),$mdata$jscomp$1$$)},$APP.$cljs$core$group_by$$($APP.$cljs$cst$725$name$$,
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2001$variant_properties$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$296$$,$objects$jscomp$262$$,$variant_id$jscomp$8$$)]))))};
$APP.$app$common$files$variant$is_secondary_variant_QMARK_$$=function($component$jscomp$48$$,$data$jscomp$298_objects$jscomp$inline_6252$$){var $shapes$jscomp$34_temp__5825__auto__$jscomp$inline_6250$$=$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$48$$);if($APP.$cljs$core$truth_$$($shapes$jscomp$34_temp__5825__auto__$jscomp$inline_6250$$)){var $page_id$jscomp$inline_6251$$=$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$48$$);
$data$jscomp$298_objects$jscomp$inline_6252$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$298_objects$jscomp$inline_6252$$,$APP.$cljs$cst$1630$pages_index$$),$page_id$jscomp$inline_6251$$),$APP.$cljs$cst$1631$objects$$);$shapes$jscomp$34_temp__5825__auto__$jscomp$inline_6250$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$298_objects$jscomp$inline_6252$$,
$shapes$jscomp$34_temp__5825__auto__$jscomp$inline_6250$$),$APP.$cljs$cst$1614$shapes$$)}else $shapes$jscomp$34_temp__5825__auto__$jscomp$inline_6250$$=null;return $APP.$cljs$core$seq$$($shapes$jscomp$34_temp__5825__auto__$jscomp$inline_6250$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$48$$),$APP.$cljs$core$last$$($shapes$jscomp$34_temp__5825__auto__$jscomp$inline_6250$$))};
$app$common$geom$align$align_to_parent$$=function($shape$jscomp$380$$,$parent$jscomp$207$$,$axis$jscomp$22$$){var $parent_bounds$jscomp$4$$=$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$207$$),$wrapper_rect$jscomp$1$$=$APP.$app$common$geom$rect$points__GT_rect$$($app$common$geom$shapes$transform_points$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$380$$),$APP.$app$common$geom$shapes$common$shape__GT_center$$($parent$jscomp$207$$),
$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$207$$))),$align_pos$jscomp$1_delta$jscomp$17$$=function(){var $G__55642$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$207$$);return $app$common$geom$align$calc_align_pos$$.$cljs$core$IFn$_invoke$arity$3$?$app$common$geom$align$calc_align_pos$$.$cljs$core$IFn$_invoke$arity$3$($wrapper_rect$jscomp$1$$,$G__55642$$,$axis$jscomp$22$$):$app$common$geom$align$calc_align_pos$$($wrapper_rect$jscomp$1$$,
$G__55642$$,$axis$jscomp$22$$)}();$align_pos$jscomp$1_delta$jscomp$17$$=$APP.$app$common$geom$point$add$$(function($p1__55639_SHARP_$$){return $APP.$app$common$geom$shapes$points$start_hv$$($parent_bounds$jscomp$4$$,$p1__55639_SHARP_$$)}($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($align_pos$jscomp$1_delta$jscomp$17$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_rect$jscomp$1$$)),function($p1__55640_SHARP_$$){return $APP.$app$common$geom$shapes$points$start_vv$$($parent_bounds$jscomp$4$$,
$p1__55640_SHARP_$$)}($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($align_pos$jscomp$1_delta$jscomp$17$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_rect$jscomp$1$$)));return $app$common$geom$shapes$transforms$move$$($shape$jscomp$380$$,$align_pos$jscomp$1_delta$jscomp$17$$)};
$app$common$geom$align$calc_align_pos$$=function($wrapper_rect$jscomp$2$$,$bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$,$G__55646__$1_axis$jscomp$23$$){$G__55646__$1_axis$jscomp$23$$=$G__55646__$1_axis$jscomp$23$$ instanceof $APP.$cljs$core$Keyword$$?$G__55646__$1_axis$jscomp$23$$.$fqn$:null;switch($G__55646__$1_axis$jscomp$23$$){case "hleft":return $bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_rect$jscomp$2$$)],null);case "hcenter":return $bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$)+
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$)/2,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_rect$jscomp$2$$)/2,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_rect$jscomp$2$$)],
null);case "hright":return $bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,
$bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_rect$jscomp$2$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_rect$jscomp$2$$)],null);case "vtop":return $bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_rect$jscomp$2$$),$APP.$cljs$cst$1511$y$$,$bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$],null);case "vcenter":return $bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$)+
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$)/2,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_rect$jscomp$2$$),$APP.$cljs$cst$1511$y$$,$bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_rect$jscomp$2$$)/
2],null);case "vbottom":return $bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_rect$jscomp$2$$),$APP.$cljs$cst$1511$y$$,$bottom$jscomp$4_center$jscomp$33_left$jscomp$26_rect$jscomp$30_right$jscomp$22_top$jscomp$7$$-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_rect$jscomp$2$$)],null);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__55646__$1_axis$jscomp$23$$)].join(""));}};
$app$common$geom$align$distribute_space$$=function($shapes$jscomp$35_sorted_shapes$$,$axis$jscomp$24_deltas$jscomp$1$$){var $coord$jscomp$4$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$24_deltas$jscomp$1$$,$APP.$cljs$cst$1909$horizontal$$)?$APP.$cljs$cst$1510$x$$:$APP.$cljs$cst$1511$y$$,$other_coord$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$24_deltas$jscomp$1$$,$APP.$cljs$cst$1909$horizontal$$)?$APP.$cljs$cst$1511$y$$:$APP.$cljs$cst$1510$x$$,$size$jscomp$117$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$24_deltas$jscomp$1$$,$APP.$cljs$cst$1909$horizontal$$)?$APP.$cljs$cst$290$width$$:$APP.$cljs$cst$1522$height$$,$wrapper_rect$jscomp$3$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($shapes$jscomp$35_sorted_shapes$$);$shapes$jscomp$35_sorted_shapes$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__55651_SHARP_$$){return $coord$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$shapes$common$shape__GT_center$$($p1__55651_SHARP_$$))},
$shapes$jscomp$35_sorted_shapes$$);var $wrapped_shapes$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__55652_SHARP_$$){return $APP.$app$common$geom$shapes$common$shapes__GT_rect$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__55652_SHARP_$$],null))},$shapes$jscomp$35_sorted_shapes$$),$unit_space$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_$$,$size$jscomp$117$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_rect$jscomp$3$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($size$jscomp$117$$,$wrapped_shapes$$))/($APP.$cljs$core$count$$($wrapped_shapes$$)-1);$axis$jscomp$24_deltas$jscomp$1$$=function(){for(var $G__55680_shapes_SINGLEQUOTE_$$=$wrapped_shapes$$,$G__55681_new_pos_start_pos$jscomp$18$$=$coord$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_rect$jscomp$3$$),$G__55682_deltas$jscomp$2$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $first_shape$$=$APP.$cljs$core$first$$($G__55680_shapes_SINGLEQUOTE_$$),
$delta$jscomp$18$$=$G__55681_new_pos_start_pos$jscomp$18$$-$coord$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$$);$G__55681_new_pos_start_pos$jscomp$18$$=$G__55681_new_pos_start_pos$jscomp$18$$+$size$jscomp$117$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$$)+$unit_space$$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($G__55680_shapes_SINGLEQUOTE_$$),1))return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__55682_deltas$jscomp$2$$,$delta$jscomp$18$$);
$G__55680_shapes_SINGLEQUOTE_$$=$APP.$cljs$core$rest$$($G__55680_shapes_SINGLEQUOTE_$$);$G__55682_deltas$jscomp$2$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__55682_deltas$jscomp$2$$,$delta$jscomp$18$$)}}();return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(function($p1__55653_SHARP_$$,$p2__55654_SHARP_$$){return $app$common$geom$shapes$move$$($p1__55653_SHARP_$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$0$(),
$coord$jscomp$4$$,$p2__55654_SHARP_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$other_coord$$,0])))},$shapes$jscomp$35_sorted_shapes$$,$axis$jscomp$24_deltas$jscomp$1$$)};
$APP.$app$common$geom$align$adjust_to_viewport$cljs$0core$0IFn$0_invoke$0arity$03$$=function($vbox_height_viewport$jscomp$1$$,$anchor_y_srect$jscomp$2$$,$adjusted_rect_map__55670__$1_p__55669$$){$adjusted_rect_map__55670__$1_p__55669$$=$APP.$cljs$core$__destructure_map$$($adjusted_rect_map__55670__$1_p__55669$$);var $padding$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($adjusted_rect_map__55670__$1_p__55669$$,$APP.$cljs$cst$256$padding$$,0),$min_zoom$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($adjusted_rect_map__55670__$1_p__55669$$,
$APP.$cljs$cst$3421$min_zoom$$,null),$gprop$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox_height_viewport$jscomp$1$$)/$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox_height_viewport$jscomp$1$$),$srect_padded$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($anchor_y_srect$jscomp$2$$,
$APP.$cljs$cst$1510$x$$,function($p1__55660_SHARP_$$){return $p1__55660_SHARP_$$-$padding$jscomp$5$$}),$APP.$cljs$cst$1511$y$$,function($p1__55661_SHARP_$$){return $p1__55661_SHARP_$$-$padding$jscomp$5$$}),$APP.$cljs$cst$290$width$$,function($p1__55662_SHARP_$$){return $p1__55662_SHARP_$$+$padding$jscomp$5$$+$padding$jscomp$5$$}),$APP.$cljs$cst$1522$height$$,function($p1__55663_SHARP_$$){return $p1__55663_SHARP_$$+$padding$jscomp$5$$+$padding$jscomp$5$$}),$width$jscomp$101$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($srect_padded$$),
$height$jscomp$90$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($srect_padded$$),$lprop$$=$width$jscomp$101$$/$height$jscomp$90$$;$adjusted_rect_map__55670__$1_p__55669$$=$gprop$$>$lprop$$?function(){var $width_SINGLEQUOTE_$$=$width$jscomp$101$$/$lprop$$*$gprop$$,$padding__$1$jscomp$1$$=($width_SINGLEQUOTE_$$-$width$jscomp$101$$)/2;return $APP.$app$common$geom$rect$update_rect$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($srect_padded$$,
$APP.$cljs$cst$1510$x$$,function($p1__55664_SHARP_$$){return $p1__55664_SHARP_$$-$padding__$1$jscomp$1$$}),$APP.$cljs$cst$290$width$$,$width_SINGLEQUOTE_$$),$APP.$cljs$cst$1676$position$$)}():$gprop$$<$lprop$$?function(){var $height_SINGLEQUOTE_$$=$height$jscomp$90$$*$lprop$$/$gprop$$,$padding__$1$jscomp$2$$=($height_SINGLEQUOTE_$$-$height$jscomp$90$$)/2;return $APP.$app$common$geom$rect$update_rect$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($srect_padded$$,
$APP.$cljs$cst$1511$y$$,function($p1__55665_SHARP_$$){return $p1__55665_SHARP_$$-$padding__$1$jscomp$2$$}),$APP.$cljs$cst$1522$height$$,$height_SINGLEQUOTE_$$),$APP.$cljs$cst$1676$position$$)}():$APP.$app$common$geom$rect$update_rect$$($srect_padded$$,$APP.$cljs$cst$1676$position$$);if($min_zoom$$!=null&&$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox_height_viewport$jscomp$1$$)/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($adjusted_rect_map__55670__$1_p__55669$$)<$min_zoom$$){var $anchor_x$$=
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($anchor_y_srect$jscomp$2$$);$anchor_y_srect$jscomp$2$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($anchor_y_srect$jscomp$2$$);var $vbox_width$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox_height_viewport$jscomp$1$$)/$min_zoom$$;$vbox_height_viewport$jscomp$1$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox_height_viewport$jscomp$1$$)/$min_zoom$$;return $APP.$app$common$geom$rect$update_rect$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($adjusted_rect_map__55670__$1_p__55669$$,
$APP.$cljs$cst$1510$x$$,$anchor_x$$-$vbox_width$$/2,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1511$y$$,$anchor_y_srect$jscomp$2$$-$vbox_height_viewport$jscomp$1$$/2,$APP.$cljs$cst$290$width$$,$vbox_width$$,$APP.$cljs$cst$1522$height$$,$vbox_height_viewport$jscomp$1$$])),$APP.$cljs$cst$1676$position$$)}return $adjusted_rect_map__55670__$1_p__55669$$};
$app$main$data$comments$extract_mentions$$=function($content$jscomp$152$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$419_p__55687$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$419_p__55687$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$419_p__55687$$,1,null);$id$jscomp$419_p__55687$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$419_p__55687$$,2,null);return $APP.$app$common$uuid$parse$$($id$jscomp$419_p__55687$$)},
$APP.$cljs$core$re_seq$$($app$main$data$comments$r_mentions$$,$content$jscomp$152$$))};
$APP.$app$main$data$comments$update_mentions$$=function($map__55694__$1_p__55693$$){$map__55694__$1_p__55693$$=$APP.$cljs$core$__destructure_map$$($map__55694__$1_p__55693$$);var $content$jscomp$153$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55694__$1_p__55693$$,$APP.$cljs$cst$1637$content$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__55694__$1_p__55693$$,$cljs$cst$3431$mentions$$,$app$main$data$comments$extract_mentions$$($content$jscomp$153$$))};
$app$main$data$comments$created_thread_on_workspace$cljs$0core$0IFn$0_invoke$0arity$02$$=function($p__55703$$,$open_QMARK_$$){var $map__55704__$1$$=$APP.$cljs$core$__destructure_map$$($p__55703$$),$id$jscomp$420$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55704__$1$$,$APP.$cljs$cst$266$id$$),$comment$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55704__$1$$,$APP.$cljs$cst$3432$comment$$),$page_id$jscomp$89$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55704__$1$$,
$APP.$cljs$cst$2043$page_id$$);typeof $app$main$data$comments$created_thread_on_workspace_55705$$==="undefined"&&($app$main$data$comments$created_thread_on_workspace_55705$$=function($p__55703$jscomp$1$$,$open_QMARK_$jscomp$1$$,$map__55704$jscomp$1$$,$thread$jscomp$2$$,$id$jscomp$421$$,$comment$jscomp$1$$,$page_id$jscomp$90$$,$meta55706$$){this.$p__55703$=$p__55703$jscomp$1$$;this.$open_QMARK_$=$open_QMARK_$jscomp$1$$;this.$map__55704$=$map__55704$jscomp$1$$;this.thread=$thread$jscomp$2$$;this.id=
$id$jscomp$421$$;this.comment=$comment$jscomp$1$$;this.$page_id$=$page_id$jscomp$90$$;this.$meta55706$=$meta55706$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$created_thread_on_workspace_55705$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$created_thread_on_workspace_55705$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3433$app_DOT_main_DOT_data_DOT_comments_SLASH_created_thread_on_workspace$$},
$app$main$data$comments$created_thread_on_workspace_55705$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55707$$,$meta55706__$1$$){return new $app$main$data$comments$created_thread_on_workspace_55705$$(this.$p__55703$,this.$open_QMARK_$,this.$map__55704$,this.thread,this.id,this.comment,this.$page_id$,$meta55706__$1$$)},$app$main$data$comments$created_thread_on_workspace_55705$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55706$},$app$main$data$comments$created_thread_on_workspace_55705$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$created_thread_on_workspace_55705$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1797$$,$state$jscomp$252$$){var $self__$jscomp$3910$$=this,$position$jscomp$61$$=$APP.$cljs$core$select_keys$$($self__$jscomp$3910$$.thread,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1607$frame_id$$],null)),$page_id__$1$jscomp$2$$=function(){var $or__5025__auto__$jscomp$633$$=
$self__$jscomp$3910$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$633$$)?$or__5025__auto__$jscomp$633$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$252$$)}();return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$(function(){var $G__55710$$=$app$main$data$helpers$update_page$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$252$$,
$APP.$cljs$cst$2175$comment_threads$$,$APP.$cljs$core$assoc$$,$self__$jscomp$3910$$.id,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$3910$$.thread,$APP.$cljs$cst$3432$comment$$)),$page_id__$1$jscomp$2$$,function($p1__55695_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__55695_SHARP_$$,$APP.$cljs$cst$2061$comment_thread_positions$$,$APP.$cljs$core$assoc$$,$self__$jscomp$3910$$.id,$position$jscomp$61$$)});return $APP.$cljs$core$truth_$$($self__$jscomp$3910$$.$open_QMARK_$)?
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($G__55710$$,$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3434$open$$,$self__$jscomp$3910$$.id):$G__55710$$}(),$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$873$options$$,null),$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3435$draft$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3436$comments$$,
$self__$jscomp$3910$$.id],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3910$$.comment),$self__$jscomp$3910$$.comment)},$app$main$data$comments$created_thread_on_workspace_55705$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$created_thread_on_workspace_55705$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-comment-thread",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace",$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$3437$content_size$$,$APP.$cljs$core$count$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$(this.comment))],null),$APP.$cljs$core$meta$$(this)]))))});return new $app$main$data$comments$created_thread_on_workspace_55705$$($p__55703$$,$open_QMARK_$$,$map__55704__$1$$,$map__55704__$1$$,
$id$jscomp$420$$,$comment$$,$page_id$jscomp$89$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$comments$create_thread_on_workspace$cljs$0core$0IFn$0_invoke$0arity$03$$=function($params$jscomp$231$$,$on_thread_created$$,$open_QMARK_$jscomp$2$$){typeof $app$main$data$comments$create_thread_on_workspace_55739$$==="undefined"&&($app$main$data$comments$create_thread_on_workspace_55739$$=function($params$jscomp$232$$,$on_thread_created$jscomp$1$$,$open_QMARK_$jscomp$3$$,$meta55740$$){this.params=$params$jscomp$232$$;this.$on_thread_created$=$on_thread_created$jscomp$1$$;this.$open_QMARK_$=
$open_QMARK_$jscomp$3$$;this.$meta55740$=$meta55740$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$create_thread_on_workspace_55739$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$create_thread_on_workspace_55739$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3438$app_DOT_main_DOT_data_DOT_comments_SLASH_create_thread_on_workspace$$},$app$main$data$comments$create_thread_on_workspace_55739$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55741$$,$meta55740__$1$$){return new $app$main$data$comments$create_thread_on_workspace_55739$$(this.params,this.$on_thread_created$,this.$open_QMARK_$,$meta55740__$1$$)},$app$main$data$comments$create_thread_on_workspace_55739$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55740$},$app$main$data$comments$create_thread_on_workspace_55739$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$create_thread_on_workspace_55739$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($it$jscomp$145_page_id$jscomp$91$$,$frame_id$jscomp$35_objects$jscomp$265_params__$1$jscomp$31_state$jscomp$253$$){var $self__$jscomp$3915$$=this,$it__$1$jscomp$30$$=this;$it$jscomp$145_page_id$jscomp$91$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$35_objects$jscomp$265_params__$1$jscomp$31_state$jscomp$253$$);$frame_id$jscomp$35_objects$jscomp$265_params__$1$jscomp$31_state$jscomp$253$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$35_objects$jscomp$265_params__$1$jscomp$31_state$jscomp$253$$,
$it$jscomp$145_page_id$jscomp$91$$);$frame_id$jscomp$35_objects$jscomp$265_params__$1$jscomp$31_state$jscomp$253$$=$app$common$types$shape_tree$get_frame_id_by_position$cljs$0core$0IFn$0_invoke$0arity$02$$($frame_id$jscomp$35_objects$jscomp$265_params__$1$jscomp$31_state$jscomp$253$$,$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3915$$.params));$frame_id$jscomp$35_objects$jscomp$265_params__$1$jscomp$31_state$jscomp$253$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$data$comments$update_mentions$$($self__$jscomp$3915$$.params),
$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$35_objects$jscomp$265_params__$1$jscomp$31_state$jscomp$253$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($map__55754__$1_p__55753$$){$map__55754__$1_p__55753$$=$APP.$cljs$core$__destructure_map$$($map__55754__$1_p__55753$$);var $type$jscomp$442$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55754__$1_p__55753$$,$APP.$cljs$cst$139$type$$),$code$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55754__$1_p__55753$$,
$APP.$cljs$cst$273$code$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$442$$,$APP.$cljs$cst$2561$restriction$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$38$$,$APP.$cljs$cst$3382$max_quote_reached$$)?$APP.$beicon$v2$core$throw$0$$($map__55754__$1_p__55753$$):$APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3377$comment_error$$],null))},$APP.$beicon$v2$core$map$$(function($data$jscomp$301$$){return $APP.$cljs$core$with_meta$$($app$main$data$comments$created_thread_on_workspace$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$301$$,
$self__$jscomp$3915$$.$open_QMARK_$),$APP.$cljs$core$meta$$($it__$1$jscomp$30$$))},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$3915$$.$on_thread_created$,$APP.$beicon$v2$core$mapcat$$(function($p1__55733_SHARP_$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3439$get_comment_thread$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__55733_SHARP_$$),
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__55733_SHARP_$$)],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3440$create_comment_thread$$,$frame_id$jscomp$35_objects$jscomp$265_params__$1$jscomp$31_state$jscomp$253$$)))))});return new $app$main$data$comments$create_thread_on_workspace_55739$$($params$jscomp$231$$,$on_thread_created$$,$open_QMARK_$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$update_comment_thread_status$$=function($thread_id$$){typeof $app$main$data$comments$update_comment_thread_status_55895$$==="undefined"&&($app$main$data$comments$update_comment_thread_status_55895$$=function($thread_id$jscomp$1$$,$meta55896$$){this.$thread_id$=$thread_id$jscomp$1$$;this.$meta55896$=$meta55896$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$update_comment_thread_status_55895$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_comment_thread_status_55895$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3443$app_DOT_main_DOT_data_DOT_comments_SLASH_update_comment_thread_status$$},$app$main$data$comments$update_comment_thread_status_55895$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55897$$,$meta55896__$1$$){return new $app$main$data$comments$update_comment_thread_status_55895$$(this.$thread_id$,$meta55896__$1$$)},
$app$main$data$comments$update_comment_thread_status_55895$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55896$},$app$main$data$comments$update_comment_thread_status_55895$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_comment_thread_status_55895$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1803_share_id$jscomp$2$$,$state$jscomp$256$$){var $self__$jscomp$3928$$=this;$_$jscomp$1803_share_id$jscomp$2$$=
$APP.$cljs$cst$3237$share_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2231$viewer_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$256$$));return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3377$comment_error$$],null))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$(function($p1__55891_SHARP_$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($p1__55891_SHARP_$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2175$comment_threads$$,$self__$jscomp$3928$$.$thread_id$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3428$count_unread_comments$$,0]))}),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3444$update_comment_thread_status$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$self__$jscomp$3928$$.$thread_id$,
$APP.$cljs$cst$3237$share_id$$,$_$jscomp$1803_share_id$jscomp$2$$],null))))});return new $app$main$data$comments$update_comment_thread_status_55895$$($thread_id$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$comments$update_comment_thread$$=function($p__55918$$){var $map__55919__$1$$=$APP.$cljs$core$__destructure_map$$($p__55918$$),$id$jscomp$424$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55919__$1$$,$APP.$cljs$cst$266$id$$),$is_resolved$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55919__$1$$,$APP.$cljs$cst$3445$is_resolved$$);typeof $app$main$data$comments$update_comment_thread_55920$$==="undefined"&&($app$main$data$comments$update_comment_thread_55920$$=
function($p__55918$jscomp$1$$,$map__55919$jscomp$1$$,$thread$jscomp$6$$,$id$jscomp$425$$,$is_resolved$jscomp$1$$,$meta55921$$){this.$p__55918$=$p__55918$jscomp$1$$;this.$map__55919$=$map__55919$jscomp$1$$;this.thread=$thread$jscomp$6$$;this.id=$id$jscomp$425$$;this.$is_resolved$=$is_resolved$jscomp$1$$;this.$meta55921$=$meta55921$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$update_comment_thread_55920$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_comment_thread_55920$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3446$app_DOT_main_DOT_data_DOT_comments_SLASH_update_comment_thread$$},$app$main$data$comments$update_comment_thread_55920$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55922$$,$meta55921__$1$$){return new $app$main$data$comments$update_comment_thread_55920$$(this.$p__55918$,this.$map__55919$,this.thread,this.id,this.$is_resolved$,
$meta55921__$1$$)},$app$main$data$comments$update_comment_thread_55920$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55921$},$app$main$data$comments$update_comment_thread_55920$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3445$is_resolved$$,this.$is_resolved$],null)},$app$main$data$comments$update_comment_thread_55920$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$comments$update_comment_thread_55920$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1805$$,$state$jscomp$257$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$257$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2175$comment_threads$$,this.id],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3445$is_resolved$$,
this.$is_resolved$]))},$app$main$data$comments$update_comment_thread_55920$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_comment_thread_55920$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$146_share_id$jscomp$3$$,$state$jscomp$258$$){$it$jscomp$146_share_id$jscomp$3$$=$APP.$cljs$cst$3237$share_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2231$viewer_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$258$$));
return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$truth_$$(this.$is_resolved$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"resolve-comment-thread",$APP.$cljs$cst$3430$thread_id$$,this.id],null),$APP.$cljs$core$meta$$(this)])))):null,$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($map__55936__$1_p__55934$$){$map__55936__$1_p__55934$$=
$APP.$cljs$core$__destructure_map$$($map__55936__$1_p__55934$$);var $type$jscomp$444$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55936__$1_p__55934$$,$APP.$cljs$cst$139$type$$),$code$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55936__$1_p__55934$$,$APP.$cljs$cst$273$code$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$444$$,$APP.$cljs$cst$2561$restriction$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$40$$,
$APP.$cljs$cst$3382$max_quote_reached$$)?$APP.$beicon$v2$core$throw$0$$($map__55936__$1_p__55934$$):$APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3377$comment_error$$],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3447$update_comment_thread$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$3445$is_resolved$$,this.$is_resolved$,$APP.$cljs$cst$3237$share_id$$,
$it$jscomp$146_share_id$jscomp$3$$],null)))))});return new $app$main$data$comments$update_comment_thread_55920$$($p__55918$$,$map__55919__$1$$,$map__55919__$1$$,$id$jscomp$424$$,$is_resolved$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$add_comment$$=function($thread$jscomp$7$$,$content$jscomp$154$$){typeof $app$main$data$comments$create_comment_55943$$==="undefined"&&($app$main$data$comments$create_comment_55943$$=function($thread$jscomp$8$$,$content$jscomp$155$$,$meta55944$$){this.thread=$thread$jscomp$8$$;this.content=$content$jscomp$155$$;this.$meta55944$=$meta55944$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$create_comment_55943$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$create_comment_55943$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3448$app_DOT_main_DOT_data_DOT_comments_SLASH_create_comment$$},$app$main$data$comments$create_comment_55943$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55945$$,$meta55944__$1$$){return new $app$main$data$comments$create_comment_55943$$(this.thread,this.content,$meta55944__$1$$)},$app$main$data$comments$create_comment_55943$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55944$},$app$main$data$comments$create_comment_55943$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$create_comment_55943$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3430$thread_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.thread),$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$(this.thread),
$APP.$cljs$cst$3437$content_size$$,$APP.$cljs$core$count$$(this.content)],null)},$app$main$data$comments$create_comment_55943$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$create_comment_55943$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1808_params$jscomp$235_share_id$jscomp$4$$,$state$jscomp$259$$){function $created$$($comment$jscomp$4$$,$state__$1$jscomp$16$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state__$1$jscomp$16$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3436$comments$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3939$$.thread)],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($comment$jscomp$4$$),$comment$jscomp$4$$)}var $self__$jscomp$3939$$=this;$_$jscomp$1808_params$jscomp$235_share_id$jscomp$4$$=$APP.$cljs$cst$3237$share_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2231$viewer_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$259$$));
$_$jscomp$1808_params$jscomp$235_share_id$jscomp$4$$=$APP.$app$main$data$comments$update_mentions$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3430$thread_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3939$$.thread),$APP.$cljs$cst$1637$content$$,$self__$jscomp$3939$$.content,$APP.$cljs$cst$3237$share_id$$,$_$jscomp$1808_params$jscomp$235_share_id$jscomp$4$$],null));return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($map__55952__$1_p__55951$$){$map__55952__$1_p__55951$$=
$APP.$cljs$core$__destructure_map$$($map__55952__$1_p__55951$$);var $type$jscomp$445$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55952__$1_p__55951$$,$APP.$cljs$cst$139$type$$),$code$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55952__$1_p__55951$$,$APP.$cljs$cst$273$code$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$445$$,$APP.$cljs$cst$2561$restriction$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$41$$,
$APP.$cljs$cst$3382$max_quote_reached$$)?$APP.$beicon$v2$core$throw$0$$($map__55952__$1_p__55951$$):$APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3377$comment_error$$],null))},$APP.$beicon$v2$core$map$$(function($comment$jscomp$5$$){return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($created$$,$comment$jscomp$5$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3449$create_comment$$,
$_$jscomp$1808_params$jscomp$235_share_id$jscomp$4$$))),(0,$APP.$beicon$v2$core$of$$)($app$main$data$comments$refresh_comment_thread$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$comments$refresh_comment_thread$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3939$$.thread):$app$main$data$comments$refresh_comment_thread$$($self__$jscomp$3939$$.thread)))});return new $app$main$data$comments$create_comment_55943$$($thread$jscomp$7$$,$content$jscomp$154$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$update_comment$$=function($p__55955$$){var $map__55956__$1$$=$APP.$cljs$core$__destructure_map$$($p__55955$$),$id$jscomp$426$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55956__$1$$,$APP.$cljs$cst$266$id$$),$content$jscomp$156$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55956__$1$$,$APP.$cljs$cst$1637$content$$),$thread_id$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55956__$1$$,$APP.$cljs$cst$3430$thread_id$$),$file_id$jscomp$69$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55956__$1$$,$APP.$cljs$cst$1644$file_id$$);typeof $app$main$data$comments$update_comment_55957$$==="undefined"&&($app$main$data$comments$update_comment_55957$$=function($p__55955$jscomp$1$$,$map__55956$jscomp$1$$,$comment$jscomp$7$$,$id$jscomp$427$$,$content$jscomp$157$$,$thread_id$jscomp$3$$,$file_id$jscomp$70$$,$meta55958$$){this.$p__55955$=$p__55955$jscomp$1$$;this.$map__55956$=$map__55956$jscomp$1$$;this.comment=$comment$jscomp$7$$;this.id=
$id$jscomp$427$$;this.content=$content$jscomp$157$$;this.$thread_id$=$thread_id$jscomp$3$$;this.$file_id$=$file_id$jscomp$70$$;this.$meta55958$=$meta55958$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$update_comment_55957$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_comment_55957$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3450$app_DOT_main_DOT_data_DOT_comments_SLASH_update_comment$$},
$app$main$data$comments$update_comment_55957$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55959$$,$meta55958__$1$$){return new $app$main$data$comments$update_comment_55957$$(this.$p__55955$,this.$map__55956$,this.comment,this.id,this.content,this.$thread_id$,this.$file_id$,$meta55958__$1$$)},$app$main$data$comments$update_comment_55957$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55958$},$app$main$data$comments$update_comment_55957$$.prototype.$app$main$data$event$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_comment_55957$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3430$thread_id$$,this.$thread_id$,$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$3437$content_size$$,$APP.$cljs$core$count$$(this.content)],null)},$app$main$data$comments$update_comment_55957$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_comment_55957$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$1810$$,$state$jscomp$260$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$260$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3436$comments$$,this.$thread_id$,this.id],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$,this.content]))},$app$main$data$comments$update_comment_55957$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_comment_55957$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1811_params__$1$jscomp$33_share_id$jscomp$5$$,$state$jscomp$261$$){var $self__$jscomp$3945$$=this;$_$jscomp$1811_params__$1$jscomp$33_share_id$jscomp$5$$=$APP.$cljs$cst$3237$share_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2231$viewer_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$261$$));$_$jscomp$1811_params__$1$jscomp$33_share_id$jscomp$5$$=
$APP.$app$main$data$comments$update_mentions$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$self__$jscomp$3945$$.id,$APP.$cljs$cst$1637$content$$,$self__$jscomp$3945$$.content,$APP.$cljs$cst$3237$share_id$$,$_$jscomp$1811_params__$1$jscomp$33_share_id$jscomp$5$$],null));return $APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$comments$retrieve_comment_threads$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$data$comments$retrieve_comment_threads$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3945$$.$file_id$):
$APP.$app$main$data$comments$retrieve_comment_threads$$($self__$jscomp$3945$$.$file_id$)},$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3377$comment_error$$],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3451$update_comment$$,$_$jscomp$1811_params__$1$jscomp$33_share_id$jscomp$5$$)))});return new $app$main$data$comments$update_comment_55957$$($p__55955$$,
$map__55956__$1$$,$map__55956__$1$$,$id$jscomp$426$$,$content$jscomp$156$$,$thread_id$jscomp$2$$,$file_id$jscomp$69$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$comments$delete_comment_thread_on_workspace$cljs$0core$0IFn$0_invoke$0arity$02$$=function($p__55969$$,$on_delete$$){var $map__55970__$1$$=$APP.$cljs$core$__destructure_map$$($p__55969$$),$id$jscomp$428$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55970__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$comments$delete_comment_thread_on_workspace_55971$$==="undefined"&&($app$main$data$comments$delete_comment_thread_on_workspace_55971$$=function($p__55969$jscomp$1$$,
$on_delete$jscomp$1$$,$map__55970$jscomp$1$$,$thread$jscomp$10$$,$id$jscomp$429$$,$meta55972$$){this.$p__55969$=$p__55969$jscomp$1$$;this.$on_delete$=$on_delete$jscomp$1$$;this.$map__55970$=$map__55970$jscomp$1$$;this.thread=$thread$jscomp$10$$;this.id=$id$jscomp$429$$;this.$meta55972$=$meta55972$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$delete_comment_thread_on_workspace_55971$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$comments$delete_comment_thread_on_workspace_55971$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3452$app_DOT_main_DOT_data_DOT_comments_SLASH_delete_comment_thread_on_workspace$$},$app$main$data$comments$delete_comment_thread_on_workspace_55971$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55973$$,$meta55972__$1$$){return new $app$main$data$comments$delete_comment_thread_on_workspace_55971$$(this.$p__55969$,this.$on_delete$,this.$map__55970$,
this.thread,this.id,$meta55972__$1$$)},$app$main$data$comments$delete_comment_thread_on_workspace_55971$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55972$},$app$main$data$comments$delete_comment_thread_on_workspace_55971$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$delete_comment_thread_on_workspace_55971$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1812$$,$state$jscomp$262$$){var $self__$jscomp$3949$$=
this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($app$main$data$helpers$update_page$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$262$$,function($p1__55963_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__55963_SHARP_$$,$APP.$cljs$cst$2061$comment_thread_positions$$,$APP.$cljs$core$dissoc$$,$self__$jscomp$3949$$.id)}),$APP.$cljs$cst$3436$comments$$,$APP.$cljs$core$dissoc$$,$self__$jscomp$3949$$.id),
$APP.$cljs$cst$2175$comment_threads$$,$APP.$cljs$core$dissoc$$,$self__$jscomp$3949$$.id)},$app$main$data$comments$delete_comment_thread_on_workspace_55971$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$delete_comment_thread_on_workspace_55971$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(this.$on_delete$,
$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3377$comment_error$$],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3453$delete_comment_thread$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,this.id],null))))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-comment-thread",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace",$APP.$cljs$cst$266$id$$,this.id],null),$APP.$cljs$core$meta$$(this)])))))});return new $app$main$data$comments$delete_comment_thread_on_workspace_55971$$($p__55969$$,$on_delete$$,$map__55970__$1$$,$map__55970__$1$$,$id$jscomp$428$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$delete_comment_thread_on_viewer$$=function($p__55974$$){var $map__55975__$1$$=$APP.$cljs$core$__destructure_map$$($p__55974$$),$id$jscomp$430$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55975__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$comments$delete_comment_thread_on_viewer_55976$$==="undefined"&&($app$main$data$comments$delete_comment_thread_on_viewer_55976$$=function($p__55974$jscomp$1$$,$map__55975$jscomp$1$$,$thread$jscomp$12$$,$id$jscomp$431$$,
$meta55977$$){this.$p__55974$=$p__55974$jscomp$1$$;this.$map__55975$=$map__55975$jscomp$1$$;this.thread=$thread$jscomp$12$$;this.id=$id$jscomp$431$$;this.$meta55977$=$meta55977$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$delete_comment_thread_on_viewer_55976$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$delete_comment_thread_on_viewer_55976$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3454$app_DOT_main_DOT_data_DOT_comments_SLASH_delete_comment_thread_on_viewer$$},$app$main$data$comments$delete_comment_thread_on_viewer_55976$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55978$$,$meta55977__$1$$){return new $app$main$data$comments$delete_comment_thread_on_viewer_55976$$(this.$p__55974$,this.$map__55975$,this.thread,this.id,$meta55977__$1$$)},$app$main$data$comments$delete_comment_thread_on_viewer_55976$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55977$},$app$main$data$comments$delete_comment_thread_on_viewer_55976$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$delete_comment_thread_on_viewer_55976$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1814_page_id$jscomp$94$$,$state$jscomp$263$$){$_$jscomp$1814_page_id$jscomp$94$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$263$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$263$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$2228$pages$$,$_$jscomp$1814_page_id$jscomp$94$$,$APP.$cljs$cst$2061$comment_thread_positions$$],null),$APP.$cljs$core$dissoc$$,this.id),$APP.$cljs$cst$3436$comments$$,$APP.$cljs$core$dissoc$$,this.id),$APP.$cljs$cst$2175$comment_threads$$,$APP.$cljs$core$dissoc$$,this.id)},$app$main$data$comments$delete_comment_thread_on_viewer_55976$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$delete_comment_thread_on_viewer_55976$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1815_share_id$jscomp$6$$,$state$jscomp$264$$){$_$jscomp$1815_share_id$jscomp$6$$=$APP.$cljs$cst$3237$share_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2231$viewer_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$264$$));return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3377$comment_error$$],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3453$delete_comment_thread$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$3237$share_id$$,$_$jscomp$1815_share_id$jscomp$6$$],null)))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"delete-comment-thread",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"viewer",$APP.$cljs$cst$266$id$$,this.id],null))))});return new $app$main$data$comments$delete_comment_thread_on_viewer_55976$$($p__55974$$,$map__55975__$1$$,$map__55975__$1$$,$id$jscomp$430$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$delete_comment$$=function($p__55980$$){var $map__55981__$1$$=$APP.$cljs$core$__destructure_map$$($p__55980$$),$id$jscomp$432$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55981__$1$$,$APP.$cljs$cst$266$id$$),$thread_id$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55981__$1$$,$APP.$cljs$cst$3430$thread_id$$);typeof $app$main$data$comments$delete_comment_55982$$==="undefined"&&($app$main$data$comments$delete_comment_55982$$=function($p__55980$jscomp$1$$,
$map__55981$jscomp$1$$,$comment$jscomp$9$$,$id$jscomp$433$$,$thread_id$jscomp$5$$,$meta55983$$){this.$p__55980$=$p__55980$jscomp$1$$;this.$map__55981$=$map__55981$jscomp$1$$;this.comment=$comment$jscomp$9$$;this.id=$id$jscomp$433$$;this.$thread_id$=$thread_id$jscomp$5$$;this.$meta55983$=$meta55983$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$delete_comment_55982$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$comments$delete_comment_55982$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3455$app_DOT_main_DOT_data_DOT_comments_SLASH_delete_comment$$},$app$main$data$comments$delete_comment_55982$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55984$$,$meta55983__$1$$){return new $app$main$data$comments$delete_comment_55982$$(this.$p__55980$,this.$map__55981$,this.comment,this.id,this.$thread_id$,$meta55983__$1$$)},$app$main$data$comments$delete_comment_55982$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55983$},$app$main$data$comments$delete_comment_55982$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$delete_comment_55982$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3430$thread_id$$,this.$thread_id$],null)},$app$main$data$comments$delete_comment_55982$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$comments$delete_comment_55982$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1817$$,$state$jscomp$265$$){return $APP.$app$common$data$update_in_when$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$265$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3436$comments$$,this.$thread_id$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.id])),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2175$comment_threads$$,this.$thread_id$,$cljs$cst$3429$count_comments$$],null),$APP.$cljs$core$dec$$)},$app$main$data$comments$delete_comment_55982$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$delete_comment_55982$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1818_share_id$jscomp$7$$,$state$jscomp$266$$){$_$jscomp$1818_share_id$jscomp$7$$=
$APP.$cljs$cst$3237$share_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2231$viewer_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$266$$));return $APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3377$comment_error$$],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3456$delete_comment$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$3237$share_id$$,$_$jscomp$1818_share_id$jscomp$7$$],null))))});return new $app$main$data$comments$delete_comment_55982$$($p__55980$$,$map__55981__$1$$,$map__55981__$1$$,$id$jscomp$432$$,$thread_id$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$refresh_comment_thread$$=function($p__55986$$){var $map__55987__$1$$=$APP.$cljs$core$__destructure_map$$($p__55986$$),$id$jscomp$434$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55987__$1$$,$APP.$cljs$cst$266$id$$),$file_id$jscomp$71$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55987__$1$$,$APP.$cljs$cst$1644$file_id$$);typeof $app$main$data$comments$refresh_comment_thread_55988$$==="undefined"&&($app$main$data$comments$refresh_comment_thread_55988$$=
function($p__55986$jscomp$1$$,$map__55987$jscomp$1$$,$thread$jscomp$14$$,$id$jscomp$435$$,$file_id$jscomp$72$$,$fetched$jscomp$3$$,$meta55989$$){this.$p__55986$=$p__55986$jscomp$1$$;this.$map__55987$=$map__55987$jscomp$1$$;this.thread=$thread$jscomp$14$$;this.id=$id$jscomp$435$$;this.$file_id$=$file_id$jscomp$72$$;this.$fetched$=$fetched$jscomp$3$$;this.$meta55989$=$meta55989$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$refresh_comment_thread_55988$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$refresh_comment_thread_55988$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3457$app_DOT_main_DOT_data_DOT_comments_SLASH_refresh_comment_thread$$},$app$main$data$comments$refresh_comment_thread_55988$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55990$$,$meta55989__$1$$){return new $app$main$data$comments$refresh_comment_thread_55988$$(this.$p__55986$,this.$map__55987$,this.thread,this.id,this.$file_id$,
this.$fetched$,$meta55989__$1$$)},$app$main$data$comments$refresh_comment_thread_55988$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55989$},$app$main$data$comments$refresh_comment_thread_55988$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$refresh_comment_thread_55988$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1819_share_id$jscomp$8$$,$state$jscomp$268$$){var $self__$jscomp$3965$$=this;$_$jscomp$1819_share_id$jscomp$8$$=
$APP.$cljs$cst$3237$share_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2231$viewer_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$268$$));return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3377$comment_error$$],null))},$APP.$beicon$v2$core$map$$(function($p1__55985_SHARP_$$){return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$3965$$.$fetched$,
$p1__55985_SHARP_$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3439$get_comment_thread$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$3965$$.$file_id$,$APP.$cljs$cst$266$id$$,$self__$jscomp$3965$$.id,$APP.$cljs$cst$3237$share_id$$,$_$jscomp$1819_share_id$jscomp$8$$],null))))});return new $app$main$data$comments$refresh_comment_thread_55988$$($p__55986$$,$map__55987__$1$$,$map__55987__$1$$,$id$jscomp$434$$,$file_id$jscomp$71$$,
function($thread__$1$$,$state$jscomp$267$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$267$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2175$comment_threads$$,$id$jscomp$434$$],null),$thread__$1$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$comment_threads_fetched$$=function($threads$$){typeof $app$main$data$comments$comment_threads_fetched_55996$$==="undefined"&&($app$main$data$comments$comment_threads_fetched_55996$$=function($threads$jscomp$1$$,$meta55997$$){this.threads=$threads$jscomp$1$$;this.$meta55997$=$meta55997$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$comment_threads_fetched_55996$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$comments$comment_threads_fetched_55996$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3458$app_DOT_main_DOT_data_DOT_comments_SLASH_comment_threads_fetched$$},$app$main$data$comments$comment_threads_fetched_55996$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55998$$,$meta55997__$1$$){return new $app$main$data$comments$comment_threads_fetched_55996$$(this.threads,$meta55997__$1$$)},$app$main$data$comments$comment_threads_fetched_55996$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55997$},$app$main$data$comments$comment_threads_fetched_55996$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$comment_threads_fetched_55996$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1820$$,$state$jscomp$269$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($state__$1$jscomp$17$$,$file_id$jscomp$73_p__55999$$){var $map__56000__$1$$=$APP.$cljs$core$__destructure_map$$($file_id$jscomp$73_p__55999$$),
$id$jscomp$436$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56000__$1$$,$APP.$cljs$cst$266$id$$);$file_id$jscomp$73_p__55999$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56000__$1$$,$APP.$cljs$cst$1644$file_id$$);var $page_id$jscomp$95$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56000__$1$$,$APP.$cljs$cst$2043$page_id$$);return $app$main$data$helpers$update_page$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state__$1$jscomp$17$$,
$APP.$cljs$cst$2175$comment_threads$$,$APP.$cljs$core$assoc$$,$id$jscomp$436$$,$map__56000__$1$$),$file_id$jscomp$73_p__55999$$,$page_id$jscomp$95$$,function($page$jscomp$47$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($page$jscomp$47$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2061$comment_thread_positions$$,$id$jscomp$436$$],null),function($state__$2$jscomp$1$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$2$jscomp$1$$,
$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($map__56000__$1$$)),$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($map__56000__$1$$))})})},$state$jscomp$269$$,this.threads)});return new $app$main$data$comments$comment_threads_fetched_55996$$($threads$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$comments$retrieve_comment_threads$$=function($file_id$jscomp$74$$){typeof $app$main$data$comments$retrieve_comment_threads_56001$$==="undefined"&&($app$main$data$comments$retrieve_comment_threads_56001$$=function($file_id$jscomp$75$$,$meta56002$$){this.$file_id$=$file_id$jscomp$75$$;this.$meta56002$=$meta56002$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$retrieve_comment_threads_56001$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$retrieve_comment_threads_56001$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3459$app_DOT_main_DOT_data_DOT_comments_SLASH_retrieve_comment_threads$$},$app$main$data$comments$retrieve_comment_threads_56001$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56003$$,$meta56002__$1$$){return new $app$main$data$comments$retrieve_comment_threads_56001$$(this.$file_id$,$meta56002__$1$$)},$app$main$data$comments$retrieve_comment_threads_56001$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta56002$},$app$main$data$comments$retrieve_comment_threads_56001$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$retrieve_comment_threads_56001$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1821$$,$state$jscomp$270$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$270$$,$APP.$cljs$cst$2175$comment_threads$$)},$app$main$data$comments$retrieve_comment_threads_56001$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$retrieve_comment_threads_56001$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1822_share_id$jscomp$9$$,$state$jscomp$271$$){$_$jscomp$1822_share_id$jscomp$9$$=$APP.$cljs$cst$3237$share_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2231$viewer_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$271$$));return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$($app$main$data$comments$comment_threads_fetched$$,
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3460$get_comment_threads$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,this.$file_id$,$APP.$cljs$cst$3237$share_id$$,$_$jscomp$1822_share_id$jscomp$9$$],null))),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1920$workspace_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$271$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$(null)):
null)});return new $app$main$data$comments$retrieve_comment_threads_56001$$($file_id$jscomp$74$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$retrieve_comments$$=function($thread_id$jscomp$6$$){typeof $app$main$data$comments$retrieve_comments_56006$$==="undefined"&&($app$main$data$comments$retrieve_comments_56006$$=function($thread_id$jscomp$7$$,$fetched$jscomp$5$$,$meta56007$$){this.$thread_id$=$thread_id$jscomp$7$$;this.$fetched$=$fetched$jscomp$5$$;this.$meta56007$=$meta56007$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$retrieve_comments_56006$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$retrieve_comments_56006$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3461$app_DOT_main_DOT_data_DOT_comments_SLASH_retrieve_comments$$},$app$main$data$comments$retrieve_comments_56006$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56008$$,$meta56007__$1$$){return new $app$main$data$comments$retrieve_comments_56006$$(this.$thread_id$,this.$fetched$,$meta56007__$1$$)},$app$main$data$comments$retrieve_comments_56006$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta56007$},$app$main$data$comments$retrieve_comments_56006$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$retrieve_comments_56006$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1823_share_id$jscomp$10$$,$state$jscomp$273$$){var $self__$jscomp$3978$$=this;$_$jscomp$1823_share_id$jscomp$10$$=$APP.$cljs$cst$3237$share_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2231$viewer_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$273$$));
return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3377$comment_error$$],null))},$APP.$beicon$v2$core$map$$(function($p1__56004_SHARP_$$){return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$3978$$.$fetched$,$p1__56004_SHARP_$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3462$get_comments$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3430$thread_id$$,$self__$jscomp$3978$$.$thread_id$,$APP.$cljs$cst$3237$share_id$$,$_$jscomp$1823_share_id$jscomp$10$$],null))))});return new $app$main$data$comments$retrieve_comments_56006$$($thread_id$jscomp$6$$,function($comments$$,$state$jscomp$272$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$272$$,$APP.$cljs$cst$3436$comments$$,$APP.$cljs$core$assoc$$,$thread_id$jscomp$6$$,$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,
$comments$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$retrieve_unread_comment_threads$$=function($team_id$jscomp$67$$){typeof $app$main$data$comments$retrieve_unread_comment_threads_56024$$==="undefined"&&($app$main$data$comments$retrieve_unread_comment_threads_56024$$=function($team_id$jscomp$68$$,$meta56025$$){this.$team_id$=$team_id$jscomp$68$$;this.$meta56025$=$meta56025$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$retrieve_unread_comment_threads_56024$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$retrieve_unread_comment_threads_56024$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3463$app_DOT_main_DOT_data_DOT_comments_SLASH_retrieve_unread_comment_threads$$},$app$main$data$comments$retrieve_unread_comment_threads_56024$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56026$$,$meta56025__$1$$){return new $app$main$data$comments$retrieve_unread_comment_threads_56024$$(this.$team_id$,$meta56025__$1$$)},
$app$main$data$comments$retrieve_unread_comment_threads_56024$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56025$},$app$main$data$comments$retrieve_unread_comment_threads_56024$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$retrieve_unread_comment_threads_56024$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){function $fetched_users$$($p1__56019_SHARP_$$,$p2__56018_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p2__56018_SHARP_$$,
$cljs$cst$3464$current_team_comments_users$$,$p1__56019_SHARP_$$)}function $fetched_comments$$($p1__56017_SHARP_$$,$p2__56016_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p2__56016_SHARP_$$,$APP.$cljs$cst$2175$comment_threads$$,$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$p1__56017_SHARP_$$))}return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3377$comment_error$$],null))},$APP.$beicon$v2$core$merge_map$$(function($comments$jscomp$1$$){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($fetched_comments$$,$comments$jscomp$1$$)),$APP.$beicon$v2$core$map$$(function($p1__56023_SHARP_$$){return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($fetched_users$$,$p1__56023_SHARP_$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__56021_SHARP_$$,
$p2__56022_SHARP_$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__56021_SHARP_$$,$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$p2__56022_SHARP_$$)]))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$merge_map$$(function($p1__56020_SHARP_$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3238$get_profiles_for_file_comments$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$p1__56020_SHARP_$$],null))},$APP.$beicon$v2$core$from$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1644$file_id$$),$comments$jscomp$1$$))))))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3465$get_unread_comment_threads$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,
[$APP.$cljs$cst$1927$team_id$$,this.$team_id$],null))))});return new $app$main$data$comments$retrieve_unread_comment_threads_56024$$($team_id$jscomp$67$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$mark_all_threads_as_read$$=function($team_id$jscomp$69$$){typeof $app$main$data$comments$mark_all_threads_as_read_56027$$==="undefined"&&($app$main$data$comments$mark_all_threads_as_read_56027$$=function($team_id$jscomp$70$$,$meta56028$$){this.$team_id$=$team_id$jscomp$70$$;this.$meta56028$=$meta56028$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$mark_all_threads_as_read_56027$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$mark_all_threads_as_read_56027$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3466$app_DOT_main_DOT_data_DOT_comments_SLASH_mark_all_threads_as_read$$},$app$main$data$comments$mark_all_threads_as_read_56027$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56029$$,$meta56028__$1$$){return new $app$main$data$comments$mark_all_threads_as_read_56027$$(this.$team_id$,$meta56028__$1$$)},$app$main$data$comments$mark_all_threads_as_read_56027$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta56028$},$app$main$data$comments$mark_all_threads_as_read_56027$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$mark_all_threads_as_read_56027$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return $APP.$cljs$core$PersistentArrayMap$EMPTY$$},$app$main$data$comments$mark_all_threads_as_read_56027$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$mark_all_threads_as_read_56027$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1826_threads$jscomp$2$$,$state$jscomp$274$$){var $self__$jscomp$3987$$=this;$_$jscomp$1826_threads$jscomp$2$$=$APP.$cljs$core$vals$$($APP.$cljs$cst$2175$comment_threads$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$274$$));return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3377$comment_error$$],
null))},$APP.$beicon$v2$core$map$$(function(){return $app$main$data$comments$retrieve_unread_comment_threads$$($self__$jscomp$3987$$.$team_id$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3467$mark_all_threads_as_read$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3468$threads$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$_$jscomp$1826_threads$jscomp$2$$)],null)))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.mark-all-as-read.success"),$APP.$cljs$cst$2353$timeout$$,7E3],null))))});return new $app$main$data$comments$mark_all_threads_as_read_56027$$($team_id$jscomp$69$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$comments$open_thread$$=function($p__56039$$){var $map__56040__$1$$=$APP.$cljs$core$__destructure_map$$($p__56039$$),$id$jscomp$437$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56040__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$comments$open_comment_thread_56043$$==="undefined"&&($app$main$data$comments$open_comment_thread_56043$$=function($p__56039$jscomp$1$$,$map__56040$jscomp$1$$,$thread$jscomp$17$$,$id$jscomp$438$$,$meta56044$$){this.$p__56039$=$p__56039$jscomp$1$$;
this.$map__56040$=$map__56040$jscomp$1$$;this.thread=$thread$jscomp$17$$;this.id=$id$jscomp$438$$;this.$meta56044$=$meta56044$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$open_comment_thread_56043$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$open_comment_thread_56043$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3469$app_DOT_main_DOT_data_DOT_comments_SLASH_open_comment_thread$$},
$app$main$data$comments$open_comment_thread_56043$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56045$$,$meta56044__$1$$){return new $app$main$data$comments$open_comment_thread_56043$$(this.$p__56039$,this.$map__56040$,this.thread,this.id,$meta56044__$1$$)},$app$main$data$comments$open_comment_thread_56043$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56044$},$app$main$data$comments$open_comment_thread_56043$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$comments$open_comment_thread_56043$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3430$thread_id$$,this.id],null)},$app$main$data$comments$open_comment_thread_56043$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$open_comment_thread_56043$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1828$$,$state$jscomp$275$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$275$$,
$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3434$open$$,this.id),$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$873$options$$,null),$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3435$draft$$)});return new $app$main$data$comments$open_comment_thread_56043$$($p__56039$$,$map__56040__$1$$,$map__56040__$1$$,$id$jscomp$437$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$comments$close_thread$$=function(){typeof $app$main$data$comments$close_comment_thread_56051$$==="undefined"&&($app$main$data$comments$close_comment_thread_56051$$=function($meta56052$$){this.$meta56052$=$meta56052$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$close_comment_thread_56051$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$close_comment_thread_56051$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3470$app_DOT_main_DOT_data_DOT_comments_SLASH_close_comment_thread$$},$app$main$data$comments$close_comment_thread_56051$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56053$$,$meta56052__$1$$){return new $app$main$data$comments$close_comment_thread_56051$$($meta56052__$1$$)},$app$main$data$comments$close_comment_thread_56051$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56052$},$app$main$data$comments$close_comment_thread_56051$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$close_comment_thread_56051$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1829$$,$state$jscomp$276$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$6$($state$jscomp$276$$,$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3434$open$$,$APP.$cljs$cst$3435$draft$$,$APP.$cljs$cst$873$options$$)});return new $app$main$data$comments$close_comment_thread_56051$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$update_filters$$=function($p__56059$$){var $map__56061__$1$$=$APP.$cljs$core$__destructure_map$$($p__56059$$),$mode$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56061__$1$$,$APP.$cljs$cst$320$mode$$),$show$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56061__$1$$,$cljs$cst$3471$show$$),$list$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56061__$1$$,$APP.$cljs$cst$201$list$$);typeof $app$main$data$comments$update_filters_56062$$===
"undefined"&&($app$main$data$comments$update_filters_56062$$=function($p__56059$jscomp$1$$,$map__56061$jscomp$1$$,$params$jscomp$239$$,$mode$jscomp$23$$,$show$jscomp$1$$,$list$jscomp$4$$,$meta56063$$){this.$p__56059$=$p__56059$jscomp$1$$;this.$map__56061$=$map__56061$jscomp$1$$;this.params=$params$jscomp$239$$;this.mode=$mode$jscomp$23$$;this.show=$show$jscomp$1$$;this.list=$list$jscomp$4$$;this.$meta56063$=$meta56063$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$comments$update_filters_56062$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_filters_56062$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3472$app_DOT_main_DOT_data_DOT_comments_SLASH_update_filters$$},$app$main$data$comments$update_filters_56062$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56064$$,$meta56063__$1$$){return new $app$main$data$comments$update_filters_56062$$(this.$p__56059$,
this.$map__56061$,this.params,this.mode,this.show,this.list,$meta56063__$1$$)},$app$main$data$comments$update_filters_56062$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56063$},$app$main$data$comments$update_filters_56062$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_filters_56062$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1830$$,$state$jscomp$277$$){var $self__$jscomp$4000$$=this;
return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$277$$,$APP.$cljs$cst$2233$comments_local$$,function($G__56070__$1_G__56070__$2_local$jscomp$1$$){$G__56070__$1_G__56070__$2_local$jscomp$1$$=$self__$jscomp$4000$$.mode!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__56070__$1_G__56070__$2_local$jscomp$1$$,$APP.$cljs$cst$320$mode$$,$self__$jscomp$4000$$.mode):$G__56070__$1_G__56070__$2_local$jscomp$1$$;$G__56070__$1_G__56070__$2_local$jscomp$1$$=$self__$jscomp$4000$$.show!=
null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__56070__$1_G__56070__$2_local$jscomp$1$$,$cljs$cst$3471$show$$,$self__$jscomp$4000$$.show):$G__56070__$1_G__56070__$2_local$jscomp$1$$;return $self__$jscomp$4000$$.list!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__56070__$1_G__56070__$2_local$jscomp$1$$,$APP.$cljs$cst$201$list$$,$self__$jscomp$4000$$.list):$G__56070__$1_G__56070__$2_local$jscomp$1$$})});return new $app$main$data$comments$update_filters_56062$$($p__56059$$,
$map__56061__$1$$,$map__56061__$1$$,$mode$jscomp$22$$,$show$$,$list$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$update_options$$=function($params$jscomp$240$$){typeof $app$main$data$comments$update_options_56074$$==="undefined"&&($app$main$data$comments$update_options_56074$$=function($params$jscomp$241$$,$meta56075$$){this.params=$params$jscomp$241$$;this.$meta56075$=$meta56075$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$update_options_56074$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$comments$update_options_56074$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3473$app_DOT_main_DOT_data_DOT_comments_SLASH_update_options$$},$app$main$data$comments$update_options_56074$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56076$$,$meta56075__$1$$){return new $app$main$data$comments$update_options_56074$$(this.params,$meta56075__$1$$)},$app$main$data$comments$update_options_56074$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56075$},
$app$main$data$comments$update_options_56074$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_options_56074$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1831$$,$state$jscomp$278$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$278$$,$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$core$merge$$,this.params)});return new $app$main$data$comments$update_options_56074$$($params$jscomp$240$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$comments$create_draft$$=function($params$jscomp$242$$){typeof $app$main$data$comments$create_draft_56086$$==="undefined"&&($app$main$data$comments$create_draft_56086$$=function($params$jscomp$243$$,$meta56087$$){this.params=$params$jscomp$243$$;this.$meta56087$=$meta56087$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$create_draft_56086$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$comments$create_draft_56086$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3474$app_DOT_main_DOT_data_DOT_comments_SLASH_create_draft$$},$app$main$data$comments$create_draft_56086$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56088$$,$meta56087__$1$$){return new $app$main$data$comments$create_draft_56086$$(this.params,$meta56087__$1$$)},$app$main$data$comments$create_draft_56086$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56087$},
$app$main$data$comments$create_draft_56086$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$create_draft_56086$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1832$$,$state$jscomp$279$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$279$$,$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3435$draft$$,this.params)});return new $app$main$data$comments$create_draft_56086$$($params$jscomp$242$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$update_draft_thread$$=function($data$jscomp$302$$){typeof $app$main$data$comments$update_draft_thread_56092$$==="undefined"&&($app$main$data$comments$update_draft_thread_56092$$=function($data$jscomp$303$$,$meta56093$$){this.data=$data$jscomp$303$$;this.$meta56093$=$meta56093$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$update_draft_thread_56092$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$comments$update_draft_thread_56092$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3475$app_DOT_main_DOT_data_DOT_comments_SLASH_update_draft_thread$$},$app$main$data$comments$update_draft_thread_56092$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56094$$,$meta56093__$1$$){return new $app$main$data$comments$update_draft_thread_56092$$(this.data,$meta56093__$1$$)},$app$main$data$comments$update_draft_thread_56092$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta56093$},$app$main$data$comments$update_draft_thread_56092$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_draft_thread_56092$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1833$$,$state$jscomp$280$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$280$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$cst$3435$draft$$],null),$APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.data]))});return new $app$main$data$comments$update_draft_thread_56092$$($data$jscomp$302$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$toggle_comment_options$$=function($comment_id$$){typeof $app$main$data$comments$toggle_comment_options_56099$$==="undefined"&&($app$main$data$comments$toggle_comment_options_56099$$=function($comment_id$jscomp$1$$,$meta56100$$){this.$comment_id$=$comment_id$jscomp$1$$;this.$meta56100$=$meta56100$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$toggle_comment_options_56099$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$toggle_comment_options_56099$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3476$app_DOT_main_DOT_data_DOT_comments_SLASH_toggle_comment_options$$},$app$main$data$comments$toggle_comment_options_56099$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56101$$,$meta56100__$1$$){return new $app$main$data$comments$toggle_comment_options_56099$$(this.$comment_id$,$meta56100__$1$$)},$app$main$data$comments$toggle_comment_options_56099$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta56100$},$app$main$data$comments$toggle_comment_options_56099$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$toggle_comment_options_56099$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1834$$,$state$jscomp$281$$){var $self__$jscomp$4016$$=this;return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$281$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$cst$873$options$$],null),function($p1__56098_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4016$$.$comment_id$,$p1__56098_SHARP_$$)?null:$self__$jscomp$4016$$.$comment_id$})});return new $app$main$data$comments$toggle_comment_options_56099$$($comment_id$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$hide_comment_options$$=function(){typeof $app$main$data$comments$hide_comment_options_56107$$==="undefined"&&($app$main$data$comments$hide_comment_options_56107$$=function($meta56108$$){this.$meta56108$=$meta56108$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$hide_comment_options_56107$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$hide_comment_options_56107$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3477$app_DOT_main_DOT_data_DOT_comments_SLASH_hide_comment_options$$},$app$main$data$comments$hide_comment_options_56107$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56109$$,$meta56108__$1$$){return new $app$main$data$comments$hide_comment_options_56107$$($meta56108__$1$$)},$app$main$data$comments$hide_comment_options_56107$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56108$},$app$main$data$comments$hide_comment_options_56107$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$hide_comment_options_56107$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1835$$,$state$jscomp$282$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$282$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2233$comments_local$$,$APP.$cljs$cst$873$options$$],null),$APP.$cljs$core$constantly$$(null))});return new $app$main$data$comments$hide_comment_options_56107$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$comments$get_owner$$=function($thread_or_comment$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$3324$owner_id$$.$cljs$core$IFn$_invoke$arity$1$($thread_or_comment$$),$APP.$cljs$cst$1360$fullname$$,$cljs$cst$3422$owner_fullname$$.$cljs$core$IFn$_invoke$arity$1$($thread_or_comment$$),$APP.$cljs$cst$3183$email$$,$cljs$cst$3423$owner_email$$.$cljs$core$IFn$_invoke$arity$1$($thread_or_comment$$),$APP.$cljs$cst$1359$photo_id$$,$cljs$cst$3478$owner_photo_id$$.$cljs$core$IFn$_invoke$arity$1$($thread_or_comment$$)],
null)};
$app$main$data$comments$group_threads_by_page$$=function($threads$jscomp$3$$){return $APP.$cljs$core$reverse$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$264$$,$thread$jscomp$18$$){var $current$jscomp$35$$=$APP.$cljs$core$first$$($result$jscomp$264$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$35$$),$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$18$$))?$APP.$cljs$core$cons$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($current$jscomp$35$$,
$APP.$cljs$cst$1838$items$$,$APP.$cljs$core$conj$$,$thread$jscomp$18$$),$APP.$cljs$core$rest$$($result$jscomp$264$$)):$APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$18$$),$cljs$cst$3424$page_name$$,$cljs$cst$3424$page_name$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$18$$),$APP.$cljs$cst$1838$items$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$thread$jscomp$18$$],null)],null),$result$jscomp$264$$)},null,$threads$jscomp$3$$))};
$app$main$data$comments$group_threads_by_file_and_page$$=function($threads$jscomp$4$$){return $APP.$cljs$core$reverse$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$265$$,$thread$jscomp$19$$){var $current$jscomp$36$$=$APP.$cljs$core$first$$($result$jscomp$265$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$36$$),$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$19$$))&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$36$$),$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$19$$))?$APP.$cljs$core$cons$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($current$jscomp$36$$,$APP.$cljs$cst$1838$items$$,$APP.$cljs$core$conj$$,$thread$jscomp$19$$),$APP.$cljs$core$rest$$($result$jscomp$265$$)):$APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$19$$),$cljs$cst$3424$page_name$$,$cljs$cst$3424$page_name$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$19$$),$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$19$$),$cljs$cst$3425$file_name$$,$cljs$cst$3425$file_name$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$19$$),$APP.$cljs$cst$1838$items$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$thread$jscomp$19$$],null)],null),$result$jscomp$265$$)},null,$threads$jscomp$4$$))};
$APP.$app$main$data$comments$apply_filters$$=function($cstate_map__56145__$1_mode$jscomp$24$$,$profile$jscomp$19$$,$G__56146__$1_G__56146__$2_threads$jscomp$5$$){$cstate_map__56145__$1_mode$jscomp$24$$=$APP.$cljs$core$__destructure_map$$($cstate_map__56145__$1_mode$jscomp$24$$);var $show$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cstate_map__56145__$1_mode$jscomp$24$$,$cljs$cst$3471$show$$);$cstate_map__56145__$1_mode$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cstate_map__56145__$1_mode$jscomp$24$$,
$APP.$cljs$cst$320$mode$$);$G__56146__$1_G__56146__$2_threads$jscomp$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$111$pending$$,$show$jscomp$2$$)?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$not$$,$APP.$cljs$cst$3445$is_resolved$$),$G__56146__$1_G__56146__$2_threads$jscomp$5$$):$G__56146__$1_G__56146__$2_threads$jscomp$5$$;$G__56146__$1_G__56146__$2_threads$jscomp$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3479$yours$$,
$cstate_map__56145__$1_mode$jscomp$24$$)?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__56143_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$3427$participants$$.$cljs$core$IFn$_invoke$arity$1$($p1__56143_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$19$$))},$G__56146__$1_G__56146__$2_threads$jscomp$5$$):$G__56146__$1_G__56146__$2_threads$jscomp$5$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3431$mentions$$,
$cstate_map__56145__$1_mode$jscomp$24$$)?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__56144_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$set$$($cljs$cst$3431$mentions$$.$cljs$core$IFn$_invoke$arity$1$($p1__56144_SHARP_$$)),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$19$$))},$G__56146__$1_G__56146__$2_threads$jscomp$5$$):$G__56146__$1_G__56146__$2_threads$jscomp$5$$};
$app$main$data$comments$detach_comment_thread$$=function($ids$jscomp$47$$){typeof $app$main$data$comments$detach_comment_thread_56173$$==="undefined"&&($app$main$data$comments$detach_comment_thread_56173$$=function($ids$jscomp$48$$,$meta56174$$){this.ids=$ids$jscomp$48$$;this.$meta56174$=$meta56174$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$detach_comment_thread_56173$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$comments$detach_comment_thread_56173$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3482$app_DOT_main_DOT_data_DOT_comments_SLASH_detach_comment_thread$$},$app$main$data$comments$detach_comment_thread_56173$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56175$$,$meta56174__$1$$){return new $app$main$data$comments$detach_comment_thread_56173$$(this.ids,$meta56174__$1$$)},$app$main$data$comments$detach_comment_thread_56173$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta56174$},$app$main$data$comments$detach_comment_thread_56173$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$detach_comment_thread_56173$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1838$$,$state$jscomp$284$$){var $objects$jscomp$266$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$284$$),$frame_ids_QMARK_$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($id$jscomp$439$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$266$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$439$$,$APP.$cljs$cst$139$type$$],null)))}),this.ids);return $APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$comments$update_comment_thread_frame$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($comment$jscomp$10$$){return $APP.$cljs$core$some$$(function($p1__56172_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__56172_SHARP_$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($comment$jscomp$10$$))},$frame_ids_QMARK_$$)},$APP.$cljs$core$vals$$($APP.$cljs$cst$2175$comment_threads$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$284$$)))))});return new $app$main$data$comments$detach_comment_thread_56173$$($ids$jscomp$47$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$fetch_profiles$$=function(){typeof $app$main$data$comments$fetch_profiles_56183$$==="undefined"&&($app$main$data$comments$fetch_profiles_56183$$=function($meta56184$$){this.$meta56184$=$meta56184$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$fetch_profiles_56183$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$fetch_profiles_56183$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3483$app_DOT_main_DOT_data_DOT_comments_SLASH_fetch_profiles$$},
$app$main$data$comments$fetch_profiles_56183$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56185$$,$meta56184__$1$$){return new $app$main$data$comments$fetch_profiles_56183$$($meta56184__$1$$)},$app$main$data$comments$fetch_profiles_56183$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56184$},$app$main$data$comments$fetch_profiles_56183$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$fetch_profiles_56183$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1839_file_id$jscomp$76$$,$state$jscomp$285$$){$_$jscomp$1839_file_id$jscomp$76$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$285$$);var $share_id$jscomp$11$$=function(){var $or__5025__auto__$jscomp$634$$=$APP.$cljs$cst$3237$share_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2231$viewer_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$285$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$634$$)?$or__5025__auto__$jscomp$634$$:
$APP.$cljs$cst$3484$current_share_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$285$$)}();return $APP.$beicon$v2$core$map$$(function($profiles$$){return function($p1__56182_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__56182_SHARP_$$,$APP.$cljs$cst$1915$profiles$$,$APP.$cljs$core$merge$$,$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$profiles$$))}},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3238$get_profiles_for_file_comments$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$_$jscomp$1839_file_id$jscomp$76$$,$APP.$cljs$cst$3237$share_id$$,$share_id$jscomp$11$$],null)))});return new $app$main$data$comments$fetch_profiles_56183$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$uploads$upload_blob_chunked$$=function($var_args$jscomp$1182$$){for(var $args__5755__auto__$jscomp$211$$=[],$len__5749__auto___55711$$=arguments.length,$i__5750__auto___55712$$=0;;)if($i__5750__auto___55712$$<$len__5749__auto___55711$$)$args__5755__auto__$jscomp$211$$.push(arguments[$i__5750__auto___55712$$]),$i__5750__auto___55712$$+=1;else break;return $APP.$app$main$data$uploads$upload_blob_chunked$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$211$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$211$$.slice(1),0,null):null)};
$APP.$app$main$data$uploads$upload_blob_chunked$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($blob$jscomp$21$$,$map__55697__$1_p__55696$$){$map__55697__$1_p__55696$$=$APP.$cljs$core$__destructure_map$$($map__55697__$1_p__55696$$);var $chunk_size$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55697__$1_p__55696$$,$APP.$cljs$cst$3485$chunk_size$$,$app$config$upload_chunk_size$$),$total_size$jscomp$1$$=$blob$jscomp$21$$.size,$total_chunks$$=Math.ceil($total_size$jscomp$1$$/
$chunk_size$jscomp$1$$);return $APP.$beicon$v2$core$mapcat$$(function($chunk_uploads_map__55701__$1_p__55700_raw_session_id$$){$chunk_uploads_map__55701__$1_p__55700_raw_session_id$$=$APP.$cljs$core$__destructure_map$$($chunk_uploads_map__55701__$1_p__55700_raw_session_id$$);$chunk_uploads_map__55701__$1_p__55700_raw_session_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($chunk_uploads_map__55701__$1_p__55700_raw_session_id$$,$APP.$cljs$cst$2332$session_id$$);var $session_id$jscomp$3$$=
typeof $chunk_uploads_map__55701__$1_p__55700_raw_session_id$$==="string"?$APP.$cljs$core$uuid$$($chunk_uploads_map__55701__$1_p__55700_raw_session_id$$):$chunk_uploads_map__55701__$1_p__55700_raw_session_id$$;$chunk_uploads_map__55701__$1_p__55700_raw_session_id$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($idx$jscomp$84$$){var $start$jscomp$214$$=$idx$jscomp$84$$*$chunk_size$jscomp$1$$,$x__5113__auto__$jscomp$inline_6254$$=$start$jscomp$214$$+$chunk_size$jscomp$1$$;return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2284$upload_chunk$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2332$session_id$$,$session_id$jscomp$3$$,$APP.$cljs$cst$1795$index$$,$idx$jscomp$84$$,$APP.$cljs$cst$1637$content$$,new $APP.$cljs$core$List$$(null,$blob$jscomp$21$$.slice($start$jscomp$214$$,$x__5113__auto__$jscomp$inline_6254$$<$total_size$jscomp$1$$?$x__5113__auto__$jscomp$inline_6254$$:$total_size$jscomp$1$$),new $APP.$cljs$core$List$$(null,"chunk-"+($idx$jscomp$84$$??""),null,1,null),2,null)],null))},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($total_chunks$$));
return $APP.$beicon$v2$core$map$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2332$session_id$$,$session_id$jscomp$3$$],null)},$APP.$beicon$v2$core$last$$($beicon$v2$core$merge_all$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$from$$($chunk_uploads_map__55701__$1_p__55700_raw_session_id$$))))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3486$create_upload_session$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3487$total_chunks$$,
$total_chunks$$],null)))};
$APP.$app$main$data$fonts$fonts_fetched$$=function($fonts$jscomp$11$$){function $prepare_font_variant$$($item$jscomp$67$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$266$id$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$67$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$67$$))].join(""),$APP.$cljs$cst$725$name$$,
$APP.$app$common$media$font_display_variant$$($APP.$cljs$cst$2002$variant_name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$67$$),$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$67$$),$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$67$$)),$APP.$cljs$cst$1904$style$$,$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$67$$),$APP.$cljs$cst$1996$weight$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$67$$)),
$cljs$cst$2681$app_DOT_main_DOT_fonts_SLASH_woff1_file_id$$,$cljs$cst$3488$woff1_file_id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$67$$),$cljs$cst$3489$app_DOT_main_DOT_fonts_SLASH_woff2_file_id$$,$cljs$cst$3490$woff2_file_id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$67$$),$cljs$cst$3491$app_DOT_main_DOT_fonts_SLASH_ttf_file_id$$,$cljs$cst$2970$ttf_file_id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$67$$),$cljs$cst$3492$app_DOT_main_DOT_fonts_SLASH_otf_file_id$$,$cljs$cst$3493$otf_file_id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$67$$)],
null)}function $variant_sort_fn$$($item$jscomp$66$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$66$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("normal",$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$66$$))?1:2],null)}typeof $app$main$data$fonts$fonts_loaded_55734$$==="undefined"&&($app$main$data$fonts$fonts_loaded_55734$$=function($fonts$jscomp$12$$,
$prepare_font$jscomp$1$$,$variant_sort_fn$jscomp$1$$,$prepare_font_variant$jscomp$1$$,$adapt_font_id$jscomp$1$$,$meta55735$$){this.fonts=$fonts$jscomp$12$$;this.$prepare_font$=$prepare_font$jscomp$1$$;this.$variant_sort_fn$=$variant_sort_fn$jscomp$1$$;this.$prepare_font_variant$=$prepare_font_variant$jscomp$1$$;this.$adapt_font_id$=$adapt_font_id$jscomp$1$$;this.$meta55735$=$meta55735$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$fonts$fonts_loaded_55734$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$fonts_loaded_55734$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3494$app_DOT_main_DOT_data_DOT_fonts_SLASH_fonts_loaded$$},$app$main$data$fonts$fonts_loaded_55734$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55736$$,$meta55735__$1$$){return new $app$main$data$fonts$fonts_loaded_55734$$(this.fonts,this.$prepare_font$,this.$variant_sort_fn$,this.$prepare_font_variant$,this.$adapt_font_id$,$meta55735__$1$$)},
$app$main$data$fonts$fonts_loaded_55734$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55735$},$app$main$data$fonts$fonts_loaded_55734$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$fonts_loaded_55734$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1841$$,$state$jscomp$286$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$286$$,$APP.$cljs$cst$2969$fonts$$,$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,
this.fonts))},$app$main$data$fonts$fonts_loaded_55734$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$fonts_loaded_55734$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){var $fonts__$1$jscomp$2$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(this.$prepare_font$,$APP.$cljs$core$group_by$$($APP.$cljs$cst$1757$font_id$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(this.$adapt_font_id$,this.fonts)));return $app$main$fonts$register_BANG_$$($cljs$cst$2682$custom$$,
$fonts__$1$jscomp$2$$)});return new $app$main$data$fonts$fonts_loaded_55734$$($fonts$jscomp$11$$,function($p__55726_vec__55730$$){var $id$jscomp$440$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55726_vec__55730$$,0,null);$p__55726_vec__55730$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55726_vec__55730$$,1,null);var $item$jscomp$65$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55726_vec__55730$$,0,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$266$id$$,$id$jscomp$440$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$65$$),$APP.$cljs$cst$2675$family$$,$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$65$$),$APP.$cljs$cst$2676$variants$$,$APP.$cljs$core$vec$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($variant_sort_fn$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($prepare_font_variant$$,$p__55726_vec__55730$$)))],
null)},$variant_sort_fn$$,$prepare_font_variant$$,function($variant$jscomp$12$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($variant$jscomp$12$$,$APP.$cljs$cst$1757$font_id$$,function($p1__55714_SHARP_$$){return["custom-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__55714_SHARP_$$)].join("")})},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$fonts$fetch_fonts$$=function($team_id$jscomp$71$$){typeof $app$main$data$fonts$fetch_fonts_55742$$==="undefined"&&($app$main$data$fonts$fetch_fonts_55742$$=function($team_id$jscomp$72$$,$meta55743$$){this.$team_id$=$team_id$jscomp$72$$;this.$meta55743$=$meta55743$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$fonts$fetch_fonts_55742$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$fetch_fonts_55742$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3495$app_DOT_main_DOT_data_DOT_fonts_SLASH_fetch_fonts$$},$app$main$data$fonts$fetch_fonts_55742$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55744$$,$meta55743__$1$$){return new $app$main$data$fonts$fetch_fonts_55742$$(this.$team_id$,$meta55743__$1$$)},$app$main$data$fonts$fetch_fonts_55742$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55743$},$app$main$data$fonts$fetch_fonts_55742$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$fonts$fetch_fonts_55742$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($APP.$app$main$data$fonts$fonts_fetched$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3496$get_font_variants$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,this.$team_id$],null)))});return new $app$main$data$fonts$fetch_fonts_55742$$($team_id$jscomp$71$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$project$project_fetched$$=function($p__55745$$){var $map__55746__$1$$=$APP.$cljs$core$__destructure_map$$($p__55745$$),$id$jscomp$447$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55746__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$project$project_fetched_55747$$==="undefined"&&($app$main$data$project$project_fetched_55747$$=function($p__55745$jscomp$1$$,$map__55746$jscomp$1$$,$project$jscomp$1$$,$id$jscomp$448$$,$meta55748$$){this.$p__55745$=$p__55745$jscomp$1$$;
this.$map__55746$=$map__55746$jscomp$1$$;this.project=$project$jscomp$1$$;this.id=$id$jscomp$448$$;this.$meta55748$=$meta55748$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$project$project_fetched_55747$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$project_fetched_55747$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3509$app_DOT_main_DOT_data_DOT_project_SLASH_project_fetched$$},
$app$main$data$project$project_fetched_55747$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55749$$,$meta55748__$1$$){return new $app$main$data$project$project_fetched_55747$$(this.$p__55745$,this.$map__55746$,this.project,this.id,$meta55748__$1$$)},$app$main$data$project$project_fetched_55747$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55748$},$app$main$data$project$project_fetched_55747$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$project$project_fetched_55747$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1855$$,$state$jscomp$298$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$298$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1928$projects$$,this.id],null),$APP.$cljs$core$merge$$,this.project)});return new $app$main$data$project$project_fetched_55747$$($p__55745$$,$map__55746__$1$$,
$map__55746__$1$$,$id$jscomp$447$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$project$fetch_project$cljs$0core$0IFn$0_invoke$0arity$01$$=function($project_id$jscomp$5$$){typeof $app$main$data$project$fetch_project_55771$$==="undefined"&&($app$main$data$project$fetch_project_55771$$=function($project_id$jscomp$6$$,$meta55772$$){this.$project_id$=$project_id$jscomp$6$$;this.$meta55772$=$meta55772$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$project$fetch_project_55771$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$fetch_project_55771$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3510$app_DOT_main_DOT_data_DOT_project_SLASH_fetch_project$$},$app$main$data$project$fetch_project_55771$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55773$$,$meta55772__$1$$){return new $app$main$data$project$fetch_project_55771$$(this.$project_id$,$meta55772__$1$$)},$app$main$data$project$fetch_project_55771$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55772$},$app$main$data$project$fetch_project_55771$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$fetch_project_55771$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1856_or__5025__auto__$jscomp$inline_6256$$,$project_id__$1$jscomp$1_state$jscomp$299$$){$_$jscomp$1856_or__5025__auto__$jscomp$inline_6256$$=this.$project_id$;$project_id__$1$jscomp$1_state$jscomp$299$$=$APP.$cljs$core$truth_$$($_$jscomp$1856_or__5025__auto__$jscomp$inline_6256$$)?
$_$jscomp$1856_or__5025__auto__$jscomp$inline_6256$$:$APP.$cljs$cst$2174$current_project_id$$.$cljs$core$IFn$_invoke$arity$1$($project_id__$1$jscomp$1_state$jscomp$299$$);return $APP.$beicon$v2$core$map$$($app$main$data$project$project_fetched$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3511$get_project$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$project_id__$1$jscomp$1_state$jscomp$299$$],null)))});return new $app$main$data$project$fetch_project_55771$$($project_id$jscomp$5$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$project$initialize_project$$=function($project_id$jscomp$7$$){typeof $app$main$data$project$initialize_project_55788$$==="undefined"&&($app$main$data$project$initialize_project_55788$$=function($project_id$jscomp$8$$,$meta55789$$){this.$project_id$=$project_id$jscomp$8$$;this.$meta55789$=$meta55789$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$project$initialize_project_55788$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$project$initialize_project_55788$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3512$app_DOT_main_DOT_data_DOT_project_SLASH_initialize_project$$},$app$main$data$project$initialize_project_55788$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55790$$,$meta55789__$1$$){return new $app$main$data$project$initialize_project_55788$$(this.$project_id$,$meta55789__$1$$)},$app$main$data$project$initialize_project_55788$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55789$},$app$main$data$project$initialize_project_55788$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$initialize_project_55788$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1857$$,$state$jscomp$300$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$300$$,$APP.$cljs$cst$2174$current_project_id$$,this.$project_id$)},$app$main$data$project$initialize_project_55788$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$initialize_project_55788$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$project$fetch_project$cljs$0core$0IFn$0_invoke$0arity$01$$(this.$project_id$))});return new $app$main$data$project$initialize_project_55788$$($project_id$jscomp$7$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$logic$variant_properties$generate_update_property_name$$=function($changes$jscomp$85$$,$related_components_variant_id$jscomp$11$$,$pos$jscomp$97$$,$new_name$jscomp$11$$){var $data$jscomp$308_prop_names_prop_names__$1_props$jscomp$143$$=$APP.$app$common$files$changes_builder$get_library_data$$($changes$jscomp$85$$),$objects$jscomp$267$$=$APP.$app$common$files$changes_builder$get_objects$$($changes$jscomp$85$$);$related_components_variant_id$jscomp$11$$=$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$308_prop_names_prop_names__$1_props$jscomp$143$$,
$objects$jscomp$267$$,$related_components_variant_id$jscomp$11$$);$data$jscomp$308_prop_names_prop_names__$1_props$jscomp$143$$=$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($related_components_variant_id$jscomp$11$$));$data$jscomp$308_prop_names_prop_names__$1_props$jscomp$143$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$data$jscomp$308_prop_names_prop_names__$1_props$jscomp$143$$);$data$jscomp$308_prop_names_prop_names__$1_props$jscomp$143$$=
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$308_prop_names_prop_names__$1_props$jscomp$143$$,0,$pos$jscomp$97$$),$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$308_prop_names_prop_names__$1_props$jscomp$143$$,$pos$jscomp$97$$+1));var $new_name__$1$$=$app$common$types$variant$update_number_in_repeated_item$$($data$jscomp$308_prop_names_prop_names__$1_props$jscomp$143$$,$new_name$jscomp$11$$);
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$8$$,$component$jscomp$51$$){return $APP.$app$common$files$changes_builder$update_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($changes__$1$jscomp$8$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$51$$),function($component__$1$$){return $APP.$app$common$data$update_in_when$$($component__$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2001$variant_properties$$,$pos$jscomp$97$$],null),function($p1__55801_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55801_SHARP_$$,$APP.$cljs$cst$725$name$$,$new_name__$1$$)})},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3179$apply_changes_local_library_QMARK_$$,!0],null)]))},$changes$jscomp$85$$,$related_components_variant_id$jscomp$11$$)};
$app$common$logic$variant_properties$generate_remove_property$$=function($changes$jscomp$86$$,$related_components$jscomp$1_variant_id$jscomp$12$$,$pos$jscomp$98$$){var $data$jscomp$309_props$jscomp$144$$=$APP.$app$common$files$changes_builder$get_library_data$$($changes$jscomp$86$$),$objects$jscomp$268$$=$APP.$app$common$files$changes_builder$get_objects$$($changes$jscomp$86$$);$related_components$jscomp$1_variant_id$jscomp$12$$=$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$309_props$jscomp$144$$,
$objects$jscomp$268$$,$related_components$jscomp$1_variant_id$jscomp$12$$);$data$jscomp$309_props$jscomp$144$$=$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($related_components$jscomp$1_variant_id$jscomp$12$$));return $APP.$cljs$core$seq$$($data$jscomp$309_props$jscomp$144$$)&&0<=$pos$jscomp$98$$&&$pos$jscomp$98$$<$APP.$cljs$core$count$$($data$jscomp$309_props$jscomp$144$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$9$$,
$component$jscomp$52$$){var $main_id_props__$1$jscomp$21$$=$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$52$$),$props__$2$jscomp$3$$=$APP.$app$common$data$remove_at_index$$($main_id_props__$1$jscomp$21$$,$pos$jscomp$98$$);$main_id_props__$1$jscomp$21$$=$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$52$$);var $name$jscomp$284$$=$APP.$app$common$types$variant$properties_to_name$$($props__$2$jscomp$3$$);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($changes__$1$jscomp$9$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$52$$),function($p1__55811_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55811_SHARP_$$,$APP.$cljs$cst$2001$variant_properties$$,$props__$2$jscomp$3$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3179$apply_changes_local_library_QMARK_$$,!0],null)])),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$main_id_props__$1$jscomp$21$$],null),function($p1__55813_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55813_SHARP_$$,$APP.$cljs$cst$2002$variant_name$$,$name$jscomp$284$$)})},$changes$jscomp$86$$,$related_components$jscomp$1_variant_id$jscomp$12$$):$changes$jscomp$86$$};
$app$common$logic$variant_properties$generate_update_property_value$$=function($changes$jscomp$87$$,$component_id$jscomp$33$$,$pos$jscomp$99$$,$value$jscomp$539$$){var $component$jscomp$53_data$jscomp$310$$=$APP.$app$common$files$changes_builder$get_library_data$$($changes$jscomp$87$$);$component$jscomp$53_data$jscomp$310$$=$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($component$jscomp$53_data$jscomp$310$$,$component_id$jscomp$33$$,!0);var $main_id$jscomp$1$$=
$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$53_data$jscomp$310$$),$name$jscomp$285$$=$APP.$app$common$types$variant$properties_to_name$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$53_data$jscomp$310$$),$pos$jscomp$99$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$260$value$$,$value$jscomp$539$$));return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($changes$jscomp$87$$,
$component_id$jscomp$33$$,function($p1__55823_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__55823_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2001$variant_properties$$,$pos$jscomp$99$$,$APP.$cljs$cst$260$value$$],null),$value$jscomp$539$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3179$apply_changes_local_library_QMARK_$$,!0],null)])),
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$main_id$jscomp$1$$],null),function($p1__55824_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55824_SHARP_$$,$APP.$cljs$cst$2002$variant_name$$,$name$jscomp$285$$)})};
$app$common$logic$variant_properties$generate_set_variant_error$$=function($changes$jscomp$88$$,$component$jscomp$54_component_id$jscomp$34_main_id$jscomp$2$$,$value$jscomp$540$$){var $data$jscomp$311$$=$APP.$app$common$files$changes_builder$get_library_data$$($changes$jscomp$88$$);$component$jscomp$54_component_id$jscomp$34_main_id$jscomp$2$$=$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$311$$,$component$jscomp$54_component_id$jscomp$34_main_id$jscomp$2$$,
!0);$component$jscomp$54_component_id$jscomp$34_main_id$jscomp$2$$=$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$54_component_id$jscomp$34_main_id$jscomp$2$$);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$88$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$component$jscomp$54_component_id$jscomp$34_main_id$jscomp$2$$],null),$value$jscomp$540$$==
null?function($p1__55827_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__55827_SHARP_$$,$APP.$cljs$cst$2003$variant_error$$)}:function($p1__55828_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55828_SHARP_$$,$APP.$cljs$cst$2003$variant_error$$,$value$jscomp$540$$)})};
$app$common$logic$variant_properties$generate_add_new_property$$=function($var_args$jscomp$1185$$){for(var $args__5755__auto__$jscomp$212$$=[],$len__5749__auto___55966$$=arguments.length,$i__5750__auto___55967$$=0;;)if($i__5750__auto___55967$$<$len__5749__auto___55966$$)$args__5755__auto__$jscomp$212$$.push(arguments[$i__5750__auto___55967$$]),$i__5750__auto___55967$$+=1;else break;return $app$common$logic$variant_properties$generate_add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
arguments[1],2<$args__5755__auto__$jscomp$212$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$212$$.slice(2),0,null):null)};
$app$common$logic$variant_properties$generate_add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($changes$jscomp$90_vec__55877$$,$related_components$jscomp$3_variant_id$jscomp$14$$,$editing_QMARK__p__55864$$){var $data$jscomp$313_map__55865__$1_prop_names$jscomp$1_props$jscomp$146$$=$APP.$cljs$core$__destructure_map$$($editing_QMARK__p__55864$$),$fill_values_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$313_map__55865__$1_prop_names$jscomp$1_props$jscomp$146$$,
$cljs$cst$3517$fill_values_QMARK_$$);$editing_QMARK__p__55864$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$313_map__55865__$1_prop_names$jscomp$1_props$jscomp$146$$,$APP.$cljs$cst$3518$editing_QMARK_$$);var $property_name_property_name__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$313_map__55865__$1_prop_names$jscomp$1_props$jscomp$146$$,$cljs$cst$3519$property_name$$),$property_value$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$313_map__55865__$1_prop_names$jscomp$1_props$jscomp$146$$,
$APP.$cljs$cst$3520$property_value$$);$data$jscomp$313_map__55865__$1_prop_names$jscomp$1_props$jscomp$146$$=$APP.$app$common$files$changes_builder$get_library_data$$($changes$jscomp$90_vec__55877$$);var $next_prop_num$jscomp$1_objects$jscomp$270$$=$APP.$app$common$files$changes_builder$get_objects$$($changes$jscomp$90_vec__55877$$);$related_components$jscomp$3_variant_id$jscomp$14$$=$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$313_map__55865__$1_prop_names$jscomp$1_props$jscomp$146$$,
$next_prop_num$jscomp$1_objects$jscomp$270$$,$related_components$jscomp$3_variant_id$jscomp$14$$);$data$jscomp$313_map__55865__$1_prop_names$jscomp$1_props$jscomp$146$$=$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($related_components$jscomp$3_variant_id$jscomp$14$$));$next_prop_num$jscomp$1_objects$jscomp$270$$=$app$common$types$variant$next_property_number$$($data$jscomp$313_map__55865__$1_prop_names$jscomp$1_props$jscomp$146$$);$property_name_property_name__$1$$=
$APP.$cljs$core$truth_$$($property_name_property_name__$1$$)?$property_name_property_name__$1$$:["Property ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($next_prop_num$jscomp$1_objects$jscomp$270$$)].join("");$data$jscomp$313_map__55865__$1_prop_names$jscomp$1_props$jscomp$146$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$data$jscomp$313_map__55865__$1_prop_names$jscomp$1_props$jscomp$146$$);var $property_name__$2$$=$app$common$types$variant$update_number_in_repeated_item$$($data$jscomp$313_map__55865__$1_prop_names$jscomp$1_props$jscomp$146$$,
$property_name_property_name__$1$$),$mdata$jscomp$2$$=$APP.$cljs$core$truth_$$($editing_QMARK__p__55864$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3518$editing_QMARK_$$,!0],null):null;$changes$jscomp$90_vec__55877$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$12_p__55882$$,$component$jscomp$56$$){function $update_name$$($p1__55855_SHARP_$$){return $APP.$cljs$core$truth_$$($fill_values_QMARK_$$)?$APP.$cuerdas$core$empty_QMARK_$$($p1__55855_SHARP_$$)?
["Value ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($num$jscomp$31$$)].join(""):[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__55855_SHARP_$$),", Value ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($num$jscomp$31$$)].join(""):$APP.$cljs$core$truth_$$($property_value$$)?$APP.$cuerdas$core$empty_QMARK_$$($p1__55855_SHARP_$$)?$property_value$$:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__55855_SHARP_$$),", ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($property_value$$)].join(""):
$p1__55855_SHARP_$$}function $update_props$$($p1__55854_SHARP_$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($p1__55854_SHARP_$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,$property_name__$2$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$truth_$$($fill_values_QMARK_$$)?["Value ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($num$jscomp$31$$)].join(""):
$APP.$cljs$core$truth_$$($property_value$$)?$property_value$$:""],null),$mdata$jscomp$2$$))}var $num$jscomp$31$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$1$jscomp$12_p__55882$$,0,null);$changes__$1$jscomp$12_p__55882$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$1$jscomp$12_p__55882$$,1,null);var $main_id$jscomp$4$$=$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$56$$);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$num$jscomp$31$$+1,$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($changes__$1$jscomp$12_p__55882$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$56$$),function($p1__55858_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__55858_SHARP_$$,$APP.$cljs$cst$2001$variant_properties$$,
$update_props$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3179$apply_changes_local_library_QMARK_$$,!0],null)])),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$main_id$jscomp$4$$],null),function($p1__55859_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__55859_SHARP_$$,$APP.$cljs$cst$2002$variant_name$$,$update_name$$)})],null)},new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,$changes$jscomp$90_vec__55877$$],null),$related_components$jscomp$3_variant_id$jscomp$14$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$90_vec__55877$$,0,null);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$90_vec__55877$$,1,null)};
$app$common$logic$variant_properties$generate_make_shape_no_variant$$=function($changes$jscomp$91$$,$shape$jscomp$381$$){var $new_name$jscomp$12$$=$app$common$types$variant$variant_name_to_name$$($shape$jscomp$381$$),$vec__55912$$=$app$common$path_names$split_group_name$$($new_name$jscomp$12$$),$cpath$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__55912$$,0,null),$cname$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__55912$$,1,null);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($changes$jscomp$91$$,
$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$381$$),function($p1__55898_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__55898_SHARP_$$,$APP.$cljs$cst$2000$variant_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2001$variant_properties$$])),$APP.$cljs$cst$725$name$$,$cname$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$296$path$$,
$cpath$jscomp$1$$]))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3179$apply_changes_local_library_QMARK_$$,!0],null)])),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$381$$)],null),function($p1__55899_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__55899_SHARP_$$,
$APP.$cljs$cst$2000$variant_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2002$variant_name$$])),$APP.$cljs$cst$725$name$$,$new_name$jscomp$12$$)})};
$app$common$logic$variant_properties$generate_make_shapes_variant$$=function($changes$jscomp$93_changes__$1$jscomp$13_changes__$2$jscomp$1$$,$shapes$jscomp$37$$,$variant_container$$){function $create_new_properties$$($component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$,$JSCompiler_temp$jscomp$1088_min_props$jscomp$3_new_props$jscomp$inline_6267_props__$1$jscomp$inline_6268$$){if($APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$)){$component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$=
$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$315$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$),!0);var $add_name_QMARK_$jscomp$inline_6265_component_full_name$jscomp$inline_6264_long_name$jscomp$inline_12327$$=$APP.$app$common$path_names$merge_path_item$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$),
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$));$add_name_QMARK_$jscomp$inline_6265_component_full_name$jscomp$inline_6264_long_name$jscomp$inline_12327$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($add_name_QMARK_$jscomp$inline_6265_component_full_name$jscomp$inline_6264_long_name$jscomp$inline_12327$$,$container_name$jscomp$2$$);var $props$jscomp$inline_6266$$=$app$common$types$variant$merge_properties$$($base_props$$,
$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$));$JSCompiler_temp$jscomp$1088_min_props$jscomp$3_new_props$jscomp$inline_6267_props__$1$jscomp$inline_6268$$-=$APP.$cljs$core$count$$($props$jscomp$inline_6266$$)+($add_name_QMARK_$jscomp$inline_6265_component_full_name$jscomp$inline_6264_long_name$jscomp$inline_12327$$?1:0);$JSCompiler_temp$jscomp$1088_min_props$jscomp$3_new_props$jscomp$inline_6267_props__$1$jscomp$inline_6268$$=
$app$common$types$variant$add_new_props$$($props$jscomp$inline_6266$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$1088_min_props$jscomp$3_new_props$jscomp$inline_6267_props__$1$jscomp$inline_6268$$,""));$JSCompiler_temp$jscomp$1088_min_props$jscomp$3_new_props$jscomp$inline_6267_props__$1$jscomp$inline_6268$$=$add_name_QMARK_$jscomp$inline_6265_component_full_name$jscomp$inline_6264_long_name$jscomp$inline_12327$$?$app$common$types$variant$add_new_prop$$($JSCompiler_temp$jscomp$1088_min_props$jscomp$3_new_props$jscomp$inline_6267_props__$1$jscomp$inline_6268$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$)):$JSCompiler_temp$jscomp$1088_min_props$jscomp$3_new_props$jscomp$inline_6267_props__$1$jscomp$inline_6268$$}else $component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$),
$add_name_QMARK_$jscomp$inline_6265_component_full_name$jscomp$inline_6264_long_name$jscomp$inline_12327$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($container_name$jscomp$2$$)," / "].join(""),$component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$=$APP.$cuerdas$core$starts_with_QMARK_$$($component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$,$add_name_QMARK_$jscomp$inline_6265_component_full_name$jscomp$inline_6264_long_name$jscomp$inline_12327$$)?
$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$,$add_name_QMARK_$jscomp$inline_6265_component_full_name$jscomp$inline_6264_long_name$jscomp$inline_12327$$.length):$APP.$cuerdas$core$starts_with_QMARK_$$($component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$,$container_name$jscomp$2$$)?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$,
$APP.$cljs$core$count$$($container_name$jscomp$2$$)):$component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$,$JSCompiler_temp$jscomp$1088_min_props$jscomp$3_new_props$jscomp$inline_6267_props__$1$jscomp$inline_6268$$=$app$common$types$variant$path_to_properties$cljs$0core$0IFn$0_invoke$0arity$03$$($component$jscomp$inline_6263_name$jscomp$inline_12325_shape$jscomp$384_shape_name$jscomp$inline_6274$$,$base_props$$,$JSCompiler_temp$jscomp$1088_min_props$jscomp$3_new_props$jscomp$inline_6267_props__$1$jscomp$inline_6268$$);
return $JSCompiler_temp$jscomp$1088_min_props$jscomp$3_new_props$jscomp$inline_6267_props__$1$jscomp$inline_6268$$}var $data$jscomp$315$$=$APP.$app$common$files$changes_builder$get_library_data$$($changes$jscomp$93_changes__$1$jscomp$13_changes__$2$jscomp$1$$),$first_comp_id_objects$jscomp$271_vec__55948$$=$APP.$app$common$files$changes_builder$get_objects$$($changes$jscomp$93_changes__$1$jscomp$13_changes__$2$jscomp$1$$),$variant_id$jscomp$15$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($variant_container$$),
$num_shapes$$=$APP.$cljs$core$count$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($variant_container$$));$first_comp_id_objects$jscomp$271_vec__55948$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_comp_id_objects$jscomp$271_vec__55948$$,$APP.$cljs$core$first$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($variant_container$$))));var $base_props$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__55940_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55940_SHARP_$$,
$APP.$cljs$cst$260$value$$,"")},$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$315$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$first_comp_id_objects$jscomp$271_vec__55948$$,$APP.$cljs$cst$2001$variant_properties$$],null))),$num_base_props$$=$APP.$cljs$core$count$$($base_props$$);$first_comp_id_objects$jscomp$271_vec__55948$$=$app$common$path_names$split_group_name$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($variant_container$$));
var $cpath$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($first_comp_id_objects$jscomp$271_vec__55948$$,0,null),$cname$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($first_comp_id_objects$jscomp$271_vec__55948$$,1,null),$container_name$jscomp$2$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($variant_container$$),$total_props$jscomp$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($m$jscomp$216$$,$shape$jscomp$385_y__5111__auto__$jscomp$58$$){$shape$jscomp$385_y__5111__auto__$jscomp$58$$=
$APP.$cljs$core$count$$($create_new_properties$$($shape$jscomp$385_y__5111__auto__$jscomp$58$$,$num_base_props$$));return $m$jscomp$216$$>$shape$jscomp$385_y__5111__auto__$jscomp$58$$?$m$jscomp$216$$:$shape$jscomp$385_y__5111__auto__$jscomp$58$$},0,$shapes$jscomp$37$$);$changes$jscomp$93_changes__$1$jscomp$13_changes__$2$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$core$iterate$$(function($p1__55941_SHARP_$$){return $app$common$logic$variant_properties$generate_add_new_property$$($p1__55941_SHARP_$$,
$variant_id$jscomp$15$$)},$changes$jscomp$93_changes__$1$jscomp$13_changes__$2$jscomp$1$$),$num_shapes$$===0||$total_props$jscomp$1$$<$num_base_props$$?0:$total_props$jscomp$1$$-$num_base_props$$);$changes$jscomp$93_changes__$1$jscomp$13_changes__$2$jscomp$1$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$93_changes__$1$jscomp$13_changes__$2$jscomp$1$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$shapes$jscomp$37$$),
function($p1__55942_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__55942_SHARP_$$,$APP.$cljs$cst$2000$variant_id$$,$variant_id$jscomp$15$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($variant_container$$)]))});return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$3$$,$shape$jscomp$386$$){var $component$jscomp$58$$=$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$315$$,
$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$386$$),!0);if($num_shapes$$===0||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant_id$jscomp$15$$,$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$386$$))&&$APP.$cljs$core$not$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$58$$)))return $changes__$3$$;var $props$jscomp$148$$=$create_new_properties$$($shape$jscomp$386$$,$total_props$jscomp$1$$),
$variant_name$jscomp$1$$=$APP.$app$common$types$variant$properties_to_name$$($props$jscomp$148$$);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($changes__$3$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$386$$),function($p1__55946_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__55946_SHARP_$$,
$APP.$cljs$cst$2000$variant_id$$,$variant_id$jscomp$15$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2001$variant_properties$$,$props$jscomp$148$$,$APP.$cljs$cst$725$name$$,$cname$jscomp$1$$,$APP.$cljs$cst$296$path$$,$cpath$jscomp$2$$]))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3179$apply_changes_local_library_QMARK_$$,!0],null)])),new $APP.$cljs$core$PersistentVector$$(null,1,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$386$$)],null),function($p1__55947_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55947_SHARP_$$,$APP.$cljs$cst$2002$variant_name$$,$variant_name$jscomp$1$$)})},$changes$jscomp$93_changes__$1$jscomp$13_changes__$2$jscomp$1$$,$shapes$jscomp$37$$)};
$app$common$types$shape$token$font_weight_applied_QMARK_$$=function($shape$jscomp$387$$){var $or__5025__auto__$jscomp$644$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$387$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1873$applied_tokens$$,$APP.$cljs$cst$1761$font_weight$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$644$$)?$or__5025__auto__$jscomp$644$$:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$387$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1873$applied_tokens$$,$APP.$cljs$cst$1981$typography$$,$APP.$cljs$cst$1761$font_weight$$],null))};
$app$common$logic$shapes$generate_unapply_tokens$$=function($changes$jscomp$94$$,$objects$jscomp$272$$,$changed_sub_attr$jscomp$1$$){function $check_attr$$($shape$jscomp$389$$,$changes__$1$jscomp$14$$,$attr$jscomp$40$$){var $shape_id$jscomp$63$$=$shape$jscomp$389$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$389$$,$APP.$cljs$cst$266$id$$),$tokens$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$389$$,$APP.$cljs$cst$1873$applied_tokens$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$),$token_attrs$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$389$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$40$$,$APP.$cljs$cst$1637$content$$)?$text_changed_attrs$$($shape$jscomp$389$$):$APP.$app$common$types$token$shape_attr__GT_token_attrs$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$40$$,$changed_sub_attr$jscomp$1$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__56012_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($tokens$jscomp$20$$,
$p1__56012_SHARP_$$)},$token_attrs$$))?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$1$jscomp$14$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$63$$],null),function($p1__56013_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__56013_SHARP_$$,$APP.$cljs$cst$1873$applied_tokens$$,$APP.$app$common$data$without_keys$$,$token_attrs$$)}):$changes__$1$jscomp$14$$}
function $text_changed_attrs$$($JSCompiler_inline_result$jscomp$inline_12330_attrs__$1$jscomp$9_shape$jscomp$388$$){var $G__56015__$1$jscomp$inline_12329_new_shape$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_objects$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$inline_12330_attrs__$1$jscomp$9_shape$jscomp$388$$)),$and__5023__auto__$jscomp$inline_12331_attrs$jscomp$66$$=$app$common$types$text$get_diff_attrs$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$inline_12330_attrs__$1$jscomp$9_shape$jscomp$388$$),
$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($G__56015__$1$jscomp$inline_12329_new_shape$jscomp$4$$));$G__56015__$1$jscomp$inline_12329_new_shape$jscomp$4$$=$APP.$cljs$core$seq$$($APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($app$common$logic$shapes$text_typography_style_attrs$$,$and__5023__auto__$jscomp$inline_12331_attrs$jscomp$66$$))?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$inline_12331_attrs$jscomp$66$$,$app$common$types$token$typography_keys$$):
$and__5023__auto__$jscomp$inline_12331_attrs$jscomp$66$$;$and__5023__auto__$jscomp$inline_12331_attrs$jscomp$66$$=$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$inline_12331_attrs$jscomp$66$$);$JSCompiler_inline_result$jscomp$inline_12330_attrs__$1$jscomp$9_shape$jscomp$388$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_12331_attrs$jscomp$66$$)?$app$common$types$shape$token$font_weight_applied_QMARK_$$($JSCompiler_inline_result$jscomp$inline_12330_attrs__$1$jscomp$9_shape$jscomp$388$$):
$and__5023__auto__$jscomp$inline_12331_attrs$jscomp$66$$;$JSCompiler_inline_result$jscomp$inline_12330_attrs__$1$jscomp$9_shape$jscomp$388$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_12330_attrs__$1$jscomp$9_shape$jscomp$388$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__56015__$1$jscomp$inline_12329_new_shape$jscomp$4$$,$APP.$cljs$cst$1761$font_weight$$):$G__56015__$1$jscomp$inline_12329_new_shape$jscomp$4$$;return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$union$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$token$shape_attr__GT_token_attrs$$,$JSCompiler_inline_result$jscomp$inline_12330_attrs__$1$jscomp$9_shape$jscomp$388$$))}var $new_objects$$=$APP.$app$common$files$changes_builder$get_objects$$($changes$jscomp$94$$),$mod_obj_changes$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__56011_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__56011_SHARP_$$),
$APP.$cljs$cst$2612$mod_obj$$)},$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$94$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$15$$,$attrs$jscomp$67_mod_obj_change$$){var $shape$jscomp$390$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$272$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$67_mod_obj_change$$));$attrs$jscomp$67_mod_obj_change$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__56014_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__56014_SHARP_$$),$APP.$cljs$cst$203$set$$)}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2599$attr$$)),$APP.$cljs$cst$2613$operations$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$67_mod_obj_change$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($check_attr$$,
$shape$jscomp$390$$),$changes__$1$jscomp$15$$,$attrs$jscomp$67_mod_obj_change$$)},$changes$jscomp$94$$,$mod_obj_changes$$)};
$app$common$logic$shapes$generate_update_shapes$$=function($changes$jscomp$95$$,$ids$jscomp$49$$,$update_fn$jscomp$13$$,$objects$jscomp$273$$,$map__56031__$1_p__56030_translation_QMARK_$jscomp$5$$){$map__56031__$1_p__56030_translation_QMARK_$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($map__56031__$1_p__56030_translation_QMARK_$jscomp$5$$);var $attrs$jscomp$68$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56031__$1_p__56030_translation_QMARK_$jscomp$5$$,$APP.$cljs$cst$2645$attrs$$),
$changed_sub_attr$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56031__$1_p__56030_translation_QMARK_$jscomp$5$$,$APP.$cljs$cst$3521$changed_sub_attr$$),$ignore_tree$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56031__$1_p__56030_translation_QMARK_$jscomp$5$$,$cljs$cst$3522$ignore_tree$$),$ignore_touched$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56031__$1_p__56030_translation_QMARK_$jscomp$5$$,$APP.$cljs$cst$2556$ignore_touched$$),
$with_objects_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56031__$1_p__56030_translation_QMARK_$jscomp$5$$,$APP.$cljs$cst$3175$with_objects_QMARK_$$);$map__56031__$1_p__56030_translation_QMARK_$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56031__$1_p__56030_translation_QMARK_$jscomp$5$$,$cljs$cst$3145$translation_QMARK_$$);var $changes__$1$jscomp$16$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$17$$,
$id$jscomp$449$$){var $opts$jscomp$296$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2645$attrs$$,$attrs$jscomp$68$$,$cljs$cst$3176$ignore_geometry_QMARK_$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ignore_tree$$,$id$jscomp$449$$),$APP.$cljs$cst$2556$ignore_touched$$,$ignore_touched$jscomp$8$$,$APP.$cljs$cst$3175$with_objects_QMARK_$$,$with_objects_QMARK_$jscomp$2$$],null);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($changes__$1$jscomp$17$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$449$$],null),$update_fn$jscomp$13$$,$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$296$$))},$objects$jscomp$273$$!=null?$APP.$app$common$files$changes_builder$with_objects$$($changes$jscomp$95$$,$objects$jscomp$273$$):$changes$jscomp$95$$,$ids$jscomp$49$$),$grid_ids$$=$APP.$cljs$core$truth_$$($map__56031__$1_p__56030_translation_QMARK_$jscomp$5$$)?null:$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$,
$objects$jscomp$273$$),$ids$jscomp$49$$);return function(){var $G__56037__$1$$=$APP.$cljs$core$seq$$($grid_ids$$)?$APP.$app$common$files$changes_builder$reorder_grid_children$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($changes__$1$jscomp$16$$,$grid_ids$$,$app$common$types$shape$layout$assign_cell_positions$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)),$ids$jscomp$49$$):$changes__$1$jscomp$16$$;
return $APP.$cljs$core$not$$($ignore_touched$jscomp$8$$)?$app$common$logic$shapes$generate_unapply_tokens$$($G__56037__$1$$,$objects$jscomp$273$$,$changed_sub_attr$jscomp$2$$):$G__56037__$1$$}()};
$app$common$logic$shapes$generate_update_shape_flags$$=function($changes$jscomp$96$$,$ids$jscomp$50_ids__$1$jscomp$2$$,$objects$jscomp$274$$){var $map__56047__$1$$=$APP.$cljs$core$__destructure_map$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1620$hidden$$,!0],null)),$blocked$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56047__$1$$,$APP.$cljs$cst$1623$blocked$$),$hidden$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56047__$1$$,$APP.$cljs$cst$1620$hidden$$);
$ids$jscomp$50_ids__$1$jscomp$2$$=$APP.$cljs$core$boolean_QMARK_$$($blocked$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$50_ids__$1$jscomp$2$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__56038_SHARP_$$){return $APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$274$$,$p1__56038_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$ids$jscomp$50_ids__$1$jscomp$2$$]))):$ids$jscomp$50_ids__$1$jscomp$2$$;
return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$96$$,$ids$jscomp$50_ids__$1$jscomp$2$$,function($G__56049__$1_obj$jscomp$197$$){$G__56049__$1_obj$jscomp$197$$=$APP.$cljs$core$boolean_QMARK_$$($blocked$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__56049__$1_obj$jscomp$197$$,$APP.$cljs$cst$1623$blocked$$,$blocked$$):$G__56049__$1_obj$jscomp$197$$;return $APP.$cljs$core$boolean_QMARK_$$($hidden$jscomp$6$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__56049__$1_obj$jscomp$197$$,
$APP.$cljs$cst$1620$hidden$$,$hidden$jscomp$6$$):$G__56049__$1_obj$jscomp$197$$},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1620$hidden$$,null,$APP.$cljs$cst$1623$blocked$$,null],null),null)],null))};
$app$common$logic$shapes$generate_delete_shapes$cljs$0core$0IFn$0_invoke$0arity$06$$=function($changes$jscomp$97$$,$file$jscomp$46$$,$page$jscomp$48$$,$objects$jscomp$275$$,$ids$jscomp$51$$,$options$jscomp$503$$){return $app$common$logic$shapes$generate_delete_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($changes$jscomp$97$$,$page$jscomp$48$$),
$objects$jscomp$275$$),$file$jscomp$46$$),$ids$jscomp$51$$,$options$jscomp$503$$)};
$app$common$logic$shapes$generate_delete_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$=function($changes$jscomp$98$$,$ids$jscomp$52_ids_to_hide_vec__56071$$,$changes__$4_ignore_touched$jscomp$9_p__56065$$){var $interacting_shapes_map__56066__$1$$=$APP.$cljs$core$__destructure_map$$($changes__$4_ignore_touched$jscomp$9_p__56065$$);$changes__$4_ignore_touched$jscomp$9_p__56065$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interacting_shapes_map__56066__$1$$,$APP.$cljs$cst$2556$ignore_touched$$);
var $allow_altering_copies$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interacting_shapes_map__56066__$1$$,$cljs$cst$2618$allow_altering_copies$$),$ignore_children_fn$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($interacting_shapes_map__56066__$1$$,$cljs$cst$1618$ignore_children_fn$$,$APP.$cljs$core$constantly$$(!1)),$groups_to_unmask_ignore_mask$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($interacting_shapes_map__56066__$1$$,$cljs$cst$3523$ignore_mask$$,
!1),$ignore_flows_for$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($interacting_shapes_map__56066__$1$$,$cljs$cst$3524$ignore_flows_for$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$objects$jscomp$276$$=$APP.$app$common$files$changes_builder$get_objects$$($changes$jscomp$98$$),$data$jscomp$316$$=$APP.$app$common$files$changes_builder$get_library_data$$($changes$jscomp$98$$),$page_id$jscomp$96$$=$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$98$$)),
$page$jscomp$49$$=function(){var $or__5025__auto__$jscomp$645$$=$APP.$cljs$cst$3167$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$98$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$645$$)?$or__5025__auto__$jscomp$645$$:$APP.$app$common$types$pages_list$get_page$$($data$jscomp$316$$,$page_id$jscomp$96$$)}(),$ids__$1$jscomp$3$$=$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$276$$,$ids$jscomp$52_ids_to_hide_vec__56071$$);
$ids$jscomp$52_ids_to_hide_vec__56071$$=function(){for(var $G__56187_G__56190_ids_seq$$=$APP.$cljs$core$seq$$($ids__$1$jscomp$3$$),$G__56188_G__56191_ids_to_delete$jscomp$1$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$G__56189_G__56192_ids_to_hide$jscomp$1$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $id$jscomp$450$$=$APP.$cljs$core$first$$($G__56187_G__56190_ids_seq$$);if($id$jscomp$450$$==null)return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$G__56188_G__56191_ids_to_delete$jscomp$1$$,$G__56189_G__56192_ids_to_hide$jscomp$1$$],null);var $and__5023__auto__$jscomp$inline_6280_shape$jscomp$inline_6279$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$276$$,$id$jscomp$450$$);$and__5023__auto__$jscomp$inline_6280_shape$jscomp$inline_6279$$=$APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$276$$,$and__5023__auto__$jscomp$inline_6280_shape$jscomp$inline_6279$$);$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_6280_shape$jscomp$inline_6279$$)?
$APP.$cljs$core$not$$($allow_altering_copies$jscomp$1$$):$and__5023__auto__$jscomp$inline_6280_shape$jscomp$inline_6279$$)?($G__56187_G__56190_ids_seq$$=$APP.$cljs$core$rest$$($G__56187_G__56190_ids_seq$$),$G__56189_G__56192_ids_to_hide$jscomp$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__56189_G__56192_ids_to_hide$jscomp$1$$,$id$jscomp$450$$)):($G__56187_G__56190_ids_seq$$=$APP.$cljs$core$rest$$($G__56187_G__56190_ids_seq$$),$G__56188_G__56191_ids_to_delete$jscomp$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__56188_G__56191_ids_to_delete$jscomp$1$$,
$id$jscomp$450$$))}}();var $ids_to_delete$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$52_ids_to_hide_vec__56071$$,0,null);$ids$jscomp$52_ids_to_hide_vec__56071$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$52_ids_to_hide_vec__56071$$,1,null);var $lookup$jscomp$17$$=$APP.$app$common$data$getf$$($objects$jscomp$276$$);$groups_to_unmask_ignore_mask$$=$APP.$cljs$core$truth_$$($groups_to_unmask_ignore_mask$$)?null:function(){$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($group_ids$$,
$JSCompiler_inline_result$jscomp$1091_id$jscomp$451$$){var $obj$jscomp$198_parent$jscomp$208$$=$lookup$jscomp$17$$($JSCompiler_inline_result$jscomp$1091_id$jscomp$451$$);$obj$jscomp$198_parent$jscomp$208$$=$lookup$jscomp$17$$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$198_parent$jscomp$208$$));var $and__5023__auto__$jscomp$inline_6282$$=$APP.$cljs$cst$1609$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$198_parent$jscomp$208$$);$JSCompiler_inline_result$jscomp$1091_id$jscomp$451$$=
$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_6282$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1091_id$jscomp$451$$,$APP.$cljs$core$first$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$198_parent$jscomp$208$$))):$and__5023__auto__$jscomp$inline_6282$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1091_id$jscomp$451$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($group_ids$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$198_parent$jscomp$208$$)):
$group_ids$$},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$ids_to_delete$$);return $APP.$cljs$core$PersistentVector$EMPTY$$}();$interacting_shapes_map__56066__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($interactions$jscomp$9_shape$jscomp$392$$){$interactions$jscomp$9_shape$jscomp$392$$=$APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($interactions$jscomp$9_shape$jscomp$392$$);return $APP.$cljs$core$some$$(function($p1__56050_SHARP_$$){var $and__5023__auto__$jscomp$362$$=
$APP.$app$common$types$shape$interactions$has_destination$$($p1__56050_SHARP_$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$362$$)?$APP.$cljs$core$contains_QMARK_$$($ids_to_delete$$,$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($p1__56050_SHARP_$$)):$and__5023__auto__$jscomp$362$$},$interactions$jscomp$9_shape$jscomp$392$$)},$APP.$cljs$core$vals$$($objects$jscomp$276$$));var $id_to_delete_QMARK_$$=$APP.$cljs$core$set$$($ids_to_delete$$),$changes__$1$jscomp$18_changes__$2$jscomp$3_changes__$3$jscomp$1$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$19$$,$JSCompiler_inline_result$jscomp$10838_flow$jscomp$1_p__56081$$){var $id$jscomp$452$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$10838_flow$jscomp$1_p__56081$$,0,null);$JSCompiler_inline_result$jscomp$10838_flow$jscomp$1_p__56081$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$10838_flow$jscomp$1_p__56081$$,1,null);
var $G__56085$jscomp$inline_12334_and__5023__auto__$jscomp$inline_12333$$=$APP.$cljs$cst$2053$starting_frame$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10838_flow$jscomp$1_p__56081$$);$G__56085$jscomp$inline_12334_and__5023__auto__$jscomp$inline_12333$$=$id_to_delete_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$id_to_delete_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__56085$jscomp$inline_12334_and__5023__auto__$jscomp$inline_12333$$):$id_to_delete_QMARK_$$($G__56085$jscomp$inline_12334_and__5023__auto__$jscomp$inline_12333$$);
$JSCompiler_inline_result$jscomp$10838_flow$jscomp$1_p__56081$$=$APP.$cljs$core$truth_$$($G__56085$jscomp$inline_12334_and__5023__auto__$jscomp$inline_12333$$)?!$APP.$cljs$core$contains_QMARK_$$($ignore_flows_for$$,$APP.$cljs$cst$2053$starting_frame$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10838_flow$jscomp$1_p__56081$$)):$G__56085$jscomp$inline_12334_and__5023__auto__$jscomp$inline_12333$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10838_flow$jscomp$1_p__56081$$)?
$app$common$files$changes_builder$set_flow$$($APP.$app$common$files$changes_builder$with_page$$($changes__$1$jscomp$19$$,$page$jscomp$49$$),$id$jscomp$452$$,null):$changes__$1$jscomp$19$$},$changes$jscomp$98$$,$APP.$cljs$cst$2056$flows$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$49$$)),$all_parents$jscomp$2$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($res$jscomp$39$$,$id$jscomp$453$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($res$jscomp$39$$,$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$276$$,
$id$jscomp$453$$))},$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($ids_to_delete$$,$ids$jscomp$52_ids_to_hide_vec__56071$$)),$descendants_to_delete$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$reverse$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($res$jscomp$40$$,$id$jscomp$454$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($res$jscomp$40$$,
$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$276$$,$id$jscomp$454$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1618$ignore_children_fn$$,$ignore_children_fn$jscomp$1$$],null)))},$APP.$cljs$core$PersistentVector$EMPTY$$,$ids_to_delete$$))),$empty_parents_find_all_empty_parents$$=function $app$common$logic$shapes$recursive_find_empty_parents$$($empty_parents$jscomp$1$$){var $all_ids_parents$jscomp$5_xform$jscomp$33$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($empty_parents$jscomp$1$$,
$ids_to_delete$$),$contains_QMARK_$jscomp$1$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$contains_QMARK_$$,$all_ids_parents$jscomp$5_xform$jscomp$33$$);$all_ids_parents$jscomp$5_xform$jscomp$33$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($lookup$jscomp$17$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__56054_SHARP_$$){var $or__5025__auto__$jscomp$646_or__5025__auto____$1$jscomp$80$$=
$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__56054_SHARP_$$);return $or__5025__auto__$jscomp$646_or__5025__auto____$1$jscomp$80$$?$or__5025__auto__$jscomp$646_or__5025__auto____$1$jscomp$80$$:($or__5025__auto__$jscomp$646_or__5025__auto____$1$jscomp$80$$=$APP.$app$common$files$helpers$bool_shape_QMARK_$$($p1__56054_SHARP_$$))?$or__5025__auto__$jscomp$646_or__5025__auto____$1$jscomp$80$$:$APP.$app$common$types$component$is_variant_container_QMARK_$$($p1__56054_SHARP_$$)}),
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__56055_SHARP_$$){return $APP.$cljs$core$seq$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($contains_QMARK_$jscomp$1$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($p1__56055_SHARP_$$)))}),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$)]));$all_ids_parents$jscomp$5_xform$jscomp$33$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$all_ids_parents$jscomp$5_xform$jscomp$33$$,$all_parents$jscomp$2$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($empty_parents$jscomp$1$$,$all_ids_parents$jscomp$5_xform$jscomp$33$$)?$empty_parents$jscomp$1$$:$app$common$logic$shapes$recursive_find_empty_parents$$($all_ids_parents$jscomp$5_xform$jscomp$33$$)};$empty_parents_find_all_empty_parents$$=$APP.$cljs$core$not$$($allow_altering_copies$jscomp$1$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),
$empty_parents_find_all_empty_parents$$($APP.$cljs$core$PersistentHashSet$EMPTY$$)):$APP.$cljs$core$PersistentHashSet$EMPTY$$;var $components_to_delete$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($components$jscomp$3$$,$id$jscomp$455_shape$jscomp$393$$){$id$jscomp$455_shape$jscomp$393$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$276$$,$id$jscomp$455_shape$jscomp$393$$);var $JSCompiler_inline_result$jscomp$1092_and__5023__auto__$jscomp$inline_6286$$=
($JSCompiler_inline_result$jscomp$1092_and__5023__auto__$jscomp$inline_6286$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$455_shape$jscomp$393$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$316$$)))?$APP.$cljs$cst$2045$main_instance$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$455_shape$jscomp$393$$):$JSCompiler_inline_result$jscomp$1092_and__5023__auto__$jscomp$inline_6286$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1092_and__5023__auto__$jscomp$inline_6286$$)?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($components$jscomp$3$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$455_shape$jscomp$393$$)):$components$jscomp$3$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($ids_to_delete$$,$descendants_to_delete$$)),$ids_set$jscomp$1$$=$APP.$cljs$core$set$$($ids_to_delete$$),$guides_to_delete$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__56056_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($ids_set$jscomp$1$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__56056_SHARP_$$))},$APP.$cljs$core$vals$$($APP.$cljs$cst$2057$guides$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$49$$))));$changes__$1$jscomp$18_changes__$2$jscomp$3_changes__$3$jscomp$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$2$jscomp$4$$,$guide_id$$){return $app$common$files$changes_builder$set_flow$$($APP.$app$common$files$changes_builder$with_page$$($changes__$2$jscomp$4$$,
$page$jscomp$49$$),$guide_id$$,null)},$changes__$1$jscomp$18_changes__$2$jscomp$3_changes__$3$jscomp$1$$,$guides_to_delete$$);$changes__$1$jscomp$18_changes__$2$jscomp$3_changes__$3$jscomp$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$3$jscomp$2$$,$component_id$jscomp$35$$){return $APP.$app$common$files$changes_builder$delete_component$$($changes__$3$jscomp$2$$,$component_id$jscomp$35$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$49$$))},
$changes__$1$jscomp$18_changes__$2$jscomp$3_changes__$3$jscomp$1$$,$components_to_delete$$);$changes__$4_ignore_touched$jscomp$9_p__56065$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$resize_parents$$($app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$logic$shapes$generate_update_shape_flags$$($changes__$1$jscomp$18_changes__$2$jscomp$3_changes__$3$jscomp$1$$,
$ids$jscomp$52_ids_to_hide_vec__56071$$,$objects$jscomp$276$$),$descendants_to_delete$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null)),$ids_to_delete$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,$changes__$4_ignore_touched$jscomp$9_p__56065$$],null)),$empty_parents_find_all_empty_parents$$),$all_parents$jscomp$2$$),$groups_to_unmask_ignore_mask$$,function($shape$jscomp$394$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$394$$,
$APP.$cljs$cst$1609$masked_group$$,!1)}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$interacting_shapes_map__56066__$1$$),function($shape$jscomp$395$$){return $APP.$app$common$data$update_when$$($shape$jscomp$395$$,$APP.$cljs$cst$2051$interactions$$,function($interactions$jscomp$10$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__56057_SHARP_$$){var $and__5023__auto__$jscomp$365$$=
$APP.$app$common$types$shape$interactions$has_destination$$($p1__56057_SHARP_$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$365$$)?$APP.$cljs$core$contains_QMARK_$$($ids_to_delete$$,$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($p1__56057_SHARP_$$)):$and__5023__auto__$jscomp$365$$}),$interactions$jscomp$10$$)})});return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$all_parents$jscomp$2$$,$changes__$4_ignore_touched$jscomp$9_p__56065$$],
null)};
$app$common$logic$shapes$generate_relocate$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($changes$jscomp$99$$,$parent_id$jscomp$38$$,$to_index$jscomp$8$$,$G__56147_all_parents$jscomp$3_ids$jscomp$53$$,$cell$jscomp$21_empty_variant_cont_p__56129$$){var $ignore_parents_QMARK__index_cell_data_map__56130__$1_vec__56131$$=$APP.$cljs$core$__destructure_map$$($cell$jscomp$21_empty_variant_cont_p__56129$$);$cell$jscomp$21_empty_variant_cont_p__56129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ignore_parents_QMARK__index_cell_data_map__56130__$1_vec__56131$$,$APP.$cljs$cst$3525$cell$$);
$ignore_parents_QMARK__index_cell_data_map__56130__$1_vec__56131$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ignore_parents_QMARK__index_cell_data_map__56130__$1_vec__56131$$,$cljs$cst$3526$ignore_parents_QMARK_$$);var $objects$jscomp$277$$=$APP.$app$common$files$changes_builder$get_objects$$($changes$jscomp$99$$),$ids__$1$jscomp$4$$=$app$common$files$helpers$order_by_indexed_shapes$$($objects$jscomp$277$$,$G__56147_all_parents$jscomp$3_ids$jscomp$53$$),$shapes$jscomp$38$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$277$$),
$ids__$1$jscomp$4$$),$parent$jscomp$209$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$277$$,$parent_id$jscomp$38$$);$G__56147_all_parents$jscomp$3_ids$jscomp$53$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$parent_id$jscomp$38$$]),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__56114_SHARP_$$){return $APP.$app$common$files$helpers$get_parent_id$$($objects$jscomp$277$$,$p1__56114_SHARP_$$)}),
$ids__$1$jscomp$4$$);var $parents$jscomp$6$$=$APP.$cljs$core$truth_$$($ignore_parents_QMARK__index_cell_data_map__56130__$1_vec__56131$$)?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$parent_id$jscomp$38$$]):$G__56147_all_parents$jscomp$3_ids$jscomp$53$$,$children_ids$jscomp$5$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__56115_SHARP_$$){return $app$common$files$helpers$get_children_ids_with_self$$($objects$jscomp$277$$,$p1__56115_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$ids__$1$jscomp$4$$])),
$child_heads$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__56116_SHARP_$$){return $app$common$types$container$get_child_heads$$($objects$jscomp$277$$,$p1__56116_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$ids__$1$jscomp$4$$])),$child_heads_ids$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$child_heads$$),$variant_shapes$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$is_variant_QMARK_$$,
$shapes$jscomp$38$$),$component_main_parent$$=$APP.$app$common$types$container$find_component_main$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$277$$,$parent$jscomp$209$$,!1),$groups_to_delete$$=function(){for(var $G__56203_current_id$jscomp$4$$=$APP.$cljs$core$first$$($parents$jscomp$6$$),$G__56199_G__56204_to_check$jscomp$1$$=$APP.$cljs$core$rest$$($parents$jscomp$6$$),$G__56201_G__56205_removed_id_QMARK_$$=$APP.$cljs$core$set$$($ids__$1$jscomp$4$$),$G__56202_G__56206_result$jscomp$267$$=
$APP.$cljs$core$PersistentHashSet$EMPTY$$;;){if($APP.$cljs$core$not$$($G__56203_current_id$jscomp$4$$))return $G__56202_G__56206_result$jscomp$267$$;var $G__56200_group$jscomp$29_to_check__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$277$$,$G__56203_current_id$jscomp$4$$);$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__56200_group$jscomp$29_to_check__$1$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__56203_current_id$jscomp$4$$,
$parent_id$jscomp$38$$)&&$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($G__56201_G__56205_removed_id_QMARK_$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($G__56200_group$jscomp$29_to_check__$1$$)))?($G__56200_group$jscomp$29_to_check__$1$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($G__56199_G__56204_to_check$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$files$helpers$get_parent_id$$($objects$jscomp$277$$,
$G__56203_current_id$jscomp$4$$)],null)),$G__56199_G__56204_to_check$jscomp$1$$=$APP.$cljs$core$first$$($G__56200_group$jscomp$29_to_check__$1$$),$G__56200_group$jscomp$29_to_check__$1$$=$APP.$cljs$core$rest$$($G__56200_group$jscomp$29_to_check__$1$$),$G__56201_G__56205_removed_id_QMARK_$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__56201_G__56205_removed_id_QMARK_$$,$G__56203_current_id$jscomp$4$$),$G__56202_G__56206_result$jscomp$267$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__56202_G__56206_result$jscomp$267$$,
$G__56203_current_id$jscomp$4$$),$G__56203_current_id$jscomp$4$$=$G__56199_G__56204_to_check$jscomp$1$$,$G__56199_G__56204_to_check$jscomp$1$$=$G__56200_group$jscomp$29_to_check__$1$$):($G__56203_current_id$jscomp$4$$=$APP.$cljs$core$first$$($G__56199_G__56204_to_check$jscomp$1$$),$G__56199_G__56204_to_check$jscomp$1$$=$APP.$cljs$core$rest$$($G__56199_G__56204_to_check$jscomp$1$$))}}(),$groups_to_unmask$jscomp$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($group_ids$jscomp$1$$,
$JSCompiler_inline_result$jscomp$1093_id$jscomp$456$$){var $obj$jscomp$199_parent__$1$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$277$$,$JSCompiler_inline_result$jscomp$1093_id$jscomp$456$$);$obj$jscomp$199_parent__$1$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$277$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$199_parent__$1$jscomp$52$$));var $and__5023__auto__$jscomp$inline_6288$$=$APP.$cljs$cst$1609$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$199_parent__$1$jscomp$52$$);
$JSCompiler_inline_result$jscomp$1093_id$jscomp$456$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_6288$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1093_id$jscomp$456$$,$APP.$cljs$core$first$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$199_parent__$1$jscomp$52$$)))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$199_parent__$1$jscomp$52$$),
$parent_id$jscomp$38$$):$and__5023__auto__$jscomp$inline_6288$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1093_id$jscomp$456$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($group_ids$jscomp$1$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$199_parent__$1$jscomp$52$$)):$group_ids$jscomp$1$$},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$ids__$1$jscomp$4$$);$ignore_parents_QMARK__index_cell_data_map__56130__$1_vec__56131$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__56134_shapes_to_reroot$jscomp$1$$,
$id$jscomp$457$$){var $shapes_to_detach$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__56134_shapes_to_reroot$jscomp$1$$,0,null),$shapes_to_deroot$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__56134_shapes_to_reroot$jscomp$1$$,1,null);$p__56134_shapes_to_reroot$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__56134_shapes_to_reroot$jscomp$1$$,2,null);var $reroot_QMARK__shape$jscomp$396$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$277$$,
$id$jscomp$457$$),$deroot_QMARK__parent__$1$jscomp$53_root_parent$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$277$$,$parent_id$jscomp$38$$),$component_shape$jscomp$2_detach_QMARK_$$=$APP.$app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$277$$,$reroot_QMARK__shape$jscomp$396$$),$component_shape_parent_ids_to_detach$$=$app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$277$$,
$deroot_QMARK__parent__$1$jscomp$53_root_parent$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2547$allow_main_QMARK_$$,!0],null));$deroot_QMARK__parent__$1$jscomp$53_root_parent$$=$APP.$app$common$types$container$get_instance_root$$($objects$jscomp$277$$,$deroot_QMARK__parent__$1$jscomp$53_root_parent$$);$component_shape$jscomp$2_detach_QMARK_$$=$app$common$types$component$in_component_copy_not_head_QMARK_$$($reroot_QMARK__shape$jscomp$396$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$jscomp$2_detach_QMARK_$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_shape_parent_ids_to_detach$$));var $and__5023__auto__$jscomp$inline_12336$$=$APP.$app$common$types$component$instance_root_QMARK_$$($reroot_QMARK__shape$jscomp$396$$);$deroot_QMARK__parent__$1$jscomp$53_root_parent$$=$and__5023__auto__$jscomp$inline_12336$$?$deroot_QMARK__parent__$1$jscomp$53_root_parent$$:$and__5023__auto__$jscomp$inline_12336$$;$reroot_QMARK__shape$jscomp$396$$=$app$common$types$component$subinstance_head_QMARK_$$($reroot_QMARK__shape$jscomp$396$$)&&
$APP.$cljs$core$not$$($component_shape_parent_ids_to_detach$$);$component_shape_parent_ids_to_detach$$=$component_shape$jscomp$2_detach_QMARK_$$?$APP.$cljs$core$cons$$($id$jscomp$457$$,$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$277$$,$id$jscomp$457$$)):null;return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$component_shape$jscomp$2_detach_QMARK_$$?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($shapes_to_detach$jscomp$1$$,
$component_shape_parent_ids_to_detach$$):$shapes_to_detach$jscomp$1$$,$APP.$cljs$core$truth_$$($deroot_QMARK__parent__$1$jscomp$53_root_parent$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($shapes_to_deroot$jscomp$1$$,$id$jscomp$457$$):$shapes_to_deroot$jscomp$1$$,$reroot_QMARK__shape$jscomp$396$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p__56134_shapes_to_reroot$jscomp$1$$,$id$jscomp$457$$):$p__56134_shapes_to_reroot$jscomp$1$$],null)},new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__56117_SHARP_$$){return $app$common$types$container$get_child_heads$$($objects$jscomp$277$$,$p1__56117_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$ids__$1$jscomp$4$$]))));
var $shapes_to_detach$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ignore_parents_QMARK__index_cell_data_map__56130__$1_vec__56131$$,0,null),$shapes_to_deroot$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ignore_parents_QMARK__index_cell_data_map__56130__$1_vec__56131$$,1,null),$shapes_to_reroot$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ignore_parents_QMARK__index_cell_data_map__56130__$1_vec__56131$$,2,null);$ignore_parents_QMARK__index_cell_data_map__56130__$1_vec__56131$$=
$APP.$cljs$core$truth_$$($to_index$jscomp$8$$)?$app$common$types$shape$layout$get_cell_by_index$$($parent$jscomp$209$$,$to_index$jscomp$8$$):null;var $cell__$1$jscomp$3$$=$APP.$cljs$core$truth_$$($cell$jscomp$21_empty_variant_cont_p__56129$$)?$cell$jscomp$21_empty_variant_cont_p__56129$$:$APP.$cljs$core$truth_$$($ignore_parents_QMARK__index_cell_data_map__56130__$1_vec__56131$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($ignore_parents_QMARK__index_cell_data_map__56130__$1_vec__56131$$),
$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($ignore_parents_QMARK__index_cell_data_map__56130__$1_vec__56131$$)],null):$ignore_parents_QMARK__index_cell_data_map__56130__$1_vec__56131$$;$cell$jscomp$21_empty_variant_cont_p__56129$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($to_delete$$,$parent__$1$jscomp$54_parent_id__$1$jscomp$4$$){$parent__$1$jscomp$54_parent_id__$1$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$277$$,
$parent__$1$jscomp$54_parent_id__$1$jscomp$4$$);var $JSCompiler_inline_result$jscomp$1094_and__5023__auto__$jscomp$inline_6290$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($parent__$1$jscomp$54_parent_id__$1$jscomp$4$$);$JSCompiler_inline_result$jscomp$1094_and__5023__auto__$jscomp$inline_6290$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1094_and__5023__auto__$jscomp$inline_6290$$)?$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($ids__$1$jscomp$4$$),
$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$54_parent_id__$1$jscomp$4$$))):$JSCompiler_inline_result$jscomp$1094_and__5023__auto__$jscomp$inline_6290$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1094_and__5023__auto__$jscomp$inline_6290$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($to_delete$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$54_parent_id__$1$jscomp$4$$)):$to_delete$$},$APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__56118_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__56118_SHARP_$$,$parent_id$jscomp$38$$)},$G__56147_all_parents$jscomp$3_ids$jscomp$53$$));$G__56147_all_parents$jscomp$3_ids$jscomp$53$$=$APP.$app$common$files$changes_builder$resize_parents$$(function(){var $G__56148$$=function(){var $G__56149$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$04$$(function(){var $G__56150$$=
function(){var $G__56151$$=function(){var $G__56152$$=function(){var $G__56153$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(function(){var $G__56154$$=$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$209$$)?$changes$jscomp$99$$:$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$99$$,
$ids__$1$jscomp$4$$,$app$common$types$shape$layout$remove_layout_item_data$$),$ids__$1$jscomp$4$$,$app$common$types$token$unapply_layout_item_tokens$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$parent_id$jscomp$38$$)&&$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$209$$)?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__56154$$,$ids__$1$jscomp$4$$,function($p1__56119_SHARP_$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__56119_SHARP_$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__56119_SHARP_$$,$APP.$cljs$cst$1875$hide_in_viewer$$,!0):$p1__56119_SHARP_$$}):$G__56154$$}(),$child_heads_ids$$,function($shape$jscomp$397$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($component_main_parent$$,$APP.$app$common$types$container$find_component_main$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$277$$,$shape$jscomp$397$$,!1))?$app$common$types$component$remove_swap_slot$$($shape$jscomp$397$$):$shape$jscomp$397$$});
return $APP.$cljs$core$truth_$$($APP.$app$common$types$container$get_instance_root$$($objects$jscomp$277$$,$parent$jscomp$209$$))?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__56153$$,$children_ids$jscomp$5$$,function($p1__56120_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__56120_SHARP_$$,$APP.$cljs$cst$2044$component_root$$)}):$G__56153$$}();return $APP.$cljs$core$not$$($APP.$app$common$types$container$get_instance_root$$($objects$jscomp$277$$,
$parent$jscomp$209$$))?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__56152$$,$child_heads_ids$$,function($p1__56121_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__56121_SHARP_$$,$APP.$cljs$cst$2044$component_root$$,!0)}):$G__56152$$}();return $APP.$cljs$core$not$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($parent$jscomp$209$$))?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$logic$variant_properties$generate_make_shape_no_variant$$,
$G__56151$$,$variant_shapes$$):$G__56151$$}();return $APP.$cljs$core$truth_$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($parent$jscomp$209$$))?$app$common$logic$variant_properties$generate_make_shapes_variant$$($G__56150$$,$child_heads$$,$parent$jscomp$209$$):$G__56150$$}(),$parent_id$jscomp$38$$,$shapes$jscomp$38$$,$to_index$jscomp$8$$),$groups_to_delete$$),$groups_to_unmask$jscomp$1$$,function($shape$jscomp$398$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$398$$,
$APP.$cljs$cst$1609$masked_group$$,!1)}),$shapes_to_detach$$,$app$common$types$component$detach_shape$$),$shapes_to_deroot$$,function($shape$jscomp$399$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$399$$,$APP.$cljs$cst$2044$component_root$$,null)}),$shapes_to_reroot$$,function($shape$jscomp$400$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$400$$,$APP.$cljs$cst$2044$component_root$$,!0)}),$ids__$1$jscomp$4$$,function($shape$jscomp$401$$){var $frame_id$jscomp$39_moved_shape$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$209$$),$APP.$cljs$cst$1606$frame$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$209$$):$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$209$$);$frame_id$jscomp$39_moved_shape$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape$jscomp$401$$,$APP.$cljs$cst$1619$parent_id$$,$parent_id$jscomp$38$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1607$frame_id$$,
$frame_id$jscomp$39_moved_shape$$]));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape$jscomp$401$$,$APP.$cljs$cst$1872$constraints_h$$,$APP.$app$common$geom$shapes$constraints$default_constraints_h$$($frame_id$jscomp$39_moved_shape$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1871$constraints_v$$,$APP.$app$common$geom$shapes$constraints$default_constraints_v$$($frame_id$jscomp$39_moved_shape$$)]))},new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null)),$parents$jscomp$6$$,function($parent__$1$jscomp$55$$){if($APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$55$$)){var $G__56165__$1$$=$APP.$cljs$core$truth_$$($app$common$types$shape$layout$change_h_sizing_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$55$$),$objects$jscomp$277$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$55$$)))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parent__$1$jscomp$55$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$,$APP.$cljs$cst$1697$fix$$):$parent__$1$jscomp$55$$;return $APP.$cljs$core$truth_$$($app$common$types$shape$layout$change_v_sizing_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$55$$),$objects$jscomp$277$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$55$$)))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__56165__$1$$,
$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1697$fix$$):$G__56165__$1$$}return $parent__$1$jscomp$55$$});return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$277$$,$parent_id$jscomp$38$$))?$APP.$app$common$files$changes_builder$reorder_grid_children$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($G__56149$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$parent_id$jscomp$38$$],null),function($frame$jscomp$15$$,$objects__$1$jscomp$5$$){var $row$jscomp$21$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell__$1$jscomp$3$$,0,null),$column$jscomp$27$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell__$1$jscomp$3$$,1,null);return $app$common$types$shape$layout$assign_cell_positions$$($cell__$1$jscomp$3$$!=null?$APP.$app$common$types$shape$layout$assign_cells$$($app$common$types$shape$layout$push_into_cell$$($app$common$types$shape$layout$free_cell_shapes$$($frame$jscomp$15$$,
$ids__$1$jscomp$4$$),$ids__$1$jscomp$4$$,$row$jscomp$21$$,$column$jscomp$27$$),$objects__$1$jscomp$5$$):$frame$jscomp$15$$,$objects__$1$jscomp$5$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent_id$jscomp$38$$],null)):$G__56149$$}();return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1623$blocked$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$209$$))?
$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__56148$$,$ids__$1$jscomp$4$$,function($p1__56122_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__56122_SHARP_$$,$APP.$cljs$cst$1623$blocked$$,!0)}):$G__56148$$}(),$parents$jscomp$6$$);return $APP.$cljs$core$seq$$($cell$jscomp$21_empty_variant_cont_p__56129$$)?$APP.$cljs$core$second$$($app$common$logic$shapes$generate_delete_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__56147_all_parents$jscomp$3_ids$jscomp$53$$,
$cell$jscomp$21_empty_variant_cont_p__56129$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)):$G__56147_all_parents$jscomp$3_ids$jscomp$53$$};$APP.$app$common$logic$shapes$show_in_viewer$$=function($shape$jscomp$404$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$404$$,$APP.$cljs$cst$1875$hide_in_viewer$$)};
$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$=function($JSCompiler_inline_result$jscomp$710_JSCompiler_temp$jscomp$706_id$jscomp$458$$,$container$jscomp$38_objects$jscomp$inline_6292$$){var $JSCompiler_temp_const$jscomp$708_or__5025__auto__$jscomp$648_or__5025__auto____$1$jscomp$81$$=$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$PersistentHashSet$EMPTY$$);if($JSCompiler_temp_const$jscomp$708_or__5025__auto__$jscomp$648_or__5025__auto____$1$jscomp$81$$||($JSCompiler_temp_const$jscomp$708_or__5025__auto__$jscomp$648_or__5025__auto____$1$jscomp$81$$=
$JSCompiler_inline_result$jscomp$710_JSCompiler_temp$jscomp$706_id$jscomp$458$$==null))return $JSCompiler_temp_const$jscomp$708_or__5025__auto__$jscomp$648_or__5025__auto____$1$jscomp$81$$;if($APP.$cljs$core$truth_$$($container$jscomp$38_objects$jscomp$inline_6292$$)){$JSCompiler_temp_const$jscomp$708_or__5025__auto__$jscomp$648_or__5025__auto____$1$jscomp$81$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$;var $JSCompiler_temp_const$jscomp$707$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$;
$container$jscomp$38_objects$jscomp$inline_6292$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$38_objects$jscomp$inline_6292$$);$JSCompiler_inline_result$jscomp$710_JSCompiler_temp$jscomp$706_id$jscomp$458$$=$APP.$cljs$core$cons$$($JSCompiler_inline_result$jscomp$710_JSCompiler_temp$jscomp$706_id$jscomp$458$$,$app$common$files$helpers$get_parent_ids_seq$$($container$jscomp$38_objects$jscomp$inline_6292$$,$JSCompiler_inline_result$jscomp$710_JSCompiler_temp$jscomp$706_id$jscomp$458$$));
$JSCompiler_inline_result$jscomp$710_JSCompiler_temp$jscomp$706_id$jscomp$458$$=$JSCompiler_temp_const$jscomp$708_or__5025__auto__$jscomp$648_or__5025__auto____$1$jscomp$81$$.call($APP.$cljs$core$into$$,$JSCompiler_temp_const$jscomp$707$$,$JSCompiler_inline_result$jscomp$710_JSCompiler_temp$jscomp$706_id$jscomp$458$$)}else $JSCompiler_inline_result$jscomp$710_JSCompiler_temp$jscomp$706_id$jscomp$458$$=$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$JSCompiler_inline_result$jscomp$710_JSCompiler_temp$jscomp$706_id$jscomp$458$$]);
return $APP.$cljs$core$seq$$($APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$JSCompiler_inline_result$jscomp$710_JSCompiler_temp$jscomp$706_id$jscomp$458$$))};
$app$common$logic$libraries$enabled_container_QMARK_$$=function($id$jscomp$459$$){var $or__5025__auto__$jscomp$649$$=$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$PersistentHashSet$EMPTY$$);return $or__5025__auto__$jscomp$649$$?$or__5025__auto__$jscomp$649$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$PersistentHashSet$EMPTY$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$459$$):(0,$APP.$cljs$core$PersistentHashSet$EMPTY$$)($id$jscomp$459$$)};
$app$common$logic$libraries$pretty_file$$=function($file_id$jscomp$79$$,$libraries$jscomp$34$$,$current_file_id$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$79$$,$current_file_id$$)?"\x3clocal\x3e":["\x3c",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$34$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file_id$jscomp$79$$,$APP.$cljs$cst$725$name$$],
null))),"\x3e"].join("")};$APP.$app$common$logic$libraries$pretty_uuid$$=function($uuid$jscomp$14_uuid_str$$){$uuid$jscomp$14_uuid_str$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($uuid$jscomp$14_uuid_str$$);return $APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($uuid$jscomp$14_uuid_str$$,$uuid$jscomp$14_uuid_str$$.length-6)};
$app$common$logic$libraries$duplicate_component$$=function($component$jscomp$59$$,$new_component_id$$,$new_component_file$$,$library_data$jscomp$22_main_instance_shape$jscomp$1_vec__66076_xf_shape$$,$force_id$jscomp$3_new_instance_shape$$,$delta$jscomp$19_new_instance_shapes_new_instance_shapes__$1$$,$variant_id$jscomp$16$$){var $main_instance_page$jscomp$6$$=$APP.$app$common$types$file$get_component_page$$($library_data$jscomp$22_main_instance_shape$jscomp$1_vec__66076_xf_shape$$,$component$jscomp$59$$);
$library_data$jscomp$22_main_instance_shape$jscomp$1_vec__66076_xf_shape$$=$APP.$app$common$types$file$get_component_root$$($library_data$jscomp$22_main_instance_shape$jscomp$1_vec__66076_xf_shape$$,$component$jscomp$59$$);var $delta__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($delta$jscomp$19_new_instance_shapes_new_instance_shapes__$1$$)?$delta$jscomp$19_new_instance_shapes_new_instance_shapes__$1$$:$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$22_main_instance_shape$jscomp$1_vec__66076_xf_shape$$)+
50,0),$ids_map$jscomp$9$$=$APP.$cljs$core$volatile_BANG_$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$inverted_ids_map$$=$APP.$cljs$core$volatile_BANG_$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$nested_main_heads$$=$APP.$cljs$core$volatile_BANG_$$($APP.$cljs$core$PersistentHashSet$EMPTY$$);$library_data$jscomp$22_main_instance_shape$jscomp$1_vec__66076_xf_shape$$=$APP.$app$common$types$shape_tree$clone_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($library_data$jscomp$22_main_instance_shape$jscomp$1_vec__66076_xf_shape$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$22_main_instance_shape$jscomp$1_vec__66076_xf_shape$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($main_instance_page$jscomp$6$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2089$update_new_shape$$,function($G__66084__$3_new_shape$jscomp$6$$){var $G__66084__$1_G__66084__$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($G__66084__$3_new_shape$jscomp$6$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$59$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66084__$3_new_shape$jscomp$6$$,$APP.$cljs$cst$1627$component_id$$,$new_component_id$$):$G__66084__$3_new_shape$jscomp$6$$;$G__66084__$1_G__66084__$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($G__66084__$3_new_shape$jscomp$6$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$59$$))&&
$new_component_file$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_component_file$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($G__66084__$3_new_shape$jscomp$6$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66084__$1_G__66084__$2$$,$APP.$cljs$cst$1643$component_file$$,$new_component_file$$):$G__66084__$1_G__66084__$2$$;$G__66084__$3_new_shape$jscomp$6$$=$APP.$app$common$types$component$instance_root_QMARK_$$($G__66084__$3_new_shape$jscomp$6$$)&&
$variant_id$jscomp$16$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66084__$1_G__66084__$2$$,$APP.$cljs$cst$2000$variant_id$$,$variant_id$jscomp$16$$):$G__66084__$1_G__66084__$2$$;return $app$common$geom$shapes$transforms$move$$($G__66084__$3_new_shape$jscomp$6$$,$delta__$1$jscomp$1$$)},$APP.$cljs$cst$2090$update_original_shape$$,function($original_shape$jscomp$1$$,$new_shape$jscomp$5$$){$ids_map$jscomp$9$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($ids_map$jscomp$9$$.$cljs$core$IDeref$_deref$arity$1$(null),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($original_shape$jscomp$1$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$5$$)));$inverted_ids_map$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($inverted_ids_map$$.$cljs$core$IDeref$_deref$arity$1$(null),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$5$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($original_shape$jscomp$1$$)));
$APP.$app$common$types$component$main_instance_QMARK_$$($original_shape$jscomp$1$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($original_shape$jscomp$1$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$59$$))&&$nested_main_heads$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($nested_main_heads$$.$cljs$core$IDeref$_deref$arity$1$(null),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($original_shape$jscomp$1$$)));return $original_shape$jscomp$1$$},$cljs$cst$2091$force_id$$,$force_id$jscomp$3_new_instance_shape$$]));$force_id$jscomp$3_new_instance_shape$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($library_data$jscomp$22_main_instance_shape$jscomp$1_vec__66076_xf_shape$$,0,null);$delta$jscomp$19_new_instance_shapes_new_instance_shapes__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($library_data$jscomp$22_main_instance_shape$jscomp$1_vec__66076_xf_shape$$,
1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($library_data$jscomp$22_main_instance_shape$jscomp$1_vec__66076_xf_shape$$,2,null);$library_data$jscomp$22_main_instance_shape$jscomp$1_vec__66076_xf_shape$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($shape$jscomp$405$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$405$$,$APP.$cljs$cst$1607$frame_id$$,function($p1__66069_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($ids_map$jscomp$9$$),
$p1__66069_SHARP_$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$405$$))})}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($G__66097__$1_shape$jscomp$406$$){var $origin_shape_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($inverted_ids_map$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__66097__$1_shape$jscomp$406$$)),$objects$jscomp$278_parent_ids$jscomp$1$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($main_instance_page$jscomp$6$$);
$objects$jscomp$278_parent_ids$jscomp$1$$=$APP.$cljs$core$cons$$($origin_shape_id$$,$app$common$files$helpers$get_parent_ids_seq$$($objects$jscomp$278_parent_ids$jscomp$1$$,$origin_shape_id$$));var $JSCompiler_inline_result$jscomp$1095_fexpr__66098$jscomp$inline_6295$$=$APP.$cljs$core$_deref$$($nested_main_heads$$);$JSCompiler_inline_result$jscomp$1095_fexpr__66098$jscomp$inline_6295$$=$JSCompiler_inline_result$jscomp$1095_fexpr__66098$jscomp$inline_6295$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$1095_fexpr__66098$jscomp$inline_6295$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape_id$$):
$JSCompiler_inline_result$jscomp$1095_fexpr__66098$jscomp$inline_6295$$($origin_shape_id$$);$G__66097__$1_shape$jscomp$406$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1095_fexpr__66098$jscomp$inline_6295$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__66097__$1_shape$jscomp$406$$,$APP.$cljs$cst$2045$main_instance$$):$G__66097__$1_shape$jscomp$406$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($APP.$cljs$core$_deref$$($nested_main_heads$$),$objects$jscomp$278_parent_ids$jscomp$1$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66097__$1_shape$jscomp$406$$,$APP.$cljs$cst$2047$shape_ref$$,$origin_shape_id$$):$G__66097__$1_shape$jscomp$406$$}));$delta$jscomp$19_new_instance_shapes_new_instance_shapes__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$library_data$jscomp$22_main_instance_shape$jscomp$1_vec__66076_xf_shape$$,$delta$jscomp$19_new_instance_shapes_new_instance_shapes__$1$$);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$force_id$jscomp$3_new_instance_shape$$,$delta$jscomp$19_new_instance_shapes_new_instance_shapes__$1$$],null)};
$APP.$app$common$logic$libraries$generate_duplicate_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($changes$jscomp$100$$,$library$jscomp$15_new_main_instance_shape$$,$component$jscomp$60_component_id$jscomp$36$$,$new_component_id$jscomp$1$$,$apply_changes_local_library_QMARK_$jscomp$2_p__66113$$){var $map__66114__$1_new_name$jscomp$13$$=$APP.$cljs$core$__destructure_map$$($apply_changes_local_library_QMARK_$jscomp$2_p__66113$$),$new_component_file$jscomp$1_new_main_instance_shapes_vec__66117$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66114__$1_new_name$jscomp$13$$,$cljs$cst$3527$new_component_file$$),$new_shape_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66114__$1_new_name$jscomp$13$$,$cljs$cst$3528$new_shape_id$$);$apply_changes_local_library_QMARK_$jscomp$2_p__66113$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66114__$1_new_name$jscomp$13$$,$APP.$cljs$cst$3179$apply_changes_local_library_QMARK_$$);var $delta$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66114__$1_new_name$jscomp$13$$,
$cljs$cst$2634$delta$$),$new_variant_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66114__$1_new_name$jscomp$13$$,$cljs$cst$3529$new_variant_id$$),$page_id$jscomp$97_target_page_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66114__$1_new_name$jscomp$13$$,$APP.$cljs$cst$2043$page_id$$);$component$jscomp$60_component_id$jscomp$36$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$15_new_main_instance_shape$$),
$component$jscomp$60_component_id$jscomp$36$$);$map__66114__$1_new_name$jscomp$13$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$60_component_id$jscomp$36$$);var $main_instance_page$jscomp$7$$=$APP.$app$common$types$file$get_component_page$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$15_new_main_instance_shape$$),$component$jscomp$60_component_id$jscomp$36$$);$page_id$jscomp$97_target_page_id$$=$APP.$cljs$core$truth_$$($page_id$jscomp$97_target_page_id$$)?
$page_id$jscomp$97_target_page_id$$:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($main_instance_page$jscomp$7$$);$new_component_file$jscomp$1_new_main_instance_shapes_vec__66117$$=$app$common$logic$libraries$duplicate_component$$($component$jscomp$60_component_id$jscomp$36$$,$new_component_id$jscomp$1$$,$new_component_file$jscomp$1_new_main_instance_shapes_vec__66117$$,$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$15_new_main_instance_shape$$),$new_shape_id$$,
$delta$jscomp$20$$,$new_variant_id$$);$library$jscomp$15_new_main_instance_shape$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_component_file$jscomp$1_new_main_instance_shapes_vec__66117$$,0,null);$new_component_file$jscomp$1_new_main_instance_shapes_vec__66117$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_component_file$jscomp$1_new_main_instance_shapes_vec__66117$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$library$jscomp$15_new_main_instance_shape$$,$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($app$common$files$changes_builder$add_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$files$changes_builder$add_objects$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$100$$,$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$,
$page_id$jscomp$97_target_page_id$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($main_instance_page$jscomp$7$$)),$new_component_file$jscomp$1_new_main_instance_shapes_vec__66117$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null)),$new_component_id$jscomp$1$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$60_component_id$jscomp$36$$),$map__66114__$1_new_name$jscomp$13$$,$APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$15_new_main_instance_shape$$),$page_id$jscomp$97_target_page_id$$,$APP.$cljs$cst$2542$annotation$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$60_component_id$jscomp$36$$),$APP.$cljs$core$truth_$$($new_variant_id$$)?$new_variant_id$$:$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$60_component_id$jscomp$36$$),$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$60_component_id$jscomp$36$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3179$apply_changes_local_library_QMARK_$$,$apply_changes_local_library_QMARK_$jscomp$2_p__66113$$],null)])),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$15_new_main_instance_shape$$)],null),function($shape$jscomp$407$$,$objects$jscomp$279$$){return $APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$407$$)?
$APP.$app$common$types$shape$layout$assign_cells$$($shape$jscomp$407$$,$objects$jscomp$279$$):$shape$jscomp$407$$},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null))],null)};
$app$common$logic$libraries$generate_instantiate_component$cljs$0core$0IFn$0_invoke$0arity$012$$=function($changes$jscomp$103$$,$objects$jscomp$282$$,$file_id$jscomp$82_library$jscomp$16$$,$component_id$jscomp$39$$,$position$jscomp$65$$,$new_shape$jscomp$7_page$jscomp$52$$,$libraries$jscomp$37$$,$old_id$jscomp$1$$,$changes__$2$jscomp$5_changes__$3$jscomp$3_parent_id$jscomp$40_vec__66152$$,$frame_id$jscomp$41$$,$ids_map$jscomp$10$$,$map__66151__$1_p__66150$$){$map__66151__$1_p__66150$$=$APP.$cljs$core$__destructure_map$$($map__66151__$1_p__66150$$);
var $force_frame_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__66151__$1_p__66150$$,$cljs$cst$3530$force_frame_QMARK_$$,!1),$component$jscomp$61$$=$APP.$app$common$types$file$get_component$$($libraries$jscomp$37$$,$file_id$jscomp$82_library$jscomp$16$$,$component_id$jscomp$39$$);$file_id$jscomp$82_library$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$37$$,$file_id$jscomp$82_library$jscomp$16$$);var $parent$jscomp$210$$=$APP.$cljs$core$truth_$$($changes__$2$jscomp$5_changes__$3$jscomp$3_parent_id$jscomp$40_vec__66152$$)?
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$282$$,$changes__$2$jscomp$5_changes__$3$jscomp$3_parent_id$jscomp$40_vec__66152$$):null,$parent__$1$jscomp$56$$=$APP.$cljs$core$truth_$$($parent$jscomp$210$$)?$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$370$$=$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$61$$);return $and__5023__auto__$jscomp$370$$?$APP.$app$common$types$component$is_variant_container_QMARK_$$($parent$jscomp$210$$):
$and__5023__auto__$jscomp$370$$}())?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$282$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$210$$)):$parent$jscomp$210$$:null,$parent_id__$1$jscomp$5$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$56$$),$changes__$2$jscomp$5_changes__$3$jscomp$3_parent_id$jscomp$40_vec__66152$$),$frame_id__$1$jscomp$6$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$56$$),
$frame_id$jscomp$41$$);$changes__$2$jscomp$5_changes__$3$jscomp$3_parent_id$jscomp$40_vec__66152$$=$APP.$app$common$types$container$make_component_instance$cljs$0core$0IFn$0_invoke$0arity$05$$($new_shape$jscomp$7_page$jscomp$52$$,$component$jscomp$61$$,$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$82_library$jscomp$16$$),$position$jscomp$65$$,function(){var $G__66155_G__66155__$1$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;$G__66155_G__66155__$1$$=$APP.$cljs$core$contains_QMARK_$$($ids_map$jscomp$10$$,
$old_id$jscomp$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66155_G__66155__$1$$,$cljs$cst$2091$force_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ids_map$jscomp$10$$,$old_id$jscomp$1$$)):$G__66155_G__66155__$1$$;return $APP.$cljs$core$truth_$$($force_frame_QMARK_$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66155_G__66155__$1$$,$APP.$cljs$cst$2549$force_frame_id$$,$frame_id__$1$jscomp$6$$):$G__66155_G__66155__$1$$}());$new_shape$jscomp$7_page$jscomp$52$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$2$jscomp$5_changes__$3$jscomp$3_parent_id$jscomp$40_vec__66152$$,0,null);var $new_shapes$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$2$jscomp$5_changes__$3$jscomp$3_parent_id$jscomp$40_vec__66152$$,1,null),$first_shape$jscomp$1$$=function(){var $G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$=$APP.$cljs$core$first$$($new_shapes$jscomp$5$$);$G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$=
$parent_id__$1$jscomp$5$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$,$APP.$cljs$cst$1619$parent_id$$,$parent_id__$1$jscomp$5$$):$G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$;$G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$=$parent__$1$jscomp$56$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$56$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$56$$)):$G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$;$G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$=$parent__$1$jscomp$56$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$56$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($parent__$1$jscomp$56$$)):$G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$;var $JSCompiler_inline_result$jscomp$1096_and__5023__auto__$jscomp$inline_6297$$=($JSCompiler_inline_result$jscomp$1096_and__5023__auto__$jscomp$inline_6297$$=$parent__$1$jscomp$56$$!=null)?$APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$282$$,
$parent__$1$jscomp$56$$):$JSCompiler_inline_result$jscomp$1096_and__5023__auto__$jscomp$inline_6297$$;$G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1096_and__5023__auto__$jscomp$inline_6297$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$,$APP.$cljs$cst$2044$component_root$$):$G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$;return $parent__$1$jscomp$56$$==
null&&$frame_id__$1$jscomp$6$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id__$1$jscomp$6$$):$G__66156_G__66156__$1_G__66156__$2_G__66156__$3_G__66156__$4$$}(),$changes__$1$jscomp$20$$=function(){var $G__66164$$=$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$103$$,$first_shape$jscomp$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null));return $old_id$jscomp$1$$!=null?$app$common$files$changes_builder$amend_last_change$$($G__66164$$,function($p1__66137_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__66137_SHARP_$$,$APP.$cljs$cst$3531$old_id$$,$old_id$jscomp$1$$)}):$G__66164$$}(),$duplicated_parent_QMARK_$$=$APP.$cljs$core$some$$(function($p1__66138_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__66138_SHARP_$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$1$$))},
$APP.$cljs$core$vals$$($ids_map$jscomp$10$$));$changes__$2$jscomp$5_changes__$3$jscomp$3_parent_id$jscomp$40_vec__66152$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$372$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$282$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$1$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$372$$)?$APP.$cljs$core$not$$($duplicated_parent_QMARK_$$):
$and__5023__auto__$jscomp$372$$}())?function(){var $target_cell$jscomp$3_vec__66171$$=$APP.$cljs$cst$3525$cell$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($position$jscomp$65$$));$target_cell$jscomp$3_vec__66171$$=$target_cell$jscomp$3_vec__66171$$!=null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$3_vec__66171$$),$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$3_vec__66171$$)],
null):null;var $row$jscomp$22$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($target_cell$jscomp$3_vec__66171$$,0,null),$column$jscomp$28$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($target_cell$jscomp$3_vec__66171$$,1,null);return $APP.$app$common$files$changes_builder$reorder_grid_children$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($changes__$1$jscomp$20$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$1$$)],null),function($G__66174_shape$jscomp$408$$,$objects__$1$jscomp$6$$){$G__66174_shape$jscomp$408$$=$APP.$app$common$types$shape$layout$assign_cells$$($G__66174_shape$jscomp$408$$,$objects__$1$jscomp$6$$);return $row$jscomp$22$$!=null&&$column$jscomp$28$$!=null?$APP.$app$common$types$shape$layout$assign_cells$$($app$common$types$shape$layout$push_into_cell$$($G__66174_shape$jscomp$408$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$1$$)],null),$row$jscomp$22$$,$column$jscomp$28$$),$objects__$1$jscomp$6$$):$G__66174_shape$jscomp$408$$},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$1$$)],
null))}():$changes__$1$jscomp$20$$;$changes__$2$jscomp$5_changes__$3$jscomp$3_parent_id$jscomp$40_vec__66152$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__66140_SHARP_$$,$p2__66141_SHARP_$$){return $app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__66140_SHARP_$$,$p2__66141_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null))},$changes__$2$jscomp$5_changes__$3$jscomp$3_parent_id$jscomp$40_vec__66152$$,
$APP.$cljs$core$rest$$($new_shapes$jscomp$5$$));return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_shape$jscomp$7_page$jscomp$52$$,$changes__$2$jscomp$5_changes__$3$jscomp$3_parent_id$jscomp$40_vec__66152$$],null)};
$app$common$logic$libraries$generate_detach_instance$$=function($changes$jscomp$104$$,$container$jscomp$39$$,$libraries$jscomp$38$$,$shape_id$jscomp$65$$){var $G__66188_shape$jscomp$409$$=$APP.$app$common$types$container$get_shape$$($container$jscomp$39$$,$shape_id$jscomp$65$$);$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($shape_id$jscomp$65$$,$container$jscomp$39$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Detach instance"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2543$shape_id$$,$shape_id$jscomp$65$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2588$container$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$39$$)],
null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$,!1);$G__66188_shape$jscomp$409$$=$APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($G__66188_shape$jscomp$409$$)===!0;return $app$common$logic$libraries$generate_detach_recursive$$.$cljs$core$IFn$_invoke$arity$6$?$app$common$logic$libraries$generate_detach_recursive$$.$cljs$core$IFn$_invoke$arity$6$($changes$jscomp$104$$,$container$jscomp$39$$,$libraries$jscomp$38$$,$shape_id$jscomp$65$$,!0,$G__66188_shape$jscomp$409$$):
$app$common$logic$libraries$generate_detach_recursive$$($changes$jscomp$104$$,$container$jscomp$39$$,$libraries$jscomp$38$$,$shape_id$jscomp$65$$,!0,$G__66188_shape$jscomp$409$$)};
$app$common$logic$libraries$generate_advance_nesting_level$$=function($changes$jscomp$106$$,$file$jscomp$47$$,$container$jscomp$41$$,$libraries$jscomp$40$$,$shape_id$jscomp$67$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"  -\x3e advance-nesting-level"],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);var $detached_ids$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$children$jscomp$205$$=$APP.$app$common$files$helpers$get_children_with_self$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$41$$),$shape_id$jscomp$67$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($G__66240__$1_G__66240__$2_G__66240__$3_changes__$1$jscomp$21$$,
$shape$jscomp$411$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$411$$),$container$jscomp$41$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"     * advancing"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$411$$)],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);if($APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($detached_ids$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$411$$)))return $APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",
$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"       (detached)"],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1),$G__66240__$1_G__66240__$2_G__66240__$3_changes__$1$jscomp$21$$;var $ref_shape$jscomp$2$$=
$app$common$types$file$find_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($file$jscomp$47$$,$container$jscomp$41$$,$libraries$jscomp$40$$,$shape$jscomp$411$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0],null)]));$G__66240__$1_G__66240__$2_G__66240__$3_changes__$1$jscomp$21$$=$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($ref_shape$jscomp$2$$)!=null?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66240__$1_G__66240__$2_G__66240__$3_changes__$1$jscomp$21$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$411$$)],null),function($p1__66222_SHARP_$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,["       (advanced to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($ref_shape$jscomp$2$$)),")"].join("")],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__66222_SHARP_$$,$APP.$cljs$cst$2047$shape_ref$$,$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($ref_shape$jscomp$2$$))}):
$G__66240__$1_G__66240__$2_G__66240__$3_changes__$1$jscomp$21$$;$G__66240__$1_G__66240__$2_G__66240__$3_changes__$1$jscomp$21$$=$ref_shape$jscomp$2$$!=null?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66240__$1_G__66240__$2_G__66240__$3_changes__$1$jscomp$21$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$411$$)],null),function($p1__66224_SHARP_$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",
$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"       (merge touched)"],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",
$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,["       (ref-shape: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($ref_shape$jscomp$2$$)),")"].join("")],null)],
null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,["       (ref touched: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($ref_shape$jscomp$2$$)),
")"].join("")],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__66224_SHARP_$$,$APP.$cljs$cst$1626$touched$$,$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$411$$),$app$common$types$component$normal_touched_groups$$($ref_shape$jscomp$2$$)))}):$G__66240__$1_G__66240__$2_G__66240__$3_changes__$1$jscomp$21$$;$G__66240__$1_G__66240__$2_G__66240__$3_changes__$1$jscomp$21$$=
$APP.$app$common$types$component$get_swap_slot$$($ref_shape$jscomp$2$$)!=null&&$APP.$app$common$types$component$get_swap_slot$$($shape$jscomp$411$$)==null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$411$$),$shape_id$jscomp$67$$)?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66240__$1_G__66240__$2_G__66240__$3_changes__$1$jscomp$21$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$411$$)],null),function($p1__66225_SHARP_$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1546$msg$$,["       (got swap-slot ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$component$get_swap_slot$$($ref_shape$jscomp$2$$)),")"].join("")],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);return $app$common$types$component$set_swap_slot$$($p1__66225_SHARP_$$,$APP.$app$common$types$component$get_swap_slot$$($ref_shape$jscomp$2$$))}):$G__66240__$1_G__66240__$2_G__66240__$3_changes__$1$jscomp$21$$;if($ref_shape$jscomp$2$$==
null){var $G__66259$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$411$$);return $app$common$logic$libraries$generate_detach_immediate$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$logic$libraries$generate_detach_immediate$$.$cljs$core$IFn$_invoke$arity$4$($G__66240__$1_G__66240__$2_G__66240__$3_changes__$1$jscomp$21$$,$container$jscomp$41$$,$G__66259$$,$detached_ids$$):$app$common$logic$libraries$generate_detach_immediate$$($G__66240__$1_G__66240__$2_G__66240__$3_changes__$1$jscomp$21$$,
$container$jscomp$41$$,$G__66259$$,$detached_ids$$)}return $G__66240__$1_G__66240__$2_G__66240__$3_changes__$1$jscomp$21$$},$changes$jscomp$106$$,$children$jscomp$205$$)};
$app$common$logic$libraries$generate_detach_immediate$$=function($changes$jscomp$107$$,$container$jscomp$42$$,$shape_id$jscomp$68$$,$detached_ids$jscomp$1$$){var $shape_and_children$$=$app$common$files$helpers$get_children_ids_with_self$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$42$$),$shape_id$jscomp$68$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"       (cannot advance; detach shape and children)"],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($detached_ids$jscomp$1$$,function($p1__66263_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($p1__66263_SHARP_$$,
$shape_and_children$$)});return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$107$$,$shape_and_children$$,$app$common$types$component$detach_shape$$)};
$APP.$app$common$logic$libraries$prepare_restore_component$cljs$0core$0IFn$0_invoke$0arity$08$$=function($changes$jscomp$109$$,$library_data$jscomp$24$$,$component_id$jscomp$41$$,$page$jscomp$54$$,$minusdelta_position$jscomp$66$$,$old_id$jscomp$2$$,$parent_id$jscomp$41$$,$frame_id$jscomp$42$$){var $changes__$2$jscomp$6_changes__$4$jscomp$1_library_data__$1$$=function(){var $or__5025__auto__$jscomp$654$$=$APP.$app$common$files$changes_builder$get_library_data$$($changes$jscomp$109$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$654$$)?
$or__5025__auto__$jscomp$654$$:$library_data$jscomp$24$$}(),$component$jscomp$63_orig_pos$jscomp$1$$=$APP.$app$common$types$components_list$get_deleted_component$$($changes__$2$jscomp$6_changes__$4$jscomp$1_library_data__$1$$,$component_id$jscomp$41$$),$objects$jscomp$283$$=function(){var $or__5025__auto__$jscomp$655$$=$APP.$app$common$files$changes_builder$get_objects$$($changes$jscomp$109$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$655$$)?$or__5025__auto__$jscomp$655$$:$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$54$$)}(),
$parent$jscomp$211$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$283$$,$parent_id$jscomp$41$$),$main_inst$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$63_orig_pos$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$objects$$,$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$63_orig_pos$jscomp$1$$)],null)),$inside_component_QMARK_$jscomp$1$$=
$APP.$app$common$types$container$get_instance_root$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$54$$),$parent$jscomp$211$$)!=null,$shapes$jscomp$39$$=$APP.$app$common$files$helpers$get_children_with_self$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$63_orig_pos$jscomp$1$$),$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$63_orig_pos$jscomp$1$$)),$is_variant_QMARK_$$=$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$63_orig_pos$jscomp$1$$);
$component$jscomp$63_orig_pos$jscomp$1$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($main_inst$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($main_inst$$));var $delta$jscomp$21$$=$APP.$cljs$core$truth_$$($minusdelta_position$jscomp$66$$)?$APP.$app$common$geom$point$subtract$$($minusdelta_position$jscomp$66$$,$component$jscomp$63_orig_pos$jscomp$1$$):$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,
0);$minusdelta_position$jscomp$66$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$21$$),-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$21$$));var $moved_shapes$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66265_SHARP_$$){return $app$common$geom$shapes$transforms$move$$($p1__66265_SHARP_$$,$delta$jscomp$21$$)},$shapes$jscomp$39$$),$first_shape$jscomp$2$$=function(){var $G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$=
$APP.$cljs$core$first$$($moved_shapes$$);$G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$=$parent_id$jscomp$41$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$,$APP.$cljs$cst$1619$parent_id$$,$parent_id$jscomp$41$$):$G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$;$G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$=$frame_id$jscomp$42$$!=
null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$42$$):$G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$;$G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$373$$=$frame_id$jscomp$42$$==null;return $and__5023__auto__$jscomp$373$$?$APP.$cljs$core$truth_$$($parent$jscomp$211$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$211$$)):$parent$jscomp$211$$:$and__5023__auto__$jscomp$373$$}())?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$,$APP.$cljs$cst$1607$frame_id$$,$parent_id$jscomp$41$$):$G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$;$G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$=
$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$374$$=$frame_id$jscomp$42$$==null;return $and__5023__auto__$jscomp$374$$?$APP.$cljs$core$truth_$$($parent$jscomp$211$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$211$$)):$parent$jscomp$211$$:$and__5023__auto__$jscomp$374$$}())?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$,
$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$211$$)):$G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$;$G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$=$inside_component_QMARK_$jscomp$1$$?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$,$APP.$cljs$cst$2044$component_root$$):$G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$;
return $inside_component_QMARK_$jscomp$1$$?$G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66277_G__66277__$1_G__66277__$2_G__66277__$3_G__66277__$4_G__66277__$5$$,$APP.$cljs$cst$2044$component_root$$,!0)}(),$restoring_into_parent$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$283$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$2$$)),$changes__$1$jscomp$22$$=
$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($changes$jscomp$109$$,$page$jscomp$54$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$54$$)),$changes__$2$jscomp$6_changes__$4$jscomp$1_library_data__$1$$);$changes__$2$jscomp$6_changes__$4$jscomp$1_library_data__$1$$=function(){var $G__66284$$=$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$1$jscomp$22$$,
$first_shape$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null));return $old_id$jscomp$2$$!=null?$app$common$files$changes_builder$amend_last_change$$($G__66284$$,function($p1__66266_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__66266_SHARP_$$,$APP.$cljs$cst$3531$old_id$$,$old_id$jscomp$2$$)}):$G__66284$$}();var $changes__$3$jscomp$4$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__66267_SHARP_$$,
$p2__66268_SHARP_$$){return $app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__66267_SHARP_$$,$p2__66268_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null))},$changes__$2$jscomp$6_changes__$4$jscomp$1_library_data__$1$$,$APP.$cljs$core$rest$$($moved_shapes$$));$changes__$2$jscomp$6_changes__$4$jscomp$1_library_data__$1$$=function(){if($is_variant_QMARK_$$){var $G__66288__$1_JSCompiler_inline_result$jscomp$10839_or__5025__auto__$jscomp$inline_12338$$=
$APP.$cljs$core$truth_$$($parent$jscomp$211$$)?$APP.$cljs$core$not$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($parent$jscomp$211$$)):$parent$jscomp$211$$;$G__66288__$1_JSCompiler_inline_result$jscomp$10839_or__5025__auto__$jscomp$inline_12338$$=$APP.$cljs$core$truth_$$($G__66288__$1_JSCompiler_inline_result$jscomp$10839_or__5025__auto__$jscomp$inline_12338$$)?$G__66288__$1_JSCompiler_inline_result$jscomp$10839_or__5025__auto__$jscomp$inline_12338$$:$restoring_into_parent$$==
null}else $G__66288__$1_JSCompiler_inline_result$jscomp$10839_or__5025__auto__$jscomp$inline_12338$$=$is_variant_QMARK_$$;$G__66288__$1_JSCompiler_inline_result$jscomp$10839_or__5025__auto__$jscomp$inline_12338$$=$APP.$cljs$core$truth_$$($G__66288__$1_JSCompiler_inline_result$jscomp$10839_or__5025__auto__$jscomp$inline_12338$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$logic$variant_properties$generate_make_shape_no_variant$$,$changes__$3$jscomp$4$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$first_shape$jscomp$2$$],null)):$changes__$3$jscomp$4$$;return $APP.$cljs$core$truth_$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($restoring_into_parent$$))?$app$common$logic$variant_properties$generate_make_shapes_variant$$($G__66288__$1_JSCompiler_inline_result$jscomp$10839_or__5025__auto__$jscomp$inline_12338$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$first_shape$jscomp$2$$],
null),$restoring_into_parent$$):$G__66288__$1_JSCompiler_inline_result$jscomp$10839_or__5025__auto__$jscomp$inline_12338$$}();return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3131$changes$$,$app$common$files$changes_builder$restore_component$$($changes__$2$jscomp$6_changes__$4$jscomp$1_library_data__$1$$,$component_id$jscomp$41$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$54$$),$minusdelta_position$jscomp$66$$),$APP.$cljs$cst$1811$shape$$,$APP.$cljs$core$first$$($moved_shapes$$)],
null)};
$app$common$logic$libraries$generate_sync_file$$=function($G__67203_changes$jscomp$110_changes__$1$jscomp$23$$,$file_id$jscomp$83$$,$asset_type$jscomp$3$$,$asset_id$jscomp$5$$,$library_id$jscomp$21$$,$libraries$jscomp$41$$,$current_file_id$jscomp$1$$){$APP.$cljs$core$truth_$$($app$common$logic$libraries$enabled_container_QMARK_$$($asset_id$jscomp$5$$))&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,5,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Sync file with library"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2545$asset_type$$,$asset_type$jscomp$3$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2544$asset_id$$,$asset_id$jscomp$5$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$208$file$$,$app$common$logic$libraries$pretty_file$$($file_id$jscomp$83$$,$libraries$jscomp$41$$,$current_file_id$jscomp$1$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3532$library$$,$app$common$logic$libraries$pretty_file$$($library_id$jscomp$21$$,$libraries$jscomp$41$$,$current_file_id$jscomp$1$$)],null)],null)}),
null,"app.common.logic.libraries",$APP.$cljs$cst$1161$info$$,!1);var $G__67202_containers_file$jscomp$48$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$41$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file_id$jscomp$83$$,$APP.$cljs$cst$142$data$$],null));for($G__67202_containers_file$jscomp$48$$=$APP.$app$common$types$file$object_containers_seq$$($G__67202_containers_file$jscomp$48$$);;){var $temp__5823__auto__$jscomp$163$$=
$APP.$cljs$core$first$$($G__67202_containers_file$jscomp$48$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$163$$)){var $container$jscomp$43$$=$temp__5823__auto__$jscomp$163$$;$G__67202_containers_file$jscomp$48$$=$APP.$cljs$core$next$$($G__67202_containers_file$jscomp$48$$);$G__67203_changes$jscomp$110_changes__$1$jscomp$23$$=$APP.$app$common$files$changes_builder$concat_changes$$($G__67203_changes$jscomp$110_changes__$1$jscomp$23$$,function(){var $G__66311$$=$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$G__66315$$=$container$jscomp$43$$;return $app$common$logic$libraries$generate_sync_container$$.$cljs$core$IFn$_invoke$arity$7$?$app$common$logic$libraries$generate_sync_container$$.$cljs$core$IFn$_invoke$arity$7$($G__66311$$,$asset_type$jscomp$3$$,$asset_id$jscomp$5$$,$library_id$jscomp$21$$,$G__66315$$,$libraries$jscomp$41$$,$current_file_id$jscomp$1$$):$app$common$logic$libraries$generate_sync_container$$($G__66311$$,$asset_type$jscomp$3$$,$asset_id$jscomp$5$$,$library_id$jscomp$21$$,$G__66315$$,
$libraries$jscomp$41$$,$current_file_id$jscomp$1$$)}())}else return $G__67203_changes$jscomp$110_changes__$1$jscomp$23$$}};
$app$common$logic$libraries$generate_sync_library$$=function($G__67212_changes$jscomp$111_changes__$1$jscomp$24$$,$file_id$jscomp$84$$,$asset_type$jscomp$4$$,$asset_id$jscomp$6$$,$library_id$jscomp$22$$,$libraries$jscomp$42$$,$current_file_id$jscomp$2$$){$APP.$cljs$core$truth_$$($app$common$logic$libraries$enabled_container_QMARK_$$($asset_id$jscomp$6$$))&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Sync local components with library"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2545$asset_type$$,$asset_type$jscomp$4$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2544$asset_id$$,$asset_id$jscomp$6$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$208$file$$,$app$common$logic$libraries$pretty_file$$($file_id$jscomp$84$$,$libraries$jscomp$42$$,$current_file_id$jscomp$2$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3532$library$$,$app$common$logic$libraries$pretty_file$$($library_id$jscomp$22$$,$libraries$jscomp$42$$,$current_file_id$jscomp$2$$)],null)],null)}),
null,"app.common.logic.libraries",$APP.$cljs$cst$1161$info$$,!1);var $G__67211_file$jscomp$49_local_components$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$42$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file_id$jscomp$84$$,$APP.$cljs$cst$142$data$$],null));for($G__67211_file$jscomp$49_local_components$$=$APP.$app$common$types$components_list$components_seq$$($G__67211_file$jscomp$49_local_components$$);;){var $temp__5823__auto__$jscomp$164$$=
$APP.$cljs$core$first$$($G__67211_file$jscomp$49_local_components$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$164$$)){var $local_component$$=$temp__5823__auto__$jscomp$164$$;$G__67211_file$jscomp$49_local_components$$=$APP.$cljs$core$next$$($G__67211_file$jscomp$49_local_components$$);$G__67212_changes$jscomp$111_changes__$1$jscomp$24$$=$APP.$app$common$files$changes_builder$concat_changes$$($G__67212_changes$jscomp$111_changes__$1$jscomp$24$$,function(){var $G__66332$$=$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$G__66336$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($local_component$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1625$component$$);return $app$common$logic$libraries$generate_sync_container$$.$cljs$core$IFn$_invoke$arity$7$?$app$common$logic$libraries$generate_sync_container$$.$cljs$core$IFn$_invoke$arity$7$($G__66332$$,$asset_type$jscomp$4$$,$asset_id$jscomp$6$$,$library_id$jscomp$22$$,$G__66336$$,$libraries$jscomp$42$$,$current_file_id$jscomp$2$$):$app$common$logic$libraries$generate_sync_container$$($G__66332$$,
$asset_type$jscomp$4$$,$asset_id$jscomp$6$$,$library_id$jscomp$22$$,$G__66336$$,$libraries$jscomp$42$$,$current_file_id$jscomp$2$$)}())}else return $G__67212_changes$jscomp$111_changes__$1$jscomp$24$$}};
$app$common$logic$libraries$generate_sync_container$$=function($G__67222_changes$jscomp$112_temp__5823__auto__$jscomp$165$$,$asset_type$jscomp$5$$,$asset_id$jscomp$7$$,$library_id$jscomp$23$$,$container$jscomp$44$$,$libraries$jscomp$43$$,$current_file_id$jscomp$3$$){$app$common$files$helpers$page_QMARK_$$($container$jscomp$44$$)?$APP.$cljs$core$truth_$$($app$common$logic$libraries$enabled_container_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$44$$)))&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Sync page in local file"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$44$$)],
null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$,!1):$APP.$cljs$core$truth_$$($app$common$logic$libraries$enabled_container_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$44$$)))&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Sync component in local library"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$44$$)],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$,!1);var $G__67221_linked_shapes_shapes$jscomp$40$$=
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66339_SHARP_$$){return $app$common$logic$libraries$uses_assets_QMARK_$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$logic$libraries$uses_assets_QMARK_$$.$cljs$core$IFn$_invoke$arity$4$($asset_type$jscomp$5$$,$asset_id$jscomp$7$$,$p1__66339_SHARP_$$,$library_id$jscomp$23$$):$app$common$logic$libraries$uses_assets_QMARK_$$($asset_type$jscomp$5$$,$asset_id$jscomp$7$$,$p1__66339_SHARP_$$,$library_id$jscomp$23$$)},$APP.$cljs$core$vals$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$44$$)));
$G__67221_linked_shapes_shapes$jscomp$40$$=$APP.$cljs$core$seq$$($G__67221_linked_shapes_shapes$jscomp$40$$);for(var $changes__$1$jscomp$25$$=$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_container$$($G__67222_changes$jscomp$112_temp__5823__auto__$jscomp$165$$,$container$jscomp$44$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$44$$));;)if($G__67222_changes$jscomp$112_temp__5823__auto__$jscomp$165$$=$APP.$cljs$core$first$$($G__67221_linked_shapes_shapes$jscomp$40$$),
$APP.$cljs$core$truth_$$($G__67222_changes$jscomp$112_temp__5823__auto__$jscomp$165$$)){var $shape$jscomp$412$$=$G__67222_changes$jscomp$112_temp__5823__auto__$jscomp$165$$;$G__67221_linked_shapes_shapes$jscomp$40$$=$APP.$cljs$core$next$$($G__67221_linked_shapes_shapes$jscomp$40$$);$changes__$1$jscomp$25$$=$G__67222_changes$jscomp$112_temp__5823__auto__$jscomp$165$$=function(){var $objects_SINGLEQUOTE__shape_SINGLEQUOTE_$jscomp$3$$=$APP.$app$common$files$changes_builder$get_objects$$($changes__$1$jscomp$25$$);
$objects_SINGLEQUOTE__shape_SINGLEQUOTE_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects_SINGLEQUOTE__shape_SINGLEQUOTE_$jscomp$3$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$412$$));return $APP.$cljs$core$truth_$$($objects_SINGLEQUOTE__shape_SINGLEQUOTE_$jscomp$3$$)?$app$common$logic$libraries$generate_sync_shape$$.$cljs$core$IFn$_invoke$arity$7$?$app$common$logic$libraries$generate_sync_shape$$.$cljs$core$IFn$_invoke$arity$7$($asset_type$jscomp$5$$,
$changes__$1$jscomp$25$$,$library_id$jscomp$23$$,$container$jscomp$44$$,$objects_SINGLEQUOTE__shape_SINGLEQUOTE_$jscomp$3$$,$libraries$jscomp$43$$,$current_file_id$jscomp$3$$):$app$common$logic$libraries$generate_sync_shape$$($asset_type$jscomp$5$$,$changes__$1$jscomp$25$$,$library_id$jscomp$23$$,$container$jscomp$44$$,$objects_SINGLEQUOTE__shape_SINGLEQUOTE_$jscomp$3$$,$libraries$jscomp$43$$,$current_file_id$jscomp$3$$):$changes__$1$jscomp$25$$}()}else return $changes__$1$jscomp$25$$};
$app$common$logic$libraries$generate_sync_text_shape$$=function($changes$jscomp$116$$,$shape$jscomp$419$$,$container$jscomp$47$$,$changes_SINGLEQUOTE__redo_change$jscomp$4_update_node$jscomp$1$$){var $old_content$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$419$$),$new_content$jscomp$3$$=$APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$02$$($changes_SINGLEQUOTE__redo_change$jscomp$4_update_node$jscomp$1$$,$old_content$$);$changes_SINGLEQUOTE__redo_change$jscomp$4_update_node$jscomp$1$$=
function(){var $G__66355$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$419$$),$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1637$content$$,
$APP.$cljs$cst$108$val$$,$new_content$jscomp$3$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1891$position_data$$,$APP.$cljs$cst$108$val$$,null],null)],null)],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$47$$,$G__66355$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$47$$,
$G__66355$$)}();var $undo_change$jscomp$4$$=function(){var $G__66357$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$419$$),$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,
$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$108$val$$,$old_content$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1891$position_data$$,$APP.$cljs$cst$108$val$$,null],null)],null)],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$47$$,
$G__66357$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$47$$,$G__66357$$)}();$changes_SINGLEQUOTE__redo_change$jscomp$4_update_node$jscomp$1$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$116$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,$changes_SINGLEQUOTE__redo_change$jscomp$4_update_node$jscomp$1$$),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,$undo_change$jscomp$4$$);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_content$jscomp$3$$,$old_content$$)?$changes$jscomp$116$$:$APP.$app$common$files$changes_builder$apply_changes_local$$($changes_SINGLEQUOTE__redo_change$jscomp$4_update_node$jscomp$1$$)};
$APP.$app$common$logic$libraries$generate_sync_shape_direct$$=function($changes$jscomp$117$$,$file$jscomp$51$$,$libraries$jscomp$47$$,$container$jscomp$48$$,$shape_id$jscomp$70$$,$reset_QMARK_$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($shape_id$jscomp$70$$,$container$jscomp$48$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Sync shape direct"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3533$shape_inst$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$70$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3534$reset_QMARK_$$,
$reset_QMARK_$$],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$,!1);var $shape_inst$jscomp$3$$=$APP.$app$common$types$container$get_shape$$($container$jscomp$48$$,$shape_id$jscomp$70$$),$library$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$47$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$3$$)),$APP.$cljs$cst$142$data$$),$component$jscomp$64$$=
$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($library$jscomp$17$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$3$$),!0);if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$376_or__5025__auto__$jscomp$657_ref_component$jscomp$inline_6304$$=$APP.$app$common$types$component$in_component_copy_QMARK_$$($shape_inst$jscomp$3$$);return $and__5023__auto__$jscomp$376_or__5025__auto__$jscomp$657_ref_component$jscomp$inline_6304$$?
($and__5023__auto__$jscomp$376_or__5025__auto__$jscomp$657_ref_component$jscomp$inline_6304$$=$app$common$types$file$find_ref_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($container$jscomp$48$$,$libraries$jscomp$47$$,$shape_inst$jscomp$3$$),($and__5023__auto__$jscomp$376_or__5025__auto__$jscomp$657_ref_component$jscomp$inline_6304$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$64$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$376_or__5025__auto__$jscomp$657_ref_component$jscomp$inline_6304$$))===
!0)?$and__5023__auto__$jscomp$376_or__5025__auto__$jscomp$657_ref_component$jscomp$inline_6304$$:$reset_QMARK_$$):$and__5023__auto__$jscomp$376_or__5025__auto__$jscomp$657_ref_component$jscomp$inline_6304$$}())){var $shape_main$jscomp$3$$=$APP.$cljs$core$truth_$$($component$jscomp$64$$)?$APP.$cljs$core$truth_$$($reset_QMARK_$$)?$app$common$types$file$find_ref_shape$$($file$jscomp$51$$,$container$jscomp$48$$,$libraries$jscomp$47$$,$shape_inst$jscomp$3$$):$APP.$app$common$types$file$get_ref_shape$$($library$jscomp$17$$,
$component$jscomp$64$$,$shape_inst$jscomp$3$$):null,$initial_root_QMARK_$$=$APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$3$$);return $APP.$cljs$core$truth_$$($component$jscomp$64$$)?$app$common$logic$libraries$generate_sync_shape_direct_recursive$$.$cljs$core$IFn$_invoke$arity$12$?$app$common$logic$libraries$generate_sync_shape_direct_recursive$$.$cljs$core$IFn$_invoke$arity$12$($changes$jscomp$117$$,$container$jscomp$48$$,$shape_inst$jscomp$3$$,$component$jscomp$64$$,
$library$jscomp$17$$,$file$jscomp$51$$,$libraries$jscomp$47$$,$shape_main$jscomp$3$$,$shape_inst$jscomp$3$$,$shape_main$jscomp$3$$,$reset_QMARK_$$,$initial_root_QMARK_$$):$app$common$logic$libraries$generate_sync_shape_direct_recursive$$($changes$jscomp$117$$,$container$jscomp$48$$,$shape_inst$jscomp$3$$,$component$jscomp$64$$,$library$jscomp$17$$,$file$jscomp$51$$,$libraries$jscomp$47$$,$shape_main$jscomp$3$$,$shape_inst$jscomp$3$$,$shape_main$jscomp$3$$,$reset_QMARK_$$,$initial_root_QMARK_$$):$changes$jscomp$117$$}return $changes$jscomp$117$$};
$app$common$logic$libraries$find_main_container$$=function($container_inst$jscomp$1$$,$component_SINGLEQUOTE___$1_parent$jscomp$212_shape_inst$jscomp$4_shape_inst_SINGLEQUOTE_$$,$shape_main$jscomp$4$$,$library$jscomp$18_library_SINGLEQUOTE_$$,$file$jscomp$52$$,$libraries$jscomp$48$$,$G__67269_component$jscomp$65_component_SINGLEQUOTE__container$jscomp$49$$){for(;;){$G__67269_component$jscomp$65_component_SINGLEQUOTE__container$jscomp$49$$=$APP.$app$common$types$file$get_component_container$$($library$jscomp$18_library_SINGLEQUOTE_$$,
$G__67269_component$jscomp$65_component_SINGLEQUOTE__container$jscomp$49$$);if($APP.$app$common$types$container$get_shape$$($G__67269_component$jscomp$65_component_SINGLEQUOTE__container$jscomp$49$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_main$jscomp$4$$))!=null)return $G__67269_component$jscomp$65_component_SINGLEQUOTE__container$jscomp$49$$;$component_SINGLEQUOTE___$1_parent$jscomp$212_shape_inst$jscomp$4_shape_inst_SINGLEQUOTE_$$=$APP.$app$common$types$container$get_shape$$($container_inst$jscomp$1$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($component_SINGLEQUOTE___$1_parent$jscomp$212_shape_inst$jscomp$4_shape_inst_SINGLEQUOTE_$$));var $shape_inst_SINGLEQUOTE___$1$$=$APP.$app$common$types$container$get_head_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container_inst$jscomp$1$$),$component_SINGLEQUOTE___$1_parent$jscomp$212_shape_inst$jscomp$4_shape_inst_SINGLEQUOTE_$$),$next_file$$=function(){var $G__66370_G__66370__$1$$=
$shape_inst_SINGLEQUOTE___$1$$;$G__66370_G__66370__$1$$=$G__66370_G__66370__$1$$==null?null:$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($G__66370_G__66370__$1$$);return $G__66370_G__66370__$1$$==null?null:$app$common$types$file$find_component_file$$($file$jscomp$52$$,$libraries$jscomp$48$$,$G__66370_G__66370__$1$$)}(),$next_data$$=function(){var $G__66371$$=$next_file$$;return $G__66371$$==null?null:$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($G__66371$$)}();
$component_SINGLEQUOTE___$1_parent$jscomp$212_shape_inst$jscomp$4_shape_inst_SINGLEQUOTE_$$=$APP.$cljs$core$truth_$$($next_data$$)?function(){var $or__5025__auto__$jscomp$658$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($next_data$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst_SINGLEQUOTE___$1$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$658$$)?$or__5025__auto__$jscomp$658$$:$APP.$app$common$types$components_list$get_deleted_component$$($next_data$$,
$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst_SINGLEQUOTE___$1$$))}():null;if($component_SINGLEQUOTE___$1_parent$jscomp$212_shape_inst$jscomp$4_shape_inst_SINGLEQUOTE_$$!=null){$G__67269_component$jscomp$65_component_SINGLEQUOTE__container$jscomp$49$$=$next_data$$;var $G__67270$$=$component_SINGLEQUOTE___$1_parent$jscomp$212_shape_inst$jscomp$4_shape_inst_SINGLEQUOTE_$$;$component_SINGLEQUOTE___$1_parent$jscomp$212_shape_inst$jscomp$4_shape_inst_SINGLEQUOTE_$$=$shape_inst_SINGLEQUOTE___$1$$;
$library$jscomp$18_library_SINGLEQUOTE_$$=$G__67269_component$jscomp$65_component_SINGLEQUOTE__container$jscomp$49$$;$G__67269_component$jscomp$65_component_SINGLEQUOTE__container$jscomp$49$$=$G__67270$$}else return null}};
$APP.$app$common$logic$libraries$generate_rename_component$$=function($changes$jscomp$119$$,$id$jscomp$460$$,$new_name$jscomp$14_vec__66500$$,$library_data$jscomp$25$$){$new_name$jscomp$14_vec__66500$$=$app$common$path_names$split_group_name$$($new_name$jscomp$14_vec__66500$$);var $path$jscomp$233$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_name$jscomp$14_vec__66500$$,0,null),$name$jscomp$287$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_name$jscomp$14_vec__66500$$,
1,null);return $APP.$app$common$files$changes_builder$update_component$$($APP.$app$common$files$changes_builder$with_library_data$$($changes$jscomp$119$$,$library_data$jscomp$25$$),$id$jscomp$460$$,function($p1__66492_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__66492_SHARP_$$,$APP.$cljs$cst$296$path$$,$path$jscomp$233$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,$name$jscomp$287$$]))})};
$APP.$app$common$logic$libraries$compare_children$$=function($G__67324_G__67327_G__67330_G__67331_G__67336_changes$jscomp$122$$,$shape_inst$jscomp$8$$,$G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$,$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$,$container_inst$jscomp$2$$,$container_main$jscomp$1$$,$file$jscomp$56$$,$libraries$jscomp$52$$,$only_inst_cb$$,$only_main_cb$$,$both_cb$$,$swapped_cb$$,$moved_cb$$,$inverse_QMARK_$$,
$reset_QMARK_$jscomp$2$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$8$$),$container_inst$jscomp$2$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Compare children"],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);$G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$=$APP.$cljs$core$seq$$($APP.$cljs$core$truth_$$($G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$)?$G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$:$APP.$cljs$core$PersistentVector$EMPTY$$);
$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$=$APP.$cljs$core$seq$$($APP.$cljs$core$truth_$$($G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$)?$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$:$APP.$cljs$core$PersistentVector$EMPTY$$);for(var $changes__$1$jscomp$29$$=$G__67324_G__67327_G__67330_G__67331_G__67336_changes$jscomp$122$$;;){var $child_inst$jscomp$8$$=$APP.$cljs$core$first$$($G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$),
$child_main$jscomp$8$$=$APP.$cljs$core$first$$($G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$);$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$8$$),$container_inst$jscomp$2$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function($children_inst__$1$jscomp$1$$,
$children_main__$1$jscomp$1$$,$changes__$1$jscomp$30$$,$child_inst$jscomp$9$$,$child_main$jscomp$9$$){return function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Comparing"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1280$main$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($child_main$jscomp$9$$)),
" ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_main$jscomp$9$$))].join("")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3541$inst$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$9$$))," ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$9$$))].join("")],
null)],null)}}($G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$,$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$,$changes__$1$jscomp$29$$,$child_inst$jscomp$8$$,$child_main$jscomp$8$$)),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);if($child_inst$jscomp$8$$==null&&$child_main$jscomp$8$$==null)return $changes__$1$jscomp$29$$;if($child_inst$jscomp$8$$==null)return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($only_main_cb$$,
$changes__$1$jscomp$29$$,$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$);if($child_main$jscomp$8$$==null)return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($only_inst_cb$$,$changes__$1$jscomp$29$$,$G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$);if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$380_or__5025__auto__$jscomp$661$$=$APP.$app$common$types$component$is_main_of_QMARK_$$($child_main$jscomp$8$$,
$child_inst$jscomp$8$$);if($and__5023__auto__$jscomp$380_or__5025__auto__$jscomp$661$$)return $and__5023__auto__$jscomp$380_or__5025__auto__$jscomp$661$$;$and__5023__auto__$jscomp$380_or__5025__auto__$jscomp$661$$=$app$common$types$file$match_swap_slot_QMARK_$$($child_main$jscomp$8$$,$child_inst$jscomp$8$$,$container_inst$jscomp$2$$,$container_main$jscomp$1$$,$file$jscomp$56$$,$libraries$jscomp$52$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$380_or__5025__auto__$jscomp$661$$)?$APP.$cljs$core$not$$($reset_QMARK_$jscomp$2$$):
$and__5023__auto__$jscomp$380_or__5025__auto__$jscomp$661$$}()))$G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$=$APP.$cljs$core$next$$($G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$),$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$=$APP.$cljs$core$next$$($G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$),$changes__$1$jscomp$29$$=$G__67324_G__67327_G__67330_G__67331_G__67336_changes$jscomp$122$$=
$APP.$app$common$types$component$is_main_of_QMARK_$$($child_main$jscomp$8$$,$child_inst$jscomp$8$$)?$both_cb$$.$cljs$core$IFn$_invoke$arity$3$?$both_cb$$.$cljs$core$IFn$_invoke$arity$3$($changes__$1$jscomp$29$$,$child_inst$jscomp$8$$,$child_main$jscomp$8$$):$both_cb$$($changes__$1$jscomp$29$$,$child_inst$jscomp$8$$,$child_main$jscomp$8$$):$swapped_cb$$.$cljs$core$IFn$_invoke$arity$3$?$swapped_cb$$.$cljs$core$IFn$_invoke$arity$3$($changes__$1$jscomp$29$$,$child_inst$jscomp$8$$,$child_main$jscomp$8$$):
$swapped_cb$$($changes__$1$jscomp$29$$,$child_inst$jscomp$8$$,$child_main$jscomp$8$$);else{var $child_inst_SINGLEQUOTE_$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($children_inst__$1$jscomp$2$$,$children_main__$1$jscomp$2$$,$changes__$1$jscomp$31$$,$child_inst$jscomp$10$$,$child_main$jscomp$10$$){return function($and__5023__auto__$jscomp$381_p1__66600_SHARP_$$){var $or__5025__auto__$jscomp$662$$=$APP.$app$common$types$component$is_main_of_QMARK_$$($child_main$jscomp$10$$,
$and__5023__auto__$jscomp$381_p1__66600_SHARP_$$);if($or__5025__auto__$jscomp$662$$)return $or__5025__auto__$jscomp$662$$;$and__5023__auto__$jscomp$381_p1__66600_SHARP_$$=$app$common$types$file$match_swap_slot_QMARK_$$($child_main$jscomp$10$$,$and__5023__auto__$jscomp$381_p1__66600_SHARP_$$,$container_inst$jscomp$2$$,$container_main$jscomp$1$$,$file$jscomp$56$$,$libraries$jscomp$52$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$381_p1__66600_SHARP_$$)?$APP.$cljs$core$not$$($reset_QMARK_$jscomp$2$$):
$and__5023__auto__$jscomp$381_p1__66600_SHARP_$$}}($G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$,$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$,$changes__$1$jscomp$29$$,$child_inst$jscomp$8$$,$child_main$jscomp$8$$),$G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$),$child_main_SINGLEQUOTE_$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($children_inst__$1$jscomp$3$$,
$children_main__$1$jscomp$3$$,$changes__$1$jscomp$32$$,$child_inst_SINGLEQUOTE_$jscomp$1$$,$child_inst$jscomp$11$$){return function($and__5023__auto__$jscomp$382_p1__66601_SHARP_$$){var $or__5025__auto__$jscomp$663$$=$APP.$app$common$types$component$is_main_of_QMARK_$$($and__5023__auto__$jscomp$382_p1__66601_SHARP_$$,$child_inst$jscomp$11$$);if($or__5025__auto__$jscomp$663$$)return $or__5025__auto__$jscomp$663$$;$and__5023__auto__$jscomp$382_p1__66601_SHARP_$$=$app$common$types$file$match_swap_slot_QMARK_$$($and__5023__auto__$jscomp$382_p1__66601_SHARP_$$,
$child_inst$jscomp$11$$,$container_inst$jscomp$2$$,$container_main$jscomp$1$$,$file$jscomp$56$$,$libraries$jscomp$52$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$382_p1__66601_SHARP_$$)?$APP.$cljs$core$not$$($reset_QMARK_$jscomp$2$$):$and__5023__auto__$jscomp$382_p1__66601_SHARP_$$}}($G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$,$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$,$changes__$1$jscomp$29$$,$child_inst_SINGLEQUOTE_$$,
$child_inst$jscomp$8$$,$child_main$jscomp$8$$),$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$);if($child_inst_SINGLEQUOTE_$$==null)$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$=$APP.$cljs$core$next$$($G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$),$changes__$1$jscomp$29$$=$G__67324_G__67327_G__67330_G__67331_G__67336_changes$jscomp$122$$=$only_main_cb$$.$cljs$core$IFn$_invoke$arity$2$?
$only_main_cb$$.$cljs$core$IFn$_invoke$arity$2$($changes__$1$jscomp$29$$,$child_main$jscomp$8$$):$only_main_cb$$($changes__$1$jscomp$29$$,$child_main$jscomp$8$$);else if($child_main_SINGLEQUOTE_$$==null)$G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$=$APP.$cljs$core$next$$($G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$),$changes__$1$jscomp$29$$=$G__67324_G__67327_G__67330_G__67331_G__67336_changes$jscomp$122$$=$only_inst_cb$$.$cljs$core$IFn$_invoke$arity$2$?
$only_inst_cb$$.$cljs$core$IFn$_invoke$arity$2$($changes__$1$jscomp$29$$,$child_inst$jscomp$8$$):$only_inst_cb$$($changes__$1$jscomp$29$$,$child_inst$jscomp$8$$);else if($APP.$cljs$core$truth_$$($inverse_QMARK_$$)){var $is_main_QMARK_$$=$APP.$app$common$types$component$is_main_of_QMARK_$$($child_inst$jscomp$8$$,$child_main_SINGLEQUOTE_$$);$G__67324_G__67327_G__67330_G__67331_G__67336_changes$jscomp$122$$=$APP.$cljs$core$next$$($G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$);
$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($children_inst__$1$jscomp$4$$,$children_main__$1$jscomp$4$$,$changes__$1$jscomp$33$$,$is_main_QMARK_$jscomp$1$$,$child_inst_SINGLEQUOTE_$jscomp$2$$,$child_main_SINGLEQUOTE_$jscomp$1$$){return function($p1__66602_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__66602_SHARP_$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_main_SINGLEQUOTE_$jscomp$1$$))}}($G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$,$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$,$changes__$1$jscomp$29$$,$is_main_QMARK_$$,$child_inst_SINGLEQUOTE_$$,$child_main_SINGLEQUOTE_$$,$child_inst$jscomp$8$$,$child_main$jscomp$8$$),$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$);var $G__67333$$=
function(){var $G__66656_G__66656__$1_G__66656__$2$$=$changes__$1$jscomp$29$$;$G__66656_G__66656__$1_G__66656__$2$$=$is_main_QMARK_$$?$both_cb$$.$cljs$core$IFn$_invoke$arity$3$?$both_cb$$.$cljs$core$IFn$_invoke$arity$3$($G__66656_G__66656__$1_G__66656__$2$$,$child_inst$jscomp$8$$,$child_main_SINGLEQUOTE_$$):$both_cb$$($G__66656_G__66656__$1_G__66656__$2$$,$child_inst$jscomp$8$$,$child_main_SINGLEQUOTE_$$):$G__66656_G__66656__$1_G__66656__$2$$;$G__66656_G__66656__$1_G__66656__$2$$=$is_main_QMARK_$$?
$G__66656_G__66656__$1_G__66656__$2$$:$swapped_cb$$.$cljs$core$IFn$_invoke$arity$3$?$swapped_cb$$.$cljs$core$IFn$_invoke$arity$3$($G__66656_G__66656__$1_G__66656__$2$$,$child_inst$jscomp$8$$,$child_main_SINGLEQUOTE_$$):$swapped_cb$$($G__66656_G__66656__$1_G__66656__$2$$,$child_inst$jscomp$8$$,$child_main_SINGLEQUOTE_$$);return $moved_cb$$.$cljs$core$IFn$_invoke$arity$3$?$moved_cb$$.$cljs$core$IFn$_invoke$arity$3$($G__66656_G__66656__$1_G__66656__$2$$,$child_inst$jscomp$8$$,$child_main_SINGLEQUOTE_$$):
$moved_cb$$($G__66656_G__66656__$1_G__66656__$2$$,$child_inst$jscomp$8$$,$child_main_SINGLEQUOTE_$$)}();$G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$=$G__67324_G__67327_G__67330_G__67331_G__67336_changes$jscomp$122$$;$changes__$1$jscomp$29$$=$G__67333$$}else $is_main_QMARK_$$=$APP.$app$common$types$component$is_main_of_QMARK_$$($child_inst_SINGLEQUOTE_$$,$child_main$jscomp$8$$),$G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($children_inst__$1$jscomp$5$$,
$children_main__$1$jscomp$5$$,$changes__$1$jscomp$34$$,$is_main_QMARK_$jscomp$2$$,$child_inst_SINGLEQUOTE_$jscomp$3$$){return function($p1__66605_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__66605_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_inst_SINGLEQUOTE_$jscomp$3$$))}}($G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$,$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$,
$changes__$1$jscomp$29$$,$is_main_QMARK_$$,$child_inst_SINGLEQUOTE_$$,$child_main_SINGLEQUOTE_$$,$child_inst$jscomp$8$$,$child_main$jscomp$8$$),$G__67322_G__67325_G__67328_G__67334_children_inst$jscomp$2_children_inst__$1$$),$G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$=$APP.$cljs$core$next$$($G__67323_G__67326_G__67329_G__67332_G__67335_children_main$jscomp$2_children_main__$1$$),$changes__$1$jscomp$29$$=$G__67324_G__67327_G__67330_G__67331_G__67336_changes$jscomp$122$$=
function(){var $G__66658_G__66658__$1_G__66658__$2$$=$changes__$1$jscomp$29$$;$G__66658_G__66658__$1_G__66658__$2$$=$is_main_QMARK_$$?$both_cb$$.$cljs$core$IFn$_invoke$arity$3$?$both_cb$$.$cljs$core$IFn$_invoke$arity$3$($G__66658_G__66658__$1_G__66658__$2$$,$child_inst_SINGLEQUOTE_$$,$child_main$jscomp$8$$):$both_cb$$($G__66658_G__66658__$1_G__66658__$2$$,$child_inst_SINGLEQUOTE_$$,$child_main$jscomp$8$$):$G__66658_G__66658__$1_G__66658__$2$$;$G__66658_G__66658__$1_G__66658__$2$$=$is_main_QMARK_$$?
$G__66658_G__66658__$1_G__66658__$2$$:$swapped_cb$$.$cljs$core$IFn$_invoke$arity$3$?$swapped_cb$$.$cljs$core$IFn$_invoke$arity$3$($G__66658_G__66658__$1_G__66658__$2$$,$child_inst_SINGLEQUOTE_$$,$child_main$jscomp$8$$):$swapped_cb$$($G__66658_G__66658__$1_G__66658__$2$$,$child_inst_SINGLEQUOTE_$$,$child_main$jscomp$8$$);return $moved_cb$$.$cljs$core$IFn$_invoke$arity$3$?$moved_cb$$.$cljs$core$IFn$_invoke$arity$3$($G__66658_G__66658__$1_G__66658__$2$$,$child_inst_SINGLEQUOTE_$$,$child_main$jscomp$8$$):
$moved_cb$$($G__66658_G__66658__$1_G__66658__$2$$,$child_inst_SINGLEQUOTE_$$,$child_main$jscomp$8$$)}()}}};
$app$common$logic$libraries$add_shape_to_instance$$=function($changes$jscomp$123$$,$component_shape$jscomp$3$$,$index$jscomp$256$$,$changes_SINGLEQUOTE___$2_component_page$jscomp$4_new_shapes$jscomp$6$$,$container$jscomp$53$$,$root_instance$$,$root_main$jscomp$4$$,$omit_touched_QMARK_$jscomp$3$$,$set_remote_synced_QMARK_$jscomp$2$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$jscomp$3$$),$changes_SINGLEQUOTE___$2_component_page$jscomp$4_new_shapes$jscomp$6$$)&&
$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,["ADD [P ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$53$$)),
"] ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$jscomp$3$$))," ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$jscomp$3$$))].join("")],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1161$info$$,!1);var $component_parent_shape$$=$APP.$app$common$types$container$get_shape$$($changes_SINGLEQUOTE___$2_component_page$jscomp$4_new_shapes$jscomp$6$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$jscomp$3$$)),$parent_shape$jscomp$1$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__66660_SHARP_$$){return $APP.$app$common$types$component$is_main_of_QMARK_$$($component_parent_shape$$,$p1__66660_SHARP_$$)},$APP.$app$common$files$helpers$get_children_with_self$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$53$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root_instance$$))),
$all_parents$jscomp$4$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent_shape$jscomp$1$$)],null),$APP.$app$common$files$helpers$get_parent_ids$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$53$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent_shape$jscomp$1$$))),$changes_SINGLEQUOTE_$jscomp$1_changes_SINGLEQUOTE___$1_vec__66662$$=
$APP.$app$common$types$shape_tree$clone_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($component_shape$jscomp$3$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent_shape$jscomp$1$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes_SINGLEQUOTE___$2_component_page$jscomp$4_new_shapes$jscomp$6$$,$APP.$cljs$cst$1631$objects$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2089$update_new_shape$$,function($G__66668_G__66668__$1_G__66668__$2_new_shape$jscomp$8$$,
$original_shape$jscomp$2$$){$G__66668_G__66668__$1_G__66668__$2_new_shape$jscomp$8$$=$APP.$app$common$logic$libraries$reposition_shape$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$app$common$logic$libraries$reposition_shape$$.$cljs$core$IFn$_invoke$arity$3$($G__66668_G__66668__$1_G__66668__$2_new_shape$jscomp$8$$,$root_main$jscomp$4$$,$root_instance$$):$APP.$app$common$logic$libraries$reposition_shape$$($G__66668_G__66668__$1_G__66668__$2_new_shape$jscomp$8$$,$root_main$jscomp$4$$,$root_instance$$);$G__66668_G__66668__$1_G__66668__$2_new_shape$jscomp$8$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($original_shape$jscomp$2$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$jscomp$3$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66668_G__66668__$1_G__66668__$2_new_shape$jscomp$8$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($parent_shape$jscomp$1$$),
$APP.$cljs$cst$1606$frame$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent_shape$jscomp$1$$):$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($parent_shape$jscomp$1$$)):$G__66668_G__66668__$1_G__66668__$2_new_shape$jscomp$8$$;$G__66668_G__66668__$1_G__66668__$2_new_shape$jscomp$8$$=$APP.$cljs$core$truth_$$($set_remote_synced_QMARK_$jscomp$2$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66668_G__66668__$1_G__66668__$2_new_shape$jscomp$8$$,$APP.$cljs$cst$2046$remote_synced$$,
!0):$G__66668_G__66668__$1_G__66668__$2_new_shape$jscomp$8$$;return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66668_G__66668__$1_G__66668__$2_new_shape$jscomp$8$$,$APP.$cljs$cst$2047$shape_ref$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($original_shape$jscomp$2$$)),$APP.$cljs$cst$1626$touched$$)},$APP.$cljs$cst$2090$update_original_shape$$,function($original_shape$jscomp$3$$){return $original_shape$jscomp$3$$},
$cljs$cst$2093$dest_objects$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$53$$,$APP.$cljs$cst$1631$objects$$)]));$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes_SINGLEQUOTE_$jscomp$1_changes_SINGLEQUOTE___$1_vec__66662$$,0,null);$changes_SINGLEQUOTE___$2_component_page$jscomp$4_new_shapes$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes_SINGLEQUOTE_$jscomp$1_changes_SINGLEQUOTE___$1_vec__66662$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes_SINGLEQUOTE_$jscomp$1_changes_SINGLEQUOTE___$1_vec__66662$$,
2,null);$changes_SINGLEQUOTE_$jscomp$1_changes_SINGLEQUOTE___$1_vec__66662$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$35$$,$G__66670$jscomp$inline_12340_JSCompiler_inline_result$jscomp$10842_shape_SINGLEQUOTE_$jscomp$4$$){var $JSCompiler_temp_const$jscomp$10840$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$,$G__66675$jscomp$inline_12341$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2610$add_obj$$,
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__66670$jscomp$inline_12340_JSCompiler_inline_result$jscomp$10842_shape_SINGLEQUOTE_$jscomp$4$$),$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($G__66670$jscomp$inline_12340_JSCompiler_inline_result$jscomp$10842_shape_SINGLEQUOTE_$jscomp$4$$),$APP.$cljs$cst$1795$index$$,$index$jscomp$256$$,$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2611$obj$$,$G__66670$jscomp$inline_12340_JSCompiler_inline_result$jscomp$10842_shape_SINGLEQUOTE_$jscomp$4$$],
null);$G__66670$jscomp$inline_12340_JSCompiler_inline_result$jscomp$10842_shape_SINGLEQUOTE_$jscomp$4$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($G__66670$jscomp$inline_12340_JSCompiler_inline_result$jscomp$10842_shape_SINGLEQUOTE_$jscomp$4$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66675$jscomp$inline_12341$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($G__66670$jscomp$inline_12340_JSCompiler_inline_result$jscomp$10842_shape_SINGLEQUOTE_$jscomp$4$$)):
$G__66675$jscomp$inline_12341$$;$G__66670$jscomp$inline_12340_JSCompiler_inline_result$jscomp$10842_shape_SINGLEQUOTE_$jscomp$4$$=$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$53$$,$G__66670$jscomp$inline_12340_JSCompiler_inline_result$jscomp$10842_shape_SINGLEQUOTE_$jscomp$4$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$53$$,$G__66670$jscomp$inline_12340_JSCompiler_inline_result$jscomp$10842_shape_SINGLEQUOTE_$jscomp$4$$);
return $JSCompiler_temp_const$jscomp$10840$$.call($APP.$cljs$core$update$$,$changes__$1$jscomp$35$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,$G__66670$jscomp$inline_12340_JSCompiler_inline_result$jscomp$10842_shape_SINGLEQUOTE_$jscomp$4$$)},$changes$jscomp$123$$,$changes_SINGLEQUOTE___$2_component_page$jscomp$4_new_shapes$jscomp$6$$);$changes_SINGLEQUOTE_$jscomp$1_changes_SINGLEQUOTE___$1_vec__66662$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes_SINGLEQUOTE_$jscomp$1_changes_SINGLEQUOTE___$1_vec__66662$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,function(){var $G__66679$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2624$reg_objects$$,$APP.$cljs$cst$1614$shapes$$,$all_parents$jscomp$4$$],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$53$$,$G__66679$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$53$$,
$G__66679$$)}());$changes_SINGLEQUOTE___$2_component_page$jscomp$4_new_shapes$jscomp$6$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$36$$,$G__66677$jscomp$inline_6310_JSCompiler_inline_result$jscomp$1100_shape_SINGLEQUOTE_$jscomp$5$$){var $JSCompiler_temp_const$jscomp$1098$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$;$G__66677$jscomp$inline_6310_JSCompiler_inline_result$jscomp$1100_shape_SINGLEQUOTE_$jscomp$5$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2614$del_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__66677$jscomp$inline_6310_JSCompiler_inline_result$jscomp$1100_shape_SINGLEQUOTE_$jscomp$5$$),$APP.$cljs$cst$2556$ignore_touched$$,!0],null);$G__66677$jscomp$inline_6310_JSCompiler_inline_result$jscomp$1100_shape_SINGLEQUOTE_$jscomp$5$$=$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$53$$,
$G__66677$jscomp$inline_6310_JSCompiler_inline_result$jscomp$1100_shape_SINGLEQUOTE_$jscomp$5$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$53$$,$G__66677$jscomp$inline_6310_JSCompiler_inline_result$jscomp$1100_shape_SINGLEQUOTE_$jscomp$5$$);return $JSCompiler_temp_const$jscomp$1098$$.call($APP.$cljs$core$update$$,$changes__$1$jscomp$36$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,$G__66677$jscomp$inline_6310_JSCompiler_inline_result$jscomp$1100_shape_SINGLEQUOTE_$jscomp$5$$)},
$changes_SINGLEQUOTE_$jscomp$1_changes_SINGLEQUOTE___$1_vec__66662$$,$changes_SINGLEQUOTE___$2_component_page$jscomp$4_new_shapes$jscomp$6$$);return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$383$$=$app$common$types$component$touched_group_QMARK_$$($parent_shape$jscomp$1$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$383$$)?$omit_touched_QMARK_$jscomp$3$$:$and__5023__auto__$jscomp$383$$}())?$changes$jscomp$123$$:$APP.$app$common$files$changes_builder$apply_changes_local$$($changes_SINGLEQUOTE___$2_component_page$jscomp$4_new_shapes$jscomp$6$$)};
$APP.$app$common$logic$libraries$remove_shape$$=function($changes$jscomp$125$$,$shape$jscomp$421$$,$container$jscomp$54$$,$omit_touched_QMARK_$jscomp$4$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$421$$),$container$jscomp$54$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,["REMOVE-SHAPE ",$app$common$files$helpers$page_QMARK_$$($container$jscomp$54$$)?"[P ":"[C ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$54$$)),"] ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$421$$)),
" ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$421$$))].join("")],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1161$info$$,!1);var $objects$jscomp$284$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$54$$,$APP.$cljs$cst$1631$objects$$),$parents$jscomp$7$$=$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$284$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$421$$)),
$parent$jscomp$213$$=$APP.$cljs$core$first$$($parents$jscomp$7$$),$changes_SINGLEQUOTE___$1$jscomp$2_children$jscomp$206_ids$jscomp$55$$=$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$284$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$421$$));$changes_SINGLEQUOTE___$1$jscomp$2_children$jscomp$206_ids$jscomp$55$$=$APP.$cljs$core$reverse$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$421$$)],null),$changes_SINGLEQUOTE___$1$jscomp$2_children$jscomp$206_ids$jscomp$55$$));var $changes_SINGLEQUOTE_$jscomp$3$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$40$$,$G__66691$jscomp$inline_6312_JSCompiler_inline_result$jscomp$1103_id$jscomp$461$$){var $JSCompiler_temp_const$jscomp$1101$$=
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$;$G__66691$jscomp$inline_6312_JSCompiler_inline_result$jscomp$1103_id$jscomp$461$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2614$del_obj$$,$APP.$cljs$cst$266$id$$,$G__66691$jscomp$inline_6312_JSCompiler_inline_result$jscomp$1103_id$jscomp$461$$,$APP.$cljs$cst$2556$ignore_touched$$,!0],null);$G__66691$jscomp$inline_6312_JSCompiler_inline_result$jscomp$1103_id$jscomp$461$$=$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$54$$,$G__66691$jscomp$inline_6312_JSCompiler_inline_result$jscomp$1103_id$jscomp$461$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$54$$,$G__66691$jscomp$inline_6312_JSCompiler_inline_result$jscomp$1103_id$jscomp$461$$);return $JSCompiler_temp_const$jscomp$1101$$.call($APP.$cljs$core$update$$,$changes__$1$jscomp$40$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,$G__66691$jscomp$inline_6312_JSCompiler_inline_result$jscomp$1103_id$jscomp$461$$)},
$changes$jscomp$125$$,$changes_SINGLEQUOTE___$1$jscomp$2_children$jscomp$206_ids$jscomp$55$$),$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,function(){var $G__66696$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2624$reg_objects$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$vec$$($parents$jscomp$7$$)],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$54$$,
$G__66696$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$54$$,$G__66696$$)}());$changes_SINGLEQUOTE___$1$jscomp$2_children$jscomp$206_ids$jscomp$55$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$41$$,$G__66694$jscomp$inline_12344_id$jscomp$462$$){var $G__66693$jscomp$inline_12343_JSCompiler_inline_result$jscomp$10845_shape_SINGLEQUOTE_$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$284$$,$G__66694$jscomp$inline_12344_id$jscomp$462$$),
$JSCompiler_temp_const$jscomp$10843$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$;$G__66694$jscomp$inline_12344_id$jscomp$462$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2610$add_obj$$,$APP.$cljs$cst$266$id$$,$G__66694$jscomp$inline_12344_id$jscomp$462$$,$APP.$cljs$cst$1795$index$$,$app$common$files$helpers$get_position_on_parent$$($objects$jscomp$284$$,$G__66694$jscomp$inline_12344_id$jscomp$462$$),$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($G__66693$jscomp$inline_12343_JSCompiler_inline_result$jscomp$10845_shape_SINGLEQUOTE_$jscomp$9$$),
$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2611$obj$$,$G__66693$jscomp$inline_12343_JSCompiler_inline_result$jscomp$10845_shape_SINGLEQUOTE_$jscomp$9$$],null);$G__66693$jscomp$inline_12343_JSCompiler_inline_result$jscomp$10845_shape_SINGLEQUOTE_$jscomp$9$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($G__66693$jscomp$inline_12343_JSCompiler_inline_result$jscomp$10845_shape_SINGLEQUOTE_$jscomp$9$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66694$jscomp$inline_12344_id$jscomp$462$$,
$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($G__66693$jscomp$inline_12343_JSCompiler_inline_result$jscomp$10845_shape_SINGLEQUOTE_$jscomp$9$$)):$G__66694$jscomp$inline_12344_id$jscomp$462$$;$G__66693$jscomp$inline_12343_JSCompiler_inline_result$jscomp$10845_shape_SINGLEQUOTE_$jscomp$9$$=$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$54$$,
$G__66693$jscomp$inline_12343_JSCompiler_inline_result$jscomp$10845_shape_SINGLEQUOTE_$jscomp$9$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$54$$,$G__66693$jscomp$inline_12343_JSCompiler_inline_result$jscomp$10845_shape_SINGLEQUOTE_$jscomp$9$$);return $JSCompiler_temp_const$jscomp$10843$$.call($APP.$cljs$core$update$$,$changes__$1$jscomp$41$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,$G__66693$jscomp$inline_12343_JSCompiler_inline_result$jscomp$10845_shape_SINGLEQUOTE_$jscomp$9$$)},
$changes_SINGLEQUOTE_$jscomp$3$$,$changes_SINGLEQUOTE___$1$jscomp$2_children$jscomp$206_ids$jscomp$55$$);return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$384$$=$app$common$types$component$touched_group_QMARK_$$($parent$jscomp$213$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$384$$)?$omit_touched_QMARK_$jscomp$4$$:$and__5023__auto__$jscomp$384$$}())?$changes$jscomp$125$$:$APP.$app$common$files$changes_builder$apply_changes_local$$($changes_SINGLEQUOTE___$1$jscomp$2_children$jscomp$206_ids$jscomp$55$$)};
$APP.$app$common$logic$libraries$move_shape$$=function($changes$jscomp$126$$,$shape$jscomp$422$$,$index_before$$,$index_after$$,$container$jscomp$55$$,$omit_touched_QMARK_$jscomp$5$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$422$$),$container$jscomp$55$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,["MOVE ",$app$common$files$helpers$page_QMARK_$$($container$jscomp$55$$)?"[P ":"[C ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$55$$)),"] ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$422$$)),
" ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$422$$))," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index_before$$)," -\x3e ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index_after$$)].join("")],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1161$info$$,!1);var $parent$jscomp$214$$=$APP.$app$common$types$container$get_shape$$($container$jscomp$55$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$422$$)),
$changes_SINGLEQUOTE_$jscomp$4$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$126$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,function(){var $G__66706$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$cljs$cst$2616$mov_objects$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$422$$),$APP.$cljs$cst$1614$shapes$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$422$$)],null),$APP.$cljs$cst$1795$index$$,$index_after$$,$APP.$cljs$cst$2556$ignore_touched$$,!0,$cljs$cst$2618$allow_altering_copies$$,!0],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$55$$,$G__66706$$):
$APP.$app$common$logic$libraries$make_change$$($container$jscomp$55$$,$G__66706$$)}()),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,function(){var $G__66708$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$cljs$cst$2616$mov_objects$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$422$$),$APP.$cljs$cst$1614$shapes$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$422$$)],null),$APP.$cljs$cst$1795$index$$,$index_before$$,$APP.$cljs$cst$2556$ignore_touched$$,!0,$cljs$cst$2618$allow_altering_copies$$,!0],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$55$$,$G__66708$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$55$$,$G__66708$$)}());
return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$385$$=$app$common$types$component$touched_group_QMARK_$$($parent$jscomp$214$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$385$$)?$omit_touched_QMARK_$jscomp$5$$:$and__5023__auto__$jscomp$385$$}())?$changes$jscomp$126$$:$APP.$app$common$files$changes_builder$apply_changes_local$$($changes_SINGLEQUOTE_$jscomp$4$$)};
$APP.$app$common$logic$libraries$change_touched$$=function($changes$jscomp$127$$,$dest_shape$$,$origin_shape$$,$container$jscomp$56$$,$p__66715_reset_touched_QMARK_$$){var $map__66716__$1$$=$APP.$cljs$core$__destructure_map$$($p__66715_reset_touched_QMARK_$$);$p__66715_reset_touched_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66716__$1$$,$APP.$cljs$cst$3535$reset_touched_QMARK_$$);var $copy_touched_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66716__$1$$,
$APP.$cljs$cst$3539$copy_touched_QMARK_$$);if($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$$)==null)return $changes$jscomp$127$$;$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$$),$container$jscomp$56$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,["CHANGE-TOUCHED ",$app$common$files$helpers$page_QMARK_$$($container$jscomp$56$$)?"[P ":"[C ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$56$$)),"] ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$$)),
" ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$$))].join("")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$873$options$$,$map__66716__$1$$],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1161$info$$,!1);var $new_touched$$=$APP.$cljs$core$truth_$$($p__66715_reset_touched_QMARK_$$)?null:$APP.$cljs$core$truth_$$($copy_touched_QMARK_$$)?$APP.$cljs$core$truth_$$($APP.$cljs$cst$2046$remote_synced$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$$))?
null:$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$$),$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$$)):$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$$);return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$127$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,function(){var $G__66724$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$$),$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2600$set_touched$$,
$APP.$cljs$cst$1626$touched$$,$new_touched$$],null)],null)],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$56$$,$G__66724$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$56$$,$G__66724$$)}()),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,function(){var $G__66726$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$$),$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2600$set_touched$$,$APP.$cljs$cst$1626$touched$$,$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$$)],null)],null)],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$56$$,$G__66726$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$56$$,$G__66726$$)}()))};
$APP.$app$common$logic$libraries$change_remote_synced$$=function($changes$jscomp$128$$,$shape$jscomp$423$$,$container$jscomp$57$$,$remote_synced_QMARK_$$){if($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$423$$)==null)return $changes$jscomp$128$$;$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$423$$),$container$jscomp$57$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",
$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,["CHANGE-REMOTE-SYNCED? ",$app$common$files$helpers$page_QMARK_$$($container$jscomp$57$$)?"[P ":"[C ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$57$$)),
"] ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$423$$))," ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$423$$))].join("")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2046$remote_synced$$,$remote_synced_QMARK_$$],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1161$info$$,
!1);return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$128$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,function(){var $G__66734$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$423$$),$APP.$cljs$cst$2613$operations$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2601$set_remote_synced$$,$APP.$cljs$cst$2046$remote_synced$$,$remote_synced_QMARK_$$],null)],null)],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$57$$,$G__66734$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$57$$,
$G__66734$$)}()),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,function(){var $G__66736$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$423$$),$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,
$cljs$cst$2601$set_remote_synced$$,$APP.$cljs$cst$2046$remote_synced$$,$APP.$cljs$cst$2046$remote_synced$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$423$$)],null)],null)],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$57$$,$G__66736$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$57$$,$G__66736$$)}()))};
$app$common$logic$libraries$update_tokens$$=function($changes$jscomp$129$$,$container$jscomp$58$$,$dest_shape$jscomp$1$$,$orig_shape$$,$token_attrs$jscomp$1$$){var $orig_tokens$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($orig_shape$$,$APP.$cljs$cst$1873$applied_tokens$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),$dest_tokens$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($dest_shape$jscomp$1$$,$APP.$cljs$cst$1873$applied_tokens$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),
$dest_tokens_SINGLEQUOTE_$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($dest_tokens_SINGLEQUOTE_$jscomp$1$$,$token_attr$jscomp$1$$){var $orig_token$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($orig_tokens$$,$token_attr$jscomp$1$$),$dest_token$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dest_tokens$$,$token_attr$jscomp$1$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($orig_token$$,$dest_token$$)?$dest_tokens_SINGLEQUOTE_$jscomp$1$$:
$orig_token$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($dest_tokens_SINGLEQUOTE_$jscomp$1$$,$token_attr$jscomp$1$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($dest_tokens_SINGLEQUOTE_$jscomp$1$$,$token_attr$jscomp$1$$,$orig_token$$)},$dest_tokens$$,$token_attrs$jscomp$1$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dest_tokens$$,$dest_tokens_SINGLEQUOTE_$$)?$changes$jscomp$129$$:$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$129$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,function(){var $G__66738$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$1$$),$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,
$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1873$applied_tokens$$,$APP.$cljs$cst$108$val$$,$dest_tokens_SINGLEQUOTE_$$,$APP.$cljs$cst$2556$ignore_touched$$,!0],null)],null)],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$58$$,$G__66738$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$58$$,$G__66738$$)}()),$APP.$cljs$cst$3137$undo_changes$$,
$APP.$cljs$core$conj$$,function(){var $G__66740$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$1$$),$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,
$APP.$cljs$cst$1873$applied_tokens$$,$APP.$cljs$cst$108$val$$,$dest_tokens$$,$APP.$cljs$cst$2556$ignore_touched$$,!0],null)],null)],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$58$$,$G__66740$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$58$$,$G__66740$$)}()))};
$app$common$logic$libraries$generate_update_tokens$$=function($changes$jscomp$130$$,$container$jscomp$59$$,$dest_shape$jscomp$2$$,$origin_shape$jscomp$1$$,$touched$jscomp$5$$,$omit_touched_QMARK_$jscomp$6$$,$valid_attrs$$){var $applied_tokens_attrs$jscomp$69$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66741_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1696$layout_grid_cells$$,$p1__66741_SHARP_$$)},$APP.$cljs$core$keys$$($app$common$types$component$sync_attrs$$));
$applied_tokens_attrs$jscomp$69$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($applied_tokens$jscomp$1$$,$attr$jscomp$41$$){var $or__5025__auto__$jscomp$inline_6316_sync_group$$=$app$common$types$component$resolve_sync_group$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$jscomp$1$$),$attr$jscomp$41$$);$or__5025__auto__$jscomp$inline_6316_sync_group$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_6316_sync_group$$)?$or__5025__auto__$jscomp$inline_6316_sync_group$$:
$app$common$types$component$resolve_sync_group$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$2$$),$attr$jscomp$41$$);var $token_attrs$jscomp$2$$=$APP.$app$common$types$token$shape_attr__GT_token_attrs$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$41$$);return($APP.$cljs$core$not$$($omit_touched_QMARK_$jscomp$6$$)||$APP.$cljs$core$not$$($touched$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$inline_6316_sync_group$$):
$touched$jscomp$5$$($or__5025__auto__$jscomp$inline_6316_sync_group$$)))&&($APP.$cljs$core$empty_QMARK_$$($valid_attrs$$)||$APP.$cljs$core$contains_QMARK_$$($valid_attrs$$,$attr$jscomp$41$$))?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$1$$,$token_attrs$jscomp$2$$):$applied_tokens$jscomp$1$$},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$applied_tokens_attrs$jscomp$69$$);return $APP.$cljs$core$seq$$($applied_tokens_attrs$jscomp$69$$)?$app$common$logic$libraries$update_tokens$$($changes$jscomp$130$$,
$container$jscomp$59$$,$dest_shape$jscomp$2$$,$origin_shape$jscomp$1$$,$applied_tokens_attrs$jscomp$69$$):$changes$jscomp$130$$};
$app$common$logic$libraries$add_update_attr_changes$$=function($changes$jscomp$131$$,$dest_shape$jscomp$3$$,$container$jscomp$60$$,$roperations$$,$uoperations$$){var $all_parents$jscomp$6$$=$APP.$app$common$files$helpers$get_parent_ids$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$60$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$3$$));return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$131$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,function(){var $G__66745$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$3$$),$APP.$cljs$cst$2613$operations$$,$roperations$$],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$60$$,
$G__66745$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$60$$,$G__66745$$)}()),$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,function(){var $G__66747$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2624$reg_objects$$,$APP.$cljs$cst$1614$shapes$$,$all_parents$jscomp$6$$],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$60$$,
$G__66747$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$60$$,$G__66747$$)}()),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,function(){var $G__66749$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$3$$),$APP.$cljs$cst$2613$operations$$,$APP.$cljs$core$vec$$($uoperations$$)],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$60$$,$G__66749$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$60$$,$G__66749$$)}()),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$concat$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[function(){var $G__66751$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2624$reg_objects$$,$APP.$cljs$cst$1614$shapes$$,
$all_parents$jscomp$6$$],null);return $APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($container$jscomp$60$$,$G__66751$$):$APP.$app$common$logic$libraries$make_change$$($container$jscomp$60$$,$G__66751$$)}()],null)))};
$app$common$logic$libraries$text_change_value$$=function($touched_content$$,$untouched_content$$,$touched$jscomp$6$$){var $diff_structure_QMARK__main_comps_diff$$=$app$common$types$text$get_diff_type$$($touched_content$$,$untouched_content$$);$diff_structure_QMARK__main_comps_diff$$=$APP.$cljs$core$contains_QMARK_$$($diff_structure_QMARK__main_comps_diff$$,$cljs$cst$1773$text_content_structure$$);var $touched_attrs$$=$app$common$types$text$get_first_paragraph_text_attrs$$($touched_content$$),$thed_unif_style_QMARK_$$=
$app$common$types$text$equal_attrs_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($touched_content$$,$touched_attrs$$,!0),$untouched_attrs$$=$app$common$types$text$get_first_paragraph_text_attrs$$($untouched_content$$),$untched_unif_style_QMARK_$$=$app$common$types$text$equal_attrs_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($untouched_content$$,$untouched_attrs$$,!0);return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$386$$=$touched$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1774$text_content_text$$):
$touched$jscomp$6$$($cljs$cst$1774$text_content_text$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$386$$)?$touched$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1775$text_content_attribute$$):$touched$jscomp$6$$($cljs$cst$1775$text_content_attribute$$):$and__5023__auto__$jscomp$386$$}())?$touched_content$$:$APP.$cljs$core$truth_$$($touched$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1773$text_content_structure$$):
$touched$jscomp$6$$($cljs$cst$1773$text_content_structure$$))?$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$387$$=$APP.$cljs$core$not$$($touched$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1775$text_content_attribute$$):$touched$jscomp$6$$($cljs$cst$1775$text_content_attribute$$));return $and__5023__auto__$jscomp$387$$?$APP.$cljs$core$truth_$$($thed_unif_style_QMARK_$$)?$untched_unif_style_QMARK_$$:$thed_unif_style_QMARK_$$:
$and__5023__auto__$jscomp$387$$}())?$app$common$types$text$copy_attrs_keys$$($touched_content$$,$untouched_attrs$$):$touched_content$$:$APP.$cljs$core$truth_$$($touched$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1774$text_content_text$$):$touched$jscomp$6$$($cljs$cst$1774$text_content_text$$))?$app$common$types$text$copy_text_keys$$($touched_content$$,$untouched_content$$):$APP.$cljs$core$truth_$$($touched$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?
$touched$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1775$text_content_attribute$$):$touched$jscomp$6$$($cljs$cst$1775$text_content_attribute$$))?$diff_structure_QMARK__main_comps_diff$$?$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($thed_unif_style_QMARK_$$)?$untched_unif_style_QMARK_$$:$thed_unif_style_QMARK_$$)?$app$common$types$text$copy_attrs_keys$$($untouched_content$$,$touched_attrs$$):$touched_content$$:$app$common$types$text$copy_text_keys$$($untouched_content$$,$touched_content$$):
$untouched_content$$};
$app$common$logic$libraries$add_update_attr_operations$$=function($attr$jscomp$42_uoperation$$,$dest_shape$jscomp$4$$,$roperations$jscomp$1$$,$uoperations$jscomp$1$$,$attr_val$jscomp$1_roperation$$){$attr_val$jscomp$1_roperation$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$attr$jscomp$42_uoperation$$,$APP.$cljs$cst$108$val$$,$attr_val$jscomp$1_roperation$$,$APP.$cljs$cst$2556$ignore_touched$$,!0],null);$attr$jscomp$42_uoperation$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$attr$jscomp$42_uoperation$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dest_shape$jscomp$4$$,$attr$jscomp$42_uoperation$$),$APP.$cljs$cst$2556$ignore_touched$$,!0],null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($roperations$jscomp$1$$,
$attr_val$jscomp$1_roperation$$),$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($uoperations$jscomp$1$$,$attr$jscomp$42_uoperation$$)],null)};
$app$common$logic$libraries$check_detached_main$$=function($changes$jscomp$132$$,$dest_shape$jscomp$5$$,$origin_shape$jscomp$2$$){var $JSCompiler_temp$jscomp$817$$;if($JSCompiler_temp$jscomp$817$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$5$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$jscomp$2$$)))$JSCompiler_temp$jscomp$817$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$5$$)!=
null&&$APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$5$$)==null&&$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$5$$)!=null&&!$APP.$app$common$types$component$instance_head_QMARK_$$($origin_shape$jscomp$2$$);return $JSCompiler_temp$jscomp$817$$?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$132$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$5$$)],null),$app$common$types$component$unhead_shape$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null)):$changes$jscomp$132$$};
$app$common$logic$libraries$check_swapped_main$$=function($changes$jscomp$133$$,$dest_shape$jscomp$6$$,$origin_shape$jscomp$3$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$6$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$jscomp$3$$))&&$APP.$app$common$types$component$instance_head_QMARK_$$($dest_shape$jscomp$6$$)&&$APP.$app$common$types$component$instance_head_QMARK_$$($origin_shape$jscomp$3$$)&&
($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$6$$),$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$jscomp$3$$))||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$6$$),$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$jscomp$3$$)))?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$133$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$6$$)],null),function($p1__66762_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__66762_SHARP_$$,$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$jscomp$3$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1643$component_file$$,
$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$jscomp$3$$)]))},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null)):$changes$jscomp$133$$};
$APP.$app$common$logic$libraries$update_attrs$$=function($G__66782_G__66782__$1_G__66782__$2_G__66782__$3_changes$jscomp$134$$,$dest_shape$jscomp$7$$,$origin_shape$jscomp$4$$,$G__67367_attrs$jscomp$70_dest_root$$,$G__67368_origin_root_roperations$jscomp$2_roperations_SINGLEQUOTE__roperations__$1$$,$container$jscomp$61$$,$omit_touched_QMARK_$jscomp$7$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$7$$),$container$jscomp$61$$)&&
$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,["SYNC ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$jscomp$4$$)),
" ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$jscomp$4$$))," -\x3e ",$app$common$files$helpers$page_QMARK_$$($container$jscomp$61$$)?"[P ":"[C ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$61$$)),"] ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$7$$))," ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$7$$))].join("")],
null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1161$info$$,!1);var $origin_shape__$1$$=$APP.$app$common$logic$libraries$reposition_shape$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$app$common$logic$libraries$reposition_shape$$.$cljs$core$IFn$_invoke$arity$3$($origin_shape$jscomp$4$$,$G__67368_origin_root_roperations$jscomp$2_roperations_SINGLEQUOTE__roperations__$1$$,$G__67367_attrs$jscomp$70_dest_root$$):$APP.$app$common$logic$libraries$reposition_shape$$($origin_shape$jscomp$4$$,$G__67368_origin_root_roperations$jscomp$2_roperations_SINGLEQUOTE__roperations__$1$$,
$G__67367_attrs$jscomp$70_dest_root$$),$touched$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($dest_shape$jscomp$7$$,$APP.$cljs$cst$1626$touched$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);$G__67367_attrs$jscomp$70_dest_root$$=$app$common$logic$libraries$updatable_attrs$$;$G__67368_origin_root_roperations$jscomp$2_roperations_SINGLEQUOTE__roperations__$1$$=$APP.$cljs$core$PersistentVector$EMPTY$$;for(var $G__67369_uoperations$jscomp$2_uoperations_SINGLEQUOTE__uoperations__$1_vec__66785_vec__66788$$=
$APP.$cljs$core$List$EMPTY$$;;){var $attr$jscomp$43$$=$APP.$cljs$core$first$$($G__67367_attrs$jscomp$70_dest_root$$);if($attr$jscomp$43$$==null)return $G__66782_G__66782__$1_G__66782__$2_G__66782__$3_changes$jscomp$134$$=$APP.$cljs$core$seq$$($G__67368_origin_root_roperations$jscomp$2_roperations_SINGLEQUOTE__roperations__$1$$)?$app$common$logic$libraries$add_update_attr_changes$$($G__66782_G__66782__$1_G__66782__$2_G__66782__$3_changes$jscomp$134$$,$dest_shape$jscomp$7$$,$container$jscomp$61$$,$G__67368_origin_root_roperations$jscomp$2_roperations_SINGLEQUOTE__roperations__$1$$,
$G__67369_uoperations$jscomp$2_uoperations_SINGLEQUOTE__uoperations__$1_vec__66785_vec__66788$$):$G__66782_G__66782__$1_G__66782__$2_G__66782__$3_changes$jscomp$134$$,$G__66782_G__66782__$1_G__66782__$2_G__66782__$3_changes$jscomp$134$$=$app$common$logic$libraries$check_detached_main$$($G__66782_G__66782__$1_G__66782__$2_G__66782__$3_changes$jscomp$134$$,$dest_shape$jscomp$7$$,$origin_shape__$1$$),$G__66782_G__66782__$1_G__66782__$2_G__66782__$3_changes$jscomp$134$$=$app$common$logic$libraries$check_swapped_main$$($G__66782_G__66782__$1_G__66782__$2_G__66782__$3_changes$jscomp$134$$,
$dest_shape$jscomp$7$$,$origin_shape__$1$$),$app$common$logic$libraries$generate_update_tokens$$($G__66782_G__66782__$1_G__66782__$2_G__66782__$3_changes$jscomp$134$$,$container$jscomp$61$$,$dest_shape$jscomp$7$$,$origin_shape__$1$$,$touched$jscomp$7$$,$omit_touched_QMARK_$jscomp$7$$,null);var $sync_group$jscomp$1$$=function(){var $or__5025__auto__$jscomp$665$$=$app$common$types$component$resolve_sync_group$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape__$1$$),$attr$jscomp$43$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$665$$)?$or__5025__auto__$jscomp$665$$:$app$common$types$component$resolve_sync_group$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$7$$),$attr$jscomp$43$$)}(),$reset_pos_data_QMARK_$$=function(){var $and__5023__auto__$jscomp$389_and__5023__auto____$1$jscomp$69_and__5023__auto____$2$jscomp$27$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape__$1$$);return $and__5023__auto__$jscomp$389_and__5023__auto____$1$jscomp$69_and__5023__auto____$2$jscomp$27$$?
($and__5023__auto__$jscomp$389_and__5023__auto____$1$jscomp$69_and__5023__auto____$2$jscomp$27$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$43$$,$APP.$cljs$cst$1891$position_data$$))?($and__5023__auto__$jscomp$389_and__5023__auto____$1$jscomp$69_and__5023__auto____$2$jscomp$27$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape__$1$$),$APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$7$$)))?
$touched$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$2065$geometry_group$$):$touched$jscomp$7$$($cljs$cst$2065$geometry_group$$):$and__5023__auto__$jscomp$389_and__5023__auto____$1$jscomp$69_and__5023__auto____$2$jscomp$27$$:$and__5023__auto__$jscomp$389_and__5023__auto____$1$jscomp$69_and__5023__auto____$2$jscomp$27$$:$and__5023__auto__$jscomp$389_and__5023__auto____$1$jscomp$69_and__5023__auto____$2$jscomp$27$$}(),$text_content_change_QMARK_$$=
function(){if($APP.$cljs$core$truth_$$($omit_touched_QMARK_$jscomp$7$$)){var $and__5023__auto____$1$jscomp$70_and__5023__auto____$2$jscomp$28$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape__$1$$);return $and__5023__auto____$1$jscomp$70_and__5023__auto____$2$jscomp$28$$?($and__5023__auto____$1$jscomp$70_and__5023__auto____$2$jscomp$28$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1637$content$$,$attr$jscomp$43$$))?$touched$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?
$touched$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($sync_group$jscomp$1$$):$touched$jscomp$7$$($sync_group$jscomp$1$$):$and__5023__auto____$1$jscomp$70_and__5023__auto____$2$jscomp$28$$:$and__5023__auto____$1$jscomp$70_and__5023__auto____$2$jscomp$28$$}return $omit_touched_QMARK_$jscomp$7$$}(),$skip_operations_QMARK_$$=function(){var $and__5023__auto__$jscomp$391_or__5025__auto__$jscomp$666$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($origin_shape__$1$$,
$attr$jscomp$43$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dest_shape$jscomp$7$$,$attr$jscomp$43$$));if($and__5023__auto__$jscomp$391_or__5025__auto__$jscomp$666$$)return $and__5023__auto__$jscomp$391_or__5025__auto__$jscomp$666$$;$and__5023__auto__$jscomp$391_or__5025__auto__$jscomp$666$$=$touched$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($sync_group$jscomp$1$$):$touched$jscomp$7$$($sync_group$jscomp$1$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$391_or__5025__auto__$jscomp$666$$)?
$APP.$cljs$core$truth_$$($omit_touched_QMARK_$jscomp$7$$)?$APP.$cljs$core$not$$($text_content_change_QMARK_$$):$omit_touched_QMARK_$jscomp$7$$:$and__5023__auto__$jscomp$391_or__5025__auto__$jscomp$666$$}(),$attr_val$jscomp$2$$=$APP.$cljs$core$truth_$$($skip_operations_QMARK_$$)?null:$APP.$cljs$core$truth_$$($reset_pos_data_QMARK_$$)?null:$APP.$cljs$core$truth_$$($text_content_change_QMARK_$$)?$app$common$logic$libraries$text_change_value$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$7$$),
$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape__$1$$),$touched$jscomp$7$$):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($origin_shape__$1$$,$attr$jscomp$43$$),$skip_operations_QMARK___$1$$=function(){var $or__5025__auto__$jscomp$667$$=$skip_operations_QMARK_$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$667$$)?$or__5025__auto__$jscomp$667$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr_val$jscomp$2$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dest_shape$jscomp$7$$,
$attr$jscomp$43$$))}();$G__67369_uoperations$jscomp$2_uoperations_SINGLEQUOTE__uoperations__$1_vec__66785_vec__66788$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$392$$=$text_content_change_QMARK_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$392$$)?$APP.$cljs$core$not$$($skip_operations_QMARK___$1$$):$and__5023__auto__$jscomp$392$$}())?$app$common$logic$libraries$add_update_attr_operations$$($APP.$cljs$cst$1891$position_data$$,$dest_shape$jscomp$7$$,$G__67368_origin_root_roperations$jscomp$2_roperations_SINGLEQUOTE__roperations__$1$$,
$G__67369_uoperations$jscomp$2_uoperations_SINGLEQUOTE__uoperations__$1_vec__66785_vec__66788$$,null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__67368_origin_root_roperations$jscomp$2_roperations_SINGLEQUOTE__roperations__$1$$,$G__67369_uoperations$jscomp$2_uoperations_SINGLEQUOTE__uoperations__$1_vec__66785_vec__66788$$],null);$G__67368_origin_root_roperations$jscomp$2_roperations_SINGLEQUOTE__roperations__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67369_uoperations$jscomp$2_uoperations_SINGLEQUOTE__uoperations__$1_vec__66785_vec__66788$$,
0,null);$G__67369_uoperations$jscomp$2_uoperations_SINGLEQUOTE__uoperations__$1_vec__66785_vec__66788$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67369_uoperations$jscomp$2_uoperations_SINGLEQUOTE__uoperations__$1_vec__66785_vec__66788$$,1,null);$G__67369_uoperations$jscomp$2_uoperations_SINGLEQUOTE__uoperations__$1_vec__66785_vec__66788$$=$APP.$cljs$core$truth_$$($skip_operations_QMARK___$1$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$G__67368_origin_root_roperations$jscomp$2_roperations_SINGLEQUOTE__roperations__$1$$,$G__67369_uoperations$jscomp$2_uoperations_SINGLEQUOTE__uoperations__$1_vec__66785_vec__66788$$],null):$app$common$logic$libraries$add_update_attr_operations$$($attr$jscomp$43$$,$dest_shape$jscomp$7$$,$G__67368_origin_root_roperations$jscomp$2_roperations_SINGLEQUOTE__roperations__$1$$,$G__67369_uoperations$jscomp$2_uoperations_SINGLEQUOTE__uoperations__$1_vec__66785_vec__66788$$,$attr_val$jscomp$2$$);$G__67368_origin_root_roperations$jscomp$2_roperations_SINGLEQUOTE__roperations__$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67369_uoperations$jscomp$2_uoperations_SINGLEQUOTE__uoperations__$1_vec__66785_vec__66788$$,0,null);$G__67369_uoperations$jscomp$2_uoperations_SINGLEQUOTE__uoperations__$1_vec__66785_vec__66788$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67369_uoperations$jscomp$2_uoperations_SINGLEQUOTE__uoperations__$1_vec__66785_vec__66788$$,1,null);$G__67367_attrs$jscomp$70_dest_root$$=$APP.$cljs$core$next$$($G__67367_attrs$jscomp$70_dest_root$$)}};
$app$common$logic$libraries$switch_path_change_value$$=function($content$jscomp$inline_12346_new_pos$jscomp$inline_6330_prev_center$jscomp$inline_6328_prev_shape$jscomp$1_shape$jscomp$425$$,$current_shape$jscomp$4_shape$jscomp$inline_6327$$,$new_content$jscomp$inline_6323_old_height_ref_shape$jscomp$3$$,$attr$jscomp$44$$){var $delta$jscomp$inline_6329_new_points$jscomp$inline_6324_old_width_transform$jscomp$78$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($new_content$jscomp$inline_6323_old_height_ref_shape$jscomp$3$$)),
$new_width$jscomp$1_points_center$jscomp$inline_6325$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$inline_12346_new_pos$jscomp$inline_6330_prev_center$jscomp$inline_6328_prev_shape$jscomp$1_shape$jscomp$425$$));$new_content$jscomp$inline_6323_old_height_ref_shape$jscomp$3$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($new_content$jscomp$inline_6323_old_height_ref_shape$jscomp$3$$));
var $new_height$jscomp$1_new_selrect$jscomp$inline_6326$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$inline_12346_new_pos$jscomp$inline_6330_prev_center$jscomp$inline_6328_prev_shape$jscomp$1_shape$jscomp$425$$));$delta$jscomp$inline_6329_new_points$jscomp$inline_6324_old_width_transform$jscomp$78$$=$app$common$geom$matrix$scale_matrix$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($new_width$jscomp$1_points_center$jscomp$inline_6325$$/
$delta$jscomp$inline_6329_new_points$jscomp$inline_6324_old_width_transform$jscomp$78$$,$new_height$jscomp$1_new_selrect$jscomp$inline_6326$$/$new_content$jscomp$inline_6323_old_height_ref_shape$jscomp$3$$));$new_content$jscomp$inline_6323_old_height_ref_shape$jscomp$3$$=$app$common$types$path$segment$transform_content$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$jscomp$4_shape$jscomp$inline_6327$$),$APP.$app$common$geom$matrix$transform_in$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,
0),$delta$jscomp$inline_6329_new_points$jscomp$inline_6324_old_width_transform$jscomp$78$$));$delta$jscomp$inline_6329_new_points$jscomp$inline_6324_old_width_transform$jscomp$78$$=$APP.$app$common$geom$rect$rect__GT_points$$($app$common$types$path$segment$content__GT_selrect$$($new_content$jscomp$inline_6323_old_height_ref_shape$jscomp$3$$));$new_width$jscomp$1_points_center$jscomp$inline_6325$$=$APP.$app$common$geom$shapes$common$points__GT_center$$($delta$jscomp$inline_6329_new_points$jscomp$inline_6324_old_width_transform$jscomp$78$$);
$new_height$jscomp$1_new_selrect$jscomp$inline_6326$$=$app$common$geom$shapes$transforms$calculate_selrect$$($delta$jscomp$inline_6329_new_points$jscomp$inline_6324_old_width_transform$jscomp$78$$,$new_width$jscomp$1_points_center$jscomp$inline_6325$$);$current_shape$jscomp$4_shape$jscomp$inline_6327$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($current_shape$jscomp$4_shape$jscomp$inline_6327$$,$APP.$cljs$cst$1637$content$$,$new_content$jscomp$inline_6323_old_height_ref_shape$jscomp$3$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1604$points$$,$delta$jscomp$inline_6329_new_points$jscomp$inline_6324_old_width_transform$jscomp$78$$,$APP.$cljs$cst$1605$selrect$$,$new_height$jscomp$1_new_selrect$jscomp$inline_6326$$]));$content$jscomp$inline_12346_new_pos$jscomp$inline_6330_prev_center$jscomp$inline_6328_prev_shape$jscomp$1_shape$jscomp$425$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$inline_12346_new_pos$jscomp$inline_6330_prev_center$jscomp$inline_6328_prev_shape$jscomp$1_shape$jscomp$425$$);
$content$jscomp$inline_12346_new_pos$jscomp$inline_6330_prev_center$jscomp$inline_6328_prev_shape$jscomp$1_shape$jscomp$425$$=$APP.$app$common$geom$rect$rect__GT_center$$($app$common$types$path$segment$content__GT_selrect$$($content$jscomp$inline_12346_new_pos$jscomp$inline_6330_prev_center$jscomp$inline_6328_prev_shape$jscomp$1_shape$jscomp$425$$));$delta$jscomp$inline_6329_new_points$jscomp$inline_6324_old_width_transform$jscomp$78$$=$APP.$app$common$geom$point$subtract$$($new_width$jscomp$1_points_center$jscomp$inline_6325$$,
$APP.$cljs$core$first$$($delta$jscomp$inline_6329_new_points$jscomp$inline_6324_old_width_transform$jscomp$78$$));$content$jscomp$inline_12346_new_pos$jscomp$inline_6330_prev_center$jscomp$inline_6328_prev_shape$jscomp$1_shape$jscomp$425$$=$APP.$app$common$geom$point$subtract$$($content$jscomp$inline_12346_new_pos$jscomp$inline_6330_prev_center$jscomp$inline_6328_prev_shape$jscomp$1_shape$jscomp$425$$,$delta$jscomp$inline_6329_new_points$jscomp$inline_6324_old_width_transform$jscomp$78$$);$content$jscomp$inline_12346_new_pos$jscomp$inline_6330_prev_center$jscomp$inline_6328_prev_shape$jscomp$1_shape$jscomp$425$$=
$app$common$geom$shapes$transforms$absolute_move$$($current_shape$jscomp$4_shape$jscomp$inline_6327$$,$content$jscomp$inline_12346_new_pos$jscomp$inline_6330_prev_center$jscomp$inline_6328_prev_shape$jscomp$1_shape$jscomp$425$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$inline_12346_new_pos$jscomp$inline_6330_prev_center$jscomp$inline_6328_prev_shape$jscomp$1_shape$jscomp$425$$,$attr$jscomp$44$$)};
$app$common$logic$libraries$switch_text_change_value$$=function($prev_content$jscomp$1$$,$current_content$$,$ref_content_ref_unif_style_QMARK_$$,$touched$jscomp$8$$){var $main_comps_diff$jscomp$1_main_diff_structure_QMARK_$$=$app$common$types$text$get_diff_type$$($ref_content_ref_unif_style_QMARK_$$,$current_content$$),$can_keep_text_QMARK_$$=!$APP.$cljs$core$contains_QMARK_$$($main_comps_diff$jscomp$1_main_diff_structure_QMARK_$$,$cljs$cst$1774$text_content_text$$),$can_keep_attr_QMARK_$$=!$APP.$cljs$core$contains_QMARK_$$($main_comps_diff$jscomp$1_main_diff_structure_QMARK_$$,
$cljs$cst$1775$text_content_attribute$$);$main_comps_diff$jscomp$1_main_diff_structure_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($main_comps_diff$jscomp$1_main_diff_structure_QMARK_$$,$cljs$cst$1773$text_content_structure$$);var $current_attrs$$=$app$common$types$text$get_first_paragraph_text_attrs$$($current_content$$),$curr_unif_style_QMARK_$$=$app$common$types$text$equal_attrs_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($current_content$$,$current_attrs$$,!0),$prev_attrs$$=$app$common$types$text$get_first_paragraph_text_attrs$$($prev_content$jscomp$1$$),
$prev_unif_style_QMARK_$$=$app$common$types$text$equal_attrs_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($prev_content$jscomp$1$$,$prev_attrs$$,!0),$ref_attrs$$=$app$common$types$text$get_first_paragraph_text_attrs$$($ref_content_ref_unif_style_QMARK_$$);$ref_content_ref_unif_style_QMARK_$$=$app$common$types$text$equal_attrs_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($ref_content_ref_unif_style_QMARK_$$,$ref_attrs$$,!0);return $main_comps_diff$jscomp$1_main_diff_structure_QMARK_$$?$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($curr_unif_style_QMARK_$$)?
$APP.$cljs$core$truth_$$($ref_content_ref_unif_style_QMARK_$$)?$APP.$cljs$core$truth_$$($prev_unif_style_QMARK_$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ref_attrs$$,$current_attrs$$):$prev_unif_style_QMARK_$$:$ref_content_ref_unif_style_QMARK_$$:$curr_unif_style_QMARK_$$)?$app$common$types$text$copy_attrs_keys$$($current_content$$,$prev_attrs$$):$current_content$$:$can_keep_text_QMARK_$$&&$can_keep_attr_QMARK_$$?$prev_content$jscomp$1$$:$can_keep_text_QMARK_$$||$can_keep_attr_QMARK_$$?
$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$394$$=$touched$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1773$text_content_structure$$):$touched$jscomp$8$$($cljs$cst$1773$text_content_structure$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$394$$)?$APP.$cljs$core$truth_$$($curr_unif_style_QMARK_$$)?$prev_unif_style_QMARK_$$:$curr_unif_style_QMARK_$$:$and__5023__auto__$jscomp$394$$}())?$can_keep_text_QMARK_$$?
$app$common$types$text$copy_attrs_keys$$($prev_content$jscomp$1$$,$current_attrs$$):$app$common$types$text$copy_attrs_keys$$($current_content$$,$prev_attrs$$):$APP.$cljs$core$truth_$$($touched$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1773$text_content_structure$$):$touched$jscomp$8$$($cljs$cst$1773$text_content_structure$$))?$current_content$$:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$395$$=$touched$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$?
$touched$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1774$text_content_text$$):$touched$jscomp$8$$($cljs$cst$1774$text_content_text$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$395$$)?$can_keep_text_QMARK_$$:$and__5023__auto__$jscomp$395$$}())?$app$common$types$text$copy_text_keys$$($prev_content$jscomp$1$$,$current_content$$):$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$396$$=$touched$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1775$text_content_attribute$$):
$touched$jscomp$8$$($cljs$cst$1775$text_content_attribute$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$396$$)?$can_keep_attr_QMARK_$$:$and__5023__auto__$jscomp$396$$}())?$app$common$types$text$copy_text_keys$$($current_content$$,$prev_content$jscomp$1$$):$current_content$$:$current_content$$};
$app$common$logic$libraries$switch_fixed_layout_geom_change_value$$=function($prev_shape$jscomp$2_v_sizing$jscomp$1$$,$JSCompiler_inline_result$jscomp$1108_current_shape$jscomp$5_or__5025__auto__$jscomp$inline_6332$$,$origin_shape$jscomp$5_x$jscomp$1169$$,$G__66843__$1_JSCompiler_temp_const$jscomp$1106_attr$jscomp$45$$){var $final_width_prev_width$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($prev_shape$jscomp$2_v_sizing$jscomp$1$$)),
$current_width$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1108_current_shape$jscomp$5_or__5025__auto__$jscomp$inline_6332$$)),$origin_width$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$jscomp$5_x$jscomp$1169$$)),$JSCompiler_temp_const$jscomp$1105_final_height_prev_height$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($prev_shape$jscomp$2_v_sizing$jscomp$1$$)),
$JSCompiler_temp_const$jscomp$1104_current_height_selrect$jscomp$40$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1108_current_shape$jscomp$5_or__5025__auto__$jscomp$inline_6332$$)),$origin_height$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$jscomp$5_x$jscomp$1169$$));$origin_shape$jscomp$5_x$jscomp$1169$$=
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1108_current_shape$jscomp$5_or__5025__auto__$jscomp$inline_6332$$));var $y$jscomp$406$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1108_current_shape$jscomp$5_or__5025__auto__$jscomp$inline_6332$$)),$h_sizing$jscomp$1$$=$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($prev_shape$jscomp$2_v_sizing$jscomp$1$$);
$prev_shape$jscomp$2_v_sizing$jscomp$1$$=$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($prev_shape$jscomp$2_v_sizing$jscomp$1$$);$final_width_prev_width$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1697$fix$$,$h_sizing$jscomp$1$$)?$current_width$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin_width$$,$current_width$$)?$final_width_prev_width$$:$current_width$$;$JSCompiler_temp_const$jscomp$1105_final_height_prev_height$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1697$fix$$,
$prev_shape$jscomp$2_v_sizing$jscomp$1$$)?$JSCompiler_temp_const$jscomp$1104_current_height_selrect$jscomp$40$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin_height$$,$JSCompiler_temp_const$jscomp$1104_current_height_selrect$jscomp$40$$)?$JSCompiler_temp_const$jscomp$1105_final_height_prev_height$$:$JSCompiler_temp_const$jscomp$1104_current_height_selrect$jscomp$40$$;$JSCompiler_temp_const$jscomp$1104_current_height_selrect$jscomp$40$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1108_current_shape$jscomp$5_or__5025__auto__$jscomp$inline_6332$$),
$APP.$cljs$cst$290$width$$,$final_width_prev_width$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1522$height$$,$JSCompiler_temp_const$jscomp$1105_final_height_prev_height$$,$APP.$cljs$cst$1510$x$$,$origin_shape$jscomp$5_x$jscomp$1169$$,$APP.$cljs$cst$1511$y$$,$y$jscomp$406$$,$APP.$cljs$cst$1523$x1$$,$origin_shape$jscomp$5_x$jscomp$1169$$,$APP.$cljs$cst$1524$y1$$,$y$jscomp$406$$,$APP.$cljs$cst$1525$x2$$,$origin_shape$jscomp$5_x$jscomp$1169$$+$final_width_prev_width$$,
$APP.$cljs$cst$1526$y2$$,$y$jscomp$406$$+$JSCompiler_temp_const$jscomp$1105_final_height_prev_height$$]));$G__66843__$1_JSCompiler_temp_const$jscomp$1106_attr$jscomp$45$$=$G__66843__$1_JSCompiler_temp_const$jscomp$1106_attr$jscomp$45$$ instanceof $APP.$cljs$core$Keyword$$?$G__66843__$1_JSCompiler_temp_const$jscomp$1106_attr$jscomp$45$$.$fqn$:null;switch($G__66843__$1_JSCompiler_temp_const$jscomp$1106_attr$jscomp$45$$){case "width":return $final_width_prev_width$$;case "height":return $JSCompiler_temp_const$jscomp$1105_final_height_prev_height$$;
case "selrect":return $JSCompiler_temp_const$jscomp$1104_current_height_selrect$jscomp$40$$;case "points":return $G__66843__$1_JSCompiler_temp_const$jscomp$1106_attr$jscomp$45$$=$app$common$geom$shapes$transform_points$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1105_final_height_prev_height$$=$APP.$app$common$geom$rect$rect__GT_points$$($JSCompiler_temp_const$jscomp$1104_current_height_selrect$jscomp$40$$),$JSCompiler_temp_const$jscomp$1104_current_height_selrect$jscomp$40$$=
$APP.$app$common$geom$rect$rect__GT_center$$($JSCompiler_temp_const$jscomp$1104_current_height_selrect$jscomp$40$$),$JSCompiler_inline_result$jscomp$1108_current_shape$jscomp$5_or__5025__auto__$jscomp$inline_6332$$=$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1108_current_shape$jscomp$5_or__5025__auto__$jscomp$inline_6332$$),$JSCompiler_inline_result$jscomp$1108_current_shape$jscomp$5_or__5025__auto__$jscomp$inline_6332$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1108_current_shape$jscomp$5_or__5025__auto__$jscomp$inline_6332$$)?
$JSCompiler_inline_result$jscomp$1108_current_shape$jscomp$5_or__5025__auto__$jscomp$inline_6332$$:$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$(),$G__66843__$1_JSCompiler_temp_const$jscomp$1106_attr$jscomp$45$$.call($app$common$geom$shapes$transform_points$$,$JSCompiler_temp_const$jscomp$1105_final_height_prev_height$$,$JSCompiler_temp_const$jscomp$1104_current_height_selrect$jscomp$40$$,$JSCompiler_inline_result$jscomp$1108_current_shape$jscomp$5_or__5025__auto__$jscomp$inline_6332$$);
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__66843__$1_JSCompiler_temp_const$jscomp$1106_attr$jscomp$45$$)].join(""));}};
$app$common$logic$libraries$equal_geometry_QMARK_$$=function($shape$jscomp$426$$,$origin_shape$jscomp$6$$,$attr$jscomp$46$$){var $and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$=function(){var $and__5023__auto__$jscomp$398_and__5023__auto____$1$jscomp$75$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$46$$,$APP.$cljs$cst$1605$selrect$$);return $and__5023__auto__$jscomp$398_and__5023__auto____$1$jscomp$75$$?
($and__5023__auto__$jscomp$398_and__5023__auto____$1$jscomp$75$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$426$$)),$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$jscomp$6$$))),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$398_and__5023__auto____$1$jscomp$75$$)?
$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$426$$)),$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$jscomp$6$$))):$and__5023__auto__$jscomp$398_and__5023__auto____$1$jscomp$75$$):$and__5023__auto__$jscomp$398_and__5023__auto____$1$jscomp$75$$}();if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$)||
($and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$=function(){var $a$jscomp$386_and__5023__auto__$jscomp$399$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$46$$,$APP.$cljs$cst$1604$points$$);if($a$jscomp$386_and__5023__auto__$jscomp$399$$){var $b$jscomp$316_normalize_pts$$=function($pts$jscomp$2$$){if($APP.$cljs$core$seq$$($pts$jscomp$2$$)){var $f$jscomp$824$$=$APP.$cljs$core$first$$($pts$jscomp$2$$);
return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66844_SHARP_$$){return $APP.$app$common$geom$point$subtract$$($p1__66844_SHARP_$$,$f$jscomp$824$$)},$pts$jscomp$2$$)}return null};$a$jscomp$386_and__5023__auto__$jscomp$399$$=$b$jscomp$316_normalize_pts$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$426$$,$APP.$cljs$cst$1604$points$$));$b$jscomp$316_normalize_pts$$=$b$jscomp$316_normalize_pts$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($origin_shape$jscomp$6$$,
$APP.$cljs$cst$1604$points$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($a$jscomp$386_and__5023__auto__$jscomp$399$$),$APP.$cljs$core$count$$($b$jscomp$316_normalize_pts$$))&&$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$identity$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($app$common$geom$point$close_QMARK_$$,$a$jscomp$386_and__5023__auto__$jscomp$399$$,$b$jscomp$316_normalize_pts$$))}return $a$jscomp$386_and__5023__auto__$jscomp$399$$}()))return $and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$;
if($and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$46$$,$APP.$cljs$cst$1637$content$$)){if($and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$=$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$426$$)){$and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$=
$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$426$$);var $cb$jscomp$12_selrect_b$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($origin_shape$jscomp$6$$),$and__5023__auto____$2$jscomp$30_and__5023__auto____$3$jscomp$5_and__5023__auto____$4$jscomp$3_and__5023__auto____$5$jscomp$1_and__5023__auto____$6$jscomp$1$$=$and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$!=
null;return $and__5023__auto____$2$jscomp$30_and__5023__auto____$3$jscomp$5_and__5023__auto____$4$jscomp$3_and__5023__auto____$5$jscomp$1_and__5023__auto____$6$jscomp$1$$?($and__5023__auto____$2$jscomp$30_and__5023__auto____$3$jscomp$5_and__5023__auto____$4$jscomp$3_and__5023__auto____$5$jscomp$1_and__5023__auto____$6$jscomp$1$$=$cb$jscomp$12_selrect_b$$!=null)?($and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$=
$app$common$types$path$segment$content__GT_selrect$$($and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$),$cb$jscomp$12_selrect_b$$=$app$common$types$path$segment$content__GT_selrect$$($cb$jscomp$12_selrect_b$$),($and__5023__auto____$2$jscomp$30_and__5023__auto____$3$jscomp$5_and__5023__auto____$4$jscomp$3_and__5023__auto____$5$jscomp$1_and__5023__auto____$6$jscomp$1$$=$and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$!=
null)?($and__5023__auto____$2$jscomp$30_and__5023__auto____$3$jscomp$5_and__5023__auto____$4$jscomp$3_and__5023__auto____$5$jscomp$1_and__5023__auto____$6$jscomp$1$$=$cb$jscomp$12_selrect_b$$!=null)?($and__5023__auto____$2$jscomp$30_and__5023__auto____$3$jscomp$5_and__5023__auto____$4$jscomp$3_and__5023__auto____$5$jscomp$1_and__5023__auto____$6$jscomp$1$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$),
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($cb$jscomp$12_selrect_b$$)),$APP.$cljs$core$truth_$$($and__5023__auto____$2$jscomp$30_and__5023__auto____$3$jscomp$5_and__5023__auto____$4$jscomp$3_and__5023__auto____$5$jscomp$1_and__5023__auto____$6$jscomp$1$$)?$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$),
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($cb$jscomp$12_selrect_b$$)):$and__5023__auto____$2$jscomp$30_and__5023__auto____$3$jscomp$5_and__5023__auto____$4$jscomp$3_and__5023__auto____$5$jscomp$1_and__5023__auto____$6$jscomp$1$$):$and__5023__auto____$2$jscomp$30_and__5023__auto____$3$jscomp$5_and__5023__auto____$4$jscomp$3_and__5023__auto____$5$jscomp$1_and__5023__auto____$6$jscomp$1$$:$and__5023__auto____$2$jscomp$30_and__5023__auto____$3$jscomp$5_and__5023__auto____$4$jscomp$3_and__5023__auto____$5$jscomp$1_and__5023__auto____$6$jscomp$1$$):
$and__5023__auto____$2$jscomp$30_and__5023__auto____$3$jscomp$5_and__5023__auto____$4$jscomp$3_and__5023__auto____$5$jscomp$1_and__5023__auto____$6$jscomp$1$$:$and__5023__auto____$2$jscomp$30_and__5023__auto____$3$jscomp$5_and__5023__auto____$4$jscomp$3_and__5023__auto____$5$jscomp$1_and__5023__auto____$6$jscomp$1$$}return $and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$}return $and__5023__auto__$jscomp$397_and__5023__auto____$1$jscomp$74_ca$jscomp$3_or__5025__auto__$jscomp$669_or__5025__auto____$1$jscomp$83_selrect_a$$};
$app$common$logic$libraries$update_attrs_on_switch$$=function($G__66912_changes$jscomp$135$$,$current_shape$jscomp$6$$,$G__67384_attrs$jscomp$71_new_touched$jscomp$1_previous_shape_updated_sync_groups$$,$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$,$G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$,$origin_ref_shape$$,$container$jscomp$62$$){var $previous_shape__$1$$=$APP.$app$common$logic$libraries$reposition_shape$$.$cljs$core$IFn$_invoke$arity$3$?
$APP.$app$common$logic$libraries$reposition_shape$$.$cljs$core$IFn$_invoke$arity$3$($G__67384_attrs$jscomp$71_new_touched$jscomp$1_previous_shape_updated_sync_groups$$,$G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$,$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$):$APP.$app$common$logic$libraries$reposition_shape$$($G__67384_attrs$jscomp$71_new_touched$jscomp$1_previous_shape_updated_sync_groups$$,
$G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$,$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$),$touched$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($previous_shape__$1$$,$APP.$cljs$cst$1626$touched$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$text_auto_QMARK_$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$jscomp$6$$)&&
$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2035$auto_height$$,null,$APP.$cljs$cst$2036$auto_width$$,null],null),null),$APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$jscomp$6$$));$G__67384_attrs$jscomp$71_new_touched$jscomp$1_previous_shape_updated_sync_groups$$=$app$common$logic$libraries$updatable_attrs$$;$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$=
$APP.$cljs$core$PersistentVector$EMPTY$$;for(var $uoperations$jscomp$3$$=$APP.$cljs$core$List$EMPTY$$;;){var $temp__5823__auto__$jscomp$167$$=$APP.$cljs$core$first$$($G__67384_attrs$jscomp$71_new_touched$jscomp$1_previous_shape_updated_sync_groups$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$167$$)){var $attr$jscomp$47$$=$temp__5823__auto__$jscomp$167$$,$sync_group$jscomp$2$$=$app$common$types$component$resolve_sync_group$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($previous_shape__$1$$),
$attr$jscomp$47$$),$skip_operations_QMARK_$jscomp$1$$=function(){var $or__5025__auto__$jscomp$670_or__5025__auto____$1$jscomp$84_or__5025__auto____$2$jscomp$23_or__5025__auto____$3$jscomp$9$$=$text_auto_QMARK_$$&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1891$position_data$$,null,$APP.$cljs$cst$1605$selrect$$,null,$APP.$cljs$cst$1522$height$$,
null],null),null),$attr$jscomp$47$$);if($or__5025__auto__$jscomp$670_or__5025__auto____$1$jscomp$84_or__5025__auto____$2$jscomp$23_or__5025__auto____$3$jscomp$9$$||($or__5025__auto__$jscomp$670_or__5025__auto____$1$jscomp$84_or__5025__auto____$2$jscomp$23_or__5025__auto____$3$jscomp$9$$=$APP.$cljs$core$not$$($app$common$types$shape$is_allowed_switch_keep_attr_QMARK_$$($attr$jscomp$47$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$jscomp$6$$))))||($or__5025__auto__$jscomp$670_or__5025__auto____$1$jscomp$84_or__5025__auto____$2$jscomp$23_or__5025__auto____$3$jscomp$9$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($previous_shape__$1$$,$attr$jscomp$47$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_shape$jscomp$6$$,$attr$jscomp$47$$))))return $or__5025__auto__$jscomp$670_or__5025__auto____$1$jscomp$84_or__5025__auto____$2$jscomp$23_or__5025__auto____$3$jscomp$9$$;$or__5025__auto__$jscomp$670_or__5025__auto____$1$jscomp$84_or__5025__auto____$2$jscomp$23_or__5025__auto____$3$jscomp$9$$=
$app$common$logic$libraries$equal_geometry_QMARK_$$($previous_shape__$1$$,$origin_ref_shape$$,$attr$jscomp$47$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$670_or__5025__auto____$1$jscomp$84_or__5025__auto____$2$jscomp$23_or__5025__auto____$3$jscomp$9$$)?$or__5025__auto__$jscomp$670_or__5025__auto____$1$jscomp$84_or__5025__auto____$2$jscomp$23_or__5025__auto____$3$jscomp$9$$:$APP.$cljs$core$not$$($touched$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$($sync_group$jscomp$2$$):
$touched$jscomp$9$$($sync_group$jscomp$2$$))||!$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1637$content$$,null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1605$selrect$$,null],null),null),$attr$jscomp$47$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($origin_ref_shape$$,$attr$jscomp$47$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_shape$jscomp$6$$,
$attr$jscomp$47$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$47$$,$APP.$cljs$cst$1637$content$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($previous_shape__$1$$),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$jscomp$6$$))}(),$text_change_QMARK_$$=function(){var $and__5023__auto__$jscomp$400_and__5023__auto____$1$jscomp$76_and__5023__auto____$2$jscomp$31_and__5023__auto____$3$jscomp$6$$=
$APP.$cljs$core$not$$($skip_operations_QMARK_$jscomp$1$$);return $and__5023__auto__$jscomp$400_and__5023__auto____$1$jscomp$76_and__5023__auto____$2$jscomp$31_and__5023__auto____$3$jscomp$6$$?($and__5023__auto__$jscomp$400_and__5023__auto____$1$jscomp$76_and__5023__auto____$2$jscomp$31_and__5023__auto____$3$jscomp$6$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$jscomp$6$$))?($and__5023__auto__$jscomp$400_and__5023__auto____$1$jscomp$76_and__5023__auto____$2$jscomp$31_and__5023__auto____$3$jscomp$6$$=
$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($previous_shape__$1$$))?($and__5023__auto__$jscomp$400_and__5023__auto____$1$jscomp$76_and__5023__auto____$2$jscomp$31_and__5023__auto____$3$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1637$content$$,$attr$jscomp$47$$))?$touched$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$($sync_group$jscomp$2$$):$touched$jscomp$9$$($sync_group$jscomp$2$$):
$and__5023__auto__$jscomp$400_and__5023__auto____$1$jscomp$76_and__5023__auto____$2$jscomp$31_and__5023__auto____$3$jscomp$6$$:$and__5023__auto__$jscomp$400_and__5023__auto____$1$jscomp$76_and__5023__auto____$2$jscomp$31_and__5023__auto____$3$jscomp$6$$:$and__5023__auto__$jscomp$400_and__5023__auto____$1$jscomp$76_and__5023__auto____$2$jscomp$31_and__5023__auto____$3$jscomp$6$$:$and__5023__auto__$jscomp$400_and__5023__auto____$1$jscomp$76_and__5023__auto____$2$jscomp$31_and__5023__auto____$3$jscomp$6$$}(),
$path_change_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$jscomp$6$$))&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1637$content$$,null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1605$selrect$$,null],null),null),$attr$jscomp$47$$),$reset_pos_data_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$401_and__5023__auto____$1$jscomp$77_and__5023__auto____$2$jscomp$32_and__5023__auto____$3$jscomp$7$$=
$APP.$cljs$core$not$$($skip_operations_QMARK_$jscomp$1$$);return $and__5023__auto__$jscomp$401_and__5023__auto____$1$jscomp$77_and__5023__auto____$2$jscomp$32_and__5023__auto____$3$jscomp$7$$?($and__5023__auto__$jscomp$401_and__5023__auto____$1$jscomp$77_and__5023__auto____$2$jscomp$32_and__5023__auto____$3$jscomp$7$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($previous_shape__$1$$))?($and__5023__auto__$jscomp$401_and__5023__auto____$1$jscomp$77_and__5023__auto____$2$jscomp$32_and__5023__auto____$3$jscomp$7$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$47$$,$APP.$cljs$cst$1891$position_data$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$47$$,$APP.$cljs$cst$1605$selrect$$))?($and__5023__auto__$jscomp$401_and__5023__auto____$1$jscomp$77_and__5023__auto____$2$jscomp$32_and__5023__auto____$3$jscomp$7$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($previous_shape__$1$$),$APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$jscomp$6$$)))?
$touched$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$2065$geometry_group$$):$touched$jscomp$9$$($cljs$cst$2065$geometry_group$$):$and__5023__auto__$jscomp$401_and__5023__auto____$1$jscomp$77_and__5023__auto____$2$jscomp$32_and__5023__auto____$3$jscomp$7$$:$and__5023__auto__$jscomp$401_and__5023__auto____$1$jscomp$77_and__5023__auto____$2$jscomp$32_and__5023__auto____$3$jscomp$7$$:$and__5023__auto__$jscomp$401_and__5023__auto____$1$jscomp$77_and__5023__auto____$2$jscomp$32_and__5023__auto____$3$jscomp$7$$:
$and__5023__auto__$jscomp$401_and__5023__auto____$1$jscomp$77_and__5023__auto____$2$jscomp$32_and__5023__auto____$3$jscomp$7$$}(),$skip_operations_QMARK___$1$jscomp$1$$=function(){var $and__5023__auto__$jscomp$inline_6334_or__5025__auto__$jscomp$671_or__5025__auto____$1$jscomp$85$$=$skip_operations_QMARK_$jscomp$1$$;if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_6334_or__5025__auto__$jscomp$671_or__5025__auto____$1$jscomp$85$$))return $and__5023__auto__$jscomp$inline_6334_or__5025__auto__$jscomp$671_or__5025__auto____$1$jscomp$85$$;
$and__5023__auto__$jscomp$inline_6334_or__5025__auto__$jscomp$671_or__5025__auto____$1$jscomp$85$$=$reset_pos_data_QMARK_$jscomp$1$$;$and__5023__auto__$jscomp$inline_6334_or__5025__auto__$jscomp$671_or__5025__auto____$1$jscomp$85$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_6334_or__5025__auto__$jscomp$671_or__5025__auto____$1$jscomp$85$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$47$$,$APP.$cljs$cst$1605$selrect$$):$and__5023__auto__$jscomp$inline_6334_or__5025__auto__$jscomp$671_or__5025__auto____$1$jscomp$85$$;
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_6334_or__5025__auto__$jscomp$671_or__5025__auto____$1$jscomp$85$$)?$and__5023__auto__$jscomp$inline_6334_or__5025__auto__$jscomp$671_or__5025__auto____$1$jscomp$85$$:$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1605$selrect$$,null],null),null),$attr$jscomp$47$$)&&!$path_change_QMARK_$$&&!($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1697$fix$$,
$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($previous_shape__$1$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1697$fix$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($previous_shape__$1$$)))&&($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($origin_ref_shape$$,$APP.$cljs$cst$290$width$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_shape$jscomp$6$$,
$APP.$cljs$cst$290$width$$))||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($origin_ref_shape$$,$APP.$cljs$cst$1522$height$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_shape$jscomp$6$$,$APP.$cljs$cst$1522$height$$)))}(),$attr_val$jscomp$3$$=$APP.$cljs$core$truth_$$($skip_operations_QMARK___$1$jscomp$1$$)?null:$APP.$cljs$core$truth_$$($reset_pos_data_QMARK_$jscomp$1$$)?null:$APP.$cljs$core$truth_$$($text_change_QMARK_$$)?
$app$common$logic$libraries$switch_text_change_value$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($previous_shape__$1$$),$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$jscomp$6$$),$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($origin_ref_shape$$),$touched$jscomp$9$$):$path_change_QMARK_$$?$app$common$logic$libraries$switch_path_change_value$$($previous_shape__$1$$,$current_shape$jscomp$6$$,$origin_ref_shape$$,$attr$jscomp$47$$):($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1697$fix$$,
$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($previous_shape__$1$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1697$fix$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($previous_shape__$1$$)))&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1605$selrect$$,
null,$APP.$cljs$cst$1522$height$$,null],null),null),$attr$jscomp$47$$)?$app$common$logic$libraries$switch_fixed_layout_geom_change_value$$($previous_shape__$1$$,$current_shape$jscomp$6$$,$origin_ref_shape$$,$attr$jscomp$47$$):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($previous_shape__$1$$,$attr$jscomp$47$$),$skip_operations_QMARK___$2$$=function(){var $or__5025__auto__$jscomp$672$$=$skip_operations_QMARK___$1$jscomp$1$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$672$$)?$or__5025__auto__$jscomp$672$$:
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr_val$jscomp$3$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_shape$jscomp$6$$,$attr$jscomp$47$$))}();$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$403$$=$APP.$cljs$core$not$$($skip_operations_QMARK___$2$$);return $and__5023__auto__$jscomp$403$$?$text_change_QMARK_$$:$and__5023__auto__$jscomp$403$$}())?
$app$common$logic$libraries$add_update_attr_operations$$($APP.$cljs$cst$1891$position_data$$,$current_shape$jscomp$6$$,$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$,$uoperations$jscomp$3$$,null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$,$uoperations$jscomp$3$$],null);var $roperations__$1$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$,0,null),$uoperations__$1$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$,1,null);$G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$=$APP.$cljs$core$not$$($skip_operations_QMARK___$2$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$47$$,$APP.$cljs$cst$1788$rotation$$)?function(){var $uoperations__$2$jscomp$1_vec__66909$$=$app$common$logic$libraries$add_update_attr_operations$$($APP.$cljs$cst$1289$transform$$,$current_shape$jscomp$6$$,$roperations__$1$jscomp$1$$,$uoperations__$1$jscomp$1$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($previous_shape__$1$$)),$roperations__$2$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($uoperations__$2$jscomp$1_vec__66909$$,
0,null);$uoperations__$2$jscomp$1_vec__66909$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($uoperations__$2$jscomp$1_vec__66909$$,1,null);return $app$common$logic$libraries$add_update_attr_operations$$($APP.$cljs$cst$1787$transform_inverse$$,$current_shape$jscomp$6$$,$roperations__$2$jscomp$1$$,$uoperations__$2$jscomp$1_vec__66909$$,$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($previous_shape__$1$$))}():new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$roperations__$1$jscomp$1$$,$uoperations__$1$jscomp$1$$],null);$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$,0,null);$G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$,
1,null);$G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$=$APP.$cljs$core$truth_$$($skip_operations_QMARK___$2$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$,$G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$],null):$app$common$logic$libraries$add_update_attr_operations$$($attr$jscomp$47$$,
$current_shape$jscomp$6$$,$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$,$G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$,$attr_val$jscomp$3$$);$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$,
0,null);$G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$,1,null);$G__67384_attrs$jscomp$71_new_touched$jscomp$1_previous_shape_updated_sync_groups$$=$APP.$cljs$core$next$$($G__67384_attrs$jscomp$71_new_touched$jscomp$1_previous_shape_updated_sync_groups$$);$uoperations$jscomp$3$$=
$G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$}else return $G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function(){return function($p1__66884_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$203$set$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__66884_SHARP_$$))}}($G__67384_attrs$jscomp$71_new_touched$jscomp$1_previous_shape_updated_sync_groups$$,$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$,$uoperations$jscomp$3$$,$temp__5823__auto__$jscomp$167$$,$previous_shape__$1$$,$touched$jscomp$9$$,$text_auto_QMARK_$$)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2599$attr$$)),$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$),
$G__67384_attrs$jscomp$71_new_touched$jscomp$1_previous_shape_updated_sync_groups$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($attrs$jscomp$73$$,$roperations$jscomp$5$$,$uoperations$jscomp$5$$,$updated_attrs$jscomp$1$$,$temp__5823__auto__$jscomp$169$$,$previous_shape__$1$jscomp$2$$){return function($p1__66885_SHARP_$$){return $app$common$types$component$resolve_sync_group$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($previous_shape__$1$jscomp$2$$),
$p1__66885_SHARP_$$)}}($G__67384_attrs$jscomp$71_new_touched$jscomp$1_previous_shape_updated_sync_groups$$,$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$,$uoperations$jscomp$3$$,$G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$,$temp__5823__auto__$jscomp$167$$,$previous_shape__$1$$,$touched$jscomp$9$$,$text_auto_QMARK_$$)),$G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$),
$G__67384_attrs$jscomp$71_new_touched$jscomp$1_previous_shape_updated_sync_groups$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $or__5025__auto__$jscomp$673$$=$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$673$$)?$or__5025__auto__$jscomp$673$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$}(),$G__67384_attrs$jscomp$71_new_touched$jscomp$1_previous_shape_updated_sync_groups$$),
$roperations__$1$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2600$set_touched$$,$APP.$cljs$cst$1626$touched$$,$G__67384_attrs$jscomp$71_new_touched$jscomp$1_previous_shape_updated_sync_groups$$],null)],null),$G__67385_current_root_roperations$jscomp$3_roperations_SINGLEQUOTE_$jscomp$1_roperations__$2_vec__66900$$),
$uoperations__$1$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2600$set_touched$$,$APP.$cljs$cst$1626$touched$$,$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($current_shape$jscomp$6$$)],null),null,1,null),$uoperations$jscomp$3$$),$APP.$cljs$core$count$$($roperations__$1$jscomp$1$$)>1?$app$common$logic$libraries$generate_update_tokens$$($app$common$logic$libraries$add_update_attr_changes$$($G__66912_changes$jscomp$135$$,
$current_shape$jscomp$6$$,$container$jscomp$62$$,$roperations__$1$jscomp$1$$,$uoperations__$1$jscomp$1$$),$container$jscomp$62$$,$current_shape$jscomp$6$$,$previous_shape__$1$$,$touched$jscomp$9$$,!1,$G__67386_prev_root_uoperations_SINGLEQUOTE_$jscomp$1_uoperations__$2_updated_attrs_vec__66903_vec__66906$$):$G__66912_changes$jscomp$135$$}};
$APP.$app$common$logic$libraries$propagate_attrs$$=function($dest$jscomp$3$$,$origin$jscomp$25$$,$attrs$jscomp$74$$,$omit_touched_QMARK_$jscomp$8$$){var $touched$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($dest$jscomp$3$$,$APP.$cljs$cst$1626$touched$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($dest__$1$$,$attr$jscomp$48$$){var $or__5025__auto__$jscomp$inline_6336_sync_group$jscomp$3$$=$app$common$types$component$resolve_sync_group$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($origin$jscomp$25$$),
$attr$jscomp$48$$);$or__5025__auto__$jscomp$inline_6336_sync_group$jscomp$3$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_6336_sync_group$jscomp$3$$)?$or__5025__auto__$jscomp$inline_6336_sync_group$jscomp$3$$:$app$common$types$component$resolve_sync_group$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($dest__$1$$),$attr$jscomp$48$$);return $APP.$cljs$core$not$$($touched$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$touched$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$inline_6336_sync_group$jscomp$3$$):
$touched$jscomp$12$$($or__5025__auto__$jscomp$inline_6336_sync_group$jscomp$3$$))||$APP.$cljs$core$not$$($omit_touched_QMARK_$jscomp$8$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($dest__$1$$,$attr$jscomp$48$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$25$$,$attr$jscomp$48$$)):$dest__$1$$},$dest$jscomp$3$$,$attrs$jscomp$74$$)};
$app$common$logic$libraries$update_flex_child_copy_attrs$$=function($changes$jscomp$136$$,$shape_main$jscomp$8$$,$new_changes$jscomp$1_shape_copy$$,$main_container$$,$main_component$$,$copy_container$$,$omit_touched_QMARK_$jscomp$9$$){$new_changes$jscomp$1_shape_copy$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_container$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$copy_container$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($copy_container$$)),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_changes$jscomp$1_shape_copy$$)],null),function($G__66914__$1_shape_copy__$1$$){$G__66914__$1_shape_copy__$1$$=$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1697$fix$$,
null,$APP.$cljs$cst$1672$auto$$,null],null),null),$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape_main$jscomp$8$$))?$APP.$app$common$logic$libraries$propagate_attrs$$($G__66914__$1_shape_copy__$1$$,$shape_main$jscomp$8$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1708$layout_item_h_sizing$$,null],null),null),$omit_touched_QMARK_$jscomp$9$$):$G__66914__$1_shape_copy__$1$$;return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1697$fix$$,null,$APP.$cljs$cst$1672$auto$$,null],null),null),$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape_main$jscomp$8$$))?$APP.$app$common$logic$libraries$propagate_attrs$$($G__66914__$1_shape_copy__$1$$,$shape_main$jscomp$8$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1709$layout_item_v_sizing$$,null],null),null),$omit_touched_QMARK_$jscomp$9$$):
$G__66914__$1_shape_copy__$1$$},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null)),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($new_changes$jscomp$1_shape_copy$$),function($child_copy$$){var $child_main$jscomp$14$$=$APP.$app$common$types$file$get_ref_shape$$($main_container$$,$main_component$$,$child_copy$$);return $APP.$app$common$logic$libraries$propagate_attrs$$($child_copy$$,$child_main$jscomp$14$$,$APP.$app$common$types$component$swap_keep_attrs$$,
$omit_touched_QMARK_$jscomp$9$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,!0],null));return $APP.$app$common$files$changes_builder$concat_changes$$($changes$jscomp$136$$,$new_changes$jscomp$1_shape_copy$$)};
$app$common$logic$libraries$update_grid_copy_attrs$$=function($changes$jscomp$138$$,$shape_copy_id$$,$shape_main$jscomp$10$$,$main_container$jscomp$2$$,$main_component$jscomp$1$$,$omit_touched_QMARK_$jscomp$11$$){return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$apply_changes_local$$($changes$jscomp$138$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_copy_id$$],
null),function($shape_copy$jscomp$2$$,$objects$jscomp$285$$){var $component_page$jscomp$5$$=$APP.$app$common$types$file$get_component_page$$($main_container$jscomp$2$$,$main_component$jscomp$1$$),$component_swap_children$$=$APP.$cljs$core$group_by$$($APP.$app$common$types$component$get_swap_slot$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66922_SHARP_$$){return $APP.$app$common$types$component$get_swap_slot$$($p1__66922_SHARP_$$)!=null},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66918_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component_page$jscomp$5$$),
$p1__66918_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape_main$jscomp$10$$)))),$ids_map$jscomp$11_main_cells$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__66923_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$285$$,$p1__66923_SHARP_$$)}),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($copy_shape$$){var $main_shape$jscomp$1$$=
$APP.$app$common$types$component$get_swap_slot$$($copy_shape$$)!=null?$APP.$cljs$core$first$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component_swap_children$$,$APP.$app$common$types$component$get_swap_slot$$($copy_shape$$))):$APP.$app$common$types$file$get_ref_shape$$($main_container$jscomp$2$$,$main_component$jscomp$1$$,$copy_shape$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($main_shape$jscomp$1$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($copy_shape$$)],null)})),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape_copy$jscomp$2$$)),$copy_cells$$=function($cells$jscomp$20$$,$map__66927__$1_p__66926_shapes$jscomp$41$$){$map__66927__$1_p__66926_shapes$jscomp$41$$=$APP.$cljs$core$__destructure_map$$($map__66927__$1_p__66926_shapes$jscomp$41$$);$map__66927__$1_p__66926_shapes$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66927__$1_p__66926_shapes$jscomp$41$$,
$APP.$cljs$cst$1614$shapes$$);var $child_QMARK_$jscomp$1$$=$APP.$cljs$core$set$$($map__66927__$1_p__66926_shapes$jscomp$41$$);return $APP.$cljs$core$update_vals$$($cells$jscomp$20$$,function($cell$jscomp$22$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($cell$jscomp$22$$,$APP.$cljs$cst$1614$shapes$$,function($p1__66924_SHARP_$$){return $APP.$cljs$core$filterv$$($child_QMARK_$jscomp$1$$,$p1__66924_SHARP_$$)})})}($APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($shape_copy$jscomp$2$$),
$shape_copy$jscomp$2$$);$ids_map$jscomp$11_main_cells$$=$APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$shape$layout$remap_grid_cells$$($shape_main$jscomp$10$$,$ids_map$jscomp$11_main_cells$$));return $APP.$app$common$types$shape$layout$assign_cells$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape_copy$jscomp$2$$,$APP.$cljs$cst$1696$layout_grid_cells$$,$app$common$types$shape$layout$merge_cells$$($ids_map$jscomp$11_main_cells$$,$copy_cells$$,
$omit_touched_QMARK_$jscomp$11$$)),$objects$jscomp$285$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null))};
$APP.$app$common$logic$libraries$reposition_shape$$=function($shape$jscomp$427$$,$origin_root$jscomp$1_origin_root_pos$$,$delta$jscomp$23_dest_root$jscomp$1_dest_root_pos$$){function $shape_pos$$($shape__$1$jscomp$31$$){return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$31$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1510$x$$],
null)),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$31$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1511$y$$],null)))}$origin_root$jscomp$1_origin_root_pos$$=$shape_pos$$($origin_root$jscomp$1_origin_root_pos$$);$delta$jscomp$23_dest_root$jscomp$1_dest_root_pos$$=$shape_pos$$($delta$jscomp$23_dest_root$jscomp$1_dest_root_pos$$);$delta$jscomp$23_dest_root$jscomp$1_dest_root_pos$$=
$APP.$app$common$geom$point$subtract$$($delta$jscomp$23_dest_root$jscomp$1_dest_root_pos$$,$origin_root$jscomp$1_origin_root_pos$$);return $app$common$geom$shapes$transforms$move$$($shape$jscomp$427$$,$delta$jscomp$23_dest_root$jscomp$1_dest_root_pos$$)};
$APP.$app$common$logic$libraries$make_change$$=function($container$jscomp$63$$,$change$jscomp$24$$){return $app$common$files$helpers$page_QMARK_$$($container$jscomp$63$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($change$jscomp$24$$,$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$63$$)):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($change$jscomp$24$$,$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$63$$))};
$app$common$logic$libraries$generate_add_component_changes$$=function($changes$jscomp$140_changes__$1$jscomp$42$$,$root$jscomp$50$$,$objects$jscomp$286_root_shape$jscomp$1$$,$file_id$jscomp$85_updated_shapes$jscomp$5_vec__66934$$,$page_id$jscomp$98$$,$props$jscomp$149_variant_props$$){var $name$jscomp$288_path$jscomp$234$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$50$$),$variant_id$jscomp$17$$=$APP.$app$common$types$component$is_variant_QMARK_$$($root$jscomp$50$$)?$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$50$$):
null;$props$jscomp$149_variant_props$$=$APP.$app$common$types$component$is_variant_QMARK_$$($root$jscomp$50$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$149_variant_props$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$50$$)):null;var $name__$1$jscomp$5_vec__66931$$=$app$common$path_names$split_group_name$$($name$jscomp$288_path$jscomp$234$$);$name$jscomp$288_path$jscomp$234$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name__$1$jscomp$5_vec__66931$$,
0,null);$name__$1$jscomp$5_vec__66931$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name__$1$jscomp$5_vec__66931$$,1,null);$file_id$jscomp$85_updated_shapes$jscomp$5_vec__66934$$=$APP.$app$common$types$container$convert_shape_in_component$$($root$jscomp$50$$,$objects$jscomp$286_root_shape$jscomp$1$$,$file_id$jscomp$85_updated_shapes$jscomp$5_vec__66934$$);$objects$jscomp$286_root_shape$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_id$jscomp$85_updated_shapes$jscomp$5_vec__66934$$,
0,null);$file_id$jscomp$85_updated_shapes$jscomp$5_vec__66934$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_id$jscomp$85_updated_shapes$jscomp$5_vec__66934$$,1,null);$changes$jscomp$140_changes__$1$jscomp$42$$=$APP.$app$common$files$changes_builder$add_component$$($changes$jscomp$140_changes__$1$jscomp$42$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$286_root_shape$jscomp$1$$),$name$jscomp$288_path$jscomp$234$$,$name__$1$jscomp$5_vec__66931$$,$file_id$jscomp$85_updated_shapes$jscomp$5_vec__66934$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$50$$),$page_id$jscomp$98$$,null,$variant_id$jscomp$17$$,$props$jscomp$149_variant_props$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$objects$jscomp$286_root_shape$jscomp$1$$,$changes$jscomp$140_changes__$1$jscomp$42$$],null)};
$app$common$logic$libraries$generate_add_component$$=function($changes$jscomp$141_changes__$5_old_root_ids_vec__66938$$,$shapes$jscomp$42$$,$objects$jscomp$287$$,$page_id$jscomp$99_root_shape$jscomp$2$$,$changes__$4$jscomp$2_file_id$jscomp$86_vec__66941$$){var $prepare_create_board$$=$APP.$app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$,$changes__$1$jscomp$43$$=$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$141_changes__$5_old_root_ids_vec__66938$$,
$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$,$page_id$jscomp$99_root_shape$jscomp$2$$),$shapes_count$$=$APP.$cljs$core$count$$($shapes$jscomp$42$$),$first_shape$jscomp$3$$=$APP.$cljs$core$first$$($shapes$jscomp$42$$),$from_singe_frame_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$shapes_count$$)&&$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$3$$);$changes$jscomp$141_changes__$5_old_root_ids_vec__66938$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shapes_count$$,1)&&$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$3$$)&&!$APP.$app$common$types$component$instance_head_QMARK_$$($first_shape$jscomp$3$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$first_shape$jscomp$3$$,$APP.$app$common$files$changes_builder$with_objects$$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($changes__$1$jscomp$43$$,
$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$,$page_id$jscomp$99_root_shape$jscomp$2$$),$objects$jscomp$287$$),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$3$$)],null):function(){var $root$jscomp$52_root_name$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$shapes_count$$)?$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$3$$):"Component 1",$shape_ids$jscomp$3$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$shapes$jscomp$42$$);var $G__66949$jscomp$inline_6338_changes__$2$jscomp$20_vec__66945$$=$APP.$app$common$uuid$next$$();var $G__66950$jscomp$inline_6339$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$3$$);$G__66949$jscomp$inline_6338_changes__$2$jscomp$20_vec__66945$$=$prepare_create_board$$.$cljs$core$IFn$_invoke$arity$8$?$prepare_create_board$$.$cljs$core$IFn$_invoke$arity$8$($changes__$1$jscomp$43$$,
$G__66949$jscomp$inline_6338_changes__$2$jscomp$20_vec__66945$$,$G__66950$jscomp$inline_6339$$,$objects$jscomp$287$$,$shape_ids$jscomp$3$$,null,$root$jscomp$52_root_name$$,!0):$prepare_create_board$$($changes__$1$jscomp$43$$,$G__66949$jscomp$inline_6338_changes__$2$jscomp$20_vec__66945$$,$G__66950$jscomp$inline_6339$$,$objects$jscomp$287$$,$shape_ids$jscomp$3$$,null,$root$jscomp$52_root_name$$,!0);$root$jscomp$52_root_name$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66949$jscomp$inline_6338_changes__$2$jscomp$20_vec__66945$$,
0,null);$G__66949$jscomp$inline_6338_changes__$2$jscomp$20_vec__66945$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66949$jscomp$inline_6338_changes__$2$jscomp$20_vec__66945$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$root$jscomp$52_root_name$$,$G__66949$jscomp$inline_6338_changes__$2$jscomp$20_vec__66945$$,$shape_ids$jscomp$3$$],null)}();var $root$jscomp$51$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$141_changes__$5_old_root_ids_vec__66938$$,
0,null),$changes__$2$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$141_changes__$5_old_root_ids_vec__66938$$,1,null);$changes$jscomp$141_changes__$5_old_root_ids_vec__66938$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$141_changes__$5_old_root_ids_vec__66938$$,2,null);var $changes__$3$jscomp$6$$=function(){return $from_singe_frame_QMARK_$$?$changes__$2$jscomp$19$$:$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$2$jscomp$19$$,
$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$51$$),function($shape$jscomp$428$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape$jscomp$428$$,$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$1902$scale$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1902$scale$$]))})}(),$objects_SINGLEQUOTE_$jscomp$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$287$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$51$$),$root$jscomp$51$$);$changes__$4$jscomp$2_file_id$jscomp$86_vec__66941$$=$app$common$logic$libraries$generate_add_component_changes$$($changes__$3$jscomp$6$$,$root$jscomp$51$$,$objects_SINGLEQUOTE_$jscomp$1$$,$changes__$4$jscomp$2_file_id$jscomp$86_vec__66941$$,$page_id$jscomp$99_root_shape$jscomp$2$$,null);$page_id$jscomp$99_root_shape$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$4$jscomp$2_file_id$jscomp$86_vec__66941$$,
0,null);$changes__$4$jscomp$2_file_id$jscomp$86_vec__66941$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$4$jscomp$2_file_id$jscomp$86_vec__66941$$,1,null);$changes$jscomp$141_changes__$5_old_root_ids_vec__66938$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($changes__$4$jscomp$2_file_id$jscomp$86_vec__66941$$,$changes$jscomp$141_changes__$5_old_root_ids_vec__66938$$,function($p1__66937_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__66937_SHARP_$$,
$APP.$cljs$cst$2044$component_root$$)},new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2044$component_root$$],null));return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$root$jscomp$51$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$99_root_shape$jscomp$2$$),$changes$jscomp$141_changes__$5_old_root_ids_vec__66938$$],null)};
$app$common$logic$libraries$generate_detach_component$$=function($changes$jscomp$143$$,$id$jscomp$463$$,$container$jscomp$64_file$jscomp$57$$,$page_id$jscomp$100$$,$libraries$jscomp$53$$){$container$jscomp$64_file$jscomp$57$$=$APP.$app$common$types$container$get_container$$($container$jscomp$64_file$jscomp$57$$,$page_id$jscomp$100$$);return $app$common$logic$libraries$generate_detach_instance$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_container$$($changes$jscomp$143$$,
$container$jscomp$64_file$jscomp$57$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$64_file$jscomp$57$$)),$container$jscomp$64_file$jscomp$57$$,$libraries$jscomp$53$$,$id$jscomp$463$$)};
$app$common$logic$libraries$generate_new_shape_for_swap$$=function($changes$jscomp$144_changes__$1$jscomp$45$$,$shape$jscomp$430$$,$file$jscomp$58$$,$page$jscomp$56$$,$libraries$jscomp$54$$,$changes__$2$jscomp$22_id_new_component_vec__66983$$,$index$jscomp$258$$,$position__$1$jscomp$1_target_cell$jscomp$4$$,$keep_props_values$$){var $new_shape__$1$jscomp$2_objects$jscomp$289$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$56$$),$parent$jscomp$215_position$jscomp$67$$=
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$430$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$430$$));$changes$jscomp$144_changes__$1$jscomp$45$$=$APP.$app$common$files$changes_builder$with_objects$$($changes$jscomp$144_changes__$1$jscomp$45$$,$new_shape__$1$jscomp$2_objects$jscomp$289$$);$position__$1$jscomp$1_target_cell$jscomp$4$$=$APP.$cljs$core$with_meta$$($parent$jscomp$215_position$jscomp$67$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3525$cell$$,$position__$1$jscomp$1_target_cell$jscomp$4$$],null));$parent$jscomp$215_position$jscomp$67$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_shape__$1$jscomp$2_objects$jscomp$289$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$430$$));var $inside_comp_QMARK_$$=$APP.$app$common$types$container$in_any_component_QMARK_$$($new_shape__$1$jscomp$2_objects$jscomp$289$$,$parent$jscomp$215_position$jscomp$67$$);
$changes__$2$jscomp$22_id_new_component_vec__66983$$=$app$common$logic$libraries$generate_instantiate_component$cljs$0core$0IFn$0_invoke$0arity$012$$($changes$jscomp$144_changes__$1$jscomp$45$$,$new_shape__$1$jscomp$2_objects$jscomp$289$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$58$$),$changes__$2$jscomp$22_id_new_component_vec__66983$$,$position__$1$jscomp$1_target_cell$jscomp$4$$,$page$jscomp$56$$,$libraries$jscomp$54$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$430$$),
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$430$$),$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$430$$),$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$430$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$430$$)]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3530$force_frame_QMARK_$$,!0],null));var $new_shape$jscomp$11$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$2$jscomp$22_id_new_component_vec__66983$$,0,null);$changes__$2$jscomp$22_id_new_component_vec__66983$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$2$jscomp$22_id_new_component_vec__66983$$,1,null);$new_shape__$1$jscomp$2_objects$jscomp$289$$=function(){var $JSCompiler_inline_result$jscomp$10790_JSCompiler_temp$jscomp$10789_and__5023__auto__$jscomp$inline_6341_file$jscomp$inline_12350$$=$APP.$app$common$types$component$get_swap_slot$$($new_shape$jscomp$11$$)==
null;$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10790_JSCompiler_temp$jscomp$10789_and__5023__auto__$jscomp$inline_6341_file$jscomp$inline_12350$$?$inside_comp_QMARK_$$:$JSCompiler_inline_result$jscomp$10790_JSCompiler_temp$jscomp$10789_and__5023__auto__$jscomp$inline_6341_file$jscomp$inline_12350$$)?($JSCompiler_inline_result$jscomp$10790_JSCompiler_temp$jscomp$10789_and__5023__auto__$jscomp$inline_6341_file$jscomp$inline_12350$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$58$$),$APP.$cljs$cst$142$data$$,$file$jscomp$58$$],null),$JSCompiler_inline_result$jscomp$10790_JSCompiler_temp$jscomp$10789_and__5023__auto__$jscomp$inline_6341_file$jscomp$inline_12350$$=$app$common$types$file$find_swap_slot$cljs$0core$0IFn$0_invoke$0arity$05$$($shape$jscomp$430$$,$page$jscomp$56$$,$JSCompiler_inline_result$jscomp$10790_JSCompiler_temp$jscomp$10789_and__5023__auto__$jscomp$inline_6341_file$jscomp$inline_12350$$,
$libraries$jscomp$54$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$JSCompiler_inline_result$jscomp$10790_JSCompiler_temp$jscomp$10789_and__5023__auto__$jscomp$inline_6341_file$jscomp$inline_12350$$=$app$common$types$component$set_swap_slot$$($new_shape$jscomp$11$$,$JSCompiler_inline_result$jscomp$10790_JSCompiler_temp$jscomp$10789_and__5023__auto__$jscomp$inline_6341_file$jscomp$inline_12350$$)):$JSCompiler_inline_result$jscomp$10790_JSCompiler_temp$jscomp$10789_and__5023__auto__$jscomp$inline_6341_file$jscomp$inline_12350$$=
$new_shape$jscomp$11$$;return $JSCompiler_inline_result$jscomp$10790_JSCompiler_temp$jscomp$10789_and__5023__auto__$jscomp$inline_6341_file$jscomp$inline_12350$$}();return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_shape__$1$jscomp$2_objects$jscomp$289$$,$APP.$app$common$logic$libraries$change_touched$$($app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$2$jscomp$22_id_new_component_vec__66983$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape__$1$jscomp$2_objects$jscomp$289$$)],null),function($p1__66982_SHARP_$$){return $APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($p1__66982_SHARP_$$,$keep_props_values$$)}),$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$430$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$new_shape__$1$jscomp$2_objects$jscomp$289$$],null),$index$jscomp$258$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$2618$allow_altering_copies$$,!0,$APP.$cljs$cst$2556$ignore_touched$$,!0],null)),$new_shape__$1$jscomp$2_objects$jscomp$289$$,$shape$jscomp$430$$,$app$common$types$container$make_container$$($page$jscomp$56$$,$APP.$cljs$cst$1624$page$$),$APP.$cljs$core$PersistentArrayMap$EMPTY$$)],null)};
$app$common$logic$libraries$generate_component_swap$$=function($all_parents$jscomp$7_changes$jscomp$145$$,$objects$jscomp$290$$,$new_shape$jscomp$12_shape$jscomp$431$$,$changes__$2$jscomp$23_file$jscomp$59_vec__67006$$,$page$jscomp$57$$,$libraries$jscomp$55$$,$id_new_component$jscomp$1$$,$index$jscomp$259$$,$target_cell$jscomp$5$$,$keep_props_values$jscomp$1$$,$changes__$1$jscomp$46_ignore_swapped_QMARK__ignore_swapped_fn_vec__67003$$){$changes__$1$jscomp$46_ignore_swapped_QMARK__ignore_swapped_fn_vec__67003$$=
$APP.$cljs$core$truth_$$($changes__$1$jscomp$46_ignore_swapped_QMARK__ignore_swapped_fn_vec__67003$$)?function($p1__66998_SHARP_$$){return $APP.$app$common$types$component$get_swap_slot$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$290$$,$p1__66998_SHARP_$$))}:$APP.$cljs$core$constantly$$(!1);$changes__$1$jscomp$46_ignore_swapped_QMARK__ignore_swapped_fn_vec__67003$$=$app$common$logic$shapes$generate_delete_shapes$cljs$0core$0IFn$0_invoke$0arity$06$$($all_parents$jscomp$7_changes$jscomp$145$$,
$changes__$2$jscomp$23_file$jscomp$59_vec__67006$$,$page$jscomp$57$$,$objects$jscomp$290$$,$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$12_shape$jscomp$431$$)),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$2618$allow_altering_copies$$,!0,$cljs$cst$1618$ignore_children_fn$$,$changes__$1$jscomp$46_ignore_swapped_QMARK__ignore_swapped_fn_vec__67003$$,$cljs$cst$3523$ignore_mask$$,!0,$cljs$cst$3524$ignore_flows_for$$,
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$12_shape$jscomp$431$$)])],null));$all_parents$jscomp$7_changes$jscomp$145$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$1$jscomp$46_ignore_swapped_QMARK__ignore_swapped_fn_vec__67003$$,0,null);$changes__$1$jscomp$46_ignore_swapped_QMARK__ignore_swapped_fn_vec__67003$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$1$jscomp$46_ignore_swapped_QMARK__ignore_swapped_fn_vec__67003$$,
1,null);$changes__$2$jscomp$23_file$jscomp$59_vec__67006$$=$app$common$logic$libraries$generate_new_shape_for_swap$$($changes__$1$jscomp$46_ignore_swapped_QMARK__ignore_swapped_fn_vec__67003$$,$new_shape$jscomp$12_shape$jscomp$431$$,$changes__$2$jscomp$23_file$jscomp$59_vec__67006$$,$page$jscomp$57$$,$libraries$jscomp$55$$,$id_new_component$jscomp$1$$,$index$jscomp$259$$,$target_cell$jscomp$5$$,$keep_props_values$jscomp$1$$);$new_shape$jscomp$12_shape$jscomp$431$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$2$jscomp$23_file$jscomp$59_vec__67006$$,
0,null);$changes__$2$jscomp$23_file$jscomp$59_vec__67006$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$2$jscomp$23_file$jscomp$59_vec__67006$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_shape$jscomp$12_shape$jscomp$431$$,$all_parents$jscomp$7_changes$jscomp$145$$,$changes__$2$jscomp$23_file$jscomp$59_vec__67006$$],null)};
$app$common$logic$libraries$generate_sync_file_changes$$=function($G__67011__$1_G__67011__$2_G__67011__$3_G__67011__$4_changes$jscomp$146$$,$undo_group$jscomp$5$$,$asset_type$jscomp$8_sync_typographies_QMARK_$$,$file_id$jscomp$87$$,$asset_id$jscomp$8$$,$library_id$jscomp$30$$,$libraries$jscomp$56$$,$current_file_id$jscomp$5$$){var $G__67011__$5_sync_components_QMARK_$$=$asset_type$jscomp$8_sync_typographies_QMARK_$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($asset_type$jscomp$8_sync_typographies_QMARK_$$,
$APP.$cljs$cst$1638$components$$),$G__67011__$6_sync_colors_QMARK_$$=$asset_type$jscomp$8_sync_typographies_QMARK_$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($asset_type$jscomp$8_sync_typographies_QMARK_$$,$APP.$cljs$cst$2212$colors$$);$asset_type$jscomp$8_sync_typographies_QMARK_$$=$asset_type$jscomp$8_sync_typographies_QMARK_$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($asset_type$jscomp$8_sync_typographies_QMARK_$$,$APP.$cljs$cst$2215$typographies$$);$G__67011__$1_G__67011__$2_G__67011__$3_G__67011__$4_changes$jscomp$146$$=
$APP.$app$common$files$changes_builder$set_undo_group$$($G__67011__$1_G__67011__$2_G__67011__$3_G__67011__$4_changes$jscomp$146$$,$undo_group$jscomp$5$$);$G__67011__$1_G__67011__$2_G__67011__$3_G__67011__$4_changes$jscomp$146$$=$G__67011__$5_sync_components_QMARK_$$?$app$common$logic$libraries$generate_sync_library$$($G__67011__$1_G__67011__$2_G__67011__$3_G__67011__$4_changes$jscomp$146$$,$file_id$jscomp$87$$,$APP.$cljs$cst$1638$components$$,$asset_id$jscomp$8$$,$library_id$jscomp$30$$,$libraries$jscomp$56$$,
$current_file_id$jscomp$5$$):$G__67011__$1_G__67011__$2_G__67011__$3_G__67011__$4_changes$jscomp$146$$;$G__67011__$1_G__67011__$2_G__67011__$3_G__67011__$4_changes$jscomp$146$$=$G__67011__$6_sync_colors_QMARK_$$?$app$common$logic$libraries$generate_sync_library$$($G__67011__$1_G__67011__$2_G__67011__$3_G__67011__$4_changes$jscomp$146$$,$file_id$jscomp$87$$,$APP.$cljs$cst$2212$colors$$,$asset_id$jscomp$8$$,$library_id$jscomp$30$$,$libraries$jscomp$56$$,$current_file_id$jscomp$5$$):$G__67011__$1_G__67011__$2_G__67011__$3_G__67011__$4_changes$jscomp$146$$;
$G__67011__$1_G__67011__$2_G__67011__$3_G__67011__$4_changes$jscomp$146$$=$asset_type$jscomp$8_sync_typographies_QMARK_$$?$app$common$logic$libraries$generate_sync_library$$($G__67011__$1_G__67011__$2_G__67011__$3_G__67011__$4_changes$jscomp$146$$,$file_id$jscomp$87$$,$APP.$cljs$cst$2215$typographies$$,$asset_id$jscomp$8$$,$library_id$jscomp$30$$,$libraries$jscomp$56$$,$current_file_id$jscomp$5$$):$G__67011__$1_G__67011__$2_G__67011__$3_G__67011__$4_changes$jscomp$146$$;$G__67011__$5_sync_components_QMARK_$$=
$G__67011__$5_sync_components_QMARK_$$?$app$common$logic$libraries$generate_sync_file$$($G__67011__$1_G__67011__$2_G__67011__$3_G__67011__$4_changes$jscomp$146$$,$file_id$jscomp$87$$,$APP.$cljs$cst$1638$components$$,$asset_id$jscomp$8$$,$library_id$jscomp$30$$,$libraries$jscomp$56$$,$current_file_id$jscomp$5$$):$G__67011__$1_G__67011__$2_G__67011__$3_G__67011__$4_changes$jscomp$146$$;$G__67011__$6_sync_colors_QMARK_$$=$G__67011__$6_sync_colors_QMARK_$$?$app$common$logic$libraries$generate_sync_file$$($G__67011__$5_sync_components_QMARK_$$,
$file_id$jscomp$87$$,$APP.$cljs$cst$2212$colors$$,$asset_id$jscomp$8$$,$library_id$jscomp$30$$,$libraries$jscomp$56$$,$current_file_id$jscomp$5$$):$G__67011__$5_sync_components_QMARK_$$;return $asset_type$jscomp$8_sync_typographies_QMARK_$$?$app$common$logic$libraries$generate_sync_file$$($G__67011__$6_sync_colors_QMARK_$$,$file_id$jscomp$87$$,$APP.$cljs$cst$2215$typographies$$,$asset_id$jscomp$8$$,$library_id$jscomp$30$$,$libraries$jscomp$56$$,$current_file_id$jscomp$5$$):$G__67011__$6_sync_colors_QMARK_$$};
$app$common$logic$libraries$generate_duplicate_flows$$=function($changes$jscomp$149$$,$shapes$jscomp$43$$,$page$jscomp$58$$,$ids_map$jscomp$13$$){var $flows$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$58$$,$APP.$cljs$cst$2056$flows$$),$unames$jscomp$2$$=$APP.$cljs$core$volatile_BANG_$$($APP.$app$common$files$helpers$get_used_names$$($APP.$cljs$core$vals$$($flows$jscomp$4$$)));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$49$$,
$flow_id$jscomp$1_frame_id$jscomp$43$$){var $name$jscomp$289$$=$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$("Flow",$APP.$cljs$core$_deref$$($unames$jscomp$2$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1629$immediate_suffix_QMARK_$$,!0])),$frame_id__$1$jscomp$7_new_flow$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ids_map$jscomp$13$$,$flow_id$jscomp$1_frame_id$jscomp$43$$);$flow_id$jscomp$1_frame_id$jscomp$43$$=
$APP.$app$common$uuid$next$$();$frame_id__$1$jscomp$7_new_flow$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$flow_id$jscomp$1_frame_id$jscomp$43$$,$APP.$cljs$cst$725$name$$,$name$jscomp$289$$,$APP.$cljs$cst$2053$starting_frame$$,$frame_id__$1$jscomp$7_new_flow$$],null);$unames$jscomp$2$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($unames$jscomp$2$$.$cljs$core$IDeref$_deref$arity$1$(null),$name$jscomp$289$$));
return $app$common$files$changes_builder$set_flow$$($APP.$app$common$files$changes_builder$with_page$$($changes__$1$jscomp$49$$,$page$jscomp$58$$),$flow_id$jscomp$1_frame_id$jscomp$43$$,$frame_id__$1$jscomp$7_new_flow$$)},$changes$jscomp$149$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$page$get_frame_flow$$,$flows$jscomp$4$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,$shapes$jscomp$43$$))))};
$app$common$logic$libraries$generate_duplicate_guides$$=function($changes$jscomp$150$$,$frames$jscomp$11_shapes$jscomp$44$$,$page$jscomp$59$$,$ids_map$jscomp$14$$,$delta$jscomp$24$$){var $guides$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$59$$,$APP.$cljs$cst$2057$guides$$);$frames$jscomp$11_shapes$jscomp$44$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,$frames$jscomp$11_shapes$jscomp$44$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$50$$,
$frame$jscomp$16$$){var $new_id$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ids_map$jscomp$14$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$16$$)),$new_frame$$=$app$common$geom$shapes$transforms$move$$($frame$jscomp$16$$,$delta$jscomp$24$$);return $APP.$cljs$core$reduce_kv$$(function($changes__$2$jscomp$24$$,$_$jscomp$1873_guide_id$jscomp$1$$,$guide$jscomp$1_guide__$1$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$16$$),
$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$1_guide__$1$$))){$_$jscomp$1873_guide_id$jscomp$1$$=$APP.$app$common$uuid$next$$();var $position$jscomp$68$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2054$axis$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$1_guide__$1$$),$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$1_guide__$1$$)+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($new_frame$$)-
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$16$$)):$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$1_guide__$1$$)+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($new_frame$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$16$$));$guide$jscomp$1_guide__$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$_$jscomp$1873_guide_id$jscomp$1$$,$APP.$cljs$cst$1607$frame_id$$,$new_id$jscomp$10$$,
$APP.$cljs$cst$1676$position$$,$position$jscomp$68$$,$APP.$cljs$cst$2054$axis$$,$APP.$cljs$cst$2054$axis$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$1_guide__$1$$)],null);return $APP.$app$common$files$changes_builder$set_guide$$($changes__$2$jscomp$24$$,$_$jscomp$1873_guide_id$jscomp$1$$,$guide$jscomp$1_guide__$1$$)}return $changes__$2$jscomp$24$$},$changes__$1$jscomp$50$$,$guides$jscomp$3$$)},$APP.$app$common$files$changes_builder$with_page$$($changes$jscomp$150$$,$page$jscomp$59$$),$frames$jscomp$11_shapes$jscomp$44$$)};
$app$common$logic$libraries$duplicate_variant$$=function($changes$jscomp$151_shape$jscomp$432$$,$JSCompiler_temp_const$jscomp$10846_library$jscomp$22$$,$G__67025__$2$jscomp$inline_12354_component$jscomp$70$$,$base_pos_new_component_id$jscomp$2$$,$JSCompiler_inline_result$jscomp$10847_parent$jscomp$217$$,$G__67025__$1$jscomp$inline_12353_changes__$1$jscomp$51_page_id$jscomp$101_vec__67020$$,$into_new_variant_QMARK_$$,$new_component_file$jscomp$2$$){var $component_page$jscomp$6_objects$jscomp$293_value$jscomp$541$$=
$APP.$app$common$types$pages_list$get_page$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10846_library$jscomp$22$$),$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($G__67025__$2$jscomp$inline_12354_component$jscomp$70$$));$component_page$jscomp$6_objects$jscomp$293_value$jscomp$541$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component_page$jscomp$6_objects$jscomp$293_value$jscomp$541$$);var $component_shape$jscomp$4_delta$jscomp$25_orig_pos$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component_page$jscomp$6_objects$jscomp$293_value$jscomp$541$$,$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($G__67025__$2$jscomp$inline_12354_component$jscomp$70$$));$component_shape$jscomp$4_delta$jscomp$25_orig_pos$jscomp$2$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$jscomp$4_delta$jscomp$25_orig_pos$jscomp$2$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$jscomp$4_delta$jscomp$25_orig_pos$jscomp$2$$));
$component_shape$jscomp$4_delta$jscomp$25_orig_pos$jscomp$2$$=$APP.$app$common$geom$point$subtract$$($base_pos_new_component_id$jscomp$2$$,$component_shape$jscomp$4_delta$jscomp$25_orig_pos$jscomp$2$$);$base_pos_new_component_id$jscomp$2$$=$APP.$app$common$uuid$next$$();$G__67025__$1$jscomp$inline_12353_changes__$1$jscomp$51_page_id$jscomp$101_vec__67020$$=$APP.$app$common$logic$libraries$generate_duplicate_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($changes$jscomp$151_shape$jscomp$432$$,
$JSCompiler_temp_const$jscomp$10846_library$jscomp$22$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__67025__$2$jscomp$inline_12354_component$jscomp$70$$),$base_pos_new_component_id$jscomp$2$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$3179$apply_changes_local_library_QMARK_$$,!0,$cljs$cst$2634$delta$$,$component_shape$jscomp$4_delta$jscomp$25_orig_pos$jscomp$2$$,$cljs$cst$3529$new_variant_id$$,$APP.$cljs$core$truth_$$($into_new_variant_QMARK_$$)?
null:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10847_parent$jscomp$217$$),$APP.$cljs$cst$2043$page_id$$,$G__67025__$1$jscomp$inline_12353_changes__$1$jscomp$51_page_id$jscomp$101_vec__67020$$,$cljs$cst$3527$new_component_file$$,$new_component_file$jscomp$2$$],null)]));$changes$jscomp$151_shape$jscomp$432$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67025__$1$jscomp$inline_12353_changes__$1$jscomp$51_page_id$jscomp$101_vec__67020$$,0,
null);$G__67025__$1$jscomp$inline_12353_changes__$1$jscomp$51_page_id$jscomp$101_vec__67020$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67025__$1$jscomp$inline_12353_changes__$1$jscomp$51_page_id$jscomp$101_vec__67020$$,1,null);$component_page$jscomp$6_objects$jscomp$293_value$jscomp$541$$=$APP.$cljs$core$truth_$$($into_new_variant_QMARK_$$)?["Value ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$count$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($APP.$app$common$files$variant$extract_properties_values$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10846_library$jscomp$22$$),
$component_page$jscomp$6_objects$jscomp$293_value$jscomp$541$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10847_parent$jscomp$217$$)))))+1)].join(""):null;$JSCompiler_temp_const$jscomp$10846_library$jscomp$22$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;$G__67025__$1$jscomp$inline_12353_changes__$1$jscomp$51_page_id$jscomp$101_vec__67020$$=$APP.$cljs$core$truth_$$($into_new_variant_QMARK_$$)?$app$common$logic$variant_properties$generate_make_shapes_variant$$($G__67025__$1$jscomp$inline_12353_changes__$1$jscomp$51_page_id$jscomp$101_vec__67020$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$changes$jscomp$151_shape$jscomp$432$$],null),$JSCompiler_inline_result$jscomp$10847_parent$jscomp$217$$):$G__67025__$1$jscomp$inline_12353_changes__$1$jscomp$51_page_id$jscomp$101_vec__67020$$;$G__67025__$2$jscomp$inline_12354_component$jscomp$70$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($into_new_variant_QMARK_$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($G__67025__$2$jscomp$inline_12354_component$jscomp$70$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10847_parent$jscomp$217$$)):$into_new_variant_QMARK_$$)?$app$common$logic$variant_properties$generate_update_property_value$$($G__67025__$1$jscomp$inline_12353_changes__$1$jscomp$51_page_id$jscomp$101_vec__67020$$,$base_pos_new_component_id$jscomp$2$$,$APP.$cljs$core$count$$($APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($G__67025__$2$jscomp$inline_12354_component$jscomp$70$$))-1,$component_page$jscomp$6_objects$jscomp$293_value$jscomp$541$$):
$G__67025__$1$jscomp$inline_12353_changes__$1$jscomp$51_page_id$jscomp$101_vec__67020$$;$JSCompiler_inline_result$jscomp$10847_parent$jscomp$217$$=$APP.$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$04$$($G__67025__$2$jscomp$inline_12354_component$jscomp$70$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10847_parent$jscomp$217$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$changes$jscomp$151_shape$jscomp$432$$],null),0);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$10846_library$jscomp$22$$,[$changes$jscomp$151_shape$jscomp$432$$,$JSCompiler_inline_result$jscomp$10847_parent$jscomp$217$$],null)};
$app$common$logic$libraries$generate_duplicate_component_change$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($changes$jscomp$152$$,$objects$jscomp$294_vec__67044$$,$page$jscomp$60$$,$main$jscomp$1$$,$parent_id$jscomp$43$$,$frame_id$jscomp$44$$,$delta$jscomp$26$$,$libraries$jscomp$59$$,$library_data$jscomp$27$$,$ids_map$jscomp$15$$,$map__67043__$1_new_component_file$jscomp$3_p__67042$$){function $restore_component$$(){var $map__67048_shape$jscomp$433$$=$APP.$app$common$logic$libraries$prepare_restore_component$cljs$0core$0IFn$0_invoke$0arity$08$$($changes$jscomp$152$$,
$library_data$jscomp$27$$,$component_id$jscomp$44$$,$page$jscomp$60$$,$pos$jscomp$100$$,$main_id$jscomp$5$$,$parent_id$jscomp$43$$,$frame_id$jscomp$44$$),$changes__$1$jscomp$53_map__67048__$1$$=$APP.$cljs$core$__destructure_map$$($map__67048_shape$jscomp$433$$);$map__67048_shape$jscomp$433$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes__$1$jscomp$53_map__67048__$1$$,$APP.$cljs$cst$1811$shape$$);$changes__$1$jscomp$53_map__67048__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes__$1$jscomp$53_map__67048__$1$$,
$APP.$cljs$cst$3131$changes$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$map__67048_shape$jscomp$433$$,$changes__$1$jscomp$53_map__67048__$1$$],null)}$map__67043__$1_new_component_file$jscomp$3_p__67042$$=$APP.$cljs$core$__destructure_map$$($map__67043__$1_new_component_file$jscomp$3_p__67042$$);$map__67043__$1_new_component_file$jscomp$3_p__67042$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67043__$1_new_component_file$jscomp$3_p__67042$$,
$cljs$cst$3527$new_component_file$$);var $main_id$jscomp$5$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($main$jscomp$1$$),$component_id$jscomp$44$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($main$jscomp$1$$),$source_file_id$$=$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($main$jscomp$1$$),$component$jscomp$71$$=$APP.$app$common$types$file$get_component$$($libraries$jscomp$59$$,$source_file_id$$,$component_id$jscomp$44$$),$pos$jscomp$100$$=
function(){var $$$jscomp$18$$=$app$common$geom$shapes$transforms$move$$($main$jscomp$1$$,$delta$jscomp$26$$);return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($$$jscomp$18$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($$$jscomp$18$$))}(),$parent$jscomp$218$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$294_vec__67044$$,$parent_id$jscomp$43$$),$in_variant_container_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($ids_map$jscomp$15$$,
$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($main$jscomp$1$$));$objects$jscomp$294_vec__67044$$=$component$jscomp$71$$==null?$restore_component$$():$APP.$app$common$types$component$is_variant_QMARK_$$($main$jscomp$1$$)&&$in_variant_container_QMARK_$$?$app$common$logic$libraries$duplicate_variant$$($changes$jscomp$152$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$59$$,$source_file_id$$),$component$jscomp$71$$,$pos$jscomp$100$$,$parent$jscomp$218$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$60$$),
!1,$map__67043__$1_new_component_file$jscomp$3_p__67042$$):$APP.$cljs$core$truth_$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($parent$jscomp$218$$))?$app$common$logic$libraries$duplicate_variant$$($changes$jscomp$152$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$59$$,$source_file_id$$),$component$jscomp$71$$,$pos$jscomp$100$$,$parent$jscomp$218$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$60$$),!0,$map__67043__$1_new_component_file$jscomp$3_p__67042$$):
$app$common$logic$libraries$generate_instantiate_component$cljs$0core$0IFn$0_invoke$0arity$012$$($changes$jscomp$152$$,$objects$jscomp$294_vec__67044$$,$source_file_id$$,$component_id$jscomp$44$$,$pos$jscomp$100$$,$page$jscomp$60$$,$libraries$jscomp$59$$,$main_id$jscomp$5$$,$parent_id$jscomp$43$$,$frame_id$jscomp$44$$,$ids_map$jscomp$15$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$294_vec__67044$$,0,null);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$294_vec__67044$$,
1,null)};
$app$common$logic$libraries$generate_duplicate_shape_change$cljs$0core$0IFn$0_invoke$0arity$019$$=function($changes$jscomp$155$$,$objects$jscomp$297$$,$page$jscomp$63$$,$unames$jscomp$5$$,$update_unames_BANG_$jscomp$2$$,$ids$jscomp$58$$,$ids_map$jscomp$18$$,$obj$jscomp$202$$,$delta$jscomp$29$$,$changes__$1$jscomp$54_changes__$2$jscomp$25_level_delta$jscomp$2_new_obj$jscomp$3$$,$libraries$jscomp$62$$,$library_data$jscomp$30$$,$file_id$jscomp$90$$,$frame_id$jscomp$45$$,$is_component_main_QMARK__parent_id$jscomp$44$$,$duplicating_component_QMARK_$$,
$child_QMARK_$jscomp$2$$,$remove_swap_slot_QMARK_$$,$variant_props$jscomp$2$$){function $regenerate_component$$($changes__$1$jscomp$55_vec__67058$$,$shape$jscomp$434$$){$changes__$1$jscomp$55_vec__67058$$=$app$common$logic$libraries$generate_add_component_changes$$($changes__$1$jscomp$55_vec__67058$$,$shape$jscomp$434$$,$objects$jscomp$297$$,$file_id$jscomp$90$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$63$$),$variant_props$jscomp$2$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$1$jscomp$55_vec__67058$$,
0,null);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$1$jscomp$55_vec__67058$$,1,null)}if($obj$jscomp$202$$==null)return $changes$jscomp$155$$;if($APP.$cljs$core$truth_$$($app$common$types$file$is_main_of_known_component_QMARK_$$($obj$jscomp$202$$,$libraries$jscomp$62$$)))return $app$common$logic$libraries$generate_duplicate_component_change$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($changes$jscomp$155$$,$objects$jscomp$297$$,$page$jscomp$63$$,$obj$jscomp$202$$,$is_component_main_QMARK__parent_id$jscomp$44$$,
$frame_id$jscomp$45$$,$delta$jscomp$29$$,$libraries$jscomp$62$$,$library_data$jscomp$30$$,$ids_map$jscomp$18$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3527$new_component_file$$,$file_id$jscomp$90$$],null)]));var $frame_QMARK_$jscomp$1$$=$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$202$$),$group_QMARK_$jscomp$1$$=$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$202$$),
$bool_QMARK_$jscomp$1$$=$APP.$app$common$files$helpers$bool_shape_QMARK_$$($obj$jscomp$202$$),$new_id$jscomp$11$$=function(){var $G__67055$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$202$$);return $ids_map$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$?$ids_map$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$($G__67055$$):$ids_map$jscomp$18$$($G__67055$$)}(),$parent_id__$1$jscomp$6$$=$APP.$cljs$core$truth_$$($is_component_main_QMARK__parent_id$jscomp$44$$)?$is_component_main_QMARK__parent_id$jscomp$44$$:
$frame_id$jscomp$45$$,$parent$jscomp$219$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$297$$,$parent_id__$1$jscomp$6$$),$name$jscomp$290$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$202$$),$is_component_root_QMARK_$$=function(){var $or__5025__auto__$jscomp$676_or__5025__auto____$1$jscomp$86$$=$cljs$cst$3542$saved_component_root$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$202$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$676_or__5025__auto____$1$jscomp$86$$))return $or__5025__auto__$jscomp$676_or__5025__auto____$1$jscomp$86$$;
$or__5025__auto__$jscomp$676_or__5025__auto____$1$jscomp$86$$=$cljs$cst$3543$saved_component_root_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$202$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$676_or__5025__auto____$1$jscomp$86$$)?$or__5025__auto__$jscomp$676_or__5025__auto____$1$jscomp$86$$:$APP.$app$common$types$component$instance_root_QMARK_$$($obj$jscomp$202$$)}(),$duplicating_component_QMARK___$1$$=$APP.$cljs$core$truth_$$($duplicating_component_QMARK_$$)?$duplicating_component_QMARK_$$:
$APP.$app$common$types$component$instance_head_QMARK_$$($obj$jscomp$202$$);$is_component_main_QMARK__parent_id$jscomp$44$$=$APP.$app$common$types$component$main_instance_QMARK_$$($obj$jscomp$202$$);var $subinstance_head_QMARK_$$=$app$common$types$component$subinstance_head_QMARK_$$($obj$jscomp$202$$),$instance_root_QMARK_$$=$APP.$app$common$types$component$instance_root_QMARK_$$($obj$jscomp$202$$),$into_component_QMARK_$$=$APP.$cljs$core$truth_$$($duplicating_component_QMARK___$1$$)?$APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$297$$,
$parent$jscomp$219$$):$duplicating_component_QMARK___$1$$,$level_delta__$1$$=$changes__$1$jscomp$54_changes__$2$jscomp$25_level_delta$jscomp$2_new_obj$jscomp$3$$!=null?$changes__$1$jscomp$54_changes__$2$jscomp$25_level_delta$jscomp$2_new_obj$jscomp$3$$:$app$common$types$container$get_nesting_level_delta$$($objects$jscomp$297$$,$obj$jscomp$202$$,$parent$jscomp$219$$),$new_shape_ref$$=$app$common$types$file$advance_shape_ref$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(null,$page$jscomp$63$$,$libraries$jscomp$62$$,
$obj$jscomp$202$$,$level_delta__$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0],null)]));$changes__$1$jscomp$54_changes__$2$jscomp$25_level_delta$jscomp$2_new_obj$jscomp$3$$=function(){var $G__67061$$=function(){var $G__67062$$=function(){var $G__67063$$=$APP.$app$common$data$update_when$$($app$common$geom$shapes$move$$(function(){var $G__67064$$=function(){var $G__67065_G__67066$jscomp$inline_14842_G__67067$jscomp$inline_14843_G__67068$jscomp$inline_14848_JSCompiler_temp_const$jscomp$inline_14844$$=
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$;var $G__67069$jscomp$inline_14846_JSCompiler_inline_result$jscomp$inline_14845$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($obj$jscomp$202$$,$APP.$cljs$cst$266$id$$,$new_id$jscomp$11$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,$name$jscomp$290$$,$APP.$cljs$cst$1619$parent_id$$,$parent_id__$1$jscomp$6$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$45$$]));var $and__5023__auto__$jscomp$inline_14847$$=
!$instance_root_QMARK_$$;$G__67069$jscomp$inline_14846_JSCompiler_inline_result$jscomp$inline_14845$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_14847$$?$subinstance_head_QMARK_$$?$remove_swap_slot_QMARK_$$:$subinstance_head_QMARK_$$:$and__5023__auto__$jscomp$inline_14847$$)?$app$common$types$component$remove_swap_slot$$($G__67069$jscomp$inline_14846_JSCompiler_inline_result$jscomp$inline_14845$$):$G__67069$jscomp$inline_14846_JSCompiler_inline_result$jscomp$inline_14845$$;$G__67065_G__67066$jscomp$inline_14842_G__67067$jscomp$inline_14843_G__67068$jscomp$inline_14848_JSCompiler_temp_const$jscomp$inline_14844$$=
$G__67065_G__67066$jscomp$inline_14842_G__67067$jscomp$inline_14843_G__67068$jscomp$inline_14848_JSCompiler_temp_const$jscomp$inline_14844$$.call($APP.$cljs$core$dissoc$$,$G__67069$jscomp$inline_14846_JSCompiler_inline_result$jscomp$inline_14845$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2964$use_for_thumbnail$$]));$G__67065_G__67066$jscomp$inline_14842_G__67067$jscomp$inline_14843_G__67068$jscomp$inline_14848_JSCompiler_temp_const$jscomp$inline_14844$$=
$APP.$cljs$core$not$$($is_component_root_QMARK_$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__67065_G__67066$jscomp$inline_14842_G__67067$jscomp$inline_14843_G__67068$jscomp$inline_14848_JSCompiler_temp_const$jscomp$inline_14844$$,$APP.$cljs$cst$2045$main_instance$$):$G__67065_G__67066$jscomp$inline_14842_G__67067$jscomp$inline_14843_G__67068$jscomp$inline_14848_JSCompiler_temp_const$jscomp$inline_14844$$;$G__67065_G__67066$jscomp$inline_14842_G__67067$jscomp$inline_14843_G__67068$jscomp$inline_14848_JSCompiler_temp_const$jscomp$inline_14844$$=
$APP.$cljs$core$truth_$$($into_component_QMARK_$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__67065_G__67066$jscomp$inline_14842_G__67067$jscomp$inline_14843_G__67068$jscomp$inline_14848_JSCompiler_temp_const$jscomp$inline_14844$$,$APP.$cljs$cst$2044$component_root$$):$G__67065_G__67066$jscomp$inline_14842_G__67067$jscomp$inline_14843_G__67068$jscomp$inline_14848_JSCompiler_temp_const$jscomp$inline_14844$$;$G__67065_G__67066$jscomp$inline_14842_G__67067$jscomp$inline_14843_G__67068$jscomp$inline_14848_JSCompiler_temp_const$jscomp$inline_14844$$=
$APP.$app$common$types$component$instance_head_QMARK_$$($obj$jscomp$202$$)&&$APP.$cljs$core$not$$($into_component_QMARK_$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__67065_G__67066$jscomp$inline_14842_G__67067$jscomp$inline_14843_G__67068$jscomp$inline_14848_JSCompiler_temp_const$jscomp$inline_14844$$,$APP.$cljs$cst$2044$component_root$$,!0):$G__67065_G__67066$jscomp$inline_14842_G__67067$jscomp$inline_14843_G__67068$jscomp$inline_14848_JSCompiler_temp_const$jscomp$inline_14844$$;
return $frame_QMARK_$jscomp$1$$||$group_QMARK_$jscomp$1$$||$bool_QMARK_$jscomp$1$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__67065_G__67066$jscomp$inline_14842_G__67067$jscomp$inline_14843_G__67068$jscomp$inline_14848_JSCompiler_temp_const$jscomp$inline_14844$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$):$G__67065_G__67066$jscomp$inline_14842_G__67067$jscomp$inline_14843_G__67068$jscomp$inline_14848_JSCompiler_temp_const$jscomp$inline_14844$$}();return $new_shape_ref$$!=
null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_shape_ref$$,$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$202$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__67064$$,$APP.$cljs$cst$2047$shape_ref$$,$new_shape_ref$$):$G__67064$$}(),$delta$jscomp$29$$),$APP.$cljs$cst$2051$interactions$$,function($p1__67049_SHARP_$$){return $app$common$types$shape$interactions$remap_interactions$$($p1__67049_SHARP_$$,$ids_map$jscomp$18$$,$objects$jscomp$297$$)});
return $APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$202$$)?$APP.$app$common$types$shape$layout$remap_grid_cells$$($G__67063$$,$ids_map$jscomp$18$$):$G__67063$$}();return $APP.$cljs$core$truth_$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($parent$jscomp$219$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__67062$$,$APP.$cljs$cst$2000$variant_id$$,$parent_id__$1$jscomp$6$$):$G__67062$$}();return $APP.$app$common$types$component$is_variant_QMARK_$$($obj$jscomp$202$$)&&
$APP.$cljs$core$not$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($parent$jscomp$219$$))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__67061$$,$APP.$cljs$cst$725$name$$,$app$common$types$variant$variant_name_to_name$$($obj$jscomp$202$$)),$APP.$cljs$cst$2000$variant_id$$):$G__67061$$}();var $new_obj__$1$$=$APP.$cljs$core$not$$($duplicating_component_QMARK___$1$$)?$app$common$types$component$detach_shape$$($changes__$1$jscomp$54_changes__$2$jscomp$25_level_delta$jscomp$2_new_obj$jscomp$3$$):
$changes__$1$jscomp$54_changes__$2$jscomp$25_level_delta$jscomp$2_new_obj$jscomp$3$$;$changes__$1$jscomp$54_changes__$2$jscomp$25_level_delta$jscomp$2_new_obj$jscomp$3$$=function(){var $G__67072$$=$app$common$files$changes_builder$amend_last_change$$($app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$155$$,$new_obj__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2556$ignore_touched$$,$APP.$cljs$core$truth_$$($duplicating_component_QMARK___$1$$)?
$child_QMARK_$jscomp$2$$:$duplicating_component_QMARK___$1$$],null)),function($p1__67050_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__67050_SHARP_$$,$APP.$cljs$cst$3531$old_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$202$$))});return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$297$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$202$$)))?
$APP.$app$common$files$changes_builder$reorder_grid_children$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($G__67072$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$202$$)],null),$APP.$app$common$types$shape$layout$assign_cells$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)),
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$202$$)],null)):$G__67072$$}();$changes__$1$jscomp$54_changes__$2$jscomp$25_level_delta$jscomp$2_new_obj$jscomp$3$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_component_root_QMARK_$$)?$is_component_main_QMARK__parent_id$jscomp$44$$:$is_component_root_QMARK_$$)?$regenerate_component$$($changes__$1$jscomp$54_changes__$2$jscomp$25_level_delta$jscomp$2_new_obj$jscomp$3$$,
$new_obj__$1$$):$changes__$1$jscomp$54_changes__$2$jscomp$25_level_delta$jscomp$2_new_obj$jscomp$3$$;var $page_SINGLEQUOTE_$$=$app$common$types$shape_tree$add_shape$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_obj__$1$$),$new_obj__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1631$objects$$,$objects$jscomp$297$$],null),$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($new_obj__$1$$),$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($new_obj__$1$$),
null,!0);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$3$jscomp$7$$,$child$jscomp$79$$){return $app$common$logic$libraries$generate_duplicate_shape_change$cljs$0core$0IFn$0_invoke$0arity$019$$($changes__$3$jscomp$7$$,$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page_SINGLEQUOTE_$$),$page$jscomp$63$$,$unames$jscomp$5$$,$update_unames_BANG_$jscomp$2$$,$ids$jscomp$58$$,$ids_map$jscomp$18$$,$child$jscomp$79$$,$delta$jscomp$29$$,$level_delta__$1$$,
$libraries$jscomp$62$$,$library_data$jscomp$30$$,$file_id$jscomp$90$$,$frame_QMARK_$jscomp$1$$?$new_id$jscomp$11$$:$frame_id$jscomp$45$$,$new_id$jscomp$11$$,$duplicating_component_QMARK___$1$$,!0,$APP.$cljs$core$truth_$$($remove_swap_slot_QMARK_$$)?!$subinstance_head_QMARK_$$&&!$instance_root_QMARK_$$:$remove_swap_slot_QMARK_$$,$variant_props$jscomp$2$$)},$changes__$1$jscomp$54_changes__$2$jscomp$25_level_delta$jscomp$2_new_obj$jscomp$3$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$297$$),
$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$202$$)))};
$APP.$app$common$logic$libraries$generate_duplicate_changes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($changes$jscomp$156_changes__$1$jscomp$56_changes__$2$jscomp$27$$,$all_objects$$,$page$jscomp$64$$,$ids$jscomp$59$$,$delta$jscomp$30$$,$libraries$jscomp$63$$,$library_data$jscomp$31$$,$file_id$jscomp$91$$,$map__67093__$1_p__67092_shapes$jscomp$45_shapes__$1$jscomp$5$$){function $update_unames_BANG_$jscomp$3$$($new_name$jscomp$15$$){return $unames$jscomp$6$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($unames$jscomp$6$$.$cljs$core$IDeref$_deref$arity$1$(null),
$new_name$jscomp$15$$))}$map__67093__$1_p__67092_shapes$jscomp$45_shapes__$1$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($map__67093__$1_p__67092_shapes$jscomp$45_shapes__$1$jscomp$5$$);var $variant_props$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67093__$1_p__67092_shapes$jscomp$45_shapes__$1$jscomp$5$$,$cljs$cst$3544$variant_props$$),$alt_duplication_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67093__$1_p__67092_shapes$jscomp$45_shapes__$1$jscomp$5$$,
$cljs$cst$3545$alt_duplication_QMARK_$$);$map__67093__$1_p__67092_shapes$jscomp$45_shapes__$1$jscomp$5$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($all_objects$$),$ids$jscomp$59$$);var $unames$jscomp$6$$=$APP.$cljs$core$volatile_BANG_$$($APP.$app$common$files$helpers$get_used_names$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$64$$))),$all_ids$jscomp$1_ids_map__$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__67075_SHARP_$$,
$p2__67076_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($p1__67075_SHARP_$$,$APP.$cljs$core$cons$$($p2__67076_SHARP_$$,$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($all_objects$$,$p2__67076_SHARP_$$)))},$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$ids$jscomp$59$$),$ids_map$jscomp$19$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__67077_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__67077_SHARP_$$,$APP.$app$common$uuid$next$$()],null)}),$all_ids$jscomp$1_ids_map__$1$$);$map__67093__$1_p__67092_shapes$jscomp$45_shapes__$1$jscomp$5$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($shape$jscomp$435$$){return $APP.$cljs$core$truth_$$($alt_duplication_QMARK_$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape$jscomp$435$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$app$common$uuid$zero$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1607$frame_id$$,
$APP.$app$common$uuid$zero$$])):$shape$jscomp$435$$},$map__67093__$1_p__67092_shapes$jscomp$45_shapes__$1$jscomp$5$$);$changes$jscomp$156_changes__$1$jscomp$56_changes__$2$jscomp$27$$=$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($changes$jscomp$156_changes__$1$jscomp$56_changes__$2$jscomp$27$$,$page$jscomp$64$$),$all_objects$$),$library_data$jscomp$31$$);$changes$jscomp$156_changes__$1$jscomp$56_changes__$2$jscomp$27$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__67078_SHARP_$$,$p2__67079_SHARP_$$){return $app$common$logic$libraries$generate_duplicate_shape_change$cljs$0core$0IFn$0_invoke$0arity$019$$($p1__67078_SHARP_$$,$all_objects$$,$page$jscomp$64$$,$unames$jscomp$6$$,$update_unames_BANG_$jscomp$3$$,$ids$jscomp$59$$,$ids_map$jscomp$19$$,$p2__67079_SHARP_$$,$delta$jscomp$30$$,null,$libraries$jscomp$63$$,$library_data$jscomp$31$$,$file_id$jscomp$91$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p2__67079_SHARP_$$),
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($p2__67079_SHARP_$$),!1,!1,!0,$variant_props$jscomp$3$$)},$changes$jscomp$156_changes__$1$jscomp$56_changes__$2$jscomp$27$$,$map__67093__$1_p__67092_shapes$jscomp$45_shapes__$1$jscomp$5$$);$all_ids$jscomp$1_ids_map__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__67080_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2610$add_obj$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__67080_SHARP_$$))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__67081_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3531$old_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__67081_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2611$obj$$.$cljs$core$IFn$_invoke$arity$1$($p1__67081_SHARP_$$))],null)})),$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$156_changes__$1$jscomp$56_changes__$2$jscomp$27$$));
return $app$common$logic$libraries$generate_duplicate_guides$$($app$common$logic$libraries$generate_duplicate_flows$$($changes$jscomp$156_changes__$1$jscomp$56_changes__$2$jscomp$27$$,$map__67093__$1_p__67092_shapes$jscomp$45_shapes__$1$jscomp$5$$,$page$jscomp$64$$,$all_ids$jscomp$1_ids_map__$1$$),$map__67093__$1_p__67092_shapes$jscomp$45_shapes__$1$jscomp$5$$,$page$jscomp$64$$,$all_ids$jscomp$1_ids_map__$1$$,$delta$jscomp$30$$)};
$APP.$app$common$logic$libraries$generate_duplicate_changes_update_indices$$=function($changes$jscomp$157$$,$objects$jscomp$298$$,$ids$jscomp$60_index_map$$){function $inc_indices$$($p__67098_result$jscomp$268$$,$index$jscomp$260_p__67099$$){var $offset$jscomp$170$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67098_result$jscomp$268$$,0,null);$p__67098_result$jscomp$268$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67098_result$jscomp$268$$,1,null);var $id$jscomp$467$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($index$jscomp$260_p__67099$$,0,null);$index$jscomp$260_p__67099$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($index$jscomp$260_p__67099$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$offset$jscomp$170$$+1,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p__67098_result$jscomp$268$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$id$jscomp$467$$,$index$jscomp$260_p__67099$$+$offset$jscomp$170$$],null))],null)}$ids$jscomp$60_index_map$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($index_map$jscomp$1$$,$id$jscomp$466$$){var $parent_id$jscomp$45$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$298$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$466$$,$APP.$cljs$cst$1619$parent_id$$],null)),$parent_index$$=$app$common$files$helpers$get_position_on_parent$$($objects$jscomp$298$$,
$id$jscomp$466$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($index_map$jscomp$1$$,$parent_id$jscomp$45$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$466$$,$parent_index$$],null))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$ids$jscomp$60_index_map$$);var $objects_indices$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$merge$$,
$APP.$cljs$core$vals$$($APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$(function($_$jscomp$1875$$,$entry$jscomp$47$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$second$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($inc_indices$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,
$entry$jscomp$47$$))))},$ids$jscomp$60_index_map$$)));return $app$common$files$changes_builder$amend_changes$$($changes$jscomp$157$$,function($change$jscomp$25$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($change$jscomp$25$$,$APP.$cljs$cst$1795$index$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects_indices$$,$APP.$cljs$cst$3531$old_id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$25$$)))})};
$app$main$data$workspace$collapse$expand_all_parents$$=function($ids$jscomp$61$$,$objects$jscomp$299$$){typeof $app$main$data$workspace$collapse$expand_all_parents_56078$$==="undefined"&&($app$main$data$workspace$collapse$expand_all_parents_56078$$=function($ids$jscomp$62$$,$objects$jscomp$300$$,$meta56079$$){this.ids=$ids$jscomp$62$$;this.objects=$objects$jscomp$300$$;this.$meta56079$=$meta56079$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$collapse$expand_all_parents_56078$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$collapse$expand_all_parents_56078$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3546$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_expand_all_parents$$},$app$main$data$workspace$collapse$expand_all_parents_56078$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56080$$,$meta56079__$1$$){return new $app$main$data$workspace$collapse$expand_all_parents_56078$$(this.ids,this.objects,$meta56079__$1$$)},
$app$main$data$workspace$collapse$expand_all_parents_56078$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56079$},$app$main$data$workspace$collapse$expand_all_parents_56078$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$collapse$expand_all_parents_56078$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1876$$,$state$jscomp$304$$){var $self__$jscomp$4097$$=this;return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$304$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$3547$expanded$$],null),function($expanded$jscomp$3$$){var $distinct_parents_flat_parents_non_root_parents_parents_seqs$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($x$jscomp$1170$$){return $APP.$app$common$files$helpers$get_parent_ids$$($self__$jscomp$4097$$.objects,$x$jscomp$1170$$)},$self__$jscomp$4097$$.ids);$distinct_parents_flat_parents_non_root_parents_parents_seqs$$=
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,$distinct_parents_flat_parents_non_root_parents_parents_seqs$$);$distinct_parents_flat_parents_non_root_parents_parents_seqs$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__56077_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__56077_SHARP_$$,$APP.$app$common$uuid$zero$$)},$distinct_parents_flat_parents_non_root_parents_parents_seqs$$);$distinct_parents_flat_parents_non_root_parents_parents_seqs$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$distinct_parents_flat_parents_non_root_parents_parents_seqs$$);return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$expanded$jscomp$3$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$468$$){return $APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$id$jscomp$468$$,
!0])},$distinct_parents_flat_parents_non_root_parents_parents_seqs$$))]))})});return new $app$main$data$workspace$collapse$expand_all_parents_56078$$($ids$jscomp$61$$,$objects$jscomp$299$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$collapse$toggle_collapse$$=function($id$jscomp$469$$){typeof $app$main$data$workspace$collapse$toggle_collapse_56089$$==="undefined"&&($app$main$data$workspace$collapse$toggle_collapse_56089$$=function($id$jscomp$470$$,$meta56090$$){this.id=$id$jscomp$470$$;this.$meta56090$=$meta56090$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$collapse$toggle_collapse_56089$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$collapse$toggle_collapse_56089$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3548$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_toggle_collapse$$},$app$main$data$workspace$collapse$toggle_collapse_56089$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56091$$,$meta56090__$1$$){return new $app$main$data$workspace$collapse$toggle_collapse_56089$$(this.id,$meta56090__$1$$)},$app$main$data$workspace$collapse$toggle_collapse_56089$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta56090$},$app$main$data$workspace$collapse$toggle_collapse_56089$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$collapse$toggle_collapse_56089$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1877$$,$state$jscomp$305$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$305$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$3547$expanded$$,this.id],null),$APP.$cljs$core$not$$)});return new $app$main$data$workspace$collapse$toggle_collapse_56089$$($id$jscomp$469$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$collapse$expand_collapse$$=function($id$jscomp$471$$){typeof $app$main$data$workspace$collapse$expand_collapse_56095$$==="undefined"&&($app$main$data$workspace$collapse$expand_collapse_56095$$=function($id$jscomp$472$$,$meta56096$$){this.id=$id$jscomp$472$$;this.$meta56096$=$meta56096$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$collapse$expand_collapse_56095$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$collapse$expand_collapse_56095$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3549$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_expand_collapse$$},$app$main$data$workspace$collapse$expand_collapse_56095$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56097$$,$meta56096__$1$$){return new $app$main$data$workspace$collapse$expand_collapse_56095$$(this.id,$meta56096__$1$$)},$app$main$data$workspace$collapse$expand_collapse_56095$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta56096$},$app$main$data$workspace$collapse$expand_collapse_56095$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$collapse$expand_collapse_56095$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1878$$,$state$jscomp$306$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$306$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$APP.$cljs$cst$3547$expanded$$,this.id],null),!0)});return new $app$main$data$workspace$collapse$expand_collapse_56095$$($id$jscomp$471$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$collapse$collapse_all$$=function(){typeof $app$main$data$workspace$collapse$collapse_all_56103$$==="undefined"&&($app$main$data$workspace$collapse$collapse_all_56103$$=function($meta56104$$){this.$meta56104$=$meta56104$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$collapse$collapse_all_56103$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$collapse$collapse_all_56103$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3550$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_collapse_all$$},$app$main$data$workspace$collapse$collapse_all_56103$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56105$$,$meta56104__$1$$){return new $app$main$data$workspace$collapse$collapse_all_56103$$($meta56104__$1$$)},$app$main$data$workspace$collapse$collapse_all_56103$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56104$},$app$main$data$workspace$collapse$collapse_all_56103$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$collapse$collapse_all_56103$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1879$$,$state$jscomp$307$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$307$$,$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3547$expanded$$)});return new $app$main$data$workspace$collapse$collapse_all_56103$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$collapse$expand_subtree$$=function($id$jscomp$473$$,$objects$jscomp$301$$){typeof $app$main$data$workspace$collapse$expand_subtree_56111$$==="undefined"&&($app$main$data$workspace$collapse$expand_subtree_56111$$=function($id$jscomp$474$$,$objects$jscomp$302$$,$meta56112$$){this.id=$id$jscomp$474$$;this.objects=$objects$jscomp$302$$;this.$meta56112$=$meta56112$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$collapse$expand_subtree_56111$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$collapse$expand_subtree_56111$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3551$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_expand_subtree$$},$app$main$data$workspace$collapse$expand_subtree_56111$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56113$$,$meta56112__$1$$){return new $app$main$data$workspace$collapse$expand_subtree_56111$$(this.id,this.objects,$meta56112__$1$$)},$app$main$data$workspace$collapse$expand_subtree_56111$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta56112$},$app$main$data$workspace$collapse$expand_subtree_56111$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$collapse$expand_subtree_56111$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1880_expansions_ids$jscomp$63$$,$state$jscomp$308$$){$_$jscomp$1880_expansions_ids$jscomp$63$$=$app$common$files$helpers$get_children_ids_with_self$$(this.objects,this.id);$_$jscomp$1880_expansions_ids$jscomp$63$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($descendant_id$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$descendant_id$$,!0],null)}),$_$jscomp$1880_expansions_ids$jscomp$63$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$308$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$3547$expanded$$],null),$APP.$cljs$core$merge$$,$_$jscomp$1880_expansions_ids$jscomp$63$$)});return new $app$main$data$workspace$collapse$expand_subtree_56111$$($id$jscomp$473$$,$objects$jscomp$301$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$path$state$get_path_id$$=function($state$jscomp$309$$){var $or__5025__auto__$jscomp$678$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$309$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2199$edition$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$678$$)?$or__5025__auto__$jscomp$678$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$309$$,
$APP.$cljs$cst$2189$workspace_drawing$$),$APP.$cljs$cst$2198$object$$),$APP.$cljs$cst$266$id$$)};
$app$main$data$workspace$path$state$get_path_location$$=function($var_args$jscomp$1194$$){for(var $args__5755__auto__$jscomp$217$$=[],$len__5749__auto___56176$$=arguments.length,$i__5750__auto___56177$$=0;;)if($i__5750__auto___56177$$<$len__5749__auto___56176$$)$args__5755__auto__$jscomp$217$$.push(arguments[$i__5750__auto___56177$$]),$i__5750__auto___56177$$+=1;else break;return $app$main$data$workspace$path$state$get_path_location$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$217$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$217$$.slice(1),0,null):null)};
$app$main$data$workspace$path$state$get_path_location$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($file_id$jscomp$92_state$jscomp$310$$,$ks$jscomp$59$$){var $temp__5823__auto__$jscomp$170$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$92_state$jscomp$310$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2199$edition$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$170$$)){var $page_id$jscomp$102$$=
$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$92_state$jscomp$310$$);$file_id$jscomp$92_state$jscomp$310$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$92_state$jscomp$310$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,$file_id$jscomp$92_state$jscomp$310$$,$APP.$cljs$cst$142$data$$,
$APP.$cljs$cst$1630$pages_index$$,$page_id$jscomp$102$$,$APP.$cljs$cst$1631$objects$$,$temp__5823__auto__$jscomp$170$$],null),$ks$jscomp$59$$)}return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$cst$2198$object$$],null),$ks$jscomp$59$$)};
$app$main$data$workspace$path$state$get_path$$=function($var_args$jscomp$1195$$){for(var $args__5755__auto__$jscomp$218$$=[],$len__5749__auto___56179$$=arguments.length,$i__5750__auto___56180$$=0;;)if($i__5750__auto___56180$$<$len__5749__auto___56179$$)$args__5755__auto__$jscomp$218$$.push(arguments[$i__5750__auto___56180$$]),$i__5750__auto___56180$$+=1;else break;return $APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$218$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$218$$.slice(1),0,null):null)};
$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($shape$jscomp$436_state$jscomp$311$$,$ks$jscomp$60$$){var $path_loc$$=$app$main$data$workspace$path$state$get_path_location$$($shape$jscomp$436_state$jscomp$311$$);$shape$jscomp$436_state$jscomp$311$$=$app$common$types$path$shape_to_path$convert_to_path$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$436_state$jscomp$311$$,$path_loc$$),$APP.$cljs$core$PersistentArrayMap$EMPTY$$);
return $APP.$cljs$core$empty_QMARK_$$($ks$jscomp$60$$)?$shape$jscomp$436_state$jscomp$311$$:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$436_state$jscomp$311$$,$ks$jscomp$60$$)};
$APP.$app$main$data$workspace$path$state$set_content$$=function($state$jscomp$312$$,$content$jscomp$159$$){var $path_loc$jscomp$1$$=$app$main$data$workspace$path$state$get_path_location$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$312$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]));return $APP.$cljs$core$assoc_in$$($state$jscomp$312$$,$path_loc$jscomp$1$$,$content$jscomp$159$$)};
$app$main$data$workspace$path$common$clean_edit_state$$=function($state$jscomp$313$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$313$$,$APP.$cljs$cst$3553$last_point$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3554$prev_handler$$,$APP.$cljs$cst$3555$drag_handler$$,$APP.$cljs$cst$3556$preview$$]))};
$APP.$app$main$data$workspace$path$common$finish_path$$=function(){typeof $app$main$data$workspace$path$common$finish_path_66050$$==="undefined"&&($app$main$data$workspace$path$common$finish_path_66050$$=function($meta66051$$){this.$meta66051$=$meta66051$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$common$finish_path_66050$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$common$finish_path_66050$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3557$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_common_SLASH_finish_path$$},$app$main$data$workspace$path$common$finish_path_66050$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66052$$,$meta66051__$1$$){return new $app$main$data$workspace$path$common$finish_path_66050$$($meta66051__$1$$)},$app$main$data$workspace$path$common$finish_path_66050$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66051$},$app$main$data$workspace$path$common$finish_path_66050$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$common$finish_path_66050$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1881_id$jscomp$475$$,$state$jscomp$314$$){$_$jscomp$1881_id$jscomp$475$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$314$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$314$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$1881_id$jscomp$475$$],null),$app$main$data$workspace$path$common$clean_edit_state$$),$app$main$data$workspace$path$state$get_path_location$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$314$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$])),$app$common$types$path$close_subpaths$$)});return new $app$main$data$workspace$path$common$finish_path_66050$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$edition$interrupt_QMARK_$$=function($e$jscomp$318$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$318$$,$APP.$cljs$cst$2169$interrupt$$)};
$APP.$app$main$data$workspace$edition$start_edition_mode$$=function($id$jscomp$476$$){typeof $app$main$data$workspace$edition$start_edition_mode_66094$$==="undefined"&&($app$main$data$workspace$edition$start_edition_mode_66094$$=function($id$jscomp$477$$,$meta66095$$){this.id=$id$jscomp$477$$;this.$meta66095$=$meta66095$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$edition$start_edition_mode_66094$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$edition$start_edition_mode_66094$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3558$app_DOT_main_DOT_data_DOT_workspace_DOT_edition_SLASH_start_edition_mode$$},$app$main$data$workspace$edition$start_edition_mode_66094$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66096$$,$meta66095__$1$$){return new $app$main$data$workspace$edition$start_edition_mode_66094$$(this.id,$meta66095__$1$$)},$app$main$data$workspace$edition$start_edition_mode_66094$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66095$},$app$main$data$workspace$edition$start_edition_mode_66094$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$edition$start_edition_mode_66094$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1882_objects$jscomp$303$$,$state$jscomp$315$$){$_$jscomp$1882_objects$jscomp$303$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$315$$);return $APP.$cljs$core$contains_QMARK_$$($_$jscomp$1882_objects$jscomp$303$$,
this.id)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$315$$,$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2199$edition$$,this.id),$APP.$cljs$cst$2240$workspace_grid_edition$$):$state$jscomp$315$$},$app$main$data$workspace$edition$start_edition_mode_66094$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$edition$start_edition_mode_66094$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1883$$,$___$1$jscomp$1192$$,$stream$jscomp$36$$){return $APP.$beicon$v2$core$map$$($APP.$app$main$data$workspace$edition$clear_edition_mode$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($app$main$data$workspace$edition$interrupt_QMARK_$$,$stream$jscomp$36$$)))});return new $app$main$data$workspace$edition$start_edition_mode_66094$$($id$jscomp$476$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$edition$clear_edition_mode$$=function(){typeof $app$main$data$workspace$edition$clear_edition_mode_66133$$==="undefined"&&($app$main$data$workspace$edition$clear_edition_mode_66133$$=function($meta66134$$){this.$meta66134$=$meta66134$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$edition$clear_edition_mode_66133$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$edition$clear_edition_mode_66133$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3559$app_DOT_main_DOT_data_DOT_workspace_DOT_edition_SLASH_clear_edition_mode$$},$app$main$data$workspace$edition$clear_edition_mode_66133$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66135$$,$meta66134__$1$$){return new $app$main$data$workspace$edition$clear_edition_mode_66133$$($meta66134__$1$$)},$app$main$data$workspace$edition$clear_edition_mode_66133$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66134$},$app$main$data$workspace$edition$clear_edition_mode_66133$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$edition$clear_edition_mode_66133$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1884$$,$state$jscomp$316$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$6$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$316$$,$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$dissoc$$,
$APP.$cljs$cst$2199$edition$$,$APP.$cljs$cst$1923$edit_path$$),$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$2197$tool$$,$APP.$cljs$cst$2198$object$$,$cljs$cst$3560$lock$$),$APP.$cljs$cst$2240$workspace_grid_edition$$),$APP.$cljs$cst$2224$workspace_wasm_editor_styles$$)},$app$main$data$workspace$edition$clear_edition_mode_66133$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$edition$clear_edition_mode_66133$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1885_id$jscomp$478$$,$state$jscomp$317$$){$_$jscomp$1885_id$jscomp$478$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$317$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2199$edition$$],null));return $APP.$beicon$v2$core$concat$$($_$jscomp$1885_id$jscomp$478$$!=null?$APP.$app$main$data$workspace$path$common$finish_path$$():null)},$app$main$data$workspace$edition$clear_edition_mode_66133$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$edition$clear_edition_mode_66133$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1886_cause53515$jscomp$inline_6361_fn_53514$jscomp$inline_6360$$,$code__52999__auto__$jscomp$inline_6364_code_num__52998__auto__$jscomp$inline_6363_read_code_fn__52997__auto__$jscomp$inline_6362_state$jscomp$318$$){if($APP.$app$main$features$active_feature_QMARK_$$($code__52999__auto__$jscomp$inline_6364_code_num__52998__auto__$jscomp$inline_6363_read_code_fn__52997__auto__$jscomp$inline_6362_state$jscomp$318$$,
"text-editor-wasm/v1")){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){$_$jscomp$1886_cause53515$jscomp$inline_6361_fn_53514$jscomp$inline_6360$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_dispose;try{$_$jscomp$1886_cause53515$jscomp$inline_6361_fn_53514$jscomp$inline_6360$$()}catch($e53516$jscomp$inline_6366$$){$_$jscomp$1886_cause53515$jscomp$inline_6361_fn_53514$jscomp$inline_6360$$=$e53516$jscomp$inline_6366$$;$code__52999__auto__$jscomp$inline_6364_code_num__52998__auto__$jscomp$inline_6363_read_code_fn__52997__auto__$jscomp$inline_6362_state$jscomp$318$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$inline_6364_code_num__52998__auto__$jscomp$inline_6363_read_code_fn__52997__auto__$jscomp$inline_6362_state$jscomp$318$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_6364_code_num__52998__auto__$jscomp$inline_6363_read_code_fn__52997__auto__$jscomp$inline_6362_state$jscomp$318$$)?$code__52999__auto__$jscomp$inline_6364_code_num__52998__auto__$jscomp$inline_6363_read_code_fn__52997__auto__$jscomp$inline_6362_state$jscomp$318$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$inline_6364_code_num__52998__auto__$jscomp$inline_6363_read_code_fn__52997__auto__$jscomp$inline_6362_state$jscomp$318$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$inline_6364_code_num__52998__auto__$jscomp$inline_6363_read_code_fn__52997__auto__$jscomp$inline_6362_state$jscomp$318$$():null;$code__52999__auto__$jscomp$inline_6364_code_num__52998__auto__$jscomp$inline_6363_read_code_fn__52997__auto__$jscomp$inline_6362_state$jscomp$318$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code__52999__auto__$jscomp$inline_6364_code_num__52998__auto__$jscomp$inline_6363_read_code_fn__52997__auto__$jscomp$inline_6362_state$jscomp$318$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$inline_6365$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_6364_code_num__52998__auto__$jscomp$inline_6363_read_code_fn__52997__auto__$jscomp$inline_6362_state$jscomp$318$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$inline_6365$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_dispose",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$inline_6365$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_6364_code_num__52998__auto__$jscomp$inline_6363_read_code_fn__52997__auto__$jscomp$inline_6362_state$jscomp$318$$],null),$_$jscomp$1886_cause53515$jscomp$inline_6361_fn_53514$jscomp$inline_6360$$);}}return $APP.$app$render_wasm$api$request_render$$("clear-edition-mode")}return null});
return new $app$main$data$workspace$edition$clear_edition_mode_66133$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$undo$conj_undo_entry$$=function($undo$jscomp$1_undo__$1$$,$cnt$jscomp$46_data$jscomp$317$$){$undo$jscomp$1_undo__$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($undo$jscomp$1_undo__$1$$,$cnt$jscomp$46_data$jscomp$317$$);$cnt$jscomp$46_data$jscomp$317$$=$APP.$cljs$core$count$$($undo$jscomp$1_undo__$1$$);return $cnt$jscomp$46_data$jscomp$317$$>50?$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($undo$jscomp$1_undo__$1$$,$cnt$jscomp$46_data$jscomp$317$$-
50):$undo$jscomp$1_undo__$1$$};
$app$main$data$workspace$undo$materialize_undo$$=function($_changes$jscomp$1$$,$index$jscomp$261$$){typeof $app$main$data$workspace$undo$materialize_undo_66059$$==="undefined"&&($app$main$data$workspace$undo$materialize_undo_66059$$=function($_changes$jscomp$2$$,$index$jscomp$262$$,$meta66060$$){this.$_changes$=$_changes$jscomp$2$$;this.index=$index$jscomp$262$$;this.$meta66060$=$meta66060$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$undo$materialize_undo_66059$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$materialize_undo_66059$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3562$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_materialize_undo$$},$app$main$data$workspace$undo$materialize_undo_66059$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66061$$,$meta66060__$1$$){return new $app$main$data$workspace$undo$materialize_undo_66059$$(this.$_changes$,this.index,$meta66060__$1$$)},$app$main$data$workspace$undo$materialize_undo_66059$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66060$},$app$main$data$workspace$undo$materialize_undo_66059$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$materialize_undo_66059$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1887$$,$state$jscomp$319$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$319$$,$APP.$cljs$cst$3563$workspace_undo$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1795$index$$,this.index)});
return new $app$main$data$workspace$undo$materialize_undo_66059$$($_changes$jscomp$1$$,$index$jscomp$261$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$undo$add_undo_entry$$=function($state$jscomp$320$$,$entry$jscomp$48$$){if($APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($entry$jscomp$48$$)){var $and__5023__auto____$1$jscomp$79$$=$APP.$cljs$core$not_empty$$($APP.$cljs$cst$3137$undo_changes$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$48$$));return $APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$79$$)?$APP.$cljs$core$not_empty$$($APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$48$$)):
$and__5023__auto____$1$jscomp$79$$}return $entry$jscomp$48$$}())){var $index$jscomp$263$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$320$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3563$workspace_undo$$,$APP.$cljs$cst$1795$index$$],null),-1),$items$jscomp$34_items__$1$jscomp$2_items__$2$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$320$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3563$workspace_undo$$,$APP.$cljs$cst$1838$items$$],null),$APP.$cljs$core$PersistentVector$EMPTY$$);$items$jscomp$34_items__$1$jscomp$2_items__$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$263$$+1,$items$jscomp$34_items__$1$jscomp$2_items__$2$$));$items$jscomp$34_items__$1$jscomp$2_items__$2$$=$app$main$data$workspace$undo$conj_undo_entry$$($items$jscomp$34_items__$1$jscomp$2_items__$2$$,
$entry$jscomp$48$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$320$$,$APP.$cljs$cst$3563$workspace_undo$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1838$items$$,$items$jscomp$34_items__$1$jscomp$2_items__$2$$,$APP.$cljs$cst$1795$index$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([function(){var $x__5113__auto__$jscomp$42$$=$index$jscomp$263$$+1;return $x__5113__auto__$jscomp$42$$<49?$x__5113__auto__$jscomp$42$$:49}()]))}return $state$jscomp$320$$};
$app$main$data$workspace$undo$stack_undo_entry$$=function($state$jscomp$321$$,$map__66082__$1_p__66080$$){$map__66082__$1_p__66080$$=$APP.$cljs$core$__destructure_map$$($map__66082__$1_p__66080$$);var $undo_changes$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66082__$1_p__66080$$,$APP.$cljs$cst$3137$undo_changes$$),$redo_changes$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66082__$1_p__66080$$,$APP.$cljs$cst$3133$redo_changes$$),$selected_after$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66082__$1_p__66080$$,$cljs$cst$3561$selected_after$$),$index$jscomp$264$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$321$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3563$workspace_undo$$,$APP.$cljs$cst$1795$index$$],null),-1);return $index$jscomp$264$$>=0?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$321$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3563$workspace_undo$$,$APP.$cljs$cst$1838$items$$,$index$jscomp$264$$],null),function($item$jscomp$69$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($item$jscomp$69$$,$APP.$cljs$cst$3137$undo_changes$$,function($p1__66073_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($undo_changes$jscomp$7$$,
$p1__66073_SHARP_$$)}),$APP.$cljs$cst$3133$redo_changes$$,function($p1__66074_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($p1__66074_SHARP_$$,$redo_changes$jscomp$11$$)}),$cljs$cst$3561$selected_after$$,$selected_after$$)}):$app$main$data$workspace$undo$add_undo_entry$$($state$jscomp$321$$,$map__66082__$1_p__66080$$)};
$app$main$data$workspace$undo$accumulate_undo_entry$$=function($state$jscomp$322$$,$p__66088_tags$jscomp$9$$){var $map__66090__$1_selected_after$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($p__66088_tags$jscomp$9$$),$undo_changes$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66090__$1_selected_after$jscomp$1$$,$APP.$cljs$cst$3137$undo_changes$$),$redo_changes$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66090__$1_selected_after$jscomp$1$$,$APP.$cljs$cst$3133$redo_changes$$),
$undo_group$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66090__$1_selected_after$jscomp$1$$,$APP.$cljs$cst$3138$undo_group$$);$p__66088_tags$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66090__$1_selected_after$jscomp$1$$,$APP.$cljs$cst$3142$tags$$);var $selected_before$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66090__$1_selected_after$jscomp$1$$,$cljs$cst$3144$selected_before$$);$map__66090__$1_selected_after$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66090__$1_selected_after$jscomp$1$$,$cljs$cst$3561$selected_after$$);return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$(function(){var $G__66091$$=function(){var $G__66092$$=$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$322$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3563$workspace_undo$$,
$cljs$cst$3564$transaction$$,$APP.$cljs$cst$3137$undo_changes$$],null),function($p1__66085_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($undo_changes$jscomp$8$$,$p1__66085_SHARP_$$)}),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3563$workspace_undo$$,$cljs$cst$3564$transaction$$,$APP.$cljs$cst$3133$redo_changes$$],null),function($p1__66086_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($p1__66086_SHARP_$$,
$redo_changes$jscomp$12$$)});return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$322$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3563$workspace_undo$$,$cljs$cst$3564$transaction$$,$APP.$cljs$cst$3138$undo_group$$],null))==null?$APP.$cljs$core$assoc_in$$($G__66092$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3563$workspace_undo$$,$cljs$cst$3564$transaction$$,
$APP.$cljs$cst$3138$undo_group$$],null),$undo_group$jscomp$6$$):$G__66092$$}();return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$322$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3563$workspace_undo$$,$cljs$cst$3564$transaction$$,$cljs$cst$3144$selected_before$$],null))==null?$APP.$cljs$core$assoc_in$$($G__66091$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3563$workspace_undo$$,$cljs$cst$3564$transaction$$,$cljs$cst$3144$selected_before$$],null),$selected_before$jscomp$2$$):$G__66091$$}(),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3563$workspace_undo$$,$cljs$cst$3564$transaction$$,$cljs$cst$3561$selected_after$$],null),$map__66090__$1_selected_after$jscomp$1$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3563$workspace_undo$$,
$cljs$cst$3564$transaction$$,$APP.$cljs$cst$3142$tags$$],null),$p__66088_tags$jscomp$9$$)};
$app$main$data$workspace$undo$append_undo$$=function($entry$jscomp$50$$,$stack_QMARK_$$){typeof $app$main$data$workspace$undo$append_undo_66100$$==="undefined"&&($app$main$data$workspace$undo$append_undo_66100$$=function($entry$jscomp$51$$,$stack_QMARK_$jscomp$1$$,$meta66101$$){this.entry=$entry$jscomp$51$$;this.$stack_QMARK_$=$stack_QMARK_$jscomp$1$$;this.$meta66101$=$meta66101$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$undo$append_undo_66100$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$append_undo_66100$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3565$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_append_undo$$},$app$main$data$workspace$undo$append_undo_66100$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66102$$,$meta66101__$1$$){return new $app$main$data$workspace$undo$append_undo_66100$$(this.entry,this.$stack_QMARK_$,$meta66101__$1$$)},$app$main$data$workspace$undo$append_undo_66100$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66101$},$app$main$data$workspace$undo$append_undo_66100$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$append_undo_66100$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1888_entry__$1$jscomp$1_selected_after$jscomp$2$$,$state$jscomp$323$$){$_$jscomp$1888_entry__$1$jscomp$1_selected_after$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$323$$,
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1921$selected$$);$_$jscomp$1888_entry__$1$jscomp$1_selected_after$jscomp$2$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.entry,$cljs$cst$3561$selected_after$$,$_$jscomp$1888_entry__$1$jscomp$1_selected_after$jscomp$2$$);var $JSCompiler_inline_result$jscomp$1112_and__5023__auto__$jscomp$inline_6368$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$323$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3563$workspace_undo$$,$cljs$cst$3564$transaction$$],null));$JSCompiler_inline_result$jscomp$1112_and__5023__auto__$jscomp$inline_6368$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1112_and__5023__auto__$jscomp$inline_6368$$)?$APP.$cljs$core$not$$(this.$stack_QMARK_$)||$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$323$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3563$workspace_undo$$,$cljs$cst$3564$transaction$$,$APP.$cljs$cst$3137$undo_changes$$],null)))||$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$323$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3563$workspace_undo$$,$cljs$cst$3564$transaction$$,$APP.$cljs$cst$3133$redo_changes$$],null))):$JSCompiler_inline_result$jscomp$1112_and__5023__auto__$jscomp$inline_6368$$;
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1112_and__5023__auto__$jscomp$inline_6368$$)?$app$main$data$workspace$undo$accumulate_undo_entry$$($state$jscomp$323$$,$_$jscomp$1888_entry__$1$jscomp$1_selected_after$jscomp$2$$):$APP.$cljs$core$truth_$$(this.$stack_QMARK_$)?$app$main$data$workspace$undo$stack_undo_entry$$($state$jscomp$323$$,$_$jscomp$1888_entry__$1$jscomp$1_selected_after$jscomp$2$$):$app$main$data$workspace$undo$add_undo_entry$$($state$jscomp$323$$,$_$jscomp$1888_entry__$1$jscomp$1_selected_after$jscomp$2$$)});
return new $app$main$data$workspace$undo$append_undo_66100$$($entry$jscomp$50$$,$stack_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$undo$start_undo_transaction$$=function($var_args$jscomp$1196$$){for(var $args__5755__auto__$jscomp$219$$=[],$len__5749__auto___66351$$=arguments.length,$i__5750__auto___66352$$=0;;)if($i__5750__auto___66352$$<$len__5749__auto___66351$$)$args__5755__auto__$jscomp$219$$.push(arguments[$i__5750__auto___66352$$]),$i__5750__auto___66352$$+=1;else break;return $app$main$data$workspace$undo$start_undo_transaction$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$219$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$219$$.slice(1),0,null):null)};
$app$main$data$workspace$undo$start_undo_transaction$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($id$jscomp$479$$,$p__66127$$){var $map__66128__$1$$=$APP.$cljs$core$__destructure_map$$($p__66127$$),$timeout$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__66128__$1$$,$APP.$cljs$cst$2353$timeout$$,2E4);typeof $app$main$data$workspace$undo$start_undo_transaction_66130$$==="undefined"&&($app$main$data$workspace$undo$start_undo_transaction_66130$$=function($id$jscomp$480$$,
$p__66127$jscomp$1$$,$map__66128$jscomp$1$$,$timeout$jscomp$14$$,$meta66131$$){this.id=$id$jscomp$480$$;this.$p__66127$=$p__66127$jscomp$1$$;this.$map__66128$=$map__66128$jscomp$1$$;this.timeout=$timeout$jscomp$14$$;this.$meta66131$=$meta66131$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$undo$start_undo_transaction_66130$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$start_undo_transaction_66130$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3566$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_start_undo_transaction$$},$app$main$data$workspace$undo$start_undo_transaction_66130$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66132$$,$meta66131__$1$$){return new $app$main$data$workspace$undo$start_undo_transaction_66130$$(this.id,this.$p__66127$,this.$map__66128$,this.timeout,$meta66131__$1$$)},$app$main$data$workspace$undo$start_undo_transaction_66130$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66131$},$app$main$data$workspace$undo$start_undo_transaction_66130$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$start_undo_transaction_66130$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1889$$,$state$jscomp$324$$){var $self__$jscomp$4140$$=this;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.undo",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"start-undo-transaction"],null)],null)}),null,"app.main.data.workspace.undo",$APP.$cljs$cst$1161$info$$,!1);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$324$$,$APP.$cljs$cst$3563$workspace_undo$$,function($undo_state$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($undo_state$$,
$cljs$cst$3564$transaction$$,function($p1__66123_SHARP_$$){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($p1__66123_SHARP_$$,$app$main$data$workspace$undo$empty_tx$$)}),$cljs$cst$3567$transactions_pending$$,$APP.$cljs$core$assoc$$,$self__$jscomp$4140$$.id,$APP.$app$common$time$now$$())})},$app$main$data$workspace$undo$start_undo_transaction_66130$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$start_undo_transaction_66130$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1890_and__5023__auto__$jscomp$inline_6370$$,$___$1$jscomp$1199$$,$stoper_stream$jscomp$37$$){$_$jscomp$1890_and__5023__auto__$jscomp$inline_6370$$=this.timeout;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($_$jscomp$1890_and__5023__auto__$jscomp$inline_6370$$)?this.timeout>0:$_$jscomp$1890_and__5023__auto__$jscomp$inline_6370$$)?($stoper_stream$jscomp$37$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3566$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_start_undo_transaction$$),
$stoper_stream$jscomp$37$$),$APP.$beicon$v2$core$take_until$$($stoper_stream$jscomp$37$$,$APP.$beicon$v2$core$delay$$(this.timeout,(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$undo$check_open_transactions$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$undo$check_open_transactions$$.$cljs$core$IFn$_invoke$arity$1$(this.timeout):$app$main$data$workspace$undo$check_open_transactions$$(this.timeout))))):null});return new $app$main$data$workspace$undo$start_undo_transaction_66130$$($id$jscomp$479$$,
$p__66127$$,$map__66128__$1$$,$timeout$jscomp$13$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$undo$add_transaction_undo_entry$$=function($state$jscomp$326$$){var $pending_tx_undo_state$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$326$$,$APP.$cljs$cst$3563$workspace_undo$$),$current_tx$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pending_tx_undo_state$jscomp$1$$,$cljs$cst$3564$transaction$$);$pending_tx_undo_state$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pending_tx_undo_state$jscomp$1$$,$cljs$cst$3567$transactions_pending$$);
return $current_tx$$!=null&&$APP.$cljs$core$empty_QMARK_$$($pending_tx_undo_state$jscomp$1$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($app$main$data$workspace$undo$add_undo_entry$$($state$jscomp$326$$,$current_tx$$),$APP.$cljs$cst$3563$workspace_undo$$,$APP.$cljs$core$dissoc$$,$cljs$cst$3564$transaction$$):$state$jscomp$326$$};
$APP.$app$main$data$workspace$undo$commit_undo_transaction$$=function($id$jscomp$481$$){typeof $app$main$data$workspace$undo$commit_undo_transaction_66180$$==="undefined"&&($app$main$data$workspace$undo$commit_undo_transaction_66180$$=function($id$jscomp$482$$,$meta66181$$){this.id=$id$jscomp$482$$;this.$meta66181$=$meta66181$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$undo$commit_undo_transaction_66180$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$commit_undo_transaction_66180$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3569$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_commit_undo_transaction$$},$app$main$data$workspace$undo$commit_undo_transaction_66180$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66182$$,$meta66181__$1$$){return new $app$main$data$workspace$undo$commit_undo_transaction_66180$$(this.id,$meta66181__$1$$)},
$app$main$data$workspace$undo$commit_undo_transaction_66180$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66181$},$app$main$data$workspace$undo$commit_undo_transaction_66180$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$commit_undo_transaction_66180$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1892$$,$state$jscomp$327$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.undo",
$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"commit-undo-transaction"],null)],null)}),null,"app.main.data.workspace.undo",$APP.$cljs$cst$1161$info$$,!1);return $app$main$data$workspace$undo$add_transaction_undo_entry$$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$327$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3563$workspace_undo$$,$cljs$cst$3567$transactions_pending$$],null),$APP.$cljs$core$dissoc$$,this.id))});return new $app$main$data$workspace$undo$commit_undo_transaction_66180$$($id$jscomp$481$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$undo$check_open_transactions$$=function($timeout$jscomp$15$$){typeof $app$main$data$workspace$undo$check_open_transactions_66216$$==="undefined"&&($app$main$data$workspace$undo$check_open_transactions_66216$$=function($timeout$jscomp$16$$,$meta66217$$){this.timeout=$timeout$jscomp$16$$;this.$meta66217$=$meta66217$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$undo$check_open_transactions_66216$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$check_open_transactions_66216$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3571$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_check_open_transactions$$},$app$main$data$workspace$undo$check_open_transactions_66216$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66218$$,$meta66217__$1$$){return new $app$main$data$workspace$undo$check_open_transactions_66216$$(this.timeout,$meta66217__$1$$)},
$app$main$data$workspace$undo$check_open_transactions_66216$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66217$},$app$main$data$workspace$undo$check_open_transactions_66216$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$check_open_transactions_66216$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1894_pending_ts$$,$state$jscomp$329$$){var $self__$jscomp$4157$$=this;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.undo",
$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"check-open-transactions"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2353$timeout$$,$self__$jscomp$4157$$.timeout],
null)],null)}),null,"app.main.data.workspace.undo",$APP.$cljs$cst$1161$info$$,!1);$_$jscomp$1894_pending_ts$$=$APP.$cljs$core$update_vals$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$329$$,$APP.$cljs$cst$3563$workspace_undo$$),$cljs$cst$3567$transactions_pending$$),function($p1__66209_SHARP_$$){return $APP.$app$common$time$diff_ms$$($p1__66209_SHARP_$$)});return $APP.$beicon$v2$core$map$$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$,
$APP.$beicon$v2$core$map$$($APP.$cljs$core$first$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__66210_SHARP_$$){return console.warn("FORCE COMMIT TRANSACTION AFTER "+($APP.$cljs$core$second$$($p1__66210_SHARP_$$)??"")+"MS")},$APP.$beicon$v2$core$from$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__66236$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66236$$,0,null);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66236$$,
1,null)>=$self__$jscomp$4157$$.timeout},$_$jscomp$1894_pending_ts$$)))))});return new $app$main$data$workspace$undo$check_open_transactions_66216$$($timeout$jscomp$15$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$undo$restore_selection$$=function($selected_ids$$){typeof $app$main$data$workspace$undo$restore_selection_66241$$==="undefined"&&($app$main$data$workspace$undo$restore_selection_66241$$=function($selected_ids$jscomp$1$$,$meta66242$$){this.$selected_ids$=$selected_ids$jscomp$1$$;this.$meta66242$=$meta66242$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$undo$restore_selection_66241$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$restore_selection_66241$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3572$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_restore_selection$$},$app$main$data$workspace$undo$restore_selection_66241$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66243$$,$meta66242__$1$$){return new $app$main$data$workspace$undo$restore_selection_66241$$(this.$selected_ids$,$meta66242__$1$$)},$app$main$data$workspace$undo$restore_selection_66241$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66242$},$app$main$data$workspace$undo$restore_selection_66241$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$restore_selection_66241$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1895$$,$state$jscomp$330$$){return this.$selected_ids$!=null?$APP.$cljs$core$assoc_in$$($state$jscomp$330$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$APP.$cljs$cst$1921$selected$$],null),this.$selected_ids$):$state$jscomp$330$$});return new $app$main$data$workspace$undo$restore_selection_66241$$($selected_ids$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$undo$undo_to_index$$=function($dest_index$$){typeof $app$main$data$workspace$undo$undo_to_index_66254$$==="undefined"&&($app$main$data$workspace$undo$undo_to_index_66254$$=function($dest_index$jscomp$1$$,$meta66255$$){this.$dest_index$=$dest_index$jscomp$1$$;this.$meta66255$=$meta66255$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$undo$undo_to_index_66254$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$undo$undo_to_index_66254$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3573$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_undo_to_index$$},$app$main$data$workspace$undo$undo_to_index_66254$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66256$$,$meta66255__$1$$){return new $app$main$data$workspace$undo$undo_to_index_66254$$(this.$dest_index$,$meta66255__$1$$)},$app$main$data$workspace$undo$undo_to_index_66254$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66255$},$app$main$data$workspace$undo$undo_to_index_66254$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$undo_to_index_66254$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($index$jscomp$265_it$jscomp$148_objects$jscomp$304_or__5025__auto__$jscomp$inline_6378_undo$jscomp$2$$,$changes$jscomp$158_items$jscomp$35_state$jscomp$331$$){$index$jscomp$265_it$jscomp$148_objects$jscomp$304_or__5025__auto__$jscomp$inline_6378_undo$jscomp$2$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$158_items$jscomp$35_state$jscomp$331$$);var $edition$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$158_items$jscomp$35_state$jscomp$331$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2199$edition$$],null)),$drawing$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$158_items$jscomp$35_state$jscomp$331$$,
$APP.$cljs$cst$2189$workspace_drawing$$);if($edition$$==null&&$APP.$cljs$cst$2198$object$$.$cljs$core$IFn$_invoke$arity$1$($drawing$$)==null||!$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$265_it$jscomp$148_objects$jscomp$304_or__5025__auto__$jscomp$inline_6378_undo$jscomp$2$$,$edition$$)))if($index$jscomp$265_it$jscomp$148_objects$jscomp$304_or__5025__auto__$jscomp$inline_6378_undo$jscomp$2$$=$APP.$cljs$cst$3563$workspace_undo$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$158_items$jscomp$35_state$jscomp$331$$),
$changes$jscomp$158_items$jscomp$35_state$jscomp$331$$=$APP.$cljs$cst$1838$items$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$265_it$jscomp$148_objects$jscomp$304_or__5025__auto__$jscomp$inline_6378_undo$jscomp$2$$),$index$jscomp$265_it$jscomp$148_objects$jscomp$304_or__5025__auto__$jscomp$inline_6378_undo$jscomp$2$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$265_it$jscomp$148_objects$jscomp$304_or__5025__auto__$jscomp$inline_6378_undo$jscomp$2$$),$index$jscomp$265_it$jscomp$148_objects$jscomp$304_or__5025__auto__$jscomp$inline_6378_undo$jscomp$2$$=
$APP.$cljs$core$truth_$$($index$jscomp$265_it$jscomp$148_objects$jscomp$304_or__5025__auto__$jscomp$inline_6378_undo$jscomp$2$$)?$index$jscomp$265_it$jscomp$148_objects$jscomp$304_or__5025__auto__$jscomp$inline_6378_undo$jscomp$2$$:$APP.$cljs$core$count$$($changes$jscomp$158_items$jscomp$35_state$jscomp$331$$)-1,$changes$jscomp$158_items$jscomp$35_state$jscomp$331$$!=null&&-1<=this.$dest_index$&&this.$dest_index$<=$APP.$cljs$core$count$$($changes$jscomp$158_items$jscomp$35_state$jscomp$331$$)-1)return $changes$jscomp$158_items$jscomp$35_state$jscomp$331$$=
$APP.$cljs$core$vec$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,this.$dest_index$<$index$jscomp$265_it$jscomp$148_objects$jscomp$304_or__5025__auto__$jscomp$inline_6378_undo$jscomp$2$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$reverse$$($APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$158_items$jscomp$35_state$jscomp$331$$,this.$dest_index$+1,$index$jscomp$265_it$jscomp$148_objects$jscomp$304_or__5025__auto__$jscomp$inline_6378_undo$jscomp$2$$+
1))):this.$dest_index$>$index$jscomp$265_it$jscomp$148_objects$jscomp$304_or__5025__auto__$jscomp$inline_6378_undo$jscomp$2$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$158_items$jscomp$35_state$jscomp$331$$,$index$jscomp$265_it$jscomp$148_objects$jscomp$304_or__5025__auto__$jscomp$inline_6378_undo$jscomp$2$$+1,this.$dest_index$+1)):$APP.$cljs$core$PersistentVector$EMPTY$$)),$APP.$cljs$core$seq$$($changes$jscomp$158_items$jscomp$35_state$jscomp$331$$)?
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$undo$materialize_undo$$($changes$jscomp$158_items$jscomp$35_state$jscomp$331$$,this.$dest_index$),$APP.$app$main$data$changes$commit_changes$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3133$redo_changes$$,$changes$jscomp$158_items$jscomp$35_state$jscomp$331$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1786$origin$$,this,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!1],null))):null;
return null});return new $app$main$data$workspace$undo$undo_to_index_66254$$($dest_index$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$undo$assure_valid_current_page$$=function(){typeof $app$main$data$workspace$undo$assure_valid_current_page_66340$$==="undefined"&&($app$main$data$workspace$undo$assure_valid_current_page_66340$$=function($meta66341$$){this.$meta66341$=$meta66341$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$undo$assure_valid_current_page_66340$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$undo$assure_valid_current_page_66340$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3576$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_assure_valid_current_page$$},$app$main$data$workspace$undo$assure_valid_current_page_66340$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66342$$,$meta66341__$1$$){return new $app$main$data$workspace$undo$assure_valid_current_page_66340$$($meta66341__$1$$)},$app$main$data$workspace$undo$assure_valid_current_page_66340$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66341$},$app$main$data$workspace$undo$assure_valid_current_page_66340$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$undo$assure_valid_current_page_66340$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1899_page_id$jscomp$103$$,$pages$jscomp$2_state$jscomp$334$$){$_$jscomp$1899_page_id$jscomp$103$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($pages$jscomp$2_state$jscomp$334$$);
$pages$jscomp$2_state$jscomp$334$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($pages$jscomp$2_state$jscomp$334$$),$APP.$cljs$cst$2228$pages$$);return $APP.$cljs$core$contains_QMARK_$$($pages$jscomp$2_state$jscomp$334$$,$_$jscomp$1899_page_id$jscomp$103$$)?$APP.$beicon$v2$core$empty$$():(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2043$page_id$$,
$APP.$cljs$core$first$$($pages$jscomp$2_state$jscomp$334$$)])))});return new $app$main$data$workspace$undo$assure_valid_current_page_66340$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$=function($state$jscomp$335$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$335$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2186$render_state$$,$cljs$cst$2187$lost$$],null))===!0};
$APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$=function($state$jscomp$336_vbox$jscomp$inline_12362$$){if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$336_vbox$jscomp$inline_12362$$,"render-wasm/v1")&&!$APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$336_vbox$jscomp$inline_12362$$))if($APP.$app$render_wasm$api$initialized_QMARK_$$()){var $JSCompiler_temp$jscomp$10822_zoom$jscomp$inline_12361$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$336_vbox$jscomp$inline_12362$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2196$zoom$$],null));$state$jscomp$336_vbox$jscomp$inline_12362$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$336_vbox$jscomp$inline_12362$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1925$vbox$$],null));$JSCompiler_temp$jscomp$10822_zoom$jscomp$inline_12361$$=
$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10822_zoom$jscomp$inline_12361$$)?$state$jscomp$336_vbox$jscomp$inline_12362$$:$JSCompiler_temp$jscomp$10822_zoom$jscomp$inline_12361$$)?$APP.$app$render_wasm$api$set_view_box$$($JSCompiler_temp$jscomp$10822_zoom$jscomp$inline_12361$$,$state$jscomp$336_vbox$jscomp$inline_12362$$):null}else $JSCompiler_temp$jscomp$10822_zoom$jscomp$inline_12361$$=null;else $JSCompiler_temp$jscomp$10822_zoom$jscomp$inline_12361$$=null;return $JSCompiler_temp$jscomp$10822_zoom$jscomp$inline_12361$$};
$app$main$data$workspace$zoom$impl_update_zoom$$=function($map__66089__$1_p__66087$$,$center$jscomp$34_center__$1_mtx$jscomp$7$$,$JSCompiler_temp$jscomp$1114_new_zoom_zoom$jscomp$5$$){$map__66089__$1_p__66087$$=$APP.$cljs$core$__destructure_map$$($map__66089__$1_p__66087$$);var $vbox$jscomp$5_vbox_SINGLEQUOTE_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66089__$1_p__66087$$,$APP.$cljs$cst$1925$vbox$$);if($APP.$cljs$core$fn_QMARK_$$($JSCompiler_temp$jscomp$1114_new_zoom_zoom$jscomp$5$$)){var $G__66093$jscomp$inline_6424_old_zoom$$=
$APP.$cljs$cst$2196$zoom$$.$cljs$core$IFn$_invoke$arity$1$($map__66089__$1_p__66087$$);$JSCompiler_temp$jscomp$1114_new_zoom_zoom$jscomp$5$$=$JSCompiler_temp$jscomp$1114_new_zoom_zoom$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_temp$jscomp$1114_new_zoom_zoom$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($G__66093$jscomp$inline_6424_old_zoom$$):$JSCompiler_temp$jscomp$1114_new_zoom_zoom$jscomp$5$$($G__66093$jscomp$inline_6424_old_zoom$$)}$G__66093$jscomp$inline_6424_old_zoom$$=$APP.$cljs$cst$2196$zoom$$.$cljs$core$IFn$_invoke$arity$1$($map__66089__$1_p__66087$$);
$center$jscomp$34_center__$1_mtx$jscomp$7$$=$APP.$cljs$core$truth_$$($center$jscomp$34_center__$1_mtx$jscomp$7$$)?$center$jscomp$34_center__$1_mtx$jscomp$7$$:$APP.$app$common$geom$rect$rect__GT_center$$($vbox$jscomp$5_vbox_SINGLEQUOTE_$$);$center$jscomp$34_center__$1_mtx$jscomp$7$$=$app$common$geom$matrix$scale_matrix$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($G__66093$jscomp$inline_6424_old_zoom$$/$JSCompiler_temp$jscomp$1114_new_zoom_zoom$jscomp$5$$),
$center$jscomp$34_center__$1_mtx$jscomp$7$$);$vbox$jscomp$5_vbox_SINGLEQUOTE_$$=$app$common$geom$shapes$transforms$transform_rect$$($vbox$jscomp$5_vbox_SINGLEQUOTE_$$,$center$jscomp$34_center__$1_mtx$jscomp$7$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__66089__$1_p__66087$$,$APP.$cljs$cst$2196$zoom$$,$JSCompiler_temp$jscomp$1114_new_zoom_zoom$jscomp$5$$),$APP.$cljs$cst$3577$zoom_inverse$$,
1/$JSCompiler_temp$jscomp$1114_new_zoom_zoom$jscomp$5$$),$APP.$cljs$cst$1925$vbox$$,$APP.$cljs$core$merge$$,$APP.$cljs$core$select_keys$$($vbox$jscomp$5_vbox_SINGLEQUOTE_$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$],null)))};
$app$main$data$workspace$zoom$increase_zoom$cljs$0core$0IFn$0_invoke$0arity$01$$=function($center$jscomp$35$$){typeof $app$main$data$workspace$zoom$increase_zoom_66110$$==="undefined"&&($app$main$data$workspace$zoom$increase_zoom_66110$$=function($center$jscomp$36$$,$meta66111$$){this.$center$=$center$jscomp$36$$;this.$meta66111$=$meta66111$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$zoom$increase_zoom_66110$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$increase_zoom_66110$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3579$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_increase_zoom$$},$app$main$data$workspace$zoom$increase_zoom_66110$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66112$$,$meta66111__$1$$){return new $app$main$data$workspace$zoom$increase_zoom_66110$$(this.$center$,$meta66111__$1$$)},$app$main$data$workspace$zoom$increase_zoom_66110$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66111$},$app$main$data$workspace$zoom$increase_zoom_66110$$.prototype.$app$main$data$event$PerformanceEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$increase_zoom_66110$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$increase_zoom_66110$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1900$$,$state$jscomp$339$$){if($APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$339$$))return $state$jscomp$339$$;
var $center__$1$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$center$,$cljs$cst$3578$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_auto$$)?$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$):this.$center$;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$339$$,$APP.$cljs$cst$1920$workspace_local$$,function($p1__66099_SHARP_$$){return $app$main$data$workspace$zoom$impl_update_zoom$$($p1__66099_SHARP_$$,$center__$1$jscomp$1$$,
function($x__5113__auto__$jscomp$43_z$jscomp$107$$){$x__5113__auto__$jscomp$43_z$jscomp$107$$*=1.3;return $x__5113__auto__$jscomp$43_z$jscomp$107$$<200?$x__5113__auto__$jscomp$43_z$jscomp$107$$:200})})},$app$main$data$workspace$zoom$increase_zoom_66110$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$increase_zoom_66110$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1901$$,$state$jscomp$340$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$340$$)});
return new $app$main$data$workspace$zoom$increase_zoom_66110$$($center$jscomp$35$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$zoom$decrease_zoom$cljs$0core$0IFn$0_invoke$0arity$01$$=function($center$jscomp$37$$){typeof $app$main$data$workspace$zoom$decrease_zoom_66145$$==="undefined"&&($app$main$data$workspace$zoom$decrease_zoom_66145$$=function($center$jscomp$38$$,$meta66146$$){this.$center$=$center$jscomp$38$$;this.$meta66146$=$meta66146$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$zoom$decrease_zoom_66145$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$decrease_zoom_66145$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3580$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_decrease_zoom$$},$app$main$data$workspace$zoom$decrease_zoom_66145$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66147$$,$meta66146__$1$$){return new $app$main$data$workspace$zoom$decrease_zoom_66145$$(this.$center$,$meta66146__$1$$)},$app$main$data$workspace$zoom$decrease_zoom_66145$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66146$},$app$main$data$workspace$zoom$decrease_zoom_66145$$.prototype.$app$main$data$event$PerformanceEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$decrease_zoom_66145$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$decrease_zoom_66145$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1902$$,$state$jscomp$341$$){if($APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$341$$))return $state$jscomp$341$$;
var $center__$1$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$center$,$cljs$cst$3578$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_auto$$)?$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$):this.$center$;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$341$$,$APP.$cljs$cst$1920$workspace_local$$,function($p1__66129_SHARP_$$){return $app$main$data$workspace$zoom$impl_update_zoom$$($p1__66129_SHARP_$$,$center__$1$jscomp$2$$,
function($x__5110__auto__$jscomp$59_z$jscomp$108$$){$x__5110__auto__$jscomp$59_z$jscomp$108$$/=1.3;return $x__5110__auto__$jscomp$59_z$jscomp$108$$>.01?$x__5110__auto__$jscomp$59_z$jscomp$108$$:.01})})},$app$main$data$workspace$zoom$decrease_zoom_66145$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$decrease_zoom_66145$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1903$$,$state$jscomp$342$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$342$$)});
return new $app$main$data$workspace$zoom$decrease_zoom_66145$$($center$jscomp$37$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$zoom$set_zoom$cljs$0core$0IFn$0_invoke$0arity$02$$=function($center$jscomp$39$$,$scale$jscomp$23$$){typeof $app$main$data$workspace$zoom$set_zoom_66175$$==="undefined"&&($app$main$data$workspace$zoom$set_zoom_66175$$=function($center$jscomp$40$$,$scale$jscomp$24$$,$meta66176$$){this.$center$=$center$jscomp$40$$;this.scale=$scale$jscomp$24$$;this.$meta66176$=$meta66176$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$zoom$set_zoom_66175$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$set_zoom_66175$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3581$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_set_zoom$$},$app$main$data$workspace$zoom$set_zoom_66175$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66177$$,$meta66176__$1$$){return new $app$main$data$workspace$zoom$set_zoom_66175$$(this.$center$,this.scale,$meta66176__$1$$)},$app$main$data$workspace$zoom$set_zoom_66175$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66176$},$app$main$data$workspace$zoom$set_zoom_66175$$.prototype.$app$main$data$event$PerformanceEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$set_zoom_66175$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$set_zoom_66175$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1904_x$jscomp$1171$$,$state$jscomp$343$$){var $self__$jscomp$4191$$=this;if($APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$343$$))return $state$jscomp$343$$;
var $vp$jscomp$1_y$jscomp$407$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$343$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1925$vbox$$);$_$jscomp$1904_x$jscomp$1171$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vp$jscomp$1_y$jscomp$407$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vp$jscomp$1_y$jscomp$407$$)/2;$vp$jscomp$1_y$jscomp$407$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vp$jscomp$1_y$jscomp$407$$)+
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vp$jscomp$1_y$jscomp$407$$)/2;var $center__$1$jscomp$3$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4191$$.$center$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1904_x$jscomp$1171$$,$vp$jscomp$1_y$jscomp$407$$));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$343$$,$APP.$cljs$cst$1920$workspace_local$$,function($p1__66162_SHARP_$$){return $app$main$data$workspace$zoom$impl_update_zoom$$($p1__66162_SHARP_$$,
$center__$1$jscomp$3$$,function($x__5110__auto__$jscomp$inline_6426_x__5113__auto__$jscomp$44_z$jscomp$109$$){$x__5110__auto__$jscomp$inline_6426_x__5113__auto__$jscomp$44_z$jscomp$109$$*=$self__$jscomp$4191$$.scale;$x__5110__auto__$jscomp$inline_6426_x__5113__auto__$jscomp$44_z$jscomp$109$$=$x__5110__auto__$jscomp$inline_6426_x__5113__auto__$jscomp$44_z$jscomp$109$$>.01?$x__5110__auto__$jscomp$inline_6426_x__5113__auto__$jscomp$44_z$jscomp$109$$:.01;return $x__5110__auto__$jscomp$inline_6426_x__5113__auto__$jscomp$44_z$jscomp$109$$<
200?$x__5110__auto__$jscomp$inline_6426_x__5113__auto__$jscomp$44_z$jscomp$109$$:200})})},$app$main$data$workspace$zoom$set_zoom_66175$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$set_zoom_66175$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1905$$,$state$jscomp$344$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$344$$)});return new $app$main$data$workspace$zoom$set_zoom_66175$$($center$jscomp$39$$,
$scale$jscomp$23$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$01$$=function($id$jscomp$483$$){return $app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$483$$,!1)};
$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$02$$=function($id$jscomp$484$$,$toggle_QMARK_$jscomp$1$$){typeof $app$main$data$workspace$selection$select_shape_67181$$==="undefined"&&($app$main$data$workspace$selection$select_shape_67181$$=function($id$jscomp$485$$,$toggle_QMARK_$jscomp$2$$,$meta67182$$){this.id=$id$jscomp$485$$;this.$toggle_QMARK_$=$toggle_QMARK_$jscomp$2$$;this.$meta67182$=$meta67182$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$selection$select_shape_67181$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_shape_67181$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3592$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_shape$$},$app$main$data$workspace$selection$select_shape_67181$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67183$$,$meta67182__$1$$){return new $app$main$data$workspace$selection$select_shape_67181$$(this.id,
this.$toggle_QMARK_$,$meta67182__$1$$)},$app$main$data$workspace$selection$select_shape_67181$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67182$},$app$main$data$workspace$selection$select_shape_67181$$.prototype.$app$main$data$event$PerformanceEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_shape_67181$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_shape_67181$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$1919$$,$state$jscomp$358$$){return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$358$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1921$selected$$],null),$app$common$data$toggle_selection$$,this.id,this.$toggle_QMARK_$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$cljs$cst$3593$last_selected$$],null),this.id)},$app$main$data$workspace$selection$select_shape_67181$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_shape_67181$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1920_frame_ids_page_id$jscomp$107_selected$jscomp$19_selected_id$$,$params_board_state$jscomp$359$$){$_$jscomp$1920_frame_ids_page_id$jscomp$107_selected$jscomp$19_selected_id$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($params_board_state$jscomp$359$$);
var $objects$jscomp$310$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($params_board_state$jscomp$359$$,$_$jscomp$1920_frame_ids_page_id$jscomp$107_selected$jscomp$19_selected_id$$);$_$jscomp$1920_frame_ids_page_id$jscomp$107_selected$jscomp$19_selected_id$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($params_board_state$jscomp$359$$);$_$jscomp$1920_frame_ids_page_id$jscomp$107_selected$jscomp$19_selected_id$$=$app$main$data$helpers$lookup_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($params_board_state$jscomp$359$$,
$_$jscomp$1920_frame_ids_page_id$jscomp$107_selected$jscomp$19_selected_id$$);$_$jscomp$1920_frame_ids_page_id$jscomp$107_selected$jscomp$19_selected_id$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($item$jscomp$72_parent$jscomp$220$$){$item$jscomp$72_parent$jscomp$220$$=$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$310$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$72_parent$jscomp$220$$));return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$72_parent$jscomp$220$$)},
$_$jscomp$1920_frame_ids_page_id$jscomp$107_selected$jscomp$19_selected_id$$);var $params_without_board$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$router$get_params$$($params_board_state$jscomp$359$$),$cljs$cst$3594$board_id$$);$params_board_state$jscomp$359$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$router$get_params$$($params_board_state$jscomp$359$$),$cljs$cst$3594$board_id$$,$_$jscomp$1920_frame_ids_page_id$jscomp$107_selected$jscomp$19_selected_id$$);
return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$collapse$expand_all_parents$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.id],null),$objects$jscomp$310$$),$APP.$cljs$cst$2169$interrupt$$,$APP.$cljs$cst$3595$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_interrupt$$,$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__67169_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__67169_SHARP_$$,
$APP.$app$common$uuid$zero$$)},$_$jscomp$1920_frame_ids_page_id$jscomp$107_selected$jscomp$19_selected_id$$))?$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2532$workspace$$,$params_without_board$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2455$app_DOT_main_DOT_router_SLASH_replace$$,!0],null)])):$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2532$workspace$$,
$params_board_state$jscomp$359$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2455$app_DOT_main_DOT_router_SLASH_replace$$,!0],null)])))});return new $app$main$data$workspace$selection$select_shape_67181$$($id$jscomp$484$$,$toggle_QMARK_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$selection$select_prev_shape$$=function(){typeof $app$main$data$workspace$selection$select_prev_shape_67230$$==="undefined"&&($app$main$data$workspace$selection$select_prev_shape_67230$$=function($meta67231$$){this.$meta67231$=$meta67231$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$select_prev_shape_67230$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_prev_shape_67230$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3596$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_prev_shape$$},$app$main$data$workspace$selection$select_prev_shape_67230$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67232$$,$meta67231__$1$$){return new $app$main$data$workspace$selection$select_prev_shape_67230$$($meta67231__$1$$)},$app$main$data$workspace$selection$select_prev_shape_67230$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67231$},$app$main$data$workspace$selection$select_prev_shape_67230$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_prev_shape_67230$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1921_count_selected$$,$objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$){var $first_selected_selected$jscomp$20$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$);$_$jscomp$1921_count_selected$$=
$APP.$cljs$core$count$$($first_selected_selected$jscomp$20$$);$first_selected_selected$jscomp$20$$=$APP.$cljs$core$first$$($first_selected_selected$jscomp$20$$);var $current$jscomp$37_current_index$jscomp$1_page_id$jscomp$108$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$);$objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$,
$current$jscomp$37_current_index$jscomp$1_page_id$jscomp$108$$);$current$jscomp$37_current_index$jscomp$1_page_id$jscomp$108$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$,$first_selected_selected$jscomp$20$$);$objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$37_current_index$jscomp$1_page_id$jscomp$108$$));$objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$);$current$jscomp$37_current_index$jscomp$1_page_id$jscomp$108$$=$objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$==
null?null:$APP.$app$common$data$index_of$$($objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$,$first_selected_selected$jscomp$20$$);$objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$=$current$jscomp$37_current_index$jscomp$1_page_id$jscomp$108$$!=null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$)-1,$current$jscomp$37_current_index$jscomp$1_page_id$jscomp$108$$)?
$APP.$cljs$core$first$$($objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$):$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$,$current$jscomp$37_current_index$jscomp$1_page_id$jscomp$108$$+1,null):null;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$_$jscomp$1921_count_selected$$)&&$objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$!=
null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$01$$($objects$jscomp$311_parent$jscomp$221_sibling$jscomp$1_sibling_ids_state$jscomp$360$$)):$_$jscomp$1921_count_selected$$>1?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$01$$($first_selected_selected$jscomp$20$$)):null});return new $app$main$data$workspace$selection$select_prev_shape_67230$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$selection$select_next_shape$$=function(){typeof $app$main$data$workspace$selection$select_next_shape_67251$$==="undefined"&&($app$main$data$workspace$selection$select_next_shape_67251$$=function($meta67252$$){this.$meta67252$=$meta67252$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$select_next_shape_67251$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_next_shape_67251$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3597$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_next_shape$$},$app$main$data$workspace$selection$select_next_shape_67251$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67253$$,$meta67252__$1$$){return new $app$main$data$workspace$selection$select_next_shape_67251$$($meta67252__$1$$)},$app$main$data$workspace$selection$select_next_shape_67251$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67252$},$app$main$data$workspace$selection$select_next_shape_67251$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_next_shape_67251$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1922_count_selected$jscomp$1$$,$objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$){var $first_selected$jscomp$1_selected$jscomp$21$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$);
$_$jscomp$1922_count_selected$jscomp$1$$=$APP.$cljs$core$count$$($first_selected$jscomp$1_selected$jscomp$21$$);$first_selected$jscomp$1_selected$jscomp$21$$=$APP.$cljs$core$first$$($first_selected$jscomp$1_selected$jscomp$21$$);var $current$jscomp$38_current_index$jscomp$2_page_id$jscomp$109$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$);$objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$,$current$jscomp$38_current_index$jscomp$2_page_id$jscomp$109$$);$current$jscomp$38_current_index$jscomp$2_page_id$jscomp$109$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$,$first_selected$jscomp$1_selected$jscomp$21$$);$objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$38_current_index$jscomp$2_page_id$jscomp$109$$));$objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$);
$current$jscomp$38_current_index$jscomp$2_page_id$jscomp$109$$=$objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$==null?null:$APP.$app$common$data$index_of$$($objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$,$first_selected$jscomp$1_selected$jscomp$21$$);$objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$=$current$jscomp$38_current_index$jscomp$2_page_id$jscomp$109$$!=
null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$current$jscomp$38_current_index$jscomp$2_page_id$jscomp$109$$)?$APP.$cljs$core$last$$($objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$):$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$,$current$jscomp$38_current_index$jscomp$2_page_id$jscomp$109$$-1,null):null;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$_$jscomp$1922_count_selected$jscomp$1$$)&&$objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$!=null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$01$$($objects$jscomp$312_parent$jscomp$222_sibling$jscomp$2_sibling_ids$jscomp$1_state$jscomp$361$$)):$_$jscomp$1922_count_selected$jscomp$1$$>1?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$01$$($first_selected$jscomp$1_selected$jscomp$21$$)):
null});return new $app$main$data$workspace$selection$select_next_shape_67251$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$selection$deselect_shape$$=function($id$jscomp$486$$){typeof $app$main$data$workspace$selection$deselect_shape_67293$$==="undefined"&&($app$main$data$workspace$selection$deselect_shape_67293$$=function($id$jscomp$487$$,$meta67294$$){this.id=$id$jscomp$487$$;this.$meta67294$=$meta67294$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$deselect_shape_67293$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$deselect_shape_67293$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3598$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_deselect_shape$$},$app$main$data$workspace$selection$deselect_shape_67293$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67295$$,$meta67294__$1$$){return new $app$main$data$workspace$selection$deselect_shape_67293$$(this.id,$meta67294__$1$$)},$app$main$data$workspace$selection$deselect_shape_67293$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67294$},$app$main$data$workspace$selection$deselect_shape_67293$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$deselect_shape_67293$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$3595$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_interrupt$$)},$app$main$data$workspace$selection$deselect_shape_67293$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$deselect_shape_67293$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1924$$,$state$jscomp$362$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$362$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1921$selected$$],
null),$APP.$cljs$core$disj$$,this.id),$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$dissoc$$,$cljs$cst$3593$last_selected$$)});return new $app$main$data$workspace$selection$deselect_shape_67293$$($id$jscomp$486$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$selection$shift_select_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$=function($id$jscomp$489$$,$objects$jscomp$313$$){typeof $app$main$data$workspace$selection$shift_select_shapes_67316$$==="undefined"&&($app$main$data$workspace$selection$shift_select_shapes_67316$$=function($id$jscomp$490$$,$objects$jscomp$314$$,$meta67317$$){this.id=$id$jscomp$490$$;this.objects=$objects$jscomp$314$$;this.$meta67317$=$meta67317$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$selection$shift_select_shapes_67316$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$shift_select_shapes_67316$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3599$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_shift_select_shapes$$},$app$main$data$workspace$selection$shift_select_shapes_67316$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67318$$,$meta67317__$1$$){return new $app$main$data$workspace$selection$shift_select_shapes_67316$$(this.id,
this.objects,$meta67317__$1$$)},$app$main$data$workspace$selection$shift_select_shapes_67316$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67317$},$app$main$data$workspace$selection$shift_select_shapes_67316$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$shift_select_shapes_67316$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$3595$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_interrupt$$)},
$app$main$data$workspace$selection$shift_select_shapes_67316$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$shift_select_shapes_67316$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1926_append_to_selection_objects__$1$jscomp$8_or__5025__auto__$jscomp$inline_6472$$,$state$jscomp$363$$){$_$jscomp$1926_append_to_selection_objects__$1$jscomp$8_or__5025__auto__$jscomp$inline_6472$$=this.objects;$_$jscomp$1926_append_to_selection_objects__$1$jscomp$8_or__5025__auto__$jscomp$inline_6472$$=
$APP.$cljs$core$truth_$$($_$jscomp$1926_append_to_selection_objects__$1$jscomp$8_or__5025__auto__$jscomp$inline_6472$$)?$_$jscomp$1926_append_to_selection_objects__$1$jscomp$8_or__5025__auto__$jscomp$inline_6472$$:$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$363$$);$_$jscomp$1926_append_to_selection_objects__$1$jscomp$8_or__5025__auto__$jscomp$inline_6472$$=$APP.$app$common$files$helpers$expand_region_selection$$($_$jscomp$1926_append_to_selection_objects__$1$jscomp$8_or__5025__auto__$jscomp$inline_6472$$,
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$363$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$cljs$cst$3593$last_selected$$],null)),this.id],null)));var $selection$jscomp$7$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$363$$),
this.id);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$assoc_in$$($state$jscomp$363$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1921$selected$$],null),$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($selection$jscomp$7$$,$_$jscomp$1926_append_to_selection_objects__$1$jscomp$8_or__5025__auto__$jscomp$inline_6472$$)),$APP.$cljs$cst$1920$workspace_local$$,
$APP.$cljs$core$assoc$$,$cljs$cst$3593$last_selected$$,this.id)});return new $app$main$data$workspace$selection$shift_select_shapes_67316$$($id$jscomp$489$$,$objects$jscomp$313$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$selection$select_shapes$$=function($ids$jscomp$66$$){typeof $app$main$data$workspace$selection$select_shapes_67319$$==="undefined"&&($app$main$data$workspace$selection$select_shapes_67319$$=function($ids$jscomp$67$$,$meta67320$$){this.ids=$ids$jscomp$67$$;this.$meta67320$=$meta67320$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$select_shapes_67319$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_shapes_67319$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3600$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_shapes$$},$app$main$data$workspace$selection$select_shapes_67319$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67321$$,$meta67320__$1$$){return new $app$main$data$workspace$selection$select_shapes_67319$$(this.ids,$meta67320__$1$$)},$app$main$data$workspace$selection$select_shapes_67319$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67320$},$app$main$data$workspace$selection$select_shapes_67319$$.prototype.$app$main$data$event$PerformanceEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_shapes_67319$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_shapes_67319$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1927_ids__$1$jscomp$5_objects$jscomp$315$$,$state$jscomp$364$$){$_$jscomp$1927_ids__$1$jscomp$5_objects$jscomp$315$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$364$$);var $focus$jscomp$6$$=$APP.$cljs$cst$2226$workspace_focus_selected$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$364$$);$_$jscomp$1927_ids__$1$jscomp$5_objects$jscomp$315$$=$APP.$app$common$data$not_empty_QMARK_$$($focus$jscomp$6$$)?$app$common$files$focus$filter_not_focus$$($_$jscomp$1927_ids__$1$jscomp$5_objects$jscomp$315$$,$focus$jscomp$6$$,this.ids):this.ids;return $APP.$cljs$core$assoc_in$$($state$jscomp$364$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1921$selected$$],null),$_$jscomp$1927_ids__$1$jscomp$5_objects$jscomp$315$$)},$app$main$data$workspace$selection$select_shapes_67319$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_shapes_67319$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1928_expand_s_objects$jscomp$316$$,
$interrupt_s_state$jscomp$365$$){$_$jscomp$1928_expand_s_objects$jscomp$316$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($interrupt_s_state$jscomp$365$$);$_$jscomp$1928_expand_s_objects$jscomp$316$$=$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$collapse$expand_all_parents$$(this.ids,$_$jscomp$1928_expand_s_objects$jscomp$316$$)));$interrupt_s_state$jscomp$365$$=(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$3595$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_interrupt$$);
return $APP.$beicon$v2$core$merge$$($_$jscomp$1928_expand_s_objects$jscomp$316$$,$interrupt_s_state$jscomp$365$$)});return new $app$main$data$workspace$selection$select_shapes_67319$$($ids$jscomp$66$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$selection$select_all$$=function(){typeof $app$main$data$workspace$selection$select_all_67337$$==="undefined"&&($app$main$data$workspace$selection$select_all_67337$$=function($meta67338$$){this.$meta67338$=$meta67338$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$select_all_67337$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_all_67337$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3601$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_all$$},$app$main$data$workspace$selection$select_all_67337$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67339$$,$meta67338__$1$$){return new $app$main$data$workspace$selection$select_all_67337$$($meta67338__$1$$)},$app$main$data$workspace$selection$select_all_67337$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67338$},$app$main$data$workspace$selection$select_all_67337$$.prototype.$app$main$data$event$PerformanceEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_all_67337$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_all_67337$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1929_focus$jscomp$7_objects$jscomp$317$$,$parent$jscomp$223_parents$jscomp$8_state$jscomp$366_toselect$$){$_$jscomp$1929_focus$jscomp$7_objects$jscomp$317$$=$APP.$cljs$cst$2226$workspace_focus_selected$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$223_parents$jscomp$8_state$jscomp$366_toselect$$);
$_$jscomp$1929_focus$jscomp$7_objects$jscomp$317$$=$APP.$app$common$files$focus$focus_objects$$($APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$223_parents$jscomp$8_state$jscomp$366_toselect$$),$_$jscomp$1929_focus$jscomp$7_objects$jscomp$317$$);var $lookup$jscomp$18$$=$APP.$app$common$data$getf$$($_$jscomp$1929_focus$jscomp$7_objects$jscomp$317$$);$parent$jscomp$223_parents$jscomp$8_state$jscomp$366_toselect$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($lookup$jscomp$18$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1619$parent_id$$)),$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$223_parents$jscomp$8_state$jscomp$366_toselect$$));$parent$jscomp$223_parents$jscomp$8_state$jscomp$366_toselect$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($parent$jscomp$223_parents$jscomp$8_state$jscomp$366_toselect$$))?
$lookup$jscomp$18$$($APP.$cljs$core$first$$($parent$jscomp$223_parents$jscomp$8_state$jscomp$366_toselect$$)):$lookup$jscomp$18$$($APP.$app$common$uuid$zero$$);$parent$jscomp$223_parents$jscomp$8_state$jscomp$366_toselect$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1620$hidden$$),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1623$blocked$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$)),$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$1929_focus$jscomp$7_objects$jscomp$317$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$223_parents$jscomp$8_state$jscomp$366_toselect$$)));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$select_shapes$$($parent$jscomp$223_parents$jscomp$8_state$jscomp$366_toselect$$))});
return new $app$main$data$workspace$selection$select_all_67337$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$00$$=function(){return $APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$01$$(!1)};
$APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$01$$=function($check_modal$$){typeof $app$main$data$workspace$selection$deselect_all_67343$$==="undefined"&&($app$main$data$workspace$selection$deselect_all_67343$$=function($check_modal$jscomp$1$$,$meta67344$$){this.$check_modal$=$check_modal$jscomp$1$$;this.$meta67344$=$meta67344$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$deselect_all_67343$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$deselect_all_67343$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3602$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_deselect_all$$},$app$main$data$workspace$selection$deselect_all_67343$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67345$$,$meta67344__$1$$){return new $app$main$data$workspace$selection$deselect_all_67343$$(this.$check_modal$,$meta67344__$1$$)},$app$main$data$workspace$selection$deselect_all_67343$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67344$},$app$main$data$workspace$selection$deselect_all_67343$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$deselect_all_67343$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1930_params_without_board$jscomp$1$$,$state$jscomp$367$$){$_$jscomp$1930_params_without_board$jscomp$1$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$router$get_params$$($state$jscomp$367$$),
$cljs$cst$3594$board_id$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$3595$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_interrupt$$,$APP.$app$main$data$workspace$edition$clear_edition_mode$$(),$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2532$workspace$$,$_$jscomp$1930_params_without_board$jscomp$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2455$app_DOT_main_DOT_router_SLASH_replace$$,
!0],null)])))},$app$main$data$workspace$selection$deselect_all_67343$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$deselect_all_67343$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1931$$,$state$jscomp$368$$){return $APP.$cljs$core$not$$(this.$check_modal$)||$APP.$cljs$core$not$$($APP.$cljs$cst$2338$app_DOT_main_DOT_data_DOT_modal_SLASH_modal$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$368$$))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$368$$,
$APP.$cljs$cst$1920$workspace_local$$,function($p1__67340_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__67340_SHARP_$$,$APP.$cljs$cst$1921$selected$$,$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$()),$cljs$cst$3603$selected_frame$$)}):$state$jscomp$368$$});return new $app$main$data$workspace$selection$deselect_all_67343$$($check_modal$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$selection$clear_memorize_duplicated$$=function(){typeof $app$main$data$workspace$selection$clear_memorize_duplicated_67361$$==="undefined"&&($app$main$data$workspace$selection$clear_memorize_duplicated_67361$$=function($meta67362$$){this.$meta67362$=$meta67362$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$clear_memorize_duplicated_67361$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$selection$clear_memorize_duplicated_67361$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3611$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_clear_memorize_duplicated$$},$app$main$data$workspace$selection$clear_memorize_duplicated_67361$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67363$$,$meta67362__$1$$){return new $app$main$data$workspace$selection$clear_memorize_duplicated_67361$$($meta67362__$1$$)},$app$main$data$workspace$selection$clear_memorize_duplicated_67361$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67362$},$app$main$data$workspace$selection$clear_memorize_duplicated_67361$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$clear_memorize_duplicated_67361$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1934$$,$state$jscomp$371$$){return $APP.$app$common$data$dissoc_in$$($state$jscomp$371$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$3612$duplicated$$],null))});return new $app$main$data$workspace$selection$clear_memorize_duplicated_67361$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$selection$memorize_duplicated$$=function($id_original$$,$id_duplicated$$){typeof $app$main$data$workspace$selection$memorize_duplicated_67364$$==="undefined"&&($app$main$data$workspace$selection$memorize_duplicated_67364$$=function($id_original$jscomp$1$$,$id_duplicated$jscomp$1$$,$meta67365$$){this.$id_original$=$id_original$jscomp$1$$;this.$id_duplicated$=$id_duplicated$jscomp$1$$;this.$meta67365$=$meta67365$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$selection$memorize_duplicated_67364$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$memorize_duplicated_67364$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3613$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_memorize_duplicated$$},$app$main$data$workspace$selection$memorize_duplicated_67364$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67366$$,$meta67365__$1$$){return new $app$main$data$workspace$selection$memorize_duplicated_67364$$(this.$id_original$,
this.$id_duplicated$,$meta67365__$1$$)},$app$main$data$workspace$selection$memorize_duplicated_67364$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67365$},$app$main$data$workspace$selection$memorize_duplicated_67364$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$memorize_duplicated_67364$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1935$$,$state$jscomp$372$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$372$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$3612$duplicated$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$3614$id_original$$,this.$id_original$,$cljs$cst$3615$id_duplicated$$,this.$id_duplicated$],null))},$app$main$data$workspace$selection$memorize_duplicated_67364$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$memorize_duplicated_67364$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1936_stopper$jscomp$8$$,$___$1$jscomp$1242$$,$stream$jscomp$40$$){$_$jscomp$1936_stopper$jscomp$8$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3613$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_memorize_duplicated$$),$stream$jscomp$40$$);return $APP.$beicon$v2$core$map$$($app$main$data$workspace$selection$clear_memorize_duplicated$$,$APP.$beicon$v2$core$take_until$$($_$jscomp$1936_stopper$jscomp$8$$,(0,$APP.$beicon$v2$core$timer$$)(1E4)))});
return new $app$main$data$workspace$selection$memorize_duplicated_67364$$($id_original$$,$id_duplicated$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$selection$calc_duplicate_delta$$=function($obj$jscomp$203_pt_obj$$,$distance$jscomp$4_id_original$jscomp$2_map__67371_pt_original_state$jscomp$373$$,$new_pos$jscomp$2_objects$jscomp$320_pt_duplicated$$){$distance$jscomp$4_id_original$jscomp$2_map__67371_pt_original_state$jscomp$373$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($distance$jscomp$4_id_original$jscomp$2_map__67371_pt_original_state$jscomp$373$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$3612$duplicated$$],null));var $id_duplicated$jscomp$2_map__67371__$1$$=$APP.$cljs$core$__destructure_map$$($distance$jscomp$4_id_original$jscomp$2_map__67371_pt_original_state$jscomp$373$$);$distance$jscomp$4_id_original$jscomp$2_map__67371_pt_original_state$jscomp$373$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id_duplicated$jscomp$2_map__67371__$1$$,$cljs$cst$3614$id_original$$);$id_duplicated$jscomp$2_map__67371__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id_duplicated$jscomp$2_map__67371__$1$$,
$cljs$cst$3615$id_duplicated$$);var $move_QMARK_$jscomp$2$$=$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$203_pt_obj$$)&&!$APP.$app$common$types$component$instance_head_QMARK_$$($obj$jscomp$203_pt_obj$$);if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($distance$jscomp$4_id_original$jscomp$2_map__67371_pt_original_state$jscomp$373$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$203_pt_obj$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id_duplicated$jscomp$2_map__67371__$1$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$203_pt_obj$$))||!$APP.$cljs$core$contains_QMARK_$$($new_pos$jscomp$2_objects$jscomp$320_pt_duplicated$$,$distance$jscomp$4_id_original$jscomp$2_map__67371_pt_original_state$jscomp$373$$)||!$APP.$cljs$core$contains_QMARK_$$($new_pos$jscomp$2_objects$jscomp$320_pt_duplicated$$,$id_duplicated$jscomp$2_map__67371__$1$$))return $move_QMARK_$jscomp$2$$?$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$203_pt_obj$$)+
50,0):$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0);$distance$jscomp$4_id_original$jscomp$2_map__67371_pt_original_state$jscomp$373$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_pos$jscomp$2_objects$jscomp$320_pt_duplicated$$,$distance$jscomp$4_id_original$jscomp$2_map__67371_pt_original_state$jscomp$373$$)));$new_pos$jscomp$2_objects$jscomp$320_pt_duplicated$$=
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_pos$jscomp$2_objects$jscomp$320_pt_duplicated$$,$id_duplicated$jscomp$2_map__67371__$1$$)));$obj$jscomp$203_pt_obj$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$203_pt_obj$$));$distance$jscomp$4_id_original$jscomp$2_map__67371_pt_original_state$jscomp$373$$=
$APP.$app$common$geom$point$subtract$$($new_pos$jscomp$2_objects$jscomp$320_pt_duplicated$$,$distance$jscomp$4_id_original$jscomp$2_map__67371_pt_original_state$jscomp$373$$);$new_pos$jscomp$2_objects$jscomp$320_pt_duplicated$$=$APP.$app$common$geom$point$add$$($new_pos$jscomp$2_objects$jscomp$320_pt_duplicated$$,$distance$jscomp$4_id_original$jscomp$2_map__67371_pt_original_state$jscomp$373$$);return $APP.$app$common$geom$point$subtract$$($new_pos$jscomp$2_objects$jscomp$320_pt_duplicated$$,$obj$jscomp$203_pt_obj$$)};
$APP.$app$main$data$workspace$selection$duplicate_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($ids$jscomp$68$$,$p__67379$$){var $map__67380__$1$$=$APP.$cljs$core$__destructure_map$$($p__67379$$),$move_delta_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67380__$1$$,$cljs$cst$3616$move_delta_QMARK_$$,!1),$alt_duplication_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67380__$1$$,$cljs$cst$3545$alt_duplication_QMARK_$$,!1),$change_selection_QMARK_$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67380__$1$$,$APP.$cljs$cst$3617$change_selection_QMARK_$$,!0),$return_ref$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67380__$1$$,$APP.$cljs$cst$3618$return_ref$$,null);typeof $app$main$data$workspace$selection$duplicate_shapes_67381$$==="undefined"&&($app$main$data$workspace$selection$duplicate_shapes_67381$$=function($ids$jscomp$69$$,$p__67379$jscomp$1$$,$map__67380$jscomp$1$$,$move_delta_QMARK_$jscomp$1$$,$alt_duplication_QMARK_$jscomp$2$$,
$change_selection_QMARK_$jscomp$1$$,$return_ref$jscomp$1$$,$meta67382$$){this.ids=$ids$jscomp$69$$;this.$p__67379$=$p__67379$jscomp$1$$;this.$map__67380$=$map__67380$jscomp$1$$;this.$move_delta_QMARK_$=$move_delta_QMARK_$jscomp$1$$;this.$alt_duplication_QMARK_$=$alt_duplication_QMARK_$jscomp$2$$;this.$change_selection_QMARK_$=$change_selection_QMARK_$jscomp$1$$;this.$return_ref$=$return_ref$jscomp$1$$;this.$meta67382$=$meta67382$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$selection$duplicate_shapes_67381$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$duplicate_shapes_67381$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3619$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_duplicate_shapes$$},$app$main$data$workspace$selection$duplicate_shapes_67381$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67383$$,$meta67382__$1$$){return new $app$main$data$workspace$selection$duplicate_shapes_67381$$(this.ids,
this.$p__67379$,this.$map__67380$,this.$move_delta_QMARK_$,this.$alt_duplication_QMARK_$,this.$change_selection_QMARK_$,this.$return_ref$,$meta67382__$1$$)},$app$main$data$workspace$selection$duplicate_shapes_67381$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67382$},$app$main$data$workspace$selection$duplicate_shapes_67381$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$duplicate_shapes_67381$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($id_original$jscomp$3_it$jscomp$151_page$jscomp$65$$,$changes__$1$jscomp$57_library_data$jscomp$32_state$jscomp$374_tags$jscomp$10$$){var $self__$jscomp$4287$$=this;$id_original$jscomp$3_it$jscomp$151_page$jscomp$65$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($changes__$1$jscomp$57_library_data$jscomp$32_state$jscomp$374_tags$jscomp$10$$);var $objects$jscomp$321$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($id_original$jscomp$3_it$jscomp$151_page$jscomp$65$$),
$ids__$1$jscomp$6$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$getf$$($objects$jscomp$321$$)),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__67372_SHARP_$$){var $parent$jscomp$inline_6476$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$321$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__67372_SHARP_$$));
return!$app$common$types$component$in_component_copy_not_head_QMARK_$$($p1__67372_SHARP_$$)&&(!$APP.$app$common$types$component$instance_head_QMARK_$$($p1__67372_SHARP_$$)||!$APP.$app$common$types$component$in_component_copy_QMARK_$$($parent$jscomp$inline_6476$$))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$)),$self__$jscomp$4287$$.ids);if($APP.$cljs$core$seq$$($ids__$1$jscomp$6$$)){var $delta$jscomp$33_new_ids_obj$jscomp$204$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$321$$,
$APP.$cljs$core$first$$($ids__$1$jscomp$6$$));$delta$jscomp$33_new_ids_obj$jscomp$204$$=$APP.$cljs$core$truth_$$($self__$jscomp$4287$$.$move_delta_QMARK_$)?$app$main$data$workspace$selection$calc_duplicate_delta$$($delta$jscomp$33_new_ids_obj$jscomp$204$$,$changes__$1$jscomp$57_library_data$jscomp$32_state$jscomp$374_tags$jscomp$10$$,$objects$jscomp$321$$):$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0);var $file_id$jscomp$93$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($changes__$1$jscomp$57_library_data$jscomp$32_state$jscomp$374_tags$jscomp$10$$),
$libraries$jscomp$64$$=$APP.$app$main$data$helpers$lookup_libraries$$($changes__$1$jscomp$57_library_data$jscomp$32_state$jscomp$374_tags$jscomp$10$$);$changes__$1$jscomp$57_library_data$jscomp$32_state$jscomp$374_tags$jscomp$10$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($changes__$1$jscomp$57_library_data$jscomp$32_state$jscomp$374_tags$jscomp$10$$,$file_id$jscomp$93$$);var $changes$jscomp$161$$=$APP.$app$common$logic$libraries$generate_duplicate_changes_update_indices$$($APP.$app$common$logic$libraries$generate_duplicate_changes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$objects$jscomp$321$$,$id_original$jscomp$3_it$jscomp$151_page$jscomp$65$$,$ids__$1$jscomp$6$$,$delta$jscomp$33_new_ids_obj$jscomp$204$$,$libraries$jscomp$64$$,$changes__$1$jscomp$57_library_data$jscomp$32_state$jscomp$374_tags$jscomp$10$$,$file_id$jscomp$93$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3545$alt_duplication_QMARK_$$,$self__$jscomp$4287$$.$alt_duplication_QMARK_$],null)])),$objects$jscomp$321$$,$ids__$1$jscomp$6$$);
$changes__$1$jscomp$57_library_data$jscomp$32_state$jscomp$374_tags$jscomp$10$$=function(){var $or__5025__auto__$jscomp$687$$=$APP.$cljs$cst$3142$tags$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$161$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$687$$)?$or__5025__auto__$jscomp$687$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$}();$changes__$1$jscomp$57_library_data$jscomp$32_state$jscomp$374_tags$jscomp$10$$=$APP.$cljs$core$truth_$$($self__$jscomp$4287$$.$alt_duplication_QMARK_$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$161$$,$APP.$cljs$cst$3142$tags$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($changes__$1$jscomp$57_library_data$jscomp$32_state$jscomp$374_tags$jscomp$10$$,$cljs$cst$3620$alt_duplication$$)):$changes$jscomp$161$$;$id_original$jscomp$3_it$jscomp$151_page$jscomp$65$$=$APP.$cljs$core$first$$($ids__$1$jscomp$6$$);$delta$jscomp$33_new_ids_obj$jscomp$204$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67375_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($p1__67375_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2611$obj$$,$APP.$cljs$cst$266$id$$],null))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($G__67388_p1__67374_SHARP_$$){$G__67388_p1__67374_SHARP_$$=$APP.$cljs$cst$3531$old_id$$.$cljs$core$IFn$_invoke$arity$1$($G__67388_p1__67374_SHARP_$$);
return $ids__$1$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$ids__$1$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($G__67388_p1__67374_SHARP_$$):$ids__$1$jscomp$6$$($G__67388_p1__67374_SHARP_$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67373_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__67373_SHARP_$$),$APP.$cljs$cst$2610$add_obj$$)},$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes__$1$jscomp$57_library_data$jscomp$32_state$jscomp$374_tags$jscomp$10$$)))));
var $id_duplicated$jscomp$3$$=$APP.$cljs$core$first$$($delta$jscomp$33_new_ids_obj$jscomp$204$$),$frames$jscomp$12$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__67376_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$321$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__67376_SHARP_$$,$APP.$cljs$cst$1607$frame_id$$],
null))}),$ids__$1$jscomp$6$$),$undo_id$$=Symbol();return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$map$$(function($shape$jscomp$437_shape_id$jscomp$72$$){$shape$jscomp$437_shape_id$jscomp$72$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$321$$,$shape$jscomp$437_shape_id$jscomp$72$$);var $parent_type$$=$app$common$files$helpers$get_shape_type$$($objects$jscomp$321$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$437_shape_id$jscomp$72$$)),
$external_lib_QMARK_$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$93$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$437_shape_id$jscomp$72$$)),$component$jscomp$72$$=$app$common$types$container$get_component_from_shape$$($shape$jscomp$437_shape_id$jscomp$72$$,$libraries$jscomp$64$$);return $APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$437_shape_id$jscomp$72$$)?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"use-library-component",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:duplicate-shapes",$cljs$cst$3621$is_external_library$$,$external_lib_QMARK_$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$437_shape_id$jscomp$72$$,$APP.$cljs$cst$139$type$$),$APP.$cljs$cst$3622$parent_type$$,$parent_type$$,$cljs$cst$3623$is_variant$$,$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$72$$)],
null)):$app$common$files$helpers$has_layout_QMARK_$$($objects$jscomp$321$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$437_shape_id$jscomp$72$$))?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"layout-add-element",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:duplicate-shapes",$APP.$cljs$cst$139$type$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$437_shape_id$jscomp$72$$,
$APP.$cljs$cst$139$type$$),$APP.$cljs$cst$3622$parent_type$$,$parent_type$$],null)):$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-shape",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:duplicate-shapes",$APP.$cljs$cst$139$type$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$437_shape_id$jscomp$72$$,$APP.$cljs$cst$139$type$$),$APP.$cljs$cst$3622$parent_type$$,
$parent_type$$],null))},$APP.$beicon$v2$core$from$$($ids__$1$jscomp$6$$)),$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $self__$jscomp$4287$$.$return_ref$!=null?$APP.$cljs$core$reset_BANG_$$($self__$jscomp$4287$$.$return_ref$,$id_duplicated$jscomp$3$$):null},(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$$),$APP.$app$main$data$changes$commit_changes$$($changes__$1$jscomp$57_library_data$jscomp$32_state$jscomp$374_tags$jscomp$10$$),
$APP.$cljs$core$truth_$$($self__$jscomp$4287$$.$change_selection_QMARK_$)?$APP.$app$main$data$workspace$selection$select_shapes$$($delta$jscomp$33_new_ids_obj$jscomp$204$$):null,$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$frames$jscomp$12$$],null)),$app$main$data$workspace$selection$memorize_duplicated$$($id_original$jscomp$3_it$jscomp$151_page$jscomp$65$$,$id_duplicated$jscomp$3$$),
$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$$))))}return null});return new $app$main$data$workspace$selection$duplicate_shapes_67381$$($ids$jscomp$68$$,$p__67379$$,$map__67380__$1$$,$move_delta_QMARK_$$,$alt_duplication_QMARK_$jscomp$1$$,$change_selection_QMARK_$$,$return_ref$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$selection$duplicate_selected$cljs$0core$0IFn$0_invoke$0arity$02$$=function($move_delta_QMARK_$jscomp$3$$,$alt_duplication_QMARK_$jscomp$3$$){typeof $app$main$data$workspace$selection$duplicate_selected_67391$$==="undefined"&&($app$main$data$workspace$selection$duplicate_selected_67391$$=function($move_delta_QMARK_$jscomp$4$$,$alt_duplication_QMARK_$jscomp$4$$,$meta67392$$){this.$move_delta_QMARK_$=$move_delta_QMARK_$jscomp$4$$;this.$alt_duplication_QMARK_$=$alt_duplication_QMARK_$jscomp$4$$;
this.$meta67392$=$meta67392$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$duplicate_selected_67391$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$duplicate_selected_67391$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3625$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_duplicate_selected$$},$app$main$data$workspace$selection$duplicate_selected_67391$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_67393$$,$meta67392__$1$$){return new $app$main$data$workspace$selection$duplicate_selected_67391$$(this.$move_delta_QMARK_$,this.$alt_duplication_QMARK_$,$meta67392__$1$$)},$app$main$data$workspace$selection$duplicate_selected_67391$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67392$},$app$main$data$workspace$selection$duplicate_selected_67391$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$duplicate_selected_67391$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1938_selected$jscomp$23$$,$state$jscomp$375$$){return $APP.$cljs$core$not$$(this.$move_delta_QMARK_$)||$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$375$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1289$transform$$],null))==null?($_$jscomp$1938_selected$jscomp$23$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$375$$),
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$duplicate_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($_$jscomp$1938_selected$jscomp$23$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3616$move_delta_QMARK_$$,this.$move_delta_QMARK_$,$cljs$cst$3545$alt_duplication_QMARK_$$,this.$alt_duplication_QMARK_$])))):null});return new $app$main$data$workspace$selection$duplicate_selected_67391$$($move_delta_QMARK_$jscomp$3$$,$alt_duplication_QMARK_$jscomp$3$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$selection$update_focus_shapes$$=function($added$$,$removed$jscomp$1$$){typeof $app$main$data$workspace$selection$update_focus_shapes_67403$$==="undefined"&&($app$main$data$workspace$selection$update_focus_shapes_67403$$=function($added$jscomp$1$$,$removed$jscomp$2$$,$meta67404$$){this.$added$=$added$jscomp$1$$;this.$removed$=$removed$jscomp$2$$;this.$meta67404$=$meta67404$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$update_focus_shapes_67403$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$update_focus_shapes_67403$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3626$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_update_focus_shapes$$},$app$main$data$workspace$selection$update_focus_shapes_67403$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67405$$,$meta67404__$1$$){return new $app$main$data$workspace$selection$update_focus_shapes_67403$$(this.$added$,this.$removed$,
$meta67404__$1$$)},$app$main$data$workspace$selection$update_focus_shapes_67403$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67404$},$app$main$data$workspace$selection$update_focus_shapes_67403$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$update_focus_shapes_67403$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1940_focus__$1_objects$jscomp$322$$,$state$jscomp$377$$){$_$jscomp$1940_focus__$1_objects$jscomp$322$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$377$$);var $focus$jscomp$8$$=$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2226$workspace_focus_selected$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$377$$),this.$added$),this.$removed$);$_$jscomp$1940_focus__$1_objects$jscomp$322$$=$APP.$app$common$files$helpers$clean_loops$$($_$jscomp$1940_focus__$1_objects$jscomp$322$$,
$focus$jscomp$8$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$377$$,$APP.$cljs$cst$2226$workspace_focus_selected$$,$_$jscomp$1940_focus__$1_objects$jscomp$322$$)});return new $app$main$data$workspace$selection$update_focus_shapes_67403$$($added$$,$removed$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$selection$toggle_focus_mode$$=function(){typeof $app$main$data$workspace$selection$toggle_focus_mode_67407$$==="undefined"&&($app$main$data$workspace$selection$toggle_focus_mode_67407$$=function($meta67408$$){this.$meta67408$=$meta67408$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$toggle_focus_mode_67407$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$toggle_focus_mode_67407$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3627$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_toggle_focus_mode$$},$app$main$data$workspace$selection$toggle_focus_mode_67407$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67409$$,$meta67408__$1$$){return new $app$main$data$workspace$selection$toggle_focus_mode_67407$$($meta67408__$1$$)},$app$main$data$workspace$selection$toggle_focus_mode_67407$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67408$},$app$main$data$workspace$selection$toggle_focus_mode_67407$$.prototype.$app$main$data$event$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$toggle_focus_mode_67407$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return $APP.$cljs$core$PersistentArrayMap$EMPTY$$},$app$main$data$workspace$selection$toggle_focus_mode_67407$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$toggle_focus_mode_67407$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1942_selected$jscomp$24$$,
$state$jscomp$378$$){$_$jscomp$1942_selected$jscomp$24$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$378$$);var $have_selection_QMARK_$$=$APP.$app$common$data$not_empty_QMARK_$$($_$jscomp$1942_selected$jscomp$24$$);return $APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$2226$workspace_focus_selected$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$378$$))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$378$$,
$APP.$cljs$cst$1920$workspace_local$$,$cljs$cst$3628$workspace_pre_focus$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$378$$)),$APP.$cljs$cst$2226$workspace_focus_selected$$),$cljs$cst$3628$workspace_pre_focus$$):$have_selection_QMARK_$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$378$$,$APP.$cljs$cst$2226$workspace_focus_selected$$,$_$jscomp$1942_selected$jscomp$24$$),$cljs$cst$3628$workspace_pre_focus$$,$APP.$cljs$cst$1920$workspace_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$378$$)):
$state$jscomp$378$$},$app$main$data$workspace$selection$toggle_focus_mode_67407$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$toggle_focus_mode_67407$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1943$$,$state$jscomp$379$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$379$$)},$app$main$data$workspace$selection$toggle_focus_mode_67407$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$toggle_focus_mode_67407$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1944_stopper$jscomp$9$$,$state$jscomp$380$$,$stream$jscomp$41$$){$_$jscomp$1944_stopper$jscomp$9$$=$APP.$beicon$v2$core$filter$$(function($p1__67406_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3627$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_toggle_focus_mode$$,$APP.$potok$v2$core$type$$($p1__67406_SHARP_$$))||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3629$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_finalize_page$$,$APP.$potok$v2$core$type$$($p1__67406_SHARP_$$))},$stream$jscomp$41$$);return $APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$2226$workspace_focus_selected$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$380$$))?$APP.$beicon$v2$core$take_until$$($_$jscomp$1944_stopper$jscomp$9$$,$APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$zoom$zoom_to_selected_shape$$,
$APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$00$$()),$APP.$beicon$v2$core$merge_map$$(function($p__67413_removed$jscomp$3$$){var $added$jscomp$2_old_keys$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67413_removed$jscomp$3$$,0,null),$new_keys$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67413_removed$jscomp$3$$,1,null);$p__67413_removed$jscomp$3$$=$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($added$jscomp$2_old_keys$jscomp$1$$,
$new_keys$jscomp$3$$);$added$jscomp$2_old_keys$jscomp$1$$=$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($new_keys$jscomp$3$$,$added$jscomp$2_old_keys$jscomp$1$$);return $APP.$app$common$data$not_empty_QMARK_$$($added$jscomp$2_old_keys$jscomp$1$$)||$APP.$app$common$data$not_empty_QMARK_$$($p__67413_removed$jscomp$3$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$selection$update_focus_shapes$$($added$jscomp$2_old_keys$jscomp$1$$,$p__67413_removed$jscomp$3$$)):$APP.$beicon$v2$core$empty$$()},
$APP.$beicon$v2$core$buffer$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$beicon$v2$core$map$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$,$APP.$cljs$core$keys$$),$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$refs$workspace_page_objects$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!0],null))))))):null});return new $app$main$data$workspace$selection$toggle_focus_mode_67407$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$common$files$shapes_helpers$prepare_add_shape$$=function($changes$jscomp$162$$,$shape$jscomp$438$$,$objects$jscomp$323$$){var $index$jscomp$268$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($shape$jscomp$438$$)),$id$jscomp$494$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$438$$),$changes__$1$jscomp$58_mod_QMARK_$$=$cljs$cst$3630$mod_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($shape$jscomp$438$$)),$vec__66046$$=
$APP.$cljs$core$truth_$$($changes__$1$jscomp$58_mod_QMARK_$$)?null:$APP.$cljs$cst$3525$cell$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($shape$jscomp$438$$)),$row$jscomp$23$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__66046$$,0,null),$column$jscomp$29$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__66046$$,1,null);$changes__$1$jscomp$58_mod_QMARK_$$=function(){var $G__66049$$=function(){var $G__66053$$=function(){var $G__66054_G__66055$jscomp$inline_12364_G__66056$jscomp$inline_12365$$=
$APP.$app$common$files$changes_builder$with_objects$$($changes$jscomp$162$$,$objects$jscomp$323$$);$G__66054_G__66055$jscomp$inline_12364_G__66056$jscomp$inline_12365$$=$index$jscomp$268$$!=null?$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66054_G__66055$jscomp$inline_12364_G__66056$jscomp$inline_12365$$,$shape$jscomp$438$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1795$index$$,$index$jscomp$268$$],null)):$G__66054_G__66055$jscomp$inline_12364_G__66056$jscomp$inline_12365$$;
$G__66054_G__66055$jscomp$inline_12364_G__66056$jscomp$inline_12365$$=$index$jscomp$268$$==null?$APP.$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$02$$($G__66054_G__66055$jscomp$inline_12364_G__66056$jscomp$inline_12365$$,$shape$jscomp$438$$):$G__66054_G__66055$jscomp$inline_12364_G__66056$jscomp$inline_12365$$;return $APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$438$$)!=null?$APP.$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$04$$($G__66054_G__66055$jscomp$inline_12364_G__66056$jscomp$inline_12365$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$438$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$438$$],null),$index$jscomp$268$$):$G__66054_G__66055$jscomp$inline_12364_G__66056$jscomp$inline_12365$$}();return $vec__66046$$!=null?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66053$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$438$$)],null),function($p1__66041_SHARP_$$){return $app$common$types$shape$layout$push_into_cell$$($p1__66041_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$494$$],null),$row$jscomp$23$$,$column$jscomp$29$$)}):$G__66053$$}();return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$323$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$438$$)))?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($G__66049$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$438$$)],null),$APP.$app$common$types$shape$layout$assign_cells$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,
!0],null)):$G__66049$$}();return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$438$$,$changes__$1$jscomp$58_mod_QMARK_$$],null)};
$app$common$files$shapes_helpers$prepare_move_shapes_into_frame$$=function($G__66075_changes$jscomp$163$$,$frame_id$jscomp$46$$,$shapes$jscomp$47_shapes__$1$jscomp$6$$,$objects$jscomp$324$$,$remove_layout_data_QMARK_$$){var $parent_id$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$324$$,$frame_id$jscomp$46$$),$APP.$cljs$cst$1619$parent_id$$);$shapes$jscomp$47_shapes__$1$jscomp$6$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66066_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__66066_SHARP_$$,
$parent_id$jscomp$46$$)},$shapes$jscomp$47_shapes__$1$jscomp$6$$);var $to_move$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$324$$),$shapes$jscomp$47_shapes__$1$jscomp$6$$));return $APP.$cljs$core$truth_$$($to_move$$)?($G__66075_changes$jscomp$163$$=$APP.$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($remove_layout_data_QMARK_$$)?
$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$324$$,$frame_id$jscomp$46$$)):$remove_layout_data_QMARK_$$)?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66075_changes$jscomp$163$$,$shapes$jscomp$47_shapes__$1$jscomp$6$$,$app$common$types$shape$layout$remove_layout_item_data$$):$G__66075_changes$jscomp$163$$,$shapes$jscomp$47_shapes__$1$jscomp$6$$,function($p1__66067_SHARP_$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__66067_SHARP_$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__66067_SHARP_$$,$APP.$cljs$cst$1875$hide_in_viewer$$,!0):$p1__66067_SHARP_$$}),$frame_id$jscomp$46$$,$to_move$$,0),$APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$324$$,$frame_id$jscomp$46$$))?$APP.$app$common$files$changes_builder$reorder_grid_children$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($G__66075_changes$jscomp$163$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$46$$],null),$APP.$app$common$types$shape$layout$assign_cells$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$46$$],null)):$G__66075_changes$jscomp$163$$):$G__66075_changes$jscomp$163$$};
$app$main$data$workspace$shapes$add_undo_group$$=function($changes$jscomp$168$$,$items$jscomp$38_prev_item_state$jscomp$381$$){var $index$jscomp$273_or__5025__auto__$jscomp$inline_6484_undo$jscomp$5_undo_group$jscomp$9$$=$APP.$cljs$cst$3563$workspace_undo$$.$cljs$core$IFn$_invoke$arity$1$($items$jscomp$38_prev_item_state$jscomp$381$$);$items$jscomp$38_prev_item_state$jscomp$381$$=$APP.$cljs$cst$1838$items$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$273_or__5025__auto__$jscomp$inline_6484_undo$jscomp$5_undo_group$jscomp$9$$);
$index$jscomp$273_or__5025__auto__$jscomp$inline_6484_undo$jscomp$5_undo_group$jscomp$9$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$273_or__5025__auto__$jscomp$inline_6484_undo$jscomp$5_undo_group$jscomp$9$$);$index$jscomp$273_or__5025__auto__$jscomp$inline_6484_undo$jscomp$5_undo_group$jscomp$9$$=$APP.$cljs$core$truth_$$($index$jscomp$273_or__5025__auto__$jscomp$inline_6484_undo$jscomp$5_undo_group$jscomp$9$$)?$index$jscomp$273_or__5025__auto__$jscomp$inline_6484_undo$jscomp$5_undo_group$jscomp$9$$:
$APP.$cljs$core$count$$($items$jscomp$38_prev_item_state$jscomp$381$$)-1;$items$jscomp$38_prev_item_state$jscomp$381$$=$APP.$cljs$core$empty_QMARK_$$($items$jscomp$38_prev_item_state$jscomp$381$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$273_or__5025__auto__$jscomp$inline_6484_undo$jscomp$5_undo_group$jscomp$9$$,-1)?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$38_prev_item_state$jscomp$381$$,$index$jscomp$273_or__5025__auto__$jscomp$inline_6484_undo$jscomp$5_undo_group$jscomp$9$$);
$index$jscomp$273_or__5025__auto__$jscomp$inline_6484_undo$jscomp$5_undo_group$jscomp$9$$=$APP.$cljs$cst$3138$undo_group$$.$cljs$core$IFn$_invoke$arity$1$($items$jscomp$38_prev_item_state$jscomp$381$$);return $index$jscomp$273_or__5025__auto__$jscomp$inline_6484_undo$jscomp$5_undo_group$jscomp$9$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$168$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3133$redo_changes$$,0,$APP.$cljs$cst$139$type$$],null)),$APP.$cljs$cst$2612$mod_obj$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$38_prev_item_state$jscomp$381$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3133$redo_changes$$,0,$APP.$cljs$cst$139$type$$],null)),$APP.$cljs$cst$2610$add_obj$$)&&$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$3142$tags$$.$cljs$core$IFn$_invoke$arity$1$($items$jscomp$38_prev_item_state$jscomp$381$$),
$cljs$cst$3620$alt_duplication$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$168$$,$APP.$cljs$cst$3138$undo_group$$,$index$jscomp$273_or__5025__auto__$jscomp$inline_6484_undo$jscomp$5_undo_group$jscomp$9$$):$changes$jscomp$168$$};
$app$main$data$workspace$shapes$update_shapes_buffer_start$$=function(){typeof $app$main$data$workspace$shapes$update_shapes_buffer_start_67426$$==="undefined"&&($app$main$data$workspace$shapes$update_shapes_buffer_start_67426$$=function($meta67427$$){this.$meta67427$=$meta67427$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$update_shapes_buffer_start_67426$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$shapes$update_shapes_buffer_start_67426$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3631$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_start$$},$app$main$data$workspace$shapes$update_shapes_buffer_start_67426$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67428$$,$meta67427__$1$$){return new $app$main$data$workspace$shapes$update_shapes_buffer_start_67426$$($meta67427__$1$$)},$app$main$data$workspace$shapes$update_shapes_buffer_start_67426$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67427$},$app$main$data$workspace$shapes$update_shapes_buffer_start_67426$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$update_shapes_buffer_start_67426$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1945$$,$state$jscomp$382$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$382$$,$cljs$cst$3632$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer$$,
!0)});return new $app$main$data$workspace$shapes$update_shapes_buffer_start_67426$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shapes$update_shapes_buffer_stop$$=function(){typeof $app$main$data$workspace$shapes$update_shapes_buffer_stop_67431$$==="undefined"&&($app$main$data$workspace$shapes$update_shapes_buffer_stop_67431$$=function($meta67432$$){this.$meta67432$=$meta67432$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$update_shapes_buffer_stop_67431$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$shapes$update_shapes_buffer_stop_67431$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3633$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_stop$$},$app$main$data$workspace$shapes$update_shapes_buffer_stop_67431$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67433$$,$meta67432__$1$$){return new $app$main$data$workspace$shapes$update_shapes_buffer_stop_67431$$($meta67432__$1$$)},$app$main$data$workspace$shapes$update_shapes_buffer_stop_67431$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67432$},$app$main$data$workspace$shapes$update_shapes_buffer_stop_67431$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$update_shapes_buffer_stop_67431$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1946$$,$state$jscomp$383$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$383$$,$cljs$cst$3632$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer$$,
!1)});return new $app$main$data$workspace$shapes$update_shapes_buffer_stop_67431$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shapes$update_shapes_buffer_commit$$=function(){typeof $app$main$data$workspace$shapes$update_shapes_buffer_commit_67437$$==="undefined"&&($app$main$data$workspace$shapes$update_shapes_buffer_commit_67437$$=function($meta67438$$){this.$meta67438$=$meta67438$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$update_shapes_buffer_commit_67437$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$shapes$update_shapes_buffer_commit_67437$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3634$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_commit$$},$app$main$data$workspace$shapes$update_shapes_buffer_commit_67437$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67439$$,$meta67438__$1$$){return new $app$main$data$workspace$shapes$update_shapes_buffer_commit_67437$$($meta67438__$1$$)},$app$main$data$workspace$shapes$update_shapes_buffer_commit_67437$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67438$},$app$main$data$workspace$shapes$update_shapes_buffer_commit_67437$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$update_shapes_buffer_commit_67437$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1947$$,$state$jscomp$384$$){return $APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$changes$commit_changes$$,$APP.$cljs$core$vals$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$384$$,
$cljs$cst$3635$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_changes$$))))});return new $app$main$data$workspace$shapes$update_shapes_buffer_commit_67437$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shapes$lookup_changed_objects$$=function($state$jscomp$385$$,$page_id$jscomp$112$$){var $or__5025__auto__$jscomp$693$$=$app$common$files$changes_builder$lookup_objects$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$385$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3635$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_changes$$,$page_id$jscomp$112$$],null)));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$693$$)?
$or__5025__auto__$jscomp$693$$:$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$385$$,$page_id$jscomp$112$$)};
$app$main$data$workspace$shapes$update_shapes_buffer$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$71$$,$update_fn$jscomp$16$$,$p__67452$$){var $map__67453__$1$$=$APP.$cljs$core$__destructure_map$$($p__67452$$),$changed_sub_attr$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67453__$1$$,$APP.$cljs$cst$3521$changed_sub_attr$$),$undo_group$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67453__$1$$,$APP.$cljs$cst$3138$undo_group$$),$save_undo_QMARK_$jscomp$5$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67453__$1$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!0),$ignore_tree$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67453__$1$$,$cljs$cst$3522$ignore_tree$$),$reg_objects_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67453__$1$$,$APP.$cljs$cst$3636$reg_objects_QMARK_$$,!1),$stack_undo_QMARK_$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67453__$1$$,$APP.$cljs$cst$3141$stack_undo_QMARK_$$,
!1),$with_objects_QMARK_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67453__$1$$,$APP.$cljs$cst$3175$with_objects_QMARK_$$,!1),$ignore_touched$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67453__$1$$,$APP.$cljs$cst$2556$ignore_touched$$,!1),$translation_QMARK_$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67453__$1$$,$cljs$cst$3145$translation_QMARK_$$),$page_id$jscomp$113$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67453__$1$$,
$APP.$cljs$cst$2043$page_id$$),$attrs$jscomp$77$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67453__$1$$,$APP.$cljs$cst$2645$attrs$$),$cur_event$$=Symbol();typeof $app$main$data$workspace$shapes$update_shapes_buffer_67454$$==="undefined"&&($app$main$data$workspace$shapes$update_shapes_buffer_67454$$=function($changed_sub_attr$jscomp$4$$,$undo_group$jscomp$11$$,$save_undo_QMARK_$jscomp$6$$,$ignore_tree$jscomp$2$$,$reg_objects_QMARK_$jscomp$1$$,$stack_undo_QMARK_$jscomp$6$$,$props$jscomp$151$$,
$with_objects_QMARK_$jscomp$4$$,$cur_event$jscomp$1$$,$ignore_touched$jscomp$11$$,$p__67452$jscomp$1$$,$translation_QMARK_$jscomp$7$$,$ids$jscomp$72$$,$page_id$jscomp$114$$,$update_fn$jscomp$17$$,$map__67453$jscomp$1$$,$attrs$jscomp$78$$,$meta67455$$){this.$changed_sub_attr$=$changed_sub_attr$jscomp$4$$;this.$undo_group$=$undo_group$jscomp$11$$;this.$save_undo_QMARK_$=$save_undo_QMARK_$jscomp$6$$;this.$ignore_tree$=$ignore_tree$jscomp$2$$;this.$reg_objects_QMARK_$=$reg_objects_QMARK_$jscomp$1$$;this.$stack_undo_QMARK_$=
$stack_undo_QMARK_$jscomp$6$$;this.props=$props$jscomp$151$$;this.$with_objects_QMARK_$=$with_objects_QMARK_$jscomp$4$$;this.$cur_event$=$cur_event$jscomp$1$$;this.$ignore_touched$=$ignore_touched$jscomp$11$$;this.$p__67452$=$p__67452$jscomp$1$$;this.$translation_QMARK_$=$translation_QMARK_$jscomp$7$$;this.ids=$ids$jscomp$72$$;this.$page_id$=$page_id$jscomp$114$$;this.$update_fn$=$update_fn$jscomp$17$$;this.$map__67453$=$map__67453$jscomp$1$$;this.$attrs$=$attrs$jscomp$78$$;this.$meta67455$=$meta67455$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$update_shapes_buffer_67454$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$update_shapes_buffer_67454$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3632$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer$$},$app$main$data$workspace$shapes$update_shapes_buffer_67454$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_67456$$,$meta67455__$1$$){return new $app$main$data$workspace$shapes$update_shapes_buffer_67454$$(this.$changed_sub_attr$,this.$undo_group$,this.$save_undo_QMARK_$,this.$ignore_tree$,this.$reg_objects_QMARK_$,this.$stack_undo_QMARK_$,this.props,this.$with_objects_QMARK_$,this.$cur_event$,this.$ignore_touched$,this.$p__67452$,this.$translation_QMARK_$,this.ids,this.$page_id$,this.$update_fn$,this.$map__67453$,this.$attrs$,$meta67455__$1$$)},$app$main$data$workspace$shapes$update_shapes_buffer_67454$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67455$},$app$main$data$workspace$shapes$update_shapes_buffer_67454$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$update_shapes_buffer_67454$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($it$jscomp$152$$,$state$jscomp$386$$){var $self__$jscomp$4322$$=this,$it__$1$jscomp$37$$=this;if($cljs$cst$3637$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_event$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$386$$)==
null)return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$386$$,$cljs$cst$3637$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_event$$,$self__$jscomp$4322$$.$cur_event$);var $page_id__$1$jscomp$3$$=function(){var $or__5025__auto__$jscomp$694$$=$self__$jscomp$4322$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$694$$)?$or__5025__auto__$jscomp$694$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$386$$,$APP.$cljs$cst$1918$current_page_id$$)}(),
$objects$jscomp$329$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$386$$,$page_id__$1$jscomp$3$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$386$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3635$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_changes$$,$page_id__$1$jscomp$3$$],null),function($G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$){$APP.$cljs$core$truth_$$($G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$)||
($G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$=$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$($it__$1$jscomp$37$$,$page_id__$1$jscomp$3$$),$objects$jscomp$329$$),$G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$,$self__$jscomp$4322$$.$save_undo_QMARK_$),$G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$=
$app$common$files$changes_builder$set_stack_undo_QMARK_$$($G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$,$self__$jscomp$4322$$.$stack_undo_QMARK_$),$G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$=
$APP.$cljs$core$truth_$$($self__$jscomp$4322$$.$undo_group$)?$APP.$app$common$files$changes_builder$set_undo_group$$($G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$,$self__$jscomp$4322$$.$undo_group$):$G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$);
$G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$=$app$common$logic$shapes$generate_update_shapes$$($G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$,
$self__$jscomp$4322$$.ids,$self__$jscomp$4322$$.$update_fn$,null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2645$attrs$$,$self__$jscomp$4322$$.$attrs$,$APP.$cljs$cst$3521$changed_sub_attr$$,$self__$jscomp$4322$$.$changed_sub_attr$,$cljs$cst$3522$ignore_tree$$,$self__$jscomp$4322$$.$ignore_tree$,$APP.$cljs$cst$2556$ignore_touched$$,$self__$jscomp$4322$$.$ignore_touched$,$APP.$cljs$cst$3175$with_objects_QMARK_$$,$self__$jscomp$4322$$.$with_objects_QMARK_$],null));$G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$=
$APP.$cljs$core$truth_$$($self__$jscomp$4322$$.$reg_objects_QMARK_$)?$APP.$app$common$files$changes_builder$resize_parents$$($G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$,$self__$jscomp$4322$$.ids):$G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$;
return $app$common$files$changes_builder$set_translation_QMARK_$$($G__67457$jscomp$inline_12369_G__67458$jscomp$inline_12368_JSCompiler_inline_result$jscomp$10851_JSCompiler_inline_result$jscomp$14059_JSCompiler_inline_result$jscomp$inline_12367_changes$jscomp$169_changes$jscomp$inline_14331$$,$self__$jscomp$4322$$.$translation_QMARK_$)})},$app$main$data$workspace$shapes$update_shapes_buffer_67454$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$update_shapes_buffer_67454$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1948_stopper$jscomp$10$$,$state$jscomp$387$$,$stream$jscomp$42$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3637$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_event$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$387$$),this.$cur_event$)?($_$jscomp$1948_stopper$jscomp$10$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3633$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_stop$$),
$stream$jscomp$42$$),$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$($app$main$data$workspace$shapes$update_shapes_buffer_commit$$,$APP.$beicon$v2$core$last$$($APP.$beicon$v2$core$take_until$$($_$jscomp$1948_stopper$jscomp$10$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3632$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer$$),$stream$jscomp$42$$)))),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$shapes$update_shapes_buffer$cljs$0core$0IFn$0_invoke$0arity$03$$(this.ids,
this.$update_fn$,this.props))),(0,$APP.$beicon$v2$core$of$$)(function($p1__67446_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__67446_SHARP_$$,$cljs$cst$3635$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_changes$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3637$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_event$$]))}))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$shapes$update_shapes_buffer_67454$$($changed_sub_attr$jscomp$3$$,
$undo_group$jscomp$10$$,$save_undo_QMARK_$jscomp$5$$,$ignore_tree$jscomp$1$$,$reg_objects_QMARK_$$,$stack_undo_QMARK_$jscomp$5$$,$map__67453__$1$$,$with_objects_QMARK_$jscomp$3$$,$cur_event$$,$ignore_touched$jscomp$10$$,$p__67452$$,$translation_QMARK_$jscomp$6$$,$ids$jscomp$71$$,$page_id$jscomp$113$$,$update_fn$jscomp$16$$,$map__67453__$1$$,$attrs$jscomp$77$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$=function($ids$jscomp$73$$,$update_fn$jscomp$18$$){return $APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$73$$,$update_fn$jscomp$18$$,null)};
$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$74$$,$update_fn$jscomp$19$$,$p__67466$$){var $map__67467__$1$$=$APP.$cljs$core$__destructure_map$$($p__67466$$),$changed_sub_attr$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67467__$1$$,$APP.$cljs$cst$3521$changed_sub_attr$$),$undo_group$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67467__$1$$,$APP.$cljs$cst$3138$undo_group$$),$save_undo_QMARK_$jscomp$7$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67467__$1$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!0),$ignore_tree$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67467__$1$$,$cljs$cst$3522$ignore_tree$$),$reg_objects_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67467__$1$$,$APP.$cljs$cst$3636$reg_objects_QMARK_$$,!1),$stack_undo_QMARK_$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67467__$1$$,$APP.$cljs$cst$3141$stack_undo_QMARK_$$,
!1),$with_objects_QMARK_$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67467__$1$$,$APP.$cljs$cst$3175$with_objects_QMARK_$$,!1),$ignore_touched$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67467__$1$$,$APP.$cljs$cst$2556$ignore_touched$$,!1),$translation_QMARK_$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67467__$1$$,$cljs$cst$3145$translation_QMARK_$$),$page_id$jscomp$115$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67467__$1$$,
$APP.$cljs$cst$2043$page_id$$),$attrs$jscomp$79$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67467__$1$$,$APP.$cljs$cst$2645$attrs$$);typeof $app$main$data$workspace$shapes$update_shapes_67469$$==="undefined"&&($app$main$data$workspace$shapes$update_shapes_67469$$=function($changed_sub_attr$jscomp$6$$,$p__67466$jscomp$1$$,$undo_group$jscomp$13$$,$save_undo_QMARK_$jscomp$8$$,$ignore_tree$jscomp$4$$,$reg_objects_QMARK_$jscomp$3$$,$stack_undo_QMARK_$jscomp$8$$,$props$jscomp$153$$,$with_objects_QMARK_$jscomp$6$$,
$ignore_touched$jscomp$13$$,$translation_QMARK_$jscomp$9$$,$ids$jscomp$75$$,$map__67467$jscomp$1$$,$page_id$jscomp$116$$,$update_fn$jscomp$20$$,$attrs$jscomp$80$$,$meta67470$$){this.$changed_sub_attr$=$changed_sub_attr$jscomp$6$$;this.$p__67466$=$p__67466$jscomp$1$$;this.$undo_group$=$undo_group$jscomp$13$$;this.$save_undo_QMARK_$=$save_undo_QMARK_$jscomp$8$$;this.$ignore_tree$=$ignore_tree$jscomp$4$$;this.$reg_objects_QMARK_$=$reg_objects_QMARK_$jscomp$3$$;this.$stack_undo_QMARK_$=$stack_undo_QMARK_$jscomp$8$$;
this.props=$props$jscomp$153$$;this.$with_objects_QMARK_$=$with_objects_QMARK_$jscomp$6$$;this.$ignore_touched$=$ignore_touched$jscomp$13$$;this.$translation_QMARK_$=$translation_QMARK_$jscomp$9$$;this.ids=$ids$jscomp$75$$;this.$map__67467$=$map__67467$jscomp$1$$;this.$page_id$=$page_id$jscomp$116$$;this.$update_fn$=$update_fn$jscomp$20$$;this.$attrs$=$attrs$jscomp$80$$;this.$meta67470$=$meta67470$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$update_shapes_67469$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$update_shapes_67469$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3638$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes$$},$app$main$data$workspace$shapes$update_shapes_67469$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67471$$,$meta67470__$1$$){return new $app$main$data$workspace$shapes$update_shapes_67469$$(this.$changed_sub_attr$,this.$p__67466$,this.$undo_group$,
this.$save_undo_QMARK_$,this.$ignore_tree$,this.$reg_objects_QMARK_$,this.$stack_undo_QMARK_$,this.props,this.$with_objects_QMARK_$,this.$ignore_touched$,this.$translation_QMARK_$,this.ids,this.$map__67467$,this.$page_id$,this.$update_fn$,this.$attrs$,$meta67470__$1$$)},$app$main$data$workspace$shapes$update_shapes_67469$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67470$},$app$main$data$workspace$shapes$update_shapes_67469$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$shapes$update_shapes_67469$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$153_update_layout_ids_xf_update_layout$$,$state$jscomp$388$$){var $self__$jscomp$4327$$=this,$it__$1$jscomp$38$$=this;if($APP.$cljs$core$truth_$$($cljs$cst$3632$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$388$$)))return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$shapes$update_shapes_buffer$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$4327$$.ids,
$self__$jscomp$4327$$.$update_fn$,$self__$jscomp$4327$$.props));var $page_id__$1$jscomp$4$$=function(){var $or__5025__auto__$jscomp$696$$=$self__$jscomp$4327$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$696$$)?$or__5025__auto__$jscomp$696$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$388$$,$APP.$cljs$cst$1918$current_page_id$$)}(),$objects$jscomp$330$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$388$$,
$page_id__$1$jscomp$4$$),$ids__$1$jscomp$7$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$some_QMARK_$$),$self__$jscomp$4327$$.ids);$it$jscomp$153_update_layout_ids_xf_update_layout$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$getf$$($objects$jscomp$330$$)),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__67461_SHARP_$$){return $APP.$cljs$core$some$$($app$main$data$workspace$shapes$update_layout_attr_QMARK_$$,
$app$common$files$changes_builder$changed_attrs$$($p1__67461_SHARP_$$,$objects$jscomp$330$$,$self__$jscomp$4327$$.$update_fn$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2645$attrs$$,$self__$jscomp$4327$$.$attrs$,$APP.$cljs$cst$3175$with_objects_QMARK_$$,$self__$jscomp$4327$$.$with_objects_QMARK_$],null)))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$));$it$jscomp$153_update_layout_ids_xf_update_layout$$=$APP.$cljs$core$truth_$$($self__$jscomp$4327$$.$translation_QMARK_$)?
null:$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$it$jscomp$153_update_layout_ids_xf_update_layout$$,$ids__$1$jscomp$7$$));var $changes$jscomp$170$$=$app$common$files$changes_builder$set_translation_QMARK_$$(function(){var $G__67484_JSCompiler_inline_result$jscomp$14060_changes$jscomp$inline_14334$$=$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$($it__$1$jscomp$38$$,$page_id__$1$jscomp$4$$);
$G__67484_JSCompiler_inline_result$jscomp$14060_changes$jscomp$inline_14334$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__67484_JSCompiler_inline_result$jscomp$14060_changes$jscomp$inline_14334$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$,$self__$jscomp$4327$$.$save_undo_QMARK_$);$G__67484_JSCompiler_inline_result$jscomp$14060_changes$jscomp$inline_14334$$=$app$common$logic$shapes$generate_update_shapes$$($app$common$files$changes_builder$set_stack_undo_QMARK_$$($G__67484_JSCompiler_inline_result$jscomp$14060_changes$jscomp$inline_14334$$,
$self__$jscomp$4327$$.$stack_undo_QMARK_$),$ids__$1$jscomp$7$$,$self__$jscomp$4327$$.$update_fn$,$objects$jscomp$330$$,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$2645$attrs$$,$self__$jscomp$4327$$.$attrs$,$APP.$cljs$cst$3521$changed_sub_attr$$,$self__$jscomp$4327$$.$changed_sub_attr$,$cljs$cst$3522$ignore_tree$$,$self__$jscomp$4327$$.$ignore_tree$,$APP.$cljs$cst$2556$ignore_touched$$,$self__$jscomp$4327$$.$ignore_touched$,$APP.$cljs$cst$3175$with_objects_QMARK_$$,$self__$jscomp$4327$$.$with_objects_QMARK_$,
$cljs$cst$3145$translation_QMARK_$$,$self__$jscomp$4327$$.$translation_QMARK_$],null));return $APP.$cljs$core$truth_$$($self__$jscomp$4327$$.$undo_group$)?$APP.$app$common$files$changes_builder$set_undo_group$$($G__67484_JSCompiler_inline_result$jscomp$14060_changes$jscomp$inline_14334$$,$self__$jscomp$4327$$.$undo_group$):$G__67484_JSCompiler_inline_result$jscomp$14060_changes$jscomp$inline_14334$$}(),$self__$jscomp$4327$$.$translation_QMARK_$),$changes__$1$jscomp$61$$=$app$main$data$workspace$shapes$add_undo_group$$($changes$jscomp$170$$,
$state$jscomp$388$$);return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$seq$$($APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes__$1$jscomp$61$$))?function(){var $changes__$2$jscomp$30$$=$APP.$cljs$core$truth_$$($self__$jscomp$4327$$.$reg_objects_QMARK_$)?$APP.$app$common$files$changes_builder$resize_parents$$($changes__$1$jscomp$61$$,$ids__$1$jscomp$7$$):$changes__$1$jscomp$61$$;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes__$2$jscomp$30$$))}():
$APP.$beicon$v2$core$empty$$(),$APP.$cljs$core$truth_$$($it$jscomp$153_update_layout_ids_xf_update_layout$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$it$jscomp$153_update_layout_ids_xf_update_layout$$],null))):$APP.$beicon$v2$core$empty$$())});return new $app$main$data$workspace$shapes$update_shapes_67469$$($changed_sub_attr$jscomp$5$$,
$p__67466$$,$undo_group$jscomp$12$$,$save_undo_QMARK_$jscomp$7$$,$ignore_tree$jscomp$3$$,$reg_objects_QMARK_$jscomp$2$$,$stack_undo_QMARK_$jscomp$7$$,$map__67467__$1$$,$with_objects_QMARK_$jscomp$5$$,$ignore_touched$jscomp$12$$,$translation_QMARK_$jscomp$8$$,$ids$jscomp$74$$,$map__67467__$1$$,$page_id$jscomp$115$$,$update_fn$jscomp$19$$,$attrs$jscomp$79$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shapes$add_shape$cljs$0core$0IFn$0_invoke$0arity$02$$=function($shape$jscomp$442$$,$p__67497$$){var $map__67498__$1$$=$APP.$cljs$core$__destructure_map$$($p__67497$$),$no_select_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67498__$1$$,$cljs$cst$3639$no_select_QMARK_$$),$no_update_layout_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67498__$1$$,$cljs$cst$3640$no_update_layout_QMARK_$$),$skip_edition_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67498__$1$$,
$cljs$cst$3641$skip_edition_QMARK_$$);$app$common$types$shape$check_shape$$($shape$jscomp$442$$);typeof $app$main$data$workspace$shapes$add_shape_67499$$==="undefined"&&($app$main$data$workspace$shapes$add_shape_67499$$=function($shape$jscomp$443$$,$p__67497$jscomp$1$$,$map__67498$jscomp$1$$,$no_select_QMARK_$jscomp$1$$,$no_update_layout_QMARK_$jscomp$1$$,$skip_edition_QMARK_$jscomp$1$$,$meta67500$$){this.shape=$shape$jscomp$443$$;this.$p__67497$=$p__67497$jscomp$1$$;this.$map__67498$=$map__67498$jscomp$1$$;
this.$no_select_QMARK_$=$no_select_QMARK_$jscomp$1$$;this.$no_update_layout_QMARK_$=$no_update_layout_QMARK_$jscomp$1$$;this.$skip_edition_QMARK_$=$skip_edition_QMARK_$jscomp$1$$;this.$meta67500$=$meta67500$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$add_shape_67499$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$add_shape_67499$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3642$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_add_shape$$},$app$main$data$workspace$shapes$add_shape_67499$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67501$$,$meta67500__$1$$){return new $app$main$data$workspace$shapes$add_shape_67499$$(this.shape,this.$p__67497$,this.$map__67498$,this.$no_select_QMARK_$,this.$no_update_layout_QMARK_$,this.$skip_edition_QMARK_$,$meta67500__$1$$)},$app$main$data$workspace$shapes$add_shape_67499$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67500$},$app$main$data$workspace$shapes$add_shape_67499$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$add_shape_67499$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1950$$,$state$jscomp$389$$){return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(this.shape)&&$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$(this.shape)==null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$389$$,
$APP.$cljs$cst$3643$workspace_new_text_shapes$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.shape)):$state$jscomp$389$$},$app$main$data$workspace$shapes$add_shape_67499$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$add_shape_67499$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$,
$objects$jscomp$331_state$jscomp$390$$){$it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$331_state$jscomp$390$$);$objects$jscomp$331_state$jscomp$390$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$331_state$jscomp$390$$,$it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$);var $changes$jscomp$171_changes__$1$jscomp$62_vec__67519$$=$APP.$app$common$files$shapes_helpers$prepare_add_shape$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
$it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$),$objects$jscomp$331_state$jscomp$390$$),this.shape,$objects$jscomp$331_state$jscomp$390$$);$it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$171_changes__$1$jscomp$62_vec__67519$$,0,null);$changes$jscomp$171_changes__$1$jscomp$62_vec__67519$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$171_changes__$1$jscomp$62_vec__67519$$,1,null);$changes$jscomp$171_changes__$1$jscomp$62_vec__67519$$=
$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$)?$APP.$app$common$files$changes_builder$set_undo_group$$($changes$jscomp$171_changes__$1$jscomp$62_vec__67519$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$)):$changes$jscomp$171_changes__$1$jscomp$62_vec__67519$$;var $undo_id$jscomp$1$$=Symbol(),$parent_type$jscomp$1$$=$app$common$files$helpers$get_shape_type$$($objects$jscomp$331_state$jscomp$390$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$)),$JSCompiler_inline_result$jscomp$10853_JSCompiler_temp$jscomp$10852_and__5023__auto____$1$jscomp$inline_12372_start_edition_QMARK_$$;if($JSCompiler_inline_result$jscomp$10853_JSCompiler_temp$jscomp$10852_and__5023__auto____$1$jscomp$inline_12372_start_edition_QMARK_$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$))$JSCompiler_inline_result$jscomp$10853_JSCompiler_temp$jscomp$10852_and__5023__auto____$1$jscomp$inline_12372_start_edition_QMARK_$$=
this.$skip_edition_QMARK_$,$JSCompiler_inline_result$jscomp$10853_JSCompiler_temp$jscomp$10852_and__5023__auto____$1$jscomp$inline_12372_start_edition_QMARK_$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10853_JSCompiler_temp$jscomp$10852_and__5023__auto____$1$jscomp$inline_12372_start_edition_QMARK_$$)?$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$)!=null:$JSCompiler_inline_result$jscomp$10853_JSCompiler_temp$jscomp$10852_and__5023__auto____$1$jscomp$inline_12372_start_edition_QMARK_$$,
$JSCompiler_inline_result$jscomp$10853_JSCompiler_temp$jscomp$10852_and__5023__auto____$1$jscomp$inline_12372_start_edition_QMARK_$$=$APP.$cljs$core$not$$($JSCompiler_inline_result$jscomp$10853_JSCompiler_temp$jscomp$10852_and__5023__auto____$1$jscomp$inline_12372_start_edition_QMARK_$$);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$1$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$171_changes__$1$jscomp$62_vec__67519$$),
$APP.$cljs$core$truth_$$(this.$no_update_layout_QMARK_$)?null:$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$)],null)],null)),$APP.$cljs$core$truth_$$(this.$no_select_QMARK_$)?
null:$APP.$app$main$data$workspace$selection$select_shapes$$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$))),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$1$$)),$JSCompiler_inline_result$jscomp$10853_JSCompiler_temp$jscomp$10852_and__5023__auto____$1$jscomp$inline_12372_start_edition_QMARK_$$?$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$edition$start_edition_mode$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$)))):null,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-shape",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:add-shape",$APP.$cljs$cst$139$type$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$,$APP.$cljs$cst$139$type$$),$APP.$cljs$cst$3622$parent_type$$,$parent_type$jscomp$1$$],null))),$app$common$files$helpers$has_layout_QMARK_$$($objects$jscomp$331_state$jscomp$390$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"layout-add-element",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:add-shape",$APP.$cljs$cst$139$type$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$154_page_id$jscomp$117_shape__$1$jscomp$34$$,$APP.$cljs$cst$139$type$$),$APP.$cljs$cst$3622$parent_type$$,$parent_type$jscomp$1$$],null))):null)});return new $app$main$data$workspace$shapes$add_shape_67499$$($shape$jscomp$442$$,$p__67497$$,
$map__67498__$1$$,$no_select_QMARK_$$,$no_update_layout_QMARK_$$,$skip_edition_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shapes$move_shapes_into_frame$$=function($frame_id$jscomp$49$$,$shapes$jscomp$48$$){typeof $app$main$data$workspace$shapes$move_shapes_into_frame_67536$$==="undefined"&&($app$main$data$workspace$shapes$move_shapes_into_frame_67536$$=function($frame_id$jscomp$50$$,$shapes$jscomp$49$$,$meta67537$$){this.$frame_id$=$frame_id$jscomp$50$$;this.shapes=$shapes$jscomp$49$$;this.$meta67537$=$meta67537$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$shapes$move_shapes_into_frame_67536$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$move_shapes_into_frame_67536$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3644$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_move_shapes_into_frame$$},$app$main$data$workspace$shapes$move_shapes_into_frame_67536$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67538$$,$meta67537__$1$$){return new $app$main$data$workspace$shapes$move_shapes_into_frame_67536$$(this.$frame_id$,
this.shapes,$meta67537__$1$$)},$app$main$data$workspace$shapes$move_shapes_into_frame_67536$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67537$},$app$main$data$workspace$shapes$move_shapes_into_frame_67536$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$move_shapes_into_frame_67536$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$172_it$jscomp$155_page_id$jscomp$118$$,$changes__$1$jscomp$63_shapes__$1$jscomp$7_state$jscomp$391$$){$changes$jscomp$172_it$jscomp$155_page_id$jscomp$118$$=
$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($changes__$1$jscomp$63_shapes__$1$jscomp$7_state$jscomp$391$$);var $objects$jscomp$332$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($changes__$1$jscomp$63_shapes__$1$jscomp$7_state$jscomp$391$$,$changes$jscomp$172_it$jscomp$155_page_id$jscomp$118$$);$changes__$1$jscomp$63_shapes__$1$jscomp$7_state$jscomp$391$$=$app$common$files$helpers$order_by_indexed_shapes$$($objects$jscomp$332$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67535_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$332$$,
$p1__67535_SHARP_$$),$APP.$cljs$cst$1623$blocked$$)},this.shapes));$changes$jscomp$172_it$jscomp$155_page_id$jscomp$118$$=$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$changes$jscomp$172_it$jscomp$155_page_id$jscomp$118$$),$objects$jscomp$332$$);$changes__$1$jscomp$63_shapes__$1$jscomp$7_state$jscomp$391$$=$app$common$files$shapes_helpers$prepare_move_shapes_into_frame$$($changes$jscomp$172_it$jscomp$155_page_id$jscomp$118$$,
this.$frame_id$,$changes__$1$jscomp$63_shapes__$1$jscomp$7_state$jscomp$391$$,$objects$jscomp$332$$,!0);return $changes__$1$jscomp$63_shapes__$1$jscomp$7_state$jscomp$391$$!=null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes__$1$jscomp$63_shapes__$1$jscomp$7_state$jscomp$391$$)):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$shapes$move_shapes_into_frame_67536$$($frame_id$jscomp$49$$,$shapes$jscomp$48$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$01$$=function($ids$jscomp$76$$){return $APP.$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(null,$ids$jscomp$76$$)};
$APP.$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$=function($page_id$jscomp$120$$,$ids$jscomp$78$$){var $options$jscomp$505$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;typeof $app$main$data$workspace$shapes$delete_shapes_67546$$==="undefined"&&($app$main$data$workspace$shapes$delete_shapes_67546$$=function($page_id$jscomp$121$$,$ids$jscomp$79$$,$options$jscomp$506$$,$meta67547$$){this.$page_id$=$page_id$jscomp$121$$;this.ids=$ids$jscomp$79$$;this.options=$options$jscomp$506$$;
this.$meta67547$=$meta67547$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$delete_shapes_67546$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$delete_shapes_67546$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3645$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_delete_shapes$$},$app$main$data$workspace$shapes$delete_shapes_67546$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_67548$$,$meta67547__$1$$){return new $app$main$data$workspace$shapes$delete_shapes_67546$$(this.$page_id$,this.ids,this.options,$meta67547__$1$$)},$app$main$data$workspace$shapes$delete_shapes_67546$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67547$},$app$main$data$workspace$shapes$delete_shapes_67546$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$delete_shapes_67546$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($it$jscomp$156_page_id__$1$jscomp$5_undo_id$jscomp$2$$,$state$jscomp$392$$){var $self__$jscomp$4340$$=this,$all_parents$jscomp$8_fdata$jscomp$6_file_id$jscomp$94$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$392$$);$it$jscomp$156_page_id__$1$jscomp$5_undo_id$jscomp$2$$=function(){var $or__5025__auto__$jscomp$697$$=$self__$jscomp$4340$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$697$$)?$or__5025__auto__$jscomp$697$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$392$$)}();
$all_parents$jscomp$8_fdata$jscomp$6_file_id$jscomp$94$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$392$$,$all_parents$jscomp$8_fdata$jscomp$6_file_id$jscomp$94$$);var $changes$jscomp$173_page$jscomp$66_vec__67549$$=$APP.$app$main$data$helpers$get_page$$($all_parents$jscomp$8_fdata$jscomp$6_file_id$jscomp$94$$,$it$jscomp$156_page_id__$1$jscomp$5_undo_id$jscomp$2$$),$objects$jscomp$333$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$173_page$jscomp$66_vec__67549$$);
$it$jscomp$156_page_id__$1$jscomp$5_undo_id$jscomp$2$$=function(){var $or__5025__auto__$jscomp$698$$=$APP.$cljs$cst$3646$undo_id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4340$$.options);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$698$$)?$or__5025__auto__$jscomp$698$$:Symbol()}();$changes$jscomp$173_page$jscomp$66_vec__67549$$=$app$common$logic$shapes$generate_delete_shapes$cljs$0core$0IFn$0_invoke$0arity$06$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$173_page$jscomp$66_vec__67549$$)),$all_parents$jscomp$8_fdata$jscomp$6_file_id$jscomp$94$$,$changes$jscomp$173_page$jscomp$66_vec__67549$$,$objects$jscomp$333$$,$self__$jscomp$4340$$.ids,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2556$ignore_touched$$,$cljs$cst$2618$allow_altering_copies$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4340$$.options),$APP.$cljs$cst$3138$undo_group$$,$APP.$cljs$cst$3138$undo_group$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4340$$.options),
$APP.$cljs$cst$3646$undo_id$$,$it$jscomp$156_page_id__$1$jscomp$5_undo_id$jscomp$2$$],null));$all_parents$jscomp$8_fdata$jscomp$6_file_id$jscomp$94$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$173_page$jscomp$66_vec__67549$$,0,null);$changes$jscomp$173_page$jscomp$66_vec__67549$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$173_page$jscomp$66_vec__67549$$,1,null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($it$jscomp$156_page_id__$1$jscomp$5_undo_id$jscomp$2$$),
$app$main$data$comments$detach_comment_thread$$($self__$jscomp$4340$$.ids),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$173_page$jscomp$66_vec__67549$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1723$ids$$,$all_parents$jscomp$8_fdata$jscomp$6_file_id$jscomp$94$$,$APP.$cljs$cst$3138$undo_group$$,$APP.$cljs$cst$3138$undo_group$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4340$$.options)],
null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($it$jscomp$156_page_id__$1$jscomp$5_undo_id$jscomp$2$$))});return new $app$main$data$workspace$shapes$delete_shapes_67546$$($page_id$jscomp$120$$,$ids$jscomp$78$$,$options$jscomp$505$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shapes$create_and_add_shape$cljs$0core$0IFn$0_invoke$0arity$05$$=function($type$jscomp$450$$,$frame_x$jscomp$1$$,$frame_y$jscomp$1$$,$p__67560$$,$p__67561$$){var $map__67562__$1$$=$APP.$cljs$core$__destructure_map$$($p__67560$$),$width$jscomp$102$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67562__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$91$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67562__$1$$,$APP.$cljs$cst$1522$height$$),$map__67563__$1$$=
$APP.$cljs$core$__destructure_map$$($p__67561$$),$skip_edition_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67563__$1$$,$cljs$cst$3641$skip_edition_QMARK_$$);typeof $app$main$data$workspace$shapes$create_and_add_shape_67564$$==="undefined"&&($app$main$data$workspace$shapes$create_and_add_shape_67564$$=function($frame_x$jscomp$2$$,$height$jscomp$92$$,$p__67560$jscomp$1$$,$p__67561$jscomp$1$$,$skip_edition_QMARK_$jscomp$3$$,$width$jscomp$103$$,$type$jscomp$451$$,$map__67562$jscomp$1$$,
$map__67563$jscomp$1$$,$frame_y$jscomp$2$$,$attrs$jscomp$83$$,$meta67565$$){this.$frame_x$=$frame_x$jscomp$2$$;this.height=$height$jscomp$92$$;this.$p__67560$=$p__67560$jscomp$1$$;this.$p__67561$=$p__67561$jscomp$1$$;this.$skip_edition_QMARK_$=$skip_edition_QMARK_$jscomp$3$$;this.width=$width$jscomp$103$$;this.type=$type$jscomp$451$$;this.$map__67562$=$map__67562$jscomp$1$$;this.$map__67563$=$map__67563$jscomp$1$$;this.$frame_y$=$frame_y$jscomp$2$$;this.$attrs$=$attrs$jscomp$83$$;this.$meta67565$=
$meta67565$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$create_and_add_shape_67564$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$create_and_add_shape_67564$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3647$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_create_and_add_shape$$},$app$main$data$workspace$shapes$create_and_add_shape_67564$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_67566$$,$meta67565__$1$$){return new $app$main$data$workspace$shapes$create_and_add_shape_67564$$(this.$frame_x$,this.height,this.$p__67560$,this.$p__67561$,this.$skip_edition_QMARK_$,this.width,this.type,this.$map__67562$,this.$map__67563$,this.$frame_y$,this.$attrs$,$meta67565__$1$$)},$app$main$data$workspace$shapes$create_and_add_shape_67564$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67565$},$app$main$data$workspace$shapes$create_and_add_shape_67564$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$create_and_add_shape_67564$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1954_shape$jscomp$444_x$jscomp$1172$$,$parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$){var $vbc_y$jscomp$408$$=$APP.$app$main$data$helpers$get_viewport_center$$($parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$);$_$jscomp$1954_shape$jscomp$444_x$jscomp$1172$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$2$(this.$attrs$,
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbc_y$jscomp$408$$)-this.width/2);$vbc_y$jscomp$408$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$2$(this.$attrs$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbc_y$jscomp$408$$)-this.height/2);var $frame_id$jscomp$51_objects$jscomp$inline_12374_page_id$jscomp$122$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$),$frame_id__$1$jscomp$8_objects$jscomp$334$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$,$frame_id$jscomp$51_objects$jscomp$inline_12374_page_id$jscomp$122$$);$frame_id$jscomp$51_objects$jscomp$inline_12374_page_id$jscomp$122$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$,$frame_id$jscomp$51_objects$jscomp$inline_12374_page_id$jscomp$122$$);
$frame_id$jscomp$51_objects$jscomp$inline_12374_page_id$jscomp$122$$=$APP.$app$common$types$shape_tree$top_nested_frame$cljs$0core$0IFn$0_invoke$0arity$04$$($frame_id$jscomp$51_objects$jscomp$inline_12374_page_id$jscomp$122$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,this.$frame_x$,$APP.$cljs$cst$1511$y$$,this.$frame_y$],null),null,!1);$parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$);
var $base$jscomp$34$$=$app$common$files$helpers$get_base_shape$$($frame_id__$1$jscomp$8_objects$jscomp$334$$,$parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$);$parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$))&&$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_id__$1$jscomp$8_objects$jscomp$334$$,
$APP.$cljs$core$first$$($parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$)))||$APP.$cljs$core$empty_QMARK_$$($parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$)?$frame_id$jscomp$51_objects$jscomp$inline_12374_page_id$jscomp$122$$:$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$34$$);$parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$common$types$container$get_first_valid_parent$$($frame_id__$1$jscomp$8_objects$jscomp$334$$,
$parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$));$frame_id__$1$jscomp$8_objects$jscomp$334$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$common$types$container$get_first_valid_parent$$($frame_id__$1$jscomp$8_objects$jscomp$334$$,$frame_id$jscomp$51_objects$jscomp$inline_12374_page_id$jscomp$122$$));$_$jscomp$1954_shape$jscomp$444_x$jscomp$1172$$=$APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$attrs$,
$APP.$cljs$cst$139$type$$,this.type),$APP.$cljs$cst$1510$x$$,$_$jscomp$1954_shape$jscomp$444_x$jscomp$1172$$),$APP.$cljs$cst$1511$y$$,$vbc_y$jscomp$408$$),$APP.$cljs$cst$1607$frame_id$$,$frame_id__$1$jscomp$8_objects$jscomp$334$$),$APP.$cljs$cst$1619$parent_id$$,$parent_id$jscomp$51_parent_id__$1$jscomp$8_selected$jscomp$28_state$jscomp$393$$));return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$shapes$add_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$1954_shape$jscomp$444_x$jscomp$1172$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3641$skip_edition_QMARK_$$,this.$skip_edition_QMARK_$],null)))});return new $app$main$data$workspace$shapes$create_and_add_shape_67564$$($frame_x$jscomp$1$$,$height$jscomp$91$$,$p__67560$$,$p__67561$$,$skip_edition_QMARK_$jscomp$2$$,$width$jscomp$102$$,$type$jscomp$450$$,$map__67562__$1$$,$map__67563__$1$$,$frame_y$jscomp$1$$,$map__67562__$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shapes$create_artboard_from_shapes$cljs$0core$0IFn$0_invoke$0arity$07$$=function($shapes$jscomp$51$$,$id$jscomp$499$$,$parent_id$jscomp$53$$,$index$jscomp$275$$,$name$jscomp$292$$,$delta$jscomp$36$$,$layout_update_QMARK_$$){typeof $app$main$data$workspace$shapes$create_artboard_from_shapes_67580$$==="undefined"&&($app$main$data$workspace$shapes$create_artboard_from_shapes_67580$$=function($shapes$jscomp$52$$,$id$jscomp$500$$,$parent_id$jscomp$54$$,$index$jscomp$276$$,$name$jscomp$293$$,
$delta$jscomp$37$$,$layout_update_QMARK_$jscomp$1$$,$meta67581$$){this.shapes=$shapes$jscomp$52$$;this.id=$id$jscomp$500$$;this.$parent_id$=$parent_id$jscomp$54$$;this.index=$index$jscomp$276$$;this.name=$name$jscomp$293$$;this.$delta$=$delta$jscomp$37$$;this.$layout_update_QMARK_$=$layout_update_QMARK_$jscomp$1$$;this.$meta67581$=$meta67581$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$create_artboard_from_shapes_67580$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$create_artboard_from_shapes_67580$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3648$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_create_artboard_from_shapes$$},$app$main$data$workspace$shapes$create_artboard_from_shapes_67580$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67582$$,$meta67581__$1$$){return new $app$main$data$workspace$shapes$create_artboard_from_shapes_67580$$(this.shapes,
this.id,this.$parent_id$,this.index,this.name,this.$delta$,this.$layout_update_QMARK_$,$meta67581__$1$$)},$app$main$data$workspace$shapes$create_artboard_from_shapes_67580$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67581$},$app$main$data$workspace$shapes$create_artboard_from_shapes_67580$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$create_artboard_from_shapes_67580$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$174_frame_shape_it$jscomp$157_page_id$jscomp$123$$,$objects$jscomp$335_state$jscomp$394$$){$changes$jscomp$174_frame_shape_it$jscomp$157_page_id$jscomp$123$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$335_state$jscomp$394$$);$objects$jscomp$335_state$jscomp$394$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$335_state$jscomp$394$$,$changes$jscomp$174_frame_shape_it$jscomp$157_page_id$jscomp$123$$);
$changes$jscomp$174_frame_shape_it$jscomp$157_page_id$jscomp$123$$=$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$changes$jscomp$174_frame_shape_it$jscomp$157_page_id$jscomp$123$$),$objects$jscomp$335_state$jscomp$394$$);var $changes__$1$jscomp$64_vec__67583$$=$APP.$app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$.$cljs$core$IFn$_invoke$arity$10$($changes$jscomp$174_frame_shape_it$jscomp$157_page_id$jscomp$123$$,
this.id,this.$parent_id$,$objects$jscomp$335_state$jscomp$394$$,this.shapes,this.index,this.name,!1,null,this.$delta$);$changes$jscomp$174_frame_shape_it$jscomp$157_page_id$jscomp$123$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$1$jscomp$64_vec__67583$$,0,null);$changes__$1$jscomp$64_vec__67583$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$1$jscomp$64_vec__67583$$,1,null);var $undo_id$jscomp$3$$=Symbol();return $APP.$cljs$core$truth_$$($changes__$1$jscomp$64_vec__67583$$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$3$$),$APP.$app$main$data$changes$commit_changes$$($changes__$1$jscomp$64_vec__67583$$),$APP.$app$main$data$workspace$selection$select_shapes$$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$174_frame_shape_it$jscomp$157_page_id$jscomp$123$$))),$APP.$cljs$core$truth_$$(this.$layout_update_QMARK_$)?$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$174_frame_shape_it$jscomp$157_page_id$jscomp$123$$)],null)],null)):null,$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-board",$cljs$cst$3649$converted_from$$,
$app$common$files$helpers$get_selected_type$$($objects$jscomp$335_state$jscomp$394$$,this.shapes),$APP.$cljs$cst$3622$parent_type$$,$app$common$files$helpers$get_shape_type$$($objects$jscomp$335_state$jscomp$394$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$174_frame_shape_it$jscomp$157_page_id$jscomp$123$$))],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$3$$)):null});return new $app$main$data$workspace$shapes$create_artboard_from_shapes_67580$$($shapes$jscomp$51$$,
$id$jscomp$499$$,$parent_id$jscomp$53$$,$index$jscomp$275$$,$name$jscomp$292$$,$delta$jscomp$36$$,$layout_update_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shapes$create_artboard_from_selection$cljs$0core$0IFn$0_invoke$0arity$04$$=function($id$jscomp$504$$,$parent_id$jscomp$57$$,$index$jscomp$278$$,$name$jscomp$294$$){return $APP.$app$main$data$workspace$shapes$create_artboard_from_selection$cljs$0core$0IFn$0_invoke$0arity$05$$($id$jscomp$504$$,$parent_id$jscomp$57$$,$index$jscomp$278$$,$name$jscomp$294$$)};
$APP.$app$main$data$workspace$shapes$create_artboard_from_selection$cljs$0core$0IFn$0_invoke$0arity$05$$=function($id$jscomp$505$$,$parent_id$jscomp$58$$,$index$jscomp$279$$,$name$jscomp$295$$){typeof $app$main$data$workspace$shapes$create_artboard_from_selection_67598$$==="undefined"&&($app$main$data$workspace$shapes$create_artboard_from_selection_67598$$=function($id$jscomp$506$$,$parent_id$jscomp$59$$,$index$jscomp$280$$,$name$jscomp$296$$,$delta$jscomp$39$$,$meta67599$$){this.id=$id$jscomp$506$$;
this.$parent_id$=$parent_id$jscomp$59$$;this.index=$index$jscomp$280$$;this.name=$name$jscomp$296$$;this.$delta$=$delta$jscomp$39$$;this.$meta67599$=$meta67599$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$create_artboard_from_selection_67598$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$create_artboard_from_selection_67598$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3650$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_create_artboard_from_selection$$},$app$main$data$workspace$shapes$create_artboard_from_selection_67598$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67600$$,$meta67599__$1$$){return new $app$main$data$workspace$shapes$create_artboard_from_selection_67598$$(this.id,this.$parent_id$,this.index,this.name,this.$delta$,$meta67599__$1$$)},$app$main$data$workspace$shapes$create_artboard_from_selection_67598$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67599$},$app$main$data$workspace$shapes$create_artboard_from_selection_67598$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$create_artboard_from_selection_67598$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1956_page_id$jscomp$124$$,$selected$jscomp$29_state$jscomp$395$$){$_$jscomp$1956_page_id$jscomp$124$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$29_state$jscomp$395$$);
var $objects$jscomp$336$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$29_state$jscomp$395$$,$_$jscomp$1956_page_id$jscomp$124$$);$selected$jscomp$29_state$jscomp$395$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67587_SHARP_$$){return $APP.$app$common$types$component$is_variant_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$336$$,$p1__67587_SHARP_$$))},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67586_SHARP_$$){return $APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$336$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$336$$,$p1__67586_SHARP_$$))},$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$336$$,$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($selected$jscomp$29_state$jscomp$395$$))));return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$shapes$create_artboard_from_shapes$cljs$0core$0IFn$0_invoke$0arity$07$$($selected$jscomp$29_state$jscomp$395$$,this.id,this.$parent_id$,this.index,this.name,
this.$delta$,!0))});return new $app$main$data$workspace$shapes$create_artboard_from_selection_67598$$($id$jscomp$505$$,$parent_id$jscomp$58$$,$index$jscomp$279$$,$name$jscomp$295$$,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shapes$update_shape_flags$$=function($ids$jscomp$80$$,$flags$jscomp$29$$){var $map__67605_map__67605__$1$$=$app$common$types$shape$check_shape_generic_attrs$$($flags$jscomp$29$$);$map__67605_map__67605__$1$$=$APP.$cljs$core$__destructure_map$$($map__67605_map__67605__$1$$);var $blocked$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67605_map__67605__$1$$,$APP.$cljs$cst$1623$blocked$$),$hidden$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67605_map__67605__$1$$,
$APP.$cljs$cst$1620$hidden$$),$undo_group$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67605_map__67605__$1$$,$APP.$cljs$cst$3138$undo_group$$);typeof $app$main$data$workspace$shapes$update_shape_flags_67606$$==="undefined"&&($app$main$data$workspace$shapes$update_shape_flags_67606$$=function($ids$jscomp$81$$,$flags$jscomp$30$$,$map__67605$jscomp$1$$,$blocked$jscomp$2$$,$hidden$jscomp$8$$,$undo_group$jscomp$15$$,$meta67607$$){this.ids=$ids$jscomp$81$$;this.flags=$flags$jscomp$30$$;
this.$map__67605$=$map__67605$jscomp$1$$;this.$blocked$=$blocked$jscomp$2$$;this.hidden=$hidden$jscomp$8$$;this.$undo_group$=$undo_group$jscomp$15$$;this.$meta67607$=$meta67607$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$update_shape_flags_67606$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$update_shape_flags_67606$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3651$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shape_flags$$},$app$main$data$workspace$shapes$update_shape_flags_67606$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67608$$,$meta67607__$1$$){return new $app$main$data$workspace$shapes$update_shape_flags_67606$$(this.ids,this.flags,this.$map__67605$,this.$blocked$,this.hidden,this.$undo_group$,$meta67607__$1$$)},$app$main$data$workspace$shapes$update_shape_flags_67606$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67607$},$app$main$data$workspace$shapes$update_shape_flags_67606$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$update_shape_flags_67606$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1957_ids__$1$jscomp$8$$,$state$jscomp$396$$){var $self__$jscomp$4356$$=this,$objects$jscomp$337$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$396$$);$_$jscomp$1957_ids__$1$jscomp$8$$=
$APP.$cljs$core$boolean_QMARK_$$($self__$jscomp$4356$$.$blocked$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4356$$.ids,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__67601_SHARP_$$){return $APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$337$$,$p1__67601_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$4356$$.ids]))):$self__$jscomp$4356$$.ids;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$1957_ids__$1$jscomp$8$$,
function($G__67609__$1_obj$jscomp$205$$){$G__67609__$1_obj$jscomp$205$$=$APP.$cljs$core$boolean_QMARK_$$($self__$jscomp$4356$$.$blocked$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__67609__$1_obj$jscomp$205$$,$APP.$cljs$cst$1623$blocked$$,$self__$jscomp$4356$$.$blocked$):$G__67609__$1_obj$jscomp$205$$;return $APP.$cljs$core$boolean_QMARK_$$($self__$jscomp$4356$$.hidden)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__67609__$1_obj$jscomp$205$$,$APP.$cljs$cst$1620$hidden$$,
$self__$jscomp$4356$$.hidden):$G__67609__$1_obj$jscomp$205$$},new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1620$hidden$$,null,$APP.$cljs$cst$1623$blocked$$,null],null),null),$APP.$cljs$cst$3138$undo_group$$,$self__$jscomp$4356$$.$undo_group$],null)))});return new $app$main$data$workspace$shapes$update_shape_flags_67606$$($ids$jscomp$80$$,$flags$jscomp$29$$,$map__67605_map__67605__$1$$,
$blocked$jscomp$1$$,$hidden$jscomp$7$$,$undo_group$jscomp$14$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shapes$toggle_visibility_selected$$=function(){typeof $app$main$data$workspace$shapes$toggle_visibility_selected_67614$$==="undefined"&&($app$main$data$workspace$shapes$toggle_visibility_selected_67614$$=function($meta67615$$){this.$meta67615$=$meta67615$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$toggle_visibility_selected_67614$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$shapes$toggle_visibility_selected_67614$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3652$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_toggle_visibility_selected$$},$app$main$data$workspace$shapes$toggle_visibility_selected_67614$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67616$$,$meta67615__$1$$){return new $app$main$data$workspace$shapes$toggle_visibility_selected_67614$$($meta67615__$1$$)},$app$main$data$workspace$shapes$toggle_visibility_selected_67614$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67615$},$app$main$data$workspace$shapes$toggle_visibility_selected_67614$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$toggle_visibility_selected_67614$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1958_selected$jscomp$30$$,$state$jscomp$397$$){$_$jscomp$1958_selected$jscomp$30$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$397$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$1958_selected$jscomp$30$$,
function($p1__67612_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__67612_SHARP_$$,$APP.$cljs$cst$1620$hidden$$,$APP.$cljs$core$not$$)}))});return new $app$main$data$workspace$shapes$toggle_visibility_selected_67614$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shapes$toggle_lock_selected$$=function(){typeof $app$main$data$workspace$shapes$toggle_lock_selected_67618$$==="undefined"&&($app$main$data$workspace$shapes$toggle_lock_selected_67618$$=function($meta67619$$){this.$meta67619$=$meta67619$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$toggle_lock_selected_67618$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$toggle_lock_selected_67618$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3653$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_toggle_lock_selected$$},$app$main$data$workspace$shapes$toggle_lock_selected_67618$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67620$$,$meta67619__$1$$){return new $app$main$data$workspace$shapes$toggle_lock_selected_67618$$($meta67619__$1$$)},$app$main$data$workspace$shapes$toggle_lock_selected_67618$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67619$},$app$main$data$workspace$shapes$toggle_lock_selected_67618$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$toggle_lock_selected_67618$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1959_selected$jscomp$31$$,$state$jscomp$398$$){$_$jscomp$1959_selected$jscomp$31$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$398$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$1959_selected$jscomp$31$$,
function($p1__67617_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__67617_SHARP_$$,$APP.$cljs$cst$1623$blocked$$,$APP.$cljs$core$not$$)}))});return new $app$main$data$workspace$shapes$toggle_lock_selected_67618$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$shapes$toggle_file_thumbnail_selected$$=function(){typeof $app$main$data$workspace$shapes$toggle_file_thumbnail_selected_67624$$==="undefined"&&($app$main$data$workspace$shapes$toggle_file_thumbnail_selected_67624$$=function($meta67625$$){this.$meta67625$=$meta67625$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$toggle_file_thumbnail_selected_67624$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$shapes$toggle_file_thumbnail_selected_67624$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3654$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_toggle_file_thumbnail_selected$$},$app$main$data$workspace$shapes$toggle_file_thumbnail_selected_67624$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67626$$,$meta67625__$1$$){return new $app$main$data$workspace$shapes$toggle_file_thumbnail_selected_67624$$($meta67625__$1$$)},$app$main$data$workspace$shapes$toggle_file_thumbnail_selected_67624$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67625$},$app$main$data$workspace$shapes$toggle_file_thumbnail_selected_67624$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$toggle_file_thumbnail_selected_67624$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1960_fdata$jscomp$7_pages$jscomp$3$$,$state$jscomp$399_undo_id$jscomp$4$$){var $selected$jscomp$32$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$399_undo_id$jscomp$4$$);
$_$jscomp$1960_fdata$jscomp$7_pages$jscomp$3$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$399_undo_id$jscomp$4$$);$_$jscomp$1960_fdata$jscomp$7_pages$jscomp$3$$=$APP.$cljs$core$vals$$($APP.$cljs$cst$1630$pages_index$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1960_fdata$jscomp$7_pages$jscomp$3$$));$state$jscomp$399_undo_id$jscomp$4$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($state$jscomp$399_undo_id$jscomp$4$$)),
$APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($frame_ids$jscomp$1_p__67627$$){var $page_id$jscomp$125$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($frame_ids$jscomp$1_p__67627$$,0,null);$frame_ids$jscomp$1_p__67627$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($frame_ids$jscomp$1_p__67627$$,1,null);return $APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($frame_ids$jscomp$1_p__67627$$,function($p1__67622_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__67622_SHARP_$$,
$APP.$cljs$cst$2964$use_for_thumbnail$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$125$$],null))},$APP.$app$common$data$group_by$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$first$$,$APP.$cljs$core$second$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($objects$jscomp$338_p__67632$$){var $id$jscomp$507_map__67633__$1$$=$APP.$cljs$core$__destructure_map$$($objects$jscomp$338_p__67632$$);$objects$jscomp$338_p__67632$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$507_map__67633__$1$$,$APP.$cljs$cst$1631$objects$$);$id$jscomp$507_map__67633__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$507_map__67633__$1$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2964$use_for_thumbnail$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$32$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$id$jscomp$507_map__67633__$1$$))])),$APP.$app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$338_p__67632$$))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_$jscomp$1960_fdata$jscomp$7_pages$jscomp$3$$]))))),
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($selected$jscomp$32$$,function($p1__67623_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__67623_SHARP_$$,$APP.$cljs$cst$2964$use_for_thumbnail$$,$APP.$cljs$core$not$$)}),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($state$jscomp$399_undo_id$jscomp$4$$)))});return new $app$main$data$workspace$shapes$toggle_file_thumbnail_selected_67624$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$shapes$relocate_shapes$$=function($var_args$jscomp$1214$$){for(var $args__5755__auto__$jscomp$221$$=[],$len__5749__auto___67737$$=arguments.length,$i__5750__auto___67738$$=0;;)if($i__5750__auto___67738$$<$len__5749__auto___67737$$)$args__5755__auto__$jscomp$221$$.push(arguments[$i__5750__auto___67738$$]),$i__5750__auto___67738$$+=1;else break;return $app$main$data$workspace$shapes$relocate_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],arguments[2],
3<$args__5755__auto__$jscomp$221$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$221$$.slice(3),0,null):null)};
$app$main$data$workspace$shapes$relocate_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($ids$jscomp$82$$,$parent_id$jscomp$60$$,$to_index$jscomp$9$$,$p__67640$$){var $ignore_parents_QMARK_$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67640$$,0,null);typeof $app$main$data$workspace$shapes$relocate_shapes_67644$$==="undefined"&&($app$main$data$workspace$shapes$relocate_shapes_67644$$=function($ids$jscomp$83$$,$parent_id$jscomp$61$$,$to_index$jscomp$10$$,$p__67640$jscomp$1$$,
$vec__67641$jscomp$1$$,$ignore_parents_QMARK_$jscomp$2$$,$meta67645$$){this.ids=$ids$jscomp$83$$;this.$parent_id$=$parent_id$jscomp$61$$;this.$to_index$=$to_index$jscomp$10$$;this.$p__67640$=$p__67640$jscomp$1$$;this.$vec__67641$=$vec__67641$jscomp$1$$;this.$ignore_parents_QMARK_$=$ignore_parents_QMARK_$jscomp$2$$;this.$meta67645$=$meta67645$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shapes$relocate_shapes_67644$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$relocate_shapes_67644$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3655$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_relocate_shapes$$},$app$main$data$workspace$shapes$relocate_shapes_67644$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67646$$,$meta67645__$1$$){return new $app$main$data$workspace$shapes$relocate_shapes_67644$$(this.ids,this.$parent_id$,this.$to_index$,this.$p__67640$,
this.$vec__67641$,this.$ignore_parents_QMARK_$,$meta67645__$1$$)},$app$main$data$workspace$shapes$relocate_shapes_67644$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67645$},$app$main$data$workspace$shapes$relocate_shapes_67644$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shapes$relocate_shapes_67644$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$175_it$jscomp$158_page_id$jscomp$126$$,
$all_parents$jscomp$9_ids__$1$jscomp$9_state$jscomp$400$$){var $self__$jscomp$4372$$=this;$changes$jscomp$175_it$jscomp$158_page_id$jscomp$126$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($all_parents$jscomp$9_ids__$1$jscomp$9_state$jscomp$400$$);var $objects$jscomp$339$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($all_parents$jscomp$9_ids__$1$jscomp$9_state$jscomp$400$$,$changes$jscomp$175_it$jscomp$158_page_id$jscomp$126$$),$add_component_to_variant_QMARK__data$jscomp$318$$=
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($all_parents$jscomp$9_ids__$1$jscomp$9_state$jscomp$400$$);$all_parents$jscomp$9_ids__$1$jscomp$9_state$jscomp$400$$=$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$339$$,$self__$jscomp$4372$$.ids);var $ids__$2$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($JSCompiler_inline_result$jscomp$711_p1__67634_SHARP_$$){a:{for(var $current_id$jscomp$inline_6498$$=$self__$jscomp$4372$$.$parent_id$;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_id$jscomp$inline_6498$$,
$JSCompiler_inline_result$jscomp$711_p1__67634_SHARP_$$)){$JSCompiler_inline_result$jscomp$711_p1__67634_SHARP_$$=!0;break a}if($current_id$jscomp$inline_6498$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_id$jscomp$inline_6498$$,$APP.$app$common$uuid$zero$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_id$jscomp$inline_6498$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$339$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$current_id$jscomp$inline_6498$$,$APP.$cljs$cst$1619$parent_id$$],null)))){$JSCompiler_inline_result$jscomp$711_p1__67634_SHARP_$$=!1;break a}$current_id$jscomp$inline_6498$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$339$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$current_id$jscomp$inline_6498$$,$APP.$cljs$cst$1619$parent_id$$],null))}$JSCompiler_inline_result$jscomp$711_p1__67634_SHARP_$$=
void 0}return!$JSCompiler_inline_result$jscomp$711_p1__67634_SHARP_$$},$all_parents$jscomp$9_ids__$1$jscomp$9_state$jscomp$400$$);$all_parents$jscomp$9_ids__$1$jscomp$9_state$jscomp$400$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$self__$jscomp$4372$$.$parent_id$]),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__67635_SHARP_$$){return $APP.$app$common$files$helpers$get_parent_id$$($objects$jscomp$339$$,$p1__67635_SHARP_$$)}),
$ids__$2$$);$changes$jscomp$175_it$jscomp$158_page_id$jscomp$126$$=$app$common$logic$shapes$generate_relocate$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$,
$changes$jscomp$175_it$jscomp$158_page_id$jscomp$126$$),$objects$jscomp$339$$),$add_component_to_variant_QMARK__data$jscomp$318$$),$self__$jscomp$4372$$.$parent_id$,$self__$jscomp$4372$$.$to_index$,$ids__$2$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3526$ignore_parents_QMARK_$$,$self__$jscomp$4372$$.$ignore_parents_QMARK_$]));$add_component_to_variant_QMARK__data$jscomp$318$$=function(){var $and__5023__auto__$jscomp$419$$=$APP.$cljs$core$some$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$instance_head_QMARK_$$,
$objects$jscomp$339$$),$ids__$2$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$419$$)?$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$app$common$files$helpers$get_parents_with_self$$($objects$jscomp$339$$,$self__$jscomp$4372$$.$parent_id$)):$and__5023__auto__$jscomp$419$$}();var $add_new_variant_QMARK_$$=function(){var $and__5023__auto__$jscomp$420$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($objects$jscomp$339$$.$cljs$core$IFn$_invoke$arity$1$?
$objects$jscomp$339$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4372$$.$parent_id$):$objects$jscomp$339$$($self__$jscomp$4372$$.$parent_id$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$420$$)?$APP.$cljs$core$some$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$main_instance_QMARK_$$,$objects$jscomp$339$$),$ids__$2$$):$and__5023__auto__$jscomp$420$$}(),$undo_id$jscomp$5$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$5$$),
$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$175_it$jscomp$158_page_id$jscomp$126$$),$app$main$data$workspace$collapse$expand_collapse$$($self__$jscomp$4372$$.$parent_id$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($all_parents$jscomp$9_ids__$1$jscomp$9_state$jscomp$400$$,$ids__$2$$)],null)),
$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$5$$),$APP.$cljs$core$truth_$$($add_component_to_variant_QMARK__data$jscomp$318$$)?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-component-to-variant"],null)):null,$APP.$cljs$core$truth_$$($add_new_variant_QMARK_$$)?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"add-new-variant",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:move-shapes-in-layers-tab"],null)):null)});return new $app$main$data$workspace$shapes$relocate_shapes_67644$$($ids$jscomp$82$$,$parent_id$jscomp$60$$,$to_index$jscomp$9$$,$p__67640$$,$p__67640$$,$ignore_parents_QMARK_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$bool$create_bool_shape$$=function($head$jscomp$18_head__$1$jscomp$2_id$jscomp$508$$,$shape$jscomp$445_shape__$1$jscomp$35_type$jscomp$452$$,$name$jscomp$297$$,$shapes$jscomp$53$$,$objects$jscomp$340$$){var $shape_id$jscomp$73$$=$APP.$cljs$core$truth_$$($head$jscomp$18_head__$1$jscomp$2_id$jscomp$508$$)?$head$jscomp$18_head__$1$jscomp$2_id$jscomp$508$$:$APP.$app$common$uuid$next$$();$head$jscomp$18_head__$1$jscomp$2_id$jscomp$508$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$445_shape__$1$jscomp$35_type$jscomp$452$$,
$APP.$cljs$cst$2025$difference$$)?$APP.$cljs$core$first$$($shapes$jscomp$53$$):$APP.$cljs$core$last$$($shapes$jscomp$53$$);$head$jscomp$18_head__$1$jscomp$2_id$jscomp$508$$=$APP.$cljs$core$contains_QMARK_$$($head$jscomp$18_head__$1$jscomp$2_id$jscomp$508$$,$APP.$cljs$cst$1890$svg_attrs$$)&&$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$18_head__$1$jscomp$2_id$jscomp$508$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($head$jscomp$18_head__$1$jscomp$2_id$jscomp$508$$,
$APP.$cljs$cst$1634$fills$$,$APP.$app$common$types$path$bool$get_default_fills$$()):$head$jscomp$18_head__$1$jscomp$2_id$jscomp$508$$;$shape$jscomp$445_shape__$1$jscomp$35_type$jscomp$452$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$266$id$$,$shape_id$jscomp$73$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1610$bool$$,$APP.$cljs$cst$1888$bool_type$$,$shape$jscomp$445_shape__$1$jscomp$35_type$jscomp$452$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$18_head__$1$jscomp$2_id$jscomp$508$$),
$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$18_head__$1$jscomp$2_id$jscomp$508$$),$APP.$cljs$cst$725$name$$,$name$jscomp$297$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$app$common$data$xf_COLON_map_id$$,$shapes$jscomp$53$$)],null);$shape$jscomp$445_shape__$1$jscomp$35_type$jscomp$452$$=$APP.$app$common$types$path$update_bool_shape$$($APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shape$jscomp$445_shape__$1$jscomp$35_type$jscomp$452$$,
$APP.$cljs$core$select_keys$$($head$jscomp$18_head__$1$jscomp$2_id$jscomp$508$$,$APP.$app$common$types$path$bool$style_properties$$)]))),$objects$jscomp$340$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$445_shape__$1$jscomp$35_type$jscomp$452$$,$app$common$files$helpers$get_position_on_parent$$($objects$jscomp$340$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$18_head__$1$jscomp$2_id$jscomp$508$$))],null)};
$APP.$app$common$geom$shapes$grid_layout$bounds$layout_content_points$$=function($bounds$jscomp$14$$,$parent$jscomp$226_parent_id$jscomp$62$$,$p__66043_row_tracks$$){var $column_tracks_map__66044__$1$$=$APP.$cljs$core$__destructure_map$$($p__66043_row_tracks$$);$p__66043_row_tracks$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_tracks_map__66044__$1$$,$APP.$cljs$cst$3661$row_tracks$$);$column_tracks_map__66044__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_tracks_map__66044__$1$$,
$APP.$cljs$cst$3662$column_tracks$$);$parent$jscomp$226_parent_id$jscomp$62$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$226_parent_id$jscomp$62$$);var $parent_bounds$jscomp$5$$=$APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$14$$,$parent$jscomp$226_parent_id$jscomp$62$$));return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($JSCompiler_inline_result$jscomp$1128_p1__66039_SHARP_$jscomp$inline_6500_p1__66040_SHARP_$$){var $JSCompiler_temp_const$jscomp$1127$$=
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$JSCompiler_temp_const$jscomp$1126$$=$APP.$cljs$cst$3663$start_p$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1128_p1__66039_SHARP_$jscomp$inline_6500_p1__66040_SHARP_$$),$JSCompiler_temp_const$jscomp$1125$$=$APP.$cljs$cst$3663$start_p$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1128_p1__66039_SHARP_$jscomp$inline_6500_p1__66040_SHARP_$$);$JSCompiler_inline_result$jscomp$1128_p1__66039_SHARP_$jscomp$inline_6500_p1__66040_SHARP_$$=
$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1128_p1__66039_SHARP_$jscomp$inline_6500_p1__66040_SHARP_$$);$JSCompiler_inline_result$jscomp$1128_p1__66039_SHARP_$jscomp$inline_6500_p1__66040_SHARP_$$=$APP.$app$common$geom$shapes$points$start_vv$$($parent_bounds$jscomp$5$$,$JSCompiler_inline_result$jscomp$1128_p1__66039_SHARP_$jscomp$inline_6500_p1__66040_SHARP_$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$1127$$,
[$JSCompiler_temp_const$jscomp$1126$$,$APP.$app$common$geom$point$add$$($JSCompiler_temp_const$jscomp$1125$$,$JSCompiler_inline_result$jscomp$1128_p1__66039_SHARP_$jscomp$inline_6500_p1__66040_SHARP_$$)],null)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p__66043_row_tracks$$])),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($JSCompiler_inline_result$jscomp$1124_p1__66038_SHARP_$jscomp$inline_6502_p1__66042_SHARP_$$){var $JSCompiler_temp_const$jscomp$1123$$=
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$JSCompiler_temp_const$jscomp$1122$$=$APP.$cljs$cst$3663$start_p$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1124_p1__66038_SHARP_$jscomp$inline_6502_p1__66042_SHARP_$$),$JSCompiler_temp_const$jscomp$1121$$=$APP.$cljs$cst$3663$start_p$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1124_p1__66038_SHARP_$jscomp$inline_6502_p1__66042_SHARP_$$);$JSCompiler_inline_result$jscomp$1124_p1__66038_SHARP_$jscomp$inline_6502_p1__66042_SHARP_$$=
$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1124_p1__66038_SHARP_$jscomp$inline_6502_p1__66042_SHARP_$$);$JSCompiler_inline_result$jscomp$1124_p1__66038_SHARP_$jscomp$inline_6502_p1__66042_SHARP_$$=$APP.$app$common$geom$shapes$points$start_hv$$($parent_bounds$jscomp$5$$,$JSCompiler_inline_result$jscomp$1124_p1__66038_SHARP_$jscomp$inline_6502_p1__66042_SHARP_$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$1123$$,
[$JSCompiler_temp_const$jscomp$1122$$,$APP.$app$common$geom$point$add$$($JSCompiler_temp_const$jscomp$1121$$,$JSCompiler_inline_result$jscomp$1124_p1__66038_SHARP_$jscomp$inline_6502_p1__66042_SHARP_$$)],null)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$column_tracks_map__66044__$1$$]))]))};
$APP.$app$common$geom$shapes$grid_layout$bounds$layout_content_bounds$$=function($bounds$jscomp$15_layout_points$$,$map__66058__$1_p__66057$$,$layout_data$$){$map__66058__$1_p__66057$$=$APP.$cljs$core$__destructure_map$$($map__66058__$1_p__66057$$);var $layout_padding$jscomp$4_pad_top$jscomp$3_pad_top__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66058__$1_p__66057$$,$APP.$cljs$cst$1686$layout_padding$$),$parent_bounds$jscomp$6_parent_id$jscomp$63$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__66058__$1_p__66057$$);
$parent_bounds$jscomp$6_parent_id$jscomp$63$$=$APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$15_layout_points$$,$parent_bounds$jscomp$6_parent_id$jscomp$63$$));var $map__66062__$1_pad_left$jscomp$3_pad_left__$1$$=$APP.$cljs$core$__destructure_map$$($layout_padding$jscomp$4_pad_top$jscomp$3_pad_top__$1$$);$layout_padding$jscomp$4_pad_top$jscomp$3_pad_top__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66062__$1_pad_left$jscomp$3_pad_left__$1$$,
$APP.$cljs$cst$1093$p1$$);var $pad_right$jscomp$3_pad_right__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66062__$1_pad_left$jscomp$3_pad_left__$1$$,$APP.$cljs$cst$1091$p2$$),$pad_bottom$jscomp$3_pad_bottom__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66062__$1_pad_left$jscomp$3_pad_left__$1$$,$APP.$cljs$cst$1687$p3$$);$map__66062__$1_pad_left$jscomp$3_pad_left__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66062__$1_pad_left$jscomp$3_pad_left__$1$$,
$APP.$cljs$cst$1688$p4$$);$layout_padding$jscomp$4_pad_top$jscomp$3_pad_top__$1$$=$APP.$cljs$core$truth_$$($layout_padding$jscomp$4_pad_top$jscomp$3_pad_top__$1$$)?$layout_padding$jscomp$4_pad_top$jscomp$3_pad_top__$1$$:0;$pad_right$jscomp$3_pad_right__$1$$=$APP.$cljs$core$truth_$$($pad_right$jscomp$3_pad_right__$1$$)?$pad_right$jscomp$3_pad_right__$1$$:0;$pad_bottom$jscomp$3_pad_bottom__$1$$=$APP.$cljs$core$truth_$$($pad_bottom$jscomp$3_pad_bottom__$1$$)?$pad_bottom$jscomp$3_pad_bottom__$1$$:0;$map__66062__$1_pad_left$jscomp$3_pad_left__$1$$=
$APP.$cljs$core$truth_$$($map__66062__$1_pad_left$jscomp$3_pad_left__$1$$)?$map__66062__$1_pad_left$jscomp$3_pad_left__$1$$:0;$bounds$jscomp$15_layout_points$$=$APP.$app$common$geom$shapes$grid_layout$bounds$layout_content_points$$($bounds$jscomp$15_layout_points$$,$map__66058__$1_p__66057$$,$layout_data$$);return $APP.$app$common$data$not_empty_QMARK_$$($bounds$jscomp$15_layout_points$$)?$app$common$geom$shapes$points$pad_points$$($app$common$geom$shapes$points$merge_parent_coords_bounds$$($bounds$jscomp$15_layout_points$$,
$parent_bounds$jscomp$6_parent_id$jscomp$63$$),-$layout_padding$jscomp$4_pad_top$jscomp$3_pad_top__$1$$,-$pad_right$jscomp$3_pad_right__$1$$,-$pad_bottom$jscomp$3_pad_bottom__$1$$,-$map__66062__$1_pad_left$jscomp$3_pad_left__$1$$):$parent_bounds$jscomp$6_parent_id$jscomp$63$$};
$app$common$geom$shapes$grid_layout$layout_data$child_min_width$$=function($child$jscomp$80$$,$child_bounds$jscomp$3$$,$bounds$jscomp$16$$,$objects$jscomp$347$$){return $app$common$types$shape$layout$child_width_margin$$($child$jscomp$80$$)+($app$common$geom$shapes$grid_layout$layout_data$_child_min_width$$.$cljs$core$IFn$_invoke$arity$5$?$app$common$geom$shapes$grid_layout$layout_data$_child_min_width$$.$cljs$core$IFn$_invoke$arity$5$($child$jscomp$80$$,$child_bounds$jscomp$3$$,$bounds$jscomp$16$$,
$objects$jscomp$347$$,!0):$app$common$geom$shapes$grid_layout$layout_data$_child_min_width$$($child$jscomp$80$$,$child_bounds$jscomp$3$$,$bounds$jscomp$16$$,$objects$jscomp$347$$,!0))};
$app$common$geom$shapes$grid_layout$layout_data$child_min_height$$=function($child$jscomp$81$$,$child_bounds$jscomp$4$$,$bounds$jscomp$17$$,$objects$jscomp$348$$){return $app$common$types$shape$layout$child_height_margin$$($child$jscomp$81$$)+($app$common$geom$shapes$grid_layout$layout_data$_child_min_height$$.$cljs$core$IFn$_invoke$arity$5$?$app$common$geom$shapes$grid_layout$layout_data$_child_min_height$$.$cljs$core$IFn$_invoke$arity$5$($child$jscomp$81$$,$child_bounds$jscomp$4$$,$bounds$jscomp$17$$,
$objects$jscomp$348$$,!0):$app$common$geom$shapes$grid_layout$layout_data$_child_min_height$$($child$jscomp$81$$,$child_bounds$jscomp$4$$,$bounds$jscomp$17$$,$objects$jscomp$348$$,!0))};
$app$common$geom$shapes$grid_layout$layout_data$layout_bounds$$=function($pad_top$jscomp$4_parent$jscomp$228$$,$shape_bounds$$){var $pad_left$jscomp$4_vec__66361$$=$app$common$types$shape$layout$paddings$$($pad_top$jscomp$4_parent$jscomp$228$$);$pad_top$jscomp$4_parent$jscomp$228$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($pad_left$jscomp$4_vec__66361$$,0,null);var $pad_right$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($pad_left$jscomp$4_vec__66361$$,1,null),
$pad_bottom$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($pad_left$jscomp$4_vec__66361$$,2,null);$pad_left$jscomp$4_vec__66361$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($pad_left$jscomp$4_vec__66361$$,3,null);return $app$common$geom$shapes$points$pad_points$$($shape_bounds$$,$pad_top$jscomp$4_parent$jscomp$228$$,$pad_right$jscomp$4$$,$pad_bottom$jscomp$4$$,$pad_left$jscomp$4_vec__66361$$)};
$app$common$geom$shapes$grid_layout$layout_data$calculate_initial_track_size$$=function($total_value$$,$map__66365__$1_p__66364$$){$map__66365__$1_p__66364$$=$APP.$cljs$core$__destructure_map$$($map__66365__$1_p__66364$$);var $type$jscomp$460$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66365__$1_p__66364$$,$APP.$cljs$cst$139$type$$),$value$jscomp$544$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66365__$1_p__66364$$,$APP.$cljs$cst$260$value$$),$max_size$jscomp$3_vec__66366$$=
function(){switch($type$jscomp$460$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$460$$.$fqn$:null){case "percent":var $value__$1$jscomp$16$$=$total_value$$*$value$jscomp$544$$/100;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$value__$1$jscomp$16$$,$value__$1$jscomp$16$$],null);case "fixed":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$value$jscomp$544$$,$value$jscomp$544$$],null);
default:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[.01,Infinity],null)}}(),$size$jscomp$118$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($max_size$jscomp$3_vec__66366$$,0,null);$max_size$jscomp$3_vec__66366$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($max_size$jscomp$3_vec__66366$$,1,null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__66365__$1_p__66364$$,$APP.$cljs$cst$874$size$$,
$size$jscomp$118$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$833$max_size$$,$max_size$jscomp$3_vec__66366$$]))};
$app$common$geom$shapes$grid_layout$layout_data$set_auto_base_size$$=function($track_list$$,$children$jscomp$208$$,$shape_cells$$,$bounds$jscomp$18$$,$objects$jscomp$349$$,$type$jscomp$461_vec__66376$$){$type$jscomp$461_vec__66376$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$461_vec__66376$$,$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1658$column_span$$,
$app$common$geom$shapes$grid_layout$layout_data$child_min_width$$],null):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$1657$row_span$$,$app$common$geom$shapes$grid_layout$layout_data$child_min_height$$],null);var $prop$jscomp$24$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($type$jscomp$461_vec__66376$$,0,null),$prop_span$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($type$jscomp$461_vec__66376$$,
1,null),$size_fn$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($type$jscomp$461_vec__66376$$,2,null);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($tracks$jscomp$1$$,$child_shape_p__66379$$){var $child_bounds$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_shape_p__66379$$,0,null);$child_shape_p__66379$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_shape_p__66379$$,1,null);var $cell$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape_cells$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_shape_p__66379$$)),$idx$jscomp$85$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$24$$,$prop$jscomp$24$$)-1,$track$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tracks$jscomp$1$$,$idx$jscomp$85$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$24$$,$prop_span$jscomp$4$$),1)&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1660$flex$$,null,$APP.$cljs$cst$1672$auto$$,null],null),null),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$6$$))?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($tracks$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$idx$jscomp$85$$,$APP.$cljs$cst$874$size$$],null),$APP.$cljs$core$max$$,$size_fn$$.$cljs$core$IFn$_invoke$arity$4$?$size_fn$$.$cljs$core$IFn$_invoke$arity$4$($child_shape_p__66379$$,
$child_bounds$jscomp$5$$,$bounds$jscomp$18$$,$objects$jscomp$349$$):$size_fn$$($child_shape_p__66379$$,$child_bounds$jscomp$5$$,$bounds$jscomp$18$$,$objects$jscomp$349$$)):$tracks$jscomp$1$$},$track_list$$,$children$jscomp$208$$)};
$app$common$geom$shapes$grid_layout$layout_data$tracks_total_size$$=function($track_list$jscomp$1$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$123$$,$map__66399__$1_p__66398_size$jscomp$119$$){$map__66399__$1_p__66398_size$jscomp$119$$=$APP.$cljs$core$__destructure_map$$($map__66399__$1_p__66398_size$jscomp$119$$);$map__66399__$1_p__66398_size$jscomp$119$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66399__$1_p__66398_size$jscomp$119$$,
$APP.$cljs$cst$874$size$$);return $acc$jscomp$123$$+$map__66399__$1_p__66398_size$jscomp$119$$},0,$track_list$jscomp$1$$)};
$app$common$geom$shapes$grid_layout$layout_data$tracks_total_frs$$=function($track_list$jscomp$2$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$124$$,$p__66404_type$jscomp$462$$){var $map__66405__$1_value$jscomp$545_value__$1$jscomp$17$$=$APP.$cljs$core$__destructure_map$$($p__66404_type$jscomp$462$$);$p__66404_type$jscomp$462$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66405__$1_value$jscomp$545_value__$1$jscomp$17$$,$APP.$cljs$cst$139$type$$);
$map__66405__$1_value$jscomp$545_value__$1$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66405__$1_value$jscomp$545_value__$1$jscomp$17$$,$APP.$cljs$cst$260$value$$);$map__66405__$1_value$jscomp$545_value__$1$jscomp$17$$=1>$map__66405__$1_value$jscomp$545_value__$1$jscomp$17$$?1:$map__66405__$1_value$jscomp$545_value__$1$jscomp$17$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__66404_type$jscomp$462$$,$APP.$cljs$cst$1660$flex$$)?$acc$jscomp$124$$+$map__66405__$1_value$jscomp$545_value__$1$jscomp$17$$:
$acc$jscomp$124$$},0,$track_list$jscomp$2$$)};
$app$common$geom$shapes$grid_layout$layout_data$tracks_total_autos$$=function($track_list$jscomp$3$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$125$$,$map__66414__$1_p__66413_type$jscomp$463$$){$map__66414__$1_p__66413_type$jscomp$463$$=$APP.$cljs$core$__destructure_map$$($map__66414__$1_p__66413_type$jscomp$463$$);$map__66414__$1_p__66413_type$jscomp$463$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66414__$1_p__66413_type$jscomp$463$$,$APP.$cljs$cst$139$type$$);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__66414__$1_p__66413_type$jscomp$463$$,$APP.$cljs$cst$1672$auto$$)?$acc$jscomp$125$$+1:$acc$jscomp$125$$},0,$track_list$jscomp$3$$)};
$app$common$geom$shapes$grid_layout$layout_data$set_fr_value$$=function($track_list$jscomp$4$$,$fr_value$$,$auto_QMARK_$jscomp$1$$){function $change_fn$$($delta$jscomp$40$$){return function($assign_fr$jscomp$2$$,$p__66456_t$jscomp$90$$){var $idx$jscomp$87$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66456_t$jscomp$90$$,0,null);$p__66456_t$jscomp$90$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66456_t$jscomp$90$$,1,null);var $fr$jscomp$2$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p__66456_t$jscomp$90$$);
return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($assign_fr$jscomp$2$$,$idx$jscomp$87$$)<=$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($p__66456_t$jscomp$90$$)?$assign_fr$jscomp$2$$:$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($assign_fr$jscomp$2$$,$idx$jscomp$87$$,$APP.$cljs$core$_$$,$delta$jscomp$40$$*$fr$jscomp$2$$)}}function $assign_fn$$($free_frs_p__66433$$,$p__66434_t$jscomp$89$$){var $assign_fr$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($free_frs_p__66433$$,
0,null),$pending$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($free_frs_p__66433$$,1,null);$free_frs_p__66433$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($free_frs_p__66433$$,2,null);var $idx$jscomp$86$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66434_t$jscomp$89$$,0,null);$p__66434_t$jscomp$89$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66434_t$jscomp$89$$,1,null);var $fr$jscomp$1$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p__66434_t$jscomp$89$$),
$current$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($assign_fr$jscomp$1$$,$idx$jscomp$86$$,$fr_value$$*$fr$jscomp$1$$),$full_QMARK_$jscomp$1$$=$current$jscomp$39$$<=$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($p__66434_t$jscomp$89$$),$cur_pending$$=$full_QMARK_$jscomp$1$$?$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($p__66434_t$jscomp$89$$)-$current$jscomp$39$$:0;return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($assign_fr$jscomp$1$$,$idx$jscomp$86$$,$full_QMARK_$jscomp$1$$?$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($p__66434_t$jscomp$89$$):$current$jscomp$39$$),$pending$jscomp$15$$+$cur_pending$$,$full_QMARK_$jscomp$1$$?$free_frs_p__66433$$:$free_frs_p__66433$$+$fr$jscomp$1$$],null)}function $flex_QMARK_$$($p1__66416_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__66416_SHARP_$$)))}
var $assign_fr$$=function(){for(var $assign_fr$jscomp$3_assign_fr__$1$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;;){var $free_frs$jscomp$1_vec__66478$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($assign_fn$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$assign_fr$jscomp$3_assign_fr__$1$$,0,0],null),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($flex_QMARK_$$,$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($track_list$jscomp$4$$)));
$assign_fr$jscomp$3_assign_fr__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($free_frs$jscomp$1_vec__66478$$,0,null);var $pending$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($free_frs$jscomp$1_vec__66478$$,1,null);$free_frs$jscomp$1_vec__66478$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($free_frs$jscomp$1_vec__66478$$,2,null);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($auto_QMARK_$jscomp$1$$)?$auto_QMARK_$jscomp$1$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($free_frs$jscomp$1_vec__66478$$,
0)||$APP.$app$common$math$almost_zero_QMARK_$$($pending$jscomp$16$$)))return $assign_fr$jscomp$3_assign_fr__$1$$;$assign_fr$jscomp$3_assign_fr__$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($change_fn$$($pending$jscomp$16$$/$free_frs$jscomp$1_vec__66478$$),$assign_fr$jscomp$3_assign_fr__$1$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($flex_QMARK_$$,$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($track_list$jscomp$4$$)))}}();return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($track_list__$1$jscomp$1$$,
$assignment_p__66496$$){var $idx$jscomp$88$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($assignment_p__66496$$,0,null);$assignment_p__66496$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($assignment_p__66496$$,1,null);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($track_list__$1$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$idx$jscomp$88$$,$APP.$cljs$cst$874$size$$],null),$APP.$cljs$core$max$$,
$assignment_p__66496$$)},$track_list$jscomp$4$$,$assign_fr$$)};
$app$common$geom$shapes$grid_layout$layout_data$stretch_tracks$$=function($track_list$jscomp$5$$,$add_size$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($JSCompiler_temp$jscomp$1129_map__66508__$1_p__66507$$){$JSCompiler_temp$jscomp$1129_map__66508__$1_p__66507$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$1129_map__66508__$1_p__66507$$);var $type$jscomp$464_x__5113__auto__$jscomp$inline_6504$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1129_map__66508__$1_p__66507$$,
$APP.$cljs$cst$139$type$$),$size$jscomp$120$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1129_map__66508__$1_p__66507$$,$APP.$cljs$cst$874$size$$),$max_size$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1129_map__66508__$1_p__66507$$,$cljs$cst$833$max_size$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$type$jscomp$464_x__5113__auto__$jscomp$inline_6504$$)&&($type$jscomp$464_x__5113__auto__$jscomp$inline_6504$$=
$size$jscomp$120$$+$add_size$$,$JSCompiler_temp$jscomp$1129_map__66508__$1_p__66507$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$1129_map__66508__$1_p__66507$$,$APP.$cljs$cst$874$size$$,$type$jscomp$464_x__5113__auto__$jscomp$inline_6504$$<$max_size$jscomp$4$$?$type$jscomp$464_x__5113__auto__$jscomp$inline_6504$$:$max_size$jscomp$4$$));return $JSCompiler_temp$jscomp$1129_map__66508__$1_p__66507$$},$track_list$jscomp$5$$)};
$app$common$geom$shapes$grid_layout$layout_data$has_flex_track_QMARK_$$=function($prop$jscomp$25_type$jscomp$465$$,$track_list$jscomp$6_tracks$jscomp$2$$,$cell$jscomp$25_to_idx$$){var $from_idx_vec__66514$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$25_type$jscomp$465$$,$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1658$column_span$$],null):new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$1657$row_span$$],null);$prop$jscomp$25_type$jscomp$465$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from_idx_vec__66514$$,0,null);var $prop_span$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from_idx_vec__66514$$,1,null);$from_idx_vec__66514$$=$APP.$app$common$math$clamp$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$25_to_idx$$,$prop$jscomp$25_type$jscomp$465$$)-
1,0,$APP.$cljs$core$count$$($track_list$jscomp$6_tracks$jscomp$2$$)-1);$cell$jscomp$25_to_idx$$=$APP.$app$common$math$clamp$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$25_to_idx$$,$prop$jscomp$25_type$jscomp$465$$)-1+$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$25_to_idx$$,$prop_span$jscomp$5$$),0,$APP.$cljs$core$count$$($track_list$jscomp$6_tracks$jscomp$2$$)-1);$track_list$jscomp$6_tracks$jscomp$2$$=$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($track_list$jscomp$6_tracks$jscomp$2$$,
$from_idx_vec__66514$$,$cell$jscomp$25_to_idx$$);return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__66510_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__66510_SHARP_$$))},$track_list$jscomp$6_tracks$jscomp$2$$)!=null};
$app$common$geom$shapes$grid_layout$layout_data$size_to_allocate$$=function($sfn$jscomp$1_type$jscomp$466$$,$gap$jscomp$3_parent$jscomp$229_row_gap$jscomp$3$$,$child$jscomp$82_p__66523$$,$cell$jscomp$26_span$jscomp$6$$,$bounds$jscomp$19$$,$objects$jscomp$350$$){var $child_bounds$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$82_p__66523$$,0,null);$child$jscomp$82_p__66523$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$82_p__66523$$,1,null);
var $column_gap$jscomp$3_prop_span$jscomp$6_vec__66527_vec__66530$$=$APP.$app$common$types$shape$layout$gaps$$($gap$jscomp$3_parent$jscomp$229_row_gap$jscomp$3$$);$gap$jscomp$3_parent$jscomp$229_row_gap$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column_gap$jscomp$3_prop_span$jscomp$6_vec__66527_vec__66530$$,0,null);$column_gap$jscomp$3_prop_span$jscomp$6_vec__66527_vec__66530$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column_gap$jscomp$3_prop_span$jscomp$6_vec__66527_vec__66530$$,
1,null);$column_gap$jscomp$3_prop_span$jscomp$6_vec__66527_vec__66530$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($sfn$jscomp$1_type$jscomp$466$$,$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$geom$shapes$grid_layout$layout_data$child_min_width$$,$column_gap$jscomp$3_prop_span$jscomp$6_vec__66527_vec__66530$$,$APP.$cljs$cst$1658$column_span$$],null):new $APP.$cljs$core$PersistentVector$$(null,3,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$geom$shapes$grid_layout$layout_data$child_min_height$$,$gap$jscomp$3_parent$jscomp$229_row_gap$jscomp$3$$,$APP.$cljs$cst$1657$row_span$$],null);$sfn$jscomp$1_type$jscomp$466$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column_gap$jscomp$3_prop_span$jscomp$6_vec__66527_vec__66530$$,0,null);$gap$jscomp$3_parent$jscomp$229_row_gap$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column_gap$jscomp$3_prop_span$jscomp$6_vec__66527_vec__66530$$,
1,null);$column_gap$jscomp$3_prop_span$jscomp$6_vec__66527_vec__66530$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column_gap$jscomp$3_prop_span$jscomp$6_vec__66527_vec__66530$$,2,null);$cell$jscomp$26_span$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$26_span$jscomp$6$$,$column_gap$jscomp$3_prop_span$jscomp$6_vec__66527_vec__66530$$);return($sfn$jscomp$1_type$jscomp$466$$.$cljs$core$IFn$_invoke$arity$4$?$sfn$jscomp$1_type$jscomp$466$$.$cljs$core$IFn$_invoke$arity$4$($child$jscomp$82_p__66523$$,
$child_bounds$jscomp$6$$,$bounds$jscomp$19$$,$objects$jscomp$350$$):$sfn$jscomp$1_type$jscomp$466$$($child$jscomp$82_p__66523$$,$child_bounds$jscomp$6$$,$bounds$jscomp$19$$,$objects$jscomp$350$$))-$gap$jscomp$3_parent$jscomp$229_row_gap$jscomp$3$$*($cell$jscomp$26_span$jscomp$6$$-1)};
$app$common$geom$shapes$grid_layout$layout_data$allocate_auto_tracks$$=function($allocations$$,$indexed_tracks$$,$to_allocate$$){for(;;){if($APP.$cljs$core$empty_QMARK_$$($indexed_tracks$$))return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$allocations$$,$to_allocate$$],null);var $G__66759_vec__66542$$=$APP.$cljs$core$first$$($indexed_tracks$$),$idx$jscomp$89$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66759_vec__66542$$,0,null),
$track$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66759_vec__66542$$,1,null),$old_allocated$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($allocations$$,$idx$jscomp$89$$,.01),$auto_track_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$8$$)),$allocated$$=$auto_track_QMARK_$$?function(){var $x__5110__auto__$jscomp$62_x__5110__auto__$jscomp$inline_6506$$=
$old_allocated$$;var $y__5111__auto__$jscomp$62_y__5111__auto__$jscomp$inline_6507$$=$to_allocate$$/$APP.$cljs$core$count$$($indexed_tracks$$);$x__5110__auto__$jscomp$62_x__5110__auto__$jscomp$inline_6506$$=$x__5110__auto__$jscomp$62_x__5110__auto__$jscomp$inline_6506$$>$y__5111__auto__$jscomp$62_y__5111__auto__$jscomp$inline_6507$$?$x__5110__auto__$jscomp$62_x__5110__auto__$jscomp$inline_6506$$:$y__5111__auto__$jscomp$62_y__5111__auto__$jscomp$inline_6507$$;$y__5111__auto__$jscomp$62_y__5111__auto__$jscomp$inline_6507$$=
$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$8$$);return $x__5110__auto__$jscomp$62_x__5110__auto__$jscomp$inline_6506$$>$y__5111__auto__$jscomp$62_y__5111__auto__$jscomp$inline_6507$$?$x__5110__auto__$jscomp$62_x__5110__auto__$jscomp$inline_6506$$:$y__5111__auto__$jscomp$62_y__5111__auto__$jscomp$inline_6507$$}():$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$8$$);$G__66759_vec__66542$$=function(){var $G__66557$$=$allocations$$;return $auto_track_QMARK_$$?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66557$$,$idx$jscomp$89$$,$allocated$$):$G__66557$$}();var $G__66760$$=$APP.$cljs$core$rest$$($indexed_tracks$$),$G__66761$$=$to_allocate$$-$allocated$$;$allocations$$=$G__66759_vec__66542$$;$indexed_tracks$$=$G__66760$$;$to_allocate$$=$G__66761$$}};
$app$common$geom$shapes$grid_layout$layout_data$allocate_flex_tracks$$=function($allocations$jscomp$1$$,$G__66764_indexed_tracks$jscomp$1$$,$G__66766_fr_value$jscomp$1$$){for(;;){if($APP.$cljs$core$empty_QMARK_$$($G__66764_indexed_tracks$jscomp$1$$))return $allocations$jscomp$1$$;var $G__66763_fr$jscomp$3_vec__66558$$=$APP.$cljs$core$first$$($G__66764_indexed_tracks$jscomp$1$$),$idx$jscomp$90$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66763_fr$jscomp$3_vec__66558$$,0,null),$track$jscomp$9$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66763_fr$jscomp$3_vec__66558$$,1,null),$old_allocated$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($allocations$jscomp$1$$,$idx$jscomp$90$$,.01),$auto_track_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$9$$)),$flex_track_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$9$$));$G__66763_fr$jscomp$3_vec__66558$$=$flex_track_QMARK_$$?$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$9$$):0;var $target_allocation$$=$G__66766_fr_value$jscomp$1$$*$G__66763_fr$jscomp$3_vec__66558$$,$allocated$jscomp$1$$=$auto_track_QMARK_$jscomp$1$$||$flex_track_QMARK_$$?function(){var $x__5110__auto__$jscomp$64_x__5110__auto__$jscomp$inline_6509$$=$target_allocation$$;var $y__5111__auto__$jscomp$64_y__5111__auto__$jscomp$inline_6510$$=
$old_allocated$jscomp$1$$;$x__5110__auto__$jscomp$64_x__5110__auto__$jscomp$inline_6509$$=$x__5110__auto__$jscomp$64_x__5110__auto__$jscomp$inline_6509$$>$y__5111__auto__$jscomp$64_y__5111__auto__$jscomp$inline_6510$$?$x__5110__auto__$jscomp$64_x__5110__auto__$jscomp$inline_6509$$:$y__5111__auto__$jscomp$64_y__5111__auto__$jscomp$inline_6510$$;$y__5111__auto__$jscomp$64_y__5111__auto__$jscomp$inline_6510$$=$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$9$$);return $x__5110__auto__$jscomp$64_x__5110__auto__$jscomp$inline_6509$$>
$y__5111__auto__$jscomp$64_y__5111__auto__$jscomp$inline_6510$$?$x__5110__auto__$jscomp$64_x__5110__auto__$jscomp$inline_6509$$:$y__5111__auto__$jscomp$64_y__5111__auto__$jscomp$inline_6510$$}():$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$9$$);$G__66763_fr$jscomp$3_vec__66558$$=function(){var $G__66574$$=$allocations$jscomp$1$$;return $flex_track_QMARK_$$||$auto_track_QMARK_$jscomp$1$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66574$$,$idx$jscomp$90$$,
$allocated$jscomp$1$$):$G__66574$$}();$G__66764_indexed_tracks$jscomp$1$$=$APP.$cljs$core$rest$$($G__66764_indexed_tracks$jscomp$1$$);$allocations$jscomp$1$$=$G__66763_fr$jscomp$3_vec__66558$$}};
$app$common$geom$shapes$grid_layout$layout_data$set_auto_multi_span$$=function($parent$jscomp$230$$,$track_list$jscomp$7$$,$children_map$$,$shape_cells$jscomp$1$$,$bounds$jscomp$20$$,$objects$jscomp$351$$,$type$jscomp$467$$){var $vec__66587$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$467$$,$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1658$column_span$$],
null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$1657$row_span$$],null),$prop$jscomp$26$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__66587$$,0,null),$prop_span$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__66587$$,1,null),$allocated$jscomp$2$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($allocated$jscomp$3$$,$cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$){var $allocated__$1_allocated__$2_shape_id$jscomp$81_to_allocate__$1$$=
$APP.$cljs$core$first$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$)),$from_idx$jscomp$1_indexed_tracks$jscomp$2_non_assigned_indexed_tracks_to_allocate__$2_vec__66594$$=$APP.$app$common$math$clamp$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$,$prop$jscomp$26$$)-1,0,$APP.$cljs$core$count$$($track_list$jscomp$7$$)-
1),$to_idx$jscomp$1$$=$APP.$app$common$math$clamp$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$,$prop$jscomp$26$$)-1+$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$,$prop_span$jscomp$7$$),0,$APP.$cljs$core$count$$($track_list$jscomp$7$$)-1);$from_idx$jscomp$1_indexed_tracks$jscomp$2_non_assigned_indexed_tracks_to_allocate__$2_vec__66594$$=
$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($track_list$jscomp$7$$),$from_idx$jscomp$1_indexed_tracks$jscomp$2_non_assigned_indexed_tracks_to_allocate__$2_vec__66594$$,$to_idx$jscomp$1$$);$cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$=$app$common$geom$shapes$grid_layout$layout_data$size_to_allocate$$($type$jscomp$467$$,$parent$jscomp$230$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children_map$$,
$allocated__$1_allocated__$2_shape_id$jscomp$81_to_allocate__$1$$),$cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$,$bounds$jscomp$20$$,$objects$jscomp$351$$);$cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__66603_result$jscomp$269$$,$p__66604$$){var $to_allocate__$1$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66603_result$jscomp$269$$,
0,null);$p__66603_result$jscomp$269$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66603_result$jscomp$269$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66604$$,0,null);var $track$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66604$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$10$$))?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$to_allocate__$1$jscomp$1$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p__66603_result$jscomp$269$$,$p__66604$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$to_allocate__$1$jscomp$1$$-$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$10$$),$p__66603_result$jscomp$269$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$from_idx$jscomp$1_indexed_tracks$jscomp$2_non_assigned_indexed_tracks_to_allocate__$2_vec__66594$$);$allocated__$1_allocated__$2_shape_id$jscomp$81_to_allocate__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$,0,null);$cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$,1,null);$from_idx$jscomp$1_indexed_tracks$jscomp$2_non_assigned_indexed_tracks_to_allocate__$2_vec__66594$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p__66612$$){var $idx$jscomp$91$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66612$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66612$$,1,null);return $APP.$cljs$core$contains_QMARK_$$($allocated$jscomp$3$$,
$idx$jscomp$91$$)},$cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$);$from_idx$jscomp$1_indexed_tracks$jscomp$2_non_assigned_indexed_tracks_to_allocate__$2_vec__66594$$=$app$common$geom$shapes$grid_layout$layout_data$allocate_auto_tracks$$($allocated$jscomp$3$$,$from_idx$jscomp$1_indexed_tracks$jscomp$2_non_assigned_indexed_tracks_to_allocate__$2_vec__66594$$,$allocated__$1_allocated__$2_shape_id$jscomp$81_to_allocate__$1$$>0?$allocated__$1_allocated__$2_shape_id$jscomp$81_to_allocate__$1$$:
0);$allocated__$1_allocated__$2_shape_id$jscomp$81_to_allocate__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from_idx$jscomp$1_indexed_tracks$jscomp$2_non_assigned_indexed_tracks_to_allocate__$2_vec__66594$$,0,null);$from_idx$jscomp$1_indexed_tracks$jscomp$2_non_assigned_indexed_tracks_to_allocate__$2_vec__66594$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from_idx$jscomp$1_indexed_tracks$jscomp$2_non_assigned_indexed_tracks_to_allocate__$2_vec__66594$$,1,null);$cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$=
$app$common$geom$shapes$grid_layout$layout_data$allocate_auto_tracks$$($allocated__$1_allocated__$2_shape_id$jscomp$81_to_allocate__$1$$,$cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$,$from_idx$jscomp$1_indexed_tracks$jscomp$2_non_assigned_indexed_tracks_to_allocate__$2_vec__66594$$>0?$from_idx$jscomp$1_indexed_tracks$jscomp$2_non_assigned_indexed_tracks_to_allocate__$2_vec__66594$$:0);$allocated__$1_allocated__$2_shape_id$jscomp$81_to_allocate__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell$jscomp$27_indexed_tracks__$1_to_allocate$jscomp$2_vec__66591_vec__66597$$,1,null);return $allocated__$1_allocated__$2_shape_id$jscomp$81_to_allocate__$1$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($prop_span$jscomp$7$$,$APP.$cljs$core$_$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66578_SHARP_$$){return $app$common$geom$shapes$grid_layout$layout_data$has_flex_track_QMARK_$$($type$jscomp$467$$,
$track_list$jscomp$7$$,$p1__66578_SHARP_$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66577_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__66577_SHARP_$$,$prop_span$jscomp$7$$)>1},$APP.$cljs$core$vals$$($shape_cells$jscomp$1$$)))));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__66580_SHARP_$$,$p2__66579_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p2__66579_SHARP_$$,
$APP.$cljs$cst$874$size$$,$APP.$cljs$core$max$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($allocated$jscomp$2$$,$p1__66580_SHARP_$$,0))}),$track_list$jscomp$7$$)};
$app$common$geom$shapes$grid_layout$layout_data$set_flex_multi_span$$=function($parent$jscomp$231$$,$track_list$jscomp$8$$,$children_map$jscomp$1$$,$shape_cells$jscomp$2$$,$bounds$jscomp$21$$,$objects$jscomp$352$$,$type$jscomp$468$$){var $vec__66620$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$468$$,$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1658$column_span$$],
null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$1657$row_span$$],null),$prop$jscomp$27$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__66620$$,0,null),$prop_span$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__66620$$,1,null),$allocate_fr_tracks$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($alloc$$,$cell$jscomp$28_to_allocate$jscomp$3_to_allocate__$1$jscomp$2$$){var $shape_id$jscomp$82_total_frs$$=
$APP.$cljs$core$first$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$28_to_allocate$jscomp$3_to_allocate__$1$jscomp$2$$)),$from_idx$jscomp$2_indexed_tracks$jscomp$3_indexed_tracks__$1$jscomp$1_vec__66633$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$28_to_allocate$jscomp$3_to_allocate__$1$jscomp$2$$,$prop$jscomp$27$$)-1,$to_idx$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$28_to_allocate$jscomp$3_to_allocate__$1$jscomp$2$$,
$prop$jscomp$27$$)-1+$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$28_to_allocate$jscomp$3_to_allocate__$1$jscomp$2$$,$prop_span$jscomp$8$$);$from_idx$jscomp$2_indexed_tracks$jscomp$3_indexed_tracks__$1$jscomp$1_vec__66633$$=$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($track_list$jscomp$8$$),$from_idx$jscomp$2_indexed_tracks$jscomp$3_indexed_tracks__$1$jscomp$1_vec__66633$$,$to_idx$jscomp$2$$);
$cell$jscomp$28_to_allocate$jscomp$3_to_allocate__$1$jscomp$2$$=$app$common$geom$shapes$grid_layout$layout_data$size_to_allocate$$($type$jscomp$468$$,$parent$jscomp$231$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children_map$jscomp$1$$,$shape_id$jscomp$82_total_frs$$),$cell$jscomp$28_to_allocate$jscomp$3_to_allocate__$1$jscomp$2$$,$bounds$jscomp$21$$,$objects$jscomp$352$$);$from_idx$jscomp$2_indexed_tracks$jscomp$3_indexed_tracks__$1$jscomp$1_vec__66633$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__66636_result$jscomp$270$$,
$p__66637$$){var $to_allocate__$1$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66636_result$jscomp$270$$,0,null),$total_fr$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66636_result$jscomp$270$$,1,null);$p__66636_result$jscomp$270$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66636_result$jscomp$270$$,2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66637$$,0,null);var $track$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66637$$,
1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$11$$))?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$to_allocate__$1$jscomp$3$$,$total_fr$$+$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$11$$),$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p__66636_result$jscomp$270$$,$p__66637$$)],null):new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$to_allocate__$1$jscomp$3$$-$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$11$$),$total_fr$$,$p__66636_result$jscomp$270$$],null)},new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cell$jscomp$28_to_allocate$jscomp$3_to_allocate__$1$jscomp$2$$,0,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$from_idx$jscomp$2_indexed_tracks$jscomp$3_indexed_tracks__$1$jscomp$1_vec__66633$$);
$cell$jscomp$28_to_allocate$jscomp$3_to_allocate__$1$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from_idx$jscomp$2_indexed_tracks$jscomp$3_indexed_tracks__$1$jscomp$1_vec__66633$$,0,null);$shape_id$jscomp$82_total_frs$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from_idx$jscomp$2_indexed_tracks$jscomp$3_indexed_tracks__$1$jscomp$1_vec__66633$$,1,null);$from_idx$jscomp$2_indexed_tracks$jscomp$3_indexed_tracks__$1$jscomp$1_vec__66633$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from_idx$jscomp$2_indexed_tracks$jscomp$3_indexed_tracks__$1$jscomp$1_vec__66633$$,
2,null);return $app$common$geom$shapes$grid_layout$layout_data$allocate_flex_tracks$$($alloc$$,$from_idx$jscomp$2_indexed_tracks$jscomp$3_indexed_tracks__$1$jscomp$1_vec__66633$$,($cell$jscomp$28_to_allocate$jscomp$3_to_allocate__$1$jscomp$2$$>0?$cell$jscomp$28_to_allocate$jscomp$3_to_allocate__$1$jscomp$2$$:0)/$shape_id$jscomp$82_total_frs$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($prop_span$jscomp$8$$,$APP.$cljs$core$_$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66617_SHARP_$$){return $app$common$geom$shapes$grid_layout$layout_data$has_flex_track_QMARK_$$($type$jscomp$468$$,
$track_list$jscomp$8$$,$p1__66617_SHARP_$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66616_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__66616_SHARP_$$,$prop_span$jscomp$8$$)>1},$APP.$cljs$core$vals$$($shape_cells$jscomp$2$$)))));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__66619_SHARP_$$,$p2__66618_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p2__66618_SHARP_$$,
$APP.$cljs$cst$874$size$$,$APP.$cljs$core$max$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($allocate_fr_tracks$$,$p1__66619_SHARP_$$,0))}),$track_list$jscomp$8$$)};
$app$common$geom$shapes$grid_layout$layout_data$min_fr_value$$=function($G__66767_tracks$jscomp$3_tracks__$1$$){$G__66767_tracks$jscomp$3_tracks__$1$$=$APP.$cljs$core$seq$$($G__66767_tracks$jscomp$3_tracks__$1$$);for(var $G__66768_JSCompiler_temp$jscomp$1131_min_fr_min_fr__$1_x__5110__auto__$jscomp$inline_6512$$=.01;;){if($APP.$cljs$core$empty_QMARK_$$($G__66767_tracks$jscomp$3_tracks__$1$$))return $G__66768_JSCompiler_temp$jscomp$1131_min_fr_min_fr__$1_x__5110__auto__$jscomp$inline_6512$$;var $map__66648_size$jscomp$121_y__5111__auto__$jscomp$inline_6513$$=
$APP.$cljs$core$first$$($G__66767_tracks$jscomp$3_tracks__$1$$),$map__66648__$1_value$jscomp$546$$=$APP.$cljs$core$__destructure_map$$($map__66648_size$jscomp$121_y__5111__auto__$jscomp$inline_6513$$);$map__66648_size$jscomp$121_y__5111__auto__$jscomp$inline_6513$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66648__$1_value$jscomp$546$$,$APP.$cljs$cst$874$size$$);var $type$jscomp$469$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66648__$1_value$jscomp$546$$,$APP.$cljs$cst$139$type$$);
$map__66648__$1_value$jscomp$546$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66648__$1_value$jscomp$546$$,$APP.$cljs$cst$260$value$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$469$$,$APP.$cljs$cst$1660$flex$$)&&($map__66648_size$jscomp$121_y__5111__auto__$jscomp$inline_6513$$/=$map__66648__$1_value$jscomp$546$$,$G__66768_JSCompiler_temp$jscomp$1131_min_fr_min_fr__$1_x__5110__auto__$jscomp$inline_6512$$=$G__66768_JSCompiler_temp$jscomp$1131_min_fr_min_fr__$1_x__5110__auto__$jscomp$inline_6512$$>
$map__66648_size$jscomp$121_y__5111__auto__$jscomp$inline_6513$$?$G__66768_JSCompiler_temp$jscomp$1131_min_fr_min_fr__$1_x__5110__auto__$jscomp$inline_6512$$:$map__66648_size$jscomp$121_y__5111__auto__$jscomp$inline_6513$$);$G__66767_tracks$jscomp$3_tracks__$1$$=$APP.$cljs$core$rest$$($G__66767_tracks$jscomp$3_tracks__$1$$)}};
$app$common$geom$shapes$grid_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$05$$=function($parent$jscomp$232$$,$transformed_parent_bounds$jscomp$2$$,$children$jscomp$209$$,$bounds$jscomp$22$$,$objects$jscomp$353$$){return $app$common$geom$shapes$grid_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$06$$($parent$jscomp$232$$,$transformed_parent_bounds$jscomp$2$$,$children$jscomp$209$$,$bounds$jscomp$22$$,$objects$jscomp$353$$,!1)};
$app$common$geom$shapes$grid_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$06$$=function($parent$jscomp$233$$,$transformed_parent_bounds$jscomp$3$$,$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$,$bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$,$column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$,$auto_QMARK_$jscomp$2$$){var $layout_bounds$$=$app$common$geom$shapes$grid_layout$layout_data$layout_bounds$$($parent$jscomp$233$$,
$transformed_parent_bounds$jscomp$3$$),$bound_height$$=$APP.$app$common$geom$shapes$points$height_points$$($layout_bounds$$),$bound_width$$=$APP.$app$common$geom$shapes$points$width_points$$($layout_bounds$$),$bound_corner$$=$APP.$app$common$geom$shapes$points$origin$$($layout_bounds$$),$layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$=$APP.$app$common$types$shape$layout$gaps$$($parent$jscomp$233$$),$row_gap$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$,
0,null),$column_gap$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$,1,null),$auto_height_QMARK_$$=function(){var $or__5025__auto__$jscomp$706$$=$APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$233$$);return $or__5025__auto__$jscomp$706$$?$or__5025__auto__$jscomp$706$$:$auto_QMARK_$jscomp$2$$}(),$auto_width_QMARK_$jscomp$1$$=function(){var $or__5025__auto__$jscomp$707$$=
$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$233$$);return $or__5025__auto__$jscomp$707$$?$or__5025__auto__$jscomp$707$$:$auto_QMARK_$jscomp$2$$}();$layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$=$APP.$cljs$core$__destructure_map$$($parent$jscomp$233$$);var $auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$,
$APP.$cljs$cst$1695$layout_grid_columns$$),$column_frs_layout_grid_rows$jscomp$1_row_autos_row_tracks$jscomp$1_row_tracks__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$,$APP.$cljs$cst$1694$layout_grid_rows$$);$layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$,
$APP.$cljs$cst$1696$layout_grid_cells$$);var $children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$=$APP.$cljs$core$count$$($auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$),$fr_row_space_num_rows_row_tracks__$2$$=$APP.$cljs$core$count$$($column_frs_layout_grid_rows$jscomp$1_row_autos_row_tracks$jscomp$1_row_tracks__$1$$),$column_total_gap$$=$column_gap$jscomp$4$$*($children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$-
1),$row_total_gap$$=$row_gap$jscomp$4$$*($fr_row_space_num_rows_row_tracks__$2$$-1);$layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p__66671$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66671$$,0,null);var $cell$jscomp$29$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66671$$,
1,null);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66651_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__66651_SHARP_$$,$cell$jscomp$29$$],null)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$29$$))}),$layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$);$children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66652_SHARP_$$){return $APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__66652_SHARP_$$))},
$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$);$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__66653_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__66653_SHARP_$$)),$p1__66653_SHARP_$$],null)}),$children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$);$auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$geom$shapes$grid_layout$layout_data$calculate_initial_track_size$$,
$bound_width$$),$auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$);$column_frs_layout_grid_rows$jscomp$1_row_autos_row_tracks$jscomp$1_row_tracks__$1$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$geom$shapes$grid_layout$layout_data$calculate_initial_track_size$$,$bound_height$$),$column_frs_layout_grid_rows$jscomp$1_row_autos_row_tracks$jscomp$1_row_tracks__$1$$);
$auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$=$app$common$geom$shapes$grid_layout$layout_data$set_auto_base_size$$($auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$,$children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$,$layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$,$bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$,
$column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$,$APP.$cljs$cst$216$column$$);$column_frs_layout_grid_rows$jscomp$1_row_autos_row_tracks$jscomp$1_row_tracks__$1$$=$app$common$geom$shapes$grid_layout$layout_data$set_auto_base_size$$($column_frs_layout_grid_rows$jscomp$1_row_autos_row_tracks$jscomp$1_row_tracks__$1$$,$children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$,$layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$,
$bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$,$column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$,$APP.$cljs$cst$1656$row$$);$children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$=$app$common$geom$shapes$grid_layout$layout_data$set_auto_multi_span$$($parent$jscomp$233$$,$auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$,$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$,
$layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$,$bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$,$column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$,$APP.$cljs$cst$216$column$$);$fr_row_space_num_rows_row_tracks__$2$$=$app$common$geom$shapes$grid_layout$layout_data$set_auto_multi_span$$($parent$jscomp$233$$,$column_frs_layout_grid_rows$jscomp$1_row_autos_row_tracks$jscomp$1_row_tracks__$1$$,$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$,
$layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$,$bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$,$column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$,$APP.$cljs$cst$1656$row$$);var $column_total_size_nofr$$=$app$common$geom$shapes$grid_layout$layout_data$tracks_total_size$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66654_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__66654_SHARP_$$))},$children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$)),$row_total_size_nofr$$=$app$common$geom$shapes$grid_layout$layout_data$tracks_total_size$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66655_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__66655_SHARP_$$))},
$fr_row_space_num_rows_row_tracks__$2$$));$column_frs_layout_grid_rows$jscomp$1_row_autos_row_tracks$jscomp$1_row_tracks__$1$$=$app$common$geom$shapes$grid_layout$layout_data$tracks_total_frs$$($children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$);$auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$=$app$common$geom$shapes$grid_layout$layout_data$tracks_total_frs$$($fr_row_space_num_rows_row_tracks__$2$$);
$children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$=$app$common$geom$shapes$grid_layout$layout_data$set_flex_multi_span$$($parent$jscomp$233$$,$children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$,$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$,$layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$,$bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$,
$column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$,$APP.$cljs$cst$216$column$$);$bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$=$app$common$geom$shapes$grid_layout$layout_data$set_flex_multi_span$$($parent$jscomp$233$$,$fr_row_space_num_rows_row_tracks__$2$$,$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$,$layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$,
$bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$,$column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$,$APP.$cljs$cst$1656$row$$);$column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$=function(){var $y__5111__auto__$jscomp$70$$=$bound_width$$-($column_total_size_nofr$$+$column_total_gap$$);return 0>$y__5111__auto__$jscomp$70$$?0:$y__5111__auto__$jscomp$70$$}();$fr_row_space_num_rows_row_tracks__$2$$=function(){var $y__5111__auto__$jscomp$71$$=
$bound_height$$-($row_total_size_nofr$$+$row_total_gap$$);return 0>$y__5111__auto__$jscomp$71$$?0:$y__5111__auto__$jscomp$71$$}();$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$=$app$common$geom$shapes$grid_layout$layout_data$min_fr_value$$($children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$);var $min_row_fr$$=$app$common$geom$shapes$grid_layout$layout_data$min_fr_value$$($bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$);
$auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$=$APP.$cljs$core$truth_$$($auto_height_QMARK_$$)?$min_row_fr$$:$auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$===0?0:$APP.$app$common$math$finite$$($fr_row_space_num_rows_row_tracks__$2$$/$auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$,
0);$column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$=$app$common$geom$shapes$grid_layout$layout_data$set_fr_value$$($children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$,$APP.$cljs$core$truth_$$($auto_width_QMARK_$jscomp$1$$)?$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$:$column_frs_layout_grid_rows$jscomp$1_row_autos_row_tracks$jscomp$1_row_tracks__$1$$===
0?0:$APP.$app$common$math$finite$$($column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$/$column_frs_layout_grid_rows$jscomp$1_row_autos_row_tracks$jscomp$1_row_tracks__$1$$,0),$auto_width_QMARK_$jscomp$1$$);$bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$=$app$common$geom$shapes$grid_layout$layout_data$set_fr_value$$($bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$,$auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$,
$auto_height_QMARK_$$);var $column_total_size$$=$app$common$geom$shapes$grid_layout$layout_data$tracks_total_size$$($column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$),$row_total_size$$=$app$common$geom$shapes$grid_layout$layout_data$tracks_total_size$$($bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$);$auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$=function(){var $y__5111__auto__$jscomp$72$$=
$APP.$cljs$core$truth_$$($auto_width_QMARK_$jscomp$1$$)?0:$bound_width$$-($column_total_size$$+$column_total_gap$$);return 0>$y__5111__auto__$jscomp$72$$?0:$y__5111__auto__$jscomp$72$$}();$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$=function(){var $y__5111__auto__$jscomp$73$$=$APP.$cljs$core$truth_$$($auto_height_QMARK_$$)?0:$bound_height$$-($row_total_size$$+$row_total_gap$$);return 0>$y__5111__auto__$jscomp$73$$?0:$y__5111__auto__$jscomp$73$$}();
$children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$=$app$common$geom$shapes$grid_layout$layout_data$tracks_total_autos$$($column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$);$column_frs_layout_grid_rows$jscomp$1_row_autos_row_tracks$jscomp$1_row_tracks__$1$$=$app$common$geom$shapes$grid_layout$layout_data$tracks_total_autos$$($bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$);$auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$=
$children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$===0?0:$auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$/$children__$1$jscomp$23_column_autos_column_tracks__$2_column_tracks__$3_num_columns$$;$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$=$column_frs_layout_grid_rows$jscomp$1_row_autos_row_tracks$jscomp$1_row_tracks__$1$$===
0?0:$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$/$column_frs_layout_grid_rows$jscomp$1_row_autos_row_tracks$jscomp$1_row_tracks__$1$$;$column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1669$stretch$$,$APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?$app$common$geom$shapes$grid_layout$layout_data$stretch_tracks$$($column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$,
$auto_column_space_column_add_auto_column_tracks$jscomp$1_column_tracks__$1_layout_grid_columns$jscomp$1_row_fr_row_frs$$):$column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$;$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1669$stretch$$,$APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?
$app$common$geom$shapes$grid_layout$layout_data$stretch_tracks$$($bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$,$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$):$bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$;var $column_total_size__$1$$=$app$common$geom$shapes$grid_layout$layout_data$tracks_total_size$$($column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$),$row_total_size__$1$$=
$app$common$geom$shapes$grid_layout$layout_data$tracks_total_size$$($auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$),$num_columns__$1$$=$APP.$cljs$core$count$$($column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$),$column_gap__$1$$=$APP.$cljs$core$truth_$$($auto_width_QMARK_$jscomp$1$$)?$column_gap$jscomp$4$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1666$space_evenly$$,
$APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?function(){var $y__5111__auto__$jscomp$74$$=($bound_width$$-$column_total_size__$1$$)/($num_columns__$1$$+1);return $column_gap$jscomp$4$$>$y__5111__auto__$jscomp$74$$?$column_gap$jscomp$4$$:$y__5111__auto__$jscomp$74$$}():$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1665$space_around$$,$APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?
function(){var $y__5111__auto__$jscomp$75$$=($bound_width$$-$column_total_size__$1$$)/$num_columns__$1$$;return $column_gap$jscomp$4$$>$y__5111__auto__$jscomp$75$$?$column_gap$jscomp$4$$:$y__5111__auto__$jscomp$75$$}():$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1668$space_between$$,$APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?function(){var $y__5111__auto__$jscomp$76$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($num_columns__$1$$,
1)?$column_gap$jscomp$4$$:($bound_width$$-$column_total_size__$1$$)/($num_columns__$1$$-1);return $column_gap$jscomp$4$$>$y__5111__auto__$jscomp$76$$?$column_gap$jscomp$4$$:$y__5111__auto__$jscomp$76$$}():$column_gap$jscomp$4$$,$num_rows__$1$$=$APP.$cljs$core$count$$($auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$),$row_gap__$1$$=$APP.$cljs$core$truth_$$($auto_height_QMARK_$$)?$row_gap$jscomp$4$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1666$space_evenly$$,
$APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?function(){var $y__5111__auto__$jscomp$77$$=($bound_height$$-$row_total_size__$1$$)/($num_rows__$1$$+1);return $row_gap$jscomp$4$$>$y__5111__auto__$jscomp$77$$?$row_gap$jscomp$4$$:$y__5111__auto__$jscomp$77$$}():$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1665$space_around$$,$APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?function(){var $y__5111__auto__$jscomp$78$$=
($bound_height$$-$row_total_size__$1$$)/$num_rows__$1$$;return $row_gap$jscomp$4$$>$y__5111__auto__$jscomp$78$$?$row_gap$jscomp$4$$:$y__5111__auto__$jscomp$78$$}():$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1668$space_between$$,$APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?function(){var $y__5111__auto__$jscomp$79$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($num_rows__$1$$,1)?$row_gap$jscomp$4$$:($bound_height$$-
$row_total_size__$1$$)/($num_rows__$1$$-1);return $row_gap$jscomp$4$$>$y__5111__auto__$jscomp$79$$?$row_gap$jscomp$4$$:$y__5111__auto__$jscomp$79$$}():$row_gap$jscomp$4$$;$bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$=function(){var $G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$=$APP.$cljs$core$not$$($auto_width_QMARK_$jscomp$1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1293$end$$,$APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?
$APP.$app$common$geom$point$add$$($bound_corner$$,$APP.$app$common$geom$shapes$points$start_hv$$($transformed_parent_bounds$jscomp$3$$,$bound_width$$-($column_total_size__$1$$+$column_total_gap$$))):$bound_corner$$;$G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$=$APP.$cljs$core$not$$($auto_width_QMARK_$jscomp$1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1667$center$$,$APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?
$APP.$app$common$geom$point$add$$($G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$,$APP.$app$common$geom$shapes$points$start_hv$$($transformed_parent_bounds$jscomp$3$$,($bound_width$$-($column_total_size__$1$$+$column_total_gap$$))/2)):$G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$;$G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$=$APP.$cljs$core$not$$($auto_height_QMARK_$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1293$end$$,$APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?$APP.$app$common$geom$point$add$$($G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$,$APP.$app$common$geom$shapes$points$start_vv$$($transformed_parent_bounds$jscomp$3$$,$bound_height$$-($row_total_size__$1$$+$row_total_gap$$))):$G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$;
$G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$=$APP.$cljs$core$not$$($auto_height_QMARK_$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1667$center$$,$APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?$APP.$app$common$geom$point$add$$($G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$,$APP.$app$common$geom$shapes$points$start_vv$$($transformed_parent_bounds$jscomp$3$$,
($bound_height$$-($row_total_size__$1$$+$row_total_gap$$))/2)):$G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$;$G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$=$APP.$cljs$core$not$$($auto_width_QMARK_$jscomp$1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1665$space_around$$,$APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?$APP.$app$common$geom$point$add$$($G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$,
$APP.$app$common$geom$shapes$points$start_hv$$($transformed_parent_bounds$jscomp$3$$,$column_gap__$1$$/2)):$G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$;$G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$=$APP.$cljs$core$not$$($auto_width_QMARK_$jscomp$1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1666$space_evenly$$,$APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?
$APP.$app$common$geom$point$add$$($G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$,$APP.$app$common$geom$shapes$points$start_hv$$($transformed_parent_bounds$jscomp$3$$,$column_gap__$1$$)):$G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$;$G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$=$APP.$cljs$core$not$$($auto_height_QMARK_$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1665$space_around$$,
$APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?$APP.$app$common$geom$point$add$$($G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$,$APP.$app$common$geom$shapes$points$start_vv$$($transformed_parent_bounds$jscomp$3$$,$row_gap__$1$$/2)):$G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$;return $APP.$cljs$core$not$$($auto_height_QMARK_$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1666$space_evenly$$,
$APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$233$$))?$APP.$app$common$geom$point$add$$($G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$,$APP.$app$common$geom$shapes$points$start_vv$$($transformed_parent_bounds$jscomp$3$$,$row_gap__$1$$)):$G__66689__$1_G__66689__$2_G__66689__$3_G__66689__$4_G__66689__$5_G__66689__$6_G__66689__$7$$}();$column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$=
$APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__66709_start_p__$1$$,$map__66714__$1_p__66710$$){var $tracks$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66709_start_p__$1$$,0,null);$p__66709_start_p__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66709_start_p__$1$$,1,null);$map__66714__$1_p__66710$$=$APP.$cljs$core$__destructure_map$$($map__66714__$1_p__66710$$);var $size$jscomp$122$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66714__$1_p__66710$$,
$APP.$cljs$cst$874$size$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($tracks$jscomp$4$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__66714__$1_p__66710$$,$APP.$cljs$cst$3663$start_p$$,$p__66709_start_p__$1$$)),$APP.$app$common$geom$point$add$$($p__66709_start_p__$1$$,$APP.$app$common$geom$shapes$points$start_hv$$($transformed_parent_bounds$jscomp$3$$,$size$jscomp$122$$+
$column_gap__$1$$))],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$],null),$column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$));$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$=$APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__66717_start_p__$1$jscomp$1$$,
$map__66722__$1_p__66718$$){var $tracks$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66717_start_p__$1$jscomp$1$$,0,null);$p__66717_start_p__$1$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66717_start_p__$1$jscomp$1$$,1,null);$map__66722__$1_p__66718$$=$APP.$cljs$core$__destructure_map$$($map__66722__$1_p__66718$$);var $size$jscomp$123$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66722__$1_p__66718$$,$APP.$cljs$cst$874$size$$);
return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($tracks$jscomp$5$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__66722__$1_p__66718$$,$APP.$cljs$cst$3663$start_p$$,$p__66717_start_p__$1$jscomp$1$$)),$APP.$app$common$geom$point$add$$($p__66717_start_p__$1$jscomp$1$$,$APP.$app$common$geom$shapes$points$start_vv$$($transformed_parent_bounds$jscomp$3$$,$size$jscomp$123$$+$row_gap__$1$$))],
null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$],null),$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$));return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$3661$row_tracks$$,$APP.$cljs$cst$3664$column_total_size$$,$APP.$cljs$cst$3665$column_total_gap$$,$APP.$cljs$cst$1682$column_gap$$,
$APP.$cljs$cst$3662$column_tracks$$,$APP.$cljs$cst$3666$layout_bounds$$,$APP.$cljs$cst$3667$row_total_gap$$,$APP.$cljs$cst$1786$origin$$,$cljs$cst$3668$shape_cells$$,$APP.$cljs$cst$3669$row_total_size$$,$APP.$cljs$cst$1681$row_gap$$],[$auto_row_space_children$jscomp$210_children_map$jscomp$2_min_column_fr_row_add_auto_row_tracks__$5_row_tracks__$6$$,$column_total_size__$1$$,$column_total_gap$$,$column_gap__$1$$,$column_tracks__$4_column_tracks__$5_column_tracks__$6_fr_column_space_objects$jscomp$354$$,
$layout_bounds$$,$row_total_gap$$,$bounds$jscomp$23_row_tracks__$3_row_tracks__$4_start_p$$,$layout_grid_cells$jscomp$3_map__66667__$1_shape_cells$jscomp$3_vec__66661$$,$row_total_size__$1$$,$row_gap__$1$$])};
$app$common$geom$shapes$grid_layout$params$rect__GT_range$$=function($axis$jscomp$25$$,$rect$jscomp$31$$){var $start$jscomp$215$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$31$$),$axis$jscomp$25$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$25$$,$APP.$cljs$cst$1510$x$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$start$jscomp$215$$,
$start$jscomp$215$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$31$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$start$jscomp$215$$,$start$jscomp$215$$+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$31$$)],null)};
$app$common$geom$shapes$grid_layout$params$size_range$$=function($p__66503$$){var $start$jscomp$216$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66503$$,0,null);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66503$$,1,null)-$start$jscomp$216$$};
$app$common$geom$shapes$grid_layout$params$calculate_tracks$$=function($axis$jscomp$28$$,$G__66623_G__66628_pending$jscomp$17_shapes_by_axis$$){$G__66623_G__66628_pending$jscomp$17_shapes_by_axis$$=$APP.$cljs$core$seq$$($G__66623_G__66628_pending$jscomp$17_shapes_by_axis$$);for(var $G__66624_G__66629_result$jscomp$271$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$G__66625_G__66630_index$jscomp$282$$=1,$G__66626_G__66631_current_track_current_track__$1$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$,$current_range_end_a$jscomp$inline_12394$$=
null;;)if($G__66623_G__66628_pending$jscomp$17_shapes_by_axis$$){var $G__66627_G__66632_current_range__$1_rect$jscomp$34_start_a$jscomp$inline_12393_vec__66518$$=$APP.$cljs$core$first$$($G__66623_G__66628_pending$jscomp$17_shapes_by_axis$$),$axis$jscomp$inline_12390_next_shape_start_b$jscomp$inline_12396$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66627_G__66632_current_range__$1_rect$jscomp$34_start_a$jscomp$inline_12393_vec__66518$$,0,null);$G__66627_G__66632_current_range__$1_rect$jscomp$34_start_a$jscomp$inline_12393_vec__66518$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66627_G__66632_current_range__$1_rect$jscomp$34_start_a$jscomp$inline_12393_vec__66518$$,1,null);var $JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$=$APP.$cljs$core$not$$($current_range_end_a$jscomp$inline_12394$$);if(!$JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$){var $axis$jscomp$inline_12378_start_b$jscomp$inline_12384$$=
$axis$jscomp$28$$,$end_a$jscomp$inline_12382_p__66465$jscomp$inline_12379_rect$jscomp$inline_12392$$=$current_range_end_a$jscomp$inline_12394$$,$end_b$jscomp$inline_12385_rect$jscomp$inline_12380_vec__66469$jscomp$inline_12383$$=$G__66627_G__66632_current_range__$1_rect$jscomp$34_start_a$jscomp$inline_12393_vec__66518$$;$JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_a$jscomp$inline_12382_p__66465$jscomp$inline_12379_rect$jscomp$inline_12392$$,0,null);$end_a$jscomp$inline_12382_p__66465$jscomp$inline_12379_rect$jscomp$inline_12392$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_a$jscomp$inline_12382_p__66465$jscomp$inline_12379_rect$jscomp$inline_12392$$,1,null);$end_b$jscomp$inline_12385_rect$jscomp$inline_12380_vec__66469$jscomp$inline_12383$$=$app$common$geom$shapes$grid_layout$params$rect__GT_range$$($axis$jscomp$inline_12378_start_b$jscomp$inline_12384$$,
$end_b$jscomp$inline_12385_rect$jscomp$inline_12380_vec__66469$jscomp$inline_12383$$);$axis$jscomp$inline_12378_start_b$jscomp$inline_12384$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_b$jscomp$inline_12385_rect$jscomp$inline_12380_vec__66469$jscomp$inline_12383$$,0,null);$end_b$jscomp$inline_12385_rect$jscomp$inline_12380_vec__66469$jscomp$inline_12383$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_b$jscomp$inline_12385_rect$jscomp$inline_12380_vec__66469$jscomp$inline_12383$$,
1,null);var $or__5025__auto__$jscomp$inline_12386_or__5025__auto____$1$jscomp$inline_12387$$=$JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$<$axis$jscomp$inline_12378_start_b$jscomp$inline_12384$$&&$axis$jscomp$inline_12378_start_b$jscomp$inline_12384$$<$end_a$jscomp$inline_12382_p__66465$jscomp$inline_12379_rect$jscomp$inline_12392$$;
$or__5025__auto__$jscomp$inline_12386_or__5025__auto____$1$jscomp$inline_12387$$?$JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$=$or__5025__auto__$jscomp$inline_12386_or__5025__auto____$1$jscomp$inline_12387$$:($or__5025__auto__$jscomp$inline_12386_or__5025__auto____$1$jscomp$inline_12387$$=$axis$jscomp$inline_12378_start_b$jscomp$inline_12384$$<
$JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$&&$JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$<$end_b$jscomp$inline_12385_rect$jscomp$inline_12380_vec__66469$jscomp$inline_12383$$)?
$JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$=$or__5025__auto__$jscomp$inline_12386_or__5025__auto____$1$jscomp$inline_12387$$:($JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$=
$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$,$axis$jscomp$inline_12378_start_b$jscomp$inline_12384$$),$JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$=
$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$)?$JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$:$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($end_a$jscomp$inline_12382_p__66465$jscomp$inline_12379_rect$jscomp$inline_12392$$,
$end_b$jscomp$inline_12385_rect$jscomp$inline_12380_vec__66469$jscomp$inline_12383$$))}$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$)?($G__66626_G__66631_current_track_current_track__$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__66626_G__66631_current_track_current_track__$1$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($axis$jscomp$inline_12390_next_shape_start_b$jscomp$inline_12396$$)),
$axis$jscomp$inline_12390_next_shape_start_b$jscomp$inline_12396$$=$axis$jscomp$28$$,$JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$=$current_range_end_a$jscomp$inline_12394$$,$end_a$jscomp$inline_12382_p__66465$jscomp$inline_12379_rect$jscomp$inline_12392$$=$G__66627_G__66632_current_range__$1_rect$jscomp$34_start_a$jscomp$inline_12393_vec__66518$$,
$G__66627_G__66632_current_range__$1_rect$jscomp$34_start_a$jscomp$inline_12393_vec__66518$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$,0,null),$current_range_end_a$jscomp$inline_12394$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$,
1,null),$APP.$cljs$core$not$$($JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$)?$G__66627_G__66632_current_range__$1_rect$jscomp$34_start_a$jscomp$inline_12393_vec__66518$$=$app$common$geom$shapes$grid_layout$params$rect__GT_range$$($axis$jscomp$inline_12390_next_shape_start_b$jscomp$inline_12396$$,$end_a$jscomp$inline_12382_p__66465$jscomp$inline_12379_rect$jscomp$inline_12392$$):
($JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$=$app$common$geom$shapes$grid_layout$params$rect__GT_range$$($axis$jscomp$inline_12390_next_shape_start_b$jscomp$inline_12396$$,$end_a$jscomp$inline_12382_p__66465$jscomp$inline_12379_rect$jscomp$inline_12392$$),$axis$jscomp$inline_12390_next_shape_start_b$jscomp$inline_12396$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$,0,null),$JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$,1,null),$G__66627_G__66632_current_range__$1_rect$jscomp$34_start_a$jscomp$inline_12393_vec__66518$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__66627_G__66632_current_range__$1_rect$jscomp$34_start_a$jscomp$inline_12393_vec__66518$$<
$axis$jscomp$inline_12390_next_shape_start_b$jscomp$inline_12396$$?$G__66627_G__66632_current_range__$1_rect$jscomp$34_start_a$jscomp$inline_12393_vec__66518$$:$axis$jscomp$inline_12390_next_shape_start_b$jscomp$inline_12396$$,$current_range_end_a$jscomp$inline_12394$$>$JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$?$current_range_end_a$jscomp$inline_12394$$:
$JSCompiler_temp$jscomp$10854_end_b$jscomp$inline_12397_or__5025__auto__$jscomp$inline_6515_or__5025__auto____$2$jscomp$inline_12388_p__66488$jscomp$inline_12391_start_a$jscomp$inline_12381_vec__66493$jscomp$inline_12395$$],null)),$G__66623_G__66628_pending$jscomp$17_shapes_by_axis$$=$APP.$cljs$core$next$$($G__66623_G__66628_pending$jscomp$17_shapes_by_axis$$),$current_range_end_a$jscomp$inline_12394$$=$G__66627_G__66632_current_range__$1_rect$jscomp$34_start_a$jscomp$inline_12393_vec__66518$$):($G__66623_G__66628_pending$jscomp$17_shapes_by_axis$$=
$APP.$cljs$core$next$$($G__66623_G__66628_pending$jscomp$17_shapes_by_axis$$),$G__66624_G__66629_result$jscomp$271$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__66624_G__66629_result$jscomp$271$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1795$index$$,$G__66625_G__66630_index$jscomp$282$$,$APP.$cljs$cst$1614$shapes$$,$G__66626_G__66631_current_track_current_track__$1$$,$APP.$cljs$cst$874$size$$,$app$common$geom$shapes$grid_layout$params$size_range$$($current_range_end_a$jscomp$inline_12394$$)],
null)),$G__66625_G__66630_index$jscomp$282$$+=1,$G__66626_G__66631_current_track_current_track__$1$$=$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($axis$jscomp$inline_12390_next_shape_start_b$jscomp$inline_12396$$)]),$current_range_end_a$jscomp$inline_12394$$=$G__66627_G__66632_current_range__$1_rect$jscomp$34_start_a$jscomp$inline_12393_vec__66518$$=$app$common$geom$shapes$grid_layout$params$rect__GT_range$$($axis$jscomp$28$$,$G__66627_G__66632_current_range__$1_rect$jscomp$34_start_a$jscomp$inline_12393_vec__66518$$))}else return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__66624_G__66629_result$jscomp$271$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1795$index$$,$G__66625_G__66630_index$jscomp$282$$,$APP.$cljs$cst$1614$shapes$$,$G__66626_G__66631_current_track_current_track__$1$$,$APP.$cljs$cst$874$size$$,$app$common$geom$shapes$grid_layout$params$size_range$$($current_range_end_a$jscomp$inline_12394$$)],null))};
$app$common$geom$shapes$grid_layout$params$assign_shape_cells$$=function($params$jscomp$249_vec__66535$$,$params__$1$jscomp$34_rows$jscomp$5$$,$cols$$){$params$jscomp$249_vec__66535$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$272$$,$row$jscomp$27$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($cell$jscomp$inline_14344_p1__66533_SHARP__row_num$jscomp$inline_14342$$,$auto_QMARK___$1$jscomp$inline_14346_p2__66534_SHARP_$$){var $G__66551__$1$jscomp$inline_14349_JSCompiler_inline_result$jscomp$inline_14348_params__$1$jscomp$inline_14340$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell$jscomp$inline_14344_p1__66533_SHARP__row_num$jscomp$inline_14342$$,0,null),$JSCompiler_temp_const$jscomp$inline_14347_auto_QMARK_$jscomp$inline_14341$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell$jscomp$inline_14344_p1__66533_SHARP__row_num$jscomp$inline_14342$$,1,null);$cell$jscomp$inline_14344_p1__66533_SHARP__row_num$jscomp$inline_14342$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($row$jscomp$27$$);
var $column_num$jscomp$inline_14343_shape$jscomp$inline_14345$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($auto_QMARK___$1$jscomp$inline_14346_p2__66534_SHARP_$$);$cell$jscomp$inline_14344_p1__66533_SHARP__row_num$jscomp$inline_14342$$=$app$common$types$shape$layout$cell_by_row_column$$($G__66551__$1$jscomp$inline_14349_JSCompiler_inline_result$jscomp$inline_14348_params__$1$jscomp$inline_14340$$,$cell$jscomp$inline_14344_p1__66533_SHARP__row_num$jscomp$inline_14342$$,$column_num$jscomp$inline_14343_shape$jscomp$inline_14345$$);
$column_num$jscomp$inline_14343_shape$jscomp$inline_14345$$=$APP.$cljs$core$first$$($APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($row$jscomp$27$$),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($auto_QMARK___$1$jscomp$inline_14346_p2__66534_SHARP_$$)));$auto_QMARK___$1$jscomp$inline_14346_p2__66534_SHARP_$$=$APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$inline_14347_auto_QMARK_$jscomp$inline_14341$$)?
$column_num$jscomp$inline_14343_shape$jscomp$inline_14345$$!=null:$JSCompiler_temp_const$jscomp$inline_14347_auto_QMARK_$jscomp$inline_14341$$;$JSCompiler_temp_const$jscomp$inline_14347_auto_QMARK_$jscomp$inline_14341$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;$G__66551__$1$jscomp$inline_14349_JSCompiler_inline_result$jscomp$inline_14348_params__$1$jscomp$inline_14340$$=$column_num$jscomp$inline_14343_shape$jscomp$inline_14345$$!=null?$APP.$cljs$core$assoc_in$$($G__66551__$1$jscomp$inline_14349_JSCompiler_inline_result$jscomp$inline_14348_params__$1$jscomp$inline_14340$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_14344_p1__66533_SHARP__row_num$jscomp$inline_14342$$),$APP.$cljs$cst$1614$shapes$$],null),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$column_num$jscomp$inline_14343_shape$jscomp$inline_14345$$],null)):$G__66551__$1$jscomp$inline_14349_JSCompiler_inline_result$jscomp$inline_14348_params__$1$jscomp$inline_14340$$;
$G__66551__$1$jscomp$inline_14349_JSCompiler_inline_result$jscomp$inline_14348_params__$1$jscomp$inline_14340$$=$APP.$cljs$core$not$$($auto_QMARK___$1$jscomp$inline_14346_p2__66534_SHARP_$$)?$APP.$cljs$core$assoc_in$$($G__66551__$1$jscomp$inline_14349_JSCompiler_inline_result$jscomp$inline_14348_params__$1$jscomp$inline_14340$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_14344_p1__66533_SHARP__row_num$jscomp$inline_14342$$),
$APP.$cljs$cst$1676$position$$],null),$APP.$cljs$cst$1673$manual$$):$G__66551__$1$jscomp$inline_14349_JSCompiler_inline_result$jscomp$inline_14348_params__$1$jscomp$inline_14340$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$inline_14347_auto_QMARK_$jscomp$inline_14341$$,[$G__66551__$1$jscomp$inline_14349_JSCompiler_inline_result$jscomp$inline_14348_params__$1$jscomp$inline_14340$$,$auto_QMARK___$1$jscomp$inline_14346_p2__66534_SHARP_$$],null)},$result$jscomp$272$$,
$cols$$)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$params$jscomp$249_vec__66535$$,!0],null),$params__$1$jscomp$34_rows$jscomp$5$$);$params__$1$jscomp$34_rows$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($params$jscomp$249_vec__66535$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($params$jscomp$249_vec__66535$$,1,null);return $params__$1$jscomp$34_rows$jscomp$5$$};
$app$common$geom$shapes$grid_layout$params$calculate_params$cljs$0core$0IFn$0_invoke$0arity$03$$=function($all_shapes_rect_p_top_parent_childs_vector_shapes$jscomp$57$$,$p_left_parent$jscomp$234$$){if($APP.$cljs$core$empty_QMARK_$$($all_shapes_rect_p_top_parent_childs_vector_shapes$jscomp$57$$))return $app$common$types$shape$layout$create_cells$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1695$layout_grid_columns$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$app$common$types$shape$layout$default_track_value$$,$APP.$app$common$types$shape$layout$default_track_value$$],null),$APP.$cljs$cst$1694$layout_grid_rows$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$types$shape$layout$default_track_value$$,$APP.$app$common$types$shape$layout$default_track_value$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,1,2,2],null));var $cols$jscomp$1_shapes__$1$jscomp$8_shapes_by_x$$=
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,$all_shapes_rect_p_top_parent_childs_vector_shapes$jscomp$57$$);$all_shapes_rect_p_top_parent_childs_vector_shapes$jscomp$57$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($cols$jscomp$1_shapes__$1$jscomp$8_shapes_by_x$$);var $rows$jscomp$6_shapes_PLUS_bounds_shapes_by_y$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66569_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__66569_SHARP_$$,$APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__66569_SHARP_$$,$APP.$cljs$cst$1604$points$$))],null)},$cols$jscomp$1_shapes__$1$jscomp$8_shapes_by_x$$);$cols$jscomp$1_shapes__$1$jscomp$8_shapes_by_x$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$APP.$cljs$core$second$$),$rows$jscomp$6_shapes_PLUS_bounds_shapes_by_y$$);
$rows$jscomp$6_shapes_PLUS_bounds_shapes_by_y$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1511$y$$,$APP.$cljs$core$second$$),$rows$jscomp$6_shapes_PLUS_bounds_shapes_by_y$$);$cols$jscomp$1_shapes__$1$jscomp$8_shapes_by_x$$=$app$common$geom$shapes$grid_layout$params$calculate_tracks$$($APP.$cljs$cst$1510$x$$,$cols$jscomp$1_shapes__$1$jscomp$8_shapes_by_x$$);$rows$jscomp$6_shapes_PLUS_bounds_shapes_by_y$$=$app$common$geom$shapes$grid_layout$params$calculate_tracks$$($APP.$cljs$cst$1511$y$$,
$rows$jscomp$6_shapes_PLUS_bounds_shapes_by_y$$);var $num_cols$$=$APP.$cljs$core$count$$($cols$jscomp$1_shapes__$1$jscomp$8_shapes_by_x$$),$num_rows$jscomp$1$$=$APP.$cljs$core$count$$($rows$jscomp$6_shapes_PLUS_bounds_shapes_by_y$$),$column_gap$jscomp$5_total_cols_width$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__66570_SHARP_$$,$p2__66571_SHARP_$$){return $p1__66570_SHARP_$$+$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($p2__66571_SHARP_$$)},0,$cols$jscomp$1_shapes__$1$jscomp$8_shapes_by_x$$),
$row_gap$jscomp$5_total_rows_height$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__66572_SHARP_$$,$p2__66573_SHARP_$$){return $p1__66572_SHARP_$$+$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($p2__66573_SHARP_$$)},0,$rows$jscomp$6_shapes_PLUS_bounds_shapes_by_y$$);$column_gap$jscomp$5_total_cols_width$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($num_cols$$,1)?0:($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($all_shapes_rect_p_top_parent_childs_vector_shapes$jscomp$57$$)-
$column_gap$jscomp$5_total_cols_width$$)/($num_cols$$-1);$row_gap$jscomp$5_total_rows_height$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($num_rows$jscomp$1$$,1)?0:($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($all_shapes_rect_p_top_parent_childs_vector_shapes$jscomp$57$$)-$row_gap$jscomp$5_total_rows_height$$)/($num_rows$jscomp$1$$-1);var $layout_grid_rows$jscomp$2$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$constantly$$($APP.$app$common$types$shape$layout$default_track_value$$),
$rows$jscomp$6_shapes_PLUS_bounds_shapes_by_y$$),$layout_grid_columns$jscomp$2$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$constantly$$($APP.$app$common$types$shape$layout$default_track_value$$),$cols$jscomp$1_shapes__$1$jscomp$8_shapes_by_x$$);$all_shapes_rect_p_top_parent_childs_vector_shapes$jscomp$57$$=$APP.$app$common$geom$point$to_vec$$($APP.$app$common$geom$shapes$points$origin$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($p_left_parent$jscomp$234$$)),
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($all_shapes_rect_p_top_parent_childs_vector_shapes$jscomp$57$$));$p_left_parent$jscomp$234$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($all_shapes_rect_p_top_parent_childs_vector_shapes$jscomp$57$$);$all_shapes_rect_p_top_parent_childs_vector_shapes$jscomp$57$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($all_shapes_rect_p_top_parent_childs_vector_shapes$jscomp$57$$);return $app$common$geom$shapes$grid_layout$params$assign_shape_cells$$($app$common$types$shape$layout$create_cells$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$1695$layout_grid_columns$$,$layout_grid_columns$jscomp$2$$,$APP.$cljs$cst$1694$layout_grid_rows$$,$layout_grid_rows$jscomp$2$$,$APP.$cljs$cst$1680$layout_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1681$row_gap$$,$row_gap$jscomp$5_total_rows_height$$,$APP.$cljs$cst$1682$column_gap$$,$column_gap$jscomp$5_total_cols_width$$],null),$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1093$p1$$,$all_shapes_rect_p_top_parent_childs_vector_shapes$jscomp$57$$,
$APP.$cljs$cst$1091$p2$$,$p_left_parent$jscomp$234$$,$APP.$cljs$cst$1687$p3$$,$all_shapes_rect_p_top_parent_childs_vector_shapes$jscomp$57$$,$APP.$cljs$cst$1688$p4$$,$p_left_parent$jscomp$234$$],null),$APP.$cljs$cst$1693$layout_grid_dir$$,$num_cols$$>$num_rows$jscomp$1$$?$APP.$cljs$cst$1656$row$$:$APP.$cljs$cst$216$column$$],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,1,$num_cols$$,$num_rows$jscomp$1$$],null)),$rows$jscomp$6_shapes_PLUS_bounds_shapes_by_y$$,
$cols$jscomp$1_shapes__$1$jscomp$8_shapes_by_x$$)};
$APP.$app$common$geom$line$line_value$$=function($map__66703_p__66697_vx$jscomp$1$$,$p__66698_x$jscomp$1173$$){var $map__66702_px$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__66703_p__66697_vx$jscomp$1$$,0,null),$map__66702__$1_py$jscomp$9$$=$APP.$cljs$core$__destructure_map$$($map__66702_px$jscomp$10$$);$map__66702_px$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66702__$1_py$jscomp$9$$,$APP.$cljs$cst$1510$x$$);$map__66702__$1_py$jscomp$9$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66702__$1_py$jscomp$9$$,$APP.$cljs$cst$1511$y$$);$map__66703_p__66697_vx$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__66703_p__66697_vx$jscomp$1$$,1,null);var $map__66703__$1_vy$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__66703_p__66697_vx$jscomp$1$$);$map__66703_p__66697_vx$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66703__$1_vy$jscomp$2$$,$APP.$cljs$cst$1510$x$$);$map__66703__$1_vy$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66703__$1_vy$jscomp$2$$,$APP.$cljs$cst$1511$y$$);var $map__66704__$1_y$jscomp$409$$=$APP.$cljs$core$__destructure_map$$($p__66698_x$jscomp$1173$$);$p__66698_x$jscomp$1173$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66704__$1_y$jscomp$409$$,$APP.$cljs$cst$1510$x$$);$map__66704__$1_y$jscomp$409$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66704__$1_y$jscomp$409$$,$APP.$cljs$cst$1511$y$$);return $map__66703__$1_vy$jscomp$2$$*
$p__66698_x$jscomp$1173$$+-$map__66703_p__66697_vx$jscomp$1$$*$map__66704__$1_y$jscomp$409$$+(-$map__66703__$1_vy$jscomp$2$$*$map__66702_px$jscomp$10$$+$map__66703_p__66697_vx$jscomp$1$$*$map__66702__$1_py$jscomp$9$$)};
$APP.$app$common$geom$shapes$grid_layout$positions$cell_bounds$$=function($origin$jscomp$28_p3$jscomp$21_p__66755$$,$p__66756_row$jscomp$28$$){function $vv$jscomp$4$$($p1__66754_SHARP_$$){return $APP.$app$common$geom$shapes$points$start_vv$$($layout_bounds$jscomp$1$$,$p1__66754_SHARP_$$)}function $hv$jscomp$4$$($p1__66753_SHARP_$$){return $APP.$app$common$geom$shapes$points$start_hv$$($layout_bounds$jscomp$1$$,$p1__66753_SHARP_$$)}var $column$jscomp$33_map__66757__$1$$=$APP.$cljs$core$__destructure_map$$($origin$jscomp$28_p3$jscomp$21_p__66755$$);
$origin$jscomp$28_p3$jscomp$21_p__66755$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column$jscomp$33_map__66757__$1$$,$APP.$cljs$cst$1786$origin$$);var $p4$jscomp$7_row_tracks$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column$jscomp$33_map__66757__$1$$,$APP.$cljs$cst$3661$row_tracks$$),$column_tracks$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column$jscomp$33_map__66757__$1$$,$APP.$cljs$cst$3662$column_tracks$$),$layout_bounds$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column$jscomp$33_map__66757__$1$$,$APP.$cljs$cst$3666$layout_bounds$$),$column_gap$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column$jscomp$33_map__66757__$1$$,$APP.$cljs$cst$1682$column_gap$$),$row_gap$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column$jscomp$33_map__66757__$1$$,$APP.$cljs$cst$1681$row_gap$$),$column_span$jscomp$10_map__66758__$1$$=$APP.$cljs$core$__destructure_map$$($p__66756_row$jscomp$28$$);
$p__66756_row$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$10_map__66758__$1$$,$APP.$cljs$cst$1656$row$$);$column$jscomp$33_map__66757__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$10_map__66758__$1$$,$APP.$cljs$cst$216$column$$);var $row_span$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$10_map__66758__$1$$,$APP.$cljs$cst$1657$row_span$$);$column_span$jscomp$10_map__66758__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$10_map__66758__$1$$,
$APP.$cljs$cst$1658$column_span$$);var $span_column_tracks$$=$app$common$data$safe_subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($column_tracks$jscomp$3$$,$column$jscomp$33_map__66757__$1$$-1,$column$jscomp$33_map__66757__$1$$-1+$column_span$jscomp$10_map__66758__$1$$),$span_row_tracks$$=$app$common$data$safe_subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($p4$jscomp$7_row_tracks$jscomp$3$$,$p__66756_row$jscomp$28$$-1,$p__66756_row$jscomp$28$$-1+$row_span$jscomp$10$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($span_column_tracks$$)?
$span_row_tracks$$:$span_column_tracks$$)){var $p1$jscomp$72$$=$APP.$app$common$geom$point$add$$($origin$jscomp$28_p3$jscomp$21_p__66755$$,$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$to_vec$$($origin$jscomp$28_p3$jscomp$21_p__66755$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($span_column_tracks$$,0),$APP.$cljs$cst$3663$start_p$$)),$APP.$app$common$geom$point$to_vec$$($origin$jscomp$28_p3$jscomp$21_p__66755$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($span_row_tracks$$,
0),$APP.$cljs$cst$3663$start_p$$)))),$p2$jscomp$54$$=function(){var $$__$1$jscomp$14$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p$jscomp$243$$,$track$jscomp$14$$){return $APP.$app$common$geom$point$add$$($p$jscomp$243$$,$hv$jscomp$4$$($APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$14$$)))},$p1$jscomp$72$$,$span_column_tracks$$);return $APP.$app$common$geom$point$add$$($$__$1$jscomp$14$$,$hv$jscomp$4$$($column_gap$jscomp$6$$*($APP.$cljs$core$count$$($span_column_tracks$$)-
1)))}();$origin$jscomp$28_p3$jscomp$21_p__66755$$=function(){var $$__$1$jscomp$15$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p$jscomp$244$$,$track$jscomp$15$$){return $APP.$app$common$geom$point$add$$($p$jscomp$244$$,$vv$jscomp$4$$($APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$15$$)))},$p2$jscomp$54$$,$span_row_tracks$$);return $APP.$app$common$geom$point$add$$($$__$1$jscomp$15$$,$vv$jscomp$4$$($row_gap$jscomp$6$$*($APP.$cljs$core$count$$($span_row_tracks$$)-
1)))}();$p4$jscomp$7_row_tracks$jscomp$3$$=function(){var $$__$1$jscomp$16$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p$jscomp$245$$,$track$jscomp$16$$){return $APP.$app$common$geom$point$add$$($p$jscomp$245$$,$vv$jscomp$4$$($APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track$jscomp$16$$)))},$p1$jscomp$72$$,$span_row_tracks$$);return $APP.$app$common$geom$point$add$$($$__$1$jscomp$16$$,$vv$jscomp$4$$($row_gap$jscomp$6$$*($APP.$cljs$core$count$$($span_row_tracks$$)-
1)))}();return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1$jscomp$72$$,$p2$jscomp$54$$,$origin$jscomp$28_p3$jscomp$21_p__66755$$,$p4$jscomp$7_row_tracks$jscomp$3$$],null)}return null};
$app$common$geom$shapes$grid_layout$positions$calc_fill_width_data$$=function($transform$jscomp$79$$,$transform_inverse$jscomp$16$$,$child$jscomp$84$$,$child_origin$$,$child_width$$,$cell_bounds$$){var $target_width$jscomp$1_target_width__$1$$=function(){var $x__5110__auto__$jscomp$81$$=$APP.$app$common$geom$shapes$points$width_points$$($cell_bounds$$)-$app$common$types$shape$layout$child_width_margin$$($child$jscomp$84$$);return $x__5110__auto__$jscomp$81$$>.01?$x__5110__auto__$jscomp$81$$:.01}(),
$max_width$jscomp$5$$=function(){var $x__5110__auto__$jscomp$82$$=$app$common$types$shape$layout$child_max_width$$($child$jscomp$84$$);return $x__5110__auto__$jscomp$82$$>.01?$x__5110__auto__$jscomp$82$$:.01}();$target_width$jscomp$1_target_width__$1$$=$APP.$app$common$math$clamp$$($target_width$jscomp$1_target_width__$1$$,$app$common$types$shape$layout$child_min_width$$($child$jscomp$84$$),$max_width$jscomp$5$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,$target_width$jscomp$1_target_width__$1$$,
$APP.$cljs$cst$1810$modifiers$$,$APP.$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($target_width$jscomp$1_target_width__$1$$/$child_width$$,1),$child_origin$$,$transform$jscomp$79$$,$transform_inverse$jscomp$16$$)],null)};
$app$common$geom$shapes$grid_layout$positions$calc_fill_height_data$$=function($transform$jscomp$80$$,$transform_inverse$jscomp$17$$,$child$jscomp$85$$,$child_origin$jscomp$1$$,$child_height$$,$cell_bounds$jscomp$1$$){var $target_height$jscomp$1_target_height__$1$$=function(){var $x__5110__auto__$jscomp$83$$=$APP.$app$common$geom$shapes$points$height_points$$($cell_bounds$jscomp$1$$)-$app$common$types$shape$layout$child_height_margin$$($child$jscomp$85$$);return $x__5110__auto__$jscomp$83$$>.01?$x__5110__auto__$jscomp$83$$:
.01}(),$max_height$$=function(){var $x__5110__auto__$jscomp$84$$=$app$common$types$shape$layout$child_max_height$$($child$jscomp$85$$);return $x__5110__auto__$jscomp$84$$>.01?$x__5110__auto__$jscomp$84$$:.01}();$target_height$jscomp$1_target_height__$1$$=$APP.$app$common$math$clamp$$($target_height$jscomp$1_target_height__$1$$,$app$common$types$shape$layout$child_min_height$$($child$jscomp$85$$),$max_height$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1522$height$$,$target_height$jscomp$1_target_height__$1$$,
$APP.$cljs$cst$1810$modifiers$$,$APP.$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,$target_height$jscomp$1_target_height__$1$$/$child_height$$),$child_origin$jscomp$1$$,$transform$jscomp$80$$,$transform_inverse$jscomp$17$$)],null)};
$app$common$geom$shapes$grid_layout$positions$fill_modifiers$$=function($parent_bounds$jscomp$7_transform$jscomp$81$$,$child$jscomp$86_child_width__$1$$,$cell_bounds$jscomp$2_child_bounds$jscomp$7$$,$layout_data$jscomp$2_transform_inverse$jscomp$18_vec__66777$$,$cell_data$$){var $child_height__$1_child_origin$jscomp$2$$=$APP.$app$common$geom$shapes$points$origin$$($cell_bounds$jscomp$2_child_bounds$jscomp$7$$),$child_width$jscomp$1$$=$APP.$app$common$geom$shapes$points$width_points$$($cell_bounds$jscomp$2_child_bounds$jscomp$7$$),
$child_height$jscomp$1$$=$APP.$app$common$geom$shapes$points$height_points$$($cell_bounds$jscomp$2_child_bounds$jscomp$7$$);$cell_bounds$jscomp$2_child_bounds$jscomp$7$$=$APP.$app$common$geom$shapes$grid_layout$positions$cell_bounds$$($layout_data$jscomp$2_transform_inverse$jscomp$18_vec__66777$$,$cell_data$$);$layout_data$jscomp$2_transform_inverse$jscomp$18_vec__66777$$=$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$86_child_width__$1$$)||$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$86_child_width__$1$$)?
$app$common$geom$shapes$transforms$calculate_geometry$$($APP.$cljs$core$_deref$$($parent_bounds$jscomp$7_transform$jscomp$81$$)):null;$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_data$jscomp$2_transform_inverse$jscomp$18_vec__66777$$,0,null);$parent_bounds$jscomp$7_transform$jscomp$81$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_data$jscomp$2_transform_inverse$jscomp$18_vec__66777$$,1,null);$layout_data$jscomp$2_transform_inverse$jscomp$18_vec__66777$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_data$jscomp$2_transform_inverse$jscomp$18_vec__66777$$,
2,null);var $fill_width$$=$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$86_child_width__$1$$)?$app$common$geom$shapes$grid_layout$positions$calc_fill_width_data$$($parent_bounds$jscomp$7_transform$jscomp$81$$,$layout_data$jscomp$2_transform_inverse$jscomp$18_vec__66777$$,$child$jscomp$86_child_width__$1$$,$child_height__$1_child_origin$jscomp$2$$,$child_width$jscomp$1$$,$cell_bounds$jscomp$2_child_bounds$jscomp$7$$):null,$fill_height$$=$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$86_child_width__$1$$)?
$app$common$geom$shapes$grid_layout$positions$calc_fill_height_data$$($parent_bounds$jscomp$7_transform$jscomp$81$$,$layout_data$jscomp$2_transform_inverse$jscomp$18_vec__66777$$,$child$jscomp$86_child_width__$1$$,$child_height__$1_child_origin$jscomp$2$$,$child_height$jscomp$1$$,$cell_bounds$jscomp$2_child_bounds$jscomp$7$$):null;$child$jscomp$86_child_width__$1$$=function(){var $or__5025__auto__$jscomp$710$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($fill_width$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$710$$)?
$or__5025__auto__$jscomp$710$$:$child_width$jscomp$1$$}();$child_height__$1_child_origin$jscomp$2$$=function(){var $or__5025__auto__$jscomp$711$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($fill_height$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$711$$)?$or__5025__auto__$jscomp$711$$:$child_height$jscomp$1$$}();return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$child$jscomp$86_child_width__$1$$,$child_height__$1_child_origin$jscomp$2$$,
function(){var $G__66780_G__66781$jscomp$inline_6517$$=$APP.$app$common$types$modifiers$empty$$();$G__66780_G__66781$jscomp$inline_6517$$=$APP.$cljs$core$truth_$$($fill_width$$)?$app$common$types$modifiers$add_modifiers$$($G__66780_G__66781$jscomp$inline_6517$$,$APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($fill_width$$)):$G__66780_G__66781$jscomp$inline_6517$$;return $APP.$cljs$core$truth_$$($fill_height$$)?$app$common$types$modifiers$add_modifiers$$($G__66780_G__66781$jscomp$inline_6517$$,
$APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($fill_height$$)):$G__66780_G__66781$jscomp$inline_6517$$}()],null)};
$app$common$geom$shapes$grid_layout$positions$child_position_delta$$=function($justify_parent$jscomp$236$$,$child$jscomp$87_from_h_vec__66791$$,$child_bounds$jscomp$8_child_origin$jscomp$3_to_h_vec__66794$$,$child_width$jscomp$2$$,$child_height$jscomp$2$$,$align$jscomp$1_from_v_layout_data$jscomp$3$$,$cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$){var $temp__5823__auto__$jscomp$171$$=$APP.$app$common$geom$shapes$grid_layout$positions$cell_bounds$$($align$jscomp$1_from_v_layout_data$jscomp$3$$,
$cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$171$$)){$child_bounds$jscomp$8_child_origin$jscomp$3_to_h_vec__66794$$=$APP.$app$common$geom$shapes$points$origin$$($child_bounds$jscomp$8_child_origin$jscomp$3_to_h_vec__66794$$);$align$jscomp$1_from_v_layout_data$jscomp$3$$=$APP.$cljs$cst$1692$layout_align_items$$.$cljs$core$IFn$_invoke$arity$1$($justify_parent$jscomp$236$$);$justify_parent$jscomp$236$$=$APP.$cljs$cst$1690$layout_justify_items$$.$cljs$core$IFn$_invoke$arity$1$($justify_parent$jscomp$236$$);
var $align_self$jscomp$3_align_self__$1$$=$APP.$cljs$cst$1677$align_self$$.$cljs$core$IFn$_invoke$arity$1$($cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$);$cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$=$APP.$cljs$cst$1678$justify_self$$.$cljs$core$IFn$_invoke$arity$1$($cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$);$align_self$jscomp$3_align_self__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($align_self$jscomp$3_align_self__$1$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align_self$jscomp$3_align_self__$1$$,$APP.$cljs$cst$1672$auto$$):$align_self$jscomp$3_align_self__$1$$)?$align_self$jscomp$3_align_self__$1$$:null;$cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$,
$APP.$cljs$cst$1672$auto$$):$cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$)?$cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$:null;var $align__$1$$=$APP.$cljs$core$truth_$$($align_self$jscomp$3_align_self__$1$$)?$align_self$jscomp$3_align_self__$1$$:$align$jscomp$1_from_v_layout_data$jscomp$3$$,$justify__$1$$=$APP.$cljs$core$truth_$$($cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$)?$cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$:
$justify_parent$jscomp$236$$,$origin_h$$=$APP.$app$common$geom$shapes$points$project_point$$($temp__5823__auto__$jscomp$171$$,$APP.$cljs$cst$1899$h$$,$child_bounds$jscomp$8_child_origin$jscomp$3_to_h_vec__66794$$),$origin_v$$=$APP.$app$common$geom$shapes$points$project_point$$($temp__5823__auto__$jscomp$171$$,$APP.$cljs$cst$3670$v$$,$child_bounds$jscomp$8_child_origin$jscomp$3_to_h_vec__66794$$),$hv$jscomp$5$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$shapes$points$start_hv$$,
$temp__5823__auto__$jscomp$171$$),$vv$jscomp$5$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$shapes$points$start_vv$$,$temp__5823__auto__$jscomp$171$$);$child$jscomp$87_from_h_vec__66791$$=$app$common$types$shape$layout$child_margins$$($child$jscomp$87_from_h_vec__66791$$);var $top_m$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$87_from_h_vec__66791$$,0,null),$right_m$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$87_from_h_vec__66791$$,
1,null),$bottom_m$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$87_from_h_vec__66791$$,2,null),$left_m$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$87_from_h_vec__66791$$,3,null);$child_bounds$jscomp$8_child_origin$jscomp$3_to_h_vec__66794$$=function(){switch($justify__$1$$ instanceof $APP.$cljs$core$Keyword$$?$justify__$1$$.$fqn$:null){case "end":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$app$common$geom$point$add$$($origin_h$$,$hv$jscomp$5$$($child_width$jscomp$2$$)),$APP.$app$common$geom$point$subtract$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5823__auto__$jscomp$171$$,1),$hv$jscomp$5$$($right_m$$))],null);case "center":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$add$$($origin_h$$,$hv$jscomp$5$$($child_width$jscomp$2$$/2)),$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$add$$($APP.$app$common$geom$shapes$points$project_point$$($temp__5823__auto__$jscomp$171$$,
$APP.$cljs$cst$1899$h$$,$app$common$geom$shapes$points$center$$($temp__5823__auto__$jscomp$171$$)),$hv$jscomp$5$$($left_m$$/2)),$hv$jscomp$5$$($right_m$$/2))],null);default:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$origin_h$$,$APP.$app$common$geom$point$add$$($APP.$cljs$core$first$$($temp__5823__auto__$jscomp$171$$),$hv$jscomp$5$$($left_m$$))],null)}}();$child$jscomp$87_from_h_vec__66791$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_bounds$jscomp$8_child_origin$jscomp$3_to_h_vec__66794$$,
0,null);$child_bounds$jscomp$8_child_origin$jscomp$3_to_h_vec__66794$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_bounds$jscomp$8_child_origin$jscomp$3_to_h_vec__66794$$,1,null);$cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$=function(){switch($align__$1$$ instanceof $APP.$cljs$core$Keyword$$?$align__$1$$.$fqn$:null){case "end":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$add$$($origin_v$$,
$vv$jscomp$5$$($child_height$jscomp$2$$)),$APP.$app$common$geom$point$subtract$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5823__auto__$jscomp$171$$,3),$vv$jscomp$5$$($bottom_m$$))],null);case "center":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$add$$($origin_v$$,$vv$jscomp$5$$($child_height$jscomp$2$$/2)),$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$add$$($APP.$app$common$geom$shapes$points$project_point$$($temp__5823__auto__$jscomp$171$$,
$APP.$cljs$cst$3670$v$$,$app$common$geom$shapes$points$center$$($temp__5823__auto__$jscomp$171$$)),$vv$jscomp$5$$($top_m$$)),$vv$jscomp$5$$($bottom_m$$))],null);default:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$origin_v$$,$APP.$app$common$geom$point$add$$($APP.$cljs$core$first$$($temp__5823__auto__$jscomp$171$$),$vv$jscomp$5$$($top_m$$))],null)}}();$align$jscomp$1_from_v_layout_data$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$,
0,null);$cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$,1,null);return $APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$app$common$geom$point$subtract$$($child_bounds$jscomp$8_child_origin$jscomp$3_to_h_vec__66794$$,$child$jscomp$87_from_h_vec__66791$$)),
$APP.$app$common$geom$point$subtract$$($cell_data$jscomp$1_justify_self$jscomp$2_justify_self__$1_to_v_vec__66797$$,$align$jscomp$1_from_v_layout_data$jscomp$3$$))}return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0)};
$APP.$app$common$geom$shapes$grid_layout$positions$get_position_grid_coord$$=function($p__66810_row_idx__$1_row_tracks$jscomp$4$$,$position$jscomp$71$$){function $make_min_distance_track$$($type$jscomp$471_vec__66829$$){$type$jscomp$471_vec__66829$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$471_vec__66829$$,$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$vv$jscomp$6$$,$hv$jscomp$6$$],null):new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hv$jscomp$6$$,$vv$jscomp$6$$],null);var $vfn$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($type$jscomp$471_vec__66829$$,0,null),$ofn$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($type$jscomp$471_vec__66829$$,1,null);return function($p__66832_selected_dist$$,$map__66840_map__66840__$1_p__66833$$){var $selected$jscomp$33$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66832_selected_dist$$,
0,null);$p__66832_selected_dist$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__66832_selected_dist$$,1,null);var $cur_idx$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__66840_map__66840__$1_p__66833$$,0,null);$map__66840_map__66840__$1_p__66833$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__66840_map__66840__$1_p__66833$$,1,null);$map__66840_map__66840__$1_p__66833$$=$APP.$cljs$core$__destructure_map$$($map__66840_map__66840__$1_p__66833$$);var $dist_1_start_p$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66840_map__66840__$1_p__66833$$,$APP.$cljs$cst$3663$start_p$$),$end_p$jscomp$1_size$jscomp$125$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66840_map__66840__$1_p__66833$$,$APP.$cljs$cst$874$size$$),$dist_2_unit_v$jscomp$1$$=$vfn$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$vfn$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$(1):$vfn$jscomp$6$$(1);$end_p$jscomp$1_size$jscomp$125$$=$APP.$app$common$geom$point$add$$($dist_1_start_p$jscomp$3$$,
$ofn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$ofn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$1_size$jscomp$125$$):$ofn$jscomp$1$$($end_p$jscomp$1_size$jscomp$125$$));$dist_1_start_p$jscomp$3$$=$APP.$app$common$math$abs$$($APP.$app$common$geom$line$line_value$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$dist_1_start_p$jscomp$3$$,$dist_2_unit_v$jscomp$1$$],null),$position$jscomp$71$$));$dist_2_unit_v$jscomp$1$$=$APP.$app$common$math$abs$$($APP.$app$common$geom$line$line_value$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$end_p$jscomp$1_size$jscomp$125$$,$dist_2_unit_v$jscomp$1$$],null),$position$jscomp$71$$));return $dist_1_start_p$jscomp$3$$<$p__66832_selected_dist$$||$dist_2_unit_v$jscomp$1$$<$p__66832_selected_dist$$?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cur_idx$$,$map__66840_map__66840__$1_p__66833$$],null),
$dist_1_start_p$jscomp$3$$<$dist_2_unit_v$jscomp$1$$?$dist_1_start_p$jscomp$3$$:$dist_2_unit_v$jscomp$1$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$selected$jscomp$33$$,$p__66832_selected_dist$$],null)}}function $make_is_inside_track$$($type$jscomp$470_vec__66824$$){$type$jscomp$470_vec__66824$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$470_vec__66824$$,$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$vv$jscomp$6$$,$hv$jscomp$6$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hv$jscomp$6$$,$vv$jscomp$6$$],null);var $vfn$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($type$jscomp$470_vec__66824$$,0,null),$ofn$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($type$jscomp$470_vec__66824$$,1,null);return function($p__66827_start_p$jscomp$2$$){var $map__66828__$1_unit_v$$=
$APP.$cljs$core$__destructure_map$$($p__66827_start_p$jscomp$2$$);$p__66827_start_p$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66828__$1_unit_v$$,$APP.$cljs$cst$3663$start_p$$);var $end_p_line_2$jscomp$inline_6520_size$jscomp$124$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66828__$1_unit_v$$,$APP.$cljs$cst$874$size$$);$map__66828__$1_unit_v$$=$vfn$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$vfn$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$(1):$vfn$jscomp$5$$(1);
$end_p_line_2$jscomp$inline_6520_size$jscomp$124$$=$APP.$app$common$geom$point$add$$($p__66827_start_p$jscomp$2$$,$ofn$$.$cljs$core$IFn$_invoke$arity$1$?$ofn$$.$cljs$core$IFn$_invoke$arity$1$($end_p_line_2$jscomp$inline_6520_size$jscomp$124$$):$ofn$$($end_p_line_2$jscomp$inline_6520_size$jscomp$124$$));$end_p_line_2$jscomp$inline_6520_size$jscomp$124$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$end_p_line_2$jscomp$inline_6520_size$jscomp$124$$,
$map__66828__$1_unit_v$$],null);return $APP.$app$common$geom$line$line_value$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p__66827_start_p$jscomp$2$$,$map__66828__$1_unit_v$$],null),$position$jscomp$71$$)*$APP.$app$common$geom$line$line_value$$($end_p_line_2$jscomp$inline_6520_size$jscomp$124$$,$position$jscomp$71$$)<0}}function $vv$jscomp$6$$($p1__66809_SHARP_$$){return $APP.$app$common$geom$shapes$points$start_vv$$($layout_bounds$jscomp$2$$,$p1__66809_SHARP_$$)}
function $hv$jscomp$6$$($p1__66808_SHARP_$$){return $APP.$app$common$geom$shapes$points$start_hv$$($layout_bounds$jscomp$2$$,$p1__66808_SHARP_$$)}var $map__66811__$1_row__$1$jscomp$3_row_idx_vec__66812_vec__66821$$=$APP.$cljs$core$__destructure_map$$($p__66810_row_idx__$1_row_tracks$jscomp$4$$),$layout_bounds$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66811__$1_row__$1$jscomp$3_row_idx_vec__66812_vec__66821$$,$APP.$cljs$cst$3666$layout_bounds$$);$p__66810_row_idx__$1_row_tracks$jscomp$4$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66811__$1_row__$1$jscomp$3_row_idx_vec__66812_vec__66821$$,$APP.$cljs$cst$3661$row_tracks$$);var $col_idx__$1_column_tracks$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66811__$1_row__$1$jscomp$3_row_idx_vec__66812_vec__66821$$,$APP.$cljs$cst$3662$column_tracks$$);$map__66811__$1_row__$1$jscomp$3_row_idx_vec__66812_vec__66821$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($make_is_inside_track$$($APP.$cljs$cst$216$column$$),
$APP.$cljs$core$second$$),$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($col_idx__$1_column_tracks$jscomp$4$$));var $col_idx_column__$1$jscomp$2_vec__66818$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__66811__$1_row__$1$jscomp$3_row_idx_vec__66812_vec__66821$$,0,null),$column$jscomp$34$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__66811__$1_row__$1$jscomp$3_row_idx_vec__66812_vec__66821$$,1,null),$row$jscomp$29_vec__66815$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($make_is_inside_track$$($APP.$cljs$cst$1656$row$$),
$APP.$cljs$core$second$$),$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($p__66810_row_idx__$1_row_tracks$jscomp$4$$));$map__66811__$1_row__$1$jscomp$3_row_idx_vec__66812_vec__66821$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($row$jscomp$29_vec__66815$$,0,null);$row$jscomp$29_vec__66815$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($row$jscomp$29_vec__66815$$,1,null);$col_idx_column__$1$jscomp$2_vec__66818$$=$column$jscomp$34$$!=null?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$col_idx_column__$1$jscomp$2_vec__66818$$,$column$jscomp$34$$],null):$APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($make_min_distance_track$$($APP.$cljs$cst$216$column$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,null],null),Infinity],null),$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($col_idx__$1_column_tracks$jscomp$4$$)));
$col_idx__$1_column_tracks$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($col_idx_column__$1$jscomp$2_vec__66818$$,0,null);$col_idx_column__$1$jscomp$2_vec__66818$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($col_idx_column__$1$jscomp$2_vec__66818$$,1,null);$map__66811__$1_row__$1$jscomp$3_row_idx_vec__66812_vec__66821$$=$row$jscomp$29_vec__66815$$!=null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$map__66811__$1_row__$1$jscomp$3_row_idx_vec__66812_vec__66821$$,
$row$jscomp$29_vec__66815$$],null):$APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($make_min_distance_track$$($APP.$cljs$cst$1656$row$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,null],null),Infinity],null),$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($p__66810_row_idx__$1_row_tracks$jscomp$4$$)));
$p__66810_row_idx__$1_row_tracks$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__66811__$1_row__$1$jscomp$3_row_idx_vec__66812_vec__66821$$,0,null);$map__66811__$1_row__$1$jscomp$3_row_idx_vec__66812_vec__66821$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__66811__$1_row__$1$jscomp$3_row_idx_vec__66812_vec__66821$$,1,null);return $col_idx_column__$1$jscomp$2_vec__66818$$!=null&&$map__66811__$1_row__$1$jscomp$3_row_idx_vec__66812_vec__66821$$!=null?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p__66810_row_idx__$1_row_tracks$jscomp$4$$+1,$col_idx__$1_column_tracks$jscomp$4$$+1],null):null};
$app$common$geom$shapes$grid_layout$positions$get_drop_cell$$=function($children$jscomp$211_frame_id$jscomp$52_layout_data$jscomp$5$$,$objects$jscomp$356$$,$position$jscomp$72$$){var $frame$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$356$$,$children$jscomp$211_frame_id$jscomp$52_layout_data$jscomp$5$$);$children$jscomp$211_frame_id$jscomp$52_layout_data$jscomp$5$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66841_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($p1__66841_SHARP_$$),$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$17$$)),$p1__66841_SHARP_$$],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$356$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$17$$))));var $bounds$jscomp$24$$=$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$356$$),function($p1__66842_SHARP_$$){return $app$common$geom$shapes$common$shape__GT_points$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$356$$,$p1__66842_SHARP_$$))});$children$jscomp$211_frame_id$jscomp$52_layout_data$jscomp$5$$=$app$common$geom$shapes$grid_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$05$$($frame$jscomp$17$$,
$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$17$$),$children$jscomp$211_frame_id$jscomp$52_layout_data$jscomp$5$$,$bounds$jscomp$24$$,$objects$jscomp$356$$);return $APP.$app$common$geom$shapes$grid_layout$positions$get_position_grid_coord$$($children$jscomp$211_frame_id$jscomp$52_layout_data$jscomp$5$$,$position$jscomp$72$$)};
$app$common$geom$shapes$grid_layout$get_cell_data$$=function($JSCompiler_inline_result$jscomp$1132_origin$jscomp$inline_6526_param66856_start_p$jscomp$inline_6536$$,$param66857_row$jscomp$inline_6533_row_start_p$jscomp$inline_6535_row_tracks$jscomp$inline_6527$$,$child$jscomp$inline_6530_grid_cell$jscomp$inline_6531_param66858$$){a:{var $map__66729__$1$jscomp$inline_6525_shape_cells$jscomp$inline_6529$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$1132_origin$jscomp$inline_6526_param66856_start_p$jscomp$inline_6536$$);
$JSCompiler_inline_result$jscomp$1132_origin$jscomp$inline_6526_param66856_start_p$jscomp$inline_6536$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66729__$1$jscomp$inline_6525_shape_cells$jscomp$inline_6529$$,$APP.$cljs$cst$1786$origin$$);$param66857_row$jscomp$inline_6533_row_start_p$jscomp$inline_6535_row_tracks$jscomp$inline_6527$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66729__$1$jscomp$inline_6525_shape_cells$jscomp$inline_6529$$,$APP.$cljs$cst$3661$row_tracks$$);
var $column$jscomp$inline_6532_column_start_p$jscomp$inline_6534_column_tracks$jscomp$inline_6528$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66729__$1$jscomp$inline_6525_shape_cells$jscomp$inline_6529$$,$APP.$cljs$cst$3662$column_tracks$$);$map__66729__$1$jscomp$inline_6525_shape_cells$jscomp$inline_6529$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66729__$1$jscomp$inline_6525_shape_cells$jscomp$inline_6529$$,$cljs$cst$3668$shape_cells$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$inline_6530_grid_cell$jscomp$inline_6531_param66858$$,
0,null);$child$jscomp$inline_6530_grid_cell$jscomp$inline_6531_param66858$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$inline_6530_grid_cell$jscomp$inline_6531_param66858$$,1,null);$child$jscomp$inline_6530_grid_cell$jscomp$inline_6531_param66858$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66729__$1$jscomp$inline_6525_shape_cells$jscomp$inline_6529$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$inline_6530_grid_cell$jscomp$inline_6531_param66858$$));
if($child$jscomp$inline_6530_grid_cell$jscomp$inline_6531_param66858$$!=null&&$APP.$app$common$data$not_empty_QMARK_$$($child$jscomp$inline_6530_grid_cell$jscomp$inline_6531_param66858$$)&&($column$jscomp$inline_6532_column_start_p$jscomp$inline_6534_column_tracks$jscomp$inline_6528$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$inline_6532_column_start_p$jscomp$inline_6534_column_tracks$jscomp$inline_6528$$,$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$inline_6530_grid_cell$jscomp$inline_6531_param66858$$)-
1,null),$param66857_row$jscomp$inline_6533_row_start_p$jscomp$inline_6535_row_tracks$jscomp$inline_6527$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($param66857_row$jscomp$inline_6533_row_start_p$jscomp$inline_6535_row_tracks$jscomp$inline_6527$$,$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$inline_6530_grid_cell$jscomp$inline_6531_param66858$$)-1,null),$column$jscomp$inline_6532_column_start_p$jscomp$inline_6534_column_tracks$jscomp$inline_6528$$=$APP.$cljs$cst$3663$start_p$$.$cljs$core$IFn$_invoke$arity$1$($column$jscomp$inline_6532_column_start_p$jscomp$inline_6534_column_tracks$jscomp$inline_6528$$),
$param66857_row$jscomp$inline_6533_row_start_p$jscomp$inline_6535_row_tracks$jscomp$inline_6527$$=$APP.$cljs$cst$3663$start_p$$.$cljs$core$IFn$_invoke$arity$1$($param66857_row$jscomp$inline_6533_row_start_p$jscomp$inline_6535_row_tracks$jscomp$inline_6527$$),$column$jscomp$inline_6532_column_start_p$jscomp$inline_6534_column_tracks$jscomp$inline_6528$$!=null&&$param66857_row$jscomp$inline_6533_row_start_p$jscomp$inline_6535_row_tracks$jscomp$inline_6527$$!=null)){$JSCompiler_inline_result$jscomp$1132_origin$jscomp$inline_6526_param66856_start_p$jscomp$inline_6536$$=
$APP.$app$common$geom$point$add$$($JSCompiler_inline_result$jscomp$1132_origin$jscomp$inline_6526_param66856_start_p$jscomp$inline_6536$$,$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$subtract$$($column$jscomp$inline_6532_column_start_p$jscomp$inline_6534_column_tracks$jscomp$inline_6528$$,$JSCompiler_inline_result$jscomp$1132_origin$jscomp$inline_6526_param66856_start_p$jscomp$inline_6536$$),$APP.$app$common$geom$point$subtract$$($param66857_row$jscomp$inline_6533_row_start_p$jscomp$inline_6535_row_tracks$jscomp$inline_6527$$,
$JSCompiler_inline_result$jscomp$1132_origin$jscomp$inline_6526_param66856_start_p$jscomp$inline_6536$$)));$JSCompiler_inline_result$jscomp$1132_origin$jscomp$inline_6526_param66856_start_p$jscomp$inline_6536$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($child$jscomp$inline_6530_grid_cell$jscomp$inline_6531_param66858$$,$APP.$cljs$cst$3663$start_p$$,$JSCompiler_inline_result$jscomp$1132_origin$jscomp$inline_6526_param66856_start_p$jscomp$inline_6536$$);break a}$JSCompiler_inline_result$jscomp$1132_origin$jscomp$inline_6526_param66856_start_p$jscomp$inline_6536$$=
null}return $JSCompiler_inline_result$jscomp$1132_origin$jscomp$inline_6526_param66856_start_p$jscomp$inline_6536$$};
$APP.$app$main$data$exports$wasm$export_image_uri$$=function($p__66783_type$jscomp$472$$){var $map__66784__$1_object_id$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($p__66783_type$jscomp$472$$);$p__66783_type$jscomp$472$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66784__$1_object_id$jscomp$3$$,$APP.$cljs$cst$139$type$$);var $bytes$jscomp$10_scale$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66784__$1_object_id$jscomp$3$$,$APP.$cljs$cst$1902$scale$$);
$map__66784__$1_object_id$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66784__$1_object_id$jscomp$3$$,$APP.$cljs$cst$2272$object_id$$);$bytes$jscomp$10_scale$jscomp$26$$=$app$render_wasm$api$render_shape_pixels$$($map__66784__$1_object_id$jscomp$3$$,$bytes$jscomp$10_scale$jscomp$26$$);return $APP.$app$util$webapi$create_uri$$($APP.$app$util$webapi$create_blob$cljs$0core$0IFn$0_invoke$0arity$02$$($bytes$jscomp$10_scale$jscomp$26$$,$app$common$media$format__GT_mtype$$($p__66783_type$jscomp$472$$)))};
$app$common$files$shapes_builder$assert_valid_num$$=function($attr$jscomp$49$$,$num$jscomp$32$$){var $and__5023__auto__$jscomp$inline_6538$$=$APP.$app$common$math$finite_QMARK_$$($num$jscomp$32$$);if(!$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_6538$$)?$num$jscomp$32$$<=2147483647&&$num$jscomp$32$$>=-2147483648:$and__5023__auto__$jscomp$inline_6538$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$(["invalid numeric value for `",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$49$$),
"`: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($num$jscomp$32$$)].join(""),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$272$assertion$$,$APP.$cljs$cst$273$code$$,$cljs$cst$931$data_validation$$,$APP.$cljs$cst$275$hint$$,["invalid numeric value for `",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$49$$),
"`: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($num$jscomp$32$$)].join("")],null),null])),null);return $num$jscomp$32$$>0&&$num$jscomp$32$$<1?1:$num$jscomp$32$$<0&&$num$jscomp$32$$>-1?-1:$num$jscomp$32$$};
$app$common$files$shapes_builder$assert_valid_pos_num$$=function($attr$jscomp$50$$,$num$jscomp$33$$){if(!($num$jscomp$33$$>0))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$(["invalid numeric value for `",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$50$$),"`: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($num$jscomp$33$$)," (should be positive)"].join(""),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$272$assertion$$,$APP.$cljs$cst$273$code$$,$cljs$cst$931$data_validation$$,$APP.$cljs$cst$275$hint$$,["invalid numeric value for `",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$50$$),"`: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($num$jscomp$33$$)," (should be positive)"].join("")],null),null])),null);return $num$jscomp$33$$};
$app$common$files$shapes_builder$assert_valid_blend_mode$$=function($mode$jscomp$25_value$jscomp$547$$){$mode$jscomp$25_value$jscomp$547$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$lower$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($mode$jscomp$25_value$jscomp$547$$)));if(!$APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$blend_modes$$,$mode$jscomp$25_value$jscomp$547$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$(["unexpected blend mode: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($mode$jscomp$25_value$jscomp$547$$)].join(""),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$272$assertion$$,$APP.$cljs$cst$273$code$$,$cljs$cst$931$data_validation$$,$APP.$cljs$cst$275$hint$$,["unexpected blend mode: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($mode$jscomp$25_value$jscomp$547$$)].join("")],
null),null])),null);return $mode$jscomp$25_value$jscomp$547$$};
$app$common$files$shapes_builder$svg_dimensions$$=function($map__66917__$1_p__66916_width$jscomp$104_x$jscomp$1174$$){$map__66917__$1_p__66916_width$jscomp$104_x$jscomp$1174$$=$APP.$cljs$core$__destructure_map$$($map__66917__$1_p__66916_width$jscomp$104_x$jscomp$1174$$);var $attrs$jscomp$84_or__5025__auto__$jscomp$inline_6540_width__$1$jscomp$1_width__$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66917__$1_p__66916_width$jscomp$104_x$jscomp$1174$$,$APP.$cljs$cst$2645$attrs$$);$map__66917__$1_p__66916_width$jscomp$104_x$jscomp$1174$$=
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$84_or__5025__auto__$jscomp$inline_6540_width__$1$jscomp$1_width__$2$$,100);var $height$jscomp$93_y$jscomp$410$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$84_or__5025__auto__$jscomp$inline_6540_width__$1$jscomp$1_width__$2$$,100);$attrs$jscomp$84_or__5025__auto__$jscomp$inline_6540_width__$1$jscomp$1_width__$2$$=$cljs$cst$2880$viewBox$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$84_or__5025__auto__$jscomp$inline_6540_width__$1$jscomp$1_width__$2$$);
var $height__$1$jscomp$1_height__$2_vec__66919$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$common$svg$xf_parse_numbers$$,$APP.$cljs$core$re_seq$$($app$common$svg$number_regex$$,$APP.$cljs$core$truth_$$($attrs$jscomp$84_or__5025__auto__$jscomp$inline_6540_width__$1$jscomp$1_width__$2$$)?$attrs$jscomp$84_or__5025__auto__$jscomp$inline_6540_width__$1$jscomp$1_width__$2$$:"0 0 "+($map__66917__$1_p__66916_width$jscomp$104_x$jscomp$1174$$??"")+
" "+($height$jscomp$93_y$jscomp$410$$??"")));$map__66917__$1_p__66916_width$jscomp$104_x$jscomp$1174$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($height__$1$jscomp$1_height__$2_vec__66919$$,0,null);$height$jscomp$93_y$jscomp$410$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($height__$1$jscomp$1_height__$2_vec__66919$$,1,null);$attrs$jscomp$84_or__5025__auto__$jscomp$inline_6540_width__$1$jscomp$1_width__$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($height__$1$jscomp$1_height__$2_vec__66919$$,
2,null);$height__$1$jscomp$1_height__$2_vec__66919$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($height__$1$jscomp$1_height__$2_vec__66919$$,3,null);$attrs$jscomp$84_or__5025__auto__$jscomp$inline_6540_width__$1$jscomp$1_width__$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$84_or__5025__auto__$jscomp$inline_6540_width__$1$jscomp$1_width__$2$$,0)?1:$attrs$jscomp$84_or__5025__auto__$jscomp$inline_6540_width__$1$jscomp$1_width__$2$$;$height__$1$jscomp$1_height__$2_vec__66919$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($height__$1$jscomp$1_height__$2_vec__66919$$,0)?1:$height__$1$jscomp$1_height__$2_vec__66919$$;return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$files$shapes_builder$assert_valid_num$$($APP.$cljs$cst$1510$x$$,$map__66917__$1_p__66916_width$jscomp$104_x$jscomp$1174$$),$app$common$files$shapes_builder$assert_valid_num$$($APP.$cljs$cst$1511$y$$,$height$jscomp$93_y$jscomp$410$$),$app$common$files$shapes_builder$assert_valid_pos_num$$($APP.$cljs$cst$290$width$$,
$attrs$jscomp$84_or__5025__auto__$jscomp$inline_6540_width__$1$jscomp$1_width__$2$$),$app$common$files$shapes_builder$assert_valid_pos_num$$($APP.$cljs$cst$1522$height$$,$height__$1$jscomp$1_height__$2_vec__66919$$)],null)};
$app$common$files$shapes_builder$process_gradient_stops$$=function($stops$jscomp$8$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($stop$jscomp$2$$){var $G__66925__$2$jscomp$inline_12402_final_attrs_stop_attrs$$=$APP.$cljs$cst$2645$attrs$$.$cljs$core$IFn$_invoke$arity$1$($stop$jscomp$2$$),$stop_style_style_stop_color$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__66925__$2$jscomp$inline_12402_final_attrs_stop_attrs$$,$APP.$cljs$cst$1904$style$$),$parsed_style_style_stop_opacity$$=
typeof $stop_style_style_stop_color$$==="string"&&$APP.$cljs$core$seq$$($stop_style_style_stop_color$$)?$app$common$svg$parse_style$$($stop_style_style_stop_color$$):null;$stop_style_style_stop_color$$=$APP.$cljs$core$truth_$$($parsed_style_style_stop_opacity$$)?$cljs$cst$2904$stop_color$$.$cljs$core$IFn$_invoke$arity$1$($parsed_style_style_stop_opacity$$):null;$parsed_style_style_stop_opacity$$=$APP.$cljs$core$truth_$$($parsed_style_style_stop_opacity$$)?$cljs$cst$2915$stop_opacity$$.$cljs$core$IFn$_invoke$arity$1$($parsed_style_style_stop_opacity$$):
null;var $G__66925__$1$jscomp$inline_12401$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($stop_style_style_stop_color$$)?!$APP.$cljs$core$contains_QMARK_$$($G__66925__$2$jscomp$inline_12402_final_attrs_stop_attrs$$,$cljs$cst$2904$stop_color$$):$stop_style_style_stop_color$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66925__$2$jscomp$inline_12402_final_attrs_stop_attrs$$,$cljs$cst$2904$stop_color$$,$stop_style_style_stop_color$$):$G__66925__$2$jscomp$inline_12402_final_attrs_stop_attrs$$;
$G__66925__$2$jscomp$inline_12402_final_attrs_stop_attrs$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($parsed_style_style_stop_opacity$$)?!$APP.$cljs$core$contains_QMARK_$$($G__66925__$2$jscomp$inline_12402_final_attrs_stop_attrs$$,$cljs$cst$2915$stop_opacity$$):$parsed_style_style_stop_opacity$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66925__$1$jscomp$inline_12401$$,$cljs$cst$2915$stop_opacity$$,$parsed_style_style_stop_opacity$$):$G__66925__$1$jscomp$inline_12401$$;$G__66925__$2$jscomp$inline_12402_final_attrs_stop_attrs$$=
$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($stop_style_style_stop_color$$)?$stop_style_style_stop_color$$:$parsed_style_style_stop_opacity$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__66925__$2$jscomp$inline_12402_final_attrs_stop_attrs$$,$APP.$cljs$cst$1904$style$$):$G__66925__$2$jscomp$inline_12402_final_attrs_stop_attrs$$;return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($stop$jscomp$2$$,$APP.$cljs$cst$2645$attrs$$,$G__66925__$2$jscomp$inline_12402_final_attrs_stop_attrs$$)},
$stops$jscomp$8$$)};
$app$common$files$shapes_builder$resolve_gradient_href$$=function($defs$jscomp$6$$){var $resolve_gradient$$=function $app$common$files$shapes_builder$resolve_gradient_href_$_resolve_gradient$$($gradient_id$jscomp$2$$,$gradient_node$$,$defs__$1$jscomp$2_final_content_processed_content_resolved_base$$,$merged_attrs_ref_attrs$jscomp$1_ref_transform_visited$jscomp$3$$){if($APP.$cljs$core$contains_QMARK_$$($merged_attrs_ref_attrs$jscomp$1_ref_transform_visited$jscomp$3$$,$gradient_id$jscomp$2$$))return console.warn("[resolve-gradient] Circular reference detected for",$gradient_id$jscomp$2$$),
$gradient_node$$;var $attrs$jscomp$85$$=$APP.$cljs$cst$2645$attrs$$.$cljs$core$IFn$_invoke$arity$1$($gradient_node$$),$base_attrs_base_transform_href_id_href_id__$1$$=function(){var $or__5025__auto__$jscomp$717$$=$APP.$cljs$cst$2462$href$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$85$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$717$$)?$or__5025__auto__$jscomp$717$$:$cljs$cst$2853$xlink_COLON_href$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$85$$)}();$base_attrs_base_transform_href_id_href_id__$1$$=
typeof $base_attrs_base_transform_href_id_href_id__$1$$==="string"&&$APP.$cljs$core$count$$($base_attrs_base_transform_href_id_href_id__$1$$)>0?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($base_attrs_base_transform_href_id_href_id__$1$$,1):null;var $base_gradient$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($base_attrs_base_transform_href_id_href_id__$1$$)?$APP.$cljs$core$contains_QMARK_$$($defs__$1$jscomp$2_final_content_processed_content_resolved_base$$,$base_attrs_base_transform_href_id_href_id__$1$$):
$base_attrs_base_transform_href_id_href_id__$1$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs__$1$jscomp$2_final_content_processed_content_resolved_base$$,$base_attrs_base_transform_href_id_href_id__$1$$):null;$defs__$1$jscomp$2_final_content_processed_content_resolved_base$$=$APP.$cljs$core$truth_$$($base_gradient$$)?$app$common$files$shapes_builder$resolve_gradient_href_$_resolve_gradient$$($base_attrs_base_transform_href_id_href_id__$1$$,$base_gradient$$,$defs__$1$jscomp$2_final_content_processed_content_resolved_base$$,
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($merged_attrs_ref_attrs$jscomp$1_ref_transform_visited$jscomp$3$$,$gradient_id$jscomp$2$$)):null;if($APP.$cljs$core$truth_$$($defs__$1$jscomp$2_final_content_processed_content_resolved_base$$)){$base_attrs_base_transform_href_id_href_id__$1$$=$APP.$cljs$cst$2645$attrs$$.$cljs$core$IFn$_invoke$arity$1$($defs__$1$jscomp$2_final_content_processed_content_resolved_base$$);$merged_attrs_ref_attrs$jscomp$1_ref_transform_visited$jscomp$3$$=$APP.$cljs$cst$2645$attrs$$.$cljs$core$IFn$_invoke$arity$1$($gradient_node$$);
var $base_attrs_clean$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($base_attrs_base_transform_href_id_href_id__$1$$,$APP.$cljs$cst$266$id$$),$ref_attrs_clean$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($merged_attrs_ref_attrs$jscomp$1_ref_transform_visited$jscomp$3$$,$APP.$cljs$cst$2462$href$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$2853$xlink_COLON_href$$,$APP.$cljs$cst$266$id$$]));$base_attrs_base_transform_href_id_href_id__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_attrs_base_transform_href_id_href_id__$1$$,$cljs$cst$2889$gradientTransform$$);$merged_attrs_ref_attrs$jscomp$1_ref_transform_visited$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($merged_attrs_ref_attrs$jscomp$1_ref_transform_visited$jscomp$3$$,$cljs$cst$2889$gradientTransform$$);var $combined_transform$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($base_attrs_base_transform_href_id_href_id__$1$$)?$merged_attrs_ref_attrs$jscomp$1_ref_transform_visited$jscomp$3$$:
$base_attrs_base_transform_href_id_href_id__$1$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($base_attrs_base_transform_href_id_href_id__$1$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($merged_attrs_ref_attrs$jscomp$1_ref_transform_visited$jscomp$3$$)].join(""):$APP.$cljs$core$truth_$$($merged_attrs_ref_attrs$jscomp$1_ref_transform_visited$jscomp$3$$)?$merged_attrs_ref_attrs$jscomp$1_ref_transform_visited$jscomp$3$$:$base_attrs_base_transform_href_id_href_id__$1$$;$merged_attrs_ref_attrs$jscomp$1_ref_transform_visited$jscomp$3$$=
function(){var $G__66930$$=$APP.$app$common$data$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$($base_attrs_clean$$,$ref_attrs_clean$$);return $APP.$cljs$core$truth_$$($combined_transform$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66930$$,$cljs$cst$2889$gradientTransform$$,$combined_transform$$):$G__66930$$}();$defs__$1$jscomp$2_final_content_processed_content_resolved_base$$=$APP.$cljs$core$seq$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($gradient_node$$))?$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($gradient_node$$):
$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($defs__$1$jscomp$2_final_content_processed_content_resolved_base$$);$defs__$1$jscomp$2_final_content_processed_content_resolved_base$$=$app$common$files$shapes_builder$process_gradient_stops$$($defs__$1$jscomp$2_final_content_processed_content_resolved_base$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($gradient_node$$),$APP.$cljs$cst$2645$attrs$$,
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($merged_attrs_ref_attrs$jscomp$1_ref_transform_visited$jscomp$3$$,$APP.$cljs$cst$266$id$$,$gradient_id$jscomp$2$$),$APP.$cljs$cst$1637$content$$,$defs__$1$jscomp$2_final_content_processed_content_resolved_base$$],null)}$defs__$1$jscomp$2_final_content_processed_content_resolved_base$$=$app$common$files$shapes_builder$process_gradient_stops$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($gradient_node$$));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($gradient_node$$,
$APP.$cljs$cst$1637$content$$,$defs__$1$jscomp$2_final_content_processed_content_resolved_base$$)},$gradient_tags$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$2692$linearGradient$$,null,$cljs$cst$2693$radialGradient$$,null],null),null);return $APP.$cljs$core$reduce_kv$$(function($acc$jscomp$126$$,$id$jscomp$509$$,$node$jscomp$299$$){return $APP.$cljs$core$contains_QMARK_$$($gradient_tags$$,$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$299$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$126$$,$id$jscomp$509$$,$resolve_gradient$$($id$jscomp$509$$,$node$jscomp$299$$,$defs$jscomp$6$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$)):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$126$$,$id$jscomp$509$$,$node$jscomp$299$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$defs$jscomp$6$$)};
$APP.$app$common$files$shapes_builder$create_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$08$$=function($id$jscomp$510_root_shape$jscomp$3$$,$def_nodes_def_nodes__$1_svg_data$jscomp$4_svg_data__$1$$,$map__66959__$1_p__66958_unames$jscomp$7_vec__66960$$,$children$jscomp$212_objects$jscomp$358_vec__66966$$,$all_defs_from_children_frame_id$jscomp$54_root_shape_with_defs$$,$parent_id$jscomp$65_root_id$jscomp$4$$,$selected$jscomp$35$$,$center_QMARK_$jscomp$1_svg_data__$2_vec__66963$$){$map__66959__$1_p__66958_unames$jscomp$7_vec__66960$$=
$APP.$cljs$core$__destructure_map$$($map__66959__$1_p__66958_unames$jscomp$7_vec__66960$$);var $x$jscomp$1175$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66959__$1_p__66958_unames$jscomp$7_vec__66960$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$411$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66959__$1_p__66958_unames$jscomp$7_vec__66960$$,$APP.$cljs$cst$1511$y$$);$map__66959__$1_p__66958_unames$jscomp$7_vec__66960$$=$app$common$files$shapes_builder$svg_dimensions$$($def_nodes_def_nodes__$1_svg_data$jscomp$4_svg_data__$1$$);
var $background$jscomp$8_svg_data__$3_vb_x$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__66959__$1_p__66958_unames$jscomp$7_vec__66960$$,0,null),$vb_y$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__66959__$1_p__66958_unames$jscomp$7_vec__66960$$,1,null),$vb_width$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__66959__$1_p__66958_unames$jscomp$7_vec__66960$$,2,null),$vb_height$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__66959__$1_p__66958_unames$jscomp$7_vec__66960$$,
3,null);$map__66959__$1_p__66958_unames$jscomp$7_vec__66960$$=$APP.$app$common$files$helpers$get_used_names$$($children$jscomp$212_objects$jscomp$358_vec__66966$$);var $svg_name$$=$APP.$cuerdas$core$replace$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($def_nodes_def_nodes__$1_svg_data$jscomp$4_svg_data__$1$$),".svg","");$def_nodes_def_nodes__$1_svg_data$jscomp$4_svg_data__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($def_nodes_def_nodes__$1_svg_data$jscomp$4_svg_data__$1$$,
$APP.$cljs$cst$1510$x$$,$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($center_QMARK_$jscomp$1_svg_data__$2_vec__66963$$)?$x$jscomp$1175$$-$background$jscomp$8_svg_data__$3_vb_x$$-$vb_width$$/2:$x$jscomp$1175$$)),$APP.$cljs$cst$1511$y$$,$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($center_QMARK_$jscomp$1_svg_data__$2_vec__66963$$)?$y$jscomp$411$$-$vb_y$$-$vb_height$$/2:$y$jscomp$411$$)),$APP.$cljs$cst$1650$offset_x$$,
$background$jscomp$8_svg_data__$3_vb_x$$),$APP.$cljs$cst$1651$offset_y$$,$vb_y$$),$APP.$cljs$cst$290$width$$,$vb_width$$),$APP.$cljs$cst$1522$height$$,$vb_height$$),$APP.$cljs$cst$725$name$$,$svg_name$$);$center_QMARK_$jscomp$1_svg_data__$2_vec__66963$$=$app$common$svg$extract_defs$$($app$common$svg$fix_percents$$($app$common$svg$fix_default_values$$($def_nodes_def_nodes__$1_svg_data$jscomp$4_svg_data__$1$$)));$def_nodes_def_nodes__$1_svg_data$jscomp$4_svg_data__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($center_QMARK_$jscomp$1_svg_data__$2_vec__66963$$,
0,null);$center_QMARK_$jscomp$1_svg_data__$2_vec__66963$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($center_QMARK_$jscomp$1_svg_data__$2_vec__66963$$,1,null);$def_nodes_def_nodes__$1_svg_data$jscomp$4_svg_data__$1$$=$app$common$files$shapes_builder$resolve_gradient_href$$($def_nodes_def_nodes__$1_svg_data$jscomp$4_svg_data__$1$$);$background$jscomp$8_svg_data__$3_vb_x$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$1611$rect$$,$APP.$cljs$cst$2645$attrs$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1510$x$$,""+($background$jscomp$8_svg_data__$3_vb_x$$??""),$APP.$cljs$cst$1511$y$$,""+($vb_y$$??""),$APP.$cljs$cst$290$width$$,""+($vb_width$$??""),$APP.$cljs$cst$1522$height$$,""+($vb_height$$??""),$APP.$cljs$cst$1403$fill$$,"none",$APP.$cljs$cst$266$id$$,"base-background"],null),$APP.$cljs$cst$1620$hidden$$,!0,$APP.$cljs$cst$1637$content$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null);$background$jscomp$8_svg_data__$3_vb_x$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($center_QMARK_$jscomp$1_svg_data__$2_vec__66963$$,
$cljs$cst$2727$defs$$,$def_nodes_def_nodes__$1_svg_data$jscomp$4_svg_data__$1$$),$APP.$cljs$cst$1637$content$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$background$jscomp$8_svg_data__$3_vb_x$$],null),$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($center_QMARK_$jscomp$1_svg_data__$2_vec__66963$$)));$id$jscomp$510_root_shape$jscomp$3$$=$app$common$files$shapes_builder$create_svg_root$$.$cljs$core$IFn$_invoke$arity$4$?
$app$common$files$shapes_builder$create_svg_root$$.$cljs$core$IFn$_invoke$arity$4$($id$jscomp$510_root_shape$jscomp$3$$,$all_defs_from_children_frame_id$jscomp$54_root_shape_with_defs$$,$parent_id$jscomp$65_root_id$jscomp$4$$,$background$jscomp$8_svg_data__$3_vb_x$$):$app$common$files$shapes_builder$create_svg_root$$($id$jscomp$510_root_shape$jscomp$3$$,$all_defs_from_children_frame_id$jscomp$54_root_shape_with_defs$$,$parent_id$jscomp$65_root_id$jscomp$4$$,$background$jscomp$8_svg_data__$3_vb_x$$);
$parent_id$jscomp$65_root_id$jscomp$4$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$510_root_shape$jscomp$3$$);var $root_attrs$jscomp$1$$=$app$common$svg$format_styles$$($APP.$cljs$cst$2645$attrs$$.$cljs$core$IFn$_invoke$arity$1$($background$jscomp$8_svg_data__$3_vb_x$$));$children$jscomp$212_objects$jscomp$358_vec__66966$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$files$shapes_builder$create_svg_children$$,
$children$jscomp$212_objects$jscomp$358_vec__66966$$,$selected$jscomp$35$$,$all_defs_from_children_frame_id$jscomp$54_root_shape_with_defs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$parent_id$jscomp$65_root_id$jscomp$4$$,$background$jscomp$8_svg_data__$3_vb_x$$])),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$map__66959__$1_p__66958_unames$jscomp$7_vec__66960$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66944_SHARP_$$){return $app$common$svg$inherit_attributes$$($root_attrs$jscomp$1$$,
$p1__66944_SHARP_$$)},$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($background$jscomp$8_svg_data__$3_vb_x$$))));$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$212_objects$jscomp$358_vec__66966$$,0,null);$children$jscomp$212_objects$jscomp$358_vec__66966$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$212_objects$jscomp$358_vec__66966$$,1,null);$all_defs_from_children_frame_id$jscomp$54_root_shape_with_defs$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$127$$,
$child$jscomp$89_temp__5823__auto__$jscomp$172$$){$child$jscomp$89_temp__5823__auto__$jscomp$172$$=$cljs$cst$2943$svg_defs$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$89_temp__5823__auto__$jscomp$172$$);return $APP.$cljs$core$truth_$$($child$jscomp$89_temp__5823__auto__$jscomp$172$$)?$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$acc$jscomp$127$$,$child$jscomp$89_temp__5823__auto__$jscomp$172$$])):$acc$jscomp$127$$},
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$children$jscomp$212_objects$jscomp$358_vec__66966$$);$all_defs_from_children_frame_id$jscomp$54_root_shape_with_defs$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($id$jscomp$510_root_shape$jscomp$3$$,$cljs$cst$2943$svg_defs$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$def_nodes_def_nodes__$1_svg_data$jscomp$4_svg_data__$1$$,$all_defs_from_children_frame_id$jscomp$54_root_shape_with_defs$$])));
return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$all_defs_from_children_frame_id$jscomp$54_root_shape_with_defs$$,$children$jscomp$212_objects$jscomp$358_vec__66966$$],null)};
$app$common$files$shapes_builder$create_svg_root$$=function($id$jscomp$511$$,$frame_id$jscomp$56$$,$parent_id$jscomp$66$$,$p__66980_x$jscomp$1177$$){var $attrs$jscomp$87_map__66981__$1_props$jscomp$155$$=$APP.$cljs$core$__destructure_map$$($p__66980_x$jscomp$1177$$);$p__66980_x$jscomp$1177$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$87_map__66981__$1_props$jscomp$155$$,$APP.$cljs$cst$1510$x$$);var $height$jscomp$95$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$87_map__66981__$1_props$jscomp$155$$,
$APP.$cljs$cst$1522$height$$),$y$jscomp$413$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$87_map__66981__$1_props$jscomp$155$$,$APP.$cljs$cst$1511$y$$),$offset_y$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$87_map__66981__$1_props$jscomp$155$$,$APP.$cljs$cst$1651$offset_y$$),$name$jscomp$301$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$87_map__66981__$1_props$jscomp$155$$,$APP.$cljs$cst$725$name$$),$width$jscomp$106$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$87_map__66981__$1_props$jscomp$155$$,$APP.$cljs$cst$290$width$$),$defs$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$87_map__66981__$1_props$jscomp$155$$,$cljs$cst$2727$defs$$),$offset_x$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$87_map__66981__$1_props$jscomp$155$$,$APP.$cljs$cst$1650$offset_x$$);$attrs$jscomp$87_map__66981__$1_props$jscomp$155$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$87_map__66981__$1_props$jscomp$155$$,
$APP.$cljs$cst$2645$attrs$$);$attrs$jscomp$87_map__66981__$1_props$jscomp$155$$=$app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$without_keys$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($attrs$jscomp$87_map__66981__$1_props$jscomp$155$$,$cljs$cst$2880$viewBox$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3671$view_box$$,$cljs$cst$3672$xmlns$$])),$app$common$svg$inheritable_props$$));return $APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,
$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1619$parent_id$$,$cljs$cst$2943$svg_defs$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1522$height$$],[$y$jscomp$413$$+$offset_y$jscomp$4$$,$name$jscomp$301$$,$width$jscomp$106$$,$APP.$cljs$cst$1608$group$$,$attrs$jscomp$87_map__66981__$1_props$jscomp$155$$,$id$jscomp$511$$,$parent_id$jscomp$66$$,$defs$jscomp$8$$,$frame_id$jscomp$56$$,
$p__66980_x$jscomp$1177$$+$offset_x$jscomp$4$$,$height$jscomp$95$$]))};
$app$common$files$shapes_builder$stroke_only_svg_path_QMARK_$$=function($attrs$jscomp$89$$){var $attr_fill$jscomp$1$$=function(){var $G__67009$$=$APP.$cljs$cst$1403$fill$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$89$$);return $G__67009$$==null?null:$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($G__67009$$)}(),$style_fill$jscomp$1$$=function(){var $G__67010$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$89$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1904$style$$,$APP.$cljs$cst$1403$fill$$],null));return $G__67010$$==null?null:$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($G__67010$$)}();return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("none",$APP.$cljs$core$truth_$$($attr_fill$jscomp$1$$)?$attr_fill$jscomp$1$$:$style_fill$jscomp$1$$)};
$app$common$files$shapes_builder$create_path_shape$$=function($name$jscomp$303$$,$frame_id$jscomp$59$$,$origin$jscomp$29_svg_data$jscomp$9$$,$map__67013__$1_p__67012_transform$jscomp$83$$){$map__67013__$1_p__67012_transform$jscomp$83$$=$APP.$cljs$core$__destructure_map$$($map__67013__$1_p__67012_transform$jscomp$83$$);var $attrs$jscomp$90_attrs__$1$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67013__$1_p__67012_transform$jscomp$83$$,$APP.$cljs$cst$2645$attrs$$);if($APP.$cljs$core$contains_QMARK_$$($attrs$jscomp$90_attrs__$1$jscomp$11$$,
$cljs$cst$1447$d$$)&&$APP.$cljs$core$seq$$($cljs$cst$1447$d$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$90_attrs__$1$jscomp$11$$))){$map__67013__$1_p__67012_transform$jscomp$83$$=$app$common$svg$parse_transform$$($APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$90_attrs__$1$jscomp$11$$));var $G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$=
$app$common$files$shapes_builder$stroke_only_svg_path_QMARK_$$($attrs$jscomp$90_attrs__$1$jscomp$11$$);var $G__67014$jscomp$inline_6542_data$jscomp$inline_12404_selrect$jscomp$45$$=$cljs$cst$1447$d$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$90_attrs__$1$jscomp$11$$);$G__67014$jscomp$inline_6542_data$jscomp$inline_12404_selrect$jscomp$45$$=$app$common$types$path$impl$from_string$$($G__67014$jscomp$inline_6542_data$jscomp$inline_12404_selrect$jscomp$45$$);$G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$?
($G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$=$app$common$types$path$subpath$get_subpaths$$($G__67014$jscomp$inline_6542_data$jscomp$inline_12404_selrect$jscomp$45$$),$G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$path$subpath$join_adjacent$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$),$G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$common$types$path$subpath$xf_mapcat_data$$,$G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$),$G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$=
$APP.$app$common$types$path$impl$from_plain$$($G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$)):$G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$=$G__67014$jscomp$inline_6542_data$jscomp$inline_12404_selrect$jscomp$45$$;
$G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$=$map__67013__$1_p__67012_transform$jscomp$83$$!=null?$app$common$types$path$segment$transform_content$$($G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$,$map__67013__$1_p__67012_transform$jscomp$83$$):
$G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$;$G__67014$jscomp$inline_6542_data$jscomp$inline_12404_selrect$jscomp$45$$=$app$common$types$path$segment$content__GT_selrect$$($G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$);
var $points$jscomp$59$$=$APP.$app$common$geom$rect$rect__GT_points$$($G__67014$jscomp$inline_6542_data$jscomp$inline_12404_selrect$jscomp$45$$);$origin$jscomp$29_svg_data$jscomp$9$$=$APP.$app$common$geom$point$negate$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($origin$jscomp$29_svg_data$jscomp$9$$));$attrs$jscomp$90_attrs__$1$jscomp$11$$=$app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($attrs$jscomp$90_attrs__$1$jscomp$11$$,
$cljs$cst$1447$d$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1289$transform$$])));return $APP.$app$common$geom$shapes$translate_to_frame$$($APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$cst$1604$points$$,$cljs$cst$2965$svg_transform$$,$cljs$cst$1893$svg_viewbox$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1636$strokes$$,
$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1634$fills$$],[$G__67014__$1$jscomp$inline_6543_JSCompiler_inline_result$jscomp$14051_JSCompiler_temp$jscomp$14050_content$jscomp$160_merged$jscomp$inline_14353_stroke_only_QMARK__subpaths$jscomp$inline_14352$$,$name$jscomp$303$$,$APP.$cljs$cst$296$path$$,$attrs$jscomp$90_attrs__$1$jscomp$11$$,$points$jscomp$59$$,$map__67013__$1_p__67012_transform$jscomp$83$$,$G__67014$jscomp$inline_6542_data$jscomp$inline_12404_selrect$jscomp$45$$,$frame_id$jscomp$59$$,
$APP.$cljs$core$PersistentVector$EMPTY$$,$G__67014$jscomp$inline_6542_data$jscomp$inline_12404_selrect$jscomp$45$$,$APP.$cljs$core$PersistentVector$EMPTY$$])),$origin$jscomp$29_svg_data$jscomp$9$$)}return null};
$app$common$files$shapes_builder$calculate_rect_metadata$$=function($points$jscomp$60_rect$jscomp$35$$,$selrect$jscomp$46_transform$jscomp$84$$){$points$jscomp$60_rect$jscomp$35$$=$app$common$geom$shapes$transform_points$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$rect$rect__GT_points$$($points$jscomp$60_rect$jscomp$35$$),$selrect$jscomp$46_transform$jscomp$84$$);var $center$jscomp$41_transform__$1$jscomp$6$$=$APP.$app$common$geom$shapes$common$points__GT_center$$($points$jscomp$60_rect$jscomp$35$$);
$selrect$jscomp$46_transform$jscomp$84$$=$app$common$geom$shapes$transforms$calculate_selrect$$($points$jscomp$60_rect$jscomp$35$$,$center$jscomp$41_transform__$1$jscomp$6$$);$center$jscomp$41_transform__$1$jscomp$6$$=$app$common$geom$shapes$transforms$calculate_transform$$($points$jscomp$60_rect$jscomp$35$$,$center$jscomp$41_transform__$1$jscomp$6$$,$selrect$jscomp$46_transform$jscomp$84$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$46_transform$jscomp$84$$),
$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$46_transform$jscomp$84$$),$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$46_transform$jscomp$84$$),$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$46_transform$jscomp$84$$),$APP.$cljs$cst$1605$selrect$$,$selrect$jscomp$46_transform$jscomp$84$$,$APP.$cljs$cst$1604$points$$,$points$jscomp$60_rect$jscomp$35$$,
$APP.$cljs$cst$1289$transform$$,$center$jscomp$41_transform__$1$jscomp$6$$,$APP.$cljs$cst$1787$transform_inverse$$,$center$jscomp$41_transform__$1$jscomp$6$$!=null?$app$common$geom$matrix$inverse$$($center$jscomp$41_transform__$1$jscomp$6$$):null],null)};
$app$common$files$shapes_builder$parse_rect_attrs$$=function($p__67016_x$jscomp$1179$$){var $height$jscomp$97_map__67017__$1$$=$APP.$cljs$core$__destructure_map$$($p__67016_x$jscomp$1179$$);$p__67016_x$jscomp$1179$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$97_map__67017__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$415$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$97_map__67017__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$108$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$97_map__67017__$1$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$97_map__67017__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$97_map__67017__$1$$,$APP.$cljs$cst$1522$height$$);return $APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($p__67016_x$jscomp$1179$$,0),$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($y$jscomp$415$$,0),$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($width$jscomp$108$$,
1),$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$97_map__67017__$1$$,1))};
$app$common$files$shapes_builder$setup_fill$$=function($shape$jscomp$451$$){var $G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$451$$,$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1403$fill$$)),$color_attr__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$,
"currentColor")?"#000000":$G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$;$G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$451$$,$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1904$style$$),$APP.$cljs$cst$1403$fill$$));var $color_style__$1$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$,"currentColor")?"#000000":$G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$;$G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$=$APP.$app$common$types$color$color_string_QMARK_$$($color_attr__$1$$)?$APP.$cljs$core$assoc_in$$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$451$$,
$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1403$fill$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$cst$1904$style$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1403$fill$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1634$fills$$,0,$APP.$cljs$cst$1746$fill_color$$],null),$APP.$app$common$types$color$parse$$($color_attr__$1$$)):
$shape$jscomp$451$$;$G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$=$APP.$app$common$types$color$color_string_QMARK_$$($color_style__$1$$)?$APP.$cljs$core$assoc_in$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$cst$1904$style$$],
null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1403$fill$$),$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1403$fill$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1634$fills$$,0,$APP.$cljs$cst$1746$fill_color$$],null),$APP.$app$common$types$color$parse$$($color_style__$1$$)):$G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$;$G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$430$$=
$APP.$app$common$types$color$color_string_QMARK_$$($color_attr__$1$$)||$APP.$app$common$types$color$color_string_QMARK_$$($color_style__$1$$);return $and__5023__auto__$jscomp$430$$?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$451$$,$APP.$cljs$cst$1890$svg_attrs$$),$cljs$cst$3042$fillOpacity$$):$and__5023__auto__$jscomp$430$$}())?$APP.$cljs$core$assoc_in$$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$,
$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$core$dissoc$$,$cljs$cst$3042$fillOpacity$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$cst$1904$style$$],null),$APP.$cljs$core$dissoc$$,$cljs$cst$3042$fillOpacity$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1634$fills$$,0,$APP.$cljs$cst$1747$fill_opacity$$],null),$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$451$$,
$APP.$cljs$cst$1890$svg_attrs$$),$cljs$cst$3042$fillOpacity$$),1)):$G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$;return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$431$$=$APP.$app$common$types$color$color_string_QMARK_$$($color_attr__$1$$)||$APP.$app$common$types$color$color_string_QMARK_$$($color_style__$1$$);return $and__5023__auto__$jscomp$431$$?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$451$$,
$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1904$style$$),$cljs$cst$3042$fillOpacity$$):$and__5023__auto__$jscomp$431$$}())?$APP.$cljs$core$assoc_in$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$cst$1904$style$$],null),$APP.$cljs$core$dissoc$$,
$cljs$cst$3042$fillOpacity$$),$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$core$dissoc$$,$cljs$cst$3042$fillOpacity$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1634$fills$$,0,$APP.$cljs$cst$1747$fill_opacity$$],null),$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$451$$,
$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1904$style$$),$cljs$cst$3042$fillOpacity$$),1)):$G__67047__$1_G__67047__$2_G__67047__$3_color_attr_color_style$$};
$app$common$files$shapes_builder$setup_stroke$$=function($shape$jscomp$452$$){var $attrs$jscomp$96$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$452$$,$APP.$cljs$cst$1890$svg_attrs$$),$style$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$96$$,$APP.$cljs$cst$1904$style$$),$G__67057__$4_linecap__$1_stroke$jscomp$13$$=function(){var $or__5025__auto__$jscomp$721$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2903$stroke$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$96$$));
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$721$$)?$or__5025__auto__$jscomp$721$$:$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2903$stroke$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$38$$))}(),$color$jscomp$52$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__67057__$4_linecap__$1_stroke$jscomp$13$$,"currentColor")?"#000000":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__67057__$4_linecap__$1_stroke$jscomp$13$$,"none")?null:$APP.$app$common$types$color$color_string_QMARK_$$($G__67057__$4_linecap__$1_stroke$jscomp$13$$)?
$APP.$app$common$types$color$parse$$($G__67057__$4_linecap__$1_stroke$jscomp$13$$):null,$G__67057__$2_opacity$jscomp$25$$=$color$jscomp$52$$!=null?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $or__5025__auto__$jscomp$722$$=$cljs$cst$3674$strokeOpacity$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$96$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$722$$)?$or__5025__auto__$jscomp$722$$:$cljs$cst$3674$strokeOpacity$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$38$$)}(),
1):null,$G__67057__$3_width$jscomp$109$$=$color$jscomp$52$$!=null?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $or__5025__auto__$jscomp$723$$=$cljs$cst$3675$strokeWidth$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$96$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$723$$)?$or__5025__auto__$jscomp$723$$:$cljs$cst$3675$strokeWidth$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$38$$)}(),1):null,$linecap$$=function(){var $or__5025__auto__$jscomp$724$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$96$$,$cljs$cst$3088$strokeLinecap$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$724$$)?$or__5025__auto__$jscomp$724$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($style$jscomp$38$$,$cljs$cst$3088$strokeLinecap$$)}();$G__67057__$4_linecap__$1_stroke$jscomp$13$$=function(){var $G__67053__$1$$=$linecap$$==null?null:$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($linecap$$);return $G__67053__$1$$==null?
null:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__67053__$1$$)}();var $G__67057_G__67057__$1_attrs__$1$jscomp$12$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$52$$!=null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($attrs$jscomp$96$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3675$strokeWidth$$,$cljs$cst$3674$strokeOpacity$$])):
$attrs$jscomp$96$$,$APP.$cljs$cst$1904$style$$,function($style__$1$jscomp$4$$){return $color$jscomp$52$$!=null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($style__$1$jscomp$4$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3675$strokeWidth$$,$cljs$cst$3674$strokeOpacity$$])):$style__$1$jscomp$4$$}));$G__67057_G__67057__$1_attrs__$1$jscomp$12$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$452$$,$APP.$cljs$cst$1890$svg_attrs$$,
$G__67057_G__67057__$1_attrs__$1$jscomp$12$$);$G__67057_G__67057__$1_attrs__$1$jscomp$12$$=$color$jscomp$52$$!=null?$APP.$cljs$core$assoc_in$$($G__67057_G__67057__$1_attrs__$1$jscomp$12$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$,0,$APP.$cljs$cst$1739$stroke_color$$],null),$color$jscomp$52$$):$G__67057_G__67057__$1_attrs__$1$jscomp$12$$;$G__67057__$2_opacity$jscomp$25$$=$color$jscomp$52$$!=null&&$G__67057__$2_opacity$jscomp$25$$!=
null?$APP.$cljs$core$assoc_in$$($G__67057_G__67057__$1_attrs__$1$jscomp$12$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$,0,$APP.$cljs$cst$1740$stroke_opacity$$],null),$G__67057__$2_opacity$jscomp$25$$):$G__67057_G__67057__$1_attrs__$1$jscomp$12$$;$G__67057__$3_width$jscomp$109$$=$color$jscomp$52$$!=null&&$G__67057__$3_width$jscomp$109$$!=null?$APP.$cljs$core$assoc_in$$($G__67057__$2_opacity$jscomp$25$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$,0,$APP.$cljs$cst$1655$stroke_width$$],null),$G__67057__$3_width$jscomp$109$$):$G__67057__$2_opacity$jscomp$25$$;$G__67057__$4_linecap__$1_stroke$jscomp$13$$=$G__67057__$4_linecap__$1_stroke$jscomp$13$$!=null&&$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$452$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__67057__$4_linecap__$1_stroke$jscomp$13$$,$APP.$cljs$cst$2012$round$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__67057__$4_linecap__$1_stroke$jscomp$13$$,$APP.$cljs$cst$1933$square$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__67057__$3_width$jscomp$109$$,$APP.$cljs$cst$1865$stroke_cap_start$$,$G__67057__$4_linecap__$1_stroke$jscomp$13$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1869$stroke_cap_end$$,$G__67057__$4_linecap__$1_stroke$jscomp$13$$,$cljs$cst$2917$stroke_linecap$$,$G__67057__$4_linecap__$1_stroke$jscomp$13$$])):
$G__67057__$3_width$jscomp$109$$;return $APP.$cljs$core$truth_$$($app$common$data$any_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$452$$,$APP.$cljs$cst$1636$strokes$$),0)))?$APP.$cljs$core$assoc_in$$($G__67057__$4_linecap__$1_stroke$jscomp$13$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$,
0,$APP.$cljs$cst$1866$stroke_style$$],null),$APP.$cljs$cst$1538$svg$$):$G__67057__$4_linecap__$1_stroke$jscomp$13$$};
$app$common$files$shapes_builder$setup_opacity$$=function($shape$jscomp$453$$){var $G__67070__$1_G__67070__$2_G__67070__$3$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$453$$,$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1734$opacity$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$453$$,$APP.$cljs$cst$1890$svg_attrs$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1734$opacity$$),$APP.$cljs$cst$1734$opacity$$,$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$453$$,$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1734$opacity$$),1)):$shape$jscomp$453$$;$G__67070__$1_G__67070__$2_G__67070__$3$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$453$$,
$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1904$style$$),$APP.$cljs$cst$1734$opacity$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__67070__$1_G__67070__$2_G__67070__$3$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$cst$1904$style$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1734$opacity$$),$APP.$cljs$cst$1734$opacity$$,$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$453$$,
$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1904$style$$),$APP.$cljs$cst$1734$opacity$$),1)):$G__67070__$1_G__67070__$2_G__67070__$3$$;$G__67070__$1_G__67070__$2_G__67070__$3$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$453$$,$APP.$cljs$cst$1890$svg_attrs$$),$cljs$cst$3679$mixBlendMode$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__67070__$1_G__67070__$2_G__67070__$3$$,
$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$core$dissoc$$,$cljs$cst$3679$mixBlendMode$$),$APP.$cljs$cst$1867$blend_mode$$,$app$common$files$shapes_builder$assert_valid_blend_mode$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$453$$,$APP.$cljs$cst$1890$svg_attrs$$),$cljs$cst$3679$mixBlendMode$$))):$G__67070__$1_G__67070__$2_G__67070__$3$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$453$$,
$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1904$style$$),$cljs$cst$3679$mixBlendMode$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__67070__$1_G__67070__$2_G__67070__$3$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$cst$1904$style$$],null),$APP.$cljs$core$dissoc$$,$cljs$cst$3679$mixBlendMode$$),$APP.$cljs$cst$1867$blend_mode$$,
$app$common$files$shapes_builder$assert_valid_blend_mode$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$453$$,$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1904$style$$),$cljs$cst$3679$mixBlendMode$$))):$G__67070__$1_G__67070__$2_G__67070__$3$$};
$app$common$files$shapes_builder$setup_other$$=function($shape$jscomp$454$$){var $G__67074__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$454$$,$APP.$cljs$cst$1890$svg_attrs$$),$APP.$cljs$cst$1932$display$$),"none")?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$454$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$cst$1904$style$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1932$display$$),$APP.$cljs$cst$1620$hidden$$,!0):$shape$jscomp$454$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$454$$,$APP.$cljs$cst$1890$svg_attrs$$),
$APP.$cljs$cst$1904$style$$),$APP.$cljs$cst$1932$display$$),"none")?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__67074__$1$$,$APP.$cljs$cst$1890$svg_attrs$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1932$display$$),$APP.$cljs$cst$1620$hidden$$,!0):$G__67074__$1$$};
$app$common$files$shapes_builder$filter_valid_def_references$$=function($ref_ids$$,$defs$jscomp$10$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67091_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($defs$jscomp$10$$,$p1__67091_SHARP_$$)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($ref_id$jscomp$7$$){var $or__5025__auto__$jscomp$725_or__5025__auto____$1$jscomp$88_or__5025__auto____$2$jscomp$25$$=$app$common$types$color$hex_color_string_QMARK_$$(["#",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ref_id$jscomp$7$$)].join(""));if($or__5025__auto__$jscomp$725_or__5025__auto____$1$jscomp$88_or__5025__auto____$2$jscomp$25$$)return $or__5025__auto__$jscomp$725_or__5025__auto____$1$jscomp$88_or__5025__auto____$2$jscomp$25$$;$or__5025__auto__$jscomp$725_or__5025__auto____$1$jscomp$88_or__5025__auto____$2$jscomp$25$$=$APP.$cuerdas$core$includes_QMARK_$$($ref_id$jscomp$7$$,";");if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$725_or__5025__auto____$1$jscomp$88_or__5025__auto____$2$jscomp$25$$))return $or__5025__auto__$jscomp$725_or__5025__auto____$1$jscomp$88_or__5025__auto____$2$jscomp$25$$;
$or__5025__auto__$jscomp$725_or__5025__auto____$1$jscomp$88_or__5025__auto____$2$jscomp$25$$=$APP.$cuerdas$core$includes_QMARK_$$($ref_id$jscomp$7$$,"stop-opacity");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$725_or__5025__auto____$1$jscomp$88_or__5025__auto____$2$jscomp$25$$)?$or__5025__auto__$jscomp$725_or__5025__auto____$1$jscomp$88_or__5025__auto____$2$jscomp$25$$:$APP.$cuerdas$core$includes_QMARK_$$($ref_id$jscomp$7$$,"stop-color")},$ref_ids$$))};
$app$common$files$shapes_builder$resolve_element_name$$=function($tag$jscomp$69$$,$attrs$jscomp$97_or__5025__auto____$2$jscomp$26$$){var $or__5025__auto__$jscomp$726_or__5025__auto____$1$jscomp$89$$=$cljs$cst$3680$inkscape_COLON_label$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$97_or__5025__auto____$2$jscomp$26$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$726_or__5025__auto____$1$jscomp$89$$))return $or__5025__auto__$jscomp$726_or__5025__auto____$1$jscomp$89$$;$or__5025__auto__$jscomp$726_or__5025__auto____$1$jscomp$89$$=
$cljs$cst$3681$sodipodi_COLON_label$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$97_or__5025__auto____$2$jscomp$26$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$726_or__5025__auto____$1$jscomp$89$$))return $or__5025__auto__$jscomp$726_or__5025__auto____$1$jscomp$89$$;$attrs$jscomp$97_or__5025__auto____$2$jscomp$26$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$97_or__5025__auto____$2$jscomp$26$$);return $APP.$cljs$core$truth_$$($attrs$jscomp$97_or__5025__auto____$2$jscomp$26$$)?
$attrs$jscomp$97_or__5025__auto____$2$jscomp$26$$:"svg-"+((typeof $tag$jscomp$69$$==="string"?$tag$jscomp$69$$:$tag$jscomp$69$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$app$common$data$name$$($tag$jscomp$69$$):$tag$jscomp$69$$==null?"node":""+($tag$jscomp$69$$??""))??"")};
$app$main$data$workspace$svg_upload$extract_name$$=function($filename$jscomp$7_href$jscomp$10_href__$1$$){var $ext_idx_query_idx$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($filename$jscomp$7_href$jscomp$10_href__$1$$,"?");$filename$jscomp$7_href$jscomp$10_href__$1$$=$ext_idx_query_idx$$>0?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($filename$jscomp$7_href$jscomp$10_href__$1$$,0,$ext_idx_query_idx$$):$filename$jscomp$7_href$jscomp$10_href__$1$$;$filename$jscomp$7_href$jscomp$10_href__$1$$=
$APP.$cljs$core$last$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($filename$jscomp$7_href$jscomp$10_href__$1$$,"/"));$ext_idx_query_idx$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($filename$jscomp$7_href$jscomp$10_href__$1$$,".");return $ext_idx_query_idx$$>0?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($filename$jscomp$7_href$jscomp$10_href__$1$$,0,$ext_idx_query_idx$$):$filename$jscomp$7_href$jscomp$10_href__$1$$};
$APP.$app$main$data$workspace$svg_upload$upload_images$$=function($svg_data$jscomp$14$$,$file_id$jscomp$95$$){return $APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$mapcat$$(function($item$jscomp$73$$){return $APP.$beicon$v2$core$map$$(function($p1__67419_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2462$href$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$73$$),
$p1__67419_SHARP_$$],null)},$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return(0,$APP.$beicon$v2$core$of$$)(null)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$contains_QMARK_$$($item$jscomp$73$$,$APP.$cljs$cst$1637$content$$)?$APP.$cljs$cst$2282$upload_file_media_object$$:$APP.$cljs$cst$3682$create_file_media_object_from_url$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$73$$,$APP.$cljs$cst$2462$href$$))))},
$APP.$beicon$v2$core$filter$$(function($item$jscomp$74_url$jscomp$89$$){var $or__5025__auto__$jscomp$728$$=$APP.$cljs$core$contains_QMARK_$$($item$jscomp$74_url$jscomp$89$$,$APP.$cljs$cst$1637$content$$);if($or__5025__auto__$jscomp$728$$)return $or__5025__auto__$jscomp$728$$;$item$jscomp$74_url$jscomp$89$$=$APP.$cljs$cst$1975$url$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$74_url$jscomp$89$$);return $APP.$cuerdas$core$starts_with_QMARK_$$($item$jscomp$74_url$jscomp$89$$,"http://")||$APP.$cuerdas$core$starts_with_QMARK_$$($item$jscomp$74_url$jscomp$89$$,
"https://")},$APP.$beicon$v2$core$map$$(function($href$jscomp$11_p__67429$$){var $item__$1$jscomp$1_map__67430__$1$$=$APP.$cljs$core$__destructure_map$$($href$jscomp$11_p__67429$$);$href$jscomp$11_p__67429$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item__$1$jscomp$1_map__67430__$1$$,$APP.$cljs$cst$2462$href$$);$item__$1$jscomp$1_map__67430__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($item__$1$jscomp$1_map__67430__$1$$,
$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$95$$),$APP.$cljs$cst$2574$is_local$$,!0),$APP.$cljs$cst$725$name$$,"image");return $APP.$cuerdas$core$starts_with_QMARK_$$($href$jscomp$11_p__67429$$,"data:")?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($item__$1$jscomp$1_map__67430__$1$$,$APP.$cljs$cst$1637$content$$,$APP.$app$util$webapi$data_uri__GT_blob$$($href$jscomp$11_p__67429$$)):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($item__$1$jscomp$1_map__67430__$1$$,
$APP.$cljs$cst$725$name$$,$app$main$data$workspace$svg_upload$extract_name$$($href$jscomp$11_p__67429$$)),$APP.$cljs$cst$1975$url$$,$href$jscomp$11_p__67429$$)},$APP.$beicon$v2$core$from$$($app$common$svg$collect_images$$($svg_data$jscomp$14$$))))))};
$APP.$app$main$data$workspace$svg_upload$add_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$=function($id$jscomp$512$$,$svg_data$jscomp$16$$,$position$jscomp$74$$,$p__67440$$){var $map__67441__$1$$=$APP.$cljs$core$__destructure_map$$($p__67440$$),$change_selection_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67441__$1$$,$APP.$cljs$cst$3617$change_selection_QMARK_$$,!0),$ignore_selection_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67441__$1$$,
$APP.$cljs$cst$3683$ignore_selection_QMARK_$$,!1);typeof $app$main$data$workspace$svg_upload$add_svg_shapes_67442$$==="undefined"&&($app$main$data$workspace$svg_upload$add_svg_shapes_67442$$=function($id$jscomp$513$$,$svg_data$jscomp$17$$,$position$jscomp$75$$,$p__67440$jscomp$1$$,$map__67441$jscomp$1$$,$change_selection_QMARK_$jscomp$3$$,$ignore_selection_QMARK_$jscomp$1$$,$meta67443$$){this.id=$id$jscomp$513$$;this.$svg_data$=$svg_data$jscomp$17$$;this.position=$position$jscomp$75$$;this.$p__67440$=
$p__67440$jscomp$1$$;this.$map__67441$=$map__67441$jscomp$1$$;this.$change_selection_QMARK_$=$change_selection_QMARK_$jscomp$3$$;this.$ignore_selection_QMARK_$=$ignore_selection_QMARK_$jscomp$1$$;this.$meta67443$=$meta67443$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$svg_upload$add_svg_shapes_67442$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$svg_upload$add_svg_shapes_67442$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3684$app_DOT_main_DOT_data_DOT_workspace_DOT_svg_upload_SLASH_add_svg_shapes$$},$app$main$data$workspace$svg_upload$add_svg_shapes_67442$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67444$$,$meta67443__$1$$){return new $app$main$data$workspace$svg_upload$add_svg_shapes_67442$$(this.id,this.$svg_data$,this.position,this.$p__67440$,this.$map__67441$,this.$change_selection_QMARK_$,this.$ignore_selection_QMARK_$,$meta67443__$1$$)},$app$main$data$workspace$svg_upload$add_svg_shapes_67442$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67443$},$app$main$data$workspace$svg_upload$add_svg_shapes_67442$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$svg_upload$add_svg_shapes_67442$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($cause$jscomp$78_it$jscomp$160$$,$state$jscomp$405$$){try{var $id__$1$jscomp$6$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$(this.id,$APP.$app$common$uuid$next$$()),$page_id$jscomp$128$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$405$$),
$objects$jscomp$360$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$405$$,$page_id$jscomp$128$$),$selected$jscomp$37$$=$APP.$cljs$core$truth_$$(this.$ignore_selection_QMARK_$)?$APP.$cljs$core$PersistentHashSet$EMPTY$$:$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$405$$),$base$jscomp$35$$=$app$common$files$helpers$get_base_shape$$($objects$jscomp$360$$,$selected$jscomp$37$$),$selected_id$jscomp$2$$=$APP.$cljs$core$first$$($selected$jscomp$37$$),
$selected_frame_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($selected$jscomp$37$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$360$$,$selected_id$jscomp$2$$),$APP.$cljs$cst$139$type$$)),$base_id$jscomp$2$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$35$$),$frame_id$jscomp$64$$=
$selected_frame_QMARK_$$||$APP.$cljs$core$empty_QMARK_$$($selected$jscomp$37$$)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$360$$,$base_id$jscomp$2$$),$APP.$cljs$cst$139$type$$))?$APP.$app$common$types$shape_tree$top_nested_frame$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$360$$,this.position,null,!1):$base_id$jscomp$2$$,$parent_id$jscomp$68$$=
$selected_frame_QMARK_$$||$APP.$cljs$core$empty_QMARK_$$($selected$jscomp$37$$)?$frame_id$jscomp$64$$:$base_id$jscomp$2$$,$vec__67449$$=$APP.$app$common$files$shapes_builder$create_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$08$$($id__$1$jscomp$6$$,this.$svg_data$,this.position,$objects$jscomp$360$$,$frame_id$jscomp$64$$,$parent_id$jscomp$68$$,$selected$jscomp$37$$,!0),$new_shape$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__67449$$,0,null),$new_children$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__67449$$,
1,null),$changes$jscomp$177$$=$APP.$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$page_id$jscomp$128$$),$objects$jscomp$360$$),$new_shape$jscomp$13$$),$changes__$1$jscomp$65$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$66$$,$new_child$jscomp$3$$){return $APP.$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$02$$($changes__$1$jscomp$66$$,
$new_child$jscomp$3$$)},$changes$jscomp$177$$,$new_children$jscomp$4$$),$changes__$2$jscomp$31$$=$APP.$app$common$files$changes_builder$resize_parents$$($changes__$1$jscomp$65$$,$APP.$cljs$core$vec$$($APP.$cljs$core$reverse$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67434_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2610$add_obj$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__67434_SHARP_$$))},
$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes__$1$jscomp$65$$)))))),$undo_id$jscomp$6$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$6$$),$APP.$app$main$data$changes$commit_changes$$($changes__$2$jscomp$31$$),$APP.$cljs$core$truth_$$(this.$change_selection_QMARK_$)?$APP.$app$main$data$workspace$selection$select_shapes$$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$13$$))):
null,$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$13$$)],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$6$$))}catch($e67445$$){return $cause$jscomp$78_it$jscomp$160$$=
$e67445$$,console.error($cause$jscomp$78_it$jscomp$160$$),$APP.$beicon$v2$core$throw$0$$($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$ex_message$$($cause$jscomp$78_it$jscomp$160$$),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$3376$svg_parser$$,$APP.$cljs$cst$275$hint$$,$APP.$cljs$core$ex_message$$($cause$jscomp$78_it$jscomp$160$$)],
null),null])),null))}});return new $app$main$data$workspace$svg_upload$add_svg_shapes_67442$$($id$jscomp$512$$,$svg_data$jscomp$16$$,$position$jscomp$74$$,$p__67440$$,$map__67441__$1$$,$change_selection_QMARK_$jscomp$2$$,$ignore_selection_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$tubax$core$push_node$$=function($map__67112__$1_p__67111$$,$attrs$jscomp$inline_12445_attrs__$1$jscomp$inline_12446_new_current$jscomp$1_node$jscomp$302$$){$map__67112__$1_p__67111$$=$APP.$cljs$core$__destructure_map$$($map__67112__$1_p__67111$$);var $new_stack_stack$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67112__$1_p__67111$$,$APP.$cljs$cst$3685$stack$$),$current$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67112__$1_p__67111$$,$cljs$cst$1401$current$$),
$G__67110$jscomp$inline_12444_map__67109__$1$jscomp$inline_12441_tag$jscomp$inline_12443$$=$APP.$cljs$core$__destructure_map$$(null),$keywordize_keys$jscomp$inline_12442$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($G__67110$jscomp$inline_12444_map__67109__$1$jscomp$inline_12441_tag$jscomp$inline_12443$$,$APP.$cljs$cst$127$keywordize_keys$$,!0);$G__67110$jscomp$inline_12444_map__67109__$1$jscomp$inline_12441_tag$jscomp$inline_12443$$=$attrs$jscomp$inline_12445_attrs__$1$jscomp$inline_12446_new_current$jscomp$1_node$jscomp$302$$.name;
$G__67110$jscomp$inline_12444_map__67109__$1$jscomp$inline_12441_tag$jscomp$inline_12443$$=$APP.$cljs$core$truth_$$($keywordize_keys$jscomp$inline_12442$$)?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__67110$jscomp$inline_12444_map__67109__$1$jscomp$inline_12441_tag$jscomp$inline_12443$$):$G__67110$jscomp$inline_12444_map__67109__$1$jscomp$inline_12441_tag$jscomp$inline_12443$$;$attrs$jscomp$inline_12445_attrs__$1$jscomp$inline_12446_new_current$jscomp$1_node$jscomp$302$$=$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($attrs$jscomp$inline_12445_attrs__$1$jscomp$inline_12446_new_current$jscomp$1_node$jscomp$302$$.attributes,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,$keywordize_keys$jscomp$inline_12442$$]));$attrs$jscomp$inline_12445_attrs__$1$jscomp$inline_12446_new_current$jscomp$1_node$jscomp$302$$=$APP.$cljs$core$empty_QMARK_$$($attrs$jscomp$inline_12445_attrs__$1$jscomp$inline_12446_new_current$jscomp$1_node$jscomp$302$$)?null:$attrs$jscomp$inline_12445_attrs__$1$jscomp$inline_12446_new_current$jscomp$1_node$jscomp$302$$;$attrs$jscomp$inline_12445_attrs__$1$jscomp$inline_12446_new_current$jscomp$1_node$jscomp$302$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$G__67110$jscomp$inline_12444_map__67109__$1$jscomp$inline_12441_tag$jscomp$inline_12443$$,$APP.$cljs$cst$2645$attrs$$,$attrs$jscomp$inline_12445_attrs__$1$jscomp$inline_12446_new_current$jscomp$1_node$jscomp$302$$,$APP.$cljs$cst$1637$content$$,null],null);$new_stack_stack$jscomp$25$$=$current$jscomp$41$$!=null?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($new_stack_stack$jscomp$25$$,$current$jscomp$41$$):$new_stack_stack$jscomp$25$$;
return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__67112__$1_p__67111$$,$APP.$cljs$cst$3685$stack$$,$new_stack_stack$jscomp$25$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$1401$current$$,$attrs$jscomp$inline_12445_attrs__$1$jscomp$inline_12446_new_current$jscomp$1_node$jscomp$302$$]))};
$tubax$core$pop_node$$=function($map__67118__$1_p__67117$$,$new_stack$jscomp$1_node$jscomp$303$$){$map__67118__$1_p__67117$$=$APP.$cljs$core$__destructure_map$$($map__67118__$1_p__67117$$);var $new_current$jscomp$2_stack$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67118__$1_p__67117$$,$APP.$cljs$cst$3685$stack$$),$current$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67118__$1_p__67117$$,$cljs$cst$1401$current$$);$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($new_stack$jscomp$1_node$jscomp$303$$);
if($APP.$cljs$core$empty_QMARK_$$($new_current$jscomp$2_stack$jscomp$26$$))return $map__67118__$1_p__67117$$;$new_stack$jscomp$1_node$jscomp$303$$=$APP.$cljs$core$pop$$($new_current$jscomp$2_stack$jscomp$26$$);$new_current$jscomp$2_stack$jscomp$26$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$peek$$($new_current$jscomp$2_stack$jscomp$26$$),$APP.$cljs$cst$1637$content$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$),
$current$jscomp$42$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__67118__$1_p__67117$$,$APP.$cljs$cst$3685$stack$$,$new_stack$jscomp$1_node$jscomp$303$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$1401$current$$,$new_current$jscomp$2_stack$jscomp$26$$]))};
$tubax$core$push_text$$=function($document$jscomp$6$$,$text$jscomp$44$$){return $APP.$cljs$core$empty_QMARK_$$($text$jscomp$44$$)?$document$jscomp$6$$:$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($document$jscomp$6$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1401$current$$,$APP.$cljs$cst$1637$content$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$),
$text$jscomp$44$$)};
$tubax$core$create_parser$$=function(){var $map__67121__$1_strict_entities$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$strict$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67121__$1_strict_entities$$,$cljs$cst$967$strict$$,!0),$trim$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67121__$1_strict_entities$$,$APP.$cljs$cst$3686$trim$$,!0),$normalize$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67121__$1_strict_entities$$,$cljs$cst$3687$normalize$$,
!1),$lowercase$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67121__$1_strict_entities$$,$cljs$cst$3688$lowercase$$,!0),$xmlns$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67121__$1_strict_entities$$,$cljs$cst$3672$xmlns$$),$position$jscomp$76$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67121__$1_strict_entities$$,$APP.$cljs$cst$1676$position$$,!0);$map__67121__$1_strict_entities$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67121__$1_strict_entities$$,
$cljs$cst$3689$strict_entities$$,!1);return $shadow$js$shim$module$0sax$$.parser($strict$jscomp$1$$,{trim:$trim$$,normalize:$normalize$jscomp$1$$,lowercase:$lowercase$$,xmlns:$xmlns$$,position:$position$jscomp$76$$,strictEntities:$map__67121__$1_strict_entities$$})};
$tubax$core$xml__GT_clj$cljs$0core$0IFn$0_invoke$0arity$02$$=function($or__5025__auto__$jscomp$729_source$jscomp$46$$){var $parser$jscomp$13$$=$tubax$core$create_parser$$(),$document__$1$jscomp$4$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3685$stack$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$cljs$cst$1401$current$$,null],null)),$result$jscomp$275$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$parser$jscomp$13$$.onopentag=
function($p1__67123_SHARP_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($document__$1$jscomp$4$$,$tubax$core$push_node$$,$p1__67123_SHARP_$$)};$parser$jscomp$13$$.onclosetag=function($p1__67124_SHARP_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($document__$1$jscomp$4$$,$tubax$core$pop_node$$,$p1__67124_SHARP_$$)};$parser$jscomp$13$$.ontext=function($p1__67125_SHARP_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($document__$1$jscomp$4$$,
$tubax$core$push_text$$,$p1__67125_SHARP_$$)};$parser$jscomp$13$$.oncdata=function($p1__67126_SHARP_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($document__$1$jscomp$4$$,$tubax$core$push_text$$,$p1__67126_SHARP_$$)};$parser$jscomp$13$$.onend=function(){return $APP.$cljs$core$_deref$$($result$jscomp$275$$)!=null?null:$APP.$cljs$core$reset_BANG_$$($result$jscomp$275$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2344$success$$,$cljs$cst$1401$current$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($document__$1$jscomp$4$$))],
null))};$parser$jscomp$13$$.onerror=function($p1__67129_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($result$jscomp$275$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__67129_SHARP_$$)],null))};$parser$jscomp$13$$.write($or__5025__auto__$jscomp$729_source$jscomp$46$$);$parser$jscomp$13$$.close();$or__5025__auto__$jscomp$729_source$jscomp$46$$=$APP.$cljs$cst$2344$success$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($result$jscomp$275$$));
if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$729_source$jscomp$46$$))return $or__5025__auto__$jscomp$729_source$jscomp$46$$;throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($result$jscomp$275$$))),$APP.$cljs$core$PersistentArrayMap$EMPTY$$);};
$APP.$app$main$data$workspace$media$svg__GT_clj$$=function($p__67680_text$jscomp$45$$){var $cause$jscomp$79_name$jscomp$308$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67680_text$jscomp$45$$,0,null);$p__67680_text$jscomp$45$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67680_text$jscomp$45$$,1,null);try{var $text__$1$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1244$frontend_svgo$$)?$shadow$js$shim$module$0$0penpot$0svgo$0default$$.optimize($p__67680_text$jscomp$45$$,
$shadow$js$shim$module$0$0penpot$0svgo$0default$$.defaultOptions):$p__67680_text$jscomp$45$$,$data$jscomp$325$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($tubax$core$xml__GT_clj$cljs$0core$0IFn$0_invoke$0arity$02$$($text__$1$$),$APP.$cljs$cst$725$name$$,$cause$jscomp$79_name$jscomp$308$$);return(0,$APP.$beicon$v2$core$of$$)($data$jscomp$325$$)}catch($e67685$$){return $cause$jscomp$79_name$jscomp$308$$=$e67685$$,console.error($cause$jscomp$79_name$jscomp$308$$),$APP.$beicon$v2$core$throw$0$$($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$ex_message$$($cause$jscomp$79_name$jscomp$308$$),
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$3376$svg_parser$$,$APP.$cljs$cst$275$hint$$,$APP.$cljs$core$ex_message$$($cause$jscomp$79_name$jscomp$308$$)],null),null])),null))}};
$app$main$data$workspace$media$image_uploaded$$=function($image$jscomp$21$$,$p__67691$$){var $map__67694__$1$$=$APP.$cljs$core$__destructure_map$$($p__67691$$),$x$jscomp$1180$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67694__$1$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$416$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67694__$1$$,$APP.$cljs$cst$1511$y$$);typeof $app$main$data$workspace$media$image_uploaded_67695$$==="undefined"&&($app$main$data$workspace$media$image_uploaded_67695$$=
function($image$jscomp$22$$,$p__67691$jscomp$1$$,$map__67694$jscomp$1$$,$x$jscomp$1181$$,$y$jscomp$417$$,$meta67696$$){this.image=$image$jscomp$22$$;this.$p__67691$=$p__67691$jscomp$1$$;this.$map__67694$=$map__67694$jscomp$1$$;this.x=$x$jscomp$1181$$;this.y=$y$jscomp$417$$;this.$meta67696$=$meta67696$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$media$image_uploaded_67695$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$media$image_uploaded_67695$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3690$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_image_uploaded$$},$app$main$data$workspace$media$image_uploaded_67695$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67697$$,$meta67696__$1$$){return new $app$main$data$workspace$media$image_uploaded_67695$$(this.image,this.$p__67691$,this.$map__67694$,this.x,this.y,$meta67696__$1$$)},$app$main$data$workspace$media$image_uploaded_67695$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67696$},$app$main$data$workspace$media$image_uploaded_67695$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$image_uploaded_67695$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__67708__$1_mtype$jscomp$16$$=$APP.$cljs$core$__destructure_map$$(this.image),$JSCompiler_inline_result$jscomp$1119_name$jscomp$309_shape$jscomp$456$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67708__$1_mtype$jscomp$16$$,
$APP.$cljs$cst$725$name$$),$width$jscomp$110$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67708__$1_mtype$jscomp$16$$,$APP.$cljs$cst$290$width$$),$height$jscomp$98$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67708__$1_mtype$jscomp$16$$,$APP.$cljs$cst$1522$height$$),$fills$jscomp$21_id$jscomp$514$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67708__$1_mtype$jscomp$16$$,$APP.$cljs$cst$266$id$$);$map__67708__$1_mtype$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67708__$1_mtype$jscomp$16$$,
$APP.$cljs$cst$1726$mtype$$);$fills$jscomp$21_id$jscomp$514$$=$APP.$app$common$types$fills$create$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1747$fill_opacity$$,1,$APP.$cljs$cst$1632$fill_image$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$290$width$$,$width$jscomp$110$$,$APP.$cljs$cst$1522$height$$,$height$jscomp$98$$,$APP.$cljs$cst$1726$mtype$$,$map__67708__$1_mtype$jscomp$16$$,
$APP.$cljs$cst$266$id$$,$fills$jscomp$21_id$jscomp$514$$,$APP.$cljs$cst$1727$keep_aspect_ratio$$,!0],null)],null)]));$JSCompiler_inline_result$jscomp$1119_name$jscomp$309_shape$jscomp$456$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$725$name$$,$JSCompiler_inline_result$jscomp$1119_name$jscomp$309_shape$jscomp$456$$,$APP.$cljs$cst$290$width$$,$width$jscomp$110$$,$APP.$cljs$cst$1522$height$$,$height$jscomp$98$$,$APP.$cljs$cst$1510$x$$,$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$(this.x-
$width$jscomp$110$$/2),$APP.$cljs$cst$1511$y$$,$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$(this.y-$height$jscomp$98$$/2),$APP.$cljs$cst$1634$fills$$,$fills$jscomp$21_id$jscomp$514$$],null);$JSCompiler_inline_result$jscomp$1119_name$jscomp$309_shape$jscomp$456$$=$app$main$data$workspace$shapes$create_and_add_shape$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$cljs$cst$1611$rect$$,this.x,this.y,$JSCompiler_inline_result$jscomp$1119_name$jscomp$309_shape$jscomp$456$$,null);return(0,$APP.$beicon$v2$core$of$$)($JSCompiler_inline_result$jscomp$1119_name$jscomp$309_shape$jscomp$456$$)});
return new $app$main$data$workspace$media$image_uploaded_67695$$($image$jscomp$21$$,$p__67691$$,$map__67694__$1$$,$x$jscomp$1180$$,$y$jscomp$416$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$media$svg_uploaded$$=function($svg_data$jscomp$18$$,$file_id$jscomp$96$$,$position$jscomp$77$$){typeof $app$main$data$workspace$media$svg_uploaded_67710$$==="undefined"&&($app$main$data$workspace$media$svg_uploaded_67710$$=function($svg_data$jscomp$19$$,$file_id$jscomp$97$$,$position$jscomp$78$$,$meta67711$$){this.$svg_data$=$svg_data$jscomp$19$$;this.$file_id$=$file_id$jscomp$97$$;this.position=$position$jscomp$78$$;this.$meta67711$=$meta67711$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$media$svg_uploaded_67710$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$svg_uploaded_67710$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3691$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_svg_uploaded$$},$app$main$data$workspace$media$svg_uploaded_67710$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67712$$,$meta67711__$1$$){return new $app$main$data$workspace$media$svg_uploaded_67710$$(this.$svg_data$,
this.$file_id$,this.position,$meta67711__$1$$)},$app$main$data$workspace$media$svg_uploaded_67710$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67711$},$app$main$data$workspace$media$svg_uploaded_67710$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$svg_uploaded_67710$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$4400$$=this;return $APP.$beicon$v2$core$map$$(function($p1__67709_SHARP__svg_data$jscomp$inline_6637$$){$p1__67709_SHARP__svg_data$jscomp$inline_6637$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$4400$$.$svg_data$,$APP.$cljs$cst$3673$image_data$$,$p1__67709_SHARP__svg_data$jscomp$inline_6637$$);return $APP.$app$main$data$workspace$svg_upload$add_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$(null,$p1__67709_SHARP__svg_data$jscomp$inline_6637$$,$self__$jscomp$4400$$.position,null)},$APP.$app$main$data$workspace$svg_upload$upload_images$$($self__$jscomp$4400$$.$svg_data$,$self__$jscomp$4400$$.$file_id$))});return new $app$main$data$workspace$media$svg_uploaded_67710$$($svg_data$jscomp$18$$,
$file_id$jscomp$96$$,$position$jscomp$77$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$media$upload_blob_chunked$$=function($blob$jscomp$25_map__67716__$1_p__67715$$){$blob$jscomp$25_map__67716__$1_p__67715$$=$APP.$cljs$core$__destructure_map$$($blob$jscomp$25_map__67716__$1_p__67715$$);var $file_id$jscomp$99$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($blob$jscomp$25_map__67716__$1_p__67715$$,$APP.$cljs$cst$1644$file_id$$),$name$jscomp$311$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($blob$jscomp$25_map__67716__$1_p__67715$$,$APP.$cljs$cst$725$name$$),
$is_local$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($blob$jscomp$25_map__67716__$1_p__67715$$,$APP.$cljs$cst$2574$is_local$$);$blob$jscomp$25_map__67716__$1_p__67715$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($blob$jscomp$25_map__67716__$1_p__67715$$,$APP.$cljs$cst$1591$blob$$);var $mtype$jscomp$17$$=$blob$jscomp$25_map__67716__$1_p__67715$$.type;return $APP.$beicon$v2$core$mapcat$$(function($map__67718__$1_p__67717_session_id$jscomp$6$$){$map__67718__$1_p__67717_session_id$jscomp$6$$=
$APP.$cljs$core$__destructure_map$$($map__67718__$1_p__67717_session_id$jscomp$6$$);$map__67718__$1_p__67717_session_id$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67718__$1_p__67717_session_id$jscomp$6$$,$APP.$cljs$cst$2332$session_id$$);return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3692$assemble_file_media_object$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2332$session_id$$,$map__67718__$1_p__67717_session_id$jscomp$6$$,
$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$99$$,$APP.$cljs$cst$2574$is_local$$,$is_local$$,$APP.$cljs$cst$725$name$$,$name$jscomp$311$$,$APP.$cljs$cst$1726$mtype$$,$mtype$jscomp$17$$],null))},$app$main$data$uploads$upload_blob_chunked$$($blob$jscomp$25_map__67716__$1_p__67715$$))};
$app$main$data$workspace$media$process_uris$$=function($p__67722_uris$jscomp$8$$){function $svg_url_QMARK_$$($url$jscomp$91$$){var $or__5025__auto__$jscomp$730$$=$APP.$cljs$core$truth_$$($mtype$jscomp$18$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mtype$jscomp$18$$,"image/svg+xml"):$mtype$jscomp$18$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$730$$)?$or__5025__auto__$jscomp$730$$:$APP.$cuerdas$core$ends_with_QMARK_$$($url$jscomp$91$$,".svg")}var $map__67723__$1_on_svg$$=
$APP.$cljs$core$__destructure_map$$($p__67722_uris$jscomp$8$$),$file_id$jscomp$100$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67723__$1_on_svg$$,$APP.$cljs$cst$1644$file_id$$),$local_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67723__$1_on_svg$$,$APP.$cljs$cst$3693$local_QMARK_$$),$name$jscomp$312$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67723__$1_on_svg$$,$APP.$cljs$cst$725$name$$);$p__67722_uris$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67723__$1_on_svg$$,
$APP.$cljs$cst$3694$uris$$);var $mtype$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67723__$1_on_svg$$,$APP.$cljs$cst$1726$mtype$$),$on_image$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67723__$1_on_svg$$,$APP.$cljs$cst$3695$on_image$$);$map__67723__$1_on_svg$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67723__$1_on_svg$$,$APP.$cljs$cst$3696$on_svg$$);return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($on_image$$,
$APP.$beicon$v2$core$mapcat$$(function($uri$jscomp$90$$){return $APP.$beicon$v2$core$mapcat$$(function($p1__67719_SHARP_$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2282$upload_file_media_object$$,$p1__67719_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($content$jscomp$161$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$100$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$truth_$$($name$jscomp$312$$)?
$name$jscomp$312$$:$app$main$data$workspace$svg_upload$extract_name$$($uri$jscomp$90$$),$APP.$cljs$cst$2574$is_local$$,$local_QMARK_$jscomp$2$$,$APP.$cljs$cst$1637$content$$,$content$jscomp$161$$],null)},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1581$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$,$APP.$cljs$cst$1579$uri$$,$uri$jscomp$90$$,$APP.$cljs$cst$320$mode$$,$APP.$cljs$cst$3697$no_cors$$,$APP.$cljs$cst$1587$response_type$$,
$APP.$cljs$cst$1591$blob$$],null)))))},$APP.$beicon$v2$core$filter$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$not$$,$svg_url_QMARK_$$),$APP.$beicon$v2$core$from$$($p__67722_uris$jscomp$8$$)))),$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__67723__$1_on_svg$$,$APP.$beicon$v2$core$merge_map$$($APP.$app$main$data$workspace$media$svg__GT_clj$$,$APP.$beicon$v2$core$merge_map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$(function($name__$1$jscomp$6$$,
$uri$jscomp$91$$){return $APP.$beicon$v2$core$map$$(function($p1__67720_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$($name__$1$jscomp$6$$)?$name__$1$jscomp$6$$:$app$main$data$workspace$svg_upload$extract_name$$($uri$jscomp$91$$),$APP.$cljs$cst$1581$body$$.$cljs$core$IFn$_invoke$arity$1$($p1__67720_SHARP_$$)],null)},$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1578$method$$,
$APP.$cljs$cst$1297$get$$,$APP.$cljs$cst$1579$uri$$,$uri$jscomp$91$$,$APP.$cljs$cst$320$mode$$,$APP.$cljs$cst$3697$no_cors$$],null)))},$name$jscomp$312$$),$APP.$beicon$v2$core$filter$$($svg_url_QMARK_$$,$APP.$beicon$v2$core$from$$($p__67722_uris$jscomp$8$$))))))};
$APP.$app$main$data$workspace$media$process_blobs$$=function($blobs$jscomp$1_p__67732$$){function $svg_blob_QMARK_$$($blob$jscomp$26$$){return $APP.$cljs$core$not$$($force_media$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($blob$jscomp$26$$.type,"image/svg+xml")}var $map__67733__$1_on_svg$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($blobs$jscomp$1_p__67732$$),$file_id$jscomp$101$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67733__$1_on_svg$jscomp$1$$,$APP.$cljs$cst$1644$file_id$$),
$local_QMARK_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67733__$1_on_svg$jscomp$1$$,$APP.$cljs$cst$3693$local_QMARK_$$),$name$jscomp$313$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67733__$1_on_svg$jscomp$1$$,$APP.$cljs$cst$725$name$$);$blobs$jscomp$1_p__67732$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67733__$1_on_svg$jscomp$1$$,$APP.$cljs$cst$3698$blobs$$);var $force_media$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67733__$1_on_svg$jscomp$1$$,
$cljs$cst$3699$force_media$$),$on_image$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67733__$1_on_svg$jscomp$1$$,$APP.$cljs$cst$3695$on_image$$);$map__67733__$1_on_svg$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67733__$1_on_svg$jscomp$1$$,$APP.$cljs$cst$3696$on_svg$$);return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($on_image$jscomp$1$$,$APP.$beicon$v2$core$mapcat$$(function($blob$jscomp$27$$){var $params$jscomp$251$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$101$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$truth_$$($name$jscomp$313$$)?$name$jscomp$313$$:$APP.$app$main$data$media$file_QMARK_$$($blob$jscomp$27$$)?$APP.$cuerdas$core$replace$$($blob$jscomp$27$$.name,/(\.png)|(\.jpg)|(\.jpeg)|(\.webp)|(\.gif)|(\.svg)$/,""):"blob",$APP.$cljs$cst$2574$is_local$$,$local_QMARK_$jscomp$3$$,$APP.$cljs$cst$1591$blob$$,$blob$jscomp$27$$],null);return $blob$jscomp$27$$.size>=
$app$config$upload_chunk_size$$?$app$main$data$workspace$media$upload_blob_chunked$$($params$jscomp$251$$):$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2282$upload_file_media_object$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$101$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$251$$),$APP.$cljs$cst$2574$is_local$$,$local_QMARK_$jscomp$3$$,$APP.$cljs$cst$1637$content$$,
$blob$jscomp$27$$],null))},$APP.$beicon$v2$core$filter$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$not$$,$svg_blob_QMARK_$$),$APP.$beicon$v2$core$map$$($APP.$app$main$data$media$validate_file$$,$APP.$beicon$v2$core$from$$($blobs$jscomp$1_p__67732$$))))),$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__67733__$1_on_svg$jscomp$1$$,$APP.$beicon$v2$core$merge_map$$($APP.$app$main$data$workspace$media$svg__GT_clj$$,$APP.$beicon$v2$core$merge_map$$(function($blob$jscomp$28$$){var $name__$1$jscomp$7$$=
$APP.$cljs$core$truth_$$($name$jscomp$313$$)?$name$jscomp$313$$:$blob$jscomp$28$$.name;return $APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($blob$jscomp$28$$.text(),function($p1__67731_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$name__$1$jscomp$7$$,$p1__67731_SHARP_$$],null)})},$APP.$beicon$v2$core$filter$$($svg_blob_QMARK_$$,$APP.$beicon$v2$core$map$$($APP.$app$main$data$media$validate_file$$,$APP.$beicon$v2$core$from$$($blobs$jscomp$1_p__67732$$)))))))};
$APP.$app$main$data$workspace$media$handle_media_error$$=function($cause$jscomp$80_error$jscomp$70$$){$APP.$app$common$exceptions$print_throwable$$($cause$jscomp$80_error$jscomp$70$$);$cause$jscomp$80_error$jscomp$70$$=$APP.$cljs$core$ex_data$$($cause$jscomp$80_error$jscomp$70$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$80_error$jscomp$70$$),$cljs$cst$3700$invalid_svg_file$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.media-type-not-allowed"))):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$80_error$jscomp$70$$),$cljs$cst$3193$media_type_not_allowed$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.media-type-not-allowed"))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$80_error$jscomp$70$$),
$cljs$cst$3701$unable_to_access_to_url$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.media-type-not-allowed"))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$80_error$jscomp$70$$),$cljs$cst$3702$invalid_image$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.media-type-not-allowed"))):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$80_error$jscomp$70$$),$cljs$cst$3703$media_max_file_size_reached$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.media-too-large"))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$80_error$jscomp$70$$),
$cljs$cst$3195$media_type_mismatch$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.media-type-mismatch"))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$80_error$jscomp$70$$),$cljs$cst$3704$unable_to_optimize$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$cljs$cst$275$hint$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$80_error$jscomp$70$$))):
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.cannot-upload")))};
$APP.$app$main$data$workspace$media$process_media_objects$$=function($p__67743$$){var $map__67744__$1$$=$APP.$cljs$core$__destructure_map$$($p__67743$$),$uris$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67744__$1$$,$APP.$cljs$cst$3694$uris$$);typeof $app$main$data$workspace$media$process_media_objects_67745$$==="undefined"&&($app$main$data$workspace$media$process_media_objects_67745$$=function($p__67743$jscomp$1$$,$map__67744$jscomp$1$$,$params$jscomp$253$$,$uris$jscomp$10$$,
$meta67746$$){this.$p__67743$=$p__67743$jscomp$1$$;this.$map__67744$=$map__67744$jscomp$1$$;this.params=$params$jscomp$253$$;this.$uris$=$uris$jscomp$10$$;this.$meta67746$=$meta67746$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$media$process_media_objects_67745$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$process_media_objects_67745$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3705$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_process_media_objects$$},$app$main$data$workspace$media$process_media_objects_67745$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67747$$,$meta67746__$1$$){return new $app$main$data$workspace$media$process_media_objects_67745$$(this.$p__67743$,this.$map__67744$,this.params,this.$uris$,$meta67746__$1$$)},$app$main$data$workspace$media$process_media_objects_67745$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67746$},$app$main$data$workspace$media$process_media_objects_67745$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$process_media_objects_67745$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.loading"),
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$2353$timeout$$,null,$APP.$cljs$cst$78$tag$$,$cljs$cst$3706$media_loading$$],null))),$APP.$beicon$v2$core$finalize$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$hide$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$78$tag$$,$cljs$cst$3706$media_loading$$])))},
$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$media$handle_media_error$$,$APP.$beicon$v2$core$ignore$$($APP.$cljs$core$seq$$(this.$uris$)?$app$main$data$workspace$media$process_uris$$(this.params):$APP.$app$main$data$workspace$media$process_blobs$$(this.params)))))});return new $app$main$data$workspace$media$process_media_objects_67745$$($p__67743$$,$map__67744__$1$$,$map__67744__$1$$,$uris$jscomp$9$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$media$upload_media_workspace$$=function($map__67751__$1_p__67750_params__$1$jscomp$36$$){$map__67751__$1_p__67750_params__$1$jscomp$36$$=$APP.$cljs$core$__destructure_map$$($map__67751__$1_p__67750_params__$1$jscomp$36$$);var $position$jscomp$79$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67751__$1_p__67750_params__$1$jscomp$36$$,$APP.$cljs$cst$1676$position$$),$file_id$jscomp$102$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67751__$1_p__67750_params__$1$jscomp$36$$,
$APP.$cljs$cst$1644$file_id$$);$map__67751__$1_p__67750_params__$1$jscomp$36$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__67751__$1_p__67750_params__$1$jscomp$36$$,$APP.$cljs$cst$3693$local_QMARK_$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3695$on_image$$,function($p1__67748_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$media$image_uploaded$$($p1__67748_SHARP_$$,$position$jscomp$79$$))},
$APP.$cljs$cst$3696$on_svg$$,function($p1__67749_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$media$svg_uploaded$$($p1__67749_SHARP_$$,$file_id$jscomp$102$$,$position$jscomp$79$$))}]));return $APP.$app$main$data$workspace$media$process_media_objects$$($map__67751__$1_p__67750_params__$1$jscomp$36$$)};
$APP.$app$main$data$workspace$layout$remove_layout_flag$$=function($flag$jscomp$8$$){typeof $app$main$data$workspace$layout$remove_layout_flag_67161$$==="undefined"&&($app$main$data$workspace$layout$remove_layout_flag_67161$$=function($flag$jscomp$9$$,$meta67162$$){this.$flag$=$flag$jscomp$9$$;this.$meta67162$=$meta67162$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$layout$remove_layout_flag_67161$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layout$remove_layout_flag_67161$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3736$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_remove_layout_flag$$},$app$main$data$workspace$layout$remove_layout_flag_67161$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67163$$,$meta67162__$1$$){return new $app$main$data$workspace$layout$remove_layout_flag_67161$$(this.$flag$,$meta67162__$1$$)},$app$main$data$workspace$layout$remove_layout_flag_67161$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67162$},$app$main$data$workspace$layout$remove_layout_flag_67161$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layout$remove_layout_flag_67161$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1989$$,$state$jscomp$412$$){var $self__$jscomp$4442$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$412$$,$APP.$cljs$cst$2209$workspace_layout$$,function($flags$jscomp$33$$){return $APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($flags$jscomp$33$$,
$self__$jscomp$4442$$.$flag$)})},$app$main$data$workspace$layout$remove_layout_flag_67161$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layout$remove_layout_flag_67161$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1990_flags$jscomp$34$$,$state$jscomp$413$$){$_$jscomp$1990_flags$jscomp$34$$=$APP.$cljs$cst$2209$workspace_layout$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$413$$);return $app$main$data$workspace$layout$persist_layout_flags_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?
$app$main$data$workspace$layout$persist_layout_flags_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1990_flags$jscomp$34$$):$app$main$data$workspace$layout$persist_layout_flags_BANG_$$($_$jscomp$1990_flags$jscomp$34$$)});return new $app$main$data$workspace$layout$remove_layout_flag_67161$$($flag$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$layout$set_options_mode$$=function($mode$jscomp$26$$){typeof $app$main$data$workspace$layout$set_options_mode_67178$$==="undefined"&&($app$main$data$workspace$layout$set_options_mode_67178$$=function($mode$jscomp$27$$,$meta67179$$){this.mode=$mode$jscomp$27$$;this.$meta67179$=$meta67179$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$layout$set_options_mode_67178$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layout$set_options_mode_67178$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3737$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_set_options_mode$$},$app$main$data$workspace$layout$set_options_mode_67178$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67180$$,$meta67179__$1$$){return new $app$main$data$workspace$layout$set_options_mode_67178$$(this.mode,$meta67179__$1$$)},$app$main$data$workspace$layout$set_options_mode_67178$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67179$},$app$main$data$workspace$layout$set_options_mode_67178$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layout$set_options_mode_67178$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:sidebar",$APP.$cljs$cst$320$mode$$,$APP.$app$common$data$name$$(this.mode)],null)},
$app$main$data$workspace$layout$set_options_mode_67178$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layout$set_options_mode_67178$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1992$$,$state$jscomp$414$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$414$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$2200$options_mode$$],
null),this.mode)});return new $app$main$data$workspace$layout$set_options_mode_67178$$($mode$jscomp$26$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$layout$load_layout_flags$$=function($layout$jscomp$4_layout__$1$$){$layout$jscomp$4_layout__$1$$=$APP.$cljs$core$set$$($APP.$cljs$core$truth_$$($layout$jscomp$4_layout__$1$$)?$layout$jscomp$4_layout__$1$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$cljs$core$reduce_kv$$(function($layout__$2$$,$flag$jscomp$10$$,$expr__67192_key$jscomp$376$$){$expr__67192_key$jscomp$376$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$user$$,$expr__67192_key$jscomp$376$$,
$cljs$cst$3743$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_none$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3743$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_none$$,$expr__67192_key$jscomp$376$$):$APP.$cljs$core$_EQ_$$($cljs$cst$3743$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_none$$,$expr__67192_key$jscomp$376$$)))return $layout__$2$$;if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!1,$expr__67192_key$jscomp$376$$):$APP.$cljs$core$_EQ_$$(!1,$expr__67192_key$jscomp$376$$)))return $APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($layout__$2$$,$flag$jscomp$10$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!0,$expr__67192_key$jscomp$376$$):$APP.$cljs$core$_EQ_$$(!0,$expr__67192_key$jscomp$376$$)))return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($layout__$2$$,
$flag$jscomp$10$$);throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expr__67192_key$jscomp$376$$)].join(""));},$layout$jscomp$4_layout__$1$$,$app$main$data$workspace$layout$layout_flags_persistence_mapping$$)};
$app$main$data$workspace$layout$persist_layout_flags_BANG_$$=function($layout$jscomp$5$$){for(var $G__67282_seq__67195_seq__67195__$1_temp__5825__auto__$jscomp$198$$=$APP.$cljs$core$seq$$($app$main$data$workspace$layout$layout_flags_persistence_mapping$$),$c__5548__auto__$jscomp$19_chunk__67196_vec__67214$$=null,$G__67284_count__67197$$=0,$i__67198$$=0;;)if($i__67198$$<$G__67284_count__67197$$){var $key$jscomp$377_vec__67208$$=$c__5548__auto__$jscomp$19_chunk__67196_vec__67214$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$i__67198$$),$G__67283_flag$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($key$jscomp$377_vec__67208$$,0,null);$key$jscomp$377_vec__67208$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($key$jscomp$377_vec__67208$$,1,null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$key$jscomp$377_vec__67208$$,$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$5$$,$G__67283_flag$jscomp$11$$));$i__67198$$+=1}else if($G__67282_seq__67195_seq__67195__$1_temp__5825__auto__$jscomp$198$$=
$APP.$cljs$core$seq$$($G__67282_seq__67195_seq__67195__$1_temp__5825__auto__$jscomp$198$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__67282_seq__67195_seq__67195__$1_temp__5825__auto__$jscomp$198$$)?($c__5548__auto__$jscomp$19_chunk__67196_vec__67214$$=$APP.$cljs$core$_chunked_first$$($G__67282_seq__67195_seq__67195__$1_temp__5825__auto__$jscomp$198$$),$G__67282_seq__67195_seq__67195__$1_temp__5825__auto__$jscomp$198$$=$APP.$cljs$core$_chunked_rest$$($G__67282_seq__67195_seq__67195__$1_temp__5825__auto__$jscomp$198$$),
$G__67283_flag$jscomp$11$$=$c__5548__auto__$jscomp$19_chunk__67196_vec__67214$$,$G__67284_count__67197$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$19_chunk__67196_vec__67214$$),$c__5548__auto__$jscomp$19_chunk__67196_vec__67214$$=$G__67283_flag$jscomp$11$$):($c__5548__auto__$jscomp$19_chunk__67196_vec__67214$$=$APP.$cljs$core$first$$($G__67282_seq__67195_seq__67195__$1_temp__5825__auto__$jscomp$198$$),$G__67283_flag$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$19_chunk__67196_vec__67214$$,
0,null),$key$jscomp$377_vec__67208$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$19_chunk__67196_vec__67214$$,1,null),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$key$jscomp$377_vec__67208$$,$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$5$$,$G__67283_flag$jscomp$11$$)),$G__67282_seq__67195_seq__67195__$1_temp__5825__auto__$jscomp$198$$=$APP.$cljs$core$next$$($G__67282_seq__67195_seq__67195__$1_temp__5825__auto__$jscomp$198$$),
$c__5548__auto__$jscomp$19_chunk__67196_vec__67214$$=null,$G__67284_count__67197$$=0),$i__67198$$=0;else return null};
$app$main$data$workspace$layout$load_layout_state$$=function($state$jscomp$415$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($state__$1$jscomp$18$$,$p__67217_skey_val$jscomp$179$$){var $key$jscomp$378$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67217_skey_val$jscomp$179$$,0,null);$p__67217_skey_val$jscomp$179$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67217_skey_val$jscomp$179$$,1,null);$p__67217_skey_val$jscomp$179$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$user$$,
$p__67217_skey_val$jscomp$179$$,$cljs$cst$3743$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_none$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__67217_skey_val$jscomp$179$$,$cljs$cst$3743$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_none$$)?$state__$1$jscomp$18$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$18$$,$key$jscomp$378$$,$p__67217_skey_val$jscomp$179$$)},$state$jscomp$415$$,$APP.$app$main$data$workspace$layout$layout_state_persistence_mapping$$)};
$APP.$app$main$data$workspace$common$interrupt_QMARK_$$=function($e$jscomp$320$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$320$$,$APP.$cljs$cst$2169$interrupt$$)};
$APP.$app$main$data$workspace$common$set_workspace_visited$$=function(){typeof $app$main$data$workspace$common$set_workspace_visited_67261$$==="undefined"&&($app$main$data$workspace$common$set_workspace_visited_67261$$=function($meta67262$$){this.$meta67262$=$meta67262$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$common$set_workspace_visited_67261$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$common$set_workspace_visited_67261$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3749$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_set_workspace_visited$$},$app$main$data$workspace$common$set_workspace_visited_67261$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67263$$,$meta67262__$1$$){return new $app$main$data$workspace$common$set_workspace_visited_67261$$($meta67262__$1$$)},$app$main$data$workspace$common$set_workspace_visited_67261$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67262$},$app$main$data$workspace$common$set_workspace_visited_67261$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$common$set_workspace_visited_67261$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1993_profile$jscomp$20_props$jscomp$159$$,$state$jscomp$418$$){$_$jscomp$1993_profile$jscomp$20_props$jscomp$159$$=$APP.$cljs$cst$1914$profile$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$418$$);$_$jscomp$1993_profile$jscomp$20_props$jscomp$159$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1993_profile$jscomp$20_props$jscomp$159$$,
$APP.$cljs$cst$575$props$$);return $APP.$cljs$core$not$$($APP.$cljs$cst$3750$workspace_visited$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1993_profile$jscomp$20_props$jscomp$159$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3750$workspace_visited$$,!0],null))):null});return new $app$main$data$workspace$common$set_workspace_visited_67261$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$common$show_toolbar$$=function(){typeof $app$main$data$workspace$common$show_toolbar_67275$$==="undefined"&&($app$main$data$workspace$common$show_toolbar_67275$$=function($meta67276$$){this.$meta67276$=$meta67276$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$common$show_toolbar_67275$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$common$show_toolbar_67275$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3753$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_show_toolbar$$},$app$main$data$workspace$common$show_toolbar_67275$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67277$$,$meta67276__$1$$){return new $app$main$data$workspace$common$show_toolbar_67275$$($meta67276__$1$$)},$app$main$data$workspace$common$show_toolbar_67275$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67276$},$app$main$data$workspace$common$show_toolbar_67275$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$common$show_toolbar_67275$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1995$$,$state$jscomp$420$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$420$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$3752$hide_toolbar$$],null),!1)});return new $app$main$data$workspace$common$show_toolbar_67275$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$common$set_workspace_read_only$$=function($read_only_QMARK_$jscomp$1$$){typeof $app$main$data$workspace$common$set_workspace_read_only_67310$$==="undefined"&&($app$main$data$workspace$common$set_workspace_read_only_67310$$=function($read_only_QMARK_$jscomp$2$$,$meta67311$$){this.$read_only_QMARK_$=$read_only_QMARK_$jscomp$2$$;this.$meta67311$=$meta67311$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$common$set_workspace_read_only_67310$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$common$set_workspace_read_only_67310$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3755$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_set_workspace_read_only$$},$app$main$data$workspace$common$set_workspace_read_only_67310$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67312$$,$meta67311__$1$$){return new $app$main$data$workspace$common$set_workspace_read_only_67310$$(this.$read_only_QMARK_$,
$meta67311__$1$$)},$app$main$data$workspace$common$set_workspace_read_only_67310$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67311$},$app$main$data$workspace$common$set_workspace_read_only_67310$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$common$set_workspace_read_only_67310$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1997$$,$state$jscomp$422$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$422$$,
$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2217$read_only_QMARK_$$,this.$read_only_QMARK_$)},$app$main$data$workspace$common$set_workspace_read_only_67310$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$common$set_workspace_read_only_67310$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$cljs$core$truth_$$(this.$read_only_QMARK_$)?(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2169$interrupt$$,
$APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3715$colorpalette$$),$APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3740$textpalette$$)):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$common$set_workspace_read_only_67310$$($read_only_QMARK_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$logic$variants$add_unique_path$$=function($shapes$jscomp$59$$,$objects$jscomp$364$$,$base_id$jscomp$4$$){return $APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($counts$jscomp$2_p__67184_shape_path$$,$shape$jscomp$461$$){var $result$jscomp$276$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($counts$jscomp$2_p__67184_shape_path$$,0,null);$counts$jscomp$2_p__67184_shape_path$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($counts$jscomp$2_p__67184_shape_path$$,
1,null);var $counts_SINGLEQUOTE__path$jscomp$inline_6642_vec__67188$$=$app$common$logic$variants$generate_path$$("",$objects$jscomp$364$$,$base_id$jscomp$4$$,$shape$jscomp$461$$);var $num$jscomp$inline_6643$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($counts$jscomp$2_p__67184_shape_path$$,$counts_SINGLEQUOTE__path$jscomp$inline_6642_vec__67188$$,1);$counts_SINGLEQUOTE__path$jscomp$inline_6642_vec__67188$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($counts_SINGLEQUOTE__path$jscomp$inline_6642_vec__67188$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($num$jscomp$inline_6643$$)].join(""),$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($counts$jscomp$2_p__67184_shape_path$$,$counts_SINGLEQUOTE__path$jscomp$inline_6642_vec__67188$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$inc$$,1))],null);$counts$jscomp$2_p__67184_shape_path$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($counts_SINGLEQUOTE__path$jscomp$inline_6642_vec__67188$$,
0,null);$counts_SINGLEQUOTE__path$jscomp$inline_6642_vec__67188$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($counts_SINGLEQUOTE__path$jscomp$inline_6642_vec__67188$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$276$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$461$$,$cljs$cst$3756$shape_path$$,$counts$jscomp$2_p__67184_shape_path$$)),
$counts_SINGLEQUOTE__path$jscomp$inline_6642_vec__67188$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null),$shapes$jscomp$59$$))};
$app$common$logic$variants$keep_swapped_item$$=function($changes$jscomp$180$$,$related_shape_in_new$$,$orig_swapped_child$$,$ldata$$,$page$jscomp$71$$,$swap_ref_id$$){var $before_changes$$=$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),$page$jscomp$71$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$71$$)),
$APP.$app$common$uuid$zero$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$orig_swapped_child$$],null),0,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2618$allow_altering_copies$$,!0],null)),$objects$jscomp$365$$=$APP.$app$common$files$changes_builder$get_objects$$($changes$jscomp$180$$),$prev_swap_slot$$=$APP.$app$common$types$component$get_swap_slot$$($orig_swapped_child$$),$current_parent$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$365$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($related_shape_in_new$$)),$pos$jscomp$107$$=$APP.$app$common$data$index_of$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($current_parent$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($related_shape_in_new$$));return $APP.$cljs$core$second$$($app$common$logic$shapes$generate_delete_shapes$cljs$0core$0IFn$0_invoke$0arity$06$$(function(){var $G__67204$$=$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$app$common$files$changes_builder$concat_changes$$($before_changes$$,
$changes$jscomp$180$$),$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($related_shape_in_new$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$orig_swapped_child$$],null),$pos$jscomp$107$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2618$allow_altering_copies$$,!0],null));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prev_swap_slot$$,$swap_ref_id$$)?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67204$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($orig_swapped_child$$)],null),function($p1__67194_SHARP_$$){return $app$common$types$component$set_swap_slot$$($app$common$types$component$remove_swap_slot$$($p1__67194_SHARP_$$),$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($related_shape_in_new$$))}):$G__67204$$}(),$ldata$$,$page$jscomp$71$$,$objects$jscomp$365$$,$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($related_shape_in_new$$)),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2618$allow_altering_copies$$,!0],null)))};
$app$common$logic$variants$child_of_swapped_QMARK_$$=function($ancestors$jscomp$1_ancestors__$1_shape$jscomp$462$$,$num_ancestors_objects$jscomp$366$$,$base_parent_id$$){$ancestors$jscomp$1_ancestors__$1_shape$jscomp$462$$=$APP.$cljs$core$seq$$($APP.$cljs$core$drop_while$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__67213_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($base_parent_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__67213_SHARP_$$))},
$app$common$types$container$get_parent_heads$$($num_ancestors_objects$jscomp$366$$,$ancestors$jscomp$1_ancestors__$1_shape$jscomp$462$$)));$num_ancestors_objects$jscomp$366$$=$APP.$cljs$core$count$$($ancestors$jscomp$1_ancestors__$1_shape$jscomp$462$$);$ancestors$jscomp$1_ancestors__$1_shape$jscomp$462$$=$ancestors$jscomp$1_ancestors__$1_shape$jscomp$462$$&&3<=$num_ancestors_objects$jscomp$366$$?$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$vec$$($ancestors$jscomp$1_ancestors__$1_shape$jscomp$462$$),
1,$num_ancestors_objects$jscomp$366$$-1):null;return $APP.$cljs$core$some$$($APP.$app$common$types$component$get_swap_slot$$,$ancestors$jscomp$1_ancestors__$1_shape$jscomp$462$$)};
$app$common$logic$variants$generate_keep_touched$$=function($changes$jscomp$181_changes__$1$jscomp$68$$,$new_shape$jscomp$15$$,$original_shape$jscomp$5$$,$orig_touched_original_shapes_parents_of_swapped_vec__67245$$,$page$jscomp$72$$,$libraries$jscomp$67$$,$ldata$jscomp$1$$){var $new_shapes_w_path_o_ref_shapes_wp_objects$jscomp$367_orig_ref_objects$$=$APP.$app$common$files$changes_builder$get_objects$$($changes$jscomp$181_changes__$1$jscomp$68$$),$container$jscomp$69$$=$app$common$types$container$make_container$$($page$jscomp$72$$,
$APP.$cljs$cst$1624$page$$),$page_objects$jscomp$1$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$72$$);$orig_touched_original_shapes_parents_of_swapped_vec__67245$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67243_SHARP_$$){return $app$common$logic$variants$child_of_swapped_QMARK_$$($p1__67243_SHARP_$$,$page_objects$jscomp$1$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($original_shape$jscomp$5$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$,
$APP.$cljs$cst$1626$touched$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67242_SHARP_$$){var $new_touched$jscomp$inline_6648$$=$app$common$types$file$get_touched_from_ref_chain_until_target_ref$$($container$jscomp$69$$,$libraries$jscomp$67$$,$p1__67242_SHARP_$$,null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__67242_SHARP_$$,$APP.$cljs$cst$1626$touched$$,$new_touched$jscomp$inline_6648$$)},$orig_touched_original_shapes_parents_of_swapped_vec__67245$$)));
$new_shapes_w_path_o_ref_shapes_wp_objects$jscomp$367_orig_ref_objects$$=$app$common$logic$variants$add_unique_path$$($APP.$cljs$core$reverse$$($APP.$app$common$files$helpers$get_children_with_self$$($new_shapes_w_path_o_ref_shapes_wp_objects$jscomp$367_orig_ref_objects$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$15$$))),$new_shapes_w_path_o_ref_shapes_wp_objects$jscomp$367_orig_ref_objects$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$15$$));
var $new_shapes_map$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$3756$shape_path$$,$APP.$cljs$core$identity$$)),$new_shapes_w_path_o_ref_shapes_wp_objects$jscomp$367_orig_ref_objects$$),$orig_base_ref_shape$$=$APP.$app$common$types$file$find_remote_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($container$jscomp$69$$,$libraries$jscomp$67$$,
$original_shape$jscomp$5$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2591$with_context_QMARK_$$,!0],null)]));$new_shapes_w_path_o_ref_shapes_wp_objects$jscomp$367_orig_ref_objects$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2588$container$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($orig_base_ref_shape$$)));$new_shapes_w_path_o_ref_shapes_wp_objects$jscomp$367_orig_ref_objects$$=
$app$common$logic$variants$add_unique_path$$($APP.$cljs$core$reverse$$($APP.$app$common$files$helpers$get_children_with_self$$($new_shapes_w_path_o_ref_shapes_wp_objects$jscomp$367_orig_ref_objects$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($orig_base_ref_shape$$))),$new_shapes_w_path_o_ref_shapes_wp_objects$jscomp$367_orig_ref_objects$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($orig_base_ref_shape$$));var $o_ref_shapes_p_map$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$cljs$cst$3756$shape_path$$)),$new_shapes_w_path_o_ref_shapes_wp_objects$jscomp$367_orig_ref_objects$$);$orig_touched_original_shapes_parents_of_swapped_vec__67245$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__67257_swap_slot$jscomp$5$$,$changes__$2$jscomp$32_orig_child_touched$$){var $changes__$1$jscomp$69$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67257_swap_slot$jscomp$5$$,
0,null),$parent_of_swapped_parents_of_swapped$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67257_swap_slot$jscomp$5$$,1,null);$p__67257_swap_slot$jscomp$5$$=$APP.$app$common$types$component$get_swap_slot$$($changes__$2$jscomp$32_orig_child_touched$$);var $orig_ref_shape$$=$APP.$cljs$core$truth_$$($p__67257_swap_slot$jscomp$5$$)?null:$app$common$logic$variants$find_shape_ref_child_of$$($container$jscomp$69$$,$libraries$jscomp$67$$,$changes__$2$jscomp$32_orig_child_touched$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($orig_base_ref_shape$$));if($APP.$cljs$core$truth_$$($p__67257_swap_slot$jscomp$5$$)){var $JSCompiler_temp$jscomp$10791_orig_ref_id_swap_slot$jscomp$inline_12451$$=$APP.$app$common$types$component$get_swap_slot$$($changes__$2$jscomp$32_orig_child_touched$$);var $objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$69$$),
$parent$jscomp$inline_12453$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($changes__$2$jscomp$32_orig_child_touched$$));$objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$=$APP.$app$common$types$container$get_head_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$,
$parent$jscomp$inline_12453$$);$objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$=$app$common$types$file$find_ref_shape$$(null,$container$jscomp$69$$,$libraries$jscomp$67$$,$objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$);$JSCompiler_temp$jscomp$10791_orig_ref_id_swap_slot$jscomp$inline_12451$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10791_orig_ref_id_swap_slot$jscomp$inline_12451$$)?
$objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$:$JSCompiler_temp$jscomp$10791_orig_ref_id_swap_slot$jscomp$inline_12451$$)?$app$common$types$file$find_next_related_swap_shape_id$$($objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$,$JSCompiler_temp$jscomp$10791_orig_ref_id_swap_slot$jscomp$inline_12451$$,$libraries$jscomp$67$$):
null}else $JSCompiler_temp$jscomp$10791_orig_ref_id_swap_slot$jscomp$inline_12451$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($orig_ref_shape$$);$objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_ref_shapes_p_map$$,$JSCompiler_temp$jscomp$10791_orig_ref_id_swap_slot$jscomp$inline_12451$$);$objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_shapes_map$$,$objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$);$parent_of_swapped_parents_of_swapped$jscomp$1$$=$APP.$cljs$core$truth_$$($objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($parent_of_swapped_parents_of_swapped$jscomp$1$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$)):$parent_of_swapped_parents_of_swapped$jscomp$1$$;$changes__$2$jscomp$32_orig_child_touched$$=$APP.$cljs$core$truth_$$($objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$)?$APP.$cljs$core$truth_$$($p__67257_swap_slot$jscomp$5$$)?
$app$common$logic$variants$keep_swapped_item$$($changes__$1$jscomp$69$$,$objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$,$changes__$2$jscomp$32_orig_child_touched$$,$ldata$jscomp$1$$,$page$jscomp$72$$,$JSCompiler_temp$jscomp$10791_orig_ref_id_swap_slot$jscomp$inline_12451$$):$app$common$logic$libraries$update_attrs_on_switch$$($changes__$1$jscomp$69$$,$objects$jscomp$inline_12452_parent_head$jscomp$inline_12454_parent_ref$jscomp$inline_12455_related_shape_in_new$jscomp$1_shape_path$jscomp$1$$,
$changes__$2$jscomp$32_orig_child_touched$$,$new_shape$jscomp$15$$,$original_shape$jscomp$5$$,$orig_ref_shape$$,$container$jscomp$69$$):$changes__$1$jscomp$69$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$changes__$2$jscomp$32_orig_child_touched$$,$parent_of_swapped_parents_of_swapped$jscomp$1$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$changes$jscomp$181_changes__$1$jscomp$68$$,
$APP.$cljs$core$PersistentVector$EMPTY$$],null),$orig_touched_original_shapes_parents_of_swapped_vec__67245$$);$changes$jscomp$181_changes__$1$jscomp$68$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_touched_original_shapes_parents_of_swapped_vec__67245$$,0,null);$orig_touched_original_shapes_parents_of_swapped_vec__67245$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_touched_original_shapes_parents_of_swapped_vec__67245$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$changes$jscomp$181_changes__$1$jscomp$68$$,$orig_touched_original_shapes_parents_of_swapped_vec__67245$$],null)};
$app$main$data$workspace$groups$shapes_for_grouping$$=function($objects$jscomp$368$$,$selected$jscomp$38$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67423_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$368$$,$p1__67423_SHARP_$$)},$APP.$cljs$core$reverse$$($app$common$files$helpers$order_by_indexed_shapes$$($objects$jscomp$368$$,$selected$jscomp$38$$)))};
$app$main$data$workspace$groups$get_empty_groups_after_group_creation$$=function($objects$jscomp$369$$,$parent_id$jscomp$70$$,$G__67594_current_id$jscomp$5_shapes$jscomp$60$$){var $G__67592_G__67596_ids$jscomp$86_removed_id_QMARK_$jscomp$1$$=$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$369$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$G__67594_current_id$jscomp$5_shapes$jscomp$60$$)),
$G__67593_G__67597_parents$jscomp$9_result$jscomp$277$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__67425_SHARP_$$){return $APP.$app$common$files$helpers$get_parent_id$$($objects$jscomp$369$$,$p1__67425_SHARP_$$)}),$G__67592_G__67596_ids$jscomp$86_removed_id_QMARK_$jscomp$1$$);$G__67594_current_id$jscomp$5_shapes$jscomp$60$$=$APP.$cljs$core$first$$($G__67593_G__67597_parents$jscomp$9_result$jscomp$277$$);
var $G__67590_G__67595_to_check$jscomp$2$$=$APP.$cljs$core$rest$$($G__67593_G__67597_parents$jscomp$9_result$jscomp$277$$);for($G__67593_G__67597_parents$jscomp$9_result$jscomp$277$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$;;){if($APP.$cljs$core$not$$($G__67594_current_id$jscomp$5_shapes$jscomp$60$$))return $G__67593_G__67597_parents$jscomp$9_result$jscomp$277$$;var $G__67591_group$jscomp$32_to_check__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$369$$,$G__67594_current_id$jscomp$5_shapes$jscomp$60$$);
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__67591_group$jscomp$32_to_check__$1$jscomp$1$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__67594_current_id$jscomp$5_shapes$jscomp$60$$,$parent_id$jscomp$70$$)&&$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($G__67592_G__67596_ids$jscomp$86_removed_id_QMARK_$jscomp$1$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($G__67591_group$jscomp$32_to_check__$1$jscomp$1$$)))?
($G__67591_group$jscomp$32_to_check__$1$jscomp$1$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($G__67590_G__67595_to_check$jscomp$2$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$files$helpers$get_parent_id$$($objects$jscomp$369$$,$G__67594_current_id$jscomp$5_shapes$jscomp$60$$)],null)),$G__67590_G__67595_to_check$jscomp$2$$=$APP.$cljs$core$first$$($G__67591_group$jscomp$32_to_check__$1$jscomp$1$$),$G__67591_group$jscomp$32_to_check__$1$jscomp$1$$=
$APP.$cljs$core$rest$$($G__67591_group$jscomp$32_to_check__$1$jscomp$1$$),$G__67592_G__67596_ids$jscomp$86_removed_id_QMARK_$jscomp$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__67592_G__67596_ids$jscomp$86_removed_id_QMARK_$jscomp$1$$,$G__67594_current_id$jscomp$5_shapes$jscomp$60$$),$G__67593_G__67597_parents$jscomp$9_result$jscomp$277$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__67593_G__67597_parents$jscomp$9_result$jscomp$277$$,$G__67594_current_id$jscomp$5_shapes$jscomp$60$$),
$G__67594_current_id$jscomp$5_shapes$jscomp$60$$=$G__67590_G__67595_to_check$jscomp$2$$,$G__67590_G__67595_to_check$jscomp$2$$=$G__67591_group$jscomp$32_to_check__$1$jscomp$1$$):($G__67594_current_id$jscomp$5_shapes$jscomp$60$$=$APP.$cljs$core$first$$($G__67590_G__67595_to_check$jscomp$2$$),$G__67590_G__67595_to_check$jscomp$2$$=$APP.$cljs$core$rest$$($G__67590_G__67595_to_check$jscomp$2$$))}};
$app$main$data$workspace$groups$prepare_create_group$$=function($changes$jscomp$182$$,$changes__$1$jscomp$70_id$jscomp$520_ids_to_delete$jscomp$2$$,$objects$jscomp$370$$,$page_id$jscomp$131$$,$shapes$jscomp$61$$,$base_name$jscomp$3_gname$$,$keep_name_QMARK__selrect$jscomp$47$$){var $frame_id$jscomp$65_grid_parents$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$61$$)),$parent_id$jscomp$71$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$61$$));
$base_name$jscomp$3_gname$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($keep_name_QMARK__selrect$jscomp$47$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$61$$),1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$61$$)),$APP.$cljs$cst$1608$group$$):$keep_name_QMARK__selrect$jscomp$47$$)?$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$61$$)):
$base_name$jscomp$3_gname$$;$keep_name_QMARK__selrect$jscomp$47$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($shapes$jscomp$61$$);var $group_idx$$=$app$common$files$helpers$get_position_on_parent$$($objects$jscomp$370$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($shapes$jscomp$61$$)))+1,$group$jscomp$33$$=$APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1795$index$$,$APP.$cljs$cst$725$name$$,
$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1614$shapes$$],[$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($keep_name_QMARK__selrect$jscomp$47$$),$group_idx$$,$base_name$jscomp$3_gname$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($keep_name_QMARK__selrect$jscomp$47$$),$APP.$cljs$cst$1608$group$$,
$changes__$1$jscomp$70_id$jscomp$520_ids_to_delete$jscomp$2$$,$parent_id$jscomp$71$$,$frame_id$jscomp$65_grid_parents$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($keep_name_QMARK__selrect$jscomp$47$$),$keep_name_QMARK__selrect$jscomp$47$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($keep_name_QMARK__selrect$jscomp$47$$),$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$shapes$jscomp$61$$)])),$shapes_to_detach$jscomp$2$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$component$in_component_copy_not_head_QMARK_$$,
$shapes$jscomp$61$$);$changes__$1$jscomp$70_id$jscomp$520_ids_to_delete$jscomp$2$$=$app$main$data$workspace$groups$get_empty_groups_after_group_creation$$($objects$jscomp$370$$,$parent_id$jscomp$71$$,$shapes$jscomp$61$$);var $target_cell$jscomp$6$$=$APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$370$$,$parent_id$jscomp$71$$))?$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$370$$,
$parent_id$jscomp$71$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($shapes$jscomp$61$$))):null;$frame_id$jscomp$65_grid_parents$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1619$parent_id$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$,
$objects$jscomp$370$$))),$shapes$jscomp$61$$);$changes__$1$jscomp$70_id$jscomp$520_ids_to_delete$jscomp$2$$=$app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$(function(){var $G__67468$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$182$$,
$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$,$page_id$jscomp$131$$),$objects$jscomp$370$$),$group$jscomp$33$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1795$index$$,$group_idx$$],null)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$shapes$jscomp$61$$),function($shape$jscomp$465$$){return $app$common$data$assoc_when$$($app$common$data$assoc_when$$($shape$jscomp$465$$,$APP.$cljs$cst$1872$constraints_h$$),$APP.$cljs$cst$1871$constraints_v$$)}),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$shapes$jscomp$61$$),$app$common$types$shape$layout$remove_layout_item_data$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$33$$),$APP.$cljs$core$reverse$$($shapes$jscomp$61$$)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$shapes_to_detach$jscomp$2$$),$app$common$types$component$detach_shape$$);return $APP.$cljs$core$truth_$$($target_cell$jscomp$6$$)?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67468$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent_id$jscomp$71$$],null),function($parent$jscomp$238$$){return $APP.$cljs$core$assoc_in$$($parent$jscomp$238$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$6$$),$APP.$cljs$cst$1614$shapes$$],null),new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$33$$)],null))}):$G__67468$$}(),$frame_id$jscomp$65_grid_parents$$,$APP.$app$common$types$shape$layout$assign_cells$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)),$changes__$1$jscomp$70_id$jscomp$520_ids_to_delete$jscomp$2$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$group$jscomp$33$$,$changes__$1$jscomp$70_id$jscomp$520_ids_to_delete$jscomp$2$$],null)};
$app$main$data$workspace$groups$remove_group_changes$$=function($it$jscomp$164$$,$page_id$jscomp$132$$,$group$jscomp$34$$,$objects$jscomp$371$$){var $children$jscomp$216$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67473_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$371$$,$p1__67473_SHARP_$$)},$app$common$files$helpers$order_by_indexed_shapes$$($objects$jscomp$371$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$34$$))),
$parent_id$jscomp$72$$=$APP.$app$common$files$helpers$get_parent_id$$($objects$jscomp$371$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$34$$)),$index_in_parent_parent$jscomp$239$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$371$$,$parent_id$jscomp$72$$);$index_in_parent_parent$jscomp$239$$=$APP.$cljs$core$ffirst$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($G__67477_p1__67474_SHARP_$$){$G__67477_p1__67474_SHARP_$$=$APP.$cljs$core$second$$($G__67477_p1__67474_SHARP_$$);
var $fexpr__67476$$=$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$34$$)]);return $fexpr__67476$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__67476$$.$cljs$core$IFn$_invoke$arity$1$($G__67477_p1__67474_SHARP_$$):$fexpr__67476$$($G__67477_p1__67474_SHARP_$$)},$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($index_in_parent_parent$jscomp$239$$))))+
1;return $app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$($it$jscomp$164$$,$page_id$jscomp$132$$),$objects$jscomp$371$$),$parent_id$jscomp$72$$,$children$jscomp$216$$,$index_in_parent_parent$jscomp$239$$),new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$34$$)],null))};
$app$main$data$workspace$groups$remove_frame_changes$$=function($it$jscomp$165$$,$page_id$jscomp$133$$,$frame$jscomp$18$$,$objects$jscomp$372$$){var $children$jscomp$217$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67481_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$372$$,$p1__67481_SHARP_$$)},$app$common$files$helpers$order_by_indexed_shapes$$($objects$jscomp$372$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$18$$))),
$parent_id$jscomp$73$$=$APP.$app$common$files$helpers$get_parent_id$$($objects$jscomp$372$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$18$$)),$idx_in_parent$$=$app$common$files$helpers$get_position_on_parent$$($objects$jscomp$372$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$18$$))+1;return $app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$04$$(function(){var $G__67487$$=
$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$($it$jscomp$165$$,$page_id$jscomp$133$$),$objects$jscomp$372$$);return $APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$18$$)?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67487$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$18$$),
$app$common$types$shape$layout$remove_layout_item_data$$):$G__67487$$}(),$parent_id$jscomp$73$$,$children$jscomp$217$$,$idx_in_parent$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$18$$)],null))};
$APP.$app$main$data$workspace$groups$group_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($id$jscomp$521$$,$ids$jscomp$87$$,$p__67502$$){var $map__67503__$1$$=$APP.$cljs$core$__destructure_map$$($p__67502$$),$change_selection_QMARK_$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67503__$1$$,$APP.$cljs$cst$3617$change_selection_QMARK_$$,!1);typeof $app$main$data$workspace$groups$group_shapes_67504$$==="undefined"&&($app$main$data$workspace$groups$group_shapes_67504$$=
function($id$jscomp$522$$,$ids$jscomp$88$$,$p__67502$jscomp$1$$,$map__67503$jscomp$1$$,$change_selection_QMARK_$jscomp$5$$,$meta67505$$){this.id=$id$jscomp$522$$;this.ids=$ids$jscomp$88$$;this.$p__67502$=$p__67502$jscomp$1$$;this.$map__67503$=$map__67503$jscomp$1$$;this.$change_selection_QMARK_$=$change_selection_QMARK_$jscomp$5$$;this.$meta67505$=$meta67505$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$groups$group_shapes_67504$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$groups$group_shapes_67504$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3757$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_group_shapes$$},$app$main$data$workspace$groups$group_shapes_67504$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67506$$,$meta67505__$1$$){return new $app$main$data$workspace$groups$group_shapes_67504$$(this.id,this.ids,this.$p__67502$,this.$map__67503$,this.$change_selection_QMARK_$,
$meta67505__$1$$)},$app$main$data$workspace$groups$group_shapes_67504$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67505$},$app$main$data$workspace$groups$group_shapes_67504$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$groups$group_shapes_67504$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($group$jscomp$35_id__$1$jscomp$7_it$jscomp$166$$,$parents$jscomp$10_state$jscomp$423$$){$group$jscomp$35_id__$1$jscomp$7_it$jscomp$166$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$(this.id,$APP.$app$common$uuid$next$$());var $changes$jscomp$183_page_id$jscomp$134_vec__67510$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($parents$jscomp$10_state$jscomp$423$$),$objects$jscomp$373$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($parents$jscomp$10_state$jscomp$423$$,$changes$jscomp$183_page_id$jscomp$134_vec__67510$$),$shapes$jscomp$62$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$is_variant_QMARK_$$,
$app$main$data$workspace$groups$shapes_for_grouping$$($objects$jscomp$373$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67491_SHARP_$$){return $APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$373$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$373$$,$p1__67491_SHARP_$$))},$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$373$$,this.ids))));$parents$jscomp$10_state$jscomp$423$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1619$parent_id$$),$shapes$jscomp$62$$);if($APP.$cljs$core$empty_QMARK_$$($shapes$jscomp$62$$))return null;$changes$jscomp$183_page_id$jscomp$134_vec__67510$$=$app$main$data$workspace$groups$prepare_create_group$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$group$jscomp$35_id__$1$jscomp$7_it$jscomp$166$$,$objects$jscomp$373$$,$changes$jscomp$183_page_id$jscomp$134_vec__67510$$,
$shapes$jscomp$62$$,"Group",!1);$group$jscomp$35_id__$1$jscomp$7_it$jscomp$166$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$183_page_id$jscomp$134_vec__67510$$,0,null);$changes$jscomp$183_page_id$jscomp$134_vec__67510$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$183_page_id$jscomp$134_vec__67510$$,1,null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$183_page_id$jscomp$134_vec__67510$$),
$APP.$cljs$core$truth_$$(this.$change_selection_QMARK_$)?$APP.$app$main$data$workspace$selection$select_shapes$$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$35_id__$1$jscomp$7_it$jscomp$166$$))):null,$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$parents$jscomp$10_state$jscomp$423$$],
null)))});return new $app$main$data$workspace$groups$group_shapes_67504$$($id$jscomp$521$$,$ids$jscomp$87$$,$p__67502$$,$map__67503__$1$$,$change_selection_QMARK_$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$groups$group_selected$$=function(){typeof $app$main$data$workspace$groups$group_selected_67515$$==="undefined"&&($app$main$data$workspace$groups$group_selected_67515$$=function($meta67516$$){this.$meta67516$=$meta67516$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$groups$group_selected_67515$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$groups$group_selected_67515$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3758$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_group_selected$$},$app$main$data$workspace$groups$group_selected_67515$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67517$$,$meta67516__$1$$){return new $app$main$data$workspace$groups$group_selected_67515$$($meta67516__$1$$)},$app$main$data$workspace$groups$group_selected_67515$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67516$},$app$main$data$workspace$groups$group_selected_67515$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$groups$group_selected_67515$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2000_selected$jscomp$39$$,$state$jscomp$424$$){$_$jscomp$2000_selected$jscomp$39$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$424$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$groups$group_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(null,$_$jscomp$2000_selected$jscomp$39$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3617$change_selection_QMARK_$$,!0])))});return new $app$main$data$workspace$groups$group_selected_67515$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$groups$ungroup_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($ids$jscomp$89$$,$p__67530$$){var $map__67531__$1$$=$APP.$cljs$core$__destructure_map$$($p__67530$$),$change_selection_QMARK_$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67531__$1$$,$APP.$cljs$cst$3617$change_selection_QMARK_$$,!1);typeof $app$main$data$workspace$groups$ungroup_shapes_67532$$==="undefined"&&($app$main$data$workspace$groups$ungroup_shapes_67532$$=function($ids$jscomp$90$$,
$p__67530$jscomp$1$$,$map__67531$jscomp$1$$,$change_selection_QMARK_$jscomp$7$$,$meta67533$$){this.ids=$ids$jscomp$90$$;this.$p__67530$=$p__67530$jscomp$1$$;this.$map__67531$=$map__67531$jscomp$1$$;this.$change_selection_QMARK_$=$change_selection_QMARK_$jscomp$7$$;this.$meta67533$=$meta67533$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$groups$ungroup_shapes_67532$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$groups$ungroup_shapes_67532$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3759$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_ungroup_shapes$$},$app$main$data$workspace$groups$ungroup_shapes_67532$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67534$$,$meta67533__$1$$){return new $app$main$data$workspace$groups$ungroup_shapes_67532$$(this.ids,this.$p__67530$,this.$map__67531$,this.$change_selection_QMARK_$,$meta67533__$1$$)},
$app$main$data$workspace$groups$ungroup_shapes_67532$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67533$},$app$main$data$workspace$groups$ungroup_shapes_67532$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$groups$ungroup_shapes_67532$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($ids__$1$jscomp$11_it$jscomp$167$$,$parents$jscomp$11_state$jscomp$425$$){var $it__$1$jscomp$49$$=this,$page_id$jscomp$135$$=
$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($parents$jscomp$11_state$jscomp$425$$),$objects$jscomp$374$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($parents$jscomp$11_state$jscomp$425$$,$page_id$jscomp$135$$);$ids__$1$jscomp$11_it$jscomp$167$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67525_SHARP_$$){return $APP.$app$common$types$component$is_variant_container_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$374$$,
$p1__67525_SHARP_$$))},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67524_SHARP_$$){return $APP.$app$common$types$component$instance_head_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$374$$,$p1__67524_SHARP_$$))},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67523_SHARP_$$){return $APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$374$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$374$$,
$p1__67523_SHARP_$$))},this.ids)));var $changes$jscomp$184_changes_list$$=$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($shape$jscomp$466_shape_id$jscomp$84$$){$shape$jscomp$466_shape_id$jscomp$84$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$374$$,$shape$jscomp$466_shape_id$jscomp$84$$);var $G__67539$$=$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$466_shape_id$jscomp$84$$)||
$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$466_shape_id$jscomp$84$$)?$app$main$data$workspace$groups$remove_group_changes$$($it__$1$jscomp$49$$,$page_id$jscomp$135$$,$shape$jscomp$466_shape_id$jscomp$84$$,$objects$jscomp$374$$):$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$466_shape_id$jscomp$84$$)?$app$main$data$workspace$groups$remove_frame_changes$$($it__$1$jscomp$49$$,$page_id$jscomp$135$$,$shape$jscomp$466_shape_id$jscomp$84$$,
$objects$jscomp$374$$):null;return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$374$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$466_shape_id$jscomp$84$$)))?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($G__67539$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$466_shape_id$jscomp$84$$)],
null),$APP.$app$common$types$shape$layout$assign_cells$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)):$G__67539$$}),$ids__$1$jscomp$11_it$jscomp$167$$);$parents$jscomp$11_state$jscomp$425$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__67526_SHARP_$$){return $app$common$files$helpers$get_parent$$($objects$jscomp$374$$,
$p1__67526_SHARP_$$)}),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$266$id$$)),$ids__$1$jscomp$11_it$jscomp$167$$);var $child_ids$jscomp$3$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__67527_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$374$$,
$p1__67527_SHARP_$$),$APP.$cljs$cst$1614$shapes$$)}),$ids__$1$jscomp$11_it$jscomp$167$$);$changes$jscomp$184_changes_list$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$vec$$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$changes$jscomp$184_changes_list$$]))),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$vec$$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$3137$undo_changes$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$changes$jscomp$184_changes_list$$]))),$APP.$cljs$cst$1786$origin$$,$it__$1$jscomp$49$$],null);var $undo_id$jscomp$7$$=Symbol();return $APP.$cljs$core$empty_QMARK_$$($ids__$1$jscomp$11_it$jscomp$167$$)?null:(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$7$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$184_changes_list$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$parents$jscomp$11_state$jscomp$425$$],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$7$$),$APP.$cljs$core$truth_$$(this.$change_selection_QMARK_$)?$APP.$app$main$data$workspace$selection$select_shapes$$($child_ids$jscomp$3$$):null)});return new $app$main$data$workspace$groups$ungroup_shapes_67532$$($ids$jscomp$89$$,$p__67530$$,$map__67531__$1$$,$change_selection_QMARK_$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$groups$ungroup_selected$$=function(){typeof $app$main$data$workspace$groups$ungroup_selected_67543$$==="undefined"&&($app$main$data$workspace$groups$ungroup_selected_67543$$=function($meta67544$$){this.$meta67544$=$meta67544$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$groups$ungroup_selected_67543$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$groups$ungroup_selected_67543$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3760$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_ungroup_selected$$},$app$main$data$workspace$groups$ungroup_selected_67543$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67545$$,$meta67544__$1$$){return new $app$main$data$workspace$groups$ungroup_selected_67543$$($meta67544__$1$$)},$app$main$data$workspace$groups$ungroup_selected_67543$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67544$},$app$main$data$workspace$groups$ungroup_selected_67543$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$groups$ungroup_selected_67543$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2002_selected$jscomp$40$$,$state$jscomp$426$$){$_$jscomp$2002_selected$jscomp$40$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$426$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$groups$ungroup_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($_$jscomp$2002_selected$jscomp$40$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3617$change_selection_QMARK_$$,!0])))});return new $app$main$data$workspace$groups$ungroup_selected_67543$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$groups$mask_group$cljs$0core$0IFn$0_invoke$0arity$01$$=function($ids$jscomp$91$$){typeof $app$main$data$workspace$groups$mask_group_67555$$==="undefined"&&($app$main$data$workspace$groups$mask_group_67555$$=function($ids$jscomp$92$$,$meta67556$$){this.ids=$ids$jscomp$92$$;this.$meta67556$=$meta67556$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$groups$mask_group_67555$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$groups$mask_group_67555$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3761$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_mask_group$$},$app$main$data$workspace$groups$mask_group_67555$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67557$$,$meta67556__$1$$){return new $app$main$data$workspace$groups$mask_group_67555$$(this.ids,$meta67556__$1$$)},$app$main$data$workspace$groups$mask_group_67555$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67556$},$app$main$data$workspace$groups$mask_group_67555$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$groups$mask_group_67555$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($group$jscomp$36_it$jscomp$168_page_id$jscomp$136$$,$state$jscomp$427$$){var $self__$jscomp$4489$$=this;$group$jscomp$36_it$jscomp$168_page_id$jscomp$136$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$427$$);
var $objects$jscomp$375$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$427$$,$group$jscomp$36_it$jscomp$168_page_id$jscomp$136$$),$changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67552_SHARP_$$){return $APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$375$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$375$$,
$p1__67552_SHARP_$$))},$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$375$$,function(){var $or__5025__auto__$jscomp$736$$=$self__$jscomp$4489$$.ids;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$736$$)?$or__5025__auto__$jscomp$736$$:$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$427$$)}()));$changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$=$app$main$data$workspace$groups$shapes_for_grouping$$($objects$jscomp$375$$,
$changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$);var $first_shape$jscomp$4$$=$APP.$cljs$core$first$$($changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$);if($APP.$cljs$core$empty_QMARK_$$($changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$))return null;$changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$),
1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$)),$APP.$cljs$cst$1608$group$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$first_shape$jscomp$4$$,$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
$group$jscomp$36_it$jscomp$168_page_id$jscomp$136$$),$objects$jscomp$375$$)],null):$app$main$data$workspace$groups$prepare_create_group$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$APP.$app$common$uuid$next$$(),$objects$jscomp$375$$,$group$jscomp$36_it$jscomp$168_page_id$jscomp$136$$,$changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$,"Mask",!0);$group$jscomp$36_it$jscomp$168_page_id$jscomp$136$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$,
0,null);$changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$,1,null);$changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$=$APP.$app$common$files$changes_builder$resize_parents$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$,
$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$36_it$jscomp$168_page_id$jscomp$136$$),function($shape$jscomp$467$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape$jscomp$467$$,$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$1902$scale$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1902$scale$$]))}),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$36_it$jscomp$168_page_id$jscomp$136$$)],null),function($group__$1$jscomp$2$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($group__$1$jscomp$2$$,$APP.$cljs$cst$1609$masked_group$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$4$$),$APP.$cljs$cst$1604$points$$,$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$4$$),
$APP.$cljs$cst$1289$transform$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$4$$),$APP.$cljs$cst$1787$transform_inverse$$,$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$4$$)]))}),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$36_it$jscomp$168_page_id$jscomp$136$$)],null));var $undo_id$jscomp$8$$=Symbol();
return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$8$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$186_changes__$1$jscomp$71_selected$jscomp$41_shapes$jscomp$63_vec__67568$$),$APP.$app$main$data$workspace$selection$select_shapes$$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$36_it$jscomp$168_page_id$jscomp$136$$))),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$36_it$jscomp$168_page_id$jscomp$136$$)],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$8$$))});return new $app$main$data$workspace$groups$mask_group_67555$$($ids$jscomp$91$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$groups$unmask_group$cljs$0core$0IFn$0_invoke$0arity$01$$=function($ids$jscomp$93$$){typeof $app$main$data$workspace$groups$unmask_group_67575$$==="undefined"&&($app$main$data$workspace$groups$unmask_group_67575$$=function($ids$jscomp$94$$,$meta67576$$){this.ids=$ids$jscomp$94$$;this.$meta67576$=$meta67576$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$groups$unmask_group_67575$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$groups$unmask_group_67575$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3762$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_unmask_group$$},$app$main$data$workspace$groups$unmask_group_67575$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67577$$,$meta67576__$1$$){return new $app$main$data$workspace$groups$unmask_group_67575$$(this.ids,$meta67576__$1$$)},$app$main$data$workspace$groups$unmask_group_67575$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67576$},$app$main$data$workspace$groups$unmask_group_67575$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$groups$unmask_group_67575$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$169_page_id$jscomp$137$$,$changes$jscomp$187_masked_groups_state$jscomp$428$$){$it$jscomp$169_page_id$jscomp$137$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$187_masked_groups_state$jscomp$428$$);
var $objects$jscomp$376$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$187_masked_groups_state$jscomp$428$$,$it$jscomp$169_page_id$jscomp$137$$);$changes$jscomp$187_masked_groups_state$jscomp$428$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67572_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1610$bool$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__67572_SHARP_$$))||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__67572_SHARP_$$))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67571_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$376$$,$p1__67571_SHARP_$$)},$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$(this.ids,$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($changes$jscomp$187_masked_groups_state$jscomp$428$$))));
$changes$jscomp$187_masked_groups_state$jscomp$428$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes$jscomp$188$$,$mask$jscomp$13$$){return $APP.$app$common$files$changes_builder$resize_parents$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$188$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($mask$jscomp$13$$)],
null),function($shape$jscomp$468$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$468$$,$APP.$cljs$cst$1609$masked_group$$)}),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($mask$jscomp$13$$)],null))},$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$it$jscomp$169_page_id$jscomp$137$$),
$objects$jscomp$376$$),$changes$jscomp$187_masked_groups_state$jscomp$428$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$187_masked_groups_state$jscomp$428$$))});return new $app$main$data$workspace$groups$unmask_group_67575$$($ids$jscomp$93$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$common$thumbnails$fmt_object_id$cljs$0core$0IFn$0_invoke$0arity$04$$=function($file_id$jscomp$111$$,$page_id$jscomp$139$$,$frame_id$jscomp$66$$,$tag$jscomp$73$$){return""+($file_id$jscomp$111$$??"")+"/"+($page_id$jscomp$139$$??"")+"/"+($frame_id$jscomp$66$$??"")+"/"+($tag$jscomp$73$$??"")};$APP.$app$main$rasterizer$send_message_BANG_$$=function($message$jscomp$96$$){return $APP.$app$main$rasterizer$instance$$.contentWindow.postMessage($message$jscomp$96$$,$APP.$app$main$rasterizer$origin$$)};
$app$main$rasterizer$replace_uris$$=function($styles$jscomp$9$$){var $public_uri$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$public_uri$$),$rasterizer_uri$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$rasterizer_uri$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($public_uri$$,$rasterizer_uri$$)?$styles$jscomp$9$$:$APP.$cuerdas$core$replace$$($styles$jscomp$9$$,$public_uri$$,$rasterizer_uri$$)};
$APP.$app$main$rasterizer$render$$=function($data$jscomp$327_message$jscomp$98_p__67478$$){var $map__67479__$1_result$jscomp$278_result__$1$jscomp$32$$=$APP.$cljs$core$__destructure_map$$($data$jscomp$327_message$jscomp$98_p__67478$$);$data$jscomp$327_message$jscomp$98_p__67478$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67479__$1_result$jscomp$278_result__$1$jscomp$32$$,$APP.$cljs$cst$142$data$$);var $styles$jscomp$10_styles__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67479__$1_result$jscomp$278_result__$1$jscomp$32$$,
$APP.$cljs$cst$2940$styles$$),$width$jscomp$112$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67479__$1_result$jscomp$278_result__$1$jscomp$32$$,$APP.$cljs$cst$290$width$$);$map__67479__$1_result$jscomp$278_result__$1$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67479__$1_result$jscomp$278_result__$1$jscomp$32$$,$APP.$cljs$cst$828$result$$);$styles$jscomp$10_styles__$1$$=$app$main$rasterizer$replace_uris$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($styles$jscomp$10_styles__$1$$,
""));$map__67479__$1_result$jscomp$278_result__$1$jscomp$32$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($map__67479__$1_result$jscomp$278_result__$1$jscomp$32$$,"blob");var $id$jscomp$523$$=""+($APP.$app$common$uuid$next$$()??"");$data$jscomp$327_message$jscomp$98_p__67478$$={id:$id$jscomp$523$$,scope:"penpot/rasterizer",payload:{data:$data$jscomp$327_message$jscomp$98_p__67478$$,styles:$styles$jscomp$10_styles__$1$$,width:$width$jscomp$112$$,result:$map__67479__$1_result$jscomp$278_result__$1$jscomp$32$$}};
$APP.$app$main$rasterizer$ready_QMARK_$$?$APP.$app$main$rasterizer$send_message_BANG_$$($data$jscomp$327_message$jscomp$98_p__67478$$):$APP.$app$main$rasterizer$queue$$.push($data$jscomp$327_message$jscomp$98_p__67478$$);return $APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$mapcat$$(function($msg$jscomp$30$$){var $G__67483$$=$msg$jscomp$30$$.type;switch($G__67483$$){case "success":return(0,$APP.$beicon$v2$core$of$$)($msg$jscomp$30$$.payload);case "failure":return $APP.$beicon$v2$core$throw$0$$(Error($msg$jscomp$30$$.payload));
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__67483$$)].join(""));}},$APP.$beicon$v2$core$filter$$(function($p1__67475_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$523$$,$p1__67475_SHARP_$$.id)},$APP.$app$main$rasterizer$msgbus$$)))};
$APP.$app$main$ui$shapes$path$path_shape$$=function($pdata$jscomp$3_props_67462$$){var $shape$jscomp$469$$=$pdata$jscomp$3_props_67462$$.shape,$content$jscomp$164$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$469$$,$APP.$cljs$cst$1637$content$$);$pdata$jscomp$3_props_67462$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($content$jscomp$164$$)],function(){try{return $content$jscomp$164$$==null?"":$app$common$types$path$impl$path_data_QMARK_$$($content$jscomp$164$$)?
$content$jscomp$164$$.toString():$APP.$app$common$types$path$impl$path_data$$($content$jscomp$164$$).toString()}catch($e67465$$){var $cause$jscomp$82$$=$e67465$$;$APP.$app$common$logging$enabled_QMARK_$$("app.main.ui.shapes.path",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$275$hint$$,"unexpected error on formatting path"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3768$shape_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$469$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$469$$)],null)],null)}),$cause$jscomp$82$$,
"app.main.ui.shapes.path",$APP.$cljs$cst$849$error$$,!1);return""}});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$shape_custom_strokes$$,{shape:$shape$jscomp$469$$,children:(0,$APP.$rumext$v2$jsx$$)("path",{d:$pdata$jscomp$3_props_67462$$})})};
$APP.$app$main$ui$shapes$bool$bool_shape$$=function($shape_wrapper$jscomp$1$$){return function($metadata_QMARK_$jscomp$2_props_67485$$){var $shape$jscomp$470$$=$metadata_QMARK_$jscomp$2_props_67485$$.shape,$child_objs__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($metadata_QMARK_$jscomp$2_props_67485$$.childs);$metadata_QMARK_$jscomp$2_props_67485$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$shapes$export$0$include_metadata_ctx$$);var $content$jscomp$165$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$470$$),
$APP.$rumext$v2$adapt$$($child_objs__$1$$)],function(){var $content$jscomp$166$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$470$$);return $content$jscomp$166$$!=null?$content$jscomp$166$$:$child_objs__$1$$!=null?$app$common$types$path$calc_bool_content$$($shape$jscomp$470$$,$child_objs__$1$$):null}),$shape__$1$jscomp$37$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$470$$),$APP.$rumext$v2$adapt$$($content$jscomp$165$$)],
function(){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$470$$,$APP.$cljs$cst$1637$content$$,$content$jscomp$165$$)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$content$jscomp$165$$!=null?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$shapes$path$path_shape$$,{shape:$shape__$1$jscomp$37$$}):null,$APP.$cljs$core$truth_$$($metadata_QMARK_$jscomp$2_props_67485$$)?(0,$APP.$rumext$v2$jsx$$)("penpot:bool",{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$20$$,
$item$jscomp$76$$){$out_arr__44124__auto__$jscomp$20$$.push((0,$APP.$rumext$v2$jsx$$)($shape_wrapper$jscomp$1$$,{shape:$item$jscomp$76$$},""+($item$jscomp$76$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$76$$,$APP.$cljs$cst$266$id$$)??"")));return $out_arr__44124__auto__$jscomp$20$$},[],$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67482_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($child_objs__$1$$,$p1__67482_SHARP_$$)},
$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$37$$)))}):null]})}};
$APP.$app$main$ui$shapes$circle$circle_shape$$=function($props_67567_shape$jscomp$471$$){$props_67567_shape$jscomp$471$$=$props_67567_shape$jscomp$471$$.shape;var $props__$1$jscomp$24_x$jscomp$1182$$=$props_67567_shape$jscomp$471$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_67567_shape$jscomp$471$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$418$$=$props_67567_shape$jscomp$471$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_67567_shape$jscomp$471$$,$APP.$cljs$cst$1511$y$$),
$w$jscomp$34$$=$props_67567_shape$jscomp$471$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_67567_shape$jscomp$471$$,$APP.$cljs$cst$290$width$$),$h$jscomp$156$$=$props_67567_shape$jscomp$471$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_67567_shape$jscomp$471$$,$APP.$cljs$cst$1522$height$$),$t$jscomp$91$$=$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($props_67567_shape$jscomp$471$$),$cx$jscomp$16$$=$props__$1$jscomp$24_x$jscomp$1182$$+
$w$jscomp$34$$/2,$cy$jscomp$17$$=$y$jscomp$418$$+$h$jscomp$156$$/2,$rx$jscomp$15$$=$w$jscomp$34$$/2,$ry$jscomp$9$$=$h$jscomp$156$$/2;$props__$1$jscomp$24_x$jscomp$1182$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($props_67567_shape$jscomp$471$$)],function(){return $APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({},{cx:$cx$jscomp$16$$,cy:$cy$jscomp$17$$,rx:$rx$jscomp$15$$,ry:$ry$jscomp$9$$,transform:$t$jscomp$91$$})});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$shape_custom_strokes$$,
{shape:$props_67567_shape$jscomp$471$$,children:(0,$APP.$rumext$v2$create_element$$)("ellipse",$props__$1$jscomp$24_x$jscomp$1182$$)})};
$app$main$ui$shapes$filters$filter_str$$=function($filter_id$$,$JSCompiler_inline_result$jscomp$1145_shape$jscomp$472$$){var $and__5023__auto__$jscomp$inline_6653_or__5025__auto__$jscomp$inline_6652$$=$APP.$cljs$core$seq$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1145_shape$jscomp$472$$)));$and__5023__auto__$jscomp$inline_6653_or__5025__auto__$jscomp$inline_6652$$?
$JSCompiler_inline_result$jscomp$1145_shape$jscomp$472$$=$and__5023__auto__$jscomp$inline_6653_or__5025__auto__$jscomp$inline_6652$$:($and__5023__auto__$jscomp$inline_6653_or__5025__auto__$jscomp$inline_6652$$=$APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1145_shape$jscomp$472$$),$JSCompiler_inline_result$jscomp$1145_shape$jscomp$472$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_6653_or__5025__auto__$jscomp$inline_6652$$)?$APP.$cljs$core$not$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1145_shape$jscomp$472$$)))&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1908$layer_blur$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1145_shape$jscomp$472$$))):$and__5023__auto__$jscomp$inline_6653_or__5025__auto__$jscomp$inline_6652$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1145_shape$jscomp$472$$)?"url(#"+($filter_id$$??"")+")":null};
$app$main$ui$shapes$filters$color_matrix$$=function($a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$){$a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$=$APP.$rumext$v2$util$wrap_props$$($a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$);$a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$=$APP.$cljs$core$__destructure_map$$($a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$);
$a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$,$APP.$cljs$cst$1298$color$$);var $map__67649__$1_opacity$jscomp$26_r$jscomp$115_r__$1$jscomp$7$$=$APP.$cljs$core$__destructure_map$$($a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$);$a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67649__$1_opacity$jscomp$26_r$jscomp$115_r__$1$jscomp$7$$,$APP.$cljs$cst$1298$color$$);$map__67649__$1_opacity$jscomp$26_r$jscomp$115_r__$1$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67649__$1_opacity$jscomp$26_r$jscomp$115_r__$1$jscomp$7$$,$APP.$cljs$cst$1734$opacity$$);$a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$=$app$common$types$color$hex__GT_rgba$$($a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$,
$map__67649__$1_opacity$jscomp$26_r$jscomp$115_r__$1$jscomp$7$$);$map__67649__$1_opacity$jscomp$26_r$jscomp$115_r__$1$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$,0,null);var $g$jscomp$137_g__$1$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$,1,null),$b$jscomp$318_b__$1$jscomp$5_vec__67653$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$,2,null);$a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$,3,null);$b$jscomp$318_b__$1$jscomp$5_vec__67653$$=new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$map__67649__$1_opacity$jscomp$26_r$jscomp$115_r__$1$jscomp$7$$/255,$g$jscomp$137_g__$1$jscomp$1$$/255,$b$jscomp$318_b__$1$jscomp$5_vec__67653$$/255],null);$map__67649__$1_opacity$jscomp$26_r$jscomp$115_r__$1$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$318_b__$1$jscomp$5_vec__67653$$,0,null);$g$jscomp$137_g__$1$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$318_b__$1$jscomp$5_vec__67653$$,
1,null);$b$jscomp$318_b__$1$jscomp$5_vec__67653$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$318_b__$1$jscomp$5_vec__67653$$,2,null);return(0,$APP.$rumext$v2$jsx$$)("feColorMatrix",{type:"matrix",values:"0 0 0 0 "+($map__67649__$1_opacity$jscomp$26_r$jscomp$115_r__$1$jscomp$7$$??"")+" 0 0 0 0 "+($g$jscomp$137_g__$1$jscomp$1$$??"")+" 0 0 0 0 "+($b$jscomp$318_b__$1$jscomp$5_vec__67653$$??"")+" 0 0 0 "+($a$jscomp$388_color__$1$jscomp$2_map__67648_map__67648__$1_map__67649_props_67647_vec__67650$$??
"")+" 0"})};
$app$main$ui$shapes$filters$drop_shadow_filter$$=function($filter_in_map__67657_props_67656$$){$filter_in_map__67657_props_67656$$=$APP.$rumext$v2$util$wrap_props$$($filter_in_map__67657_props_67656$$);var $color$jscomp$54_map__67657__$1_map__67658$$=$APP.$cljs$core$__destructure_map$$($filter_in_map__67657_props_67656$$);$filter_in_map__67657_props_67656$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$54_map__67657__$1_map__67658$$,$cljs$cst$3769$filter_in$$);var $filter_id$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$54_map__67657__$1_map__67658$$,
$cljs$cst$3770$filter_id$$);$color$jscomp$54_map__67657__$1_map__67658$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$54_map__67657__$1_map__67658$$,$APP.$cljs$cst$1430$params$$);var $map__67658__$1_spread$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($color$jscomp$54_map__67657__$1_map__67658$$);$color$jscomp$54_map__67657__$1_map__67658$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67658__$1_spread$jscomp$3$$,$APP.$cljs$cst$1298$color$$);var $offset_x$jscomp$6$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67658__$1_spread$jscomp$3$$,$APP.$cljs$cst$1650$offset_x$$),$offset_y$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67658__$1_spread$jscomp$3$$,$APP.$cljs$cst$1651$offset_y$$),$blur$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67658__$1_spread$jscomp$3$$,$APP.$cljs$cst$1653$blur$$);$map__67658__$1_spread$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67658__$1_spread$jscomp$3$$,
$APP.$cljs$cst$1652$spread$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("feColorMatrix",{"in":"SourceAlpha",type:"matrix",values:"0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0"}),$map__67658__$1_spread$jscomp$3$$>0?(0,$APP.$rumext$v2$jsx$$)("feMorphology",{radius:$map__67658__$1_spread$jscomp$3$$,operator:"dilate","in":"SourceAlpha",result:$filter_id$jscomp$1$$}):null,$map__67658__$1_spread$jscomp$3$$<0?(0,$APP.$rumext$v2$jsx$$)("feMorphology",{radius:-$map__67658__$1_spread$jscomp$3$$,
operator:"erode","in":"SourceAlpha",result:$filter_id$jscomp$1$$}):null,(0,$APP.$rumext$v2$jsx$$)("feOffset",{dx:$offset_x$jscomp$6$$,dy:$offset_y$jscomp$6$$}),(0,$APP.$rumext$v2$jsx$$)("feGaussianBlur",{stdDeviation:$blur$jscomp$7$$/2}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$filters$color_matrix$$,{color:$color$jscomp$54_map__67657__$1_map__67658$$}),(0,$APP.$rumext$v2$jsx$$)("feBlend",{mode:"normal",in2:$filter_in_map__67657_props_67656$$,result:$filter_id$jscomp$1$$})]})};
$app$main$ui$shapes$filters$inner_shadow_filter$$=function($filter_in$jscomp$1_map__67661_props_67660$$){$filter_in$jscomp$1_map__67661_props_67660$$=$APP.$rumext$v2$util$wrap_props$$($filter_in$jscomp$1_map__67661_props_67660$$);var $color$jscomp$55_map__67661__$1_map__67662$$=$APP.$cljs$core$__destructure_map$$($filter_in$jscomp$1_map__67661_props_67660$$);$filter_in$jscomp$1_map__67661_props_67660$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$55_map__67661__$1_map__67662$$,
$cljs$cst$3769$filter_in$$);var $filter_id$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$55_map__67661__$1_map__67662$$,$cljs$cst$3770$filter_id$$);$color$jscomp$55_map__67661__$1_map__67662$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$55_map__67661__$1_map__67662$$,$APP.$cljs$cst$1430$params$$);var $map__67662__$1_spread$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($color$jscomp$55_map__67661__$1_map__67662$$);$color$jscomp$55_map__67661__$1_map__67662$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67662__$1_spread$jscomp$4$$,$APP.$cljs$cst$1298$color$$);var $offset_x$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67662__$1_spread$jscomp$4$$,$APP.$cljs$cst$1650$offset_x$$),$offset_y$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67662__$1_spread$jscomp$4$$,$APP.$cljs$cst$1651$offset_y$$),$blur$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67662__$1_spread$jscomp$4$$,
$APP.$cljs$cst$1653$blur$$);$map__67662__$1_spread$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67662__$1_spread$jscomp$4$$,$APP.$cljs$cst$1652$spread$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("feColorMatrix",{"in":"SourceAlpha",type:"matrix",values:"0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0",result:"hardAlpha"}),$map__67662__$1_spread$jscomp$4$$>0?(0,$APP.$rumext$v2$jsx$$)("feMorphology",{radius:$map__67662__$1_spread$jscomp$4$$,
operator:"erode","in":"SourceAlpha",result:$filter_id$jscomp$2$$}):null,(0,$APP.$rumext$v2$jsx$$)("feOffset",{dx:$offset_x$jscomp$7$$,dy:$offset_y$jscomp$7$$}),(0,$APP.$rumext$v2$jsx$$)("feGaussianBlur",{stdDeviation:$blur$jscomp$8$$/2}),(0,$APP.$rumext$v2$jsx$$)("feComposite",{in2:"hardAlpha",operator:"arithmetic",k2:"-1",k3:"1"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$filters$color_matrix$$,{color:$color$jscomp$55_map__67661__$1_map__67662$$}),(0,$APP.$rumext$v2$jsx$$)("feBlend",{mode:"normal",
in2:$filter_in$jscomp$1_map__67661_props_67660$$,result:$filter_id$jscomp$2$$})]})};
$app$main$ui$shapes$filters$background_blur_filter$$=function($filter_id$jscomp$3_map__67664_props_67663$$){$filter_id$jscomp$3_map__67664_props_67663$$=$APP.$rumext$v2$util$wrap_props$$($filter_id$jscomp$3_map__67664_props_67663$$);var $map__67664__$1_params$jscomp$262$$=$APP.$cljs$core$__destructure_map$$($filter_id$jscomp$3_map__67664_props_67663$$);$filter_id$jscomp$3_map__67664_props_67663$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67664__$1_params$jscomp$262$$,$cljs$cst$3770$filter_id$$);
$map__67664__$1_params$jscomp$262$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67664__$1_params$jscomp$262$$,$APP.$cljs$cst$1430$params$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("feGaussianBlur",{"in":"BackgroundImage",stdDeviation:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($map__67664__$1_params$jscomp$262$$)/2}),(0,$APP.$rumext$v2$jsx$$)("feComposite",{in2:"SourceAlpha",operator:"in",result:$filter_id$jscomp$3_map__67664_props_67663$$})]})};
$app$main$ui$shapes$filters$layer_blur_filter$$=function($filter_id$jscomp$4_map__67667_props_67665$$){$filter_id$jscomp$4_map__67667_props_67665$$=$APP.$rumext$v2$util$wrap_props$$($filter_id$jscomp$4_map__67667_props_67665$$);var $map__67667__$1_params$jscomp$263$$=$APP.$cljs$core$__destructure_map$$($filter_id$jscomp$4_map__67667_props_67665$$);$filter_id$jscomp$4_map__67667_props_67665$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67667__$1_params$jscomp$263$$,$cljs$cst$3770$filter_id$$);
$map__67667__$1_params$jscomp$263$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67667__$1_params$jscomp$263$$,$APP.$cljs$cst$1430$params$$);return(0,$APP.$rumext$v2$jsx$$)("feGaussianBlur",{stdDeviation:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($map__67667__$1_params$jscomp$263$$),result:$filter_id$jscomp$4_map__67667_props_67665$$})};
$app$main$ui$shapes$filters$image_fix_filter$$=function($filter_id$jscomp$5_map__67669_map__67669__$1_props_67668$$){$filter_id$jscomp$5_map__67669_map__67669__$1_props_67668$$=$APP.$rumext$v2$util$wrap_props$$($filter_id$jscomp$5_map__67669_map__67669__$1_props_67668$$);$filter_id$jscomp$5_map__67669_map__67669__$1_props_67668$$=$APP.$cljs$core$__destructure_map$$($filter_id$jscomp$5_map__67669_map__67669__$1_props_67668$$);$filter_id$jscomp$5_map__67669_map__67669__$1_props_67668$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($filter_id$jscomp$5_map__67669_map__67669__$1_props_67668$$,
$cljs$cst$3770$filter_id$$);return(0,$APP.$rumext$v2$jsx$$)("feFlood",{floodOpacity:0,result:$filter_id$jscomp$5_map__67669_map__67669__$1_props_67668$$})};
$app$main$ui$shapes$filters$blend_filters$$=function($filter_id$jscomp$6_map__67671_props_67670$$){$filter_id$jscomp$6_map__67671_props_67670$$=$APP.$rumext$v2$util$wrap_props$$($filter_id$jscomp$6_map__67671_props_67670$$);var $filter_in$jscomp$2_map__67671__$1$$=$APP.$cljs$core$__destructure_map$$($filter_id$jscomp$6_map__67671_props_67670$$);$filter_id$jscomp$6_map__67671_props_67670$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($filter_in$jscomp$2_map__67671__$1$$,$cljs$cst$3770$filter_id$$);
$filter_in$jscomp$2_map__67671__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($filter_in$jscomp$2_map__67671__$1$$,$cljs$cst$3769$filter_in$$);return(0,$APP.$rumext$v2$jsx$$)("feBlend",{mode:"normal","in":"SourceGraphic",in2:$filter_in$jscomp$2_map__67671__$1$$,result:$filter_id$jscomp$6_map__67671_props_67670$$})};
$app$main$ui$shapes$filters$filter_entry$$=function($map__67673_map__67673__$1_props$jscomp$162_props_67672$$){$map__67673_map__67673__$1_props$jscomp$162_props_67672$$=$APP.$rumext$v2$util$wrap_props$$($map__67673_map__67673__$1_props$jscomp$162_props_67672$$);$map__67673_map__67673__$1_props$jscomp$162_props_67672$$=$APP.$cljs$core$__destructure_map$$($map__67673_map__67673__$1_props$jscomp$162_props_67672$$);var $G__67674_G__67674__$1_entry$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67673_map__67673__$1_props$jscomp$162_props_67672$$,
$cljs$cst$368$entry$$);$map__67673_map__67673__$1_props$jscomp$162_props_67672$$={"filter-id":$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__67674_G__67674__$1_entry$jscomp$52$$),"filter-in":$cljs$cst$3769$filter_in$$.$cljs$core$IFn$_invoke$arity$1$($G__67674_G__67674__$1_entry$jscomp$52$$),params:$APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($G__67674_G__67674__$1_entry$jscomp$52$$)};$G__67674_G__67674__$1_entry$jscomp$52$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__67674_G__67674__$1_entry$jscomp$52$$);
$G__67674_G__67674__$1_entry$jscomp$52$$=$G__67674_G__67674__$1_entry$jscomp$52$$ instanceof $APP.$cljs$core$Keyword$$?$G__67674_G__67674__$1_entry$jscomp$52$$.$fqn$:null;switch($G__67674_G__67674__$1_entry$jscomp$52$$){case "drop-shadow":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$filters$drop_shadow_filter$$,$map__67673_map__67673__$1_props$jscomp$162_props_67672$$);case "inner-shadow":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$filters$inner_shadow_filter$$,
$map__67673_map__67673__$1_props$jscomp$162_props_67672$$);case "background-blur":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$filters$background_blur_filter$$,$map__67673_map__67673__$1_props$jscomp$162_props_67672$$);case "layer-blur":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$filters$layer_blur_filter$$,$map__67673_map__67673__$1_props$jscomp$162_props_67672$$);case "image-fix":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$filters$image_fix_filter$$,
$map__67673_map__67673__$1_props$jscomp$162_props_67672$$);case "blend-filters":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$filters$blend_filters$$,$map__67673_map__67673__$1_props$jscomp$162_props_67672$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__67674_G__67674__$1_entry$jscomp$52$$)].join(""));}};
$app$main$ui$shapes$filters$change_filter_in$$=function($filters$jscomp$5$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(function($p1__67676_SHARP_$$,$p2__67677_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__67676_SHARP_$$,$cljs$cst$3769$filter_in$$,$p2__67677_SHARP_$$)},$filters$jscomp$5$$,$APP.$cljs$core$cons$$(null,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$filters$jscomp$5$$)))};
$app$main$ui$shapes$filters$filter_coords$$=function($bounds$jscomp$25_filter_y$jscomp$1$$,$filter_units_selrect$jscomp$48$$,$padding$jscomp$6$$){var $JSCompiler_inline_result$jscomp$1146_filter_width_or__5025__auto__$jscomp$inline_6655$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$(.01,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($filter_units_selrect$jscomp$48$$));$JSCompiler_inline_result$jscomp$1146_filter_width_or__5025__auto__$jscomp$inline_6655$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1146_filter_width_or__5025__auto__$jscomp$inline_6655$$)?
$JSCompiler_inline_result$jscomp$1146_filter_width_or__5025__auto__$jscomp$inline_6655$$:$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$(.01,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($filter_units_selrect$jscomp$48$$));if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1146_filter_width_or__5025__auto__$jscomp$inline_6655$$)){$JSCompiler_inline_result$jscomp$1146_filter_width_or__5025__auto__$jscomp$inline_6655$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$25_filter_y$jscomp$1$$)+
2*$APP.$cljs$cst$1909$horizontal$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$6$$);var $filter_height$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$25_filter_y$jscomp$1$$)+2*$APP.$cljs$cst$1910$vertical$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$6$$),$filter_x$jscomp$1$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$25_filter_y$jscomp$1$$)-$APP.$cljs$cst$1909$horizontal$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$6$$);$bounds$jscomp$25_filter_y$jscomp$1$$=
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$25_filter_y$jscomp$1$$)-$APP.$cljs$cst$1910$vertical$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$6$$);$filter_units_selrect$jscomp$48$$="userSpaceOnUse"}else $JSCompiler_inline_result$jscomp$1146_filter_width_or__5025__auto__$jscomp$inline_6655$$=($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$25_filter_y$jscomp$1$$)+2*$APP.$cljs$cst$1909$horizontal$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$6$$))/
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($filter_units_selrect$jscomp$48$$),$filter_height$$=($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$25_filter_y$jscomp$1$$)+2*$APP.$cljs$cst$1910$vertical$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$6$$))/$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($filter_units_selrect$jscomp$48$$),$filter_x$jscomp$1$$=($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$25_filter_y$jscomp$1$$)-
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($filter_units_selrect$jscomp$48$$)-$APP.$cljs$cst$1909$horizontal$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$6$$))/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($filter_units_selrect$jscomp$48$$),$bounds$jscomp$25_filter_y$jscomp$1$$=($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$25_filter_y$jscomp$1$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($filter_units_selrect$jscomp$48$$)-$APP.$cljs$cst$1910$vertical$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$6$$))/
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($filter_units_selrect$jscomp$48$$),$filter_units_selrect$jscomp$48$$="objectBoundingBox";return new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$filter_x$jscomp$1$$,$bounds$jscomp$25_filter_y$jscomp$1$$,$JSCompiler_inline_result$jscomp$1146_filter_width_or__5025__auto__$jscomp$inline_6655$$,$filter_height$$,$filter_units_selrect$jscomp$48$$],null)};
$app$main$ui$shapes$filters$filters$$=function($filters__$1_map__67686_map__67686__$1_props_67679_shape_SINGLEQUOTE_$jscomp$10$$){$filters__$1_map__67686_map__67686__$1_props_67679_shape_SINGLEQUOTE_$jscomp$10$$=$APP.$rumext$v2$util$wrap_props$$($filters__$1_map__67686_map__67686__$1_props_67679_shape_SINGLEQUOTE_$jscomp$10$$);$filters__$1_map__67686_map__67686__$1_props_67679_shape_SINGLEQUOTE_$jscomp$10$$=$APP.$cljs$core$__destructure_map$$($filters__$1_map__67686_map__67686__$1_props_67679_shape_SINGLEQUOTE_$jscomp$10$$);
var $filter_id$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($filters__$1_map__67686_map__67686__$1_props_67679_shape_SINGLEQUOTE_$jscomp$10$$,$cljs$cst$3770$filter_id$$),$shape$jscomp$473$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($filters__$1_map__67686_map__67686__$1_props_67679_shape_SINGLEQUOTE_$jscomp$10$$,$APP.$cljs$cst$1811$shape$$);$filters__$1_map__67686_map__67686__$1_props_67679_shape_SINGLEQUOTE_$jscomp$10$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$473$$,
$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$core$reverse$$);$filters__$1_map__67686_map__67686__$1_props_67679_shape_SINGLEQUOTE_$jscomp$10$$=$app$main$ui$shapes$filters$change_filter_in$$($app$common$geom$shapes$bounds$shape__GT_filters$$($filters__$1_map__67686_map__67686__$1_props_67679_shape_SINGLEQUOTE_$jscomp$10$$));var $bounds$jscomp$26_filter_x$jscomp$2$$=$app$common$geom$shapes$bounds$get_rect_filter_bounds$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$473$$),
$filters__$1_map__67686_map__67686__$1_props_67679_shape_SINGLEQUOTE_$jscomp$10$$,function(){var $or__5025__auto__$jscomp$739$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$473$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$739$$)?$or__5025__auto__$jscomp$739$$:0}()),$filter_y$jscomp$2_padding$jscomp$7$$=$app$common$geom$shapes$bounds$calculate_padding$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$473$$,
!1,!1),$filter_width$jscomp$1_selrect$jscomp$49$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$473$$),$filter_units$jscomp$1_vec__67688$$=$app$main$ui$shapes$filters$filter_coords$$($bounds$jscomp$26_filter_x$jscomp$2$$,$filter_width$jscomp$1_selrect$jscomp$49$$,$filter_y$jscomp$2_padding$jscomp$7$$);$bounds$jscomp$26_filter_x$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filter_units$jscomp$1_vec__67688$$,0,null);$filter_y$jscomp$2_padding$jscomp$7$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filter_units$jscomp$1_vec__67688$$,1,null);$filter_width$jscomp$1_selrect$jscomp$49$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filter_units$jscomp$1_vec__67688$$,2,null);var $filter_height$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filter_units$jscomp$1_vec__67688$$,3,null);$filter_units$jscomp$1_vec__67688$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filter_units$jscomp$1_vec__67688$$,
4,null);return $APP.$cljs$core$count$$($filters__$1_map__67686_map__67686__$1_props_67679_shape_SINGLEQUOTE_$jscomp$10$$)>2?(0,$APP.$rumext$v2$jsx$$)("filter",{id:$filter_id$jscomp$7$$,x:$bounds$jscomp$26_filter_x$jscomp$2$$,y:$filter_y$jscomp$2_padding$jscomp$7$$,width:$filter_width$jscomp$1_selrect$jscomp$49$$,height:$filter_height$jscomp$1$$,filterUnits:$filter_units$jscomp$1_vec__67688$$,colorInterpolationFilters:"sRGB",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$21$$,
$entry$jscomp$53_p__67698$$){var $index$jscomp$283$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($entry$jscomp$53_p__67698$$,0,null);$entry$jscomp$53_p__67698$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($entry$jscomp$53_p__67698$$,1,null);$out_arr__44124__auto__$jscomp$21$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$filters$filter_entry$$,{entry:$entry$jscomp$53_p__67698$$},""+($filter_id$jscomp$7$$??"")+"-"+($index$jscomp$283$$??"")));return $out_arr__44124__auto__$jscomp$21$$},
[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($filters__$1_map__67686_map__67686__$1_props_67679_shape_SINGLEQUOTE_$jscomp$10$$))}):null};$app$main$ui$shapes$frame$frame_clip_id$$=function($shape$jscomp$474$$,$render_id$jscomp$23$$){return"frame-clip-"+($shape$jscomp$474$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$474$$,$APP.$cljs$cst$266$id$$)??"")+"-"+($render_id$jscomp$23$$??"")};
$app$main$ui$shapes$frame$frame_clip_def$$=function($props_67774_render_id$jscomp$25$$){var $shape$jscomp$476$$=$props_67774_render_id$jscomp$25$$.shape;if($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$476$$)&&!$APP.$cljs$cst$1876$show_content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$476$$)){$props_67774_render_id$jscomp$25$$=$props_67774_render_id$jscomp$25$$["render-id"];var $x$jscomp$1183$$=$shape$jscomp$476$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$476$$,
$APP.$cljs$cst$1510$x$$),$y$jscomp$419$$=$shape$jscomp$476$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$476$$,$APP.$cljs$cst$1511$y$$),$w$jscomp$35$$=$shape$jscomp$476$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$476$$,$APP.$cljs$cst$290$width$$),$h$jscomp$157$$=$shape$jscomp$476$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$476$$,$APP.$cljs$cst$1522$height$$),$t$jscomp$92$$=$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$476$$),
$props__$1$jscomp$25$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$476$$)],function(){return $APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$attrs$add_border_props_BANG_$$({},$shape$jscomp$476$$),{x:$x$jscomp$1183$$,y:$y$jscomp$419$$,width:$w$jscomp$35$$,height:$h$jscomp$157$$,transform:$t$jscomp$92$$})}),$path_QMARK_$jscomp$2$$=$props__$1$jscomp$25$$.d!=null;return(0,$APP.$rumext$v2$jsx$$)("clipPath",
{id:$app$main$ui$shapes$frame$frame_clip_id$$($shape$jscomp$476$$,$props_67774_render_id$jscomp$25$$),className:"frame-clip frame-clip-def",children:$path_QMARK_$jscomp$2$$?(0,$APP.$rumext$v2$create_element$$)("path",$props__$1$jscomp$25$$):(0,$APP.$rumext$v2$create_element$$)("rect",$props__$1$jscomp$25$$)})}return null};
$app$main$ui$shapes$frame$frame_container$$=function($children$jscomp$218_props_67779$$){var $shape$jscomp$477$$=$children$jscomp$218_props_67779$$.shape;$children$jscomp$218_props_67779$$=$children$jscomp$218_props_67779$$.children;var $render_id$jscomp$26$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$),$filter_id_blur$$="filter-blur-"+($render_id$jscomp$26$$??""),$filter_id_shadows$$="filter-shadow-"+($render_id$jscomp$26$$??""),$filter_str_blur$$=$app$main$ui$shapes$filters$filter_str$$($filter_id_blur$$,
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$477$$,$APP.$cljs$cst$1654$shadow$$)),$filter_str_shadows$$=$app$main$ui$shapes$filters$filter_str$$($filter_id_shadows$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$477$$,$APP.$cljs$cst$1653$blur$$)),$x$jscomp$1184$$=$shape$jscomp$477$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$477$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$420$$=$shape$jscomp$477$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$477$$,
$APP.$cljs$cst$1511$y$$),$w$jscomp$36$$=$shape$jscomp$477$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$477$$,$APP.$cljs$cst$290$width$$),$h$jscomp$158$$=$shape$jscomp$477$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$477$$,$APP.$cljs$cst$1522$height$$),$opacity$jscomp$27$$=$shape$jscomp$477$$?.opacity??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$477$$,$APP.$cljs$cst$1734$opacity$$),$transform$jscomp$88$$=$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$477$$),
$show_content_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$477$$,$APP.$cljs$cst$1876$show_content$$),$props__$1$jscomp$26$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$477$$)],function(){return $APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$attrs$add_border_props_BANG_$$({},$shape$jscomp$477$$),{x:$x$jscomp$1184$$,y:$y$jscomp$420$$,width:$w$jscomp$36$$,height:$h$jscomp$158$$,
transform:$transform$jscomp$88$$,className:"frame-background"})}),$path_QMARK_$jscomp$3$$=$props__$1$jscomp$26$$.d!=null;return(0,$APP.$rumext$v2$jsx$$)("g",{className:"frame-container-wrapper",opacity:$opacity$jscomp$27$$,children:(0,$APP.$rumext$v2$jsxs$$)("g",{className:"frame-container-blur",filter:$filter_str_blur$$,children:[(0,$APP.$rumext$v2$jsxs$$)("defs",{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$filters$filters$$,{shape:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$477$$,
$APP.$cljs$cst$1653$blur$$),"filter-id":$filter_id_shadows$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$filters$filters$$,{shape:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$477$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$core$PersistentVector$EMPTY$$),"filter-id":$filter_id_blur$$})]}),(0,$APP.$rumext$v2$jsx$$)("g",{className:"frame-container-shadows",filter:$filter_str_shadows$$,children:(0,$APP.$rumext$v2$jsxs$$)("g",{clipPath:$show_content_QMARK_$$?null:"url(#"+($app$main$ui$shapes$frame$frame_clip_id$$($shape$jscomp$477$$,
$render_id$jscomp$26$$)??"")+")",fill:"none",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$shape_fills$$,{shape:$shape$jscomp$477$$,children:$path_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$create_element$$)("path",$props__$1$jscomp$26$$):(0,$APP.$rumext$v2$create_element$$)("rect",$props__$1$jscomp$26$$)}),$children$jscomp$218_props_67779$$]})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$shape_strokes$$,{shape:$shape$jscomp$477$$,children:$path_QMARK_$jscomp$3$$?
(0,$APP.$rumext$v2$create_element$$)("path",$props__$1$jscomp$26$$):(0,$APP.$rumext$v2$create_element$$)("rect",$props__$1$jscomp$26$$)})]})})};
$app$main$ui$shapes$frame$frame_thumbnail_image$$=function($props_67787_shape_id$jscomp$85$$){var $shape$jscomp$478$$=$props_67787_shape_id$jscomp$85$$.shape,$bounds$jscomp$27$$=$props_67787_shape_id$jscomp$85$$.bounds;$props_67787_shape_id$jscomp$85$$=$shape$jscomp$478$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$478$$,$APP.$cljs$cst$266$id$$);var $points$jscomp$61_thumb$$=$shape$jscomp$478$$?.points??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$478$$,
$APP.$cljs$cst$1604$points$$),$bounds__$1_bw$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($bounds$jscomp$27$$),$APP.$rumext$v2$adapt$$($points$jscomp$61_thumb$$)],function(){if($APP.$cljs$core$truth_$$($bounds$jscomp$27$$))var $JSCompiler_temp$jscomp$10776_ignore_margin_QMARK_$jscomp$inline_12459$$=$bounds$jscomp$27$$;else{var $ignore_shadow_margin_QMARK_$jscomp$inline_12460_map__48762__$1$jscomp$inline_12458$$=$APP.$cljs$core$__destructure_map$$(null);
$JSCompiler_temp$jscomp$10776_ignore_margin_QMARK_$jscomp$inline_12459$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($ignore_shadow_margin_QMARK_$jscomp$inline_12460_map__48762__$1$jscomp$inline_12458$$,$APP.$cljs$cst$1911$ignore_margin_QMARK_$$,!1);$ignore_shadow_margin_QMARK_$jscomp$inline_12460_map__48762__$1$jscomp$inline_12458$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($ignore_shadow_margin_QMARK_$jscomp$inline_12460_map__48762__$1$jscomp$inline_12458$$,$APP.$cljs$cst$1912$ignore_shadow_margin_QMARK_$$,
!1);$JSCompiler_temp$jscomp$10776_ignore_margin_QMARK_$jscomp$inline_12459$$=$APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$shape$jscomp$478$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1911$ignore_margin_QMARK_$$,$JSCompiler_temp$jscomp$10776_ignore_margin_QMARK_$jscomp$inline_12459$$,$APP.$cljs$cst$1912$ignore_shadow_margin_QMARK_$$,$ignore_shadow_margin_QMARK_$jscomp$inline_12460_map__48762__$1$jscomp$inline_12458$$],
null))}return $JSCompiler_temp$jscomp$10776_ignore_margin_QMARK_$jscomp$inline_12459$$});$points$jscomp$61_thumb$$=$APP.$app$config$resolve_media$$($APP.$cljs$cst$2573$thumbnail_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$478$$));var $debug_QMARK_$$=$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$2229$thumbnails$$),$safari_QMARK_$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1346$safari$$),$bx$jscomp$1$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bounds__$1_bw$$),
$by$jscomp$2$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bounds__$1_bw$$),$bh$jscomp$2$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($bounds__$1_bw$$);$bounds__$1_bw$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($bounds__$1_bw$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("image",{width:$bounds__$1_bw$$,height:$bh$jscomp$2$$,className:"frame-thumbnail",x:$bx$jscomp$1$$,id:"thumbnail-"+($props_67787_shape_id$jscomp$85$$??
""),href:$points$jscomp$61_thumb$$,style:{filter:!$safari_QMARK_$$&&$debug_QMARK_$$?"sepia(1)":null},decoding:"async",y:$by$jscomp$2$$}),$safari_QMARK_$$&&$debug_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("rect",{x:$bx$jscomp$1$$+4,y:$by$jscomp$2$$+4,width:$bounds__$1_bw$$-8,height:$bh$jscomp$2$$-8,stroke:"red",strokeWidth:2}):null]})};
$app$main$ui$shapes$frame$frame_thumbnail$$=function($props_67795$$){return $APP.$cljs$cst$2573$thumbnail_id$$.$cljs$core$IFn$_invoke$arity$1$($props_67795$$.shape)?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$frame$frame_container$$,$props_67795$$,(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$frame$frame_thumbnail_image$$,$props_67795$$)):null};
$APP.$app$main$ui$shapes$frame$frame_shape$$=function($shape_wrapper$jscomp$2$$){return function($props_67799$$){var $childs__$1_shape$jscomp$480$$=$props_67799$$.shape,$childs$jscomp$7$$=$props_67799$$.childs,$reverse_QMARK_$jscomp$2$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($childs__$1_shape$jscomp$480$$)&&$APP.$app$common$types$shape$layout$reverse_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($childs__$1_shape$jscomp$480$$);$childs__$1_shape$jscomp$480$$=
$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($childs__$1_shape$jscomp$480$$)?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$shape$layout$comparator_layout_z_index$$,$reverse_QMARK_$jscomp$2$$),$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($childs$jscomp$7$$))):$childs$jscomp$7$$;
return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$frame$frame_container$$,$props_67799$$,(0,$APP.$rumext$v2$jsx$$)("g",{className:"frame-children",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$22$$,$JSCompiler_inline_result$jscomp$1149_item$jscomp$77$$){var $JSCompiler_temp_const$jscomp$1147$$=$out_arr__44124__auto__$jscomp$22$$.push,$id$jscomp$inline_6657$$=$JSCompiler_inline_result$jscomp$1149_item$jscomp$77$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1149_item$jscomp$77$$,
$APP.$cljs$cst$266$id$$);$JSCompiler_inline_result$jscomp$1149_item$jscomp$77$$=$id$jscomp$inline_6657$$!=null?(0,$APP.$rumext$v2$jsx$$)($shape_wrapper$jscomp$2$$,{shape:$JSCompiler_inline_result$jscomp$1149_item$jscomp$77$$},""+($id$jscomp$inline_6657$$??"")):null;$JSCompiler_temp_const$jscomp$1147$$.call($out_arr__44124__auto__$jscomp$22$$,$JSCompiler_inline_result$jscomp$1149_item$jscomp$77$$);return $out_arr__44124__auto__$jscomp$22$$},[],$childs__$1_shape$jscomp$480$$)}))}};
$app$main$ui$shapes$grid_layout_viewer$grid_cell_area_label$$=function($props_67778_text$jscomp$46$$){var $area_y_cell_origin$$=$props_67778_text$jscomp$46$$.origin,$area_x_cell_width$$=$props_67778_text$jscomp$46$$.width;$props_67778_text$jscomp$46$$=$props_67778_text$jscomp$46$$.text;var $area_width$$=10*$APP.$cljs$core$count$$($props_67778_text$jscomp$46$$);$area_x_cell_width$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($area_y_cell_origin$$)+$area_x_cell_width$$-$area_width$$;$area_y_cell_origin$$=
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($area_y_cell_origin$$);var $area_text_x$$=$area_x_cell_width$$+$area_width$$/2,$area_text_y$$=$area_y_cell_origin$$+12.5;return(0,$APP.$rumext$v2$jsxs$$)("g",{pointerEvents:"none",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$area_x_cell_width$$,y:$area_y_cell_origin$$,width:$area_width$$,height:25,style:{fill:"var(--color-accent-quaternary)",fillOpacity:.3}}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$area_text_x$$,y:$area_text_y$$,style:{fill:"var(--color-accent-quaternary)",
fontFamily:"worksans",fontWeight:600,fontSize:14,alignmentBaseline:"central",textAnchor:"middle"},children:$props_67778_text$jscomp$46$$})]})};
$app$main$ui$shapes$grid_layout_viewer$grid_cell$$=function($cell_width$jscomp$1_props_67783$$){var $shape$jscomp$481$$=$cell_width$jscomp$1_props_67783$$.shape,$cell$jscomp$32$$=$cell_width$jscomp$1_props_67783$$.cell,$cell_bounds$jscomp$4_cell_center$$=$APP.$app$common$geom$shapes$grid_layout$positions$cell_bounds$$($cell_width$jscomp$1_props_67783$$["layout-data"],$cell$jscomp$32$$),$cell_origin$jscomp$1_cell_origin__$1$$=$APP.$app$common$geom$shapes$points$origin$$($cell_bounds$jscomp$4_cell_center$$);
$cell_width$jscomp$1_props_67783$$=$APP.$app$common$geom$shapes$points$width_points$$($cell_bounds$jscomp$4_cell_center$$);var $cell_height$$=$APP.$app$common$geom$shapes$points$height_points$$($cell_bounds$jscomp$4_cell_center$$);$cell_bounds$jscomp$4_cell_center$$=$APP.$app$common$geom$shapes$common$points__GT_center$$($cell_bounds$jscomp$4_cell_center$$);$cell_origin$jscomp$1_cell_origin__$1$$=$APP.$app$common$geom$point$transform$$($cell_origin$jscomp$1_cell_origin__$1$$,$APP.$app$common$geom$matrix$transform_in$$($cell_bounds$jscomp$4_cell_center$$,
$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$481$$)));return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"cell",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{transform:""+($APP.$app$common$geom$matrix$transform_in$$($cell_bounds$jscomp$4_cell_center$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$481$$))??""),x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin$jscomp$1_cell_origin__$1$$),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin$jscomp$1_cell_origin__$1$$),
width:$cell_width$jscomp$1_props_67783$$,height:$cell_height$$,style:{stroke:"var(--color-accent-quaternary)",strokeWidth:1.5,fill:"none"}}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1675$area_name$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$32$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$grid_layout_viewer$grid_cell_area_label$$,{origin:$cell_origin$jscomp$1_cell_origin__$1$$,width:$cell_width$jscomp$1_props_67783$$,text:$APP.$cljs$cst$1675$area_name$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$32$$)}):
null]})};
$app$main$ui$shapes$grid_layout_viewer$grid_layout_viewer$$=function($bounds$jscomp$28_props_67798$$){var $shape$jscomp$482$$=$bounds$jscomp$28_props_67798$$.shape,$objects$jscomp$378$$=$bounds$jscomp$28_props_67798$$.objects;$bounds$jscomp$28_props_67798$$=$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$378$$),function($p1__67796_SHARP_$$){return $APP.$app$common$geom$shapes$shape__GT_points$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$378$$,$p1__67796_SHARP_$$))});
var $children$jscomp$219$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67797_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($p1__67797_SHARP_$$),$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$482$$)),$p1__67797_SHARP_$$],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,
$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$378$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$482$$)))),$layout_data$jscomp$7$$=$APP.$app$common$geom$shapes$grid_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$($shape$jscomp$482$$,$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$482$$),$children$jscomp$219$$,$bounds$jscomp$28_props_67798$$,$objects$jscomp$378$$);return(0,$APP.$rumext$v2$jsx$$)("g",
{className:"cells",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$23$$,$cell$jscomp$33$$){$out_arr__44124__auto__$jscomp$23$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$grid_layout_viewer$grid_cell$$,{shape:$shape$jscomp$482$$,"layout-data":$layout_data$jscomp$7$$,cell:$cell$jscomp$33$$},"cell-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$33$$)??"")));return $out_arr__44124__auto__$jscomp$23$$},[],$APP.$app$common$types$shape$layout$get_cells$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$482$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1713$sort_QMARK_$$,!0],null)))})};$app$main$ui$shapes$mask$point__GT_str$$=function($point$jscomp$55$$){return""+($point$jscomp$55$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$55$$,$APP.$cljs$cst$1510$x$$)??"")+","+($point$jscomp$55$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$55$$,$APP.$cljs$cst$1511$y$$)??"")};
$app$main$ui$shapes$mask$mask_factory$$=function($shape_wrapper$jscomp$3$$){return function($props_67793_render_id$jscomp$33$$){var $mask$jscomp$20$$=$props_67793_render_id$jscomp$33$$.mask;$props_67793_render_id$jscomp$33$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$);var $svg_text_QMARK_$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($mask$jscomp$20$$)&&$APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($mask$jscomp$20$$)!=
null,$points$jscomp$62$$=$mask$jscomp$20$$?.points??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mask$jscomp$20$$,$APP.$cljs$cst$1604$points$$),$points_str$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($points$jscomp$62$$)],function(){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$mask$point__GT_str$$,$points$jscomp$62$$))}),$bh$jscomp$3_bounds$jscomp$29$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($points$jscomp$62$$)],function(){return $APP.$app$common$geom$rect$points__GT_rect$$($points$jscomp$62$$)}),$bx$jscomp$2$$=$bh$jscomp$3_bounds$jscomp$29$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bh$jscomp$3_bounds$jscomp$29$$,$APP.$cljs$cst$1510$x$$),$by$jscomp$3$$=$bh$jscomp$3_bounds$jscomp$29$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bh$jscomp$3_bounds$jscomp$29$$,$APP.$cljs$cst$1511$y$$),
$bw$jscomp$1$$=$bh$jscomp$3_bounds$jscomp$29$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bh$jscomp$3_bounds$jscomp$29$$,$APP.$cljs$cst$290$width$$);$bh$jscomp$3_bounds$jscomp$29$$=$bh$jscomp$3_bounds$jscomp$29$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bh$jscomp$3_bounds$jscomp$29$$,$APP.$cljs$cst$1522$height$$);var $shape$jscomp$484$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mask$jscomp$20$$)],function(){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($mask$jscomp$20$$,
$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1653$blur$$])),$cljs$cst$2966$is_mask_QMARK_$$,!0)});return(0,$APP.$rumext$v2$jsxs$$)("defs",{children:[(0,$APP.$rumext$v2$jsxs$$)("filter",{id:""+($props_67793_render_id$jscomp$33$$??"")+"-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($mask$jscomp$20$$)??"")+"-filter",children:[(0,$APP.$rumext$v2$jsx$$)("feFlood",{floodColor:"white",result:"FloodResult"}),(0,$APP.$rumext$v2$jsx$$)("feComposite",
{"in":"FloodResult",in2:"SourceGraphic",operator:"in",result:"comp"})]}),(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:""+($props_67793_render_id$jscomp$33$$??"")+"-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($mask$jscomp$20$$)??"")+"-clip",className:"mask-clip-path",children:(0,$APP.$rumext$v2$jsx$$)("polyline",{points:$points_str$jscomp$1$$})}),(0,$APP.$rumext$v2$jsx$$)("mask",{width:$bw$jscomp$1$$,maskUnits:"userSpaceOnUse",height:$bh$jscomp$3_bounds$jscomp$29$$,className:"mask-shape",
children:(0,$APP.$rumext$v2$jsx$$)("g",{filter:$svg_text_QMARK_$$?null:"url(#"+(($props_67793_render_id$jscomp$33$$??"")+"-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($mask$jscomp$20$$)??"")+"-filter)"),children:(0,$APP.$rumext$v2$jsx$$)($shape_wrapper$jscomp$3$$,{shape:$shape$jscomp$484$$})}),x:$bx$jscomp$2$$,id:""+($props_67793_render_id$jscomp$33$$??"")+"-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($mask$jscomp$20$$)??"")+"-mask","data-old-y":$by$jscomp$3$$,"data-old-width":$bw$jscomp$1$$,
"data-old-x":$bx$jscomp$2$$,y:$by$jscomp$3$$,"data-old-height":$bh$jscomp$3_bounds$jscomp$29$$})]})}};
$APP.$app$main$ui$shapes$group$group_shape$$=function($shape_wrapper$jscomp$4$$){var $render_mask$$=$app$main$ui$shapes$mask$mask_factory$$($shape_wrapper$jscomp$4$$);return function($masked_group_QMARK__props_67811$$){var $shape$jscomp$485_svg_wrapper$$=$masked_group_QMARK__props_67811$$.shape,$childs$jscomp$8_childs__$1$jscomp$1$$=$masked_group_QMARK__props_67811$$.childs,$mask_props_render_id$jscomp$34$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$),$mask$jscomp$21$$=($masked_group_QMARK__props_67811$$=
$APP.$cljs$cst$1609$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$485_svg_wrapper$$))?$APP.$cljs$core$first$$($childs$jscomp$8_childs__$1$jscomp$1$$):null;$childs$jscomp$8_childs__$1$jscomp$1$$=$masked_group_QMARK__props_67811$$?$APP.$cljs$core$rest$$($childs$jscomp$8_childs__$1$jscomp$1$$):$childs$jscomp$8_childs__$1$jscomp$1$$;var $wrapper$jscomp$6$$=$masked_group_QMARK__props_67811$$?"g":$APP.$rumext$v2$Fragment$$,$clip_props$$=$masked_group_QMARK__props_67811$$?{clipPath:"url(#"+
(($mask_props_render_id$jscomp$34$$??"")+"-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($mask$jscomp$21$$)??"")+"-clip)")}:{};$mask_props_render_id$jscomp$34$$=$masked_group_QMARK__props_67811$$?{mask:"url(#"+(($mask_props_render_id$jscomp$34$$??"")+"-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($mask$jscomp$21$$)??"")+"-mask)")}:{};var $current_svg_root_id_svg_wrapper_props_vec__67813$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$current_svg_root_id$$);$current_svg_root_id_svg_wrapper_props_vec__67813$$=
$APP.$cljs$core$contains_QMARK_$$($shape$jscomp$485_svg_wrapper$$,$APP.$cljs$cst$1890$svg_attrs$$)&&$APP.$cljs$core$not$$($current_svg_root_id_svg_wrapper_props_vec__67813$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$rumext$v2$provider$$($app$main$ui$context$current_svg_root_id$$),{value:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$485_svg_wrapper$$)}],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$rumext$v2$Fragment$$,{}],null);$shape$jscomp$485_svg_wrapper$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($current_svg_root_id_svg_wrapper_props_vec__67813$$,0,null);$current_svg_root_id_svg_wrapper_props_vec__67813$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($current_svg_root_id_svg_wrapper_props_vec__67813$$,1,null);return(0,$APP.$rumext$v2$create_element$$)($shape$jscomp$485_svg_wrapper$$,$current_svg_root_id_svg_wrapper_props_vec__67813$$,(0,$APP.$rumext$v2$create_element$$)($wrapper$jscomp$6$$,
$clip_props$$,(0,$APP.$rumext$v2$create_element$$)($wrapper$jscomp$6$$,$mask_props_render_id$jscomp$34$$,$masked_group_QMARK__props_67811$$?(0,$APP.$rumext$v2$jsx$$)($render_mask$$,{mask:$mask$jscomp$21$$}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$24$$,$item$jscomp$78$$){$out_arr__44124__auto__$jscomp$24$$.push((0,$APP.$rumext$v2$jsx$$)($shape_wrapper$jscomp$4$$,{shape:$item$jscomp$78$$},""+($item$jscomp$78$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$78$$,
$APP.$cljs$cst$266$id$$)??"")));return $out_arr__44124__auto__$jscomp$24$$},[],$childs$jscomp$8_childs__$1$jscomp$1$$))))}};
$APP.$app$main$ui$shapes$image$image_shape$$=function($props_67816_props__$1$jscomp$27$$){var $shape$jscomp$486$$=$props_67816_props__$1$jscomp$27$$.shape,$x$jscomp$1185$$=$shape$jscomp$486$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$486$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$421$$=$shape$jscomp$486$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$486$$,$APP.$cljs$cst$1511$y$$),$w$jscomp$37$$=$shape$jscomp$486$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$486$$,
$APP.$cljs$cst$290$width$$),$h$jscomp$159$$=$shape$jscomp$486$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$486$$,$APP.$cljs$cst$1522$height$$),$render_id$jscomp$35$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$),$transform$jscomp$89$$=$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$486$$);$props_67816_props__$1$jscomp$27$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$486$$),
$APP.$rumext$v2$adapt$$($render_id$jscomp$35$$)],function(){return $APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$attrs$add_border_props_BANG_$$($app$main$ui$shapes$attrs$add_fill_props_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$({},$shape$jscomp$486$$,$render_id$jscomp$35$$),$shape$jscomp$486$$),{x:$x$jscomp$1185$$,y:$y$jscomp$421$$,width:$w$jscomp$37$$,height:$h$jscomp$159$$,transform:$transform$jscomp$89$$})});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$shape_custom_strokes$$,
{shape:$shape$jscomp$486$$,children:$props_67816_props__$1$jscomp$27$$.d!=null?(0,$APP.$rumext$v2$create_element$$)("path",$props_67816_props__$1$jscomp$27$$):(0,$APP.$rumext$v2$create_element$$)("rect",$props_67816_props__$1$jscomp$27$$)})};
$APP.$app$main$ui$shapes$rect$rect_shape$$=function($props_67817_props__$1$jscomp$28$$){var $shape$jscomp$487$$=$props_67817_props__$1$jscomp$28$$.shape,$x$jscomp$1186$$=$shape$jscomp$487$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$487$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$422$$=$shape$jscomp$487$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$487$$,$APP.$cljs$cst$1511$y$$),$w$jscomp$38$$=$shape$jscomp$487$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$487$$,
$APP.$cljs$cst$290$width$$),$h$jscomp$160$$=$shape$jscomp$487$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$487$$,$APP.$cljs$cst$1522$height$$),$t$jscomp$93$$=$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$487$$);$props_67817_props__$1$jscomp$28$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$487$$)],function(){return $APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$attrs$add_border_props_BANG_$$({},
$shape$jscomp$487$$),{x:$x$jscomp$1186$$,y:$y$jscomp$422$$,transform:$t$jscomp$93$$,width:$w$jscomp$38$$,height:$h$jscomp$160$$})});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$shape_custom_strokes$$,{shape:$shape$jscomp$487$$,children:$props_67817_props__$1$jscomp$28$$.d!=null?(0,$APP.$rumext$v2$create_element$$)("path",$props_67817_props__$1$jscomp$28$$):(0,$APP.$rumext$v2$create_element$$)("rect",$props_67817_props__$1$jscomp$28$$)})};
$app$main$ui$shapes$svg_defs$add_matrix$$=function($attrs$jscomp$100$$,$transform_key$$,$transform_matrix$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$100$$,$transform_key$$,function($val$jscomp$180$$){return $APP.$cljs$core$truth_$$($val$jscomp$180$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($transform_matrix$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$180$$)].join(""):$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($transform_matrix$$)})};
$app$main$ui$shapes$svg_defs$svg_defs$$=function($props_67834_transform$jscomp$92$$){var $render_id$jscomp$36$$=$props_67834_transform$jscomp$92$$["render-id"],$shape$jscomp$489$$=$props_67834_transform$jscomp$92$$.shape,$defs$jscomp$12$$=$cljs$cst$2943$svg_defs$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$489$$);$props_67834_transform$jscomp$92$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$489$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$svg_raw$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$489$$))?$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$():$app$common$svg$svg_transform_matrix$$($shape$jscomp$489$$)});var $transform__$1$jscomp$7$$=$cljs$cst$2965$svg_transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$489$$)!=null?$APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($props_67834_transform$jscomp$92$$,$cljs$cst$2965$svg_transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$489$$)):
$props_67834_transform$jscomp$92$$,$prefix_id$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($render_id$jscomp$36$$),$APP.$rumext$v2$adapt$$($defs$jscomp$12$$)],function($id$jscomp$525$$){return $APP.$cljs$core$contains_QMARK_$$($defs$jscomp$12$$,$id$jscomp$525$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($render_id$jscomp$36$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$525$$)].join(""):$id$jscomp$525$$});return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$26$$,
$node$jscomp$307_p__67836$$){var $key$jscomp$380$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($node$jscomp$307_p__67836$$,0,null);$node$jscomp$307_p__67836$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($node$jscomp$307_p__67836$$,1,null);var $JSCompiler_temp_const$jscomp$1151$$=$out_arr__44124__auto__$jscomp$26$$.push,$JSCompiler_temp_const$jscomp$1150$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$489$$);var $attrs$jscomp$inline_6664_map__67832__$1$jscomp$inline_6662$$=
$APP.$cljs$core$__destructure_map$$($node$jscomp$307_p__67836$$);var $G__67833$jscomp$inline_6665_JSCompiler_inline_result$jscomp$1153_tag$jscomp$inline_6663$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$inline_6664_map__67832__$1$jscomp$inline_6662$$,$APP.$cljs$cst$78$tag$$);$attrs$jscomp$inline_6664_map__67832__$1$jscomp$inline_6662$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$inline_6664_map__67832__$1$jscomp$inline_6662$$,$APP.$cljs$cst$2645$attrs$$);
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__67833$jscomp$inline_6665_JSCompiler_inline_result$jscomp$1153_tag$jscomp$inline_6663$$,$APP.$cljs$cst$2689$mask$$)||$APP.$cljs$core$contains_QMARK_$$($app$common$svg$filter_tags$$,$G__67833$jscomp$inline_6665_JSCompiler_inline_result$jscomp$1153_tag$jscomp$inline_6663$$)?($G__67833$jscomp$inline_6665_JSCompiler_inline_result$jscomp$1153_tag$jscomp$inline_6663$$=$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$inline_6664_map__67832__$1$jscomp$inline_6662$$,
$APP.$cljs$cst$1510$x$$)),$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$inline_6664_map__67832__$1$jscomp$inline_6662$$,$APP.$cljs$cst$1511$y$$)),$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$inline_6664_map__67832__$1$jscomp$inline_6662$$,$APP.$cljs$cst$290$width$$)),$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$inline_6664_map__67832__$1$jscomp$inline_6662$$,
$APP.$cljs$cst$1522$height$$))),$G__67833$jscomp$inline_6665_JSCompiler_inline_result$jscomp$1153_tag$jscomp$inline_6663$$=$G__67833$jscomp$inline_6665_JSCompiler_inline_result$jscomp$1153_tag$jscomp$inline_6663$$==null?null:$app$common$geom$shapes$transforms$transform_rect$$($G__67833$jscomp$inline_6665_JSCompiler_inline_result$jscomp$1153_tag$jscomp$inline_6663$$,$transform__$1$jscomp$7$$)):$G__67833$jscomp$inline_6665_JSCompiler_inline_result$jscomp$1153_tag$jscomp$inline_6663$$=$app$common$geom$shapes$bounds$get_shape_filter_bounds$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$489$$,
!1);$JSCompiler_temp_const$jscomp$1151$$.call($out_arr__44124__auto__$jscomp$26$$,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$svg_defs$svg_node$$,{type:$JSCompiler_temp_const$jscomp$1150$$,node:$node$jscomp$307_p__67836$$,"prefix-id":$prefix_id$jscomp$1$$,transform:$transform__$1$jscomp$7$$,bounds:$G__67833$jscomp$inline_6665_JSCompiler_inline_result$jscomp$1153_tag$jscomp$inline_6663$$},""+($key$jscomp$380$$??"")));return $out_arr__44124__auto__$jscomp$26$$},[],$defs$jscomp$12$$)};
$app$main$ui$shapes$shape$propagate_wrapper_styles_child$$=function($child$jscomp$90$$,$wrapper_props$jscomp$1$$){if($child$jscomp$90$$!=null){var $child_props_child_props_childs_child_props_childs__$1$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$object$clone$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$90$$,"props")),"childs");$child_props_child_props_childs_child_props_childs__$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67840_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__67840_SHARP_$$,
$cljs$cst$2944$wrapper_styles$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($wrapper_props$jscomp$1$$,"style"))},$child_props_child_props_childs_child_props_childs__$1$$);$child_props_child_props_childs_child_props_childs__$1$$=$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$clone$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$90$$,"props")),"childs",$child_props_child_props_childs_child_props_childs__$1$$);return $APP.$app$util$object$set_BANG_$$($APP.$app$util$object$clone$$($child$jscomp$90$$),
"props",$child_props_child_props_childs_child_props_childs__$1$$)}return null};
$app$main$ui$shapes$shape$propagate_wrapper_styles$$=function($children$jscomp$220$$,$wrapper_props$jscomp$2$$){return Array.isArray($children$jscomp$220$$)?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67841_SHARP_$$){return $app$main$ui$shapes$shape$propagate_wrapper_styles_child$$($p1__67841_SHARP_$$,$wrapper_props$jscomp$2$$)},$children$jscomp$220$$):$app$main$ui$shapes$shape$propagate_wrapper_styles_child$$($children$jscomp$220$$,$wrapper_props$jscomp$2$$)};
$app$main$ui$shapes$svg_raw$svg_root$$=function($children$jscomp$222_props_67848$$){var $shape$jscomp$491$$=$children$jscomp$222_props_67848$$.shape;$children$jscomp$222_props_67848$$=$children$jscomp$222_props_67848$$.children;var $x$jscomp$1187$$=$shape$jscomp$491$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$491$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$423$$=$shape$jscomp$491$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$491$$,$APP.$cljs$cst$1511$y$$),
$w$jscomp$39$$=$shape$jscomp$491$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$491$$,$APP.$cljs$cst$290$width$$),$h$jscomp$161$$=$shape$jscomp$491$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$491$$,$APP.$cljs$cst$1522$height$$),$ids_mapping$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$491$$)],function(){return $app$common$svg$generate_id_mapping$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$491$$))}),
$render_id$jscomp$38$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$),$props__$1$jscomp$29$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$491$$),$APP.$rumext$v2$adapt$$($render_id$jscomp$38$$)],function(){return $APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$unset_BANG_$$($app$main$ui$shapes$attrs$add_fill_props_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$({},
$shape$jscomp$491$$,$render_id$jscomp$38$$),"transform"),"x",$x$jscomp$1187$$),"y",$y$jscomp$423$$),"width",$w$jscomp$39$$),"height",$h$jscomp$161$$),"preserveAspectRatio","none")});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($app$main$ui$shapes$svg_raw$svg_ids_ctx$$),{value:$ids_mapping$jscomp$1$$,children:(0,$APP.$rumext$v2$jsx$$)("g",{className:"svg-raw",transform:$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$491$$),children:(0,$APP.$rumext$v2$create_element$$)("svg",
$props__$1$jscomp$29$$,$children$jscomp$222_props_67848$$)})})};
$app$main$ui$shapes$svg_raw$svg_element$$=function($children$jscomp$223_props_67849$$){var $shape$jscomp$492$$=$children$jscomp$223_props_67849$$.shape;$children$jscomp$223_props_67849$$=$children$jscomp$223_props_67849$$.children;var $ids_mapping$jscomp$2$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$shapes$svg_raw$svg_ids_ctx$$),$render_id$jscomp$39$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$),$tag$jscomp$77$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$492$$)),$shape__$1$jscomp$38$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$492$$),$APP.$rumext$v2$adapt$$($ids_mapping$jscomp$2$$)],function(){var $tag__$1$jscomp$2$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$492$$));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$492$$,$APP.$cljs$cst$1890$svg_attrs$$,
$app$common$svg$replace_attrs_ids$$,$ids_mapping$jscomp$2$$),$APP.$cljs$cst$1890$svg_attrs$$,function($attrs$jscomp$103$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$app$main$ui$shapes$svg_raw$graphic_element$$,$tag__$1$jscomp$2$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$103$$,$APP.$cljs$cst$1289$transform$$,""+($app$common$svg$svg_transform_matrix$$($shape$jscomp$492$$)??"")+" "+($APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$103$$,
"")??"")):$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$103$$,$APP.$cljs$cst$1289$transform$$)})}),$props__$1$jscomp$30$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape__$1$jscomp$38$$),$APP.$rumext$v2$adapt$$($render_id$jscomp$39$$)],function(){var $element_id$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$38$$,$APP.$cljs$cst$1890$svg_attrs$$),
$APP.$cljs$cst$266$id$$),$props__$1$jscomp$31$$=$app$main$ui$shapes$attrs$add_fill_props_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$({},$shape__$1$jscomp$38$$,$render_id$jscomp$39$$);$element_id$jscomp$1$$!=null&&$APP.$cljs$core$contains_QMARK_$$($ids_mapping$jscomp$2$$,$element_id$jscomp$1$$)&&$APP.$app$util$object$set_BANG_$$($props__$1$jscomp$31$$,"id",$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ids_mapping$jscomp$2$$,$element_id$jscomp$1$$));return $props__$1$jscomp$31$$});return(0,$APP.$rumext$v2$create_element$$)($APP.$cljs$core$name$$($tag$jscomp$77$$),
$props__$1$jscomp$30$$,$children$jscomp$223_props_67849$$)};
$APP.$app$main$ui$shapes$svg_raw$svg_raw_shape$$=function($shape_wrapper$jscomp$5$$){return function($childs$jscomp$9_props_67850$$){var $shape$jscomp$493$$=$childs$jscomp$9_props_67850$$.shape;$childs$jscomp$9_props_67850$$=$childs$jscomp$9_props_67850$$.childs;var $content$jscomp$168$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$493$$,$APP.$cljs$cst$1637$content$$),$tag$jscomp$78$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$168$$,$APP.$cljs$cst$78$tag$$),
$svg_root_QMARK_$$=$APP.$cljs$core$map_QMARK_$$($content$jscomp$168$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($tag$jscomp$78$$,$APP.$cljs$cst$1538$svg$$),$svg_tag_QMARK_$$=$APP.$cljs$core$map_QMARK_$$($content$jscomp$168$$),$svg_leaf_QMARK_$$=typeof $content$jscomp$168$$==="string",$valid_tag_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($app$common$svg$svg_tags$$,$tag$jscomp$78$$),$current_svg_root_id$jscomp$1_style_content$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$current_svg_root_id$$);
$current_svg_root_id$jscomp$1_style_content$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($tag$jscomp$78$$,$APP.$cljs$cst$1904$style$$)?"#shape-"+($current_svg_root_id$jscomp$1_style_content$$??"")+"{ "+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$493$$)))??"")+" }":null;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($tag$jscomp$78$$,
$APP.$cljs$cst$1904$style$$)?(0,$APP.$rumext$v2$jsx$$)("style",{children:$current_svg_root_id$jscomp$1_style_content$$}):$svg_root_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$svg_raw$svg_root$$,{shape:$shape$jscomp$493$$,children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$27$$,$item$jscomp$79$$){$out_arr__44124__auto__$jscomp$27$$.push((0,$APP.$rumext$v2$jsx$$)($shape_wrapper$jscomp$5$$,{shape:$item$jscomp$79$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$79$$)??
"")));return $out_arr__44124__auto__$jscomp$27$$},[],$childs$jscomp$9_props_67850$$)}):$svg_tag_QMARK_$$&&$valid_tag_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$svg_raw$svg_element$$,{shape:$shape$jscomp$493$$,children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$28$$,$item$jscomp$80$$){$out_arr__44124__auto__$jscomp$28$$.push((0,$APP.$rumext$v2$jsx$$)($shape_wrapper$jscomp$5$$,{shape:$item$jscomp$80$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$80$$)??
"")));return $out_arr__44124__auto__$jscomp$28$$},[],$childs$jscomp$9_props_67850$$)}):$svg_leaf_QMARK_$$?$content$jscomp$168$$:null}};
$app$main$ui$shapes$text$fontfaces$use_fonts_css$$=function($fonts$jscomp$14$$){var $fonts_css_ref$$=(0,$APP.$rumext$v2$use_ref$$)(""),$redraw$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0);$rumext$v2$use_ssr_effect$$([$APP.$rumext$v2$adapt$$($fonts$jscomp$14$$)],function(){var $sub$jscomp$16$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($css$jscomp$7_result$jscomp$280$$){$css$jscomp$7_result$jscomp$280$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",
$css$jscomp$7_result$jscomp$280$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($fonts_css_ref$$),$css$jscomp$7_result$jscomp$280$$))return null;$APP.$rumext$v2$set_ref_val_BANG_$$($fonts_css_ref$$,$css$jscomp$7_result$jscomp$280$$);return $APP.$cljs$core$reset_BANG_$$($redraw$$,$APP.$cljs$core$inc$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$merge_map$$($APP.$app$main$fonts$fetch_font_css$$,
$APP.$beicon$v2$core$from$$($fonts$jscomp$14$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$16$$)}});return $APP.$rumext$v2$ref_val$$($fonts_css_ref$$)};
$app$main$ui$shapes$text$fontfaces$shape__GT_fonts$$=function($shape$jscomp$494$$,$objects$jscomp$379$$){var $initial$jscomp$15$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$494$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$app$main$fonts$get_content_fonts$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$494$$))):$APP.$cljs$core$PersistentHashSet$EMPTY$$;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$clojure$set$union$$,
$initial$jscomp$15$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($app$main$fonts$get_content_fonts$$,$APP.$cljs$cst$1637$content$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$text_shape_QMARK_$$,$app$common$files$helpers$get_children$$($objects$jscomp$379$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$494$$)))))};
$APP.$app$main$ui$shapes$text$fontfaces$shapes__GT_fonts$$=function($shapes$jscomp$64$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$clojure$set$union$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($app$main$fonts$get_content_fonts$$,$APP.$cljs$cst$1637$content$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$text_shape_QMARK_$$,
$shapes$jscomp$64$$)))};
$APP.$app$util$strings$format_precision$$=function($num$jscomp$35$$,$precision$jscomp$15$$){try{if(typeof $num$jscomp$35$$==="number"){var $num_str__$1$jscomp$1$$=$APP.$cuerdas$core$replace$$($num$jscomp$35$$.toFixed($precision$jscomp$15$$),/\.0+$/,""),$temp__5823__auto__$jscomp$inline_6669$$=$APP.$cljs$core$re_find$$(/(\.\d*[^0])0+$/,$num_str__$1$jscomp$1$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_6669$$)?$APP.$cuerdas$core$replace$$($num_str__$1$jscomp$1$$,$APP.$cljs$core$first$$($temp__5823__auto__$jscomp$inline_6669$$),
$APP.$cljs$core$second$$($temp__5823__auto__$jscomp$inline_6669$$)):$num_str__$1$jscomp$1$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($num$jscomp$35$$)}catch($e67852$$){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($num$jscomp$35$$)}};
$app$util$thumbnails$get_proportional_size$cljs$0core$0IFn$0_invoke$0arity$06$$=function($width$jscomp$119$$,$height$jscomp$105$$,$clamped_width$jscomp$1_min_width$jscomp$1$$,$max_width$jscomp$6$$,$clamped_height$jscomp$1_min_height$$,$max_height$jscomp$1$$){$clamped_width$jscomp$1_min_width$jscomp$1$$=$APP.$app$common$math$clamp$$($width$jscomp$119$$,$clamped_width$jscomp$1_min_width$jscomp$1$$,$max_width$jscomp$6$$);$clamped_height$jscomp$1_min_height$$=$APP.$app$common$math$clamp$$($height$jscomp$105$$,
$clamped_height$jscomp$1_min_height$$,$max_height$jscomp$1$$);return $width$jscomp$119$$>$height$jscomp$105$$?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$clamped_width$jscomp$1_min_width$jscomp$1$$,$height$jscomp$105$$*$clamped_width$jscomp$1_min_width$jscomp$1$$/$width$jscomp$119$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$width$jscomp$119$$*$clamped_height$jscomp$1_min_height$$/$height$jscomp$105$$,
$clamped_height$jscomp$1_min_height$$],null)};
$app$util$thumbnails$get_relative_size$$=function($width$jscomp$120$$,$height$jscomp$106$$){var $aspect_ratio$jscomp$1$$=$width$jscomp$120$$/$height$jscomp$106$$;return $aspect_ratio$jscomp$1$$<.5||$aspect_ratio$jscomp$1$$>2?$app$util$thumbnails$get_proportional_size$cljs$0core$0IFn$0_invoke$0arity$06$$($width$jscomp$120$$,$height$jscomp$106$$,1,16384,1,16384):$app$util$thumbnails$get_proportional_size$cljs$0core$0IFn$0_invoke$0arity$06$$($width$jscomp$120$$,$height$jscomp$106$$,1,2048,1,2048)};
$app$main$render$calculate_dimensions$$=function($bounds$jscomp$31_objects$jscomp$380$$,$aspect_ratio$jscomp$2$$){var $root_objects$$=$app$common$types$shape_tree$get_root_objects$$($bounds$jscomp$31_objects$jscomp$380$$);if($APP.$cljs$core$empty_QMARK_$$($root_objects$$))return $app$common$geom$rect$fix_aspect_ratio$$($APP.$app$common$geom$rect$update_rect$$($APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1510$x$$,
0,$APP.$cljs$cst$1511$y$$,0,$APP.$cljs$cst$290$width$$,100,$APP.$cljs$cst$1522$height$$,100],null)),$APP.$cljs$cst$1676$position$$),$aspect_ratio$jscomp$2$$);$bounds$jscomp$31_objects$jscomp$380$$=$APP.$app$common$geom$rect$join_rects$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$shapes$bounds$get_object_bounds$$,$bounds$jscomp$31_objects$jscomp$380$$),$root_objects$$));return $app$common$geom$rect$fix_aspect_ratio$$($APP.$app$common$geom$rect$update_rect$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($bounds$jscomp$31_objects$jscomp$380$$,
$APP.$cljs$cst$1510$x$$,$APP.$app$common$math$finite$$,0),$APP.$cljs$cst$1511$y$$,$APP.$app$common$math$finite$$,0),$APP.$cljs$cst$290$width$$,$APP.$app$common$math$finite$$,1E5),$APP.$cljs$cst$1522$height$$,$APP.$app$common$math$finite$$,1E5),$APP.$cljs$cst$1676$position$$),$aspect_ratio$jscomp$2$$)};
$APP.$app$main$render$frame_wrapper_factory$$=function($objects$jscomp$381$$){var $shape_wrapper$jscomp$6$$=$APP.$app$main$render$shape_wrapper_factory$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$render$shape_wrapper_factory$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$381$$):$APP.$app$main$render$shape_wrapper_factory$$($objects$jscomp$381$$),$frame_shape$jscomp$3$$=$APP.$app$main$ui$shapes$frame$frame_shape$$($shape_wrapper$jscomp$6$$);return function($props_67871_shape$jscomp$495$$){$props_67871_shape$jscomp$495$$=
$props_67871_shape$jscomp$495$$.shape;var $thumbnails_QMARK_$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$render_thumbnails$$),$childs$jscomp$10$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$381$$),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($props_67871_shape$jscomp$495$$));return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($thumbnails_QMARK_$$)?$APP.$cljs$cst$2573$thumbnail_id$$.$cljs$core$IFn$_invoke$arity$1$($props_67871_shape$jscomp$495$$)!=
null:$thumbnails_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$frame$frame_thumbnail$$,{shape:$props_67871_shape$jscomp$495$$,bounds:$APP.$cljs$cst$1913$children_bounds$$.$cljs$core$IFn$_invoke$arity$1$($props_67871_shape$jscomp$495$$)}):(0,$APP.$rumext$v2$jsx$$)($frame_shape$jscomp$3$$,{shape:$props_67871_shape$jscomp$495$$,childs:$childs$jscomp$10$$})}};
$APP.$app$main$render$group_wrapper_factory$$=function($objects$jscomp$382$$){var $shape_wrapper$jscomp$7$$=$APP.$app$main$render$shape_wrapper_factory$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$render$shape_wrapper_factory$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$382$$):$APP.$app$main$render$shape_wrapper_factory$$($objects$jscomp$382$$),$group_shape$$=$APP.$app$main$ui$shapes$group$group_shape$$($shape_wrapper$jscomp$7$$);return function($map__67876_map__67876__$1_props_67874_shape$jscomp$496$$){$map__67876_map__67876__$1_props_67874_shape$jscomp$496$$=
$APP.$rumext$v2$util$wrap_props$$($map__67876_map__67876__$1_props_67874_shape$jscomp$496$$);$map__67876_map__67876__$1_props_67874_shape$jscomp$496$$=$APP.$cljs$core$__destructure_map$$($map__67876_map__67876__$1_props_67874_shape$jscomp$496$$);$map__67876_map__67876__$1_props_67874_shape$jscomp$496$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67876_map__67876__$1_props_67874_shape$jscomp$496$$,$APP.$cljs$cst$1811$shape$$);var $childs$jscomp$11$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67873_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$382$$,
$p1__67873_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($map__67876_map__67876__$1_props_67874_shape$jscomp$496$$));return(0,$APP.$rumext$v2$jsx$$)($group_shape$$,{shape:$map__67876_map__67876__$1_props_67874_shape$jscomp$496$$,"is-child-selected?":!0,childs:$childs$jscomp$11$$})}};
$app$main$render$bool_wrapper_factory$$=function($objects$jscomp$383$$){var $shape_wrapper$jscomp$8$$=$APP.$app$main$render$shape_wrapper_factory$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$render$shape_wrapper_factory$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$383$$):$APP.$app$main$render$shape_wrapper_factory$$($objects$jscomp$383$$),$bool_shape$$=$APP.$app$main$ui$shapes$bool$bool_shape$$($shape_wrapper$jscomp$8$$);return function($childs$jscomp$12_map__67879_map__67879__$1_props_67877$$){$childs$jscomp$12_map__67879_map__67879__$1_props_67877$$=
$APP.$rumext$v2$util$wrap_props$$($childs$jscomp$12_map__67879_map__67879__$1_props_67877$$);$childs$jscomp$12_map__67879_map__67879__$1_props_67877$$=$APP.$cljs$core$__destructure_map$$($childs$jscomp$12_map__67879_map__67879__$1_props_67877$$);var $shape$jscomp$497$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($childs$jscomp$12_map__67879_map__67879__$1_props_67877$$,$APP.$cljs$cst$1811$shape$$);$childs$jscomp$12_map__67879_map__67879__$1_props_67877$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$497$$)),
$APP.$rumext$v2$adapt$$($objects$jscomp$383$$)],function(){return $APP.$cljs$core$select_keys$$($objects$jscomp$383$$,$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$383$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$497$$)))});return(0,$APP.$rumext$v2$jsx$$)($bool_shape$$,{shape:$shape$jscomp$497$$,childs:$childs$jscomp$12_map__67879_map__67879__$1_props_67877$$})}};
$app$main$render$svg_raw_wrapper_factory$$=function($objects$jscomp$384$$){var $shape_wrapper$jscomp$9$$=$APP.$app$main$render$shape_wrapper_factory$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$render$shape_wrapper_factory$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$384$$):$APP.$app$main$render$shape_wrapper_factory$$($objects$jscomp$384$$),$svg_raw_shape$$=$APP.$app$main$ui$shapes$svg_raw$svg_raw_shape$$($shape_wrapper$jscomp$9$$);return function($map__67883_map__67883__$1_props_67881_shape$jscomp$498$$){$map__67883_map__67883__$1_props_67881_shape$jscomp$498$$=
$APP.$rumext$v2$util$wrap_props$$($map__67883_map__67883__$1_props_67881_shape$jscomp$498$$);$map__67883_map__67883__$1_props_67881_shape$jscomp$498$$=$APP.$cljs$core$__destructure_map$$($map__67883_map__67883__$1_props_67881_shape$jscomp$498$$);$map__67883_map__67883__$1_props_67881_shape$jscomp$498$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67883_map__67883__$1_props_67881_shape$jscomp$498$$,$APP.$cljs$cst$1811$shape$$);var $childs$jscomp$13$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67880_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$384$$,
$p1__67880_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($map__67883_map__67883__$1_props_67881_shape$jscomp$498$$));return $APP.$cljs$core$map_QMARK_$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($map__67883_map__67883__$1_props_67881_shape$jscomp$498$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2725$tspan$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($map__67883_map__67883__$1_props_67881_shape$jscomp$498$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$78$tag$$],null)))&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1538$svg$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($map__67883_map__67883__$1_props_67881_shape$jscomp$498$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$78$tag$$],null)))||$APP.$cljs$core$contains_QMARK_$$($map__67883_map__67883__$1_props_67881_shape$jscomp$498$$,
$APP.$cljs$cst$1890$svg_attrs$$))?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$shapes$shape$shape_container$$,{shape:$map__67883_map__67883__$1_props_67881_shape$jscomp$498$$,children:(0,$APP.$rumext$v2$jsx$$)($svg_raw_shape$$,{shape:$map__67883_map__67883__$1_props_67881_shape$jscomp$498$$,childs:$childs$jscomp$13$$})}):(0,$APP.$rumext$v2$jsx$$)($svg_raw_shape$$,{shape:$map__67883_map__67883__$1_props_67881_shape$jscomp$498$$,childs:$childs$jscomp$13$$})}};
$APP.$app$main$render$shape_wrapper_factory$$=function($objects$jscomp$385$$){return function($map__67886_map__67886__$1_props_67884_svg_raw_wrapper$$){$map__67886_map__67886__$1_props_67884_svg_raw_wrapper$$=$APP.$rumext$v2$util$wrap_props$$($map__67886_map__67886__$1_props_67884_svg_raw_wrapper$$);$map__67886_map__67886__$1_props_67884_svg_raw_wrapper$$=$APP.$cljs$core$__destructure_map$$($map__67886_map__67886__$1_props_67884_svg_raw_wrapper$$);var $frame$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67886_map__67886__$1_props_67884_svg_raw_wrapper$$,
$APP.$cljs$cst$1606$frame$$),$shape$jscomp$499$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67886_map__67886__$1_props_67884_svg_raw_wrapper$$,$APP.$cljs$cst$1811$shape$$),$group_wrapper$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$385$$)],function(){return $APP.$app$main$render$group_wrapper_factory$$($objects$jscomp$385$$)});$map__67886_map__67886__$1_props_67884_svg_raw_wrapper$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$385$$)],
function(){return $app$main$render$svg_raw_wrapper_factory$$($objects$jscomp$385$$)});var $bool_wrapper$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$385$$)],function(){return $app$main$render$bool_wrapper_factory$$($objects$jscomp$385$$)}),$frame_wrapper$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$385$$)],function(){return $APP.$app$main$render$frame_wrapper_factory$$($objects$jscomp$385$$)});
if($APP.$cljs$core$truth_$$($shape$jscomp$499$$)){var $opts$jscomp$299$$={shape:$shape$jscomp$499$$};return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$svg_raw$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$499$$))?(0,$APP.$rumext$v2$jsx$$)($map__67886_map__67886__$1_props_67884_svg_raw_wrapper$$,{shape:$shape$jscomp$499$$,frame:$frame$jscomp$19$$}):(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$shapes$shape$shape_container$$,{shape:$shape$jscomp$499$$,
children:function(){var $G__67887$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$499$$);switch($G__67887$$ instanceof $APP.$cljs$core$Keyword$$?$G__67887$$.$fqn$:null){case "text":return $APP.$rumext$v2$create_element$$($APP.$app$main$ui$shapes$text$text_shape$$,$opts$jscomp$299$$);case "rect":return $APP.$rumext$v2$create_element$$($APP.$app$main$ui$shapes$rect$rect_shape$$,$opts$jscomp$299$$);case "path":return $APP.$rumext$v2$create_element$$($APP.$app$main$ui$shapes$path$path_shape$$,
$opts$jscomp$299$$);case "image":return $APP.$rumext$v2$create_element$$($APP.$app$main$ui$shapes$image$image_shape$$,$opts$jscomp$299$$);case "circle":return $APP.$rumext$v2$create_element$$($APP.$app$main$ui$shapes$circle$circle_shape$$,$opts$jscomp$299$$);case "frame":return(0,$APP.$rumext$v2$jsx$$)($frame_wrapper$$,{shape:$shape$jscomp$499$$});case "group":return(0,$APP.$rumext$v2$jsx$$)($group_wrapper$$,{shape:$shape$jscomp$499$$,frame:$frame$jscomp$19$$});case "bool":return(0,$APP.$rumext$v2$jsx$$)($bool_wrapper$$,
{shape:$shape$jscomp$499$$,frame:$frame$jscomp$19$$});default:return null}}()})}return null}};
$APP.$app$main$render$format_viewbox$$=function($p__67889_x$jscomp$1188$$){var $height$jscomp$107_map__67890__$1$$=$APP.$cljs$core$__destructure_map$$($p__67889_x$jscomp$1188$$);$p__67889_x$jscomp$1188$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($height$jscomp$107_map__67890__$1$$,$APP.$cljs$cst$1510$x$$,0);var $y$jscomp$424$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($height$jscomp$107_map__67890__$1$$,$APP.$cljs$cst$1511$y$$,0),$width$jscomp$121$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($height$jscomp$107_map__67890__$1$$,
$APP.$cljs$cst$290$width$$,100);$height$jscomp$107_map__67890__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($height$jscomp$107_map__67890__$1$$,$APP.$cljs$cst$1522$height$$,100);return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67888_SHARP_$$){return $APP.$app$util$strings$format_precision$$($p1__67888_SHARP_$$,3)},new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$p__67889_x$jscomp$1188$$,$y$jscomp$424$$,$width$jscomp$121$$,$height$jscomp$107_map__67890__$1$$],null)))};
$app$main$render$frame_imposter$$=function($props_67897$$){var $x$jscomp$1189$$=$props_67897$$.x,$height$jscomp$108$$=$props_67897$$.height,$y$jscomp$425$$=$props_67897$$.y,$frame$jscomp$20$$=$props_67897$$.frame,$width$jscomp$122$$=$props_67897$$.width,$background$jscomp$9$$=$props_67897$$.background,$shape_wrapper$jscomp$11$$=$APP.$app$main$render$shape_wrapper_factory$$($props_67897$$.objects);return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$render_thumbnails$$),
{value:!1,children:(0,$APP.$rumext$v2$jsxs$$)("svg",{viewBox:$props_67897$$.vbox,width:$APP.$app$util$strings$format_precision$$($width$jscomp$122$$,3),height:$APP.$app$util$strings$format_precision$$($height$jscomp$108$$,3),version:"1.1",xmlns:"http://www.w3.org/2000/svg",xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",children:[$background$jscomp$9$$!=null?(0,$APP.$rumext$v2$jsx$$)("rect",{x:$x$jscomp$1189$$,y:$y$jscomp$425$$,width:$width$jscomp$122$$,height:$height$jscomp$108$$,fill:$background$jscomp$9$$}):
null,(0,$APP.$rumext$v2$jsx$$)($shape_wrapper$jscomp$11$$,{shape:$frame$jscomp$20$$})]})})};
$app$main$render$empty_grids$$=function($empty_grids__$1_props_67906$$){var $root_shape_id$$=$empty_grids__$1_props_67906$$["root-shape-id"],$objects$jscomp$391$$=$empty_grids__$1_props_67906$$.objects;$empty_grids__$1_props_67906$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67905_SHARP_$$){return $APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($p1__67905_SHARP_$$))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67904_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$391$$,
$p1__67904_SHARP_$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67903_SHARP_$$){return $APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$391$$,$p1__67903_SHARP_$$)},$APP.$cljs$core$cons$$($root_shape_id$$,$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$391$$,$root_shape_id$$)))));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$30$$,
$grid$jscomp$3$$){$out_arr__44124__auto__$jscomp$30$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$grid_layout_viewer$grid_layout_viewer$$,{shape:$grid$jscomp$3$$,objects:$objects$jscomp$391$$}));return $out_arr__44124__auto__$jscomp$30$$},[],$empty_grids__$1_props_67906$$)};
$app$main$render$render_to_canvas$$=function($objects$jscomp$396$$,$canvas$jscomp$11$$,$bounds$jscomp$35$$,$scale$jscomp$27$$,$object_id$jscomp$11$$,$on_render$jscomp$3$$){var $width$jscomp$128$$=$canvas$jscomp$11$$.width,$height$jscomp$114$$=$canvas$jscomp$11$$.height,$os_canvas$$=new OffscreenCanvas($width$jscomp$128$$,$height$jscomp$114$$);try{return $APP.$app$render_wasm$api$init_canvas_context$$($os_canvas$$)?$APP.$app$render_wasm$api$initialize_viewport$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($objects$jscomp$396$$,
$scale$jscomp$27$$,$bounds$jscomp$35$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3091$background_opacity$$,0,$cljs$cst$3092$on_render$$,function(){$app$render_wasm$api$render_sync_shape$$($object_id$jscomp$11$$);return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){var $bitmap$jscomp$5$$=$os_canvas$$.transferToImageBitmap(),$ctx2d$jscomp$1$$=$canvas$jscomp$11$$.getContext("2d");$ctx2d$jscomp$1$$.clearRect(0,0,$width$jscomp$128$$,$height$jscomp$114$$);
$ctx2d$jscomp$1$$.drawImage($bitmap$jscomp$5$$,0,0);$APP.$app$util$dom$set_attribute_BANG_$$($canvas$jscomp$11$$,"id","screenshot-"+($object_id$jscomp$11$$??""));$APP.$app$render_wasm$api$clear_canvas$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);return $on_render$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_render$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_render$jscomp$3$$()})}])):null}catch($e67940$$){return console.error("Error initializing canvas context:",
$e67940$$),!1}};
$app$main$render$render_frame$cljs$0core$0IFn$0_invoke$0arity$04$$=function($objects$jscomp$403$$,$shape$jscomp$503$$,$object_id$jscomp$14$$){if($shape$jscomp$503$$!=null){var $fonts$jscomp$21$$=$app$main$ui$shapes$text$fontfaces$shape__GT_fonts$$($shape$jscomp$503$$,$objects$jscomp$403$$),$bounds$jscomp$37_vec__67960_vec__67963$$=$APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$403$$,$shape$jscomp$503$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,
[$APP.$cljs$cst$1911$ignore_margin_QMARK_$$,!1],null)),$background$jscomp$10$$=$APP.$cuerdas$core$ends_with_QMARK_$$($object_id$jscomp$14$$,"component")?function(){var $or__5025__auto__$jscomp$744_or__5025__auto____$1$jscomp$91$$=$APP.$cljs$cst$2058$background$$.$cljs$core$IFn$_invoke$arity$1$(null);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$744_or__5025__auto____$1$jscomp$91$$))return $or__5025__auto__$jscomp$744_or__5025__auto____$1$jscomp$91$$;$or__5025__auto__$jscomp$744_or__5025__auto____$1$jscomp$91$$=
window.getComputedStyle(document.documentElement).getPropertyValue("--assets-component-background-color");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$744_or__5025__auto____$1$jscomp$91$$)?$or__5025__auto__$jscomp$744_or__5025__auto____$1$jscomp$91$$:"#fff"}():null,$x$jscomp$1190$$=$bounds$jscomp$37_vec__67960_vec__67963$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$37_vec__67960_vec__67963$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$426$$=$bounds$jscomp$37_vec__67960_vec__67963$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$37_vec__67960_vec__67963$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$130$$=$bounds$jscomp$37_vec__67960_vec__67963$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$37_vec__67960_vec__67963$$,$APP.$cljs$cst$290$width$$),$height$jscomp$116$$=$bounds$jscomp$37_vec__67960_vec__67963$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$37_vec__67960_vec__67963$$,$APP.$cljs$cst$1522$height$$),
$viewbox$jscomp$4$$=""+($x$jscomp$1190$$??"")+" "+($y$jscomp$426$$??"")+" "+($width$jscomp$130$$??"")+" "+($height$jscomp$116$$??"");$bounds$jscomp$37_vec__67960_vec__67963$$=$app$util$thumbnails$get_relative_size$$($width$jscomp$130$$,$height$jscomp$116$$);var $fixed_width$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bounds$jscomp$37_vec__67960_vec__67963$$,0,null),$fixed_height$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bounds$jscomp$37_vec__67960_vec__67963$$,1,
null);$bounds$jscomp$37_vec__67960_vec__67963$$=$app$util$thumbnails$get_proportional_size$cljs$0core$0IFn$0_invoke$0arity$06$$($width$jscomp$130$$,$height$jscomp$116$$,140,140,140,140);var $component_width$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bounds$jscomp$37_vec__67960_vec__67963$$,0,null),$component_height$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bounds$jscomp$37_vec__67960_vec__67963$$,1,null),$data$jscomp$334$$=function(){var $public_uri_orig_val__67969$$=
$APP.$app$config$public_uri$$;$APP.$app$config$public_uri$$=$APP.$app$config$rasterizer_uri$$;try{return $shadow$js$shim$module$0react_dom$0server$$.renderToStaticMarkup($rumext$v2$element$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$render$frame_imposter$$,{objects:$objects$jscomp$403$$,frame:$shape$jscomp$503$$,vbox:$viewbox$jscomp$4$$,background:$background$jscomp$10$$,x:$x$jscomp$1190$$,y:$y$jscomp$426$$,width:$width$jscomp$130$$,height:$height$jscomp$116$$}))}finally{$APP.$app$config$public_uri$$=
$public_uri_orig_val__67969$$}}(),$component_QMARK_$$=$APP.$cuerdas$core$ends_with_QMARK_$$($object_id$jscomp$14$$,"/component");return $APP.$beicon$v2$core$map$$(function($styles$jscomp$13$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,$object_id$jscomp$14$$,$APP.$cljs$cst$142$data$$,$data$jscomp$334$$,$APP.$cljs$cst$290$width$$,$component_QMARK_$$?$component_width$$:$fixed_width$$,$APP.$cljs$cst$1522$height$$,$component_QMARK_$$?$component_height$$:$fixed_height$$,
$APP.$cljs$cst$2940$styles$$,$styles$jscomp$13$$],null)},$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$83$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.render",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$275$hint$$,"unexpected error on rendering imposter"],null)],null)}),$cause$jscomp$83$$,"app.main.render",$APP.$cljs$cst$849$error$$,!1);return $APP.$beicon$v2$core$empty$$()},$APP.$app$main$fonts$render_font_styles_cached$$($fonts$jscomp$21$$)))}$APP.$app$common$logging$enabled_QMARK_$$("app.main.render",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"imposter shape is nil"],null)],null)}),null,"app.main.render",$APP.$cljs$cst$1162$warn$$,!1);return $APP.$beicon$v2$core$empty$$()};
$app$util$queue$next_process_time$$=function($queue$jscomp$2$$){var $time$jscomp$5$$=$queue$jscomp$2$$.time,$threshold$jscomp$3$$=$queue$jscomp$2$$.threshold,$calc_time$$=Math.min(Math.max(($time$jscomp$5$$-$threshold$jscomp$3$$)*10,1E3),5E3);$APP.$app$common$logging$enabled_QMARK_$$("app.util.queue",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"queue::next-process-time"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3787$time$$,$time$jscomp$5$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2501$threshold$$,$threshold$jscomp$3$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3788$calc_time$$,$calc_time$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3789$max_time$$,5E3],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3790$min_time$$,1E3],null)],null)}),null,"app.util.queue",$APP.$cljs$cst$1160$debug$$,!1);return $calc_time$$};
$app$util$queue$cancel_process_BANG_$$=function(){var $queue$jscomp$4$$=$app$main$data$workspace$thumbnails$queue$$;$APP.$app$common$logging$enabled_QMARK_$$("app.util.queue",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,
"queue::cancel-process"],null)],null)}),null,"app.util.queue",$APP.$cljs$cst$1160$debug$$,!1);var $timeout_67925$$=$queue$jscomp$4$$.timeout;$timeout_67925$$!=null&&clearTimeout($timeout_67925$$);$queue$jscomp$4$$.timeout=null;return $queue$jscomp$4$$};
$app$util$queue$process$$=function($queue$jscomp$5$$,$iterations$jscomp$1$$){var $threshold$jscomp$4$$=$queue$jscomp$5$$.threshold,$max_iterations$$=$queue$jscomp$5$$["max-iterations"],$item$jscomp$82$$=$queue$jscomp$5$$.items.shift();if($item$jscomp$82$$!=null){var $tp$jscomp$2$$=$app$common$time$tpoint_ms$$(),$f$jscomp$825$$=$item$jscomp$82$$.f,$res$jscomp$41$$=$item$jscomp$82$$.result;return $APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$04$$($f$jscomp$825$$.$cljs$core$IFn$_invoke$arity$0$?
$f$jscomp$825$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$825$$(),function($o$jscomp$266$$){return $res$jscomp$41$$.next($o$jscomp$266$$)},function($e$jscomp$323$$){return $res$jscomp$41$$.error($e$jscomp$323$$)},function(){$res$jscomp$41$$.complete();var $G__67915_G__67917_duration$jscomp$6_time__$1$$=$tp$jscomp$2$$();$G__67915_G__67917_duration$jscomp$6_time__$1$$=$queue$jscomp$5$$.time+$G__67915_G__67917_duration$jscomp$6_time__$1$$;$queue$jscomp$5$$.time=$G__67915_G__67917_duration$jscomp$6_time__$1$$;
if($G__67915_G__67917_duration$jscomp$6_time__$1$$>$threshold$jscomp$4$$||$iterations$jscomp$1$$>=$max_iterations$$)return $G__67915_G__67917_duration$jscomp$6_time__$1$$=$app$util$queue$next_process_time$$($queue$jscomp$5$$),$app$util$queue$request_process$$.$cljs$core$IFn$_invoke$arity$3$?$app$util$queue$request_process$$.$cljs$core$IFn$_invoke$arity$3$($queue$jscomp$5$$,0,$G__67915_G__67917_duration$jscomp$6_time__$1$$):$app$util$queue$request_process$$($queue$jscomp$5$$,0,$G__67915_G__67917_duration$jscomp$6_time__$1$$);
$G__67915_G__67917_duration$jscomp$6_time__$1$$=$iterations$jscomp$1$$+1;return $app$util$queue$request_process$$.$cljs$core$IFn$_invoke$arity$3$?$app$util$queue$request_process$$.$cljs$core$IFn$_invoke$arity$3$($queue$jscomp$5$$,$G__67915_G__67917_duration$jscomp$6_time__$1$$,0):$app$util$queue$request_process$$($queue$jscomp$5$$,$G__67915_G__67917_duration$jscomp$6_time__$1$$,0)})}return null};
$app$util$queue$request_process$$=function($queue$jscomp$6$$,$iterations$jscomp$2$$,$time$jscomp$7$$){$APP.$app$common$logging$enabled_QMARK_$$("app.util.queue",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"queue::request-process"],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3787$time$$,$time$jscomp$7$$],null)],null)}),null,"app.util.queue",$APP.$cljs$cst$1160$debug$$,!1);return $queue$jscomp$6$$.timeout=setTimeout(function(){$queue$jscomp$6$$.timeout=null;return $app$util$queue$process$$($queue$jscomp$6$$,$iterations$jscomp$2$$)},$time$jscomp$7$$)};
$app$main$data$workspace$thumbnails$clear_queue_BANG_$$=function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.thumbnails",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"clearing thumbnail queue"],
null)],null)}),null,"app.main.data.workspace.thumbnails",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($app$util$queue$cancel_process_BANG_$$(),"items",[]),"time",0)};
$app$main$data$workspace$thumbnails$render_thumbnail$$=function($objects$jscomp$404_state$jscomp$431$$,$file_id$jscomp$115$$,$page_id$jscomp$142$$,$frame_id$jscomp$69_shape$jscomp$504$$,$object_id$jscomp$15_tag$jscomp$80$$){$object_id$jscomp$15_tag$jscomp$80$$=$APP.$app$common$thumbnails$fmt_object_id$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$115$$,$page_id$jscomp$142$$,$frame_id$jscomp$69_shape$jscomp$504$$,$object_id$jscomp$15_tag$jscomp$80$$);var $tp$jscomp$3$$=$app$common$time$tpoint_ms$$();
$objects$jscomp$404_state$jscomp$431$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$helpers$get_page$$($APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$404_state$jscomp$431$$,$file_id$jscomp$115$$),$page_id$jscomp$142$$));$frame_id$jscomp$69_shape$jscomp$504$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$404_state$jscomp$431$$,$frame_id$jscomp$69_shape$jscomp$504$$);return $APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.thumbnails",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"thumbnail rendered"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2278$elapsed$$,""+($tp$jscomp$3$$()??"")+
"ms"],null)],null)}),null,"app.main.data.workspace.thumbnails",$APP.$cljs$cst$1160$debug$$,!1);return null},$APP.$beicon$v2$core$mapcat$$($APP.$app$main$rasterizer$render$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,$APP.$beicon$v2$core$take$$($app$main$render$render_frame$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$404_state$jscomp$431$$,$frame_id$jscomp$69_shape$jscomp$504$$,$object_id$jscomp$15_tag$jscomp$80$$)))))};
$app$main$data$workspace$thumbnails$request_thumbnail$$=function($queue$jscomp$inline_6682_state$jscomp$432$$,$file_id$jscomp$116_result$jscomp$inline_6685$$,$f$jscomp$inline_6681_item_67929$jscomp$inline_6686_item_67931$jscomp$inline_6687_page_id$jscomp$143$$,$items$jscomp$inline_6683_shape_id$jscomp$88$$,$find_fn$jscomp$inline_6684_tag$jscomp$81$$){var $request$jscomp$inline_6680$$={"file-id":$file_id$jscomp$116_result$jscomp$inline_6685$$,"page-id":$f$jscomp$inline_6681_item_67929$jscomp$inline_6686_item_67931$jscomp$inline_6687_page_id$jscomp$143$$,
"shape-id":$items$jscomp$inline_6683_shape_id$jscomp$88$$,tag:$find_fn$jscomp$inline_6684_tag$jscomp$81$$};$f$jscomp$inline_6681_item_67929$jscomp$inline_6686_item_67931$jscomp$inline_6687_page_id$jscomp$143$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$main$data$workspace$thumbnails$render_thumbnail$$,$queue$jscomp$inline_6682_state$jscomp$432$$,$file_id$jscomp$116_result$jscomp$inline_6685$$,$f$jscomp$inline_6681_item_67929$jscomp$inline_6686_item_67931$jscomp$inline_6687_page_id$jscomp$143$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$items$jscomp$inline_6683_shape_id$jscomp$88$$,$find_fn$jscomp$inline_6684_tag$jscomp$81$$]));$queue$jscomp$inline_6682_state$jscomp$432$$=$app$main$data$workspace$thumbnails$queue$$;$items$jscomp$inline_6683_shape_id$jscomp$88$$=$queue$jscomp$inline_6682_state$jscomp$432$$.items;$find_fn$jscomp$inline_6684_tag$jscomp$81$$=$queue$jscomp$inline_6682_state$jscomp$432$$["find-fn"];$file_id$jscomp$116_result$jscomp$inline_6685$$=$APP.$beicon$v2$core$subject$$();
$request$jscomp$inline_6680$$.result=$file_id$jscomp$116_result$jscomp$inline_6685$$;$request$jscomp$inline_6680$$.f=$f$jscomp$inline_6681_item_67929$jscomp$inline_6686_item_67931$jscomp$inline_6687_page_id$jscomp$143$$;$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($request$jscomp$inline_6680$$.tag,"frame")?($f$jscomp$inline_6681_item_67929$jscomp$inline_6686_item_67931$jscomp$inline_6687_page_id$jscomp$143$$=$items$jscomp$inline_6683_shape_id$jscomp$88$$.find($find_fn$jscomp$inline_6684_tag$jscomp$81$$),
$APP.$cljs$core$truth_$$($f$jscomp$inline_6681_item_67929$jscomp$inline_6686_item_67931$jscomp$inline_6687_page_id$jscomp$143$$)?$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$inline_6681_item_67929$jscomp$inline_6686_item_67931$jscomp$inline_6687_page_id$jscomp$143$$.result,$file_id$jscomp$116_result$jscomp$inline_6685$$):($queue$jscomp$inline_6682_state$jscomp$432$$.items.unshift($request$jscomp$inline_6680$$),$queue$jscomp$inline_6682_state$jscomp$432$$.timeout!=
null||$app$util$queue$request_process$$($queue$jscomp$inline_6682_state$jscomp$432$$,0,$app$util$queue$next_process_time$$($queue$jscomp$inline_6682_state$jscomp$432$$)))):($f$jscomp$inline_6681_item_67929$jscomp$inline_6686_item_67931$jscomp$inline_6687_page_id$jscomp$143$$=$items$jscomp$inline_6683_shape_id$jscomp$88$$.findLast($find_fn$jscomp$inline_6684_tag$jscomp$81$$),$APP.$cljs$core$truth_$$($f$jscomp$inline_6681_item_67929$jscomp$inline_6686_item_67931$jscomp$inline_6687_page_id$jscomp$143$$)?
$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$inline_6681_item_67929$jscomp$inline_6686_item_67931$jscomp$inline_6687_page_id$jscomp$143$$.result,$file_id$jscomp$116_result$jscomp$inline_6685$$):($queue$jscomp$inline_6682_state$jscomp$432$$.items.push($request$jscomp$inline_6680$$),$queue$jscomp$inline_6682_state$jscomp$432$$.timeout!=null||$app$util$queue$request_process$$($queue$jscomp$inline_6682_state$jscomp$432$$,0,$app$util$queue$next_process_time$$($queue$jscomp$inline_6682_state$jscomp$432$$))));
return $file_id$jscomp$116_result$jscomp$inline_6685$$.asObservable()};
$app$main$data$workspace$thumbnails$clear_thumbnail$cljs$0core$0IFn$0_invoke$0arity$04$$=function($file_id$jscomp$117$$,$page_id$jscomp$144$$,$frame_id$jscomp$70$$,$tag$jscomp$82$$){return $app$main$data$workspace$thumbnails$clear_thumbnail$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$117$$,$APP.$app$common$thumbnails$fmt_object_id$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$117$$,$page_id$jscomp$144$$,$frame_id$jscomp$70$$,$tag$jscomp$82$$))};
$app$main$data$workspace$thumbnails$clear_thumbnail$cljs$0core$0IFn$0_invoke$0arity$02$$=function($file_id$jscomp$118$$,$object_id$jscomp$16$$){var $pending$jscomp$18$$=$APP.$cljs$core$volatile_BANG_$$(!1);typeof $app$main$data$workspace$thumbnails$clear_thumbnail_68039$$==="undefined"&&($app$main$data$workspace$thumbnails$clear_thumbnail_68039$$=function($file_id$jscomp$119$$,$object_id$jscomp$17$$,$pending$jscomp$19$$,$meta68040$$){this.$file_id$=$file_id$jscomp$119$$;this.$object_id$=$object_id$jscomp$17$$;
this.pending=$pending$jscomp$19$$;this.$meta68040$=$meta68040$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$thumbnails$clear_thumbnail_68039$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$thumbnails$clear_thumbnail_68039$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3791$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_clear_thumbnail$$},
$app$main$data$workspace$thumbnails$clear_thumbnail_68039$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68041$$,$meta68040__$1$$){return new $app$main$data$workspace$thumbnails$clear_thumbnail_68039$$(this.$file_id$,this.$object_id$,this.pending,$meta68040__$1$$)},$app$main$data$workspace$thumbnails$clear_thumbnail_68039$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68040$},$app$main$data$workspace$thumbnails$clear_thumbnail_68039$$.prototype.$cljs$core$IDeref$_deref$arity$1$=
function(){return this.$object_id$},$app$main$data$workspace$thumbnails$clear_thumbnail_68039$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$thumbnails$clear_thumbnail_68039$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2010$$,$state$jscomp$433$$){var $self__$jscomp$4507$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$433$$,
$APP.$cljs$cst$2229$thumbnails$$,function($thumbs$$){var $temp__5823__auto__$jscomp$174$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($thumbs$$,$self__$jscomp$4507$$.$object_id$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$174$$)?($APP.$cljs$core$_vreset_BANG_$$($self__$jscomp$4507$$.pending,$temp__5823__auto__$jscomp$174$$),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($thumbs$$,$self__$jscomp$4507$$.$object_id$)):$thumbs$$}),$APP.$cljs$cst$2236$thumbnails_meta$$,
$APP.$cljs$core$dissoc$$,$self__$jscomp$4507$$.$object_id$)},$app$main$data$workspace$thumbnails$clear_thumbnail_68039$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$thumbnails$clear_thumbnail_68039$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $temp__5823__auto__$jscomp$175$$=$APP.$cljs$core$_deref$$(this.pending);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$175$$)?($APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.thumbnails",
$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"clear-thumbnail"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1579$uri$$,$temp__5823__auto__$jscomp$175$$],
null)],null)}),null,"app.main.data.workspace.thumbnails",$APP.$cljs$cst$144$trace$$,!1),$APP.$cuerdas$core$starts_with_QMARK_$$($temp__5823__auto__$jscomp$175$$,"blob:")&&$APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$webapi$revoke_uri$$,$temp__5823__auto__$jscomp$175$$)),$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$empty$$,
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3792$delete_file_object_thumbnail$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,this.$file_id$,$APP.$cljs$cst$2272$object_id$$,this.$object_id$],null))))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$thumbnails$clear_thumbnail_68039$$($file_id$jscomp$118$$,$object_id$jscomp$16$$,$pending$jscomp$18$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$thumbnails$assoc_thumbnail$$=function($object_id$jscomp$18$$,$uri$jscomp$94$$){var $prev_uri_STAR_$$=$APP.$cljs$core$volatile_BANG_$$(null);typeof $app$main$data$workspace$thumbnails$assoc_thumbnail_68049$$==="undefined"&&($app$main$data$workspace$thumbnails$assoc_thumbnail_68049$$=function($object_id$jscomp$19$$,$uri$jscomp$95$$,$prev_uri_STAR_$jscomp$1$$,$meta68050$$){this.$object_id$=$object_id$jscomp$19$$;this.uri=$uri$jscomp$95$$;this.$prev_uri_STAR_$=$prev_uri_STAR_$jscomp$1$$;
this.$meta68050$=$meta68050$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$thumbnails$assoc_thumbnail_68049$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$thumbnails$assoc_thumbnail_68049$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3793$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_assoc_thumbnail$$},$app$main$data$workspace$thumbnails$assoc_thumbnail_68049$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_68051$$,$meta68050__$1$$){return new $app$main$data$workspace$thumbnails$assoc_thumbnail_68049$$(this.$object_id$,this.uri,this.$prev_uri_STAR_$,$meta68050__$1$$)},$app$main$data$workspace$thumbnails$assoc_thumbnail_68049$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68050$},$app$main$data$workspace$thumbnails$assoc_thumbnail_68049$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$thumbnails$assoc_thumbnail_68049$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2012_prev_uri$$,$state$jscomp$434$$){var $self__$jscomp$4512$$=this;$_$jscomp$2012_prev_uri$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$434$$,$APP.$cljs$cst$2229$thumbnails$$),$self__$jscomp$4512$$.$object_id$);var $now$jscomp$6$$=Date.now();$_$jscomp$2012_prev_uri$$!=null&&$APP.$cljs$core$_vreset_BANG_$$($self__$jscomp$4512$$.$prev_uri_STAR_$,$_$jscomp$2012_prev_uri$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.thumbnails",
$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"assoc thumbnail"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2272$object_id$$,$self__$jscomp$4512$$.$object_id$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1579$uri$$,$self__$jscomp$4512$$.uri],null)],null)}),null,"app.main.data.workspace.thumbnails",$APP.$cljs$cst$144$trace$$,!1);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$434$$,$APP.$cljs$cst$2229$thumbnails$$,$APP.$cljs$core$assoc$$,$self__$jscomp$4512$$.$object_id$,$self__$jscomp$4512$$.uri),
$APP.$cljs$cst$2236$thumbnails_meta$$,$APP.$cljs$core$assoc$$,$self__$jscomp$4512$$.$object_id$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2237$rendered_at$$,$now$jscomp$6$$],null))},$app$main$data$workspace$thumbnails$assoc_thumbnail_68049$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$thumbnails$assoc_thumbnail_68049$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){var $self__$jscomp$4513$$=this;return $APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $temp__5825__auto__$jscomp$200$$=
$APP.$cljs$core$_deref$$($self__$jscomp$4513$$.$prev_uri_STAR_$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$200$$)?$APP.$app$util$webapi$revoke_uri$$($temp__5825__auto__$jscomp$200$$):null})});return new $app$main$data$workspace$thumbnails$assoc_thumbnail_68049$$($object_id$jscomp$18$$,$uri$jscomp$94$$,$prev_uri_STAR_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$thumbnails$update_thumbnail$$=function($file_id$jscomp$120$$,$page_id$jscomp$145$$,$frame_id$jscomp$71$$,$tag$jscomp$83$$,$requester$$){var $object_id$jscomp$20$$=$APP.$app$common$thumbnails$fmt_object_id$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$120$$,$page_id$jscomp$145$$,$frame_id$jscomp$71$$,$tag$jscomp$83$$);typeof $app$main$data$workspace$thumbnails$update_thumbnail_68066$$==="undefined"&&($app$main$data$workspace$thumbnails$update_thumbnail_68066$$=function($file_id$jscomp$121$$,
$page_id$jscomp$146$$,$frame_id$jscomp$72$$,$tag$jscomp$84$$,$requester$jscomp$1$$,$object_id$jscomp$21$$,$meta68067$$){this.$file_id$=$file_id$jscomp$121$$;this.$page_id$=$page_id$jscomp$146$$;this.$frame_id$=$frame_id$jscomp$72$$;this.tag=$tag$jscomp$84$$;this.$requester$=$requester$jscomp$1$$;this.$object_id$=$object_id$jscomp$21$$;this.$meta68067$=$meta68067$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$thumbnails$update_thumbnail_68066$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$thumbnails$update_thumbnail_68066$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3795$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_update_thumbnail$$},$app$main$data$workspace$thumbnails$update_thumbnail_68066$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68068$$,$meta68067__$1$$){return new $app$main$data$workspace$thumbnails$update_thumbnail_68066$$(this.$file_id$,this.$page_id$,
this.$frame_id$,this.tag,this.$requester$,this.$object_id$,$meta68067__$1$$)},$app$main$data$workspace$thumbnails$update_thumbnail_68066$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68067$},$app$main$data$workspace$thumbnails$update_thumbnail_68066$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.$object_id$},$app$main$data$workspace$thumbnails$update_thumbnail_68066$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$thumbnails$update_thumbnail_68066$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2016$$,$state$jscomp$436$$,$stream$jscomp$44$$){var $self__$jscomp$4522$$=this;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.thumbnails",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,
"update thumbnail"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3796$requester$$,$self__$jscomp$4522$$.$requester$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2272$object_id$$,$self__$jscomp$4522$$.$object_id$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$78$tag$$,$self__$jscomp$4522$$.tag],
null)],null)}),null,"app.main.data.workspace.thumbnails",$APP.$cljs$cst$1160$debug$$,!1);var $tp$jscomp$4$$=$app$common$time$tpoint_ms$$();return $APP.$beicon$v2$core$take_until$$($APP.$beicon$v2$core$filter$$(function($p1__68065_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($p1__68065_SHARP_$$),$self__$jscomp$4522$$.$object_id$)},$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3791$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_clear_thumbnail$$),
$stream$jscomp$44$$)),$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.thumbnails",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,
"thumbnail updated"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2278$elapsed$$,""+($tp$jscomp$4$$()??"")+"ms"],null)],null)}),null,"app.main.data.workspace.thumbnails",$APP.$cljs$cst$1160$debug$$,!1);return null},$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$84$$){console.error($cause$jscomp$84$$);return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$mapcat$$(function($blob$jscomp$29_params$jscomp$266$$){var $uri$jscomp$96$$=
$APP.$app$util$webapi$create_uri$$($blob$jscomp$29_params$jscomp$266$$),$or__5025__auto__$jscomp$inline_6689$$=$self__$jscomp$4522$$.tag;$blob$jscomp$29_params$jscomp$266$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$4522$$.$file_id$,$APP.$cljs$cst$2272$object_id$$,$self__$jscomp$4522$$.$object_id$,$APP.$cljs$cst$1639$media$$,$blob$jscomp$29_params$jscomp$266$$,$APP.$cljs$cst$78$tag$$,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_6689$$)?
$or__5025__auto__$jscomp$inline_6689$$:"frame"],null);return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$thumbnails$assoc_thumbnail$$($self__$jscomp$4522$$.$object_id$,$uri$jscomp$96$$)),$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$empty$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2262$create_file_object_thumbnail$$,$blob$jscomp$29_params$jscomp$266$$))))},
$app$main$data$workspace$thumbnails$request_thumbnail$$($state$jscomp$436$$,$self__$jscomp$4522$$.$file_id$,$self__$jscomp$4522$$.$page_id$,$self__$jscomp$4522$$.$frame_id$,$self__$jscomp$4522$$.tag)))))});return new $app$main$data$workspace$thumbnails$update_thumbnail_68066$$($file_id$jscomp$120$$,$page_id$jscomp$145$$,$frame_id$jscomp$71$$,$tag$jscomp$83$$,$requester$$,$object_id$jscomp$20$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$thumbnails$extract_frame_changes$$=function($page_id$jscomp$147$$,$p__68084_vec__68088$$){function $get_frame_ids_cached$$($id$jscomp$527$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($frame_id_cache$$),$id$jscomp$527$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($frame_id_cache$$),$id$jscomp$527$$):$get_frame_ids$$($id$jscomp$527$$)}function $get_frame_ids$$($id$jscomp$526$$){var $old_objects$jscomp$1_result$jscomp$282$$=
$lookup_data_objects$$($old_data$$,$page_id$jscomp$147$$),$new_objects$jscomp$1$$=$lookup_data_objects$$($new_data$jscomp$1$$,$page_id$jscomp$147$$),$new_shape$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_objects$jscomp$1$$,$id$jscomp$526$$),$old_shape$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_objects$jscomp$1_result$jscomp$282$$,$id$jscomp$526$$),$old_frame_id$$=$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($old_shape$$)?
$id$jscomp$526$$:$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($old_shape$$),$new_frame_id$$=$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$16$$)?$id$jscomp$526$$:$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$16$$),$root_frame_old_QMARK_$$=$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($old_objects$jscomp$1_result$jscomp$282$$,$old_frame_id$$),$root_frame_new_QMARK_$$=
$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($new_objects$jscomp$1$$,$new_frame_id$$),$instance_root_QMARK_$jscomp$1$$=$APP.$app$common$types$component$instance_root_QMARK_$$($new_shape$jscomp$16$$),$local_result$$=function(){var $G__68113__$1_G__68113__$2$$=$APP.$cljs$core$truth_$$($root_frame_old_QMARK_$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["frame",$old_frame_id$$],null)):$APP.$cljs$core$PersistentHashSet$EMPTY$$;$G__68113__$1_G__68113__$2$$=$APP.$cljs$core$truth_$$($root_frame_new_QMARK_$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__68113__$1_G__68113__$2$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["frame",$new_frame_id$$],null)):$G__68113__$1_G__68113__$2$$;return $instance_root_QMARK_$jscomp$1$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__68113__$1_G__68113__$2$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["component",$id$jscomp$526$$],null)):$G__68113__$1_G__68113__$2$$}();$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($frame_id_cache$$,$APP.$cljs$core$assoc$$,$id$jscomp$526$$,$local_result$$);$old_objects$jscomp$1_result$jscomp$282$$=function(){var $G__68114__$1$$=$APP.$cljs$core$uuid_QMARK_$$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($old_shape$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,
$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($old_shape$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$526$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($old_shape$$))?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($local_result$$,$get_frame_ids_cached$$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($old_shape$$))):$local_result$$;return $APP.$cljs$core$uuid_QMARK_$$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$16$$))&&
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$16$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$526$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$16$$))?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($G__68114__$1$$,$get_frame_ids_cached$$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$16$$))):
$G__68114__$1$$}();$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($frame_id_cache$$,$APP.$cljs$core$assoc$$,$id$jscomp$526$$,$old_objects$jscomp$1_result$jscomp$282$$);return $old_objects$jscomp$1_result$jscomp$282$$}function $lookup_data_objects$$($data$jscomp$335$$,$page_id__$1$jscomp$6$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$335$$,$APP.$cljs$cst$1630$pages_index$$),
$page_id__$1$jscomp$6$$),$APP.$cljs$cst$1631$objects$$)}var $changes$jscomp$189_event$jscomp$92$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68084_vec__68088$$,0,null);$p__68084_vec__68088$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68084_vec__68088$$,1,null);var $old_data$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68084_vec__68088$$,0,null),$new_data$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68084_vec__68088$$,
1,null);$changes$jscomp$189_event$jscomp$92$$=$APP.$cljs$cst$3131$changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$189_event$jscomp$92$$);var $frame_id_cache$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__68108__$1_p__68107$$){$map__68108__$1_p__68107$$=
$APP.$cljs$core$__destructure_map$$($map__68108__$1_p__68107$$);var $page_id__$1$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68108__$1_p__68107$$,$APP.$cljs$cst$2043$page_id$$),$G__68109$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68108__$1_p__68107$$,$APP.$cljs$cst$139$type$$);switch($G__68109$$ instanceof $APP.$cljs$core$Keyword$$?$G__68109$$.$fqn$:null){case "add-obj":return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$page_id__$1$jscomp$7$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__68108__$1_p__68107$$)],null)],null);case "mod-obj":return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$page_id__$1$jscomp$7$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__68108__$1_p__68107$$)],
null)],null);case "del-obj":return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$page_id__$1$jscomp$7$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__68108__$1_p__68107$$)],null)],null);case "mov-objects":return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68082_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$page_id__$1$jscomp$7$$,$p1__68082_SHARP_$$],null)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($map__68108__$1_p__68107$$));default:return $APP.$cljs$core$PersistentVector$EMPTY$$}}),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p__68115_page_id_SINGLEQUOTE_$$){$p__68115_page_id_SINGLEQUOTE_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68115_page_id_SINGLEQUOTE_$$,0,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$147$$,
$p__68115_page_id_SINGLEQUOTE_$$)}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p__68119$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68119$$,0,null);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68119$$,1,null)}),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($get_frame_ids_cached$$)])),$changes$jscomp$189_event$jscomp$92$$)};
$app$main$data$workspace$thumbnails$watch_state_changes$$=function($file_id$jscomp$122$$,$page_id$jscomp$148$$){typeof $app$main$data$workspace$thumbnails$watch_state_changes_68127$$==="undefined"&&($app$main$data$workspace$thumbnails$watch_state_changes_68127$$=function($file_id$jscomp$123$$,$page_id$jscomp$149$$,$meta68128$$){this.$file_id$=$file_id$jscomp$123$$;this.$page_id$=$page_id$jscomp$149$$;this.$meta68128$=$meta68128$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$thumbnails$watch_state_changes_68127$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$thumbnails$watch_state_changes_68127$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3797$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_watch_state_changes$$},$app$main$data$workspace$thumbnails$watch_state_changes_68127$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68129$$,$meta68128__$1$$){return new $app$main$data$workspace$thumbnails$watch_state_changes_68127$$(this.$file_id$,
this.$page_id$,$meta68128__$1$$)},$app$main$data$workspace$thumbnails$watch_state_changes_68127$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68128$},$app$main$data$workspace$thumbnails$watch_state_changes_68127$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$thumbnails$watch_state_changes_68127$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2018_stopper_s$$,$___$1$jscomp$1298_all_commits_s_workspace_data_s$$,
$notifier_s$jscomp$1_stream$jscomp$45$$){var $self__$jscomp$4526$$=this;$_$jscomp$2018_stopper_s$$=$APP.$beicon$v2$core$filter$$(function($event$jscomp$93_type$jscomp$480$$){$event$jscomp$93_type$jscomp$480$$=$APP.$potok$v2$core$type$$($event$jscomp$93_type$jscomp$480$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3629$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_finalize_page$$,$event$jscomp$93_type$jscomp$480$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3797$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_watch_state_changes$$,
$event$jscomp$93_type$jscomp$480$$)},$notifier_s$jscomp$1_stream$jscomp$45$$);$___$1$jscomp$1298_all_commits_s_workspace_data_s$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$buffer$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)(null),$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$refs$workspace_data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!0],null)))));
$___$1$jscomp$1298_all_commits_s_workspace_data_s$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__68123_SHARP_$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.thumbnails",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"inconming change"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1786$origin$$,"all"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1607$frame_id$$,""+($p1__68123_SHARP_$$??"")],null)],null)}),null,"app.main.data.workspace.thumbnails",$APP.$cljs$cst$144$trace$$,!1);return null},$APP.$beicon$v2$core$merge_map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$workspace$thumbnails$extract_frame_changes$$,
$self__$jscomp$4526$$.$page_id$),$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($___$1$jscomp$1298_all_commits_s_workspace_data_s$$,$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$app$main$data$changes$commit_QMARK_$$,$notifier_s$jscomp$1_stream$jscomp$45$$)))))));$notifier_s$jscomp$1_stream$jscomp$45$$=$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.thumbnails",
$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"buffer initialized"],null)],null)}),null,"app.main.data.workspace.thumbnails",$APP.$cljs$cst$144$trace$$,!1);return null},$APP.$beicon$v2$core$debounce$$(5E3,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3160$app_DOT_main_DOT_data_DOT_persistence_SLASH_commit_persisted$$),
$notifier_s$jscomp$1_stream$jscomp$45$$)));return $APP.$beicon$v2$core$take_until$$($_$jscomp$2018_stopper_s$$,$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$mapcat$$(function($frame_id$jscomp$73_p__68138$$){var $tag$jscomp$85$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($frame_id$jscomp$73_p__68138$$,0,null);$frame_id$jscomp$73_p__68138$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($frame_id$jscomp$73_p__68138$$,1,null);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$thumbnails$clear_thumbnail$cljs$0core$0IFn$0_invoke$0arity$04$$($self__$jscomp$4526$$.$file_id$,
$self__$jscomp$4526$$.$page_id$,$frame_id$jscomp$73_p__68138$$,$tag$jscomp$85$$))},$___$1$jscomp$1298_all_commits_s_workspace_data_s$$),$APP.$beicon$v2$core$map$$(function($frame_id$jscomp$74_p__68142$$){var $tag$jscomp$86$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($frame_id$jscomp$74_p__68142$$,0,null);$frame_id$jscomp$74_p__68142$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($frame_id$jscomp$74_p__68142$$,1,null);return $app$main$data$workspace$thumbnails$update_thumbnail$$($self__$jscomp$4526$$.$file_id$,
$self__$jscomp$4526$$.$page_id$,$frame_id$jscomp$74_p__68142$$,$tag$jscomp$86$$,"watch-state-changes")},$APP.$beicon$v2$core$mapcat$$(function($p1__68124_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$p1__68124_SHARP_$$)},$APP.$beicon$v2$core$buffer_until$$($notifier_s$jscomp$1_stream$jscomp$45$$,$___$1$jscomp$1298_all_commits_s_workspace_data_s$$)))))});return new $app$main$data$workspace$thumbnails$watch_state_changes_68127$$($file_id$jscomp$122$$,
$page_id$jscomp$148$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$thumbnails_wasm$png_bytes__GT_data_uri$$=function($png_bytes$$){var $blob$jscomp$30$$=$APP.$app$util$webapi$create_blob$cljs$0core$0IFn$0_invoke$0arity$02$$($png_bytes$$,"image/png"),$reader$jscomp$52$$=new FileReader;return new Promise(function($resolve$jscomp$32$$,$reject$jscomp$21$$){$reader$jscomp$52$$.onload=function(){var $G__68191$$=$reader$jscomp$52$$.result;return $resolve$jscomp$32$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$32$$.$cljs$core$IFn$_invoke$arity$1$($G__68191$$):
$resolve$jscomp$32$$($G__68191$$)};$reader$jscomp$52$$.onerror=function($e$jscomp$324$$){return $reject$jscomp$21$$.$cljs$core$IFn$_invoke$arity$1$?$reject$jscomp$21$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$324$$):$reject$jscomp$21$$($e$jscomp$324$$)};return $reader$jscomp$52$$.readAsDataURL($blob$jscomp$30$$)})};
$app$main$data$workspace$thumbnails_wasm$render_component_pixels$$=function($file_id$jscomp$124$$,$page_id$jscomp$150$$,$frame_id$jscomp$75$$){return $APP.$beicon$v2$core$create$$(function($subs$jscomp$17$$){var $req_id$$=(0,$APP.$app$util$timers$request_animation_frame$$)(function(){try{var $objects$jscomp$405$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$file_id$jscomp$124$$,$page_id$jscomp$150$$),$temp__5823__auto__$jscomp$176$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$405$$,$frame_id$jscomp$75$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$176$$)){var $map__68195$$=$app$render_wasm$api$get_shape_extrect$$($frame_id$jscomp$75$$),$map__68195__$1$$=$APP.$cljs$core$__destructure_map$$($map__68195$$),$ext_w$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68195__$1$$,$APP.$cljs$cst$290$width$$),$ext_h$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68195__$1$$,
$APP.$cljs$cst$1522$height$$),$map__68196$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($temp__5823__auto__$jscomp$176$$),$map__68196__$1$$=$APP.$cljs$core$__destructure_map$$($map__68196$$),$sel_w$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68196__$1$$,$APP.$cljs$cst$290$width$$),$sel_h$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68196__$1$$,$APP.$cljs$cst$1522$height$$),$png_bytes$jscomp$1$$=$app$render_wasm$api$render_shape_pixels$$($frame_id$jscomp$75$$,
Math.max(1,200/Math.max($APP.$cljs$core$truth_$$($ext_w$$)?$ext_w$$:$sel_w$$,$APP.$cljs$core$truth_$$($ext_h$$)?$ext_h$$:$sel_h$$)));return $png_bytes$jscomp$1$$==null||$png_bytes$jscomp$1$$.length===0?($APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.thumbnails-wasm",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"render-shape-pixels returned empty"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$75$$)],null)],null)}),null,"app.main.data.workspace.thumbnails-wasm",$APP.$cljs$cst$849$error$$,!1),$subs$jscomp$17$$.complete()):$app$main$data$workspace$thumbnails_wasm$png_bytes__GT_data_uri$$($png_bytes$jscomp$1$$).then(function($data_uri$jscomp$3$$){$subs$jscomp$17$$.next($data_uri$jscomp$3$$);
return $subs$jscomp$17$$.complete()},function($err$jscomp$36$$){return $subs$jscomp$17$$.error($err$jscomp$36$$)})}return $subs$jscomp$17$$.error("Frame not found")}catch($e68194$$){return $subs$jscomp$17$$.error($e68194$$)}});return function(){return $app$util$timers$cancel_animation_frame$$($req_id$$)}})};
$APP.$app$main$data$workspace$thumbnails_wasm$render_thumbnail$$=function($var_args$jscomp$1231$$){for(var $args__5755__auto__$jscomp$226$$=[],$len__5749__auto___68285$$=arguments.length,$i__5750__auto___68286$$=0;;)if($i__5750__auto___68286$$<$len__5749__auto___68285$$)$args__5755__auto__$jscomp$226$$.push(arguments[$i__5750__auto___68286$$]),$i__5750__auto___68286$$+=1;else break;return $app$main$data$workspace$thumbnails_wasm$render_thumbnail$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
arguments[1],arguments[2],3<$args__5755__auto__$jscomp$226$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$226$$.slice(3),0,null):null)};
$app$main$data$workspace$thumbnails_wasm$render_thumbnail$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($file_id$jscomp$125$$,$page_id$jscomp$151$$,$frame_id$jscomp$76$$,$p__68240$$){var $map__68242__$1$$=$APP.$cljs$core$__destructure_map$$($p__68240$$),$persist_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68242__$1$$,$cljs$cst$3798$persist_QMARK_$$,!1),$object_id$jscomp$22$$=$APP.$app$common$thumbnails$fmt_object_id$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$125$$,
$page_id$jscomp$151$$,$frame_id$jscomp$76$$,"component");typeof $app$main$data$workspace$thumbnails_wasm$render_thumbnail_68244$$==="undefined"&&($app$main$data$workspace$thumbnails_wasm$render_thumbnail_68244$$=function($file_id$jscomp$126$$,$page_id$jscomp$152$$,$frame_id$jscomp$77$$,$p__68240$jscomp$1$$,$map__68242$jscomp$1$$,$persist_QMARK_$jscomp$1$$,$object_id$jscomp$23$$,$meta68245$$){this.$file_id$=$file_id$jscomp$126$$;this.$page_id$=$page_id$jscomp$152$$;this.$frame_id$=$frame_id$jscomp$77$$;
this.$p__68240$=$p__68240$jscomp$1$$;this.$map__68242$=$map__68242$jscomp$1$$;this.$persist_QMARK_$=$persist_QMARK_$jscomp$1$$;this.$object_id$=$object_id$jscomp$23$$;this.$meta68245$=$meta68245$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$thumbnails_wasm$render_thumbnail_68244$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$thumbnails_wasm$render_thumbnail_68244$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3799$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_wasm_SLASH_render_thumbnail$$},$app$main$data$workspace$thumbnails_wasm$render_thumbnail_68244$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68246$$,$meta68245__$1$$){return new $app$main$data$workspace$thumbnails_wasm$render_thumbnail_68244$$(this.$file_id$,this.$page_id$,this.$frame_id$,this.$p__68240$,this.$map__68242$,this.$persist_QMARK_$,this.$object_id$,$meta68245__$1$$)},$app$main$data$workspace$thumbnails_wasm$render_thumbnail_68244$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta68245$},$app$main$data$workspace$thumbnails_wasm$render_thumbnail_68244$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.$object_id$},$app$main$data$workspace$thumbnails_wasm$render_thumbnail_68244$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$thumbnails_wasm$render_thumbnail_68244$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2021_load_objects_stream$$,$state$jscomp$437$$,
$stream$jscomp$46$$){var $self__$jscomp$4531$$=this;if($self__$jscomp$4531$$.$frame_id$!=null){$_$jscomp$2021_load_objects_stream$$=function(){return $APP.$beicon$v2$core$create$$(function($subs$jscomp$18$$){var $objects$jscomp$406_subtree$jscomp$2$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$437$$,$self__$jscomp$4531$$.$file_id$,$self__$jscomp$4531$$.$page_id$);$objects$jscomp$406_subtree$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__68203_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__68203_SHARP_$$),$p1__68203_SHARP_$$],null)}),$APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$406_subtree$jscomp$2$$,$self__$jscomp$4531$$.$frame_id$));try{return $app$render_wasm$api$set_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$406_subtree$jscomp$2$$,
function($p1__68204_SHARP_$$){return $subs$jscomp$18$$.next($p1__68204_SHARP_$$)})}catch($e68259$$){return $subs$jscomp$18$$.error($e68259$$)}})};var $persist_to_server$$=function($blob$jscomp$31_data_uri$jscomp$4$$){$blob$jscomp$31_data_uri$jscomp$4$$=$APP.$app$util$webapi$data_uri__GT_blob$$($blob$jscomp$31_data_uri$jscomp$4$$);return $APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$empty$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2262$create_file_object_thumbnail$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$4531$$.$file_id$,$APP.$cljs$cst$2272$object_id$$,$self__$jscomp$4531$$.$object_id$,$APP.$cljs$cst$1639$media$$,$blob$jscomp$31_data_uri$jscomp$4$$,$APP.$cljs$cst$78$tag$$,"component"],null))))},$do_render_thumbnail$$=function(){var $tp$jscomp$5$$=$app$common$time$tpoint_ms$$();return $APP.$beicon$v2$core$take_until$$($APP.$beicon$v2$core$filter$$(function($p1__68205_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($p1__68205_SHARP_$$),
$self__$jscomp$4531$$.$object_id$)},$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3791$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_clear_thumbnail$$),$stream$jscomp$46$$)),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($err$jscomp$38$$){console.error($err$jscomp$38$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.thumbnails-wasm",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"error rendering component thumbnail"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4531$$.$frame_id$)],null)],null)}),null,"app.main.data.workspace.thumbnails-wasm",$APP.$cljs$cst$849$error$$,
!1);return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$mapcat$$(function($data_uri$jscomp$5$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.thumbnails-wasm",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,
"component thumbnail rendered (wasm)"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2278$elapsed$$,""+($tp$jscomp$5$$()??"")+"ms"],null)],null)}),null,"app.main.data.workspace.thumbnails-wasm",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$truth_$$($self__$jscomp$4531$$.$persist_QMARK_$)?$APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$thumbnails$assoc_thumbnail$$($self__$jscomp$4531$$.$object_id$,
$data_uri$jscomp$5$$)),$persist_to_server$$($data_uri$jscomp$5$$)):(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$thumbnails$assoc_thumbnail$$($self__$jscomp$4531$$.$object_id$,$data_uri$jscomp$5$$))},$app$main$data$workspace$thumbnails_wasm$render_component_pixels$$($self__$jscomp$4531$$.$file_id$,$self__$jscomp$4531$$.$page_id$,$self__$jscomp$4531$$.$frame_id$))))};return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4531$$.$page_id$,$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$437$$))?
$APP.$beicon$v2$core$mapcat$$($do_render_thumbnail$$,$_$jscomp$2021_load_objects_stream$$()):$do_render_thumbnail$$()}return null});return new $app$main$data$workspace$thumbnails_wasm$render_thumbnail_68244$$($file_id$jscomp$125$$,$page_id$jscomp$151$$,$frame_id$jscomp$76$$,$p__68240$$,$map__68242__$1$$,$persist_QMARK_$$,$object_id$jscomp$22$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$thumbnails_wasm$persist_thumbnail$$=function($file_id$jscomp$127$$,$page_id$jscomp$153$$,$frame_id$jscomp$78$$){var $object_id$jscomp$24$$=$APP.$app$common$thumbnails$fmt_object_id$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$127$$,$page_id$jscomp$153$$,$frame_id$jscomp$78$$,"component");typeof $app$main$data$workspace$thumbnails_wasm$persist_thumbnail_68277$$==="undefined"&&($app$main$data$workspace$thumbnails_wasm$persist_thumbnail_68277$$=function($file_id$jscomp$128$$,
$page_id$jscomp$154$$,$frame_id$jscomp$79$$,$object_id$jscomp$25$$,$meta68278$$){this.$file_id$=$file_id$jscomp$128$$;this.$page_id$=$page_id$jscomp$154$$;this.$frame_id$=$frame_id$jscomp$79$$;this.$object_id$=$object_id$jscomp$25$$;this.$meta68278$=$meta68278$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$thumbnails_wasm$persist_thumbnail_68277$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$thumbnails_wasm$persist_thumbnail_68277$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3800$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_wasm_SLASH_persist_thumbnail$$},$app$main$data$workspace$thumbnails_wasm$persist_thumbnail_68277$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68279$$,$meta68278__$1$$){return new $app$main$data$workspace$thumbnails_wasm$persist_thumbnail_68277$$(this.$file_id$,this.$page_id$,this.$frame_id$,this.$object_id$,$meta68278__$1$$)},$app$main$data$workspace$thumbnails_wasm$persist_thumbnail_68277$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta68278$},$app$main$data$workspace$thumbnails_wasm$persist_thumbnail_68277$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$thumbnails_wasm$persist_thumbnail_68277$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2022_blob$jscomp$32_data_uri$jscomp$6$$,$state$jscomp$438$$){$_$jscomp$2022_blob$jscomp$32_data_uri$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$438$$,
$APP.$cljs$cst$2229$thumbnails$$),this.$object_id$);return $_$jscomp$2022_blob$jscomp$32_data_uri$jscomp$6$$!=null&&$APP.$cuerdas$core$starts_with_QMARK_$$($_$jscomp$2022_blob$jscomp$32_data_uri$jscomp$6$$,"data:")?($_$jscomp$2022_blob$jscomp$32_data_uri$jscomp$6$$=$APP.$app$util$webapi$data_uri__GT_blob$$($_$jscomp$2022_blob$jscomp$32_data_uri$jscomp$6$$),$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$empty$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2262$create_file_object_thumbnail$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1644$file_id$$,this.$file_id$,$APP.$cljs$cst$2272$object_id$$,this.$object_id$,$APP.$cljs$cst$1639$media$$,$_$jscomp$2022_blob$jscomp$32_data_uri$jscomp$6$$,$APP.$cljs$cst$78$tag$$,"component"],null))))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$thumbnails_wasm$persist_thumbnail_68277$$($file_id$jscomp$127$$,$page_id$jscomp$153$$,$frame_id$jscomp$78$$,$object_id$jscomp$24$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$geom$bounds_map$objects__GT_bounds_map$$=function($objects$jscomp$407$$){return $APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$407$$),function($p1__67951_SHARP_$$){return $app$common$geom$shapes$common$shape__GT_points$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$407$$,$p1__67951_SHARP_$$))})};
$app$common$geom$bounds_map$create_bounds$cljs$0core$0IFn$0_invoke$0arity$05$$=function($children$jscomp$225_children_bounds$jscomp$1_p__67957$$,$bounds_map$jscomp$2$$,$objects$jscomp$410$$,$modif_tree$jscomp$5$$,$G__67967_current_bounds_current_ref$$){var $map__67958__$1$$=$APP.$cljs$core$__destructure_map$$($children$jscomp$225_children_bounds$jscomp$1_p__67957$$),$id$jscomp$529$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67958__$1$$,$APP.$cljs$cst$266$id$$);if($APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__67958__$1$$)){var $modifiers$jscomp$44$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modif_tree$jscomp$5$$,$id$jscomp$529$$),$APP.$cljs$cst$1810$modifiers$$);$children$jscomp$225_children_bounds$jscomp$1_p__67957$$=function(){var $G__67959$$=$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$410$$,$id$jscomp$529$$);return $APP.$app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__67958__$1$$)?
$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(1,$G__67959$$):$G__67959$$}();var $shape_bounds$jscomp$1$$=$APP.$cljs$core$truth_$$($G__67967_current_bounds_current_ref$$)?$APP.$cljs$core$_deref$$($G__67967_current_bounds_current_ref$$):$APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds_map$jscomp$2$$,$id$jscomp$529$$));$G__67967_current_bounds_current_ref$$=function(){var $G__67966$$=$shape_bounds$jscomp$1$$;return $app$common$types$modifiers$empty_QMARK_$$($modifiers$jscomp$44$$)?
$G__67966$$:$app$common$geom$shapes$transforms$transform_bounds$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67966$$,$modifiers$jscomp$44$$)}();$children$jscomp$225_children_bounds$jscomp$1_p__67957$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67952_SHARP_$$){return $APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds_map$jscomp$2$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__67952_SHARP_$$)))},$children$jscomp$225_children_bounds$jscomp$1_p__67957$$);
return $app$common$geom$shapes$points$merge_parent_coords_bounds$$($children$jscomp$225_children_bounds$jscomp$1_p__67957$$,$G__67967_current_bounds_current_ref$$)}$modifiers$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modif_tree$jscomp$5$$,$id$jscomp$529$$),$APP.$cljs$cst$1810$modifiers$$);$G__67967_current_bounds_current_ref$$=$shape_bounds$jscomp$1$$=$APP.$cljs$core$truth_$$($G__67967_current_bounds_current_ref$$)?$APP.$cljs$core$_deref$$($G__67967_current_bounds_current_ref$$):
$APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds_map$jscomp$2$$,$id$jscomp$529$$));return $app$common$types$modifiers$empty_QMARK_$$($modifiers$jscomp$44$$)?$G__67967_current_bounds_current_ref$$:$app$common$geom$shapes$transforms$transform_bounds$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67967_current_bounds_current_ref$$,$modifiers$jscomp$44$$)};
$app$common$geom$bounds_map$resolve_modif_tree_ids$$=function($objects$jscomp$411$$,$base_ids_modif_tree$jscomp$6$$){$base_ids_modif_tree$jscomp$6$$=$APP.$cljs$core$keys$$($base_ids_modif_tree$jscomp$6$$);for(var $ids$jscomp$95$$=new Set($base_ids_modif_tree$jscomp$6$$),$base_ids_67999__$1$$=$APP.$cljs$core$seq$$($base_ids_modif_tree$jscomp$6$$);;)if($base_ids_67999__$1$$!=null){var $cid_68000_new_ids_68001$$=$APP.$cljs$core$first$$($base_ids_67999__$1$$);for($cid_68000_new_ids_68001$$=$APP.$cljs$core$seq$$($APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$(function($base_ids_67999__$1$jscomp$1$$,
$cid_68000$jscomp$1$$,$base_ids$jscomp$1$$,$ids$jscomp$96$$){return function($p1__67971_SHARP_$$){return $APP.$app$common$files$helpers$group_like_shape_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($p1__67971_SHARP_$$)&&$APP.$cljs$core$not$$($ids$jscomp$96$$.has($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__67971_SHARP_$$)))}}($base_ids_67999__$1$$,$cid_68000_new_ids_68001$$,$base_ids_modif_tree$jscomp$6$$,$ids$jscomp$95$$),$app$common$files$helpers$get_parent_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$411$$,
$cid_68000_new_ids_68001$$)));;)if($cid_68000_new_ids_68001$$!=null)$ids$jscomp$95$$.add($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($cid_68000_new_ids_68001$$))),$cid_68000_new_ids_68001$$=$APP.$cljs$core$next$$($cid_68000_new_ids_68001$$);else break;$base_ids_67999__$1$$=$APP.$cljs$core$next$$($base_ids_67999__$1$$)}else break;return $ids$jscomp$95$$};
$app$common$geom$bounds_map$transform_bounds_map$cljs$0core$0IFn$0_invoke$0arity$04$$=function($bounds_map$jscomp$4$$,$objects$jscomp$413$$,$modif_tree$jscomp$8$$,$ids$jscomp$97_new_bounds_map$$){var $bm_holder$$=$APP.$cljs$core$volatile_BANG_$$(null),$ids__$1$jscomp$12$$=$APP.$cljs$core$truth_$$($ids$jscomp$97_new_bounds_map$$)?$ids$jscomp$97_new_bounds_map$$:$app$common$geom$bounds_map$resolve_modif_tree_ids$$($objects$jscomp$413$$,$modif_tree$jscomp$8$$);$ids$jscomp$97_new_bounds_map$$=function(){for(var $tr_bounds_map$$=
$APP.$cljs$core$_as_transient$$($bounds_map$jscomp$4$$),$ids__$2$jscomp$1$$=$APP.$cljs$core$seq$$($ids__$1$jscomp$12$$);;){if($APP.$cljs$core$not$$($ids__$2$jscomp$1$$))return $APP.$cljs$core$_persistent_BANG_$$($tr_bounds_map$$);var $shape_id$jscomp$89$$=$APP.$cljs$core$first$$($ids__$2$jscomp$1$$),$G__68005$$=function(){var $G__67975$$=$tr_bounds_map$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$shape_id$jscomp$89$$)?$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($G__67975$$,
$shape_id$jscomp$89$$,new $APP.$cljs$core$Delay$$(function($tr_bounds_map$jscomp$1$$,$ids__$2$jscomp$2$$,$G__67975$jscomp$1$$,$shape_id$jscomp$90$$,$bm_holder$jscomp$1$$){return function(){return $app$common$geom$bounds_map$create_bounds$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$413$$,$shape_id$jscomp$90$$),$APP.$cljs$core$_deref$$($bm_holder$jscomp$1$$),$objects$jscomp$413$$,$modif_tree$jscomp$8$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds_map$jscomp$4$$,
$shape_id$jscomp$90$$))}}($tr_bounds_map$$,$ids__$2$jscomp$1$$,$G__67975$$,$shape_id$jscomp$89$$,$bm_holder$$,$ids__$1$jscomp$12$$))):$G__67975$$}(),$G__68006$$=$APP.$cljs$core$next$$($ids__$2$jscomp$1$$);$tr_bounds_map$$=$G__68005$$;$ids__$2$jscomp$1$$=$G__68006$$}}();$APP.$cljs$core$_vreset_BANG_$$($bm_holder$$,$ids$jscomp$97_new_bounds_map$$);return $ids$jscomp$97_new_bounds_map$$};
$app$common$geom$modif_tree$add_modifiers$$=function($G__67972__$1_modif_tree$jscomp$9$$,$id$jscomp$531$$,$modifiers$jscomp$45_new_modifiers$jscomp$1$$){if($app$common$types$modifiers$empty_QMARK_$$($modifiers$jscomp$45_new_modifiers$jscomp$1$$))return $G__67972__$1_modif_tree$jscomp$9$$;var $old_modifiers$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__67972__$1_modif_tree$jscomp$9$$,$id$jscomp$531$$),$APP.$cljs$cst$1810$modifiers$$);
$modifiers$jscomp$45_new_modifiers$jscomp$1$$=$app$common$types$modifiers$add_modifiers$$($old_modifiers$$,$modifiers$jscomp$45_new_modifiers$jscomp$1$$);$G__67972__$1_modif_tree$jscomp$9$$=$app$common$types$modifiers$empty_QMARK_$$($modifiers$jscomp$45_new_modifiers$jscomp$1$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__67972__$1_modif_tree$jscomp$9$$,$id$jscomp$531$$):$G__67972__$1_modif_tree$jscomp$9$$;return $app$common$types$modifiers$empty_QMARK_$$($modifiers$jscomp$45_new_modifiers$jscomp$1$$)?
$G__67972__$1_modif_tree$jscomp$9$$:$APP.$cljs$core$assoc_in$$($G__67972__$1_modif_tree$jscomp$9$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$531$$,$APP.$cljs$cst$1810$modifiers$$],null),$modifiers$jscomp$45_new_modifiers$jscomp$1$$)};
$app$common$geom$modif_tree$merge_modif_tree$$=function($modif_tree$jscomp$10$$,$other_tree$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($modif_tree__$1$jscomp$1$$,$map__67980_map__67980__$1_modifiers$jscomp$46_p__67976$$){var $id$jscomp$532$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__67980_map__67980__$1_modifiers$jscomp$46_p__67976$$,0,null);$map__67980_map__67980__$1_modifiers$jscomp$46_p__67976$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__67980_map__67980__$1_modifiers$jscomp$46_p__67976$$,
1,null);$map__67980_map__67980__$1_modifiers$jscomp$46_p__67976$$=$APP.$cljs$core$__destructure_map$$($map__67980_map__67980__$1_modifiers$jscomp$46_p__67976$$);$map__67980_map__67980__$1_modifiers$jscomp$46_p__67976$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67980_map__67980__$1_modifiers$jscomp$46_p__67976$$,$APP.$cljs$cst$1810$modifiers$$);return $app$common$geom$modif_tree$add_modifiers$$($modif_tree__$1$jscomp$1$$,$id$jscomp$532$$,$map__67980_map__67980__$1_modifiers$jscomp$46_p__67976$$)},
$modif_tree$jscomp$10$$,$other_tree$$)};
$app$common$geom$modif_tree$apply_structure_modifiers$$=function($objects$jscomp$415$$,$modif_tree$jscomp$11$$){function $update_children_structure_modifiers$$($objects__$1$jscomp$14$$,$ids$jscomp$98$$,$modifiers$jscomp$47$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__67981_SHARP_$$,$p2__67982_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__67981_SHARP_$$,$p2__67982_SHARP_$$,$APP.$app$common$types$modifiers$apply_structure_modifiers$$,$modifiers$jscomp$47$$)},
$objects__$1$jscomp$14$$,$ids$jscomp$98$$)}return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects__$1$jscomp$15$$,$map__68013_map__68013__$1_modifiers$jscomp$48_p__68009$$){var $id$jscomp$533$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__68013_map__68013__$1_modifiers$jscomp$48_p__68009$$,0,null);$map__68013_map__68013__$1_modifiers$jscomp$48_p__68009$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__68013_map__68013__$1_modifiers$jscomp$48_p__68009$$,
1,null);$map__68013_map__68013__$1_modifiers$jscomp$48_p__68009$$=$APP.$cljs$core$__destructure_map$$($map__68013_map__68013__$1_modifiers$jscomp$48_p__68009$$);$map__68013_map__68013__$1_modifiers$jscomp$48_p__68009$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68013_map__68013__$1_modifiers$jscomp$48_p__68009$$,$APP.$cljs$cst$1810$modifiers$$);var $G__68014__$1$$=$app$common$types$modifiers$has_structure_QMARK_$$($map__68013_map__68013__$1_modifiers$jscomp$48_p__68009$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($objects__$1$jscomp$15$$,
$id$jscomp$533$$,$APP.$app$common$types$modifiers$apply_structure_modifiers$$,$map__68013_map__68013__$1_modifiers$jscomp$48_p__68009$$):$objects__$1$jscomp$15$$;return $app$common$types$modifiers$has_structure_QMARK_$$($map__68013_map__68013__$1_modifiers$jscomp$48_p__68009$$)&&$APP.$app$common$data$not_empty_QMARK_$$($map__68013_map__68013__$1_modifiers$jscomp$48_p__68009$$?.$structure_child$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68013_map__68013__$1_modifiers$jscomp$48_p__68009$$,
$APP.$cljs$cst$1780$structure_child$$))?$update_children_structure_modifiers$$($G__68014__$1$$,$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$15$$,$id$jscomp$533$$),$app$common$types$modifiers$select_structure$$($app$common$types$modifiers$select_child$$($map__68013_map__68013__$1_modifiers$jscomp$48_p__68009$$))):$G__68014__$1$$},$objects$jscomp$415$$,$modif_tree$jscomp$11$$)};
$app$common$geom$shapes$flex_layout$bounds$child_min_width$$=function($child$jscomp$91$$,$child_bounds$jscomp$10$$,$bounds$jscomp$39$$,$objects$jscomp$416$$){return $app$common$geom$shapes$flex_layout$bounds$_child_min_width$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$geom$shapes$flex_layout$bounds$_child_min_width$$.$cljs$core$IFn$_invoke$arity$4$($child$jscomp$91$$,$child_bounds$jscomp$10$$,$bounds$jscomp$39$$,$objects$jscomp$416$$):$app$common$geom$shapes$flex_layout$bounds$_child_min_width$$($child$jscomp$91$$,
$child_bounds$jscomp$10$$,$bounds$jscomp$39$$,$objects$jscomp$416$$)};
$app$common$geom$shapes$flex_layout$bounds$child_min_height$$=function($child$jscomp$92$$,$child_bounds$jscomp$11$$,$bounds$jscomp$40$$,$objects$jscomp$417$$){return $app$common$geom$shapes$flex_layout$bounds$_child_min_height$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$geom$shapes$flex_layout$bounds$_child_min_height$$.$cljs$core$IFn$_invoke$arity$4$($child$jscomp$92$$,$child_bounds$jscomp$11$$,$bounds$jscomp$40$$,$objects$jscomp$417$$):$app$common$geom$shapes$flex_layout$bounds$_child_min_height$$($child$jscomp$92$$,
$child_bounds$jscomp$11$$,$bounds$jscomp$40$$,$objects$jscomp$417$$)};
$app$common$geom$shapes$flex_layout$bounds$child_layout_bound_points$cljs$0core$0IFn$0_invoke$0arity$07$$=function($min_width$jscomp$2_parent$jscomp$241$$,$child$jscomp$94$$,$parent_bounds$jscomp$10$$,$child_bounds$jscomp$13_min_height$jscomp$1_result__$1$jscomp$34$$,$correct_v$$,$base_p__$1_bounds$jscomp$42_correct_v__$1$$,$objects$jscomp$419$$){var $row_QMARK_$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($min_width$jscomp$2_parent$jscomp$241$$),$col_QMARK_$$=
$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($min_width$jscomp$2_parent$jscomp$241$$),$hv$jscomp$7$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$shapes$points$start_hv$$,$parent_bounds$jscomp$10$$),$vv$jscomp$7$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$shapes$points$start_vv$$,$parent_bounds$jscomp$10$$),$v_start_QMARK_$$=$app$common$types$shape$layout$v_start_QMARK_$$($min_width$jscomp$2_parent$jscomp$241$$),
$v_center_QMARK_$$=$app$common$types$shape$layout$v_center_QMARK_$$($min_width$jscomp$2_parent$jscomp$241$$),$v_end_QMARK_$$=$app$common$types$shape$layout$v_end_QMARK_$$($min_width$jscomp$2_parent$jscomp$241$$),$h_start_QMARK_$$=$app$common$types$shape$layout$h_start_QMARK_$$($min_width$jscomp$2_parent$jscomp$241$$),$h_center_QMARK_$$=$app$common$types$shape$layout$h_center_QMARK_$$($min_width$jscomp$2_parent$jscomp$241$$),$h_end_QMARK_$$=$app$common$types$shape$layout$h_end_QMARK_$$($min_width$jscomp$2_parent$jscomp$241$$),
$base_p$$=$APP.$app$common$geom$shapes$points$origin$$($child_bounds$jscomp$13_min_height$jscomp$1_result__$1$jscomp$34$$),$width$jscomp$131$$=$APP.$app$common$geom$shapes$points$width_points$$($child_bounds$jscomp$13_min_height$jscomp$1_result__$1$jscomp$34$$),$height$jscomp$117$$=$APP.$app$common$geom$shapes$points$height_points$$($child_bounds$jscomp$13_min_height$jscomp$1_result__$1$jscomp$34$$);$min_width$jscomp$2_parent$jscomp$241$$=$app$common$geom$shapes$flex_layout$bounds$child_min_width$$($child$jscomp$94$$,
$child_bounds$jscomp$13_min_height$jscomp$1_result__$1$jscomp$34$$,$base_p__$1_bounds$jscomp$42_correct_v__$1$$,$objects$jscomp$419$$);$child_bounds$jscomp$13_min_height$jscomp$1_result__$1$jscomp$34$$=$app$common$geom$shapes$flex_layout$bounds$child_min_height$$($child$jscomp$94$$,$child_bounds$jscomp$13_min_height$jscomp$1_result__$1$jscomp$34$$,$base_p__$1_bounds$jscomp$42_correct_v__$1$$,$objects$jscomp$419$$);$base_p__$1_bounds$jscomp$42_correct_v__$1$$=function(){var $G__68015__$1_G__68015__$2_G__68015__$3$$=
$row_QMARK_$$&&$v_center_QMARK_$$?$APP.$app$common$geom$point$add$$($base_p$$,$vv$jscomp$7$$($height$jscomp$117$$/2)):$base_p$$;$G__68015__$1_G__68015__$2_G__68015__$3$$=$row_QMARK_$$&&$v_end_QMARK_$$?$APP.$app$common$geom$point$add$$($G__68015__$1_G__68015__$2_G__68015__$3$$,$vv$jscomp$7$$($height$jscomp$117$$)):$G__68015__$1_G__68015__$2_G__68015__$3$$;$G__68015__$1_G__68015__$2_G__68015__$3$$=$col_QMARK_$$&&$h_center_QMARK_$$?$APP.$app$common$geom$point$add$$($G__68015__$1_G__68015__$2_G__68015__$3$$,
$hv$jscomp$7$$($width$jscomp$131$$/2)):$G__68015__$1_G__68015__$2_G__68015__$3$$;return $col_QMARK_$$&&$h_end_QMARK_$$?$APP.$app$common$geom$point$add$$($G__68015__$1_G__68015__$2_G__68015__$3$$,$hv$jscomp$7$$($width$jscomp$131$$)):$G__68015__$1_G__68015__$2_G__68015__$3$$}();var $min_width__$1$$=$min_width$jscomp$2_parent$jscomp$241$$>.01?$min_width$jscomp$2_parent$jscomp$241$$:.01,$min_height__$1$$=$child_bounds$jscomp$13_min_height$jscomp$1_result__$1$jscomp$34$$>.01?$child_bounds$jscomp$13_min_height$jscomp$1_result__$1$jscomp$34$$:
.01,$base_p__$2$$=$APP.$app$common$geom$point$add$$($base_p__$1_bounds$jscomp$42_correct_v__$1$$,$correct_v$$),$result$jscomp$283$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$base_p__$2$$,$APP.$app$common$geom$point$add$$($base_p__$2$$,$hv$jscomp$7$$(.01)),$APP.$app$common$geom$point$add$$($base_p__$2$$,$vv$jscomp$7$$(.01))],null);$child_bounds$jscomp$13_min_height$jscomp$1_result__$1$jscomp$34$$=function(){var $G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$=
$col_QMARK_$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$283$$,$APP.$app$common$geom$point$add$$($base_p__$2$$,$vv$jscomp$7$$($min_height__$1$$))):$result$jscomp$283$$;$G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$=$row_QMARK_$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$,$APP.$app$common$geom$point$add$$($base_p__$2$$,$hv$jscomp$7$$($min_width__$1$$))):
$G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$;$G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$=$col_QMARK_$$&&$h_start_QMARK_$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$,$APP.$app$common$geom$point$add$$($base_p__$2$$,$hv$jscomp$7$$($min_width__$1$$))):$G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$;
$G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$=$col_QMARK_$$&&$h_center_QMARK_$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$,$APP.$app$common$geom$point$add$$($base_p__$2$$,$hv$jscomp$7$$($min_width__$1$$/2)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$geom$point$subtract$$($base_p__$2$$,$hv$jscomp$7$$($min_width__$1$$/
2))])):$G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$;$G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$=$col_QMARK_$$&&$h_end_QMARK_$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$,$APP.$app$common$geom$point$subtract$$($base_p__$2$$,$hv$jscomp$7$$($min_width__$1$$))):$G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$;
$G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$=$row_QMARK_$$&&$v_start_QMARK_$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$,$APP.$app$common$geom$point$add$$($base_p__$2$$,$vv$jscomp$7$$($min_height__$1$$))):$G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$;$G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$=
$row_QMARK_$$&&$v_center_QMARK_$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$,$APP.$app$common$geom$point$add$$($base_p__$2$$,$vv$jscomp$7$$($min_height__$1$$/2)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$geom$point$subtract$$($base_p__$2$$,$vv$jscomp$7$$($min_height__$1$$/2))])):$G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$;
return $row_QMARK_$$&&$v_end_QMARK_$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$,$APP.$app$common$geom$point$subtract$$($base_p__$2$$,$vv$jscomp$7$$($min_height__$1$$))):$G__68016__$1_G__68016__$2_G__68016__$3_G__68016__$4_G__68016__$5_G__68016__$6_G__68016__$7$$}();$base_p__$1_bounds$jscomp$42_correct_v__$1$$=function(){var $G__68018__$1$$=$row_QMARK_$$&&$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$94$$)?
$APP.$app$common$geom$point$subtract$$($correct_v$$,$hv$jscomp$7$$($width$jscomp$131$$+$min_width__$1$$)):$correct_v$$;return $col_QMARK_$$&&$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$94$$)?$APP.$app$common$geom$point$subtract$$($G__68018__$1$$,$vv$jscomp$7$$($height$jscomp$117$$+$min_height__$1$$)):$G__68018__$1$$}();return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$child_bounds$jscomp$13_min_height$jscomp$1_result__$1$jscomp$34$$,
$base_p__$1_bounds$jscomp$42_correct_v__$1$$],null)};
$APP.$app$common$geom$shapes$flex_layout$bounds$layout_content_points$$=function($bounds$jscomp$43$$,$parent$jscomp$242$$,$children$jscomp$226_children__$1$jscomp$27$$,$objects$jscomp$420$$){var $parent_id$jscomp$74$$=$parent$jscomp$242$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$242$$,$APP.$cljs$cst$266$id$$),$parent_bounds$jscomp$11$$=$APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$43$$,$parent_id$jscomp$74$$)),$reverse_QMARK_$jscomp$3$$=
$APP.$app$common$types$shape$layout$reverse_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$242$$);$children$jscomp$226_children__$1$jscomp$27$$=$reverse_QMARK_$jscomp$3$$?$children$jscomp$226_children__$1$jscomp$27$$:$APP.$cljs$core$reverse$$($children$jscomp$226_children__$1$jscomp$27$$);for(var $G__68052_children__$2$jscomp$1$$=$APP.$cljs$core$seq$$($children$jscomp$226_children__$1$jscomp$27$$),$result$jscomp$284$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),
$correct_v$jscomp$1_correct_v__$1$jscomp$1_vec__68031$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$(0);;){if($APP.$cljs$core$not$$($G__68052_children__$2$jscomp$1$$))return $APP.$cljs$core$_persistent_BANG_$$($result$jscomp$284$$);var $child$jscomp$95_child_bounds__$1$$=$APP.$cljs$core$first$$($G__68052_children__$2$jscomp$1$$),$child_id$jscomp$2$$=$child$jscomp$95_child_bounds__$1$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($child$jscomp$95_child_bounds__$1$$,
$APP.$cljs$cst$266$id$$),$child_bounds$jscomp$14$$=$APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$43$$,$child_id$jscomp$2$$)),$vec__68028$$=$app$common$types$shape$layout$child_margins$$($child$jscomp$95_child_bounds__$1$$),$G__68053_margin_top$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__68028$$,0,null),$G__68054_margin_right$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__68028$$,1,null),$margin_bottom$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__68028$$,2,null),$margin_left$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__68028$$,3,null);$correct_v$jscomp$1_correct_v__$1$jscomp$1_vec__68031$$=$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$95_child_bounds__$1$$)||$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$95_child_bounds__$1$$)?$app$common$geom$shapes$flex_layout$bounds$child_layout_bound_points$cljs$0core$0IFn$0_invoke$0arity$07$$($parent$jscomp$242$$,
$child$jscomp$95_child_bounds__$1$$,$parent_bounds$jscomp$11$$,$child_bounds$jscomp$14$$,$correct_v$jscomp$1_correct_v__$1$jscomp$1_vec__68031$$,$bounds$jscomp$43$$,$objects$jscomp$420$$):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($children__$2$jscomp$2$$,$result$jscomp$285$$,$correct_v$jscomp$2$$){return function($p1__68019_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__68019_SHARP_$$,
$correct_v$jscomp$2$$)}}($G__68052_children__$2$jscomp$1$$,$result$jscomp$284$$,$correct_v$jscomp$1_correct_v__$1$jscomp$1_vec__68031$$,$child$jscomp$95_child_bounds__$1$$,$child_id$jscomp$2$$,$child_bounds$jscomp$14$$,$vec__68028$$,$G__68053_margin_top$jscomp$1$$,$G__68054_margin_right$jscomp$1$$,$margin_bottom$jscomp$1$$,$margin_left$jscomp$1$$,$parent_id$jscomp$74$$,$parent_bounds$jscomp$11$$,$reverse_QMARK_$jscomp$3$$,$children$jscomp$226_children__$1$jscomp$27$$),$child_bounds$jscomp$14$$),$correct_v$jscomp$1_correct_v__$1$jscomp$1_vec__68031$$],
null);$child$jscomp$95_child_bounds__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($correct_v$jscomp$1_correct_v__$1$jscomp$1_vec__68031$$,0,null);$correct_v$jscomp$1_correct_v__$1$jscomp$1_vec__68031$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($correct_v$jscomp$1_correct_v__$1$jscomp$1_vec__68031$$,1,null);var $child_bounds__$2$$=$APP.$app$common$data$not_empty_QMARK_$$($child$jscomp$95_child_bounds__$1$$)?$app$common$geom$shapes$points$pad_points$$($APP.$app$common$geom$shapes$points$parent_coords_bounds$$($child$jscomp$95_child_bounds__$1$$,
$parent_bounds$jscomp$11$$),-$G__68053_margin_top$jscomp$1$$,-$G__68054_margin_right$jscomp$1$$,-$margin_bottom$jscomp$1$$,-$margin_left$jscomp$1$$):null;$G__68052_children__$2$jscomp$1$$=$APP.$cljs$core$next$$($G__68052_children__$2$jscomp$1$$);$G__68053_margin_top$jscomp$1$$=function(){var $G__68034$$=$result$jscomp$284$$;return $child_bounds__$2$$!=null?$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__68034$$,$child_bounds__$2$$):$G__68034$$}();$G__68054_margin_right$jscomp$1$$=
$correct_v$jscomp$1_correct_v__$1$jscomp$1_vec__68031$$;$result$jscomp$284$$=$G__68053_margin_top$jscomp$1$$;$correct_v$jscomp$1_correct_v__$1$jscomp$1_vec__68031$$=$G__68054_margin_right$jscomp$1$$}};
$APP.$app$common$geom$shapes$flex_layout$bounds$layout_content_bounds$$=function($bounds$jscomp$44_layout_points$jscomp$1$$,$map__68038__$1_p__68037$$,$children$jscomp$227$$,$objects$jscomp$421$$){$map__68038__$1_p__68037$$=$APP.$cljs$core$__destructure_map$$($map__68038__$1_p__68037$$);var $layout_padding$jscomp$5_pad_top$jscomp$5_pad_top__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68038__$1_p__68037$$,$APP.$cljs$cst$1686$layout_padding$$),$parent_bounds$jscomp$13_parent_id$jscomp$76$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__68038__$1_p__68037$$);$parent_bounds$jscomp$13_parent_id$jscomp$76$$=$APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$44_layout_points$jscomp$1$$,$parent_bounds$jscomp$13_parent_id$jscomp$76$$));var $col_pad_pad_left__$1$jscomp$1_row_QMARK_$jscomp$1$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($map__68038__$1_p__68037$$),$col_QMARK_$jscomp$1_pad_bottom$jscomp$5$$=
$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__68038__$1_p__68037$$),$map__68045__$1_pad_left$jscomp$5_space_around_QMARK_$$=$app$common$types$shape$layout$space_around_QMARK_$$($map__68038__$1_p__68037$$),$pad_right$jscomp$5_pad_right__$1$jscomp$1_space_evenly_QMARK_$$=$app$common$types$shape$layout$space_evenly_QMARK_$$($map__68038__$1_p__68037$$),$content_evenly_QMARK_$$=$app$common$types$shape$layout$content_evenly_QMARK_$$($map__68038__$1_p__68037$$),$layout_gap_col$jscomp$1_vec__68042$$=
$APP.$app$common$types$shape$layout$gaps$$($map__68038__$1_p__68037$$),$layout_gap_row$jscomp$1_pad_bottom__$1$jscomp$1_row_pad$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_gap_col$jscomp$1_vec__68042$$,0,null);$layout_gap_col$jscomp$1_vec__68042$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_gap_col$jscomp$1_vec__68042$$,1,null);$layout_gap_row$jscomp$1_pad_bottom__$1$jscomp$1_row_pad$$=$col_QMARK_$jscomp$1_pad_bottom$jscomp$5$$&&$pad_right$jscomp$5_pad_right__$1$jscomp$1_space_evenly_QMARK_$$||
$col_QMARK_$jscomp$1_pad_bottom$jscomp$5$$&&$map__68045__$1_pad_left$jscomp$5_space_around_QMARK_$$||$col_pad_pad_left__$1$jscomp$1_row_QMARK_$jscomp$1$$&&$content_evenly_QMARK_$$?$layout_gap_row$jscomp$1_pad_bottom__$1$jscomp$1_row_pad$$:0;$col_pad_pad_left__$1$jscomp$1_row_QMARK_$jscomp$1$$=$col_pad_pad_left__$1$jscomp$1_row_QMARK_$jscomp$1$$&&$pad_right$jscomp$5_pad_right__$1$jscomp$1_space_evenly_QMARK_$$||$col_pad_pad_left__$1$jscomp$1_row_QMARK_$jscomp$1$$&&$map__68045__$1_pad_left$jscomp$5_space_around_QMARK_$$||
$col_QMARK_$jscomp$1_pad_bottom$jscomp$5$$&&$content_evenly_QMARK_$$?$layout_gap_col$jscomp$1_vec__68042$$:0;$map__68045__$1_pad_left$jscomp$5_space_around_QMARK_$$=$APP.$cljs$core$__destructure_map$$($layout_padding$jscomp$5_pad_top$jscomp$5_pad_top__$1$jscomp$1$$);$layout_padding$jscomp$5_pad_top$jscomp$5_pad_top__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68045__$1_pad_left$jscomp$5_space_around_QMARK_$$,$APP.$cljs$cst$1093$p1$$);$pad_right$jscomp$5_pad_right__$1$jscomp$1_space_evenly_QMARK_$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68045__$1_pad_left$jscomp$5_space_around_QMARK_$$,$APP.$cljs$cst$1091$p2$$);$col_QMARK_$jscomp$1_pad_bottom$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68045__$1_pad_left$jscomp$5_space_around_QMARK_$$,$APP.$cljs$cst$1687$p3$$);$map__68045__$1_pad_left$jscomp$5_space_around_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68045__$1_pad_left$jscomp$5_space_around_QMARK_$$,$APP.$cljs$cst$1688$p4$$);
$layout_padding$jscomp$5_pad_top$jscomp$5_pad_top__$1$jscomp$1$$=($APP.$cljs$core$truth_$$($layout_padding$jscomp$5_pad_top$jscomp$5_pad_top__$1$jscomp$1$$)?$layout_padding$jscomp$5_pad_top$jscomp$5_pad_top__$1$jscomp$1$$:0)+$layout_gap_row$jscomp$1_pad_bottom__$1$jscomp$1_row_pad$$;$pad_right$jscomp$5_pad_right__$1$jscomp$1_space_evenly_QMARK_$$=($APP.$cljs$core$truth_$$($pad_right$jscomp$5_pad_right__$1$jscomp$1_space_evenly_QMARK_$$)?$pad_right$jscomp$5_pad_right__$1$jscomp$1_space_evenly_QMARK_$$:
0)+$col_pad_pad_left__$1$jscomp$1_row_QMARK_$jscomp$1$$;$layout_gap_row$jscomp$1_pad_bottom__$1$jscomp$1_row_pad$$=($APP.$cljs$core$truth_$$($col_QMARK_$jscomp$1_pad_bottom$jscomp$5$$)?$col_QMARK_$jscomp$1_pad_bottom$jscomp$5$$:0)+$layout_gap_row$jscomp$1_pad_bottom__$1$jscomp$1_row_pad$$;$col_pad_pad_left__$1$jscomp$1_row_QMARK_$jscomp$1$$=($APP.$cljs$core$truth_$$($map__68045__$1_pad_left$jscomp$5_space_around_QMARK_$$)?$map__68045__$1_pad_left$jscomp$5_space_around_QMARK_$$:0)+$col_pad_pad_left__$1$jscomp$1_row_QMARK_$jscomp$1$$;
$bounds$jscomp$44_layout_points$jscomp$1$$=$APP.$app$common$geom$shapes$flex_layout$bounds$layout_content_points$$($bounds$jscomp$44_layout_points$jscomp$1$$,$map__68038__$1_p__68037$$,$children$jscomp$227$$,$objects$jscomp$421$$);return $APP.$app$common$data$not_empty_QMARK_$$($bounds$jscomp$44_layout_points$jscomp$1$$)?$app$common$geom$shapes$points$pad_points$$($app$common$geom$shapes$points$merge_parent_coords_bounds$$($bounds$jscomp$44_layout_points$jscomp$1$$,$parent_bounds$jscomp$13_parent_id$jscomp$76$$),
-$layout_padding$jscomp$5_pad_top$jscomp$5_pad_top__$1$jscomp$1$$,-$pad_right$jscomp$5_pad_right__$1$jscomp$1_space_evenly_QMARK_$$,-$layout_gap_row$jscomp$1_pad_bottom__$1$jscomp$1_row_pad$$,-$col_pad_pad_left__$1$jscomp$1_row_QMARK_$jscomp$1$$):$parent_bounds$jscomp$13_parent_id$jscomp$76$$};
$app$common$geom$shapes$flex_layout$positions$get_base_line$$=function($free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$,$G__68062__$1_layout_bounds$jscomp$3$$,$total_width$$,$total_height$$,$num_lines$$){var $layout_width$$=$APP.$app$common$geom$shapes$points$width_points$$($G__68062__$1_layout_bounds$jscomp$3$$),$layout_height$$=$APP.$app$common$geom$shapes$points$height_points$$($G__68062__$1_layout_bounds$jscomp$3$$),$row_QMARK_$jscomp$2$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$),
$G__68064__$1_G__68064__$2_G__68064__$3_col_QMARK_$jscomp$2$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$),$hv$jscomp$8$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$shapes$points$start_hv$$,$G__68062__$1_layout_bounds$jscomp$3$$),$vv$jscomp$8$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$shapes$points$start_vv$$,$G__68062__$1_layout_bounds$jscomp$3$$),
$layout_gap_col$jscomp$2_vec__68056_wrap_QMARK_$$=$app$common$types$shape$layout$wrap_QMARK_$$($free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$),$end_QMARK_$$=$layout_gap_col$jscomp$2_vec__68056_wrap_QMARK_$$&&$app$common$types$shape$layout$content_end_QMARK_$$($free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$)||!$layout_gap_col$jscomp$2_vec__68056_wrap_QMARK_$$&&$app$common$types$shape$layout$align_items_end_QMARK_$$($free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$),
$center_QMARK_$jscomp$2$$=$layout_gap_col$jscomp$2_vec__68056_wrap_QMARK_$$&&$app$common$types$shape$layout$content_center_QMARK_$$($free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$)||!$layout_gap_col$jscomp$2_vec__68056_wrap_QMARK_$$&&$app$common$types$shape$layout$align_items_center_QMARK_$$($free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$),$around_QMARK_$$=$layout_gap_col$jscomp$2_vec__68056_wrap_QMARK_$$&&$app$common$types$shape$layout$content_around_QMARK_$$($free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$),
$evenly_QMARK_$$=$layout_gap_col$jscomp$2_vec__68056_wrap_QMARK_$$&&$app$common$types$shape$layout$content_evenly_QMARK_$$($free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$);$layout_gap_col$jscomp$2_vec__68056_wrap_QMARK_$$=$APP.$app$common$types$shape$layout$gaps$$($free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$);$free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_gap_col$jscomp$2_vec__68056_wrap_QMARK_$$,
0,null);$layout_gap_col$jscomp$2_vec__68056_wrap_QMARK_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_gap_col$jscomp$2_vec__68056_wrap_QMARK_$$,1,null);var $lines_gap_row$$=($num_lines$$-1)*$free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$,$lines_gap_col$$=($num_lines$$-1)*$layout_gap_col$jscomp$2_vec__68056_wrap_QMARK_$$;$free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$=$layout_width$$-$total_width$$-$lines_gap_col$$;var $free_height_gap$$=$layout_height$$-
$total_height$$-$lines_gap_row$$,$free_width$$=$layout_width$$-$total_width$$,$free_height$$=$layout_height$$-$total_height$$,$G__68062$$=$APP.$app$common$geom$shapes$points$origin$$($G__68062__$1_layout_bounds$jscomp$3$$);$G__68062__$1_layout_bounds$jscomp$3$$=$row_QMARK_$jscomp$2$$?function(){var $G__68063__$1_G__68063__$2_G__68063__$3$$=$center_QMARK_$jscomp$2$$?$APP.$app$common$geom$point$add$$($G__68062$$,$vv$jscomp$8$$($free_height_gap$$/2)):$G__68062$$;$G__68063__$1_G__68063__$2_G__68063__$3$$=
$end_QMARK_$$?$APP.$app$common$geom$point$add$$($G__68063__$1_G__68063__$2_G__68063__$3$$,$vv$jscomp$8$$($free_height_gap$$)):$G__68063__$1_G__68063__$2_G__68063__$3$$;$G__68063__$1_G__68063__$2_G__68063__$3$$=$around_QMARK_$$?$APP.$app$common$geom$point$add$$($G__68063__$1_G__68063__$2_G__68063__$3$$,$vv$jscomp$8$$(function(){var $y__5111__auto__$jscomp$87$$=$free_height$$/$num_lines$$/2;return $lines_gap_row$$>$y__5111__auto__$jscomp$87$$?$lines_gap_row$$:$y__5111__auto__$jscomp$87$$}())):$G__68063__$1_G__68063__$2_G__68063__$3$$;
return $evenly_QMARK_$$?$APP.$app$common$geom$point$add$$($G__68063__$1_G__68063__$2_G__68063__$3$$,$vv$jscomp$8$$(function(){var $y__5111__auto__$jscomp$88$$=$free_height$$/($num_lines$$+1);return $lines_gap_row$$>$y__5111__auto__$jscomp$88$$?$lines_gap_row$$:$y__5111__auto__$jscomp$88$$}())):$G__68063__$1_G__68063__$2_G__68063__$3$$}():$G__68062$$;return $G__68064__$1_G__68064__$2_G__68064__$3_col_QMARK_$jscomp$2$$?($G__68064__$1_G__68064__$2_G__68064__$3_col_QMARK_$jscomp$2$$=$center_QMARK_$jscomp$2$$?
$APP.$app$common$geom$point$add$$($G__68062__$1_layout_bounds$jscomp$3$$,$hv$jscomp$8$$($free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$/2)):$G__68062__$1_layout_bounds$jscomp$3$$,$G__68064__$1_G__68064__$2_G__68064__$3_col_QMARK_$jscomp$2$$=$end_QMARK_$$?$APP.$app$common$geom$point$add$$($G__68064__$1_G__68064__$2_G__68064__$3_col_QMARK_$jscomp$2$$,$hv$jscomp$8$$($free_width_gap_layout_gap_row$jscomp$2_parent$jscomp$244$$)):$G__68064__$1_G__68064__$2_G__68064__$3_col_QMARK_$jscomp$2$$,
$G__68064__$1_G__68064__$2_G__68064__$3_col_QMARK_$jscomp$2$$=$around_QMARK_$$?$APP.$app$common$geom$point$add$$($G__68064__$1_G__68064__$2_G__68064__$3_col_QMARK_$jscomp$2$$,$hv$jscomp$8$$(function(){var $y__5111__auto__$jscomp$89$$=$free_width$$/$num_lines$$/2;return $lines_gap_col$$>$y__5111__auto__$jscomp$89$$?$lines_gap_col$$:$y__5111__auto__$jscomp$89$$}())):$G__68064__$1_G__68064__$2_G__68064__$3_col_QMARK_$jscomp$2$$,$evenly_QMARK_$$?$APP.$app$common$geom$point$add$$($G__68064__$1_G__68064__$2_G__68064__$3_col_QMARK_$jscomp$2$$,
$hv$jscomp$8$$(function(){var $y__5111__auto__$jscomp$90$$=$free_width$$/($num_lines$$+1);return $lines_gap_col$$>$y__5111__auto__$jscomp$90$$?$lines_gap_col$$:$y__5111__auto__$jscomp$90$$}())):$G__68064__$1_G__68064__$2_G__68064__$3_col_QMARK_$jscomp$2$$):$G__68062__$1_layout_bounds$jscomp$3$$};
$app$common$geom$shapes$flex_layout$positions$get_child_position$$=function($parent$jscomp$247_v_end_QMARK_$jscomp$2$$,$child$jscomp$97_corner_p_vec__68096$$,$child_width$jscomp$4$$,$child_height$jscomp$4$$,$layout_data__$1_map__68095__$1_p__68094$$){$layout_data__$1_map__68095__$1_p__68094$$=$APP.$cljs$core$__destructure_map$$($layout_data__$1_map__68095__$1_p__68094$$);var $start_p$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_data__$1_map__68095__$1_p__68094$$,$APP.$cljs$cst$3663$start_p$$),
$layout_gap_row$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_data__$1_map__68095__$1_p__68094$$,$APP.$cljs$cst$3803$layout_gap_row$$),$layout_gap_col$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_data__$1_map__68095__$1_p__68094$$,$APP.$cljs$cst$3804$layout_gap_col$$),$margin_x$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_data__$1_map__68095__$1_p__68094$$,$cljs$cst$3805$margin_x$$),$margin_y$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_data__$1_map__68095__$1_p__68094$$,
$cljs$cst$3806$margin_y$$),$line_height$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_data__$1_map__68095__$1_p__68094$$,$APP.$cljs$cst$1765$line_height$$),$line_width$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_data__$1_map__68095__$1_p__68094$$,$APP.$cljs$cst$3801$line_width$$),$layout_bounds$jscomp$6_next_p$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_data__$1_map__68095__$1_p__68094$$,$APP.$cljs$cst$3666$layout_bounds$$),
$row_QMARK_$jscomp$5$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$247_v_end_QMARK_$jscomp$2$$),$col_QMARK_$jscomp$5$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$247_v_end_QMARK_$jscomp$2$$),$h_start_QMARK_$jscomp$1$$=$app$common$types$shape$layout$h_start_QMARK_$$($parent$jscomp$247_v_end_QMARK_$jscomp$2$$),$h_center_QMARK_$jscomp$2$$=$app$common$types$shape$layout$h_center_QMARK_$$($parent$jscomp$247_v_end_QMARK_$jscomp$2$$),
$h_end_QMARK_$jscomp$2$$=$app$common$types$shape$layout$h_end_QMARK_$$($parent$jscomp$247_v_end_QMARK_$jscomp$2$$),$v_start_QMARK_$jscomp$1$$=$app$common$types$shape$layout$v_start_QMARK_$$($parent$jscomp$247_v_end_QMARK_$jscomp$2$$),$v_center_QMARK_$jscomp$2$$=$app$common$types$shape$layout$v_center_QMARK_$$($parent$jscomp$247_v_end_QMARK_$jscomp$2$$);$parent$jscomp$247_v_end_QMARK_$jscomp$2$$=$app$common$types$shape$layout$v_end_QMARK_$$($parent$jscomp$247_v_end_QMARK_$jscomp$2$$);var $self_start_QMARK_$$=
$app$common$types$shape$layout$align_self_start_QMARK_$$($child$jscomp$97_corner_p_vec__68096$$),$self_end_QMARK_$$=$app$common$types$shape$layout$align_self_end_QMARK_$$($child$jscomp$97_corner_p_vec__68096$$),$self_center_QMARK_$$=$app$common$types$shape$layout$align_self_center_QMARK_$$($child$jscomp$97_corner_p_vec__68096$$),$align_self_QMARK_$$=$self_start_QMARK_$$||$self_end_QMARK_$$||$self_center_QMARK_$$,$v_start_QMARK___$1$$=$col_QMARK_$jscomp$5$$||!$align_self_QMARK_$$?$v_start_QMARK_$jscomp$1$$:
$self_start_QMARK_$$,$v_center_QMARK___$1$$=$col_QMARK_$jscomp$5$$||!$align_self_QMARK_$$?$v_center_QMARK_$jscomp$2$$:$self_center_QMARK_$$,$v_end_QMARK___$1$$=$col_QMARK_$jscomp$5$$||!$align_self_QMARK_$$?$parent$jscomp$247_v_end_QMARK_$jscomp$2$$:$self_end_QMARK_$$,$h_start_QMARK___$1$$=$row_QMARK_$jscomp$5$$||!$align_self_QMARK_$$?$h_start_QMARK_$jscomp$1$$:$self_start_QMARK_$$,$h_center_QMARK___$1$$=$row_QMARK_$jscomp$5$$||!$align_self_QMARK_$$?$h_center_QMARK_$jscomp$2$$:$self_center_QMARK_$$,
$h_end_QMARK___$1$$=$row_QMARK_$jscomp$5$$||!$align_self_QMARK_$$?$h_end_QMARK_$jscomp$2$$:$self_end_QMARK_$$;$child$jscomp$97_corner_p_vec__68096$$=$app$common$types$shape$layout$child_margins$$($child$jscomp$97_corner_p_vec__68096$$);var $margin_top$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$97_corner_p_vec__68096$$,0,null),$margin_right$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$97_corner_p_vec__68096$$,1,null),$margin_bottom$jscomp$3$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$97_corner_p_vec__68096$$,2,null),$margin_left$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$97_corner_p_vec__68096$$,3,null),$hv$jscomp$11$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$shapes$points$start_hv$$,$layout_bounds$jscomp$6_next_p$jscomp$1$$),$vv$jscomp$11$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$shapes$points$start_vv$$,
$layout_bounds$jscomp$6_next_p$jscomp$1$$);$child$jscomp$97_corner_p_vec__68096$$=function(){var $G__68099__$1$$=$col_QMARK_$jscomp$5$$?function(){var $G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$=$margin_top$jscomp$3$$!=null?$APP.$app$common$geom$point$add$$($start_p$jscomp$5$$,$vv$jscomp$11$$($margin_top$jscomp$3$$)):$start_p$jscomp$5$$;$G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$=$h_center_QMARK___$1$$?$APP.$app$common$geom$point$add$$($G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$,
$hv$jscomp$11$$(-($child_width$jscomp$4$$/2))):$G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$;$G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$=$h_end_QMARK___$1$$?$APP.$app$common$geom$point$add$$($G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$,$hv$jscomp$11$$(-$child_width$jscomp$4$$)):$G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$;$G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$=$h_start_QMARK___$1$$?
$APP.$app$common$geom$point$add$$($G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$,$hv$jscomp$11$$($margin_left$jscomp$3$$)):$G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$;$G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$=$h_center_QMARK___$1$$?$APP.$app$common$geom$point$add$$($G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$,$hv$jscomp$11$$($line_width$jscomp$2$$/2+($margin_left$jscomp$3$$-$margin_right$jscomp$3$$)/2)):
$G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$;return $h_end_QMARK___$1$$?$APP.$app$common$geom$point$add$$($G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$,$hv$jscomp$11$$($line_width$jscomp$2$$+-$margin_right$jscomp$3$$)):$G__68100__$1_G__68100__$2_G__68100__$3_G__68100__$4_G__68100__$5$$}():$start_p$jscomp$5$$,$G__68099__$2_G__68099__$3$$=$row_QMARK_$jscomp$5$$?function(){var $G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$=$v_center_QMARK___$1$$?
$APP.$app$common$geom$point$add$$($G__68099__$1$$,$vv$jscomp$11$$(-($child_height$jscomp$4$$/2))):$G__68099__$1$$;$G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$=$v_end_QMARK___$1$$?$APP.$app$common$geom$point$add$$($G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$,$vv$jscomp$11$$(-$child_height$jscomp$4$$)):$G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$;$G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$=$margin_left$jscomp$3$$!=
null?$APP.$app$common$geom$point$add$$($G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$,$hv$jscomp$11$$($margin_left$jscomp$3$$)):$G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$;$G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$=$v_start_QMARK___$1$$?$APP.$app$common$geom$point$add$$($G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$,$vv$jscomp$11$$($margin_top$jscomp$3$$)):$G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$;
$G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$=$v_center_QMARK___$1$$?$APP.$app$common$geom$point$add$$($G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$,$vv$jscomp$11$$($line_height$jscomp$9$$/2+($margin_top$jscomp$3$$-$margin_bottom$jscomp$3$$)/2)):$G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$;return $v_end_QMARK___$1$$?$APP.$app$common$geom$point$add$$($G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$,$vv$jscomp$11$$($line_height$jscomp$9$$+
-$margin_bottom$jscomp$3$$)):$G__68101__$1_G__68101__$2_G__68101__$3_G__68101__$4_G__68101__$5$$}():$G__68099__$1$$;$G__68099__$2_G__68099__$3$$=$margin_x$$!=null?$APP.$app$common$geom$point$add$$($G__68099__$2_G__68099__$3$$,$hv$jscomp$11$$($margin_x$$)):$G__68099__$2_G__68099__$3$$;return $margin_y$$!=null?$APP.$app$common$geom$point$add$$($G__68099__$2_G__68099__$3$$,$vv$jscomp$11$$($margin_y$$)):$G__68099__$2_G__68099__$3$$}();$layout_bounds$jscomp$6_next_p$jscomp$1$$=function(){var $G__68102__$1_G__68102__$2_G__68102__$3$$=
$row_QMARK_$jscomp$5$$?$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$add$$($start_p$jscomp$5$$,$hv$jscomp$11$$($child_width$jscomp$4$$+$layout_gap_col$jscomp$5$$)),$hv$jscomp$11$$($margin_left$jscomp$3$$+$margin_right$jscomp$3$$)):$start_p$jscomp$5$$;$G__68102__$1_G__68102__$2_G__68102__$3$$=$col_QMARK_$jscomp$5$$?$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$add$$($G__68102__$1_G__68102__$2_G__68102__$3$$,$vv$jscomp$11$$($margin_top$jscomp$3$$+$margin_bottom$jscomp$3$$)),
$vv$jscomp$11$$($child_height$jscomp$4$$+$layout_gap_row$jscomp$5$$)):$G__68102__$1_G__68102__$2_G__68102__$3$$;$G__68102__$1_G__68102__$2_G__68102__$3$$=$margin_x$$!=null?$APP.$app$common$geom$point$add$$($G__68102__$1_G__68102__$2_G__68102__$3$$,$hv$jscomp$11$$($margin_x$$)):$G__68102__$1_G__68102__$2_G__68102__$3$$;return $margin_y$$!=null?$APP.$app$common$geom$point$add$$($G__68102__$1_G__68102__$2_G__68102__$3$$,$vv$jscomp$11$$($margin_y$$)):$G__68102__$1_G__68102__$2_G__68102__$3$$}();$layout_data__$1_map__68095__$1_p__68094$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($layout_data__$1_map__68095__$1_p__68094$$,$APP.$cljs$cst$3663$start_p$$,$layout_bounds$jscomp$6_next_p$jscomp$1$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$child$jscomp$97_corner_p_vec__68096$$,$layout_data__$1_map__68095__$1_p__68094$$],null)};
$app$common$geom$shapes$flex_layout$layout_data$child_min_width$$=function($child$jscomp$98$$,$child_bounds$jscomp$16$$,$bounds$jscomp$45$$,$objects$jscomp$422$$){return $app$common$geom$shapes$flex_layout$layout_data$_child_min_width$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$geom$shapes$flex_layout$layout_data$_child_min_width$$.$cljs$core$IFn$_invoke$arity$4$($child$jscomp$98$$,$child_bounds$jscomp$16$$,$bounds$jscomp$45$$,$objects$jscomp$422$$):$app$common$geom$shapes$flex_layout$layout_data$_child_min_width$$($child$jscomp$98$$,
$child_bounds$jscomp$16$$,$bounds$jscomp$45$$,$objects$jscomp$422$$)};
$app$common$geom$shapes$flex_layout$layout_data$child_min_height$$=function($child$jscomp$99$$,$child_bounds$jscomp$17$$,$bounds$jscomp$46$$,$objects$jscomp$423$$){return $app$common$geom$shapes$flex_layout$layout_data$_child_min_height$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$geom$shapes$flex_layout$layout_data$_child_min_height$$.$cljs$core$IFn$_invoke$arity$4$($child$jscomp$99$$,$child_bounds$jscomp$17$$,$bounds$jscomp$46$$,$objects$jscomp$423$$):$app$common$geom$shapes$flex_layout$layout_data$_child_min_height$$($child$jscomp$99$$,
$child_bounds$jscomp$17$$,$bounds$jscomp$46$$,$objects$jscomp$423$$)};
$app$common$geom$shapes$flex_layout$layout_data$layout_bounds$$=function($pad_top$jscomp$6_parent$jscomp$248$$,$shape_bounds$jscomp$2$$){var $pad_left$jscomp$6_vec__68110$$=$app$common$types$shape$layout$paddings$$($pad_top$jscomp$6_parent$jscomp$248$$);$pad_top$jscomp$6_parent$jscomp$248$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($pad_left$jscomp$6_vec__68110$$,0,null);var $pad_right$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($pad_left$jscomp$6_vec__68110$$,1,
null),$pad_bottom$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($pad_left$jscomp$6_vec__68110$$,2,null);$pad_left$jscomp$6_vec__68110$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($pad_left$jscomp$6_vec__68110$$,3,null);return $app$common$geom$shapes$points$pad_points$$($shape_bounds$jscomp$2$$,$pad_top$jscomp$6_parent$jscomp$248$$,$pad_right$jscomp$6$$,$pad_bottom$jscomp$6$$,$pad_left$jscomp$6_vec__68110$$)};
$app$common$geom$shapes$flex_layout$layout_data$init_layout_lines$$=function($shape$jscomp$509$$,$G__68308_G__68311_children$jscomp$228_children__$1$jscomp$29$$,$layout_bounds$jscomp$7_layout_height$jscomp$3$$,$bounds$jscomp$47$$,$objects$jscomp$424$$,$auto_QMARK_$jscomp$4$$){var $col_QMARK_$jscomp$6$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$509$$),$row_QMARK_$jscomp$6$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$509$$),
$space_around_QMARK_$jscomp$2$$=$app$common$types$shape$layout$space_around_QMARK_$$($shape$jscomp$509$$),$space_evenly_QMARK_$jscomp$2$$=$app$common$types$shape$layout$space_evenly_QMARK_$$($shape$jscomp$509$$),$auto_width_QMARK_$jscomp$4_wrap_QMARK_$jscomp$1$$=function(){var $or__5025__auto__$jscomp$753$$=$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$509$$);return $or__5025__auto__$jscomp$753$$?$or__5025__auto__$jscomp$753$$:$auto_QMARK_$jscomp$4$$}(),
$auto_height_QMARK_$jscomp$3_layout_gap_row$jscomp$6$$=function(){var $or__5025__auto__$jscomp$754$$=$APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$509$$);return $or__5025__auto__$jscomp$754$$?$or__5025__auto__$jscomp$754$$:$auto_QMARK_$jscomp$4$$}();$auto_width_QMARK_$jscomp$4_wrap_QMARK_$jscomp$1$$=$app$common$types$shape$layout$wrap_QMARK_$$($shape$jscomp$509$$)&&($col_QMARK_$jscomp$6$$||$APP.$cljs$core$not$$($auto_width_QMARK_$jscomp$4_wrap_QMARK_$jscomp$1$$))&&
($row_QMARK_$jscomp$6$$||$APP.$cljs$core$not$$($auto_height_QMARK_$jscomp$3_layout_gap_row$jscomp$6$$));var $layout_gap_col$jscomp$6_vec__68130$$=$APP.$app$common$types$shape$layout$gaps$$($shape$jscomp$509$$);$auto_height_QMARK_$jscomp$3_layout_gap_row$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_gap_col$jscomp$6_vec__68130$$,0,null);$layout_gap_col$jscomp$6_vec__68130$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_gap_col$jscomp$6_vec__68130$$,
1,null);var $layout_width$jscomp$3$$=$APP.$app$common$geom$shapes$points$width_points$$($layout_bounds$jscomp$7_layout_height$jscomp$3$$);$layout_bounds$jscomp$7_layout_height$jscomp$3$$=$APP.$app$common$geom$shapes$points$height_points$$($layout_bounds$jscomp$7_layout_height$jscomp$3$$);var $line_data$$=null,$result$jscomp$286$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);for($G__68308_G__68311_children$jscomp$228_children__$1$jscomp$29$$=$APP.$cljs$core$seq$$($G__68308_G__68311_children$jscomp$228_children__$1$jscomp$29$$);;){if($APP.$cljs$core$not$$($G__68308_G__68311_children$jscomp$228_children__$1$jscomp$29$$))return $APP.$cljs$core$persistent_BANG_$$(function(){var $G__68149$$=
$result$jscomp$286$$;return $line_data$$!=null?$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__68149$$,$line_data$$):$G__68149$$}());var $G__68306_G__68309_num_children$jscomp$1_vec__68150$$=$APP.$cljs$core$first$$($G__68308_G__68311_children$jscomp$228_children__$1$jscomp$29$$),$child_bounds$jscomp$18_child_data$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__68306_G__68309_num_children$jscomp$1_vec__68150$$,0,null),$child$jscomp$100_next_line_min_width$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__68306_G__68309_num_children$jscomp$1_vec__68150$$,
1,null),$G__68307_G__68310_children_data_map__68153__$1$$=$APP.$cljs$core$__destructure_map$$($line_data$$),$line_min_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68307_G__68310_children_data_map__68153__$1$$,$cljs$cst$3807$line_min_width$$),$line_min_height$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68307_G__68310_children_data_map__68153__$1$$,$cljs$cst$3808$line_min_height$$),$line_max_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68307_G__68310_children_data_map__68153__$1$$,
$cljs$cst$3809$line_max_width$$),$line_max_height$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68307_G__68310_children_data_map__68153__$1$$,$cljs$cst$3810$line_max_height$$);$G__68306_G__68309_num_children$jscomp$1_vec__68150$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68307_G__68310_children_data_map__68153__$1$$,$APP.$cljs$cst$3802$num_children$$);$G__68307_G__68310_children_data_map__68153__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68307_G__68310_children_data_map__68153__$1$$,
$cljs$cst$3811$children_data$$);var $child_width$jscomp$5$$=$APP.$app$common$geom$shapes$points$width_points$$($child_bounds$jscomp$18_child_data$$),$child_height$jscomp$5$$=$APP.$app$common$geom$shapes$points$height_points$$($child_bounds$jscomp$18_child_data$$),$child_max_width$$=$app$common$types$shape$layout$child_max_width$$($child$jscomp$100_next_line_min_width$$),$child_max_height$$=$app$common$types$shape$layout$child_max_height$$($child$jscomp$100_next_line_min_width$$),$child_margin_width_next_line_min_height$$=
$app$common$types$shape$layout$child_width_margin$$($child$jscomp$100_next_line_min_width$$),$child_margin_height$$=$app$common$types$shape$layout$child_height_margin$$($child$jscomp$100_next_line_min_width$$),$fill_width_QMARK_$$=$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$100_next_line_min_width$$),$fill_height_QMARK_$$=$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$100_next_line_min_width$$);
$child_bounds$jscomp$18_child_data$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$100_next_line_min_width$$),$cljs$cst$3812$child_min_width$$,$app$common$geom$shapes$flex_layout$layout_data$child_min_width$$($child$jscomp$100_next_line_min_width$$,$child_bounds$jscomp$18_child_data$$,$bounds$jscomp$47$$,$objects$jscomp$424$$),$cljs$cst$3813$child_min_height$$,$app$common$geom$shapes$flex_layout$layout_data$child_min_height$$($child$jscomp$100_next_line_min_width$$,
$child_bounds$jscomp$18_child_data$$,$bounds$jscomp$47$$,$objects$jscomp$424$$),$cljs$cst$3814$child_max_width$$,$fill_width_QMARK_$$?$child_max_width$$:$child_width$jscomp$5$$,$cljs$cst$3815$child_max_height$$,$fill_height_QMARK_$$?$child_max_height$$:$child_height$jscomp$5$$],null);var $next_min_width$$=$child_margin_width_next_line_min_height$$+$cljs$cst$3812$child_min_width$$.$cljs$core$IFn$_invoke$arity$1$($child_bounds$jscomp$18_child_data$$),$next_min_height$$=$child_margin_height$$+$cljs$cst$3813$child_min_height$$.$cljs$core$IFn$_invoke$arity$1$($child_bounds$jscomp$18_child_data$$),
$next_max_width$$=$child_margin_width_next_line_min_height$$+$cljs$cst$3814$child_max_width$$.$cljs$core$IFn$_invoke$arity$1$($child_bounds$jscomp$18_child_data$$),$next_max_height$$=$child_margin_height$$+$cljs$cst$3815$child_max_height$$.$cljs$core$IFn$_invoke$arity$1$($child_bounds$jscomp$18_child_data$$);$child$jscomp$100_next_line_min_width$$=$line_min_width$$+$next_min_width$$+($space_evenly_QMARK_$jscomp$2$$?$layout_gap_col$jscomp$6_vec__68130$$*($G__68306_G__68309_num_children$jscomp$1_vec__68150$$+
2):$space_around_QMARK_$jscomp$2$$?$layout_gap_col$jscomp$6_vec__68130$$*($G__68306_G__68309_num_children$jscomp$1_vec__68150$$+1):$layout_gap_col$jscomp$6_vec__68130$$*$G__68306_G__68309_num_children$jscomp$1_vec__68150$$);$child_margin_width_next_line_min_height$$=$line_min_height$$+$next_min_height$$+($space_evenly_QMARK_$jscomp$2$$?$auto_height_QMARK_$jscomp$3_layout_gap_row$jscomp$6$$*($G__68306_G__68309_num_children$jscomp$1_vec__68150$$+2):$space_around_QMARK_$jscomp$2$$?$auto_height_QMARK_$jscomp$3_layout_gap_row$jscomp$6$$*
($G__68306_G__68309_num_children$jscomp$1_vec__68150$$+1):$auto_height_QMARK_$jscomp$3_layout_gap_row$jscomp$6$$*$G__68306_G__68309_num_children$jscomp$1_vec__68150$$);$line_data$$!=null&&(!$auto_width_QMARK_$jscomp$4_wrap_QMARK_$jscomp$1$$||$row_QMARK_$jscomp$6$$&&($child$jscomp$100_next_line_min_width$$<$layout_width$jscomp$3$$||$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$100_next_line_min_width$$,$layout_width$jscomp$3$$,.5))||$col_QMARK_$jscomp$6$$&&($child_margin_width_next_line_min_height$$<
$layout_bounds$jscomp$7_layout_height$jscomp$3$$||$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($child_margin_width_next_line_min_height$$,$layout_bounds$jscomp$7_layout_height$jscomp$3$$,.5)))?($G__68306_G__68309_num_children$jscomp$1_vec__68150$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$3807$line_min_width$$,$row_QMARK_$jscomp$6$$?$line_min_width$$+$next_min_width$$:function(){var $x__5110__auto__$jscomp$93$$=$line_min_width$$,$y__5111__auto__$jscomp$93$$=
$next_min_width$$;return $x__5110__auto__$jscomp$93$$>$y__5111__auto__$jscomp$93$$?$x__5110__auto__$jscomp$93$$:$y__5111__auto__$jscomp$93$$}(),$cljs$cst$3809$line_max_width$$,$row_QMARK_$jscomp$6$$?$line_max_width$$+$next_max_width$$:function(){var $x__5110__auto__$jscomp$94$$=$line_max_width$$,$y__5111__auto__$jscomp$94$$=$next_max_width$$;return $x__5110__auto__$jscomp$94$$>$y__5111__auto__$jscomp$94$$?$x__5110__auto__$jscomp$94$$:$y__5111__auto__$jscomp$94$$}(),$cljs$cst$3808$line_min_height$$,
$col_QMARK_$jscomp$6$$?$line_min_height$$+$next_min_height$$:function(){var $x__5110__auto__$jscomp$95$$=$line_min_height$$,$y__5111__auto__$jscomp$95$$=$next_min_height$$;return $x__5110__auto__$jscomp$95$$>$y__5111__auto__$jscomp$95$$?$x__5110__auto__$jscomp$95$$:$y__5111__auto__$jscomp$95$$}(),$cljs$cst$3810$line_max_height$$,$col_QMARK_$jscomp$6$$?$line_max_height$$+$next_max_height$$:function(){var $x__5110__auto__$jscomp$96$$=$line_max_height$$,$y__5111__auto__$jscomp$96$$=$next_max_height$$;
return $x__5110__auto__$jscomp$96$$>$y__5111__auto__$jscomp$96$$?$x__5110__auto__$jscomp$96$$:$y__5111__auto__$jscomp$96$$}(),$APP.$cljs$cst$3802$num_children$$,$G__68306_G__68309_num_children$jscomp$1_vec__68150$$+1,$cljs$cst$3811$children_data$$,$app$common$geom$shapes$flex_layout$layout_data$conjv$$($G__68307_G__68310_children_data_map__68153__$1$$,$child_bounds$jscomp$18_child_data$$)],null),$G__68307_G__68310_children_data_map__68153__$1$$=$result$jscomp$286$$,$G__68308_G__68311_children$jscomp$228_children__$1$jscomp$29$$=
$APP.$cljs$core$next$$($G__68308_G__68311_children$jscomp$228_children__$1$jscomp$29$$),$line_data$$=$G__68306_G__68309_num_children$jscomp$1_vec__68150$$,$result$jscomp$286$$=$G__68307_G__68310_children_data_map__68153__$1$$):($G__68306_G__68309_num_children$jscomp$1_vec__68150$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$3807$line_min_width$$,$next_min_width$$,$cljs$cst$3808$line_min_height$$,$next_min_height$$,$cljs$cst$3809$line_max_width$$,$next_max_width$$,$cljs$cst$3810$line_max_height$$,
$next_max_height$$,$APP.$cljs$cst$3802$num_children$$,1,$cljs$cst$3811$children_data$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$child_bounds$jscomp$18_child_data$$],null)],null),$G__68307_G__68310_children_data_map__68153__$1$$=function(){var $G__68155$$=$result$jscomp$286$$;return $line_data$$!=null?$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__68155$$,$line_data$$):$G__68155$$}(),$G__68308_G__68311_children$jscomp$228_children__$1$jscomp$29$$=
$APP.$cljs$core$next$$($G__68308_G__68311_children$jscomp$228_children__$1$jscomp$29$$),$line_data$$=$G__68306_G__68309_num_children$jscomp$1_vec__68150$$,$result$jscomp$286$$=$G__68307_G__68310_children_data_map__68153__$1$$)}};
$app$common$geom$shapes$flex_layout$layout_data$add_space_to_items$$=function($prop$jscomp$28$$,$prop_min$$,$prop_max$$,$G__68314_result$jscomp$287_to_share$$,$G__68312_items$jscomp$43_items__$1$jscomp$3$$){var $num_items_per_line_target$$=$APP.$cljs$core$count$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68157_SHARP_$$){return $APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__68157_SHARP_$$,$prop$jscomp$28$$),
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__68157_SHARP_$$,$prop_max$$))},$G__68312_items$jscomp$43_items__$1$jscomp$3$$));$num_items_per_line_target$$=$G__68314_result$jscomp$287_to_share$$/$num_items_per_line_target$$;$G__68312_items$jscomp$43_items__$1$jscomp$3$$=$APP.$cljs$core$seq$$($G__68312_items$jscomp$43_items__$1$jscomp$3$$);var $G__68313_remainder$jscomp$13_remainder__$1$jscomp$5$$=$G__68314_result$jscomp$287_to_share$$;for($G__68314_result$jscomp$287_to_share$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;){if($APP.$cljs$core$not$$($G__68312_items$jscomp$43_items__$1$jscomp$3$$))return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$_persistent_BANG_$$($G__68314_result$jscomp$287_to_share$$),$G__68313_remainder$jscomp$13_remainder__$1$jscomp$5$$],null);var $current$jscomp$43$$=$APP.$cljs$core$first$$($G__68312_items$jscomp$43_items__$1$jscomp$3$$),$cur_val_current__$1$jscomp$1$$=function(){var $or__5025__auto__$jscomp$755_or__5025__auto____$1$jscomp$92$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$43$$,$prop$jscomp$28$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$755_or__5025__auto____$1$jscomp$92$$))return $or__5025__auto__$jscomp$755_or__5025__auto____$1$jscomp$92$$;
$or__5025__auto__$jscomp$755_or__5025__auto____$1$jscomp$92$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$43$$,$prop_min$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$755_or__5025__auto____$1$jscomp$92$$)?$or__5025__auto__$jscomp$755_or__5025__auto____$1$jscomp$92$$:0}(),$cur_inc_max_val$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$43$$,$prop_max$$);$cur_inc_max_val$$=$cur_val_current__$1$jscomp$1$$+$num_items_per_line_target$$>$cur_inc_max_val$$?
$cur_inc_max_val$$-$cur_val_current__$1$jscomp$1$$:$num_items_per_line_target$$;$cur_val_current__$1$jscomp$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($current$jscomp$43$$,$prop$jscomp$28$$,$cur_val_current__$1$jscomp$1$$+$cur_inc_max_val$$);$G__68313_remainder$jscomp$13_remainder__$1$jscomp$5$$-=$cur_inc_max_val$$;$G__68312_items$jscomp$43_items__$1$jscomp$3$$=$APP.$cljs$core$next$$($G__68312_items$jscomp$43_items__$1$jscomp$3$$);$G__68314_result$jscomp$287_to_share$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__68314_result$jscomp$287_to_share$$,
$cur_val_current__$1$jscomp$1$$)}};
$app$common$geom$shapes$flex_layout$layout_data$distribute_space$$=function($prop$jscomp$29$$,$prop_min$jscomp$1$$,$prop_max$jscomp$1$$,$min_value_to_share$jscomp$1$$,$bound_value_remainder$jscomp$14_vec__68166$$,$G__68316_items$jscomp$44_items__$1$jscomp$4_items__$2$jscomp$1$$){for($min_value_to_share$jscomp$1$$=$bound_value_remainder$jscomp$14_vec__68166$$-$min_value_to_share$jscomp$1$$;;){if($min_value_to_share$jscomp$1$$<=0)return $G__68316_items$jscomp$44_items__$1$jscomp$4_items__$2$jscomp$1$$;$bound_value_remainder$jscomp$14_vec__68166$$=
$app$common$geom$shapes$flex_layout$layout_data$add_space_to_items$$($prop$jscomp$29$$,$prop_min$jscomp$1$$,$prop_max$jscomp$1$$,$min_value_to_share$jscomp$1$$,$G__68316_items$jscomp$44_items__$1$jscomp$4_items__$2$jscomp$1$$);$G__68316_items$jscomp$44_items__$1$jscomp$4_items__$2$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bound_value_remainder$jscomp$14_vec__68166$$,0,null);$bound_value_remainder$jscomp$14_vec__68166$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bound_value_remainder$jscomp$14_vec__68166$$,
1,null);if($bound_value_remainder$jscomp$14_vec__68166$$<=0||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($bound_value_remainder$jscomp$14_vec__68166$$,$min_value_to_share$jscomp$1$$))return $G__68316_items$jscomp$44_items__$1$jscomp$4_items__$2$jscomp$1$$;$min_value_to_share$jscomp$1$$=$bound_value_remainder$jscomp$14_vec__68166$$}};
$app$common$geom$shapes$flex_layout$layout_data$add_lines_positions$$=function($parent$jscomp$249$$,$layout_bounds$jscomp$8$$,$auto_QMARK_$jscomp$5$$,$layout_lines$$){var $row_QMARK_$jscomp$7$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$249$$),$col_QMARK_$jscomp$7$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$249$$),$auto_width_QMARK_$jscomp$5$$=function(){var $or__5025__auto__$jscomp$756$$=
$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$249$$);return $or__5025__auto__$jscomp$756$$?$or__5025__auto__$jscomp$756$$:$auto_QMARK_$jscomp$5$$}(),$auto_height_QMARK_$jscomp$4$$=function(){var $or__5025__auto__$jscomp$757$$=$APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$249$$);return $or__5025__auto__$jscomp$757$$?$or__5025__auto__$jscomp$757$$:$auto_QMARK_$jscomp$5$$}(),$space_evenly_QMARK_$jscomp$3$$=
$app$common$types$shape$layout$space_evenly_QMARK_$$($parent$jscomp$249$$),$space_around_QMARK_$jscomp$3$$=$app$common$types$shape$layout$space_around_QMARK_$$($parent$jscomp$249$$),$num_lines$jscomp$3_vec__68188_vec__68249$$=$APP.$app$common$types$shape$layout$gaps$$($parent$jscomp$249$$),$layout_gap_row$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($num_lines$jscomp$3_vec__68188_vec__68249$$,0,null),$layout_gap_col$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($num_lines$jscomp$3_vec__68188_vec__68249$$,
1,null),$layout_width$jscomp$4$$=$APP.$app$common$geom$shapes$points$width_points$$($layout_bounds$jscomp$8$$),$layout_height$jscomp$4$$=$APP.$app$common$geom$shapes$points$height_points$$($layout_bounds$jscomp$8$$);$num_lines$jscomp$3_vec__68188_vec__68249$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__68226_total_max_height$jscomp$1$$,$line_min_width$jscomp$1_p__68227$$){var $total_min_width$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68226_total_max_height$jscomp$1$$,
0,null),$total_min_height$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68226_total_max_height$jscomp$1$$,1,null),$total_max_width$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68226_total_max_height$jscomp$1$$,2,null);$p__68226_total_max_height$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68226_total_max_height$jscomp$1$$,3,null);var $line_max_height$jscomp$1_map__68235__$1$$=$APP.$cljs$core$__destructure_map$$($line_min_width$jscomp$1_p__68227$$);
$line_min_width$jscomp$1_p__68227$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_max_height$jscomp$1_map__68235__$1$$,$cljs$cst$3807$line_min_width$$);var $line_min_height$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_max_height$jscomp$1_map__68235__$1$$,$cljs$cst$3808$line_min_height$$),$line_max_width$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_max_height$jscomp$1_map__68235__$1$$,$cljs$cst$3809$line_max_width$$);$line_max_height$jscomp$1_map__68235__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_max_height$jscomp$1_map__68235__$1$$,$cljs$cst$3810$line_max_height$$);return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$total_min_width$jscomp$1$$+$line_min_width$jscomp$1_p__68227$$,$total_min_height$jscomp$1$$+$line_min_height$jscomp$1$$,$total_max_width$jscomp$1$$+$line_max_width$jscomp$1$$,$p__68226_total_max_height$jscomp$1$$+$line_max_height$jscomp$1_map__68235__$1$$],null)},new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,0,0,0],null),$layout_lines$$);var $total_min_width$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($num_lines$jscomp$3_vec__68188_vec__68249$$,0,null),$total_min_height$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($num_lines$jscomp$3_vec__68188_vec__68249$$,1,null),$total_max_width$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($num_lines$jscomp$3_vec__68188_vec__68249$$,2,null),$total_max_height$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($num_lines$jscomp$3_vec__68188_vec__68249$$,
3,null);$num_lines$jscomp$3_vec__68188_vec__68249$$=$APP.$cljs$core$count$$($layout_lines$$);var $stretch_width_fix$$=$col_QMARK_$jscomp$7$$&&$app$common$types$shape$layout$content_stretch_QMARK_$$($parent$jscomp$249$$)&&$APP.$cljs$core$not$$($auto_width_QMARK_$jscomp$5$$)?($layout_width$jscomp$4$$-$layout_gap_col$jscomp$7$$*($num_lines$jscomp$3_vec__68188_vec__68249$$-1)-$total_max_width$$)/$num_lines$jscomp$3_vec__68188_vec__68249$$:0,$stretch_height_fix$$=$row_QMARK_$jscomp$7$$&&$app$common$types$shape$layout$content_stretch_QMARK_$$($parent$jscomp$249$$)&&
$APP.$cljs$core$not$$($auto_height_QMARK_$jscomp$4$$)?($layout_height$jscomp$4$$-$layout_gap_row$jscomp$7$$*($num_lines$jscomp$3_vec__68188_vec__68249$$-1)-$total_max_height$$)/$num_lines$jscomp$3_vec__68188_vec__68249$$:0,$rest_layout_height$$=$layout_height$jscomp$4$$-($num_lines$jscomp$3_vec__68188_vec__68249$$-1)*$layout_gap_row$jscomp$7$$,$rest_layout_width$$=$layout_width$jscomp$4$$-($num_lines$jscomp$3_vec__68188_vec__68249$$-1)*$layout_gap_col$jscomp$7$$,$layout_lines__$1$$=function(){var $G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$=
$row_QMARK_$jscomp$7$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68182_SHARP_$$){var $JSCompiler_temp_const$jscomp$10863$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;if($APP.$cljs$core$truth_$$($auto_width_QMARK_$jscomp$5$$))var $JSCompiler_temp$jscomp$10865_x__5110__auto__$jscomp$inline_12471$$=$cljs$cst$3807$line_min_width$$.$cljs$core$IFn$_invoke$arity$1$($p1__68182_SHARP_$$);else{$JSCompiler_temp$jscomp$10865_x__5110__auto__$jscomp$inline_12471$$=$cljs$cst$3807$line_min_width$$.$cljs$core$IFn$_invoke$arity$1$($p1__68182_SHARP_$$);
var $map__68243__$1$jscomp$inline_14356_num_children$jscomp$inline_14357_x__5113__auto__$jscomp$inline_12473_y__5111__auto__$jscomp$inline_12472$$=$APP.$cljs$core$__destructure_map$$($p1__68182_SHARP_$$);$map__68243__$1$jscomp$inline_14356_num_children$jscomp$inline_14357_x__5113__auto__$jscomp$inline_12473_y__5111__auto__$jscomp$inline_12472$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68243__$1$jscomp$inline_14356_num_children$jscomp$inline_14357_x__5113__auto__$jscomp$inline_12473_y__5111__auto__$jscomp$inline_12472$$,
$APP.$cljs$cst$3802$num_children$$);$map__68243__$1$jscomp$inline_14356_num_children$jscomp$inline_14357_x__5113__auto__$jscomp$inline_12473_y__5111__auto__$jscomp$inline_12472$$=$layout_width$jscomp$4$$-$layout_gap_col$jscomp$7$$*($space_evenly_QMARK_$jscomp$3$$?$map__68243__$1$jscomp$inline_14356_num_children$jscomp$inline_14357_x__5113__auto__$jscomp$inline_12473_y__5111__auto__$jscomp$inline_12472$$+1:$space_around_QMARK_$jscomp$3$$?$map__68243__$1$jscomp$inline_14356_num_children$jscomp$inline_14357_x__5113__auto__$jscomp$inline_12473_y__5111__auto__$jscomp$inline_12472$$:
$map__68243__$1$jscomp$inline_14356_num_children$jscomp$inline_14357_x__5113__auto__$jscomp$inline_12473_y__5111__auto__$jscomp$inline_12472$$-1);var $y__5114__auto__$jscomp$inline_12474$$=$cljs$cst$3809$line_max_width$$.$cljs$core$IFn$_invoke$arity$1$($p1__68182_SHARP_$$);$map__68243__$1$jscomp$inline_14356_num_children$jscomp$inline_14357_x__5113__auto__$jscomp$inline_12473_y__5111__auto__$jscomp$inline_12472$$=$map__68243__$1$jscomp$inline_14356_num_children$jscomp$inline_14357_x__5113__auto__$jscomp$inline_12473_y__5111__auto__$jscomp$inline_12472$$<
$y__5114__auto__$jscomp$inline_12474$$?$map__68243__$1$jscomp$inline_14356_num_children$jscomp$inline_14357_x__5113__auto__$jscomp$inline_12473_y__5111__auto__$jscomp$inline_12472$$:$y__5114__auto__$jscomp$inline_12474$$;$JSCompiler_temp$jscomp$10865_x__5110__auto__$jscomp$inline_12471$$=$JSCompiler_temp$jscomp$10865_x__5110__auto__$jscomp$inline_12471$$>$map__68243__$1$jscomp$inline_14356_num_children$jscomp$inline_14357_x__5113__auto__$jscomp$inline_12473_y__5111__auto__$jscomp$inline_12472$$?$JSCompiler_temp$jscomp$10865_x__5110__auto__$jscomp$inline_12471$$:
$map__68243__$1$jscomp$inline_14356_num_children$jscomp$inline_14357_x__5113__auto__$jscomp$inline_12473_y__5111__auto__$jscomp$inline_12472$$}return $JSCompiler_temp_const$jscomp$10863$$.call($APP.$cljs$core$assoc$$,$p1__68182_SHARP_$$,$APP.$cljs$cst$3801$line_width$$,$JSCompiler_temp$jscomp$10865_x__5110__auto__$jscomp$inline_12471$$)},$layout_lines$$):$layout_lines$$;$G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$=$col_QMARK_$jscomp$7$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68183_SHARP_$$){var $JSCompiler_temp_const$jscomp$10866$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;if($APP.$cljs$core$truth_$$($auto_height_QMARK_$jscomp$4$$))var $JSCompiler_temp$jscomp$10868_x__5110__auto__$jscomp$inline_12476$$=$cljs$cst$3808$line_min_height$$.$cljs$core$IFn$_invoke$arity$1$($p1__68183_SHARP_$$);else{$JSCompiler_temp$jscomp$10868_x__5110__auto__$jscomp$inline_12476$$=$cljs$cst$3808$line_min_height$$.$cljs$core$IFn$_invoke$arity$1$($p1__68183_SHARP_$$);var $map__68248__$1$jscomp$inline_14360_num_children$jscomp$inline_14361_x__5113__auto__$jscomp$inline_12478_y__5111__auto__$jscomp$inline_12477$$=
$APP.$cljs$core$__destructure_map$$($p1__68183_SHARP_$$);$map__68248__$1$jscomp$inline_14360_num_children$jscomp$inline_14361_x__5113__auto__$jscomp$inline_12478_y__5111__auto__$jscomp$inline_12477$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68248__$1$jscomp$inline_14360_num_children$jscomp$inline_14361_x__5113__auto__$jscomp$inline_12478_y__5111__auto__$jscomp$inline_12477$$,$APP.$cljs$cst$3802$num_children$$);$map__68248__$1$jscomp$inline_14360_num_children$jscomp$inline_14361_x__5113__auto__$jscomp$inline_12478_y__5111__auto__$jscomp$inline_12477$$=
$layout_height$jscomp$4$$-$layout_gap_row$jscomp$7$$*($space_evenly_QMARK_$jscomp$3$$?$map__68248__$1$jscomp$inline_14360_num_children$jscomp$inline_14361_x__5113__auto__$jscomp$inline_12478_y__5111__auto__$jscomp$inline_12477$$+1:$space_around_QMARK_$jscomp$3$$?$map__68248__$1$jscomp$inline_14360_num_children$jscomp$inline_14361_x__5113__auto__$jscomp$inline_12478_y__5111__auto__$jscomp$inline_12477$$:$map__68248__$1$jscomp$inline_14360_num_children$jscomp$inline_14361_x__5113__auto__$jscomp$inline_12478_y__5111__auto__$jscomp$inline_12477$$-
1);var $y__5114__auto__$jscomp$inline_12479$$=$cljs$cst$3810$line_max_height$$.$cljs$core$IFn$_invoke$arity$1$($p1__68183_SHARP_$$);$map__68248__$1$jscomp$inline_14360_num_children$jscomp$inline_14361_x__5113__auto__$jscomp$inline_12478_y__5111__auto__$jscomp$inline_12477$$=$map__68248__$1$jscomp$inline_14360_num_children$jscomp$inline_14361_x__5113__auto__$jscomp$inline_12478_y__5111__auto__$jscomp$inline_12477$$<$y__5114__auto__$jscomp$inline_12479$$?$map__68248__$1$jscomp$inline_14360_num_children$jscomp$inline_14361_x__5113__auto__$jscomp$inline_12478_y__5111__auto__$jscomp$inline_12477$$:
$y__5114__auto__$jscomp$inline_12479$$;$JSCompiler_temp$jscomp$10868_x__5110__auto__$jscomp$inline_12476$$=$JSCompiler_temp$jscomp$10868_x__5110__auto__$jscomp$inline_12476$$>$map__68248__$1$jscomp$inline_14360_num_children$jscomp$inline_14361_x__5113__auto__$jscomp$inline_12478_y__5111__auto__$jscomp$inline_12477$$?$JSCompiler_temp$jscomp$10868_x__5110__auto__$jscomp$inline_12476$$:$map__68248__$1$jscomp$inline_14360_num_children$jscomp$inline_14361_x__5113__auto__$jscomp$inline_12478_y__5111__auto__$jscomp$inline_12477$$}return $JSCompiler_temp_const$jscomp$10866$$.call($APP.$cljs$core$assoc$$,
$p1__68183_SHARP_$$,$APP.$cljs$cst$1765$line_height$$,$JSCompiler_temp$jscomp$10868_x__5110__auto__$jscomp$inline_12476$$)},$G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$):$G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$;$G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$=$APP.$cljs$core$truth_$$(function(){if($row_QMARK_$jscomp$7$$){var $or__5025__auto__$jscomp$758$$=$total_min_height$$>=$rest_layout_height$$;return $or__5025__auto__$jscomp$758$$?
$or__5025__auto__$jscomp$758$$:$auto_height_QMARK_$jscomp$4$$}return $row_QMARK_$jscomp$7$$}())?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68184_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__68184_SHARP_$$,$APP.$cljs$cst$1765$line_height$$,$cljs$cst$3808$line_min_height$$.$cljs$core$IFn$_invoke$arity$1$($p1__68184_SHARP_$$))},$G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$):$G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$;
$G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$=$row_QMARK_$jscomp$7$$&&$total_max_height$$<=$rest_layout_height$$&&$APP.$cljs$core$not$$($auto_height_QMARK_$jscomp$4$$)?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68185_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__68185_SHARP_$$,$APP.$cljs$cst$1765$line_height$$,$cljs$cst$3810$line_max_height$$.$cljs$core$IFn$_invoke$arity$1$($p1__68185_SHARP_$$)+$stretch_height_fix$$)},
$G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$):$G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$;$G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$=$APP.$cljs$core$truth_$$(function(){if($col_QMARK_$jscomp$7$$){var $or__5025__auto__$jscomp$759$$=$total_min_width$$>=$rest_layout_width$$;return $or__5025__auto__$jscomp$759$$?$or__5025__auto__$jscomp$759$$:$auto_width_QMARK_$jscomp$5$$}return $col_QMARK_$jscomp$7$$}())?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68186_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__68186_SHARP_$$,
$APP.$cljs$cst$3801$line_width$$,$cljs$cst$3807$line_min_width$$.$cljs$core$IFn$_invoke$arity$1$($p1__68186_SHARP_$$))},$G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$):$G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$;return $col_QMARK_$jscomp$7$$&&$total_max_width$$<=$rest_layout_width$$&&$APP.$cljs$core$not$$($auto_width_QMARK_$jscomp$5$$)?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68187_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__68187_SHARP_$$,
$APP.$cljs$cst$3801$line_width$$,$cljs$cst$3809$line_max_width$$.$cljs$core$IFn$_invoke$arity$1$($p1__68187_SHARP_$$)+$stretch_width_fix$$)},$G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$):$G__68255__$1_G__68255__$2_G__68255__$3_G__68255__$4_G__68255__$5$$}(),$layout_lines__$2_layout_lines__$3$$=function(){var $G__68257__$1$$=$row_QMARK_$jscomp$7$$&&$total_min_height$$<$rest_layout_height$$&&$rest_layout_height$$<$total_max_height$$&&$APP.$cljs$core$not$$($auto_height_QMARK_$jscomp$4$$)?
$app$common$geom$shapes$flex_layout$layout_data$distribute_space$$($APP.$cljs$cst$1765$line_height$$,$cljs$cst$3808$line_min_height$$,$cljs$cst$3810$line_max_height$$,$total_min_height$$,$rest_layout_height$$,$layout_lines__$1$$):$layout_lines__$1$$;return $col_QMARK_$jscomp$7$$&&$total_min_width$$<$rest_layout_width$$&&$rest_layout_width$$<$total_max_width$$&&$APP.$cljs$core$not$$($auto_width_QMARK_$jscomp$5$$)?$app$common$geom$shapes$flex_layout$layout_data$distribute_space$$($APP.$cljs$cst$3801$line_width$$,
$cljs$cst$3807$line_min_width$$,$cljs$cst$3809$line_max_width$$,$total_min_width$$,$rest_layout_width$$,$G__68257__$1$$):$G__68257__$1$$}();$layout_lines__$2_layout_lines__$3$$=$row_QMARK_$jscomp$7$$?$APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__68264_rest_layout_height__$1$$,$map__68270__$1_p__68265$$){var $result$jscomp$289$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68264_rest_layout_height__$1$$,
0,null);$p__68264_rest_layout_height__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68264_rest_layout_height__$1$$,1,null);$map__68270__$1_p__68265$$=$APP.$cljs$core$__destructure_map$$($map__68270__$1_p__68265$$);var $line_height$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68270__$1_p__68265$$,$APP.$cljs$cst$1765$line_height$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$289$$,
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__68270__$1_p__68265$$,$cljs$cst$3816$to_bound_height$$,$p__68264_rest_layout_height__$1$$)),$p__68264_rest_layout_height__$1$$-$line_height$jscomp$11$$-$layout_gap_row$jscomp$7$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$layout_height$jscomp$4$$],null),$layout_lines__$2_layout_lines__$3$$))):$col_QMARK_$jscomp$7$$?
$APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__68271_rest_layout_width__$1$$,$map__68276__$1_p__68272$$){var $result$jscomp$290$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68271_rest_layout_width__$1$$,0,null);$p__68271_rest_layout_width__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68271_rest_layout_width__$1$$,1,null);$map__68276__$1_p__68272$$=$APP.$cljs$core$__destructure_map$$($map__68276__$1_p__68272$$);
var $line_width$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68276__$1_p__68272$$,$APP.$cljs$cst$3801$line_width$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$290$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__68276__$1_p__68272$$,$cljs$cst$3817$to_bound_width$$,$p__68271_rest_layout_width__$1$$)),$p__68271_rest_layout_width__$1$$-
$line_width$jscomp$4$$-$layout_gap_col$jscomp$7$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$layout_width$jscomp$4$$],null),$layout_lines__$2_layout_lines__$3$$))):$layout_lines__$2_layout_lines__$3$$;var $total_height$jscomp$3_vec__68252$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__68220_total_height$jscomp$4$$,$line_width$jscomp$3_p__68221$$){var $total_width$jscomp$4$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68220_total_height$jscomp$4$$,0,null);$p__68220_total_height$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68220_total_height$jscomp$4$$,1,null);var $line_height$jscomp$10_map__68225__$1$$=$APP.$cljs$core$__destructure_map$$($line_width$jscomp$3_p__68221$$);$line_width$jscomp$3_p__68221$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_height$jscomp$10_map__68225__$1$$,$APP.$cljs$cst$3801$line_width$$);
$line_height$jscomp$10_map__68225__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_height$jscomp$10_map__68225__$1$$,$APP.$cljs$cst$1765$line_height$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$total_width$jscomp$4$$+$line_width$jscomp$3_p__68221$$,$p__68220_total_height$jscomp$4$$+$line_height$jscomp$10_map__68225__$1$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[0,0],null),$layout_lines__$2_layout_lines__$3$$),$total_width$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($total_height$jscomp$3_vec__68252$$,0,null);$total_height$jscomp$3_vec__68252$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($total_height$jscomp$3_vec__68252$$,1,null);var $base_p$jscomp$3$$=$app$common$geom$shapes$flex_layout$positions$get_base_line$$($parent$jscomp$249$$,$layout_bounds$jscomp$8$$,$total_width$jscomp$3$$,$total_height$jscomp$3_vec__68252$$,
$num_lines$jscomp$3_vec__68188_vec__68249$$);return $APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$(function($free_width$jscomp$inline_12543_line_gap_col$jscomp$inline_12545_total_width$jscomp$5$$,$free_height$jscomp$inline_12544_total_height$jscomp$5$$,$G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$,$base_p$jscomp$4_p__68236$$,
$layout_line$$){var $result$jscomp$288$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($base_p$jscomp$4_p__68236$$,0,null);$base_p$jscomp$4_p__68236$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($base_p$jscomp$4_p__68236$$,1,null);var $layout_height$jscomp$inline_12493_map__68078__$1$jscomp$inline_12488_start_p$jscomp$6$$=$APP.$cljs$core$__destructure_map$$($layout_line$$);var $line_width$jscomp$inline_12489_line_width__$1$jscomp$inline_12514_stretch_QMARK_$jscomp$inline_12539$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_height$jscomp$inline_12493_map__68078__$1$jscomp$inline_12488_start_p$jscomp$6$$,$APP.$cljs$cst$3801$line_width$$),$around_QMARK_$jscomp$inline_12541_line_height$jscomp$inline_12490_line_height__$1$jscomp$inline_12513$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_height$jscomp$inline_12493_map__68078__$1$jscomp$inline_12488_start_p$jscomp$6$$,$APP.$cljs$cst$1765$line_height$$),$children_gap_height$jscomp$inline_12512_num_children$jscomp$inline_12491$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_height$jscomp$inline_12493_map__68078__$1$jscomp$inline_12488_start_p$jscomp$6$$,$APP.$cljs$cst$3802$num_children$$),$G__68083__$2$jscomp$inline_12517_G__68083__$3$jscomp$inline_12518_auto_height_QMARK_$jscomp$inline_12535_layout_width$jscomp$inline_12492$$=$APP.$app$common$geom$shapes$points$width_points$$($layout_bounds$jscomp$8$$);$layout_height$jscomp$inline_12493_map__68078__$1$jscomp$inline_12488_start_p$jscomp$6$$=$APP.$app$common$geom$shapes$points$height_points$$($layout_bounds$jscomp$8$$);
var $col_QMARK_$jscomp$inline_12498_line_width$jscomp$inline_12528_vec__68079$jscomp$inline_12494$$=$APP.$app$common$types$shape$layout$gaps$$($parent$jscomp$249$$),$layout_gap_row$jscomp$inline_12495$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($col_QMARK_$jscomp$inline_12498_line_width$jscomp$inline_12528_vec__68079$jscomp$inline_12494$$,0,null),$children_gap_width$jscomp$inline_12511_layout_gap_col$jscomp$inline_12496$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($col_QMARK_$jscomp$inline_12498_line_width$jscomp$inline_12528_vec__68079$jscomp$inline_12494$$,
1,null),$layout_height$jscomp$inline_12531_row_QMARK_$jscomp$inline_12497$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$249$$);$col_QMARK_$jscomp$inline_12498_line_width$jscomp$inline_12528_vec__68079$jscomp$inline_12494$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$249$$);var $col_QMARK_$jscomp$inline_12533_map__68072__$1$jscomp$inline_12527_space_between_QMARK_$jscomp$inline_12499$$=$app$common$types$shape$layout$space_between_QMARK_$$($parent$jscomp$249$$),
$line_height$jscomp$inline_12529_space_around_QMARK_$jscomp$inline_12500$$=$app$common$types$shape$layout$space_around_QMARK_$$($parent$jscomp$249$$),$row_QMARK_$jscomp$inline_12532_space_evenly_QMARK_$jscomp$inline_12501$$=$app$common$types$shape$layout$space_evenly_QMARK_$$($parent$jscomp$249$$),$G__68083__$1$jscomp$inline_12516_evenly_QMARK_$jscomp$inline_12542_h_center_QMARK_$jscomp$inline_12502$$=$app$common$types$shape$layout$h_center_QMARK_$$($parent$jscomp$249$$),$h_end_QMARK_$jscomp$inline_12503_layout_width$jscomp$inline_12530$$=
$app$common$types$shape$layout$h_end_QMARK_$$($parent$jscomp$249$$),$auto_width_QMARK_$jscomp$inline_12534_v_center_QMARK_$jscomp$inline_12504$$=$app$common$types$shape$layout$v_center_QMARK_$$($parent$jscomp$249$$),$layout_gap_row$jscomp$inline_12537_v_end_QMARK_$jscomp$inline_12505$$=$app$common$types$shape$layout$v_end_QMARK_$$($parent$jscomp$249$$),$content_stretch_QMARK_$jscomp$inline_12506$$=$app$common$types$shape$layout$content_stretch_QMARK_$$($parent$jscomp$249$$),$auto_width_QMARK_$jscomp$inline_12507$$=
$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$249$$),$auto_height_QMARK_$jscomp$inline_12508$$=$APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$249$$),$between_QMARK_$jscomp$inline_12540_hv$jscomp$inline_12509_layout_align_content$jscomp$inline_14365_map__47898__$1$jscomp$inline_14364$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$shapes$points$start_hv$$,
$layout_bounds$jscomp$8$$),$layout_gap_col$jscomp$inline_12538_vec__68073$jscomp$inline_12536_vv$jscomp$inline_12510$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$shapes$points$start_vv$$,$layout_bounds$jscomp$8$$);$children_gap_width$jscomp$inline_12511_layout_gap_col$jscomp$inline_12496$$*=$children_gap_height$jscomp$inline_12512_num_children$jscomp$inline_12491$$-1;$children_gap_height$jscomp$inline_12512_num_children$jscomp$inline_12491$$=$layout_gap_row$jscomp$inline_12495$$*
($children_gap_height$jscomp$inline_12512_num_children$jscomp$inline_12491$$-1);$around_QMARK_$jscomp$inline_12541_line_height$jscomp$inline_12490_line_height__$1$jscomp$inline_12513$$=$layout_height$jscomp$inline_12531_row_QMARK_$jscomp$inline_12497$$&&$content_stretch_QMARK_$jscomp$inline_12506$$&&!$auto_height_QMARK_$jscomp$inline_12508$$?$around_QMARK_$jscomp$inline_12541_line_height$jscomp$inline_12490_line_height__$1$jscomp$inline_12513$$+($layout_height$jscomp$inline_12493_map__68078__$1$jscomp$inline_12488_start_p$jscomp$6$$-
$free_height$jscomp$inline_12544_total_height$jscomp$5$$)/$G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$:$around_QMARK_$jscomp$inline_12541_line_height$jscomp$inline_12490_line_height__$1$jscomp$inline_12513$$;$line_width$jscomp$inline_12489_line_width__$1$jscomp$inline_12514_stretch_QMARK_$jscomp$inline_12539$$=$col_QMARK_$jscomp$inline_12498_line_width$jscomp$inline_12528_vec__68079$jscomp$inline_12494$$&&$content_stretch_QMARK_$jscomp$inline_12506$$&&
!$auto_width_QMARK_$jscomp$inline_12507$$?$line_width$jscomp$inline_12489_line_width__$1$jscomp$inline_12514_stretch_QMARK_$jscomp$inline_12539$$+($G__68083__$2$jscomp$inline_12517_G__68083__$3$jscomp$inline_12518_auto_height_QMARK_$jscomp$inline_12535_layout_width$jscomp$inline_12492$$-$free_width$jscomp$inline_12543_line_gap_col$jscomp$inline_12545_total_width$jscomp$5$$)/$G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$:$line_width$jscomp$inline_12489_line_width__$1$jscomp$inline_12514_stretch_QMARK_$jscomp$inline_12539$$;
$G__68083__$1$jscomp$inline_12516_evenly_QMARK_$jscomp$inline_12542_h_center_QMARK_$jscomp$inline_12502$$=!$layout_height$jscomp$inline_12531_row_QMARK_$jscomp$inline_12497$$||!$G__68083__$1$jscomp$inline_12516_evenly_QMARK_$jscomp$inline_12542_h_center_QMARK_$jscomp$inline_12502$$||$line_height$jscomp$inline_12529_space_around_QMARK_$jscomp$inline_12500$$||$row_QMARK_$jscomp$inline_12532_space_evenly_QMARK_$jscomp$inline_12501$$||$col_QMARK_$jscomp$inline_12533_map__68072__$1$jscomp$inline_12527_space_between_QMARK_$jscomp$inline_12499$$?
$base_p$jscomp$4_p__68236$$:$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$add$$($base_p$jscomp$4_p__68236$$,$between_QMARK_$jscomp$inline_12540_hv$jscomp$inline_12509_layout_align_content$jscomp$inline_14365_map__47898__$1$jscomp$inline_14364$$($G__68083__$2$jscomp$inline_12517_G__68083__$3$jscomp$inline_12518_auto_height_QMARK_$jscomp$inline_12535_layout_width$jscomp$inline_12492$$/2)),$between_QMARK_$jscomp$inline_12540_hv$jscomp$inline_12509_layout_align_content$jscomp$inline_14365_map__47898__$1$jscomp$inline_14364$$(($line_width$jscomp$inline_12489_line_width__$1$jscomp$inline_12514_stretch_QMARK_$jscomp$inline_12539$$+
$children_gap_width$jscomp$inline_12511_layout_gap_col$jscomp$inline_12496$$)/2));$G__68083__$2$jscomp$inline_12517_G__68083__$3$jscomp$inline_12518_auto_height_QMARK_$jscomp$inline_12535_layout_width$jscomp$inline_12492$$=!$layout_height$jscomp$inline_12531_row_QMARK_$jscomp$inline_12497$$||!$h_end_QMARK_$jscomp$inline_12503_layout_width$jscomp$inline_12530$$||$line_height$jscomp$inline_12529_space_around_QMARK_$jscomp$inline_12500$$||$row_QMARK_$jscomp$inline_12532_space_evenly_QMARK_$jscomp$inline_12501$$||
$col_QMARK_$jscomp$inline_12533_map__68072__$1$jscomp$inline_12527_space_between_QMARK_$jscomp$inline_12499$$?$G__68083__$1$jscomp$inline_12516_evenly_QMARK_$jscomp$inline_12542_h_center_QMARK_$jscomp$inline_12502$$:$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$add$$($G__68083__$1$jscomp$inline_12516_evenly_QMARK_$jscomp$inline_12542_h_center_QMARK_$jscomp$inline_12502$$,$between_QMARK_$jscomp$inline_12540_hv$jscomp$inline_12509_layout_align_content$jscomp$inline_14365_map__47898__$1$jscomp$inline_14364$$($G__68083__$2$jscomp$inline_12517_G__68083__$3$jscomp$inline_12518_auto_height_QMARK_$jscomp$inline_12535_layout_width$jscomp$inline_12492$$)),
$between_QMARK_$jscomp$inline_12540_hv$jscomp$inline_12509_layout_align_content$jscomp$inline_14365_map__47898__$1$jscomp$inline_14364$$($line_width$jscomp$inline_12489_line_width__$1$jscomp$inline_12514_stretch_QMARK_$jscomp$inline_12539$$+$children_gap_width$jscomp$inline_12511_layout_gap_col$jscomp$inline_12496$$));$G__68083__$2$jscomp$inline_12517_G__68083__$3$jscomp$inline_12518_auto_height_QMARK_$jscomp$inline_12535_layout_width$jscomp$inline_12492$$=!$col_QMARK_$jscomp$inline_12498_line_width$jscomp$inline_12528_vec__68079$jscomp$inline_12494$$||
!$auto_width_QMARK_$jscomp$inline_12534_v_center_QMARK_$jscomp$inline_12504$$||$line_height$jscomp$inline_12529_space_around_QMARK_$jscomp$inline_12500$$||$row_QMARK_$jscomp$inline_12532_space_evenly_QMARK_$jscomp$inline_12501$$||$col_QMARK_$jscomp$inline_12533_map__68072__$1$jscomp$inline_12527_space_between_QMARK_$jscomp$inline_12499$$?$G__68083__$2$jscomp$inline_12517_G__68083__$3$jscomp$inline_12518_auto_height_QMARK_$jscomp$inline_12535_layout_width$jscomp$inline_12492$$:$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$add$$($G__68083__$2$jscomp$inline_12517_G__68083__$3$jscomp$inline_12518_auto_height_QMARK_$jscomp$inline_12535_layout_width$jscomp$inline_12492$$,
$layout_gap_col$jscomp$inline_12538_vec__68073$jscomp$inline_12536_vv$jscomp$inline_12510$$($layout_height$jscomp$inline_12493_map__68078__$1$jscomp$inline_12488_start_p$jscomp$6$$/2)),$layout_gap_col$jscomp$inline_12538_vec__68073$jscomp$inline_12536_vv$jscomp$inline_12510$$(($around_QMARK_$jscomp$inline_12541_line_height$jscomp$inline_12490_line_height__$1$jscomp$inline_12513$$+$children_gap_height$jscomp$inline_12512_num_children$jscomp$inline_12491$$)/2));$layout_height$jscomp$inline_12493_map__68078__$1$jscomp$inline_12488_start_p$jscomp$6$$=
!$col_QMARK_$jscomp$inline_12498_line_width$jscomp$inline_12528_vec__68079$jscomp$inline_12494$$||!$layout_gap_row$jscomp$inline_12537_v_end_QMARK_$jscomp$inline_12505$$||$line_height$jscomp$inline_12529_space_around_QMARK_$jscomp$inline_12500$$||$row_QMARK_$jscomp$inline_12532_space_evenly_QMARK_$jscomp$inline_12501$$||$col_QMARK_$jscomp$inline_12533_map__68072__$1$jscomp$inline_12527_space_between_QMARK_$jscomp$inline_12499$$?$G__68083__$2$jscomp$inline_12517_G__68083__$3$jscomp$inline_12518_auto_height_QMARK_$jscomp$inline_12535_layout_width$jscomp$inline_12492$$:
$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$add$$($G__68083__$2$jscomp$inline_12517_G__68083__$3$jscomp$inline_12518_auto_height_QMARK_$jscomp$inline_12535_layout_width$jscomp$inline_12492$$,$layout_gap_col$jscomp$inline_12538_vec__68073$jscomp$inline_12536_vv$jscomp$inline_12510$$($layout_height$jscomp$inline_12493_map__68078__$1$jscomp$inline_12488_start_p$jscomp$6$$)),$layout_gap_col$jscomp$inline_12538_vec__68073$jscomp$inline_12536_vv$jscomp$inline_12510$$($around_QMARK_$jscomp$inline_12541_line_height$jscomp$inline_12490_line_height__$1$jscomp$inline_12513$$+
$children_gap_height$jscomp$inline_12512_num_children$jscomp$inline_12491$$));$col_QMARK_$jscomp$inline_12533_map__68072__$1$jscomp$inline_12527_space_between_QMARK_$jscomp$inline_12499$$=$APP.$cljs$core$__destructure_map$$($layout_line$$);$col_QMARK_$jscomp$inline_12498_line_width$jscomp$inline_12528_vec__68079$jscomp$inline_12494$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($col_QMARK_$jscomp$inline_12533_map__68072__$1$jscomp$inline_12527_space_between_QMARK_$jscomp$inline_12499$$,$APP.$cljs$cst$3801$line_width$$);
$line_height$jscomp$inline_12529_space_around_QMARK_$jscomp$inline_12500$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($col_QMARK_$jscomp$inline_12533_map__68072__$1$jscomp$inline_12527_space_between_QMARK_$jscomp$inline_12499$$,$APP.$cljs$cst$1765$line_height$$);$h_end_QMARK_$jscomp$inline_12503_layout_width$jscomp$inline_12530$$=$APP.$app$common$geom$shapes$points$width_points$$($layout_bounds$jscomp$8$$);$layout_height$jscomp$inline_12531_row_QMARK_$jscomp$inline_12497$$=$APP.$app$common$geom$shapes$points$height_points$$($layout_bounds$jscomp$8$$);
$row_QMARK_$jscomp$inline_12532_space_evenly_QMARK_$jscomp$inline_12501$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$249$$);$col_QMARK_$jscomp$inline_12533_map__68072__$1$jscomp$inline_12527_space_between_QMARK_$jscomp$inline_12499$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$249$$);$auto_width_QMARK_$jscomp$inline_12534_v_center_QMARK_$jscomp$inline_12504$$=$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$249$$);
$G__68083__$2$jscomp$inline_12517_G__68083__$3$jscomp$inline_12518_auto_height_QMARK_$jscomp$inline_12535_layout_width$jscomp$inline_12492$$=$APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$249$$);$layout_gap_col$jscomp$inline_12538_vec__68073$jscomp$inline_12536_vv$jscomp$inline_12510$$=$APP.$app$common$types$shape$layout$gaps$$($parent$jscomp$249$$);$layout_gap_row$jscomp$inline_12537_v_end_QMARK_$jscomp$inline_12505$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_gap_col$jscomp$inline_12538_vec__68073$jscomp$inline_12536_vv$jscomp$inline_12510$$,
0,null);$layout_gap_col$jscomp$inline_12538_vec__68073$jscomp$inline_12536_vv$jscomp$inline_12510$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_gap_col$jscomp$inline_12538_vec__68073$jscomp$inline_12536_vv$jscomp$inline_12510$$,1,null);$line_width$jscomp$inline_12489_line_width__$1$jscomp$inline_12514_stretch_QMARK_$jscomp$inline_12539$$=$app$common$types$shape$layout$content_stretch_QMARK_$$($parent$jscomp$249$$);$between_QMARK_$jscomp$inline_12540_hv$jscomp$inline_12509_layout_align_content$jscomp$inline_14365_map__47898__$1$jscomp$inline_14364$$=
$APP.$cljs$core$__destructure_map$$($parent$jscomp$249$$);$between_QMARK_$jscomp$inline_12540_hv$jscomp$inline_12509_layout_align_content$jscomp$inline_14365_map__47898__$1$jscomp$inline_14364$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($between_QMARK_$jscomp$inline_12540_hv$jscomp$inline_12509_layout_align_content$jscomp$inline_14365_map__47898__$1$jscomp$inline_14364$$,$APP.$cljs$cst$1691$layout_align_content$$);$between_QMARK_$jscomp$inline_12540_hv$jscomp$inline_12509_layout_align_content$jscomp$inline_14365_map__47898__$1$jscomp$inline_14364$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1668$space_between$$,$between_QMARK_$jscomp$inline_12540_hv$jscomp$inline_12509_layout_align_content$jscomp$inline_14365_map__47898__$1$jscomp$inline_14364$$);$around_QMARK_$jscomp$inline_12541_line_height$jscomp$inline_12490_line_height__$1$jscomp$inline_12513$$=$app$common$types$shape$layout$content_around_QMARK_$$($parent$jscomp$249$$);$G__68083__$1$jscomp$inline_12516_evenly_QMARK_$jscomp$inline_12542_h_center_QMARK_$jscomp$inline_12502$$=
$app$common$types$shape$layout$content_evenly_QMARK_$$($parent$jscomp$249$$);$free_width$jscomp$inline_12543_line_gap_col$jscomp$inline_12545_total_width$jscomp$5$$=$h_end_QMARK_$jscomp$inline_12503_layout_width$jscomp$inline_12530$$-$free_width$jscomp$inline_12543_line_gap_col$jscomp$inline_12545_total_width$jscomp$5$$;$free_height$jscomp$inline_12544_total_height$jscomp$5$$=$layout_height$jscomp$inline_12531_row_QMARK_$jscomp$inline_12497$$-$free_height$jscomp$inline_12544_total_height$jscomp$5$$;
$free_width$jscomp$inline_12543_line_gap_col$jscomp$inline_12545_total_width$jscomp$5$$=$auto_width_QMARK_$jscomp$inline_12534_v_center_QMARK_$jscomp$inline_12504$$?$layout_gap_col$jscomp$inline_12538_vec__68073$jscomp$inline_12536_vv$jscomp$inline_12510$$:$line_width$jscomp$inline_12489_line_width__$1$jscomp$inline_12514_stretch_QMARK_$jscomp$inline_12539$$?$free_width$jscomp$inline_12543_line_gap_col$jscomp$inline_12545_total_width$jscomp$5$$/$G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$:
$between_QMARK_$jscomp$inline_12540_hv$jscomp$inline_12509_layout_align_content$jscomp$inline_14365_map__47898__$1$jscomp$inline_14364$$?$free_width$jscomp$inline_12543_line_gap_col$jscomp$inline_12545_total_width$jscomp$5$$/($G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$-1):$around_QMARK_$jscomp$inline_12541_line_height$jscomp$inline_12490_line_height__$1$jscomp$inline_12513$$?$free_width$jscomp$inline_12543_line_gap_col$jscomp$inline_12545_total_width$jscomp$5$$/
$G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$:$G__68083__$1$jscomp$inline_12516_evenly_QMARK_$jscomp$inline_12542_h_center_QMARK_$jscomp$inline_12502$$?$free_width$jscomp$inline_12543_line_gap_col$jscomp$inline_12545_total_width$jscomp$5$$/($G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$+1):$layout_gap_col$jscomp$inline_12538_vec__68073$jscomp$inline_12536_vv$jscomp$inline_12510$$;$G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$=
$G__68083__$2$jscomp$inline_12517_G__68083__$3$jscomp$inline_12518_auto_height_QMARK_$jscomp$inline_12535_layout_width$jscomp$inline_12492$$?$layout_gap_row$jscomp$inline_12537_v_end_QMARK_$jscomp$inline_12505$$:$line_width$jscomp$inline_12489_line_width__$1$jscomp$inline_12514_stretch_QMARK_$jscomp$inline_12539$$?$free_height$jscomp$inline_12544_total_height$jscomp$5$$/$G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$:$between_QMARK_$jscomp$inline_12540_hv$jscomp$inline_12509_layout_align_content$jscomp$inline_14365_map__47898__$1$jscomp$inline_14364$$?
$free_height$jscomp$inline_12544_total_height$jscomp$5$$/($G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$-1):$around_QMARK_$jscomp$inline_12541_line_height$jscomp$inline_12490_line_height__$1$jscomp$inline_12513$$?$free_height$jscomp$inline_12544_total_height$jscomp$5$$/$G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$:$G__68083__$1$jscomp$inline_12516_evenly_QMARK_$jscomp$inline_12542_h_center_QMARK_$jscomp$inline_12502$$?
$free_height$jscomp$inline_12544_total_height$jscomp$5$$/($G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$+1):$layout_gap_row$jscomp$inline_12537_v_end_QMARK_$jscomp$inline_12505$$;$G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$=$row_QMARK_$jscomp$inline_12532_space_evenly_QMARK_$jscomp$inline_12501$$?$APP.$app$common$geom$point$add$$($base_p$jscomp$4_p__68236$$,$APP.$app$common$geom$shapes$points$start_vv$$($layout_bounds$jscomp$8$$,
$line_height$jscomp$inline_12529_space_around_QMARK_$jscomp$inline_12500$$+($layout_gap_row$jscomp$inline_12537_v_end_QMARK_$jscomp$inline_12505$$>$G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$?$layout_gap_row$jscomp$inline_12537_v_end_QMARK_$jscomp$inline_12505$$:$G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$))):$base_p$jscomp$4_p__68236$$;$G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$=
$col_QMARK_$jscomp$inline_12533_map__68072__$1$jscomp$inline_12527_space_between_QMARK_$jscomp$inline_12499$$?$APP.$app$common$geom$point$add$$($G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$,$APP.$app$common$geom$shapes$points$start_hv$$($layout_bounds$jscomp$8$$,$col_QMARK_$jscomp$inline_12498_line_width$jscomp$inline_12528_vec__68079$jscomp$inline_12494$$+($layout_gap_col$jscomp$inline_12538_vec__68073$jscomp$inline_12536_vv$jscomp$inline_12510$$>
$free_width$jscomp$inline_12543_line_gap_col$jscomp$inline_12545_total_width$jscomp$5$$?$layout_gap_col$jscomp$inline_12538_vec__68073$jscomp$inline_12536_vv$jscomp$inline_12510$$:$free_width$jscomp$inline_12543_line_gap_col$jscomp$inline_12545_total_width$jscomp$5$$))):$G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$288$$,
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($layout_line$$,$APP.$cljs$cst$3663$start_p$$,$layout_height$jscomp$inline_12493_map__68078__$1$jscomp$inline_12488_start_p$jscomp$6$$)),$G__68076__$1$jscomp$inline_12547_line_gap_row$jscomp$inline_12546_next_p$jscomp$2_num_lines$jscomp$4$$],null)},$total_width$jscomp$3$$,$total_height$jscomp$3_vec__68252$$,$num_lines$jscomp$3_vec__68188_vec__68249$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$base_p$jscomp$3$$],null),$layout_lines__$2_layout_lines__$3$$)))};
$app$common$geom$shapes$flex_layout$layout_data$add_line_spacing$$=function($shape$jscomp$510$$,$layout_bounds$jscomp$9$$,$auto_QMARK_$jscomp$6$$,$map__68281__$1_p__68280$$){$map__68281__$1_p__68280$$=$APP.$cljs$core$__destructure_map$$($map__68281__$1_p__68280$$);var $num_children$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68281__$1_p__68280$$,$APP.$cljs$cst$3802$num_children$$),$line_width$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68281__$1_p__68280$$,
$APP.$cljs$cst$3801$line_width$$),$line_height$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68281__$1_p__68280$$,$APP.$cljs$cst$1765$line_height$$),$width$jscomp$132$$=$APP.$app$common$geom$shapes$points$width_points$$($layout_bounds$jscomp$9$$),$height$jscomp$118$$=$APP.$app$common$geom$shapes$points$height_points$$($layout_bounds$jscomp$9$$),$row_QMARK_$jscomp$8$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$510$$),
$col_QMARK_$jscomp$8$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$510$$),$auto_height_QMARK_$jscomp$5$$=function(){var $or__5025__auto__$jscomp$760$$=$APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$510$$);return $or__5025__auto__$jscomp$760$$?$or__5025__auto__$jscomp$760$$:$auto_QMARK_$jscomp$6$$}(),$auto_width_QMARK_$jscomp$6$$=function(){var $or__5025__auto__$jscomp$761$$=$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$510$$);
return $or__5025__auto__$jscomp$761$$?$or__5025__auto__$jscomp$761$$:$auto_QMARK_$jscomp$6$$}(),$space_between_QMARK_$jscomp$1$$=$app$common$types$shape$layout$space_between_QMARK_$$($shape$jscomp$510$$),$space_evenly_QMARK_$jscomp$4$$=$app$common$types$shape$layout$space_evenly_QMARK_$$($shape$jscomp$510$$),$space_around_QMARK_$jscomp$4$$=$app$common$types$shape$layout$space_around_QMARK_$$($shape$jscomp$510$$),$vec__68282$$=$APP.$app$common$types$shape$layout$gaps$$($shape$jscomp$510$$),$layout_gap_row$jscomp$8$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__68282$$,0,null),$layout_gap_col$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__68282$$,1,null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__68281__$1_p__68280$$,$APP.$cljs$cst$3666$layout_bounds$$,$layout_bounds$jscomp$9$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3803$layout_gap_row$$,$col_QMARK_$jscomp$8$$&&$space_evenly_QMARK_$jscomp$4$$?0:
$col_QMARK_$jscomp$8$$&&$space_around_QMARK_$jscomp$4$$?function(){var $y__5111__auto__$jscomp$105$$=($height$jscomp$118$$-$line_height$jscomp$12$$)/$num_children$jscomp$4$$;return $layout_gap_row$jscomp$8$$>$y__5111__auto__$jscomp$105$$?$layout_gap_row$jscomp$8$$:$y__5111__auto__$jscomp$105$$}()/2:$col_QMARK_$jscomp$8$$&&$space_between_QMARK_$jscomp$1$$&&$APP.$cljs$core$not$$($auto_height_QMARK_$jscomp$5$$)?function(){var $y__5111__auto__$jscomp$106$$=($height$jscomp$118$$-$line_height$jscomp$12$$)/
($num_children$jscomp$4$$-1);return $layout_gap_row$jscomp$8$$>$y__5111__auto__$jscomp$106$$?$layout_gap_row$jscomp$8$$:$y__5111__auto__$jscomp$106$$}():$layout_gap_row$jscomp$8$$,$APP.$cljs$cst$3804$layout_gap_col$$,$row_QMARK_$jscomp$8$$&&$space_evenly_QMARK_$jscomp$4$$?0:$APP.$cljs$core$truth_$$($row_QMARK_$jscomp$8$$?$space_around_QMARK_$jscomp$4$$?$auto_width_QMARK_$jscomp$6$$:$space_around_QMARK_$jscomp$4$$:$row_QMARK_$jscomp$8$$)?0:$row_QMARK_$jscomp$8$$&&$space_around_QMARK_$jscomp$4$$?function(){var $y__5111__auto__$jscomp$103$$=
($width$jscomp$132$$-$line_width$jscomp$5$$)/$num_children$jscomp$4$$;return $layout_gap_col$jscomp$8$$>$y__5111__auto__$jscomp$103$$?$layout_gap_col$jscomp$8$$:$y__5111__auto__$jscomp$103$$}()/2:$row_QMARK_$jscomp$8$$&&$space_between_QMARK_$jscomp$1$$&&$APP.$cljs$core$not$$($auto_width_QMARK_$jscomp$6$$)?function(){var $y__5111__auto__$jscomp$104$$=($width$jscomp$132$$-$line_width$jscomp$5$$)/($num_children$jscomp$4$$-1);return $layout_gap_col$jscomp$8$$>$y__5111__auto__$jscomp$104$$?$layout_gap_col$jscomp$8$$:
$y__5111__auto__$jscomp$104$$}():$layout_gap_col$jscomp$8$$,$cljs$cst$3805$margin_x$$,$row_QMARK_$jscomp$8$$&&$space_evenly_QMARK_$jscomp$4$$&&$APP.$cljs$core$not$$($auto_width_QMARK_$jscomp$6$$)?function(){var $y__5111__auto__$jscomp$99$$=($width$jscomp$132$$-$line_width$jscomp$5$$)/($num_children$jscomp$4$$+1);return $layout_gap_col$jscomp$8$$>$y__5111__auto__$jscomp$99$$?$layout_gap_col$jscomp$8$$:$y__5111__auto__$jscomp$99$$}():$row_QMARK_$jscomp$8$$&&$space_around_QMARK_$jscomp$4$$&&$APP.$cljs$core$not$$($auto_width_QMARK_$jscomp$6$$)?
function(){var $y__5111__auto__$jscomp$100$$=($width$jscomp$132$$-$line_width$jscomp$5$$)/$num_children$jscomp$4$$;return $layout_gap_col$jscomp$8$$>$y__5111__auto__$jscomp$100$$?$layout_gap_col$jscomp$8$$:$y__5111__auto__$jscomp$100$$}()/2:$APP.$cljs$core$truth_$$(function(){if($row_QMARK_$jscomp$8$$){var $and__5023__auto____$1$jscomp$81$$=$space_evenly_QMARK_$jscomp$4$$||$space_around_QMARK_$jscomp$4$$;return $and__5023__auto____$1$jscomp$81$$?$auto_width_QMARK_$jscomp$6$$:$and__5023__auto____$1$jscomp$81$$}return $row_QMARK_$jscomp$8$$}())?
$layout_gap_col$jscomp$8$$:0,$cljs$cst$3806$margin_y$$,$col_QMARK_$jscomp$8$$&&$space_evenly_QMARK_$jscomp$4$$&&$APP.$cljs$core$not$$($auto_height_QMARK_$jscomp$5$$)?function(){var $y__5111__auto__$jscomp$101$$=($height$jscomp$118$$-$line_height$jscomp$12$$)/($num_children$jscomp$4$$+1);return $layout_gap_row$jscomp$8$$>$y__5111__auto__$jscomp$101$$?$layout_gap_row$jscomp$8$$:$y__5111__auto__$jscomp$101$$}():$col_QMARK_$jscomp$8$$&&$space_around_QMARK_$jscomp$4$$&&$APP.$cljs$core$not$$($auto_height_QMARK_$jscomp$5$$)?
function(){var $y__5111__auto__$jscomp$102$$=($height$jscomp$118$$-$line_height$jscomp$12$$)/$num_children$jscomp$4$$;return $layout_gap_row$jscomp$8$$>$y__5111__auto__$jscomp$102$$?$layout_gap_row$jscomp$8$$:$y__5111__auto__$jscomp$102$$}()/2:$APP.$cljs$core$truth_$$(function(){if($col_QMARK_$jscomp$8$$){var $and__5023__auto____$1$jscomp$82$$=$space_evenly_QMARK_$jscomp$4$$||$space_around_QMARK_$jscomp$4$$;return $and__5023__auto____$1$jscomp$82$$?$auto_height_QMARK_$jscomp$5$$:$and__5023__auto____$1$jscomp$82$$}return $col_QMARK_$jscomp$8$$}())?
$layout_gap_row$jscomp$8$$:0]))};
$app$common$geom$shapes$flex_layout$layout_data$add_children_resizes$$=function($shape$jscomp$511$$,$map__68291__$1_p__68290$$){$map__68291__$1_p__68290$$=$APP.$cljs$core$__destructure_map$$($map__68291__$1_p__68290$$);var $line_min_width$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68291__$1_p__68290$$,$cljs$cst$3807$line_min_width$$),$line_width$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68291__$1_p__68290$$,$APP.$cljs$cst$3801$line_width$$),
$line_min_height$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68291__$1_p__68290$$,$cljs$cst$3808$line_min_height$$),$line_height$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68291__$1_p__68290$$,$APP.$cljs$cst$1765$line_height$$),$row_QMARK_$jscomp$9$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$511$$),$col_QMARK_$jscomp$9$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$511$$);
return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($map__68291__$1_p__68290$$,$cljs$cst$3811$children_data$$,function($G__68292__$1_G__68292__$2_G__68292__$3_G__68292__$4_children_data$jscomp$1$$){$G__68292__$1_G__68292__$2_G__68292__$3_G__68292__$4_children_data$jscomp$1$$=$row_QMARK_$jscomp$9$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68288_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__68288_SHARP_$$,$cljs$cst$3818$child_width$$,
$cljs$cst$3812$child_min_width$$.$cljs$core$IFn$_invoke$arity$1$($p1__68288_SHARP_$$))},$G__68292__$1_G__68292__$2_G__68292__$3_G__68292__$4_children_data$jscomp$1$$):$G__68292__$1_G__68292__$2_G__68292__$3_G__68292__$4_children_data$jscomp$1$$;$G__68292__$1_G__68292__$2_G__68292__$3_G__68292__$4_children_data$jscomp$1$$=$col_QMARK_$jscomp$9$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68289_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__68289_SHARP_$$,
$cljs$cst$3819$child_height$$,$cljs$cst$3813$child_min_height$$.$cljs$core$IFn$_invoke$arity$1$($p1__68289_SHARP_$$))},$G__68292__$1_G__68292__$2_G__68292__$3_G__68292__$4_children_data$jscomp$1$$):$G__68292__$1_G__68292__$2_G__68292__$3_G__68292__$4_children_data$jscomp$1$$;$G__68292__$1_G__68292__$2_G__68292__$3_G__68292__$4_children_data$jscomp$1$$=$row_QMARK_$jscomp$9$$?$app$common$geom$shapes$flex_layout$layout_data$distribute_space$$($cljs$cst$3818$child_width$$,$cljs$cst$3812$child_min_width$$,
$cljs$cst$3814$child_max_width$$,$line_min_width$jscomp$2$$,$line_width$jscomp$6$$,$G__68292__$1_G__68292__$2_G__68292__$3_G__68292__$4_children_data$jscomp$1$$):$G__68292__$1_G__68292__$2_G__68292__$3_G__68292__$4_children_data$jscomp$1$$;$G__68292__$1_G__68292__$2_G__68292__$3_G__68292__$4_children_data$jscomp$1$$=$col_QMARK_$jscomp$9$$?$app$common$geom$shapes$flex_layout$layout_data$distribute_space$$($cljs$cst$3819$child_height$$,$cljs$cst$3813$child_min_height$$,$cljs$cst$3815$child_max_height$$,
$line_min_height$jscomp$2$$,$line_height$jscomp$13$$,$G__68292__$1_G__68292__$2_G__68292__$3_G__68292__$4_children_data$jscomp$1$$):$G__68292__$1_G__68292__$2_G__68292__$3_G__68292__$4_children_data$jscomp$1$$;return $APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$G__68292__$1_G__68292__$2_G__68292__$3_G__68292__$4_children_data$jscomp$1$$)})};
$app$common$geom$shapes$flex_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$05$$=function($shape$jscomp$512$$,$shape_bounds$jscomp$3$$,$children$jscomp$229$$,$bounds$jscomp$48$$,$objects$jscomp$425$$){return $app$common$geom$shapes$flex_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$06$$($shape$jscomp$512$$,$shape_bounds$jscomp$3$$,$children$jscomp$229$$,$bounds$jscomp$48$$,$objects$jscomp$425$$,!1)};
$app$common$geom$shapes$flex_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$06$$=function($layout_lines$jscomp$1_shape$jscomp$513$$,$layout_bounds$jscomp$10_shape_bounds$jscomp$4$$,$children$jscomp$230_children__$1$jscomp$30_children__$2$jscomp$3$$,$bounds$jscomp$49$$,$objects$jscomp$426$$,$auto_QMARK_$jscomp$7$$){$layout_bounds$jscomp$10_shape_bounds$jscomp$4$$=$app$common$geom$shapes$flex_layout$layout_data$layout_bounds$$($layout_lines$jscomp$1_shape$jscomp$513$$,$layout_bounds$jscomp$10_shape_bounds$jscomp$4$$);
var $reverse_QMARK_$jscomp$5$$=$APP.$app$common$types$shape$layout$reverse_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($layout_lines$jscomp$1_shape$jscomp$513$$);$children$jscomp$230_children__$1$jscomp$30_children__$2$jscomp$3$$=$reverse_QMARK_$jscomp$5$$?$children$jscomp$230_children__$1$jscomp$30_children__$2$jscomp$3$$:$APP.$cljs$core$reverse$$($children$jscomp$230_children__$1$jscomp$30_children__$2$jscomp$3$$);$children$jscomp$230_children__$1$jscomp$30_children__$2$jscomp$3$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($child$jscomp$101_p__68296$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$101_p__68296$$,
0,null);$child$jscomp$101_p__68296$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$101_p__68296$$,1,null);return $APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$101_p__68296$$)},$children$jscomp$230_children__$1$jscomp$30_children__$2$jscomp$3$$);$layout_lines$jscomp$1_shape$jscomp$513$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$common$geom$shapes$flex_layout$layout_data$add_line_spacing$$,
$layout_lines$jscomp$1_shape$jscomp$513$$,$layout_bounds$jscomp$10_shape_bounds$jscomp$4$$,$auto_QMARK_$jscomp$7$$)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$geom$shapes$flex_layout$layout_data$add_children_resizes$$,$layout_lines$jscomp$1_shape$jscomp$513$$))),$app$common$geom$shapes$flex_layout$layout_data$add_lines_positions$$($layout_lines$jscomp$1_shape$jscomp$513$$,$layout_bounds$jscomp$10_shape_bounds$jscomp$4$$,
$auto_QMARK_$jscomp$7$$,$app$common$geom$shapes$flex_layout$layout_data$init_layout_lines$$($layout_lines$jscomp$1_shape$jscomp$513$$,$children$jscomp$230_children__$1$jscomp$30_children__$2$jscomp$3$$,$layout_bounds$jscomp$10_shape_bounds$jscomp$4$$,$bounds$jscomp$49$$,$objects$jscomp$426$$,$auto_QMARK_$jscomp$7$$)));return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3055$layout_lines$$,$layout_lines$jscomp$1_shape$jscomp$513$$,$APP.$cljs$cst$3666$layout_bounds$$,$layout_bounds$jscomp$10_shape_bounds$jscomp$4$$,
$cljs$cst$3820$reverse_QMARK_$$,$reverse_QMARK_$jscomp$5$$],null)};
$app$common$geom$shapes$flex_layout$drop_area$drop_line_area$$=function($map__68319__$1_p__68317$$,$layout_gap_row$jscomp$10_p__68318$$,$prev_x$jscomp$1_width$jscomp$134$$,$height$jscomp$120_prev_y$jscomp$1$$,$last_QMARK_$jscomp$2$$){$map__68319__$1_p__68317$$=$APP.$cljs$core$__destructure_map$$($map__68319__$1_p__68317$$);var $start_p__$1$jscomp$2_transform_inverse$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68319__$1_p__68317$$,$APP.$cljs$cst$1787$transform_inverse$$),
$line_width__$1$jscomp$1_margin_x$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68319__$1_p__68317$$,$cljs$cst$3805$margin_x$$),$line_height__$1$jscomp$3_margin_y$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68319__$1_p__68317$$,$cljs$cst$3806$margin_y$$),$col_QMARK_$jscomp$11_map__68320__$1$$=$APP.$cljs$core$__destructure_map$$($layout_gap_row$jscomp$10_p__68318$$),$start_p$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($col_QMARK_$jscomp$11_map__68320__$1$$,
$APP.$cljs$cst$3663$start_p$$);$layout_gap_row$jscomp$10_p__68318$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($col_QMARK_$jscomp$11_map__68320__$1$$,$APP.$cljs$cst$3803$layout_gap_row$$);var $layout_gap_col$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($col_QMARK_$jscomp$11_map__68320__$1$$,$APP.$cljs$cst$3804$layout_gap_col$$),$box_x$jscomp$1_num_children$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($col_QMARK_$jscomp$11_map__68320__$1$$,$APP.$cljs$cst$3802$num_children$$),
$line_width$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($col_QMARK_$jscomp$11_map__68320__$1$$,$APP.$cljs$cst$3801$line_width$$),$line_height$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($col_QMARK_$jscomp$11_map__68320__$1$$,$APP.$cljs$cst$1765$line_height$$);$col_QMARK_$jscomp$11_map__68320__$1$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__68319__$1_p__68317$$);var $row_QMARK_$jscomp$11$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($map__68319__$1_p__68317$$),
$box_y$jscomp$1_h_center_QMARK_$jscomp$3$$=$row_QMARK_$jscomp$11$$&&$app$common$types$shape$layout$h_center_QMARK_$$($map__68319__$1_p__68317$$),$h_end_QMARK_$jscomp$3$$=$row_QMARK_$jscomp$11$$&&$app$common$types$shape$layout$h_end_QMARK_$$($map__68319__$1_p__68317$$),$v_center_QMARK_$jscomp$3_x$jscomp$1192$$=$col_QMARK_$jscomp$11_map__68320__$1$$&&$app$common$types$shape$layout$v_center_QMARK_$$($map__68319__$1_p__68317$$),$v_end_QMARK_$jscomp$3_y$jscomp$428$$=$col_QMARK_$jscomp$11_map__68320__$1$$&&
$app$common$types$shape$layout$v_end_QMARK_$$($map__68319__$1_p__68317$$),$center$jscomp$42$$=$APP.$app$common$geom$shapes$common$shape__GT_center$$($map__68319__$1_p__68317$$);$start_p__$1$jscomp$2_transform_inverse$jscomp$19$$=$APP.$app$common$geom$matrix$transform_point_center$$($start_p$jscomp$8$$,$center$jscomp$42$$,$start_p__$1$jscomp$2_transform_inverse$jscomp$19$$);$line_width__$1$jscomp$1_margin_x$jscomp$2$$=$row_QMARK_$jscomp$11$$?$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($map__68319__$1_p__68317$$):
$line_width$jscomp$7$$+$line_width__$1$jscomp$1_margin_x$jscomp$2$$+($row_QMARK_$jscomp$11$$?$layout_gap_col$jscomp$10$$*($box_x$jscomp$1_num_children$jscomp$5$$-1):0);$line_height__$1$jscomp$3_margin_y$jscomp$2$$=$col_QMARK_$jscomp$11_map__68320__$1$$?$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($map__68319__$1_p__68317$$):$line_height$jscomp$14$$+$line_height__$1$jscomp$3_margin_y$jscomp$2$$+($col_QMARK_$jscomp$11_map__68320__$1$$?$layout_gap_row$jscomp$10_p__68318$$*($box_x$jscomp$1_num_children$jscomp$5$$-
1):0);$box_x$jscomp$1_num_children$jscomp$5$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($start_p__$1$jscomp$2_transform_inverse$jscomp$19$$)-($box_y$jscomp$1_h_center_QMARK_$jscomp$3$$?$line_width__$1$jscomp$1_margin_x$jscomp$2$$/2:$h_end_QMARK_$jscomp$3$$?$line_width__$1$jscomp$1_margin_x$jscomp$2$$:0);$box_y$jscomp$1_h_center_QMARK_$jscomp$3$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($start_p__$1$jscomp$2_transform_inverse$jscomp$19$$)-($v_center_QMARK_$jscomp$3_x$jscomp$1192$$?
$line_height__$1$jscomp$3_margin_y$jscomp$2$$/2:$v_end_QMARK_$jscomp$3_y$jscomp$428$$?$line_height__$1$jscomp$3_margin_y$jscomp$2$$:0);$v_center_QMARK_$jscomp$3_x$jscomp$1192$$=$row_QMARK_$jscomp$11$$?$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($map__68319__$1_p__68317$$):$prev_x$jscomp$1_width$jscomp$134$$;$v_end_QMARK_$jscomp$3_y$jscomp$428$$=$col_QMARK_$jscomp$11_map__68320__$1$$?$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($map__68319__$1_p__68317$$):$height$jscomp$120_prev_y$jscomp$1$$;
$prev_x$jscomp$1_width$jscomp$134$$=$APP.$cljs$core$truth_$$($col_QMARK_$jscomp$11_map__68320__$1$$?$last_QMARK_$jscomp$2$$:$col_QMARK_$jscomp$11_map__68320__$1$$)?$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($map__68319__$1_p__68317$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($map__68319__$1_p__68317$$)-$v_center_QMARK_$jscomp$3_x$jscomp$1192$$:$row_QMARK_$jscomp$11$$?$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($map__68319__$1_p__68317$$):$line_width__$1$jscomp$1_margin_x$jscomp$2$$+
($box_x$jscomp$1_num_children$jscomp$5$$-$prev_x$jscomp$1_width$jscomp$134$$)+$layout_gap_col$jscomp$10$$/2;$height$jscomp$120_prev_y$jscomp$1$$=$APP.$cljs$core$truth_$$($row_QMARK_$jscomp$11$$?$last_QMARK_$jscomp$2$$:$row_QMARK_$jscomp$11$$)?$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($map__68319__$1_p__68317$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($map__68319__$1_p__68317$$)-$v_end_QMARK_$jscomp$3_y$jscomp$428$$:$col_QMARK_$jscomp$11_map__68320__$1$$?$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($map__68319__$1_p__68317$$):
$line_height__$1$jscomp$3_margin_y$jscomp$2$$+($box_y$jscomp$1_h_center_QMARK_$jscomp$3$$-$height$jscomp$120_prev_y$jscomp$1$$)+$layout_gap_row$jscomp$10_p__68318$$/2;return $APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($v_center_QMARK_$jscomp$3_x$jscomp$1192$$,$v_end_QMARK_$jscomp$3_y$jscomp$428$$,$prev_x$jscomp$1_width$jscomp$134$$,$height$jscomp$120_prev_y$jscomp$1$$)};
$app$common$geom$shapes$flex_layout$drop_area$layout_drop_areas$$=function($frame$jscomp$25$$,$G__68369_from_idx$jscomp$3_layout_data$jscomp$9$$,$children$jscomp$231$$){var $reverse_QMARK_$jscomp$7$$=$cljs$cst$3820$reverse_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__68369_from_idx$jscomp$3_layout_data$jscomp$9$$),$children__$1$jscomp$31$$=$APP.$cljs$core$vec$$(function(){var $G__68323$$=$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($children$jscomp$231$$);return $APP.$cljs$core$not$$($reverse_QMARK_$jscomp$7$$)?
$APP.$cljs$core$reverse$$($G__68323$$):$G__68323$$}()),$G__68372_lines$jscomp$5_lines__$1$jscomp$1$$=$APP.$cljs$cst$3055$layout_lines$$.$cljs$core$IFn$_invoke$arity$1$($G__68369_from_idx$jscomp$3_layout_data$jscomp$9$$),$areas$$=$APP.$cljs$core$PersistentVector$EMPTY$$;$G__68369_from_idx$jscomp$3_layout_data$jscomp$9$$=0;var $G__68368_prev_line_x$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$25$$),$G__68371_prev_line_y$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$25$$);
for($G__68372_lines$jscomp$5_lines__$1$jscomp$1$$=$APP.$cljs$core$seq$$($G__68372_lines$jscomp$5_lines__$1$jscomp$1$$);;){if($APP.$cljs$core$empty_QMARK_$$($G__68372_lines$jscomp$5_lines__$1$jscomp$1$$))return $areas$$;var $G__68370_current_line$$=$APP.$cljs$core$first$$($G__68372_lines$jscomp$5_lines__$1$jscomp$1$$),$line_area$$=$app$common$geom$shapes$flex_layout$drop_area$drop_line_area$$($frame$jscomp$25$$,$G__68370_current_line$$,$G__68368_prev_line_x$$,$G__68371_prev_line_y$$,$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$rest$$($G__68372_lines$jscomp$5_lines__$1$jscomp$1$$))),
$children__$2$jscomp$4$$=$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($children__$1$jscomp$31$$,$G__68369_from_idx$jscomp$3_layout_data$jscomp$9$$,$G__68369_from_idx$jscomp$3_layout_data$jscomp$9$$+$APP.$cljs$cst$3802$num_children$$.$cljs$core$IFn$_invoke$arity$1$($G__68370_current_line$$));$G__68368_prev_line_x$$=function(){for(var $G__68364_areas__$1$$=$areas$$,$half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$=
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($line_area$$),$prev_child_y_prev_y$jscomp$inline_12555$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($line_area$$),$G__68367_children__$3$$=$APP.$cljs$core$seq$$($children__$2$jscomp$4$$);;){if($APP.$cljs$core$empty_QMARK_$$($G__68367_children__$3$$))return $G__68364_areas__$1$$;var $G__68365_child_area_start_child_bounds$jscomp$20_reverse_QMARK_$jscomp$inline_12553_vec__68342$$=$APP.$cljs$core$first$$($G__68367_children__$3$$),$G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__68365_child_area_start_child_bounds$jscomp$20_reverse_QMARK_$jscomp$inline_12553_vec__68342$$,0,null),$child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__68365_child_area_start_child_bounds$jscomp$20_reverse_QMARK_$jscomp$inline_12553_vec__68342$$,1,null);$G__68365_child_area_start_child_bounds$jscomp$20_reverse_QMARK_$jscomp$inline_12553_vec__68342$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$,1,null);var $frame$jscomp$inline_12549_layout_gap_row$jscomp$inline_12560$$=$frame$jscomp$25$$;$child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$=
$line_area$$;var $child_bounds$jscomp$inline_12551_x$jscomp$inline_12567$$=$G__68365_child_area_start_child_bounds$jscomp$20_reverse_QMARK_$jscomp$inline_12553_vec__68342$$;$G__68365_child_area_start_child_bounds$jscomp$20_reverse_QMARK_$jscomp$inline_12553_vec__68342$$=$APP.$cljs$core$not$$($reverse_QMARK_$jscomp$7$$);var $prev_x$jscomp$inline_12554_width$jscomp$inline_12569$$=$half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$,
$last_QMARK_$jscomp$inline_12556$$=$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$rest$$($G__68367_children__$3$$)),$col_QMARK_$jscomp$inline_12557$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$inline_12549_layout_gap_row$jscomp$inline_12560$$);$half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($frame$jscomp$inline_12549_layout_gap_row$jscomp$inline_12560$$);
var $box_x$jscomp$inline_12563_vec__68303$jscomp$inline_12559$$=$APP.$app$common$types$shape$layout$gaps$$($frame$jscomp$inline_12549_layout_gap_row$jscomp$inline_12560$$);$frame$jscomp$inline_12549_layout_gap_row$jscomp$inline_12560$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($box_x$jscomp$inline_12563_vec__68303$jscomp$inline_12559$$,0,null);var $layout_gap_col$jscomp$inline_12561$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($box_x$jscomp$inline_12563_vec__68303$jscomp$inline_12559$$,
1,null),$start_p$jscomp$inline_12562_y$jscomp$inline_12568$$=$APP.$app$common$geom$shapes$points$origin$$($child_bounds$jscomp$inline_12551_x$jscomp$inline_12567$$);$box_x$jscomp$inline_12563_vec__68303$jscomp$inline_12559$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$inline_12562_y$jscomp$inline_12568$$);var $box_y$jscomp$inline_12564$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$inline_12562_y$jscomp$inline_12568$$),$box_width$jscomp$inline_12565$$=
$APP.$app$common$geom$shapes$points$width_points$$($child_bounds$jscomp$inline_12551_x$jscomp$inline_12567$$),$box_height$jscomp$inline_12566$$=$APP.$app$common$geom$shapes$points$height_points$$($child_bounds$jscomp$inline_12551_x$jscomp$inline_12567$$);$child_bounds$jscomp$inline_12551_x$jscomp$inline_12567$$=$col_QMARK_$jscomp$inline_12557$$?$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$):
$prev_x$jscomp$inline_12554_width$jscomp$inline_12569$$;$start_p$jscomp$inline_12562_y$jscomp$inline_12568$$=$half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$?$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$):$prev_child_y_prev_y$jscomp$inline_12555$$;$prev_x$jscomp$inline_12554_width$jscomp$inline_12569$$=$APP.$cljs$core$truth_$$($half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$?
$last_QMARK_$jscomp$inline_12556$$:$half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$)?$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$)-$child_bounds$jscomp$inline_12551_x$jscomp$inline_12567$$:
$col_QMARK_$jscomp$inline_12557$$?$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$):$box_width$jscomp$inline_12565$$+($box_x$jscomp$inline_12563_vec__68303$jscomp$inline_12559$$-$prev_x$jscomp$inline_12554_width$jscomp$inline_12569$$)+$layout_gap_col$jscomp$inline_12561$$/2;$child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$=$APP.$cljs$core$truth_$$($col_QMARK_$jscomp$inline_12557$$?
$last_QMARK_$jscomp$inline_12556$$:$col_QMARK_$jscomp$inline_12557$$)?$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$)-$start_p$jscomp$inline_12562_y$jscomp$inline_12568$$:$half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$?
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$):$box_height$jscomp$inline_12566$$+($box_y$jscomp$inline_12564$$-$prev_child_y_prev_y$jscomp$inline_12555$$)+$frame$jscomp$inline_12549_layout_gap_row$jscomp$inline_12560$$/2;$half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$?($half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$=
$box_x$jscomp$inline_12563_vec__68303$jscomp$inline_12559$$-$child_bounds$jscomp$inline_12551_x$jscomp$inline_12567$$+$box_width$jscomp$inline_12565$$/2,$child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($child_bounds$jscomp$inline_12551_x$jscomp$inline_12567$$,$start_p$jscomp$inline_12562_y$jscomp$inline_12568$$,
$prev_x$jscomp$inline_12554_width$jscomp$inline_12569$$,$child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($child_bounds$jscomp$inline_12551_x$jscomp$inline_12567$$,$start_p$jscomp$inline_12562_y$jscomp$inline_12568$$,$half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$,
$child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$),$APP.$cljs$cst$1795$index$$,$APP.$cljs$core$truth_$$($G__68365_child_area_start_child_bounds$jscomp$20_reverse_QMARK_$jscomp$inline_12553_vec__68342$$)?$G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$+1:$G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($child_bounds$jscomp$inline_12551_x$jscomp$inline_12567$$+
$half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$,$start_p$jscomp$inline_12562_y$jscomp$inline_12568$$,$prev_x$jscomp$inline_12554_width$jscomp$inline_12569$$-$half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$,$child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$),$APP.$cljs$cst$1795$index$$,$APP.$cljs$core$truth_$$($G__68365_child_area_start_child_bounds$jscomp$20_reverse_QMARK_$jscomp$inline_12553_vec__68342$$)?
$G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$:$G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$+1)],null)):($half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$=$box_y$jscomp$inline_12564$$-$start_p$jscomp$inline_12562_y$jscomp$inline_12568$$+$box_height$jscomp$inline_12566$$/2,$child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$=new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($child_bounds$jscomp$inline_12551_x$jscomp$inline_12567$$,$start_p$jscomp$inline_12562_y$jscomp$inline_12568$$,$prev_x$jscomp$inline_12554_width$jscomp$inline_12569$$,$child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($child_bounds$jscomp$inline_12551_x$jscomp$inline_12567$$,
$start_p$jscomp$inline_12562_y$jscomp$inline_12568$$,$prev_x$jscomp$inline_12554_width$jscomp$inline_12569$$,$half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$),$APP.$cljs$cst$1795$index$$,$APP.$cljs$core$truth_$$($G__68365_child_area_start_child_bounds$jscomp$20_reverse_QMARK_$jscomp$inline_12553_vec__68342$$)?$G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$+1:$G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$),
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($child_bounds$jscomp$inline_12551_x$jscomp$inline_12567$$,$start_p$jscomp$inline_12562_y$jscomp$inline_12568$$+$half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$,$prev_x$jscomp$inline_12554_width$jscomp$inline_12569$$,$child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$-
$half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$),$APP.$cljs$cst$1795$index$$,$APP.$cljs$core$truth_$$($G__68365_child_area_start_child_bounds$jscomp$20_reverse_QMARK_$jscomp$inline_12553_vec__68342$$)?$G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$:$G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$+1)],null));$G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$,
0,null);$G__68365_child_area_start_child_bounds$jscomp$20_reverse_QMARK_$jscomp$inline_12553_vec__68342$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$,1,null);$child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$,
2,null);$G__68364_areas__$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($G__68364_areas__$1$$,$G__68365_child_area_start_child_bounds$jscomp$20_reverse_QMARK_$jscomp$inline_12553_vec__68342$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$child_area_end_height$jscomp$inline_12570_parent_rect$jscomp$inline_12550_vec__68345_vec__68348$$]));$G__68365_child_area_start_child_bounds$jscomp$20_reverse_QMARK_$jscomp$inline_12553_vec__68342$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$)+
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$);$G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$);$G__68367_children__$3$$=$APP.$cljs$core$rest$$($G__68367_children__$3$$);
$half_point_height$jscomp$inline_12572_half_point_width$jscomp$inline_12571_prev_child_x_row_QMARK_$jscomp$inline_12558$$=$G__68365_child_area_start_child_bounds$jscomp$20_reverse_QMARK_$jscomp$inline_12553_vec__68342$$;$prev_child_y_prev_y$jscomp$inline_12555$$=$G__68366_child_area_index$jscomp$286_index$jscomp$inline_12552$$}}();$G__68369_from_idx$jscomp$3_layout_data$jscomp$9$$+=$APP.$cljs$cst$3802$num_children$$.$cljs$core$IFn$_invoke$arity$1$($G__68370_current_line$$);$G__68370_current_line$$=
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($line_area$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($line_area$$);$G__68371_prev_line_y$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($line_area$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($line_area$$);$G__68372_lines$jscomp$5_lines__$1$jscomp$1$$=$APP.$cljs$core$rest$$($G__68372_lines$jscomp$5_lines__$1$jscomp$1$$);$areas$$=$G__68368_prev_line_x$$;$G__68368_prev_line_x$$=$G__68370_current_line$$}};
$app$common$geom$shapes$flex_layout$drop_area$get_flip_modifiers$$=function($map__68353__$1_p__68352$$){$map__68353__$1_p__68352$$=$APP.$cljs$core$__destructure_map$$($map__68353__$1_p__68352$$);var $flip_x$jscomp$7_modifiers$jscomp$49$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68353__$1_p__68352$$,$APP.$cljs$cst$1879$flip_x$$),$flip_y$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68353__$1_p__68352$$,$APP.$cljs$cst$1880$flip_y$$),$transform$jscomp$93$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68353__$1_p__68352$$,$APP.$cljs$cst$1289$transform$$),$transform_inverse$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68353__$1_p__68352$$,$APP.$cljs$cst$1787$transform_inverse$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($flip_x$jscomp$7_modifiers$jscomp$49$$)?$flip_x$jscomp$7_modifiers$jscomp$49$$:$flip_y$jscomp$7$$)?($flip_x$jscomp$7_modifiers$jscomp$49$$=$APP.$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$app$common$types$modifiers$empty$$(),
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($flip_x$jscomp$7_modifiers$jscomp$49$$)?-1:1,$APP.$cljs$core$truth_$$($flip_y$jscomp$7$$)?-1:1),$APP.$app$common$geom$shapes$common$shape__GT_center$$($map__68353__$1_p__68352$$),$transform$jscomp$93$$,$transform_inverse$jscomp$20$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$geom$shapes$transforms$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($map__68353__$1_p__68352$$,
$flip_x$jscomp$7_modifiers$jscomp$49$$),$flip_x$jscomp$7_modifiers$jscomp$49$$],null)):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$map__68353__$1_p__68352$$,null],null)};
$APP.$app$common$geom$shapes$flex_layout$drop_area$get_drop_areas$$=function($children$jscomp$232_frame$jscomp$26_vec__68356$$,$layout_data$jscomp$10_objects$jscomp$427$$,$bounds$jscomp$50$$){$children$jscomp$232_frame$jscomp$26_vec__68356$$=$app$common$geom$shapes$flex_layout$drop_area$get_flip_modifiers$$($children$jscomp$232_frame$jscomp$26_vec__68356$$);var $frame__$1$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$232_frame$jscomp$26_vec__68356$$,0,null),
$modifiers$jscomp$50$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$232_frame$jscomp$26_vec__68356$$,1,null);$children$jscomp$232_frame$jscomp$26_vec__68356$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68355_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($p1__68355_SHARP_$$),
$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$2$$)),$p1__68355_SHARP_$$],null)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68354_SHARP_$$){return $modifiers$jscomp$50$$!=null?$app$common$geom$shapes$transforms$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($p1__68354_SHARP_$$,$modifiers$jscomp$50$$):$p1__68354_SHARP_$$},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($layout_data$jscomp$10_objects$jscomp$427$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$2$$)))));$layout_data$jscomp$10_objects$jscomp$427$$=$app$common$geom$shapes$flex_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$05$$($frame__$1$jscomp$2$$,$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$2$$),$children$jscomp$232_frame$jscomp$26_vec__68356$$,$bounds$jscomp$50$$,$layout_data$jscomp$10_objects$jscomp$427$$);return $app$common$geom$shapes$flex_layout$drop_area$layout_drop_areas$$($frame__$1$jscomp$2$$,
$layout_data$jscomp$10_objects$jscomp$427$$,$children$jscomp$232_frame$jscomp$26_vec__68356$$)};
$app$common$geom$shapes$flex_layout$drop_area$get_drop_index$$=function($frame$jscomp$27_frame_id$jscomp$80$$,$objects$jscomp$428$$,$area$jscomp$2_position$jscomp$84$$){$frame$jscomp$27_frame_id$jscomp$80$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$428$$,$frame$jscomp$27_frame_id$jscomp$80$$);var $bounds$jscomp$51_drop_areas$jscomp$1$$=$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$428$$),function($p1__68360_SHARP_$$){return $app$common$geom$shapes$common$shape__GT_points$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$428$$,
$p1__68360_SHARP_$$))});$bounds$jscomp$51_drop_areas$jscomp$1$$=$APP.$app$common$geom$shapes$flex_layout$drop_area$get_drop_areas$$($frame$jscomp$27_frame_id$jscomp$80$$,$objects$jscomp$428$$,$bounds$jscomp$51_drop_areas$jscomp$1$$);var $position__$1$jscomp$2$$=$APP.$app$common$geom$matrix$transform_point_center$$($area$jscomp$2_position$jscomp$84$$,$APP.$app$common$geom$shapes$common$shape__GT_center$$($frame$jscomp$27_frame_id$jscomp$80$$),$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$27_frame_id$jscomp$80$$));
$area$jscomp$2_position$jscomp$84$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__68361_SHARP_$$){return $app$common$geom$rect$contains_point_QMARK_$$($p1__68361_SHARP_$$,$position__$1$jscomp$2$$)},$bounds$jscomp$51_drop_areas$jscomp$1$$);return $APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($area$jscomp$2_position$jscomp$84$$)};
$app$common$geom$shapes$flex_layout$modifiers$calc_fill_width_data$$=function($parent$jscomp$250_target_width$jscomp$2_target_width__$1$jscomp$1$$,$transform$jscomp$94$$,$transform_inverse$jscomp$21$$,$child$jscomp$102$$,$child_origin$jscomp$4$$,$child_width$jscomp$6$$,$map__68126__$1_max_width$jscomp$7_p__68125$$){$map__68126__$1_max_width$jscomp$7_p__68125$$=$APP.$cljs$core$__destructure_map$$($map__68126__$1_max_width$jscomp$7_p__68125$$);var $children_data$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68126__$1_max_width$jscomp$7_p__68125$$,
$cljs$cst$3811$children_data$$),$line_width$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68126__$1_max_width$jscomp$7_p__68125$$,$APP.$cljs$cst$3801$line_width$$),$to_bound_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68126__$1_max_width$jscomp$7_p__68125$$,$cljs$cst$3817$to_bound_width$$);if($APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$250_target_width$jscomp$2_target_width__$1$jscomp$1$$))return $parent$jscomp$250_target_width$jscomp$2_target_width__$1$jscomp$1$$=
function(){var $x__5110__auto__$jscomp$107$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($children_data$jscomp$2$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$102$$),$cljs$cst$3818$child_width$$],null));return $x__5110__auto__$jscomp$107$$>.01?$x__5110__auto__$jscomp$107$$:.01}(),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,$parent$jscomp$250_target_width$jscomp$2_target_width__$1$jscomp$1$$,
$APP.$cljs$cst$1810$modifiers$$,$APP.$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$250_target_width$jscomp$2_target_width__$1$jscomp$1$$/$child_width$jscomp$6$$,1),$child_origin$jscomp$4$$,$transform$jscomp$94$$,$transform_inverse$jscomp$21$$)],null);if($APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$250_target_width$jscomp$2_target_width__$1$jscomp$1$$)){var $line_width__$1$jscomp$2$$=
function(){var $y__5114__auto__$jscomp$51$$=$APP.$cljs$core$truth_$$($to_bound_width$$)?$to_bound_width$$:$line_width$jscomp$8$$;return $line_width$jscomp$8$$<$y__5114__auto__$jscomp$51$$?$line_width$jscomp$8$$:$y__5114__auto__$jscomp$51$$}();$parent$jscomp$250_target_width$jscomp$2_target_width__$1$jscomp$1$$=function(){var $x__5110__auto__$jscomp$108$$=$line_width__$1$jscomp$2$$-$app$common$types$shape$layout$child_width_margin$$($child$jscomp$102$$);return $x__5110__auto__$jscomp$108$$>.01?$x__5110__auto__$jscomp$108$$:
.01}();$map__68126__$1_max_width$jscomp$7_p__68125$$=function(){var $x__5110__auto__$jscomp$109$$=$app$common$types$shape$layout$child_max_width$$($child$jscomp$102$$);return $x__5110__auto__$jscomp$109$$>.01?$x__5110__auto__$jscomp$109$$:.01}();var $child_min_width$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($children_data$jscomp$2$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$102$$),
$cljs$cst$3812$child_min_width$$],null));$parent$jscomp$250_target_width$jscomp$2_target_width__$1$jscomp$1$$=$APP.$app$common$math$clamp$$($parent$jscomp$250_target_width$jscomp$2_target_width__$1$jscomp$1$$,$child_min_width$$,$map__68126__$1_max_width$jscomp$7_p__68125$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,$parent$jscomp$250_target_width$jscomp$2_target_width__$1$jscomp$1$$,$APP.$cljs$cst$1810$modifiers$$,$APP.$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$250_target_width$jscomp$2_target_width__$1$jscomp$1$$/
$child_width$jscomp$6$$,1),$child_origin$jscomp$4$$,$transform$jscomp$94$$,$transform_inverse$jscomp$21$$)],null)}return null};
$app$common$geom$shapes$flex_layout$modifiers$calc_fill_height_data$$=function($parent$jscomp$251_target_height$jscomp$2_target_height__$1$jscomp$1$$,$transform$jscomp$95$$,$transform_inverse$jscomp$22$$,$child$jscomp$103$$,$child_origin$jscomp$5$$,$child_height$jscomp$6$$,$map__68148__$1_max_height$jscomp$2_p__68146$$){$map__68148__$1_max_height$jscomp$2_p__68146$$=$APP.$cljs$core$__destructure_map$$($map__68148__$1_max_height$jscomp$2_p__68146$$);var $children_data$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68148__$1_max_height$jscomp$2_p__68146$$,
$cljs$cst$3811$children_data$$),$line_height$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68148__$1_max_height$jscomp$2_p__68146$$,$APP.$cljs$cst$1765$line_height$$),$to_bound_height$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68148__$1_max_height$jscomp$2_p__68146$$,$cljs$cst$3816$to_bound_height$$);if($APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$251_target_height$jscomp$2_target_height__$1$jscomp$1$$))return $parent$jscomp$251_target_height$jscomp$2_target_height__$1$jscomp$1$$=
function(){var $x__5110__auto__$jscomp$110$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($children_data$jscomp$3$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$103$$),$cljs$cst$3819$child_height$$],null));return $x__5110__auto__$jscomp$110$$>.01?$x__5110__auto__$jscomp$110$$:.01}(),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1522$height$$,$parent$jscomp$251_target_height$jscomp$2_target_height__$1$jscomp$1$$,
$APP.$cljs$cst$1810$modifiers$$,$APP.$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,$parent$jscomp$251_target_height$jscomp$2_target_height__$1$jscomp$1$$/$child_height$jscomp$6$$),$child_origin$jscomp$5$$,$transform$jscomp$95$$,$transform_inverse$jscomp$22$$)],null);if($APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$251_target_height$jscomp$2_target_height__$1$jscomp$1$$)){var $line_height__$1$jscomp$4$$=
function(){var $y__5114__auto__$jscomp$52$$=$APP.$cljs$core$truth_$$($to_bound_height$$)?$to_bound_height$$:$line_height$jscomp$15$$;return $line_height$jscomp$15$$<$y__5114__auto__$jscomp$52$$?$line_height$jscomp$15$$:$y__5114__auto__$jscomp$52$$}();$parent$jscomp$251_target_height$jscomp$2_target_height__$1$jscomp$1$$=function(){var $x__5110__auto__$jscomp$111$$=$line_height__$1$jscomp$4$$-$app$common$types$shape$layout$child_height_margin$$($child$jscomp$103$$);return $x__5110__auto__$jscomp$111$$>
.01?$x__5110__auto__$jscomp$111$$:.01}();$map__68148__$1_max_height$jscomp$2_p__68146$$=function(){var $x__5110__auto__$jscomp$112$$=$app$common$types$shape$layout$child_max_height$$($child$jscomp$103$$);return $x__5110__auto__$jscomp$112$$>.01?$x__5110__auto__$jscomp$112$$:.01}();var $child_min_height$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($children_data$jscomp$3$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$103$$),
$cljs$cst$3813$child_min_height$$],null));$parent$jscomp$251_target_height$jscomp$2_target_height__$1$jscomp$1$$=$APP.$app$common$math$clamp$$($parent$jscomp$251_target_height$jscomp$2_target_height__$1$jscomp$1$$,$child_min_height$$,$map__68148__$1_max_height$jscomp$2_p__68146$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1522$height$$,$parent$jscomp$251_target_height$jscomp$2_target_height__$1$jscomp$1$$,$APP.$cljs$cst$1810$modifiers$$,$APP.$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,
$parent$jscomp$251_target_height$jscomp$2_target_height__$1$jscomp$1$$/$child_height$jscomp$6$$),$child_origin$jscomp$5$$,$transform$jscomp$95$$,$transform_inverse$jscomp$22$$)],null)}return null};
$app$common$geom$shapes$flex_layout$modifiers$fill_modifiers$$=function($child_width__$1$jscomp$1_parent$jscomp$252$$,$parent_bounds$jscomp$14_transform$jscomp$96$$,$child$jscomp$104_child_height__$1$jscomp$1$$,$child_bounds$jscomp$21_transform_inverse$jscomp$23_vec__68158$$,$layout_line$jscomp$1$$){var $child_origin$jscomp$6$$=$APP.$app$common$geom$shapes$points$origin$$($child_bounds$jscomp$21_transform_inverse$jscomp$23_vec__68158$$),$child_width$jscomp$7$$=$APP.$app$common$geom$shapes$points$width_points$$($child_bounds$jscomp$21_transform_inverse$jscomp$23_vec__68158$$),
$child_height$jscomp$7$$=$APP.$app$common$geom$shapes$points$height_points$$($child_bounds$jscomp$21_transform_inverse$jscomp$23_vec__68158$$);$child_bounds$jscomp$21_transform_inverse$jscomp$23_vec__68158$$=$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$104_child_height__$1$jscomp$1$$)||$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$104_child_height__$1$jscomp$1$$)?$app$common$geom$shapes$transforms$calculate_geometry$$($APP.$cljs$core$_deref$$($parent_bounds$jscomp$14_transform$jscomp$96$$)):
null;$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_bounds$jscomp$21_transform_inverse$jscomp$23_vec__68158$$,0,null);$parent_bounds$jscomp$14_transform$jscomp$96$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_bounds$jscomp$21_transform_inverse$jscomp$23_vec__68158$$,1,null);$child_bounds$jscomp$21_transform_inverse$jscomp$23_vec__68158$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_bounds$jscomp$21_transform_inverse$jscomp$23_vec__68158$$,2,
null);var $fill_width$jscomp$1$$=$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$104_child_height__$1$jscomp$1$$)?$app$common$geom$shapes$flex_layout$modifiers$calc_fill_width_data$$($child_width__$1$jscomp$1_parent$jscomp$252$$,$parent_bounds$jscomp$14_transform$jscomp$96$$,$child_bounds$jscomp$21_transform_inverse$jscomp$23_vec__68158$$,$child$jscomp$104_child_height__$1$jscomp$1$$,$child_origin$jscomp$6$$,$child_width$jscomp$7$$,$layout_line$jscomp$1$$):
null,$fill_height$jscomp$1$$=$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$104_child_height__$1$jscomp$1$$)?$app$common$geom$shapes$flex_layout$modifiers$calc_fill_height_data$$($child_width__$1$jscomp$1_parent$jscomp$252$$,$parent_bounds$jscomp$14_transform$jscomp$96$$,$child_bounds$jscomp$21_transform_inverse$jscomp$23_vec__68158$$,$child$jscomp$104_child_height__$1$jscomp$1$$,$child_origin$jscomp$6$$,$child_height$jscomp$7$$,$layout_line$jscomp$1$$):
null;$child_width__$1$jscomp$1_parent$jscomp$252$$=function(){var $or__5025__auto__$jscomp$765$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($fill_width$jscomp$1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$765$$)?$or__5025__auto__$jscomp$765$$:$child_width$jscomp$7$$}();$child$jscomp$104_child_height__$1$jscomp$1$$=function(){var $or__5025__auto__$jscomp$766$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($fill_height$jscomp$1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$766$$)?
$or__5025__auto__$jscomp$766$$:$child_height$jscomp$7$$}();return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$child_width__$1$jscomp$1_parent$jscomp$252$$,$child$jscomp$104_child_height__$1$jscomp$1$$,function(){var $G__68164_G__68165$jscomp$inline_6701$$=$APP.$app$common$types$modifiers$empty$$();$G__68164_G__68165$jscomp$inline_6701$$=$APP.$cljs$core$truth_$$($fill_width$jscomp$1$$)?$app$common$types$modifiers$add_modifiers$$($G__68164_G__68165$jscomp$inline_6701$$,
$APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($fill_width$jscomp$1$$)):$G__68164_G__68165$jscomp$inline_6701$$;return $APP.$cljs$core$truth_$$($fill_height$jscomp$1$$)?$app$common$types$modifiers$add_modifiers$$($G__68164_G__68165$jscomp$inline_6701$$,$APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($fill_height$jscomp$1$$)):$G__68164_G__68165$jscomp$inline_6701$$}()],null)};
$app$common$geom$shapes$flex_layout$params$calculate_params$cljs$0core$0IFn$0_invoke$0arity$03$$=function($angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$,$G__68192_shapes$jscomp$69_shapes__$1$jscomp$10$$,$padding$jscomp$8_parent$jscomp$254$$){if($APP.$app$common$data$not_empty_QMARK_$$($G__68192_shapes$jscomp$69_shapes__$1$jscomp$10$$)){$G__68192_shapes$jscomp$69_shapes__$1$jscomp$10$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,
$G__68192_shapes$jscomp$69_shapes__$1$jscomp$10$$);$angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$shapes$common$shape__GT_center$$,$APP.$app$common$data$getf$$($angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$)),$APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$02$$($angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$G__68192_shapes$jscomp$69_shapes__$1$jscomp$10$$)));var $start$jscomp$217$$=$APP.$cljs$core$first$$($angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$);$angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(function($acc$jscomp$128$$,$p$jscomp$246$$){return $APP.$app$common$geom$point$add$$($acc$jscomp$128$$,
$APP.$app$common$geom$point$subtract$$($p$jscomp$246$$,$start$jscomp$217$$))},$angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$);$angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$=$app$common$geom$point$signed_angle_with_other$$($APP.$app$common$geom$point$subtract$$($angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$,$start$jscomp$217$$));var $angle__$1$jscomp$2$$=$APP.$cljs$core$mod$$($angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$,
360),$t1$jscomp$10$$=function(){var $x__5113__auto__$jscomp$53$$=$APP.$cljs$core$abs$$($angle__$1$jscomp$2$$-0),$y__5114__auto__$jscomp$53$$=$APP.$cljs$core$abs$$($angle__$1$jscomp$2$$-360);return $x__5113__auto__$jscomp$53$$<$y__5114__auto__$jscomp$53$$?$x__5113__auto__$jscomp$53$$:$y__5114__auto__$jscomp$53$$}(),$t2$jscomp$11$$=$APP.$cljs$core$abs$$($angle__$1$jscomp$2$$-90),$t3$jscomp$2$$=$APP.$cljs$core$abs$$($angle__$1$jscomp$2$$-180),$t4$$=$APP.$cljs$core$abs$$($angle__$1$jscomp$2$$-270);$angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$=
function(){var $x__5113__auto__$jscomp$54_x__5113__auto__$jscomp$inline_12574$$=$t1$jscomp$10$$<$t2$jscomp$11$$?$t1$jscomp$10$$:$t2$jscomp$11$$;$x__5113__auto__$jscomp$54_x__5113__auto__$jscomp$inline_12574$$=$x__5113__auto__$jscomp$54_x__5113__auto__$jscomp$inline_12574$$<$t3$jscomp$2$$?$x__5113__auto__$jscomp$54_x__5113__auto__$jscomp$inline_12574$$:$t3$jscomp$2$$;return $x__5113__auto__$jscomp$54_x__5113__auto__$jscomp$inline_12574$$<$t4$$?$x__5113__auto__$jscomp$54_x__5113__auto__$jscomp$inline_12574$$:
$t4$$}();$angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$=$APP.$cljs$core$truth_$$($APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$,$t1$jscomp$10$$))?$APP.$cljs$cst$1656$row$$:$APP.$cljs$core$truth_$$($APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$,
$t2$jscomp$11$$))?$APP.$cljs$cst$1662$column_reverse$$:$APP.$cljs$core$truth_$$($APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$,$t3$jscomp$2$$))?$APP.$cljs$cst$1661$row_reverse$$:$APP.$cljs$core$truth_$$($APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$,$t4$$))?$APP.$cljs$cst$216$column$$:
null;var $all_height_layout_gap$jscomp$2_row_gap$jscomp$7_selrects$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1605$selrect$$,$G__68192_shapes$jscomp$69_shapes__$1$jscomp$10$$),$min_x$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$min$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68169_SHARP__y__5114__auto__$jscomp$57$$){var $x__5113__auto__$jscomp$57$$=$APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($p1__68169_SHARP__y__5114__auto__$jscomp$57$$);
$p1__68169_SHARP__y__5114__auto__$jscomp$57$$=$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($p1__68169_SHARP__y__5114__auto__$jscomp$57$$);return $x__5113__auto__$jscomp$57$$<$p1__68169_SHARP__y__5114__auto__$jscomp$57$$?$x__5113__auto__$jscomp$57$$:$p1__68169_SHARP__y__5114__auto__$jscomp$57$$},$all_height_layout_gap$jscomp$2_row_gap$jscomp$7_selrects$$)),$max_x_min_y$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$max$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68170_SHARP__y__5111__auto__$jscomp$113$$){var $x__5110__auto__$jscomp$113$$=
$APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($p1__68170_SHARP__y__5111__auto__$jscomp$113$$);$p1__68170_SHARP__y__5111__auto__$jscomp$113$$=$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($p1__68170_SHARP__y__5111__auto__$jscomp$113$$);return $x__5110__auto__$jscomp$113$$>$p1__68170_SHARP__y__5111__auto__$jscomp$113$$?$x__5110__auto__$jscomp$113$$:$p1__68170_SHARP__y__5111__auto__$jscomp$113$$},$all_height_layout_gap$jscomp$2_row_gap$jscomp$7_selrects$$)),$all_width_column_gap$jscomp$7_parent_selrect$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$,$all_height_layout_gap$jscomp$2_row_gap$jscomp$7_selrects$$));$all_width_column_gap$jscomp$7_parent_selrect$$=$APP.$cljs$core$count$$($G__68192_shapes$jscomp$69_shapes__$1$jscomp$10$$)>1&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$,
$APP.$cljs$cst$1656$row$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$,$APP.$cljs$cst$1661$row_reverse$$))?($max_x_min_y$$-$min_x$$-$all_width_column_gap$jscomp$7_parent_selrect$$)/($APP.$cljs$core$count$$($G__68192_shapes$jscomp$69_shapes__$1$jscomp$10$$)-1):0;$max_x_min_y$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$min$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68171_SHARP__y__5114__auto__$jscomp$58$$){var $x__5113__auto__$jscomp$58$$=
$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($p1__68171_SHARP__y__5114__auto__$jscomp$58$$);$p1__68171_SHARP__y__5114__auto__$jscomp$58$$=$APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($p1__68171_SHARP__y__5114__auto__$jscomp$58$$);return $x__5113__auto__$jscomp$58$$<$p1__68171_SHARP__y__5114__auto__$jscomp$58$$?$x__5113__auto__$jscomp$58$$:$p1__68171_SHARP__y__5114__auto__$jscomp$58$$},$all_height_layout_gap$jscomp$2_row_gap$jscomp$7_selrects$$));var $max_y$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$max$$,
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68172_SHARP__y__5111__auto__$jscomp$114$$){var $x__5110__auto__$jscomp$114$$=$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($p1__68172_SHARP__y__5111__auto__$jscomp$114$$);$p1__68172_SHARP__y__5111__auto__$jscomp$114$$=$APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($p1__68172_SHARP__y__5111__auto__$jscomp$114$$);return $x__5110__auto__$jscomp$114$$>$p1__68172_SHARP__y__5111__auto__$jscomp$114$$?$x__5110__auto__$jscomp$114$$:
$p1__68172_SHARP__y__5111__auto__$jscomp$114$$},$all_height_layout_gap$jscomp$2_row_gap$jscomp$7_selrects$$));$all_height_layout_gap$jscomp$2_row_gap$jscomp$7_selrects$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1522$height$$,$all_height_layout_gap$jscomp$2_row_gap$jscomp$7_selrects$$));$all_height_layout_gap$jscomp$2_row_gap$jscomp$7_selrects$$=$APP.$cljs$core$count$$($G__68192_shapes$jscomp$69_shapes__$1$jscomp$10$$)>
1&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$,$APP.$cljs$cst$216$column$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$,$APP.$cljs$cst$1662$column_reverse$$))?($max_y$$-$max_x_min_y$$-$all_height_layout_gap$jscomp$2_row_gap$jscomp$7_selrects$$)/($APP.$cljs$core$count$$($G__68192_shapes$jscomp$69_shapes__$1$jscomp$10$$)-
1):0;$all_height_layout_gap$jscomp$2_row_gap$jscomp$7_selrects$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1681$row_gap$$,$all_height_layout_gap$jscomp$2_row_gap$jscomp$7_selrects$$>0?$all_height_layout_gap$jscomp$2_row_gap$jscomp$7_selrects$$:0,$APP.$cljs$cst$1682$column_gap$$,$all_width_column_gap$jscomp$7_parent_selrect$$>0?$all_width_column_gap$jscomp$7_parent_selrect$$:0],null);$all_width_column_gap$jscomp$7_parent_selrect$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$8_parent$jscomp$254$$);
$padding$jscomp$8_parent$jscomp$254$$=$padding$jscomp$8_parent$jscomp$254$$!=null&&$APP.$cljs$core$count$$($G__68192_shapes$jscomp$69_shapes__$1$jscomp$10$$)>0?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1093$p1$$,$max_x_min_y$$-$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($all_width_column_gap$jscomp$7_parent_selrect$$),$APP.$cljs$cst$1091$p2$$,$min_x$$-$APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($all_width_column_gap$jscomp$7_parent_selrect$$)],null):
null;$G__68192_shapes$jscomp$69_shapes__$1$jscomp$10$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1679$layout_flex_dir$$,$angle$jscomp$25_direction$jscomp$14_end$jscomp$84_objects$jscomp$430_points$jscomp$63_tmin$$,$APP.$cljs$cst$1680$layout_gap$$,$all_height_layout_gap$jscomp$2_row_gap$jscomp$7_selrects$$],null);return $padding$jscomp$8_parent$jscomp$254$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__68192_shapes$jscomp$69_shapes__$1$jscomp$10$$,$APP.$cljs$cst$1686$layout_padding$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1093$p1$$,$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$8_parent$jscomp$254$$),$APP.$cljs$cst$1091$p2$$,$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$8_parent$jscomp$254$$),$APP.$cljs$cst$1687$p3$$,$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$8_parent$jscomp$254$$),$APP.$cljs$cst$1688$p4$$,$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$8_parent$jscomp$254$$)],
null)):$G__68192_shapes$jscomp$69_shapes__$1$jscomp$10$$}return null};
$app$common$geom$shapes$pixel_precision$set_pixel_precision$$=function($JSCompiler_temp$jscomp$14064_bx$jscomp$inline_14395_modifiers$jscomp$54_modifiers__$1$jscomp$inline_12608$$,$modifiers__$1$jscomp$12_points__$1$jscomp$inline_12609_shape$jscomp$516$$,$deltav$jscomp$inline_14409_precision$jscomp$18_target_corner$jscomp$inline_14406$$,$ignore_axis$jscomp$1$$){var $ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$=$APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$geom$shapes$common$shape__GT_points$$($modifiers__$1$jscomp$12_points__$1$jscomp$inline_12609_shape$jscomp$516$$),
$app$common$types$modifiers$modifiers__GT_transform$$($JSCompiler_temp$jscomp$14064_bx$jscomp$inline_14395_modifiers$jscomp$54_modifiers__$1$jscomp$inline_12608$$)),$G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$=!$app$common$types$modifiers$only_move_QMARK_$$($JSCompiler_temp$jscomp$14064_bx$jscomp$inline_14395_modifiers$jscomp$54_modifiers__$1$jscomp$inline_12608$$);if($G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$){var $by$jscomp$inline_14396_origin$jscomp$inline_14371_pb$jscomp$inline_14390$$=
$APP.$app$common$geom$shapes$points$origin$$($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$),$curr_width$jscomp$inline_14372_cx$jscomp$inline_14397_scalev$jscomp$inline_14382$$=$APP.$app$common$geom$shapes$points$width_points$$($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$),$curr_height$jscomp$inline_14373_cy$jscomp$inline_14398_pc$jscomp$inline_14391$$=
$APP.$app$common$geom$shapes$points$height_points$$($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$),$center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$=$APP.$app$common$geom$shapes$common$points__GT_center$$($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$),
$miny$jscomp$inline_14402_selrect$jscomp$inline_14375_transform_inverse$jscomp$inline_14377$$=$app$common$geom$shapes$transforms$calculate_selrect$$($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$,$center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$);$center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$=
$app$common$geom$shapes$transforms$calculate_transform$$($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$,$center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$,$miny$jscomp$inline_14402_selrect$jscomp$inline_14375_transform_inverse$jscomp$inline_14377$$);$miny$jscomp$inline_14402_selrect$jscomp$inline_14375_transform_inverse$jscomp$inline_14377$$=
$center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$!=null?$app$common$geom$matrix$inverse$$($center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$):null;var $dy$jscomp$inline_14400_path_QMARK_$jscomp$inline_14378_target_width$jscomp$inline_14380$$=$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($modifiers__$1$jscomp$12_points__$1$jscomp$inline_12609_shape$jscomp$516$$),
$dx$jscomp$inline_14399_horizontal_line_QMARK_$jscomp$inline_14379_target_height$jscomp$inline_14381$$=$dy$jscomp$inline_14400_path_QMARK_$jscomp$inline_14378_target_width$jscomp$inline_14380$$&&$curr_height$jscomp$inline_14373_cy$jscomp$inline_14398_pc$jscomp$inline_14391$$<=.01;$dy$jscomp$inline_14400_path_QMARK_$jscomp$inline_14378_target_width$jscomp$inline_14380$$=$dy$jscomp$inline_14400_path_QMARK_$jscomp$inline_14378_target_width$jscomp$inline_14380$$&&$curr_width$jscomp$inline_14372_cx$jscomp$inline_14397_scalev$jscomp$inline_14382$$<=
.01?$curr_width$jscomp$inline_14372_cx$jscomp$inline_14397_scalev$jscomp$inline_14382$$:Math.max(1,$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$2$($curr_width$jscomp$inline_14372_cx$jscomp$inline_14397_scalev$jscomp$inline_14382$$,$deltav$jscomp$inline_14409_precision$jscomp$18_target_corner$jscomp$inline_14406$$));$dx$jscomp$inline_14399_horizontal_line_QMARK_$jscomp$inline_14379_target_height$jscomp$inline_14381$$=$dx$jscomp$inline_14399_horizontal_line_QMARK_$jscomp$inline_14379_target_height$jscomp$inline_14381$$?
$curr_height$jscomp$inline_14373_cy$jscomp$inline_14398_pc$jscomp$inline_14391$$:Math.max(1,$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$2$($curr_height$jscomp$inline_14373_cy$jscomp$inline_14398_pc$jscomp$inline_14391$$,$deltav$jscomp$inline_14409_precision$jscomp$18_target_corner$jscomp$inline_14406$$));$curr_width$jscomp$inline_14372_cx$jscomp$inline_14397_scalev$jscomp$inline_14382$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($dy$jscomp$inline_14400_path_QMARK_$jscomp$inline_14378_target_width$jscomp$inline_14380$$/
$curr_width$jscomp$inline_14372_cx$jscomp$inline_14397_scalev$jscomp$inline_14382$$,$dx$jscomp$inline_14399_horizontal_line_QMARK_$jscomp$inline_14379_target_height$jscomp$inline_14381$$/$curr_height$jscomp$inline_14373_cy$jscomp$inline_14398_pc$jscomp$inline_14391$$);$JSCompiler_temp$jscomp$14064_bx$jscomp$inline_14395_modifiers$jscomp$54_modifiers__$1$jscomp$inline_12608$$=$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$06$$($JSCompiler_temp$jscomp$14064_bx$jscomp$inline_14395_modifiers$jscomp$54_modifiers__$1$jscomp$inline_12608$$,
$curr_width$jscomp$inline_14372_cx$jscomp$inline_14397_scalev$jscomp$inline_14382$$,$by$jscomp$inline_14396_origin$jscomp$inline_14371_pb$jscomp$inline_14390$$,$center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$,$miny$jscomp$inline_14402_selrect$jscomp$inline_14375_transform_inverse$jscomp$inline_14377$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1805$precise_QMARK_$$,!0],null))}$modifiers__$1$jscomp$12_points__$1$jscomp$inline_12609_shape$jscomp$516$$=
$G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$?$APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($modifiers__$1$jscomp$12_points__$1$jscomp$inline_12609_shape$jscomp$516$$),$app$common$types$modifiers$modifiers__GT_transform$$($JSCompiler_temp$jscomp$14064_bx$jscomp$inline_14395_modifiers$jscomp$54_modifiers__$1$jscomp$inline_12608$$)):
$ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$;$ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$14064_bx$jscomp$inline_14395_modifiers$jscomp$54_modifiers__$1$jscomp$inline_12608$$,
$modifiers__$1$jscomp$12_points__$1$jscomp$inline_12609_shape$jscomp$516$$],null);$modifiers__$1$jscomp$12_points__$1$jscomp$inline_12609_shape$jscomp$516$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$,0,null);$ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$,1,null);$G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$,
0,null);$by$jscomp$inline_14396_origin$jscomp$inline_14371_pb$jscomp$inline_14390$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$,1,null);$curr_height$jscomp$inline_14373_cy$jscomp$inline_14398_pc$jscomp$inline_14391$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$,
2,null);$center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$,3,null);$ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$=$G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$?.x??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$,$APP.$cljs$cst$1510$x$$);$G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$=$G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$,$APP.$cljs$cst$1511$y$$);$JSCompiler_temp$jscomp$14064_bx$jscomp$inline_14395_modifiers$jscomp$54_modifiers__$1$jscomp$inline_12608$$=$by$jscomp$inline_14396_origin$jscomp$inline_14371_pb$jscomp$inline_14390$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($by$jscomp$inline_14396_origin$jscomp$inline_14371_pb$jscomp$inline_14390$$,
$APP.$cljs$cst$1510$x$$);$by$jscomp$inline_14396_origin$jscomp$inline_14371_pb$jscomp$inline_14390$$=$by$jscomp$inline_14396_origin$jscomp$inline_14371_pb$jscomp$inline_14390$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($by$jscomp$inline_14396_origin$jscomp$inline_14371_pb$jscomp$inline_14390$$,$APP.$cljs$cst$1511$y$$);$curr_width$jscomp$inline_14372_cx$jscomp$inline_14397_scalev$jscomp$inline_14382$$=$curr_height$jscomp$inline_14373_cy$jscomp$inline_14398_pc$jscomp$inline_14391$$?.x??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($curr_height$jscomp$inline_14373_cy$jscomp$inline_14398_pc$jscomp$inline_14391$$,$APP.$cljs$cst$1510$x$$);$curr_height$jscomp$inline_14373_cy$jscomp$inline_14398_pc$jscomp$inline_14391$$=$curr_height$jscomp$inline_14373_cy$jscomp$inline_14398_pc$jscomp$inline_14391$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($curr_height$jscomp$inline_14373_cy$jscomp$inline_14398_pc$jscomp$inline_14391$$,$APP.$cljs$cst$1511$y$$);$dx$jscomp$inline_14399_horizontal_line_QMARK_$jscomp$inline_14379_target_height$jscomp$inline_14381$$=
$center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$,$APP.$cljs$cst$1510$x$$);$dy$jscomp$inline_14400_path_QMARK_$jscomp$inline_14378_target_width$jscomp$inline_14380$$=$center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$,$APP.$cljs$cst$1511$y$$);$center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$=Math.min($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$,$JSCompiler_temp$jscomp$14064_bx$jscomp$inline_14395_modifiers$jscomp$54_modifiers__$1$jscomp$inline_12608$$,
$curr_width$jscomp$inline_14372_cx$jscomp$inline_14397_scalev$jscomp$inline_14382$$,$dx$jscomp$inline_14399_horizontal_line_QMARK_$jscomp$inline_14379_target_height$jscomp$inline_14381$$);$miny$jscomp$inline_14402_selrect$jscomp$inline_14375_transform_inverse$jscomp$inline_14377$$=Math.min($G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$,$by$jscomp$inline_14396_origin$jscomp$inline_14371_pb$jscomp$inline_14390$$,
$curr_height$jscomp$inline_14373_cy$jscomp$inline_14398_pc$jscomp$inline_14391$$,$dy$jscomp$inline_14400_path_QMARK_$jscomp$inline_14378_target_width$jscomp$inline_14380$$);$ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$=Math.max($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$,$JSCompiler_temp$jscomp$14064_bx$jscomp$inline_14395_modifiers$jscomp$54_modifiers__$1$jscomp$inline_12608$$,
$curr_width$jscomp$inline_14372_cx$jscomp$inline_14397_scalev$jscomp$inline_14382$$,$dx$jscomp$inline_14399_horizontal_line_QMARK_$jscomp$inline_14379_target_height$jscomp$inline_14381$$);$G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$=Math.max($G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$,
$by$jscomp$inline_14396_origin$jscomp$inline_14371_pb$jscomp$inline_14390$$,$curr_height$jscomp$inline_14373_cy$jscomp$inline_14398_pc$jscomp$inline_14391$$,$dy$jscomp$inline_14400_path_QMARK_$jscomp$inline_14378_target_width$jscomp$inline_14380$$);$ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$=$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$04$$($center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$,
$miny$jscomp$inline_14402_selrect$jscomp$inline_14375_transform_inverse$jscomp$inline_14377$$,$ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$,$G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$)?$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$,
$miny$jscomp$inline_14402_selrect$jscomp$inline_14375_transform_inverse$jscomp$inline_14377$$,$ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$-$center$jscomp$inline_14374_minx$jscomp$inline_14401_pd$jscomp$inline_14392_transform$jscomp$inline_14376$$,$G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$-
$miny$jscomp$inline_14402_selrect$jscomp$inline_14375_transform_inverse$jscomp$inline_14377$$):null;$ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$);$G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ignore_axis$jscomp$1$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$,$APP.$cljs$cst$1511$y$$,$APP.$app$common$math$round$$,$deltav$jscomp$inline_14409_precision$jscomp$18_target_corner$jscomp$inline_14406$$):$ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$;
$G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ignore_axis$jscomp$1$$,$APP.$cljs$cst$1511$y$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$,$APP.$cljs$cst$1510$x$$,
$APP.$app$common$math$round$$,$deltav$jscomp$inline_14409_precision$jscomp$18_target_corner$jscomp$inline_14406$$):$G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$;$deltav$jscomp$inline_14409_precision$jscomp$18_target_corner$jscomp$inline_14406$$=$ignore_axis$jscomp$1$$==null?$app$common$geom$point$round_step$$($G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$,
$deltav$jscomp$inline_14409_precision$jscomp$18_target_corner$jscomp$inline_14406$$):$G__68258__$1$jscomp$inline_14407_G__68258__$2$jscomp$inline_14408_ay$jscomp$inline_14394_has_resize_QMARK__maxy$jscomp$inline_14404_pa$jscomp$inline_14389$$;$deltav$jscomp$inline_14409_precision$jscomp$18_target_corner$jscomp$inline_14406$$=$APP.$app$common$geom$point$subtract$$($deltav$jscomp$inline_14409_precision$jscomp$18_target_corner$jscomp$inline_14406$$,$ax$jscomp$inline_14393_bounds$jscomp$inline_14388_corner$jscomp$inline_14405_maxx$jscomp$inline_14403_points$jscomp$66_points__$1$jscomp$5_vec__68260$$);
return $APP.$app$common$types$modifiers$move$cljs$0core$0IFn$0_invoke$0arity$02$$($modifiers__$1$jscomp$12_points__$1$jscomp$inline_12609_shape$jscomp$516$$,$deltav$jscomp$inline_14409_precision$jscomp$18_target_corner$jscomp$inline_14406$$)};
$app$common$geom$shapes$pixel_precision$adjust_pixel_precision$$=function($modif_tree$jscomp$12$$,$objects$jscomp$435$$,$precision$jscomp$19$$,$ignore_axis$jscomp$2$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($modif_tree__$1$jscomp$2$$,$shape$jscomp$517$$){var $modifiers$jscomp$55$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modif_tree__$1$jscomp$2$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$517$$)),
$APP.$cljs$cst$1810$modifiers$$);return $modifiers$jscomp$55$$!=null&&$app$common$types$modifiers$has_geometry_QMARK_$$($modifiers$jscomp$55$$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$6$($modif_tree__$1$jscomp$2$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$517$$),$APP.$cljs$cst$1810$modifiers$$],null),$app$common$geom$shapes$pixel_precision$set_pixel_precision$$,
$shape$jscomp$517$$,$precision$jscomp$19$$,$ignore_axis$jscomp$2$$):$modif_tree__$1$jscomp$2$$},$modif_tree$jscomp$12$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$435$$),$APP.$cljs$core$keys$$($modif_tree$jscomp$12$$)))};
$app$common$geom$modifiers$set_children_modifiers$$=function($modif_tree$jscomp$13$$,$children$jscomp$235$$,$objects$jscomp$436$$,$bounds$jscomp$57$$,$parent$jscomp$255$$,$transformed_parent_bounds$jscomp$4$$,$ignore_constraints$jscomp$1$$){var $modifiers$jscomp$56$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modif_tree$jscomp$13$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$255$$)),$APP.$cljs$cst$1810$modifiers$$);
if($app$common$types$modifiers$empty_QMARK_$$($modifiers$jscomp$56$$))return $modif_tree$jscomp$13$$;if($app$common$types$modifiers$only_move_QMARK_$$($modifiers$jscomp$56$$))return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__68421_SHARP_$$,$p2__68422_SHARP_$$){return $app$common$geom$modif_tree$add_modifiers$$($p1__68421_SHARP_$$,$p2__68422_SHARP_$$,$modifiers$jscomp$56$$)},$modif_tree$jscomp$13$$,$children$jscomp$235$$);var $parent_id$jscomp$77$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$255$$),
$parent_bounds$jscomp$16$$=$app$common$geom$shapes$transforms$transform_bounds$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$57$$,$parent_id$jscomp$77$$)),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$truth_$$($modifiers$jscomp$56$$)?$modifiers$jscomp$56$$:$APP.$app$common$types$modifiers$empty$$(),$cljs$cst$1778$geometry_child$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1780$structure_child$$,
$APP.$cljs$core$PersistentVector$EMPTY$$])));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($modif_tree__$1$jscomp$3$$,$child_id$jscomp$4$$){var $child_points_before$jscomp$inline_6721_temp__5823__auto__$jscomp$177$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$436$$,$child_id$jscomp$4$$);if($APP.$cljs$core$truth_$$($child_points_before$jscomp$inline_6721_temp__5823__auto__$jscomp$177$$)){var $child_bounds$jscomp$27_child_points_after$jscomp$inline_6722$$=
$APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$57$$,$child_id$jscomp$4$$));var $modifiers__$1$jscomp$inline_6713_modifiers__$2$jscomp$inline_6717_modifiers__$3$jscomp$inline_6719$$=$app$common$types$modifiers$select_child$$($modifiers$jscomp$56$$),$constraints_h$jscomp$inline_6714_modifiers_h$jscomp$inline_6723$$=$APP.$cljs$core$truth_$$($ignore_constraints$jscomp$1$$)?$APP.$cljs$cst$1902$scale$$:$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$255$$)&&
$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child_points_before$jscomp$inline_6721_temp__5823__auto__$jscomp$177$$))?$APP.$cljs$cst$257$left$$:$APP.$cljs$cst$1872$constraints_h$$.$cljs$core$IFn$_invoke$arity$2$($child_points_before$jscomp$inline_6721_temp__5823__auto__$jscomp$177$$,$APP.$app$common$geom$shapes$constraints$default_constraints_h$$($child_points_before$jscomp$inline_6721_temp__5823__auto__$jscomp$177$$));var $child_modifiers_constraints_v$jscomp$inline_6715_modifiers_v$jscomp$inline_6724$$=
$APP.$cljs$core$truth_$$($ignore_constraints$jscomp$1$$)?$APP.$cljs$cst$1902$scale$$:$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$255$$)&&$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child_points_before$jscomp$inline_6721_temp__5823__auto__$jscomp$177$$))?$APP.$cljs$cst$1562$top$$:$APP.$cljs$cst$1871$constraints_v$$.$cljs$core$IFn$_invoke$arity$2$($child_points_before$jscomp$inline_6721_temp__5823__auto__$jscomp$177$$,
$APP.$app$common$geom$shapes$constraints$default_constraints_v$$($child_points_before$jscomp$inline_6721_temp__5823__auto__$jscomp$177$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1902$scale$$,$constraints_h$jscomp$inline_6714_modifiers_h$jscomp$inline_6723$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1902$scale$$,$child_modifiers_constraints_v$jscomp$inline_6715_modifiers_v$jscomp$inline_6724$$))$child_modifiers_constraints_v$jscomp$inline_6715_modifiers_v$jscomp$inline_6724$$=
$modifiers__$1$jscomp$inline_6713_modifiers__$2$jscomp$inline_6717_modifiers__$3$jscomp$inline_6719$$;else{var $transformed_parent_bounds__$1$jscomp$inline_6716$$=$APP.$cljs$core$_deref$$($transformed_parent_bounds$jscomp$4$$);$modifiers__$1$jscomp$inline_6713_modifiers__$2$jscomp$inline_6717_modifiers__$3$jscomp$inline_6719$$=$app$common$types$modifiers$select_child$$($modifiers__$1$jscomp$inline_6713_modifiers__$2$jscomp$inline_6717_modifiers__$3$jscomp$inline_6719$$);var $reset_modifiers_QMARK_$jscomp$inline_6718_transformed_child_bounds$jscomp$inline_6720$$=
$app$common$geom$shapes$points$axis_aligned_QMARK_$$($parent_bounds$jscomp$16$$)&&$app$common$geom$shapes$points$axis_aligned_QMARK_$$($child_bounds$jscomp$27_child_points_after$jscomp$inline_6722$$)&&$app$common$geom$shapes$points$axis_aligned_QMARK_$$($transformed_parent_bounds__$1$jscomp$inline_6716$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1902$scale$$,$constraints_h$jscomp$inline_6714_modifiers_h$jscomp$inline_6723$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1902$scale$$,
$child_modifiers_constraints_v$jscomp$inline_6715_modifiers_v$jscomp$inline_6724$$);$modifiers__$1$jscomp$inline_6713_modifiers__$2$jscomp$inline_6717_modifiers__$3$jscomp$inline_6719$$=$reset_modifiers_QMARK_$jscomp$inline_6718_transformed_child_bounds$jscomp$inline_6720$$?$APP.$app$common$types$modifiers$empty$$():$app$common$geom$shapes$constraints$normalize_modifiers$$($constraints_h$jscomp$inline_6714_modifiers_h$jscomp$inline_6723$$,$child_modifiers_constraints_v$jscomp$inline_6715_modifiers_v$jscomp$inline_6724$$,
$modifiers__$1$jscomp$inline_6713_modifiers__$2$jscomp$inline_6717_modifiers__$3$jscomp$inline_6719$$,$child_bounds$jscomp$27_child_points_after$jscomp$inline_6722$$,$app$common$geom$shapes$transforms$transform_bounds$cljs$0core$0IFn$0_invoke$0arity$03$$($child_bounds$jscomp$27_child_points_after$jscomp$inline_6722$$,$modifiers__$1$jscomp$inline_6713_modifiers__$2$jscomp$inline_6717_modifiers__$3$jscomp$inline_6719$$),$parent_bounds$jscomp$16$$,$transformed_parent_bounds__$1$jscomp$inline_6716$$);
$reset_modifiers_QMARK_$jscomp$inline_6718_transformed_child_bounds$jscomp$inline_6720$$=$reset_modifiers_QMARK_$jscomp$inline_6718_transformed_child_bounds$jscomp$inline_6720$$?$child_bounds$jscomp$27_child_points_after$jscomp$inline_6722$$:$app$common$geom$shapes$transforms$transform_bounds$cljs$0core$0IFn$0_invoke$0arity$03$$($child_bounds$jscomp$27_child_points_after$jscomp$inline_6722$$,$modifiers__$1$jscomp$inline_6713_modifiers__$2$jscomp$inline_6717_modifiers__$3$jscomp$inline_6719$$);$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$255$$)&&
$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child_points_before$jscomp$inline_6721_temp__5823__auto__$jscomp$177$$))?$child_modifiers_constraints_v$jscomp$inline_6715_modifiers_v$jscomp$inline_6724$$=$modifiers__$1$jscomp$inline_6713_modifiers__$2$jscomp$inline_6717_modifiers__$3$jscomp$inline_6719$$:($child_points_before$jscomp$inline_6721_temp__5823__auto__$jscomp$177$$=$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($child_bounds$jscomp$27_child_points_after$jscomp$inline_6722$$,
$parent_bounds$jscomp$16$$),$child_bounds$jscomp$27_child_points_after$jscomp$inline_6722$$=$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($reset_modifiers_QMARK_$jscomp$inline_6718_transformed_child_bounds$jscomp$inline_6720$$,$transformed_parent_bounds__$1$jscomp$inline_6716$$),$constraints_h$jscomp$inline_6714_modifiers_h$jscomp$inline_6723$$=$app$common$geom$shapes$constraints$constraint_modifier$$.$cljs$core$IFn$_invoke$arity$6$($constraints_h$jscomp$inline_6714_modifiers_h$jscomp$inline_6723$$.$cljs$core$IFn$_invoke$arity$1$?
$constraints_h$jscomp$inline_6714_modifiers_h$jscomp$inline_6723$$.$cljs$core$IFn$_invoke$arity$1$($app$common$geom$shapes$constraints$const__GT_type_PLUS_axis$$):$constraints_h$jscomp$inline_6714_modifiers_h$jscomp$inline_6723$$($app$common$geom$shapes$constraints$const__GT_type_PLUS_axis$$),$APP.$cljs$cst$1510$x$$,$child_points_before$jscomp$inline_6721_temp__5823__auto__$jscomp$177$$,$parent_bounds$jscomp$16$$,$child_bounds$jscomp$27_child_points_after$jscomp$inline_6722$$,$transformed_parent_bounds__$1$jscomp$inline_6716$$),
$child_modifiers_constraints_v$jscomp$inline_6715_modifiers_v$jscomp$inline_6724$$=$app$common$geom$shapes$constraints$constraint_modifier$$.$cljs$core$IFn$_invoke$arity$6$($child_modifiers_constraints_v$jscomp$inline_6715_modifiers_v$jscomp$inline_6724$$.$cljs$core$IFn$_invoke$arity$1$?$child_modifiers_constraints_v$jscomp$inline_6715_modifiers_v$jscomp$inline_6724$$.$cljs$core$IFn$_invoke$arity$1$($app$common$geom$shapes$constraints$const__GT_type_PLUS_axis$$):$child_modifiers_constraints_v$jscomp$inline_6715_modifiers_v$jscomp$inline_6724$$($app$common$geom$shapes$constraints$const__GT_type_PLUS_axis$$),
$APP.$cljs$cst$1511$y$$,$child_points_before$jscomp$inline_6721_temp__5823__auto__$jscomp$177$$,$parent_bounds$jscomp$16$$,$child_bounds$jscomp$27_child_points_after$jscomp$inline_6722$$,$transformed_parent_bounds__$1$jscomp$inline_6716$$),$child_modifiers_constraints_v$jscomp$inline_6715_modifiers_v$jscomp$inline_6724$$=$app$common$types$modifiers$add_modifiers$$($app$common$types$modifiers$add_modifiers$$($modifiers__$1$jscomp$inline_6713_modifiers__$2$jscomp$inline_6717_modifiers__$3$jscomp$inline_6719$$,
$constraints_h$jscomp$inline_6714_modifiers_h$jscomp$inline_6723$$),$child_modifiers_constraints_v$jscomp$inline_6715_modifiers_v$jscomp$inline_6724$$))}return $app$common$geom$modif_tree$add_modifiers$$($modif_tree__$1$jscomp$3$$,$child_id$jscomp$4$$,$child_modifiers_constraints_v$jscomp$inline_6715_modifiers_v$jscomp$inline_6724$$)}return $modif_tree__$1$jscomp$3$$},$modif_tree$jscomp$13$$,$children$jscomp$235$$)};
$app$common$geom$modifiers$set_flex_layout_modifiers$$=function($G__68563_modif_tree$jscomp$14_modif_tree__$1$jscomp$4_vec__68466$$,$children$jscomp$236_children__$1$jscomp$32_max_idx$$,$children__$2$jscomp$5_objects$jscomp$437$$,$G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$,$parent$jscomp$256$$,$transformed_parent_bounds$jscomp$5$$){function $set_child_modifiers$$($modif_tree__$1$jscomp$5_p__68434$$,$child$jscomp$112_p__68435$$){var $layout_line$jscomp$4_layout_line__$1$jscomp$1_layout_line__$1$jscomp$inline_12623_vec__68178$jscomp$inline_12621_vec__68442$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modif_tree__$1$jscomp$5_p__68434$$,0,null);$modif_tree__$1$jscomp$5_p__68434$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modif_tree__$1$jscomp$5_p__68434$$,1,null);var $child_bounds$jscomp$29_fill_modifiers$jscomp$inline_12620_vec__68175$jscomp$inline_12617$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$112_p__68435$$,0,null);$child$jscomp$112_p__68435$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$112_p__68435$$,
1,null);var $child_origin$jscomp$inline_12616_modifiers$jscomp$57_modifiers$jscomp$inline_12625_move_vec$jscomp$inline_12624$$=$APP.$app$common$geom$shapes$points$origin$$($child_bounds$jscomp$29_fill_modifiers$jscomp$inline_12620_vec__68175$jscomp$inline_12617$$);$child_bounds$jscomp$29_fill_modifiers$jscomp$inline_12620_vec__68175$jscomp$inline_12617$$=$app$common$geom$shapes$flex_layout$modifiers$fill_modifiers$$($parent$jscomp$256$$,$transformed_parent_bounds$jscomp$5$$,$child$jscomp$112_p__68435$$,
$child_bounds$jscomp$29_fill_modifiers$jscomp$inline_12620_vec__68175$jscomp$inline_12617$$,$layout_line$jscomp$4_layout_line__$1$jscomp$1_layout_line__$1$jscomp$inline_12623_vec__68178$jscomp$inline_12621_vec__68442$$);var $child_width$jscomp$inline_12618_corner_p$jscomp$inline_12622$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_bounds$jscomp$29_fill_modifiers$jscomp$inline_12620_vec__68175$jscomp$inline_12617$$,0,null),$child_height$jscomp$inline_12619$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_bounds$jscomp$29_fill_modifiers$jscomp$inline_12620_vec__68175$jscomp$inline_12617$$,
1,null);$child_bounds$jscomp$29_fill_modifiers$jscomp$inline_12620_vec__68175$jscomp$inline_12617$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_bounds$jscomp$29_fill_modifiers$jscomp$inline_12620_vec__68175$jscomp$inline_12617$$,2,null);$layout_line$jscomp$4_layout_line__$1$jscomp$1_layout_line__$1$jscomp$inline_12623_vec__68178$jscomp$inline_12621_vec__68442$$=$app$common$geom$shapes$flex_layout$positions$get_child_position$$($parent$jscomp$256$$,$child$jscomp$112_p__68435$$,
$child_width$jscomp$inline_12618_corner_p$jscomp$inline_12622$$,$child_height$jscomp$inline_12619$$,$layout_line$jscomp$4_layout_line__$1$jscomp$1_layout_line__$1$jscomp$inline_12623_vec__68178$jscomp$inline_12621_vec__68442$$);$child_width$jscomp$inline_12618_corner_p$jscomp$inline_12622$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_line$jscomp$4_layout_line__$1$jscomp$1_layout_line__$1$jscomp$inline_12623_vec__68178$jscomp$inline_12621_vec__68442$$,0,null);$layout_line$jscomp$4_layout_line__$1$jscomp$1_layout_line__$1$jscomp$inline_12623_vec__68178$jscomp$inline_12621_vec__68442$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_line$jscomp$4_layout_line__$1$jscomp$1_layout_line__$1$jscomp$inline_12623_vec__68178$jscomp$inline_12621_vec__68442$$,1,null);$child_origin$jscomp$inline_12616_modifiers$jscomp$57_modifiers$jscomp$inline_12625_move_vec$jscomp$inline_12624$$=$APP.$app$common$geom$point$subtract$$($child_width$jscomp$inline_12618_corner_p$jscomp$inline_12622$$,$child_origin$jscomp$inline_12616_modifiers$jscomp$57_modifiers$jscomp$inline_12625_move_vec$jscomp$inline_12624$$);
$child_origin$jscomp$inline_12616_modifiers$jscomp$57_modifiers$jscomp$inline_12625_move_vec$jscomp$inline_12624$$=$APP.$app$common$types$modifiers$move$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$modifiers$add_modifiers$$($APP.$app$common$types$modifiers$empty$$(),$child_bounds$jscomp$29_fill_modifiers$jscomp$inline_12620_vec__68175$jscomp$inline_12617$$),$child_origin$jscomp$inline_12616_modifiers$jscomp$57_modifiers$jscomp$inline_12625_move_vec$jscomp$inline_12624$$);$layout_line$jscomp$4_layout_line__$1$jscomp$1_layout_line__$1$jscomp$inline_12623_vec__68178$jscomp$inline_12621_vec__68442$$=
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$child_origin$jscomp$inline_12616_modifiers$jscomp$57_modifiers$jscomp$inline_12625_move_vec$jscomp$inline_12624$$,$layout_line$jscomp$4_layout_line__$1$jscomp$1_layout_line__$1$jscomp$inline_12623_vec__68178$jscomp$inline_12621_vec__68442$$],null);$child_origin$jscomp$inline_12616_modifiers$jscomp$57_modifiers$jscomp$inline_12625_move_vec$jscomp$inline_12624$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_line$jscomp$4_layout_line__$1$jscomp$1_layout_line__$1$jscomp$inline_12623_vec__68178$jscomp$inline_12621_vec__68442$$,
0,null);$layout_line$jscomp$4_layout_line__$1$jscomp$1_layout_line__$1$jscomp$inline_12623_vec__68178$jscomp$inline_12621_vec__68442$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_line$jscomp$4_layout_line__$1$jscomp$1_layout_line__$1$jscomp$inline_12623_vec__68178$jscomp$inline_12621_vec__68442$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$layout_line$jscomp$4_layout_line__$1$jscomp$1_layout_line__$1$jscomp$inline_12623_vec__68178$jscomp$inline_12621_vec__68442$$,
$app$common$geom$modif_tree$add_modifiers$$($modif_tree__$1$jscomp$5_p__68434$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$112_p__68435$$),$child_origin$jscomp$inline_12616_modifiers$jscomp$57_modifiers$jscomp$inline_12625_move_vec$jscomp$inline_12624$$)],null)}$G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$=$app$common$geom$bounds_map$transform_bounds_map$cljs$0core$0IFn$0_invoke$0arity$04$$($G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$,
$children__$2$jscomp$5_objects$jscomp$437$$,$G__68563_modif_tree$jscomp$14_modif_tree__$1$jscomp$4_vec__68466$$,$children$jscomp$236_children__$1$jscomp$32_max_idx$$);$children$jscomp$236_children__$1$jscomp$32_max_idx$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$(function($bounds__$1$jscomp$2_temp__5825__auto__$jscomp$201$$,$child$jscomp$111$$){$bounds__$1$jscomp$2_temp__5825__auto__$jscomp$201$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds__$1$jscomp$2_temp__5825__auto__$jscomp$201$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$111$$));return $APP.$cljs$core$truth_$$($bounds__$1$jscomp$2_temp__5825__auto__$jscomp$201$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$core$_deref$$($bounds__$1$jscomp$2_temp__5825__auto__$jscomp$201$$),$APP.$cljs$core$_deref$$($transformed_parent_bounds$jscomp$5$$)),$child$jscomp$111$$],null):null},$G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$),
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($app$common$geom$shapes$common$invalid_geometry_QMARK_$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$data$getf$$($children__$2$jscomp$5_objects$jscomp$437$$),$children$jscomp$236_children__$1$jscomp$32_max_idx$$)));$G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$=$APP.$app$common$geom$shapes$flex_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$($parent$jscomp$256$$,
$APP.$cljs$core$_deref$$($transformed_parent_bounds$jscomp$5$$),$children$jscomp$236_children__$1$jscomp$32_max_idx$$,$G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$,$children__$2$jscomp$5_objects$jscomp$437$$);$children__$2$jscomp$5_objects$jscomp$437$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$not$$($cljs$cst$3820$reverse_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$))?
$APP.$cljs$core$reverse$$($children$jscomp$236_children__$1$jscomp$32_max_idx$$):$children$jscomp$236_children__$1$jscomp$32_max_idx$$);$children$jscomp$236_children__$1$jscomp$32_max_idx$$=$APP.$cljs$core$count$$($children__$2$jscomp$5_objects$jscomp$437$$)-1;$G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$=$APP.$cljs$cst$3055$layout_lines$$.$cljs$core$IFn$_invoke$arity$1$($G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$);
var $G__68564_layout_line$jscomp$3$$=$APP.$cljs$core$first$$($G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$);$G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$=$APP.$cljs$core$rest$$($G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$);for(var $children__$3$jscomp$1_from_idx$jscomp$4$$=0;;)if($G__68564_layout_line$jscomp$3$$!=
null&&$children__$3$jscomp$1_from_idx$jscomp$4$$<=$children$jscomp$236_children__$1$jscomp$32_max_idx$$){var $G__68566_to_idx$jscomp$3$$=$children__$3$jscomp$1_from_idx$jscomp$4$$+$APP.$cljs$cst$3802$num_children$$.$cljs$core$IFn$_invoke$arity$1$($G__68564_layout_line$jscomp$3$$);$children__$3$jscomp$1_from_idx$jscomp$4$$=$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($children__$2$jscomp$5_objects$jscomp$437$$,$children__$3$jscomp$1_from_idx$jscomp$4$$,$G__68566_to_idx$jscomp$3$$);$G__68563_modif_tree$jscomp$14_modif_tree__$1$jscomp$4_vec__68466$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($set_child_modifiers$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__68564_layout_line$jscomp$3$$,$G__68563_modif_tree$jscomp$14_modif_tree__$1$jscomp$4_vec__68466$$],null),$children__$3$jscomp$1_from_idx$jscomp$4$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__68563_modif_tree$jscomp$14_modif_tree__$1$jscomp$4_vec__68466$$,0,null);$G__68563_modif_tree$jscomp$14_modif_tree__$1$jscomp$4_vec__68466$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__68563_modif_tree$jscomp$14_modif_tree__$1$jscomp$4_vec__68466$$,1,null);$G__68564_layout_line$jscomp$3$$=$APP.$cljs$core$first$$($G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$);$G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$=$APP.$cljs$core$rest$$($G__68565_bounds$jscomp$58_bounds__$1$jscomp$1_layout_data$jscomp$15_layout_lines$jscomp$2_pending$jscomp$20$$);
$children__$3$jscomp$1_from_idx$jscomp$4$$=$G__68566_to_idx$jscomp$3$$}else return $G__68563_modif_tree$jscomp$14_modif_tree__$1$jscomp$4_vec__68466$$};
$app$common$geom$modifiers$set_grid_layout_modifiers$$=function($G__68567_modif_tree$jscomp$15$$,$G__68568_objects$jscomp$438$$,$G__68569_bounds$jscomp$59_bounds__$1$jscomp$3_pending$jscomp$21$$,$parent$jscomp$257$$,$transformed_parent_bounds$jscomp$6$$){$G__68569_bounds$jscomp$59_bounds__$1$jscomp$3_pending$jscomp$21$$=$app$common$geom$bounds_map$transform_bounds_map$cljs$0core$0IFn$0_invoke$0arity$04$$($G__68569_bounds$jscomp$59_bounds__$1$jscomp$3_pending$jscomp$21$$,$G__68568_objects$jscomp$438$$,
$G__68567_modif_tree$jscomp$15$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$257$$));var $children$jscomp$237$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$(function($bounds__$1$jscomp$4_temp__5825__auto__$jscomp$202$$,$child$jscomp$113$$){$bounds__$1$jscomp$4_temp__5825__auto__$jscomp$202$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds__$1$jscomp$4_temp__5825__auto__$jscomp$202$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$113$$));return $APP.$cljs$core$truth_$$($bounds__$1$jscomp$4_temp__5825__auto__$jscomp$202$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$core$_deref$$($bounds__$1$jscomp$4_temp__5825__auto__$jscomp$202$$),$APP.$cljs$core$_deref$$($transformed_parent_bounds$jscomp$6$$)),$child$jscomp$113$$],null):null},$G__68569_bounds$jscomp$59_bounds__$1$jscomp$3_pending$jscomp$21$$),
$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$03$$($G__68568_objects$jscomp$438$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$257$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1621$remove_hidden$$,!0],null))),$grid_data$$=$APP.$app$common$geom$shapes$grid_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$($parent$jscomp$257$$,$APP.$cljs$core$_deref$$($transformed_parent_bounds$jscomp$6$$),$children$jscomp$237$$,
$G__68569_bounds$jscomp$59_bounds__$1$jscomp$3_pending$jscomp$21$$,$G__68568_objects$jscomp$438$$),$modif_tree__$1$jscomp$6$$=$G__68567_modif_tree$jscomp$15$$,$bound_PLUS_child$$=$APP.$cljs$core$first$$($children$jscomp$237$$);for($G__68569_bounds$jscomp$59_bounds__$1$jscomp$3_pending$jscomp$21$$=$APP.$cljs$core$rest$$($children$jscomp$237$$);;)if($bound_PLUS_child$$!=null){var $cell_data$jscomp$3$$=$app$common$geom$shapes$grid_layout$get_cell_data$$($grid_data$$,$APP.$cljs$core$_deref$$($transformed_parent_bounds$jscomp$6$$),
$bound_PLUS_child$$);$G__68567_modif_tree$jscomp$15$$=function(){var $G__68490_JSCompiler_temp$jscomp$1158$$=$modif_tree__$1$jscomp$6$$;if($cell_data$jscomp$3$$!=null){var $cell_data$jscomp$inline_6728_modifiers$jscomp$inline_6732_position_delta$jscomp$inline_14421$$=$cell_data$jscomp$3$$,$child$jscomp$inline_6731_p__68475$jscomp$inline_6729$$=$bound_PLUS_child$$,$G__66807$jscomp$inline_14422_child_bounds$jscomp$inline_6730$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$inline_6731_p__68475$jscomp$inline_6729$$,
0,null);$child$jscomp$inline_6731_p__68475$jscomp$inline_6729$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$inline_6731_p__68475$jscomp$inline_6729$$,1,null);var $fill_modifiers$jscomp$inline_14420_vec__66804$jscomp$inline_14417$$=$app$common$geom$shapes$grid_layout$positions$fill_modifiers$$($transformed_parent_bounds$jscomp$6$$,$child$jscomp$inline_6731_p__68475$jscomp$inline_6729$$,$G__66807$jscomp$inline_14422_child_bounds$jscomp$inline_6730$$,$grid_data$$,$cell_data$jscomp$inline_6728_modifiers$jscomp$inline_6732_position_delta$jscomp$inline_14421$$),
$child_width$jscomp$inline_14418$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_modifiers$jscomp$inline_14420_vec__66804$jscomp$inline_14417$$,0,null),$child_height$jscomp$inline_14419$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_modifiers$jscomp$inline_14420_vec__66804$jscomp$inline_14417$$,1,null);$fill_modifiers$jscomp$inline_14420_vec__66804$jscomp$inline_14417$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_modifiers$jscomp$inline_14420_vec__66804$jscomp$inline_14417$$,
2,null);$cell_data$jscomp$inline_6728_modifiers$jscomp$inline_6732_position_delta$jscomp$inline_14421$$=$app$common$geom$shapes$grid_layout$positions$child_position_delta$$($parent$jscomp$257$$,$child$jscomp$inline_6731_p__68475$jscomp$inline_6729$$,$G__66807$jscomp$inline_14422_child_bounds$jscomp$inline_6730$$,$child_width$jscomp$inline_14418$$,$child_height$jscomp$inline_14419$$,$grid_data$$,$cell_data$jscomp$inline_6728_modifiers$jscomp$inline_6732_position_delta$jscomp$inline_14421$$);$G__66807$jscomp$inline_14422_child_bounds$jscomp$inline_6730$$=
$APP.$app$common$types$modifiers$empty$$();$cell_data$jscomp$inline_6728_modifiers$jscomp$inline_6732_position_delta$jscomp$inline_14421$$=$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$inline_6731_p__68475$jscomp$inline_6729$$))?$APP.$app$common$types$modifiers$move$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$modifiers$add_modifiers$$($G__66807$jscomp$inline_14422_child_bounds$jscomp$inline_6730$$,$fill_modifiers$jscomp$inline_14420_vec__66804$jscomp$inline_14417$$),
$cell_data$jscomp$inline_6728_modifiers$jscomp$inline_6732_position_delta$jscomp$inline_14421$$):$G__66807$jscomp$inline_14422_child_bounds$jscomp$inline_6730$$;$G__68490_JSCompiler_temp$jscomp$1158$$=$app$common$geom$modif_tree$add_modifiers$$($G__68490_JSCompiler_temp$jscomp$1158$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$inline_6731_p__68475$jscomp$inline_6729$$),$cell_data$jscomp$inline_6728_modifiers$jscomp$inline_6732_position_delta$jscomp$inline_14421$$)}return $G__68490_JSCompiler_temp$jscomp$1158$$}();
$G__68568_objects$jscomp$438$$=$APP.$cljs$core$first$$($G__68569_bounds$jscomp$59_bounds__$1$jscomp$3_pending$jscomp$21$$);$G__68569_bounds$jscomp$59_bounds__$1$jscomp$3_pending$jscomp$21$$=$APP.$cljs$core$rest$$($G__68569_bounds$jscomp$59_bounds__$1$jscomp$3_pending$jscomp$21$$);$modif_tree__$1$jscomp$6$$=$G__68567_modif_tree$jscomp$15$$;$bound_PLUS_child$$=$G__68568_objects$jscomp$438$$}else return $modif_tree__$1$jscomp$6$$};
$app$common$geom$modifiers$set_modifiers_constraints$$=function($objects$jscomp$439$$,$bounds$jscomp$60$$,$ignore_constraints$jscomp$2$$,$modif_tree$jscomp$16$$,$parent$jscomp$258$$){var $parent_id$jscomp$78$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$258$$),$children$jscomp$238$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$258$$),$root_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,
$parent_id$jscomp$78$$),$modifiers$jscomp$59$$=$app$common$types$modifiers$select_geometry$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modif_tree$jscomp$16$$,$parent_id$jscomp$78$$),$APP.$cljs$cst$1810$modifiers$$)),$has_modifiers_QMARK_$$=$app$common$types$modifiers$child_modifiers_QMARK_$$($modifiers$jscomp$59$$),$parent_QMARK_$jscomp$2$$=$APP.$app$common$files$helpers$group_like_shape_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$258$$)||
$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$258$$),$transformed_parent_bounds$jscomp$7$$=new $APP.$cljs$core$Delay$$(function(){return $app$common$geom$shapes$transforms$transform_bounds$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$60$$,$parent_id$jscomp$78$$)),$modifiers$jscomp$59$$)});return $has_modifiers_QMARK_$$&&$parent_QMARK_$jscomp$2$$&&!$root_QMARK_$jscomp$1$$?
$app$common$geom$modifiers$set_children_modifiers$$($modif_tree$jscomp$16$$,$children$jscomp$238$$,$objects$jscomp$439$$,$bounds$jscomp$60$$,$parent$jscomp$258$$,$transformed_parent_bounds$jscomp$7$$,$ignore_constraints$jscomp$2$$):$modif_tree$jscomp$16$$};
$app$common$geom$modifiers$set_modifiers_layout$cljs$0core$0IFn$0_invoke$0arity$05$$=function($objects$jscomp$441$$,$bounds$jscomp$62$$,$G__68508__$1_ignore_constraints$jscomp$4$$,$modif_tree$jscomp$17$$,$parent$jscomp$260$$){var $parent_id$jscomp$79$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$260$$),$root_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$parent_id$jscomp$79$$),$modifiers$jscomp$60$$=$app$common$types$modifiers$select_geometry$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modif_tree$jscomp$17$$,
$parent_id$jscomp$79$$),$APP.$cljs$cst$1810$modifiers$$)),$has_modifiers_QMARK_$jscomp$1$$=$app$common$types$modifiers$child_modifiers_QMARK_$$($modifiers$jscomp$60$$),$G__68508__$2_flex_layout_QMARK_$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$260$$),$grid_layout_QMARK_$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$260$$),$parent_QMARK_$jscomp$3$$=$APP.$app$common$files$helpers$group_like_shape_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$260$$)||
$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$260$$),$transformed_parent_bounds$jscomp$8$$=new $APP.$cljs$core$Delay$$(function(){return $app$common$geom$shapes$transforms$transform_bounds$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$62$$,$parent_id$jscomp$79$$)),$modifiers$jscomp$60$$)}),$children_modifiers$$=$G__68508__$2_flex_layout_QMARK_$$||$grid_layout_QMARK_$$?
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68494_SHARP_$$){return $APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$441$$,$p1__68494_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$260$$)):$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$260$$),$children_layout$$=$G__68508__$2_flex_layout_QMARK_$$||$grid_layout_QMARK_$$?$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68495_SHARP_$$){return $APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$441$$,
$p1__68495_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$260$$)):null;$G__68508__$1_ignore_constraints$jscomp$4$$=$has_modifiers_QMARK_$jscomp$1$$&&$parent_QMARK_$jscomp$3$$&&!$root_QMARK_$jscomp$2$$?$app$common$geom$modifiers$set_children_modifiers$$($modif_tree$jscomp$17$$,$children_modifiers$$,$objects$jscomp$441$$,$bounds$jscomp$62$$,$parent$jscomp$260$$,$transformed_parent_bounds$jscomp$8$$,$G__68508__$1_ignore_constraints$jscomp$4$$):$modif_tree$jscomp$17$$;
$G__68508__$2_flex_layout_QMARK_$$=$G__68508__$2_flex_layout_QMARK_$$?$app$common$geom$modifiers$set_flex_layout_modifiers$$($G__68508__$1_ignore_constraints$jscomp$4$$,$children_layout$$,$objects$jscomp$441$$,$bounds$jscomp$62$$,$parent$jscomp$260$$,$transformed_parent_bounds$jscomp$8$$):$G__68508__$1_ignore_constraints$jscomp$4$$;return $grid_layout_QMARK_$$?$app$common$geom$modifiers$set_grid_layout_modifiers$$($G__68508__$2_flex_layout_QMARK_$$,$objects$jscomp$441$$,$bounds$jscomp$62$$,$parent$jscomp$260$$,
$transformed_parent_bounds$jscomp$8$$):$G__68508__$2_flex_layout_QMARK_$$};
$app$common$geom$modifiers$propagate_modifiers_constraints$cljs$0core$0IFn$0_invoke$0arity$05$$=function($objects$jscomp$443$$,$bounds$jscomp$64$$,$ignore_constraints$jscomp$6$$,$modif_tree$jscomp$18$$,$shapes$jscomp$71$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__68509_SHARP_$$,$p2__68510_SHARP_$$){return $app$common$geom$modifiers$set_modifiers_constraints$$($objects$jscomp$443$$,$bounds$jscomp$64$$,$ignore_constraints$jscomp$6$$,$p1__68509_SHARP_$$,$p2__68510_SHARP_$$)},
$modif_tree$jscomp$18$$,$shapes$jscomp$71$$)};
$app$common$geom$modifiers$propagate_modifiers_layouts$cljs$0core$0IFn$0_invoke$0arity$05$$=function($objects$jscomp$445$$,$bounds$jscomp$66$$,$ignore_constraints$jscomp$8$$,$modif_tree$jscomp$19$$,$shapes$jscomp$73$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__68513_SHARP_$$,$p2__68514_SHARP_$$){return $app$common$geom$modifiers$set_modifiers_layout$cljs$0core$0IFn$0_invoke$0arity$05$$($objects$jscomp$445$$,$bounds$jscomp$66$$,$ignore_constraints$jscomp$8$$,
$p1__68513_SHARP_$$,$p2__68514_SHARP_$$)},$modif_tree$jscomp$19$$,$shapes$jscomp$73$$)};
$app$common$geom$modifiers$calc_auto_modifiers$$=function($objects$jscomp$446$$,$bounds$jscomp$67$$,$parent$jscomp$261$$){function $set_parent_auto_height$$($modifiers$jscomp$62$$,$auto_height$jscomp$1$$){var $origin$jscomp$35$$=$APP.$app$common$geom$shapes$points$origin$$($APP.$cljs$core$_deref$$($parent_bounds$jscomp$17$$)),$current_height$jscomp$1$$=$APP.$app$common$geom$shapes$points$height_points$$($APP.$cljs$core$_deref$$($parent_bounds$jscomp$17$$));return $APP.$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$05$$($modifiers$jscomp$62$$,
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,$auto_height$jscomp$1$$/$current_height$jscomp$1$$),$origin$jscomp$35$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$261$$),$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$261$$))}function $set_parent_auto_width$$($modifiers$jscomp$61$$,$auto_width$jscomp$1$$){var $origin$jscomp$34$$=$APP.$app$common$geom$shapes$points$origin$$($APP.$cljs$core$_deref$$($parent_bounds$jscomp$17$$)),
$current_width$jscomp$1$$=$APP.$app$common$geom$shapes$points$width_points$$($APP.$cljs$core$_deref$$($parent_bounds$jscomp$17$$));return $APP.$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$05$$($modifiers$jscomp$61$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($auto_width$jscomp$1$$/$current_width$jscomp$1$$,1),$origin$jscomp$34$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$261$$),$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$261$$))}
var $G__68535_G__68535__$1_content_bounds_parent_id$jscomp$80$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$261$$),$parent_bounds$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$67$$,$G__68535_G__68535__$1_content_bounds_parent_id$jscomp$80$$),$children$jscomp$239$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($app$common$geom$shapes$common$invalid_geometry_QMARK_$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$,
$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$446$$,$G__68535_G__68535__$1_content_bounds_parent_id$jscomp$80$$))),$auto_QMARK_$jscomp$8$$=function(){var $and__5023__auto__$jscomp$449_or__5025__auto__$jscomp$767$$=$app$common$types$shape$layout$auto_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$261$$);if($and__5023__auto__$jscomp$449_or__5025__auto__$jscomp$767$$)return $and__5023__auto__$jscomp$449_or__5025__auto__$jscomp$767$$;
$and__5023__auto__$jscomp$449_or__5025__auto__$jscomp$767$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$446$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$261$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$449_or__5025__auto__$jscomp$767$$)?$app$common$types$shape$layout$fill_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$261$$):$and__5023__auto__$jscomp$449_or__5025__auto__$jscomp$767$$}(),
$auto_width_QMARK_$jscomp$7$$=function(){var $and__5023__auto__$jscomp$450_or__5025__auto__$jscomp$768$$=$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$261$$);if($and__5023__auto__$jscomp$450_or__5025__auto__$jscomp$768$$)return $and__5023__auto__$jscomp$450_or__5025__auto__$jscomp$768$$;$and__5023__auto__$jscomp$450_or__5025__auto__$jscomp$768$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$446$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$261$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$450_or__5025__auto__$jscomp$768$$)?$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$261$$):$and__5023__auto__$jscomp$450_or__5025__auto__$jscomp$768$$}(),$auto_height_QMARK_$jscomp$6$$=function(){var $and__5023__auto__$jscomp$451_or__5025__auto__$jscomp$769$$=$APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$261$$);
if($and__5023__auto__$jscomp$451_or__5025__auto__$jscomp$769$$)return $and__5023__auto__$jscomp$451_or__5025__auto__$jscomp$769$$;$and__5023__auto__$jscomp$451_or__5025__auto__$jscomp$769$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$446$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$261$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$451_or__5025__auto__$jscomp$769$$)?$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$261$$):
$and__5023__auto__$jscomp$451_or__5025__auto__$jscomp$769$$}();$G__68535_G__68535__$1_content_bounds_parent_id$jscomp$80$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$452$$=$APP.$app$common$data$not_empty_QMARK_$$($children$jscomp$239$$);return $and__5023__auto__$jscomp$452$$?$auto_QMARK_$jscomp$8$$:$and__5023__auto__$jscomp$452$$}())?$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$261$$)?$APP.$app$common$geom$shapes$flex_layout$bounds$layout_content_bounds$$($bounds$jscomp$67$$,
$parent$jscomp$261$$,$children$jscomp$239$$,$objects$jscomp$446$$):$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$261$$)?function(){var $children__$1$jscomp$33_layout_data$jscomp$16$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($child$jscomp$115$$){var $temp__5825__auto__$jscomp$203$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$67$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$115$$));
return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$203$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$_deref$$($temp__5825__auto__$jscomp$203$$),$child$jscomp$115$$],null):null},$children$jscomp$239$$);$children__$1$jscomp$33_layout_data$jscomp$16$$=$APP.$app$common$geom$shapes$grid_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$($parent$jscomp$261$$,$APP.$cljs$core$_deref$$($parent_bounds$jscomp$17$$),$children__$1$jscomp$33_layout_data$jscomp$16$$,
$bounds$jscomp$67$$,$objects$jscomp$446$$);return $APP.$app$common$geom$shapes$grid_layout$bounds$layout_content_bounds$$($bounds$jscomp$67$$,$parent$jscomp$261$$,$children__$1$jscomp$33_layout_data$jscomp$16$$)}():null:null;var $auto_width$$=$APP.$cljs$core$truth_$$($G__68535_G__68535__$1_content_bounds_parent_id$jscomp$80$$)?$APP.$app$common$geom$shapes$points$width_points$$($G__68535_G__68535__$1_content_bounds_parent_id$jscomp$80$$):null,$auto_height$$=$APP.$cljs$core$truth_$$($G__68535_G__68535__$1_content_bounds_parent_id$jscomp$80$$)?
$APP.$app$common$geom$shapes$points$height_points$$($G__68535_G__68535__$1_content_bounds_parent_id$jscomp$80$$):null;$G__68535_G__68535__$1_content_bounds_parent_id$jscomp$80$$=$APP.$app$common$types$modifiers$empty$$();$G__68535_G__68535__$1_content_bounds_parent_id$jscomp$80$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$453$$=$auto_width$$!=null;return $and__5023__auto__$jscomp$453$$?$auto_width_QMARK_$jscomp$7$$:$and__5023__auto__$jscomp$453$$}())?$set_parent_auto_width$$($G__68535_G__68535__$1_content_bounds_parent_id$jscomp$80$$,
$auto_width$$):$G__68535_G__68535__$1_content_bounds_parent_id$jscomp$80$$;return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$454$$=$auto_height$$!=null;return $and__5023__auto__$jscomp$454$$?$auto_height_QMARK_$jscomp$6$$:$and__5023__auto__$jscomp$454$$}())?$set_parent_auto_height$$($G__68535_G__68535__$1_content_bounds_parent_id$jscomp$80$$,$auto_height$$):$G__68535_G__68535__$1_content_bounds_parent_id$jscomp$80$$};
$app$common$geom$modifiers$find_auto_layouts$$=function($objects$jscomp$447$$,$shapes$jscomp$74$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($objects__$1$jscomp$16$$){return function($shape$jscomp$518$$){var $JSCompiler_inline_result$jscomp$1159_and__5023__auto__$jscomp$inline_6735_or__5025__auto__$jscomp$inline_6734$$=$app$common$types$shape$layout$auto_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$518$$);
$JSCompiler_inline_result$jscomp$1159_and__5023__auto__$jscomp$inline_6735_or__5025__auto__$jscomp$inline_6734$$||($JSCompiler_inline_result$jscomp$1159_and__5023__auto__$jscomp$inline_6735_or__5025__auto__$jscomp$inline_6734$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$16$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$518$$)),$JSCompiler_inline_result$jscomp$1159_and__5023__auto__$jscomp$inline_6735_or__5025__auto__$jscomp$inline_6734$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1159_and__5023__auto__$jscomp$inline_6735_or__5025__auto__$jscomp$inline_6734$$)?$app$common$types$shape$layout$fill_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$518$$):$JSCompiler_inline_result$jscomp$1159_and__5023__auto__$jscomp$inline_6735_or__5025__auto__$jscomp$inline_6734$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1159_and__5023__auto__$jscomp$inline_6735_or__5025__auto__$jscomp$inline_6734$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$518$$):
null}}($objects$jscomp$447$$)),$shapes$jscomp$74$$)};
$app$common$geom$modifiers$sizing_auto_modifiers$$=function($modif_tree$jscomp$20$$,$sizing_auto_layouts$$,$objects$jscomp$449$$,$bounds$jscomp$68$$,$ignore_constraints$jscomp$9$$){return $APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($bounds__$1$jscomp$5_bounds__$2_p__68540$$,$auto_modif_tree_auto_modif_tree__$1_layout_id$jscomp$1$$){var $modif_tree__$1$jscomp$8_modif_tree__$2$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bounds__$1$jscomp$5_bounds__$2_p__68540$$,0,
null);$bounds__$1$jscomp$5_bounds__$2_p__68540$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bounds__$1$jscomp$5_bounds__$2_p__68540$$,1,null);var $from_layout_layout$jscomp$6_shapes$jscomp$75$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$449$$,$auto_modif_tree_auto_modif_tree__$1_layout_id$jscomp$1$$),$auto_modifiers$$=$app$common$geom$modifiers$calc_auto_modifiers$$($objects$jscomp$449$$,$bounds__$1$jscomp$5_bounds__$2_p__68540$$,$from_layout_layout$jscomp$6_shapes$jscomp$75$$);
if($app$common$types$modifiers$empty_QMARK_$$($auto_modifiers$$)&&!$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($from_layout_layout$jscomp$6_shapes$jscomp$75$$))return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$modif_tree__$1$jscomp$8_modif_tree__$2$jscomp$2$$,$bounds__$1$jscomp$5_bounds__$2_p__68540$$],null);$from_layout_layout$jscomp$6_shapes$jscomp$75$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($sizing_auto_layouts$$,
$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$449$$,$auto_modif_tree_auto_modif_tree__$1_layout_id$jscomp$1$$));if($APP.$cljs$core$truth_$$($from_layout_layout$jscomp$6_shapes$jscomp$75$$)){var $JSCompiler_temp$jscomp$10869_layout_justify_content$jscomp$inline_12629$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$449$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from_layout_layout$jscomp$6_shapes$jscomp$75$$,
$APP.$cljs$cst$1689$layout_justify_content$$],null));$JSCompiler_temp$jscomp$10869_layout_justify_content$jscomp$inline_12629$$=!$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1665$space_around$$,null,$APP.$cljs$cst$1666$space_evenly$$,null,$APP.$cljs$cst$1667$center$$,null,$APP.$cljs$cst$1293$end$$,null,$APP.$cljs$cst$1669$stretch$$,null],null),null),$JSCompiler_temp$jscomp$10869_layout_justify_content$jscomp$inline_12629$$)}else $JSCompiler_temp$jscomp$10869_layout_justify_content$jscomp$inline_12629$$=
$from_layout_layout$jscomp$6_shapes$jscomp$75$$;$from_layout_layout$jscomp$6_shapes$jscomp$75$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10869_layout_justify_content$jscomp$inline_12629$$)?$app$common$geom$shapes$tree_seq$resolve_subtree$$($from_layout_layout$jscomp$6_shapes$jscomp$75$$,$auto_modif_tree_auto_modif_tree__$1_layout_id$jscomp$1$$,$objects$jscomp$449$$):$app$common$geom$shapes$tree_seq$resolve_tree$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$auto_modif_tree_auto_modif_tree__$1_layout_id$jscomp$1$$]),
$objects$jscomp$449$$);$auto_modif_tree_auto_modif_tree__$1_layout_id$jscomp$1$$=$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$auto_modif_tree_auto_modif_tree__$1_layout_id$jscomp$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1810$modifiers$$,$auto_modifiers$$],null)]);$auto_modif_tree_auto_modif_tree__$1_layout_id$jscomp$1$$=$app$common$geom$modifiers$propagate_modifiers_layouts$cljs$0core$0IFn$0_invoke$0arity$05$$($objects$jscomp$449$$,$bounds__$1$jscomp$5_bounds__$2_p__68540$$,
$ignore_constraints$jscomp$9$$,$auto_modif_tree_auto_modif_tree__$1_layout_id$jscomp$1$$,$from_layout_layout$jscomp$6_shapes$jscomp$75$$);$bounds__$1$jscomp$5_bounds__$2_p__68540$$=$app$common$geom$bounds_map$transform_bounds_map$cljs$0core$0IFn$0_invoke$0arity$04$$($bounds__$1$jscomp$5_bounds__$2_p__68540$$,$objects$jscomp$449$$,$auto_modif_tree_auto_modif_tree__$1_layout_id$jscomp$1$$,null);$modif_tree__$1$jscomp$8_modif_tree__$2$jscomp$2$$=$app$common$geom$modif_tree$merge_modif_tree$$($modif_tree__$1$jscomp$8_modif_tree__$2$jscomp$2$$,
$auto_modif_tree_auto_modif_tree__$1_layout_id$jscomp$1$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$modif_tree__$1$jscomp$8_modif_tree__$2$jscomp$2$$,$bounds__$1$jscomp$5_bounds__$2_p__68540$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$modif_tree$jscomp$20$$,$bounds$jscomp$68$$],null),$APP.$cljs$core$reverse$$($sizing_auto_layouts$$)))};
$app$common$geom$modifiers$filter_layouts_ids$$=function($objects$jscomp$450$$,$modif_tree$jscomp$21$$){return $APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($map__68548_map__68548__$1_modifiers$jscomp$63_p__68544$$){var $and__5023__auto__$jscomp$457_id$jscomp$534$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__68548_map__68548__$1_modifiers$jscomp$63_p__68544$$,
0,null);$map__68548_map__68548__$1_modifiers$jscomp$63_p__68544$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__68548_map__68548__$1_modifiers$jscomp$63_p__68544$$,1,null);$map__68548_map__68548__$1_modifiers$jscomp$63_p__68544$$=$APP.$cljs$core$__destructure_map$$($map__68548_map__68548__$1_modifiers$jscomp$63_p__68544$$);$map__68548_map__68548__$1_modifiers$jscomp$63_p__68544$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68548_map__68548__$1_modifiers$jscomp$63_p__68544$$,
$APP.$cljs$cst$1810$modifiers$$);var $or__5025__auto__$jscomp$771$$=$app$common$types$modifiers$empty_QMARK_$$($map__68548_map__68548__$1_modifiers$jscomp$63_p__68544$$);if($or__5025__auto__$jscomp$771$$)return $or__5025__auto__$jscomp$771$$;$and__5023__auto__$jscomp$457_id$jscomp$534$$=$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$450$$,$and__5023__auto__$jscomp$457_id$jscomp$534$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$457_id$jscomp$534$$)?
$app$common$types$modifiers$only_move_QMARK_$$($map__68548_map__68548__$1_modifiers$jscomp$63_p__68544$$):$and__5023__auto__$jscomp$457_id$jscomp$534$$},$modif_tree$jscomp$21$$)))};$APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$=function($modif_tree$jscomp$22$$,$objects$jscomp$451$$){return $APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$(null,$modif_tree$jscomp$22$$,$objects$jscomp$451$$,null)};
$APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$=function($old_modif_tree$$,$modif_tree$jscomp$24_modif_tree__$1$jscomp$9_modif_tree__$2$jscomp$3_modif_tree__$3$$,$objects$jscomp$453_objects__$1$jscomp$17$$,$ignore_constraints$jscomp$10_modif_tree__$4_p__68551$$){var $map__68552__$1_shapes_tree_layout_sizing_auto_layouts$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($ignore_constraints$jscomp$10_modif_tree__$4_p__68551$$);$ignore_constraints$jscomp$10_modif_tree__$4_p__68551$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68552__$1_shapes_tree_layout_sizing_auto_layouts$jscomp$1$$,$APP.$cljs$cst$3821$ignore_constraints$$,!1);var $bounds_map__$1_bounds_map__$2_snap_pixel_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68552__$1_shapes_tree_layout_sizing_auto_layouts$jscomp$1$$,$APP.$cljs$cst$3822$snap_pixel_QMARK_$$,!1),$modif_tree_layout_snap_precision$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68552__$1_shapes_tree_layout_sizing_auto_layouts$jscomp$1$$,
$cljs$cst$3823$snap_precision$$,1),$snap_ignore_axis$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68552__$1_shapes_tree_layout_sizing_auto_layouts$jscomp$1$$,$cljs$cst$3824$snap_ignore_axis$$,null);$objects$jscomp$453_objects__$1$jscomp$17$$=$app$common$geom$modif_tree$apply_structure_modifiers$$($old_modif_tree$$!=null?$app$common$geom$modif_tree$apply_structure_modifiers$$($objects$jscomp$453_objects__$1$jscomp$17$$,$old_modif_tree$$):$objects$jscomp$453_objects__$1$jscomp$17$$,
$modif_tree$jscomp$24_modif_tree__$1$jscomp$9_modif_tree__$2$jscomp$3_modif_tree__$3$$);var $shapes_tree_all$$=$app$common$geom$shapes$tree_seq$resolve_tree$$($APP.$cljs$core$set$$($APP.$cljs$core$keys$$($modif_tree$jscomp$24_modif_tree__$1$jscomp$9_modif_tree__$2$jscomp$3_modif_tree__$3$$)),$objects$jscomp$453_objects__$1$jscomp$17$$);$map__68552__$1_shapes_tree_layout_sizing_auto_layouts$jscomp$1$$=$app$common$geom$shapes$tree_seq$resolve_tree$$($app$common$geom$modifiers$filter_layouts_ids$$($objects$jscomp$453_objects__$1$jscomp$17$$,
$modif_tree$jscomp$24_modif_tree__$1$jscomp$9_modif_tree__$2$jscomp$3_modif_tree__$3$$),$objects$jscomp$453_objects__$1$jscomp$17$$);var $G__68555$jscomp$inline_12631_bounds_map$jscomp$6$$=$app$common$geom$bounds_map$objects__GT_bounds_map$$($objects$jscomp$453_objects__$1$jscomp$17$$);$G__68555$jscomp$inline_12631_bounds_map$jscomp$6$$=$old_modif_tree$$!=null?$app$common$geom$bounds_map$transform_bounds_map$cljs$0core$0IFn$0_invoke$0arity$04$$($G__68555$jscomp$inline_12631_bounds_map$jscomp$6$$,
$objects$jscomp$453_objects__$1$jscomp$17$$,$old_modif_tree$$,null):$G__68555$jscomp$inline_12631_bounds_map$jscomp$6$$;$modif_tree$jscomp$24_modif_tree__$1$jscomp$9_modif_tree__$2$jscomp$3_modif_tree__$3$$=$APP.$cljs$core$truth_$$($bounds_map__$1_bounds_map__$2_snap_pixel_QMARK_$$)?$app$common$geom$shapes$pixel_precision$adjust_pixel_precision$$($modif_tree$jscomp$24_modif_tree__$1$jscomp$9_modif_tree__$2$jscomp$3_modif_tree__$3$$,$objects$jscomp$453_objects__$1$jscomp$17$$,$modif_tree_layout_snap_precision$$,
$snap_ignore_axis$$):$modif_tree$jscomp$24_modif_tree__$1$jscomp$9_modif_tree__$2$jscomp$3_modif_tree__$3$$;$modif_tree$jscomp$24_modif_tree__$1$jscomp$9_modif_tree__$2$jscomp$3_modif_tree__$3$$=$app$common$geom$modifiers$propagate_modifiers_constraints$cljs$0core$0IFn$0_invoke$0arity$05$$($objects$jscomp$453_objects__$1$jscomp$17$$,$G__68555$jscomp$inline_12631_bounds_map$jscomp$6$$,$ignore_constraints$jscomp$10_modif_tree__$4_p__68551$$,$modif_tree$jscomp$24_modif_tree__$1$jscomp$9_modif_tree__$2$jscomp$3_modif_tree__$3$$,
$shapes_tree_all$$);$bounds_map__$1_bounds_map__$2_snap_pixel_QMARK_$$=$app$common$geom$bounds_map$transform_bounds_map$cljs$0core$0IFn$0_invoke$0arity$04$$($G__68555$jscomp$inline_12631_bounds_map$jscomp$6$$,$objects$jscomp$453_objects__$1$jscomp$17$$,$modif_tree$jscomp$24_modif_tree__$1$jscomp$9_modif_tree__$2$jscomp$3_modif_tree__$3$$,null);$modif_tree_layout_snap_precision$$=$app$common$geom$modifiers$propagate_modifiers_layouts$cljs$0core$0IFn$0_invoke$0arity$05$$($objects$jscomp$453_objects__$1$jscomp$17$$,
$bounds_map__$1_bounds_map__$2_snap_pixel_QMARK_$$,$ignore_constraints$jscomp$10_modif_tree__$4_p__68551$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$map__68552__$1_shapes_tree_layout_sizing_auto_layouts$jscomp$1$$);$modif_tree$jscomp$24_modif_tree__$1$jscomp$9_modif_tree__$2$jscomp$3_modif_tree__$3$$=$app$common$geom$modif_tree$merge_modif_tree$$($modif_tree$jscomp$24_modif_tree__$1$jscomp$9_modif_tree__$2$jscomp$3_modif_tree__$3$$,$modif_tree_layout_snap_precision$$);$bounds_map__$1_bounds_map__$2_snap_pixel_QMARK_$$=
$app$common$geom$bounds_map$transform_bounds_map$cljs$0core$0IFn$0_invoke$0arity$04$$($bounds_map__$1_bounds_map__$2_snap_pixel_QMARK_$$,$objects$jscomp$453_objects__$1$jscomp$17$$,$modif_tree_layout_snap_precision$$,null);$map__68552__$1_shapes_tree_layout_sizing_auto_layouts$jscomp$1$$=$app$common$geom$modifiers$find_auto_layouts$$($objects$jscomp$453_objects__$1$jscomp$17$$,$map__68552__$1_shapes_tree_layout_sizing_auto_layouts$jscomp$1$$);$ignore_constraints$jscomp$10_modif_tree__$4_p__68551$$=
$app$common$geom$modifiers$sizing_auto_modifiers$$($modif_tree$jscomp$24_modif_tree__$1$jscomp$9_modif_tree__$2$jscomp$3_modif_tree__$3$$,$map__68552__$1_shapes_tree_layout_sizing_auto_layouts$jscomp$1$$,$objects$jscomp$453_objects__$1$jscomp$17$$,$bounds_map__$1_bounds_map__$2_snap_pixel_QMARK_$$,$ignore_constraints$jscomp$10_modif_tree__$4_p__68551$$);return $APP.$cljs$core$truth_$$($old_modif_tree$$)?$app$common$geom$modif_tree$merge_modif_tree$$($old_modif_tree$$,$ignore_constraints$jscomp$10_modif_tree__$4_p__68551$$):
$ignore_constraints$jscomp$10_modif_tree__$4_p__68551$$};
$app$main$data$workspace$modifiers$check_delta$$=function($selrect$jscomp$52_shape$jscomp$519$$,$JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$,$and__5023__auto____$2$jscomp$33_transformed_selrect_transformed_shape$$,$and__5023__auto__$jscomp$458_and__5023__auto____$1$jscomp$84_distance$jscomp$5_dx$jscomp$inline_12635_transformed_root$$){$JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$)?
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($app$common$geom$shapes$left_bound$$($selrect$jscomp$52_shape$jscomp$519$$)-$app$common$geom$shapes$left_bound$$($JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$),$app$common$geom$shapes$top_bound$$($selrect$jscomp$52_shape$jscomp$519$$)-$app$common$geom$shapes$top_bound$$($JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$)):null;var $transformed_shape_delta$$=
$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$458_and__5023__auto____$1$jscomp$84_distance$jscomp$5_dx$jscomp$inline_12635_transformed_root$$)?$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($app$common$geom$shapes$left_bound$$($and__5023__auto____$2$jscomp$33_transformed_selrect_transformed_shape$$)-$app$common$geom$shapes$left_bound$$($and__5023__auto__$jscomp$458_and__5023__auto____$1$jscomp$84_distance$jscomp$5_dx$jscomp$inline_12635_transformed_root$$),$app$common$geom$shapes$top_bound$$($and__5023__auto____$2$jscomp$33_transformed_selrect_transformed_shape$$)-
$app$common$geom$shapes$top_bound$$($and__5023__auto__$jscomp$458_and__5023__auto____$1$jscomp$84_distance$jscomp$5_dx$jscomp$inline_12635_transformed_root$$)):null;$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$)?$transformed_shape_delta$$:$JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$)?($and__5023__auto__$jscomp$458_and__5023__auto____$1$jscomp$84_distance$jscomp$5_dx$jscomp$inline_12635_transformed_root$$=
($JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$,$APP.$cljs$cst$1510$x$$))-($transformed_shape_delta$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transformed_shape_delta$$,$APP.$cljs$cst$1510$x$$)),$JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$=
($JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$,$APP.$cljs$cst$1511$y$$))-($transformed_shape_delta$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transformed_shape_delta$$,$APP.$cljs$cst$1511$y$$)),$JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$=
$APP.$app$common$geom$point$pos__GT_Point$$($APP.$app$common$math$abs$$($and__5023__auto__$jscomp$458_and__5023__auto____$1$jscomp$84_distance$jscomp$5_dx$jscomp$inline_12635_transformed_root$$),$APP.$app$common$math$abs$$($JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$))):$JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0);$and__5023__auto__$jscomp$458_and__5023__auto____$1$jscomp$84_distance$jscomp$5_dx$jscomp$inline_12635_transformed_root$$=
$JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$;$JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$=$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$52_shape$jscomp$519$$)!=null&&$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$52_shape$jscomp$519$$)!=null?$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto____$2$jscomp$33_transformed_selrect_transformed_shape$$)-
$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$52_shape$jscomp$519$$):0;$selrect$jscomp$52_shape$jscomp$519$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$52_shape$jscomp$519$$);$and__5023__auto____$2$jscomp$33_transformed_selrect_transformed_shape$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto____$2$jscomp$33_transformed_selrect_transformed_shape$$);return($and__5023__auto__$jscomp$458_and__5023__auto____$1$jscomp$84_distance$jscomp$5_dx$jscomp$inline_12635_transformed_root$$=
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$458_and__5023__auto____$1$jscomp$84_distance$jscomp$5_dx$jscomp$inline_12635_transformed_root$$)<1&&$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$458_and__5023__auto____$1$jscomp$84_distance$jscomp$5_dx$jscomp$inline_12635_transformed_root$$)<1)?($and__5023__auto__$jscomp$458_and__5023__auto____$1$jscomp$84_distance$jscomp$5_dx$jscomp$inline_12635_transformed_root$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$52_shape$jscomp$519$$),
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto____$2$jscomp$33_transformed_selrect_transformed_shape$$)),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$458_and__5023__auto____$1$jscomp$84_distance$jscomp$5_dx$jscomp$inline_12635_transformed_root$$)?($and__5023__auto____$2$jscomp$33_transformed_selrect_transformed_shape$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$52_shape$jscomp$519$$),
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto____$2$jscomp$33_transformed_selrect_transformed_shape$$)),$APP.$cljs$core$truth_$$($and__5023__auto____$2$jscomp$33_transformed_selrect_transformed_shape$$)?$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$10737_dy$jscomp$inline_12636_root$jscomp$53_rotation_delta_shape_delta$$,0):$and__5023__auto____$2$jscomp$33_transformed_selrect_transformed_shape$$):$and__5023__auto__$jscomp$458_and__5023__auto____$1$jscomp$84_distance$jscomp$5_dx$jscomp$inline_12635_transformed_root$$):
$and__5023__auto__$jscomp$458_and__5023__auto____$1$jscomp$84_distance$jscomp$5_dx$jscomp$inline_12635_transformed_root$$};
$app$main$data$workspace$modifiers$calculate_ignore_tree$$=function($modif_tree$jscomp$25$$,$objects$jscomp$454$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function(){function $app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree__5$$($ignore_tree$jscomp$7_ignore_tree__$1$$,$shape$jscomp$522$$,$transformed_shape$jscomp$3$$,$root$jscomp$56$$,$transformed_root$jscomp$3$$){var $shape_id$jscomp$93$$=$shape$jscomp$522$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$522$$,
$APP.$cljs$cst$266$id$$);$ignore_tree$jscomp$7_ignore_tree__$1$$=$root$jscomp$56$$!=null&&$APP.$app$common$types$component$in_component_copy_QMARK_$$($shape$jscomp$522$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($ignore_tree$jscomp$7_ignore_tree__$1$$,$shape_id$jscomp$93$$,$app$main$data$workspace$modifiers$check_delta$$($shape$jscomp$522$$,$root$jscomp$56$$,$transformed_shape$jscomp$3$$,$transformed_root$jscomp$3$$)):$ignore_tree$jscomp$7_ignore_tree__$1$$;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ignore_tree__$2$$,
$child$jscomp$116$$){return $app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree$$.$cljs$core$IFn$_invoke$arity$4$($ignore_tree__$2$$,$child$jscomp$116$$,$root$jscomp$56$$,$transformed_root$jscomp$3$$)},$ignore_tree$jscomp$7_ignore_tree__$1$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$454$$),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$522$$)))}function $app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree__4$$($ignore_tree$jscomp$6$$,
$shape$jscomp$521$$,$root$jscomp$55$$,$transformed_root$jscomp$2$$){var $shape_id$jscomp$92_transformed_shape$jscomp$2$$=$shape$jscomp$521$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$521$$,$APP.$cljs$cst$266$id$$);$shape_id$jscomp$92_transformed_shape$jscomp$2$$=$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$521$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modif_tree$jscomp$25$$,
$shape_id$jscomp$92_transformed_shape$jscomp$2$$),$APP.$cljs$cst$1810$modifiers$$));return $app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree$$.$cljs$core$IFn$_invoke$arity$5$($ignore_tree$jscomp$6$$,$shape$jscomp$521$$,$shape_id$jscomp$92_transformed_shape$jscomp$2$$,$root$jscomp$55$$,$transformed_root$jscomp$2$$)}function $app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree__2$$($ignore_tree$jscomp$5$$,$shape$jscomp$520$$){var $shape_id$jscomp$91_transformed_shape$jscomp$1$$=
$shape$jscomp$520$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$520$$,$APP.$cljs$cst$266$id$$);$shape_id$jscomp$91_transformed_shape$jscomp$1$$=$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$520$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modif_tree$jscomp$25$$,$shape_id$jscomp$91_transformed_shape$jscomp$1$$),$APP.$cljs$cst$1810$modifiers$$));var $root$jscomp$54$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$520$$))?$shape$jscomp$520$$:$app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$454$$,$shape$jscomp$520$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2547$allow_main_QMARK_$$,!0],null)),$transformed_root$jscomp$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$520$$))?
$shape_id$jscomp$91_transformed_shape$jscomp$1$$:$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($root$jscomp$54$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modif_tree$jscomp$25$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$54$$)),$APP.$cljs$cst$1810$modifiers$$));return $app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree$$.$cljs$core$IFn$_invoke$arity$5$($ignore_tree$jscomp$5$$,
$shape$jscomp$520$$,$shape_id$jscomp$91_transformed_shape$jscomp$1$$,$root$jscomp$54$$,$transformed_root$jscomp$1$$)}var $app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree$$=null;$app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree$$=function($ignore_tree$jscomp$8$$,$shape$jscomp$523$$,$transformed_shape$jscomp$4$$,$root$jscomp$57$$,$transformed_root$jscomp$4$$){switch(arguments.length){case 2:return $app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree__2$$.call(this,
$ignore_tree$jscomp$8$$,$shape$jscomp$523$$);case 4:return $app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree__4$$.call(this,$ignore_tree$jscomp$8$$,$shape$jscomp$523$$,$transformed_shape$jscomp$4$$,$root$jscomp$57$$);case 5:return $app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree__5$$.call(this,$ignore_tree$jscomp$8$$,$shape$jscomp$523$$,$transformed_shape$jscomp$4$$,$root$jscomp$57$$,$transformed_root$jscomp$4$$)}throw Error("Invalid arity: "+arguments.length);
};$app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree$$.$cljs$core$IFn$_invoke$arity$2$=$app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree__2$$;$app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree$$.$cljs$core$IFn$_invoke$arity$4$=$app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree__4$$;$app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree$$.$cljs$core$IFn$_invoke$arity$5$=$app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree__5$$;
return $app$main$data$workspace$modifiers$calculate_ignore_tree_$_get_ignore_tree$$}(),null,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68591_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$454$$,$p1__68591_SHARP_$$)},$APP.$cljs$core$keys$$($modif_tree$jscomp$25$$)))};
$app$main$data$workspace$modifiers$calculate_ignore_tree_wasm$$=function($transforms$$,$objects$jscomp$455$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function(){function $app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree__5$$($ignore_tree$jscomp$11_ignore_tree__$1$jscomp$1$$,$shape$jscomp$526$$,$transformed_shape$jscomp$7$$,$root$jscomp$60$$,$transformed_root$jscomp$7$$){var $shape_id$jscomp$96$$=$shape$jscomp$526$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$526$$,
$APP.$cljs$cst$266$id$$);$ignore_tree$jscomp$11_ignore_tree__$1$jscomp$1$$=$root$jscomp$60$$!=null&&$APP.$app$common$types$component$in_component_copy_QMARK_$$($shape$jscomp$526$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($ignore_tree$jscomp$11_ignore_tree__$1$jscomp$1$$,$shape_id$jscomp$96$$,$app$main$data$workspace$modifiers$check_delta$$($shape$jscomp$526$$,$root$jscomp$60$$,$transformed_shape$jscomp$7$$,$transformed_root$jscomp$7$$)):$ignore_tree$jscomp$11_ignore_tree__$1$jscomp$1$$;
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ignore_tree__$2$jscomp$1$$,$child$jscomp$117$$){return $app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree$$.$cljs$core$IFn$_invoke$arity$4$($ignore_tree__$2$jscomp$1$$,$child$jscomp$117$$,$root$jscomp$60$$,$transformed_root$jscomp$7$$)},$ignore_tree$jscomp$11_ignore_tree__$1$jscomp$1$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$455$$),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$526$$)))}
function $app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree__4$$($ignore_tree$jscomp$10$$,$shape$jscomp$525$$,$root$jscomp$59$$,$transformed_root$jscomp$6$$){var $shape_id$jscomp$95_transformed_shape$jscomp$6$$=$shape$jscomp$525$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$525$$,$APP.$cljs$cst$266$id$$);$shape_id$jscomp$95_transformed_shape$jscomp$6$$=$APP.$app$common$geom$shapes$apply_transform$$($shape$jscomp$525$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transforms$$,
$shape_id$jscomp$95_transformed_shape$jscomp$6$$));return $app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree$$.$cljs$core$IFn$_invoke$arity$5$($ignore_tree$jscomp$10$$,$shape$jscomp$525$$,$shape_id$jscomp$95_transformed_shape$jscomp$6$$,$root$jscomp$59$$,$transformed_root$jscomp$6$$)}function $app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree__2$$($ignore_tree$jscomp$9$$,$shape$jscomp$524$$){var $shape_id$jscomp$94_transformed_shape$jscomp$5$$=
$shape$jscomp$524$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$524$$,$APP.$cljs$cst$266$id$$);$shape_id$jscomp$94_transformed_shape$jscomp$5$$=$APP.$app$common$geom$shapes$apply_transform$$($shape$jscomp$524$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transforms$$,$shape_id$jscomp$94_transformed_shape$jscomp$5$$));var $root$jscomp$58$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$524$$))?$shape$jscomp$524$$:
$app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$455$$,$shape$jscomp$524$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2547$allow_main_QMARK_$$,!0],null)),$transformed_root$jscomp$5$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$524$$))?$shape_id$jscomp$94_transformed_shape$jscomp$5$$:$APP.$app$common$geom$shapes$apply_transform$$($root$jscomp$58$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transforms$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$58$$)));return $app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree$$.$cljs$core$IFn$_invoke$arity$5$($ignore_tree$jscomp$9$$,$shape$jscomp$524$$,$shape_id$jscomp$94_transformed_shape$jscomp$5$$,$root$jscomp$58$$,$transformed_root$jscomp$5$$)}var $app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree$$=null;$app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree$$=
function($ignore_tree$jscomp$12$$,$shape$jscomp$527$$,$transformed_shape$jscomp$8$$,$root$jscomp$61$$,$transformed_root$jscomp$8$$){switch(arguments.length){case 2:return $app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree__2$$.call(this,$ignore_tree$jscomp$12$$,$shape$jscomp$527$$);case 4:return $app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree__4$$.call(this,$ignore_tree$jscomp$12$$,$shape$jscomp$527$$,$transformed_shape$jscomp$8$$,$root$jscomp$61$$);
case 5:return $app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree__5$$.call(this,$ignore_tree$jscomp$12$$,$shape$jscomp$527$$,$transformed_shape$jscomp$8$$,$root$jscomp$61$$,$transformed_root$jscomp$8$$)}throw Error("Invalid arity: "+arguments.length);};$app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree$$.$cljs$core$IFn$_invoke$arity$2$=$app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree__2$$;$app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree$$.$cljs$core$IFn$_invoke$arity$4$=
$app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree__4$$;$app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree$$.$cljs$core$IFn$_invoke$arity$5$=$app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree__5$$;return $app$main$data$workspace$modifiers$calculate_ignore_tree_wasm_$_get_ignore_tree$$}(),null,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68594_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$455$$,
$p1__68594_SHARP_$$)},$APP.$cljs$core$keys$$($transforms$$)))};
$app$main$data$workspace$modifiers$set_wasm_props_BANG_$$=function($objects$jscomp$456$$,$clean_props_objects_changed_prev_wasm_props_wasm_props__$1$$,$shape_changes$jscomp$2_wasm_props$$){$clean_props_objects_changed_prev_wasm_props_wasm_props__$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($map__68603_map__68603__$1_p__68599$$){var $id$jscomp$535$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__68603_map__68603__$1_p__68599$$,0,null);$map__68603_map__68603__$1_p__68599$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__68603_map__68603__$1_p__68599$$,1,null);$map__68603_map__68603__$1_p__68599$$=$APP.$cljs$core$__destructure_map$$($map__68603_map__68603__$1_p__68599$$);var $property$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68603_map__68603__$1_p__68599$$,$cljs$cst$827$property$$),$shape$jscomp$529$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$456$$,$id$jscomp$535$$);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$535$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__68603_map__68603__$1_p__68599$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$529$$,$property$jscomp$31$$))],null)},$clean_props_objects_changed_prev_wasm_props_wasm_props__$1$$);$clean_props_objects_changed_prev_wasm_props_wasm_props__$1$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($clean_props_objects_changed_prev_wasm_props_wasm_props__$1$$,
$shape_changes$jscomp$2_wasm_props$$);$shape_changes$jscomp$2_wasm_props$$=$APP.$cljs$core$update_vals$$($APP.$cljs$core$group_by$$($APP.$cljs$core$first$$,$clean_props_objects_changed_prev_wasm_props_wasm_props__$1$$),function($p1__68598_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$827$property$$,$APP.$cljs$core$second$$)),
$p1__68598_SHARP_$$)});$clean_props_objects_changed_prev_wasm_props_wasm_props__$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects__$1$jscomp$18$$,$p__68605_properties$jscomp$95_shape$jscomp$530$$){var $id$jscomp$536$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68605_properties$jscomp$95_shape$jscomp$530$$,0,null);$p__68605_properties$jscomp$95_shape$jscomp$530$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68605_properties$jscomp$95_shape$jscomp$530$$,
1,null);$p__68605_properties$jscomp$95_shape$jscomp$530$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($shape$jscomp$531$$,$operation$jscomp$3_p__68609$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($operation$jscomp$3_p__68609$$,0,null);$operation$jscomp$3_p__68609$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($operation$jscomp$3_p__68609$$,1,null);return $app$common$types$modifiers$apply_modifier$$($shape$jscomp$531$$,$operation$jscomp$3_p__68609$$)},
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$18$$,$id$jscomp$536$$),$p__68605_properties$jscomp$95_shape$jscomp$530$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($objects__$1$jscomp$18$$,$id$jscomp$536$$,$p__68605_properties$jscomp$95_shape$jscomp$530$$)},$objects$jscomp$456$$,$APP.$cljs$core$group_by$$($APP.$cljs$core$first$$,$clean_props_objects_changed_prev_wasm_props_wasm_props__$1$$));return $app$render_wasm$shape$process_shape_changes_BANG_$$($clean_props_objects_changed_prev_wasm_props_wasm_props__$1$$,
$shape_changes$jscomp$2_wasm_props$$)};
$app$main$data$workspace$modifiers$clear_local_transform$$=function(){typeof $app$main$data$workspace$modifiers$clear_local_transform_68613$$==="undefined"&&($app$main$data$workspace$modifiers$clear_local_transform_68613$$=function($meta68614$$){this.$meta68614$=$meta68614$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$modifiers$clear_local_transform_68613$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$modifiers$clear_local_transform_68613$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3825$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_clear_local_transform$$},$app$main$data$workspace$modifiers$clear_local_transform_68613$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68615$$,$meta68614__$1$$){return new $app$main$data$workspace$modifiers$clear_local_transform_68613$$($meta68614__$1$$)},$app$main$data$workspace$modifiers$clear_local_transform_68613$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta68614$},$app$main$data$workspace$modifiers$clear_local_transform_68613$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$clear_local_transform_68613$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2029_code__52999__auto__$jscomp$inline_12642_code_num__52998__auto__$jscomp$inline_12641_fn_54292$jscomp$inline_12638_read_code_fn__52997__auto__$jscomp$inline_12640$$,$cause54293$jscomp$inline_12639_state$jscomp$439$$){if($APP.$app$main$features$active_feature_QMARK_$$($cause54293$jscomp$inline_12639_state$jscomp$439$$,
"render-wasm/v1")){if($APP.$cljs$core$compare_and_set_BANG_$$($app$render_wasm$gesture$interactive_transform_active_QMARK_$$,!0,!1)&&$APP.$app$render_wasm$api$initialized_QMARK_$$()){$_$jscomp$2029_code__52999__auto__$jscomp$inline_12642_code_num__52998__auto__$jscomp$inline_12641_fn_54292$jscomp$inline_12638_read_code_fn__52997__auto__$jscomp$inline_12640$$=$APP.$app$render_wasm$wasm$internal_module$$._set_modifiers_end;try{$_$jscomp$2029_code__52999__auto__$jscomp$inline_12642_code_num__52998__auto__$jscomp$inline_12641_fn_54292$jscomp$inline_12638_read_code_fn__52997__auto__$jscomp$inline_12640$$()}catch($e54294$jscomp$inline_12644$$){$cause54293$jscomp$inline_12639_state$jscomp$439$$=
$e54294$jscomp$inline_12644$$;$_$jscomp$2029_code__52999__auto__$jscomp$inline_12642_code_num__52998__auto__$jscomp$inline_12641_fn_54292$jscomp$inline_12638_read_code_fn__52997__auto__$jscomp$inline_12640$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$_$jscomp$2029_code__52999__auto__$jscomp$inline_12642_code_num__52998__auto__$jscomp$inline_12641_fn_54292$jscomp$inline_12638_read_code_fn__52997__auto__$jscomp$inline_12640$$=$APP.$cljs$core$truth_$$($_$jscomp$2029_code__52999__auto__$jscomp$inline_12642_code_num__52998__auto__$jscomp$inline_12641_fn_54292$jscomp$inline_12638_read_code_fn__52997__auto__$jscomp$inline_12640$$)?
$_$jscomp$2029_code__52999__auto__$jscomp$inline_12642_code_num__52998__auto__$jscomp$inline_12641_fn_54292$jscomp$inline_12638_read_code_fn__52997__auto__$jscomp$inline_12640$$.$cljs$core$IFn$_invoke$arity$0$?$_$jscomp$2029_code__52999__auto__$jscomp$inline_12642_code_num__52998__auto__$jscomp$inline_12641_fn_54292$jscomp$inline_12638_read_code_fn__52997__auto__$jscomp$inline_12640$$.$cljs$core$IFn$_invoke$arity$0$():$_$jscomp$2029_code__52999__auto__$jscomp$inline_12642_code_num__52998__auto__$jscomp$inline_12641_fn_54292$jscomp$inline_12638_read_code_fn__52997__auto__$jscomp$inline_12640$$():
null;$_$jscomp$2029_code__52999__auto__$jscomp$inline_12642_code_num__52998__auto__$jscomp$inline_12641_fn_54292$jscomp$inline_12638_read_code_fn__52997__auto__$jscomp$inline_12640$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$_$jscomp$2029_code__52999__auto__$jscomp$inline_12642_code_num__52998__auto__$jscomp$inline_12641_fn_54292$jscomp$inline_12638_read_code_fn__52997__auto__$jscomp$inline_12640$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$inline_12643$$=
["WASM Error (",$APP.$app$common$data$name$$($_$jscomp$2029_code__52999__auto__$jscomp$inline_12642_code_num__52998__auto__$jscomp$inline_12641_fn_54292$jscomp$inline_12638_read_code_fn__52997__auto__$jscomp$inline_12640$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$inline_12643$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_modifiers_end",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$inline_12643$$,$APP.$cljs$cst$273$code$$,$_$jscomp$2029_code__52999__auto__$jscomp$inline_12642_code_num__52998__auto__$jscomp$inline_12641_fn_54292$jscomp$inline_12638_read_code_fn__52997__auto__$jscomp$inline_12640$$],null),$cause54293$jscomp$inline_12639_state$jscomp$439$$);}}$app$render_wasm$api$clean_modifiers$$();$APP.$cljs$core$_vreset_BANG_$$($app$main$data$workspace$modifiers$wasm_structure_modifiers_active_QMARK_$$,!1);return $app$main$data$workspace$modifiers$set_wasm_props_BANG_$$($APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($cause54293$jscomp$inline_12639_state$jscomp$439$$),
$cljs$cst$3826$wasm_props$$.$cljs$core$IFn$_invoke$arity$1$($cause54293$jscomp$inline_12639_state$jscomp$439$$),$APP.$cljs$core$PersistentVector$EMPTY$$)}return null},$app$main$data$workspace$modifiers$clear_local_transform_68613$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$clear_local_transform_68613$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2030$$,$state$jscomp$440$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$440$$,
$APP.$cljs$cst$1922$workspace_modifiers$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3826$wasm_props$$,$cljs$cst$3827$prev_wasm_props$$])),$cljs$cst$3828$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_current_move_selected$$)});return new $app$main$data$workspace$modifiers$clear_local_transform_68613$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$modifiers$create_modif_tree$$=function($ids$jscomp$99$$,$modifiers$jscomp$64$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__68626_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__68626_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1810$modifiers$$,
$modifiers$jscomp$64$$],null)],null)}),$ids$jscomp$99$$)};
$APP.$app$main$data$workspace$modifiers$build_modif_tree$$=function($ids$jscomp$100$$,$objects$jscomp$457$$,$get_modifier$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__68631_SHARP_$$){var $JSCompiler_temp_const$jscomp$1161$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;var $G__68632$jscomp$inline_6738_JSCompiler_inline_result$jscomp$1162$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$457$$,
$p1__68631_SHARP_$$);$G__68632$jscomp$inline_6738_JSCompiler_inline_result$jscomp$1162$$=$get_modifier$$.$cljs$core$IFn$_invoke$arity$1$?$get_modifier$$.$cljs$core$IFn$_invoke$arity$1$($G__68632$jscomp$inline_6738_JSCompiler_inline_result$jscomp$1162$$):$get_modifier$$($G__68632$jscomp$inline_6738_JSCompiler_inline_result$jscomp$1162$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$1161$$,[$p1__68631_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1810$modifiers$$,
$G__68632$jscomp$inline_6738_JSCompiler_inline_result$jscomp$1162$$],null)],null)}),$ids$jscomp$100$$)};
$app$main$data$workspace$modifiers$modifier_remove_from_parent$$=function($modif_tree$jscomp$26$$,$objects$jscomp$458$$,$shapes$jscomp$76$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($modif_tree__$1$jscomp$10$$,$child_id$jscomp$5$$){var $parent_id$jscomp$81$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$458$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$child_id$jscomp$5$$,$APP.$cljs$cst$1619$parent_id$$],
null));return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($modif_tree__$1$jscomp$10$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent_id$jscomp$81$$,$APP.$cljs$cst$1810$modifiers$$],null),$app$common$types$modifiers$remove_children$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$child_id$jscomp$5$$],null))},$modif_tree$jscomp$26$$,$shapes$jscomp$76$$)};
$app$main$data$workspace$modifiers$add_grid_children_modifiers$$=function($modifiers$jscomp$65$$,$frame$jscomp$28_frame_id$jscomp$81$$,$frame__$2$jscomp$1_shapes$jscomp$77$$,$objects$jscomp$459$$,$p__68639$$){var $row$jscomp$30$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68639$$,0,null),$column$jscomp$35$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68639$$,1,null);$frame$jscomp$28_frame_id$jscomp$81$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$459$$,
$frame$jscomp$28_frame_id$jscomp$81$$);var $ids$jscomp$101$$=$APP.$cljs$core$set$$($frame__$2$jscomp$1_shapes$jscomp$77$$),$frame__$1$jscomp$3$$=$APP.$app$common$types$shape$layout$assign_cells$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($frame$jscomp$28_frame_id$jscomp$81$$,$APP.$cljs$cst$1614$shapes$$,function($p1__68637_SHARP_$$){return $APP.$app$common$data$removev$$($ids$jscomp$101$$,$p1__68637_SHARP_$$)}),$objects$jscomp$459$$),$ids__$1$jscomp$14$$=$APP.$cljs$core$reverse$$($APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$459$$,
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68638_SHARP_$$){return $APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$459$$,$p1__68638_SHARP_$$)},$ids$jscomp$101$$)));$frame__$2$jscomp$1_shapes$jscomp$77$$=$APP.$app$common$types$shape$layout$assign_cells$$(function(){var $G__68643$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($frame__$1$jscomp$3$$,$APP.$cljs$cst$1614$shapes$$,$APP.$app$common$data$concat_vec$$,
$ids__$1$jscomp$14$$);return $p__68639$$!=null?$app$common$types$shape$layout$push_into_cell$$($G__68643$$,$ids__$1$jscomp$14$$,$row$jscomp$30$$,$column$jscomp$35$$):$G__68643$$}(),$objects$jscomp$459$$);return $APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$change_property$$($modifiers$jscomp$65$$,$APP.$cljs$cst$1694$layout_grid_rows$$,$APP.$cljs$cst$1694$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($frame__$2$jscomp$1_shapes$jscomp$77$$)),
$APP.$cljs$cst$1695$layout_grid_columns$$,$APP.$cljs$cst$1695$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($frame__$2$jscomp$1_shapes$jscomp$77$$)),$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($frame__$2$jscomp$1_shapes$jscomp$77$$))};
$app$main$data$workspace$modifiers$build_change_frame_modifiers$$=function($G__68663_G__68663__$1_modif_tree$jscomp$27$$,$objects$jscomp$460$$,$selected$jscomp$42$$,$target_frame_id$$,$drop_index$$,$cell_data$jscomp$5$$){function $set_parent_ids$$($modif_tree__$1$jscomp$11$$,$shapes$jscomp$78$$,$target_frame_id__$1$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($modif_tree__$2$jscomp$4$$,$id$jscomp$537$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($modif_tree__$2$jscomp$4$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$537$$,$APP.$cljs$cst$1810$modifiers$$],null),function($p1__68645_SHARP_$$){return $APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$change_property$$($p1__68645_SHARP_$$,$APP.$cljs$cst$1607$frame_id$$,$target_frame_id__$1$$),$APP.$cljs$cst$1619$parent_id$$,$target_frame_id__$1$$)})},$modif_tree__$1$jscomp$11$$,$shapes$jscomp$78$$)}var $origin_frame_ids$$=$APP.$cljs$core$group_by$$(function($p1__68644_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$460$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__68644_SHARP_$$,$APP.$cljs$cst$1607$frame_id$$],null))},$selected$jscomp$42$$),$child_set$jscomp$1$$=$APP.$cljs$core$set$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$460$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$target_frame_id$$,$APP.$cljs$cst$1614$shapes$$],null))),$target_frame$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$460$$,
$target_frame_id$$),$target_flex_layout_QMARK_$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($target_frame$$),$target_grid_layout_QMARK_$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($target_frame$$),$children_ids$jscomp$10$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($target_frame$$),$selected$jscomp$42$$);$G__68663_G__68663__$1_modif_tree$jscomp$27$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($modif_tree__$1$jscomp$12$$,$G__68659__$1_G__68659__$2_p__68651_shapes$jscomp$79$$){var $original_frame$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__68659__$1_G__68659__$2_p__68651_shapes$jscomp$79$$,0,null);$G__68659__$1_G__68659__$2_p__68651_shapes$jscomp$79$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__68659__$1_G__68659__$2_p__68651_shapes$jscomp$79$$,1,null);var $shapes__$1$jscomp$11$$=$APP.$app$common$data$removev$$(function($p1__68646_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($target_frame_id$$,
$p1__68646_SHARP_$$)},$G__68659__$1_G__68659__$2_p__68651_shapes$jscomp$79$$),$shapes__$2$$=function(){return($target_grid_layout_QMARK_$$||$target_flex_layout_QMARK_$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($original_frame$$,$target_frame_id$$)?$APP.$cljs$core$filterv$$(function($p1__68647_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($child_set$jscomp$1$$,$p1__68647_SHARP_$$)},$shapes__$1$jscomp$11$$):$shapes__$1$jscomp$11$$}(),$children_ids__$1$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($selected$jscomp$42$$),
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$460$$,$original_frame$$),$APP.$cljs$cst$1614$shapes$$)),$h_sizing_QMARK_$$=function(){var $and__5023__auto__$jscomp$460$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$460$$,$original_frame$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$460$$)?$app$common$types$shape$layout$change_h_sizing_QMARK_$$($original_frame$$,
$objects$jscomp$460$$,$children_ids__$1$$):$and__5023__auto__$jscomp$460$$}(),$v_sizing_QMARK_$$=function(){var $and__5023__auto__$jscomp$461$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$460$$,$original_frame$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$461$$)?$app$common$types$shape$layout$change_v_sizing_QMARK_$$($original_frame$$,$objects$jscomp$460$$,$children_ids__$1$$):$and__5023__auto__$jscomp$461$$}();$G__68659__$1_G__68659__$2_p__68651_shapes$jscomp$79$$=
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($original_frame$$,$target_frame_id$$)?function(){var $G__68661_G__68662$jscomp$inline_6740$$=$set_parent_ids$$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($app$main$data$workspace$modifiers$modifier_remove_from_parent$$($modif_tree__$1$jscomp$12$$,$objects$jscomp$460$$,$shapes__$2$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$target_frame_id$$,$APP.$cljs$cst$1810$modifiers$$],
null),$app$common$types$modifiers$add_children$$,$shapes__$2$$,$drop_index$$),$shapes__$2$$,$target_frame_id$$);$G__68661_G__68662$jscomp$inline_6740$$=$APP.$cljs$core$truth_$$($h_sizing_QMARK_$$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($G__68661_G__68662$jscomp$inline_6740$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$original_frame$$,$APP.$cljs$cst$1810$modifiers$$],null),$APP.$app$common$types$modifiers$change_property$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$,
$APP.$cljs$cst$1697$fix$$):$G__68661_G__68662$jscomp$inline_6740$$;return $APP.$cljs$core$truth_$$($v_sizing_QMARK_$$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($G__68661_G__68662$jscomp$inline_6740$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$original_frame$$,$APP.$cljs$cst$1810$modifiers$$],null),$APP.$app$common$types$modifiers$change_property$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1697$fix$$):$G__68661_G__68662$jscomp$inline_6740$$}():
$modif_tree__$1$jscomp$12$$;$G__68659__$1_G__68659__$2_p__68651_shapes$jscomp$79$$=$target_flex_layout_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($original_frame$$,$target_frame_id$$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($G__68659__$1_G__68659__$2_p__68651_shapes$jscomp$79$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$target_frame_id$$,$APP.$cljs$cst$1810$modifiers$$],null),$app$common$types$modifiers$add_children$$,
$shapes__$2$$,$drop_index$$):$G__68659__$1_G__68659__$2_p__68651_shapes$jscomp$79$$;return $target_grid_layout_QMARK_$$?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$variadic$($G__68659__$1_G__68659__$2_p__68651_shapes$jscomp$79$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$target_frame_id$$,$APP.$cljs$cst$1810$modifiers$$],null),$app$main$data$workspace$modifiers$add_grid_children_modifiers$$,$target_frame_id$$,$shapes__$2$$,$objects$jscomp$460$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cell_data$jscomp$5$$])):$G__68659__$1_G__68659__$2_p__68651_shapes$jscomp$79$$},$G__68663_G__68663__$1_modif_tree$jscomp$27$$,$origin_frame_ids$$);$G__68663_G__68663__$1_modif_tree$jscomp$27$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$462$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$460$$,$target_frame_id$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$462$$)?
$app$common$types$shape$layout$change_h_sizing_QMARK_$$($target_frame_id$$,$objects$jscomp$460$$,$children_ids$jscomp$10$$):$and__5023__auto__$jscomp$462$$}())?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($G__68663_G__68663__$1_modif_tree$jscomp$27$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$target_frame_id$$,$APP.$cljs$cst$1810$modifiers$$],null),$APP.$app$common$types$modifiers$change_property$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$,
$APP.$cljs$cst$1697$fix$$):$G__68663_G__68663__$1_modif_tree$jscomp$27$$;return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$463$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$460$$,$target_frame_id$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$463$$)?$app$common$types$shape$layout$change_v_sizing_QMARK_$$($target_frame_id$$,$objects$jscomp$460$$,$children_ids$jscomp$10$$):$and__5023__auto__$jscomp$463$$}())?
$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($G__68663_G__68663__$1_modif_tree$jscomp$27$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$target_frame_id$$,$APP.$cljs$cst$1810$modifiers$$],null),$APP.$app$common$types$modifiers$change_property$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1697$fix$$):$G__68663_G__68663__$1_modif_tree$jscomp$27$$};
$APP.$app$main$data$workspace$modifiers$apply_text_modifier$$=function($shape$jscomp$532$$,$G__68673__$1_p__68671_width$jscomp$135$$){var $height$jscomp$121_map__68672__$1$$=$APP.$cljs$core$__destructure_map$$($G__68673__$1_p__68671_width$jscomp$135$$);$G__68673__$1_p__68671_width$jscomp$135$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$121_map__68672__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$121_map__68672__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$121_map__68672__$1$$,
$APP.$cljs$cst$1522$height$$);$G__68673__$1_p__68671_width$jscomp$135$$=$G__68673__$1_p__68671_width$jscomp$135$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$532$$,$APP.$app$common$types$modifiers$change_dimensions_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($shape$jscomp$532$$,$APP.$cljs$cst$290$width$$,$G__68673__$1_p__68671_width$jscomp$135$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1806$ignore_lock_QMARK_$$,!0],null))):
$shape$jscomp$532$$;return $height$jscomp$121_map__68672__$1$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__68673__$1_p__68671_width$jscomp$135$$,$APP.$app$common$types$modifiers$change_dimensions_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($shape$jscomp$532$$,$APP.$cljs$cst$1522$height$$,$height$jscomp$121_map__68672__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1806$ignore_lock_QMARK_$$,!0],null))):$G__68673__$1_p__68671_width$jscomp$135$$};
$APP.$app$main$data$workspace$modifiers$apply_text_modifiers$$=function($G__68953_objects$jscomp$462_result$jscomp$291$$,$G__68952_modifiers$jscomp$66_text_modifiers$$){for($G__68952_modifiers$jscomp$66_text_modifiers$$=$APP.$cljs$core$seq$$($G__68952_modifiers$jscomp$66_text_modifiers$$);;){if($APP.$cljs$core$empty_QMARK_$$($G__68952_modifiers$jscomp$66_text_modifiers$$))return $G__68953_objects$jscomp$462_result$jscomp$291$$;var $text_modifier_vec__68675$$=$APP.$cljs$core$first$$($G__68952_modifiers$jscomp$66_text_modifiers$$),
$id$jscomp$538$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_modifier_vec__68675$$,0,null);$text_modifier_vec__68675$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_modifier_vec__68675$$,1,null);$G__68952_modifiers$jscomp$66_text_modifiers$$=$APP.$cljs$core$rest$$($G__68952_modifiers$jscomp$66_text_modifiers$$);$G__68953_objects$jscomp$462_result$jscomp$291$$=$APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__68953_objects$jscomp$462_result$jscomp$291$$,
$id$jscomp$538$$,$APP.$app$main$data$workspace$modifiers$apply_text_modifier$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$text_modifier_vec__68675$$]))}};
$app$main$data$workspace$modifiers$calculate_modifiers$cljs$0core$0IFn$0_invoke$0arity$06$$=function($$__$1$jscomp$18_state$jscomp$443$$,$ignore_constraints$jscomp$12_params$jscomp$inline_12648$$,$ignore_snap_pixel$jscomp$1_snap_pixel_QMARK_$jscomp$1$$,$modif_tree$jscomp$31$$,$objects$jscomp$463_page_id$jscomp$156_page_id__$1$jscomp$8$$,$params$jscomp$268$$){$objects$jscomp$463_page_id$jscomp$156_page_id__$1$jscomp$8$$=$APP.$cljs$core$truth_$$($objects$jscomp$463_page_id$jscomp$156_page_id__$1$jscomp$8$$)?
$objects$jscomp$463_page_id$jscomp$156_page_id__$1$jscomp$8$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($$__$1$jscomp$18_state$jscomp$443$$);$objects$jscomp$463_page_id$jscomp$156_page_id__$1$jscomp$8$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($$__$1$jscomp$18_state$jscomp$443$$,$objects$jscomp$463_page_id$jscomp$156_page_id__$1$jscomp$8$$);$ignore_snap_pixel$jscomp$1_snap_pixel_QMARK_$jscomp$1$$=$APP.$cljs$core$not$$($ignore_snap_pixel$jscomp$1_snap_pixel_QMARK_$jscomp$1$$)&&
$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$2209$workspace_layout$$.$cljs$core$IFn$_invoke$arity$1$($$__$1$jscomp$18_state$jscomp$443$$),$APP.$cljs$cst$2210$snap_pixel_grid$$);$$__$1$jscomp$18_state$jscomp$443$$=$APP.$app$main$data$workspace$modifiers$apply_text_modifiers$$($objects$jscomp$463_page_id$jscomp$156_page_id__$1$jscomp$8$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($$__$1$jscomp$18_state$jscomp$443$$,$APP.$cljs$cst$2238$workspace_text_modifier$$));$ignore_constraints$jscomp$12_params$jscomp$inline_12648$$=
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$params$jscomp$268$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3821$ignore_constraints$$,$ignore_constraints$jscomp$12_params$jscomp$inline_12648$$,$APP.$cljs$cst$3822$snap_pixel_QMARK_$$,$ignore_snap_pixel$jscomp$1_snap_pixel_QMARK_$jscomp$1$$],null)]));return $APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$(null,
$modif_tree$jscomp$31$$,$$__$1$jscomp$18_state$jscomp$443$$,$ignore_constraints$jscomp$12_params$jscomp$inline_12648$$)};
$APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$=function($modif_tree$jscomp$40$$,$ignore_constraints$jscomp$19$$,$ignore_snap_pixel$jscomp$6$$,$params$jscomp$269$$){typeof $app$main$data$workspace$modifiers$set_modifiers_68694$$==="undefined"&&($app$main$data$workspace$modifiers$set_modifiers_68694$$=function($modif_tree$jscomp$41$$,$ignore_constraints$jscomp$20$$,$ignore_snap_pixel$jscomp$7$$,$params$jscomp$270$$,$meta68695$$){this.$modif_tree$=$modif_tree$jscomp$41$$;
this.$ignore_constraints$=$ignore_constraints$jscomp$20$$;this.$ignore_snap_pixel$=$ignore_snap_pixel$jscomp$7$$;this.params=$params$jscomp$270$$;this.$meta68695$=$meta68695$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$modifiers$set_modifiers_68694$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_modifiers_68694$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3830$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_modifiers$$},$app$main$data$workspace$modifiers$set_modifiers_68694$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68696$$,$meta68695__$1$$){return new $app$main$data$workspace$modifiers$set_modifiers_68694$$(this.$modif_tree$,this.$ignore_constraints$,this.$ignore_snap_pixel$,this.params,$meta68695__$1$$)},$app$main$data$workspace$modifiers$set_modifiers_68694$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta68695$},$app$main$data$workspace$modifiers$set_modifiers_68694$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_modifiers_68694$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2032_modifiers$jscomp$67_page_id$jscomp$157$$,$state$jscomp$446$$){$_$jscomp$2032_modifiers$jscomp$67_page_id$jscomp$157$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$446$$);
$_$jscomp$2032_modifiers$jscomp$67_page_id$jscomp$157$$=$app$main$data$workspace$modifiers$calculate_modifiers$cljs$0core$0IFn$0_invoke$0arity$06$$($state$jscomp$446$$,this.$ignore_constraints$,this.$ignore_snap_pixel$,this.$modif_tree$,$_$jscomp$2032_modifiers$jscomp$67_page_id$jscomp$157$$,this.params);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$446$$,$APP.$cljs$cst$1922$workspace_modifiers$$,$_$jscomp$2032_modifiers$jscomp$67_page_id$jscomp$157$$)});return new $app$main$data$workspace$modifiers$set_modifiers_68694$$($modif_tree$jscomp$40$$,
$ignore_constraints$jscomp$19$$,$ignore_snap_pixel$jscomp$6$$,$params$jscomp$269$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$modifiers$parse_structure_modifiers$$=function($modif_tree$jscomp$42$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($data$jscomp$336_p__68709$$){var $parent_id$jscomp$82$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$336_p__68709$$,0,null);$data$jscomp$336_p__68709$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$336_p__68709$$,
1,null);return $app$common$types$modifiers$has_structure_QMARK_$$($APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$336_p__68709$$))?$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($modifier$jscomp$5$$){var $G__68714$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($modifier$jscomp$5$$);switch($G__68714$$ instanceof $APP.$cljs$core$Keyword$$?$G__68714$$.$fqn$:null){case "remove-children":return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($child_id$jscomp$6$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$cljs$cst$1800$remove_children$$,$APP.$cljs$cst$1365$parent$$,$parent_id$jscomp$82$$,$APP.$cljs$cst$266$id$$,$child_id$jscomp$6$$,$APP.$cljs$cst$1795$index$$,0,$APP.$cljs$cst$260$value$$,0],null)},$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($modifier$jscomp$5$$));case "add-children":return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($child_id$jscomp$7$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,
$cljs$cst$1801$add_children$$,$APP.$cljs$cst$1365$parent$$,$parent_id$jscomp$82$$,$APP.$cljs$cst$266$id$$,$child_id$jscomp$7$$,$APP.$cljs$cst$1795$index$$,$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($modifier$jscomp$5$$),$APP.$cljs$cst$260$value$$,0],null)},$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($modifier$jscomp$5$$));case "scale-content":return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1803$scale_content$$,$APP.$cljs$cst$1365$parent$$,$parent_id$jscomp$82$$,$APP.$cljs$cst$266$id$$,$parent_id$jscomp$82$$,$APP.$cljs$cst$1795$index$$,0,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($modifier$jscomp$5$$)],null)],null);default:return null}},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$336_p__68709$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1810$modifiers$$,$cljs$cst$1779$structure_parent$$],null)),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$336_p__68709$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1810$modifiers$$,$APP.$cljs$cst$1780$structure_child$$],null)))])):null}),$modif_tree$jscomp$42$$)};
$app$main$data$workspace$modifiers$extract_property_changes$$=function($modif_tree$jscomp$44$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($map__68725_map__68725__$1_p__68721_type$jscomp$481$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__68725_map__68725__$1_p__68721_type$jscomp$481$$,0,null);$map__68725_map__68725__$1_p__68721_type$jscomp$481$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__68725_map__68725__$1_p__68721_type$jscomp$481$$,
1,null);$map__68725_map__68725__$1_p__68721_type$jscomp$481$$=$APP.$cljs$core$__destructure_map$$($map__68725_map__68725__$1_p__68721_type$jscomp$481$$);$map__68725_map__68725__$1_p__68721_type$jscomp$481$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68725_map__68725__$1_p__68721_type$jscomp$481$$,$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__68725_map__68725__$1_p__68721_type$jscomp$481$$,$cljs$cst$1804$change_property$$)},$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($map__68732_map__68732__$1_modifiers$jscomp$68_p__68728$$){var $id$jscomp$540$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__68732_map__68732__$1_modifiers$jscomp$68_p__68728$$,0,null);$map__68732_map__68732__$1_modifiers$jscomp$68_p__68728$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__68732_map__68732__$1_modifiers$jscomp$68_p__68728$$,1,null);$map__68732_map__68732__$1_modifiers$jscomp$68_p__68728$$=$APP.$cljs$core$__destructure_map$$($map__68732_map__68732__$1_modifiers$jscomp$68_p__68728$$);$map__68732_map__68732__$1_modifiers$jscomp$68_p__68728$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68732_map__68732__$1_modifiers$jscomp$68_p__68728$$,$APP.$cljs$cst$1810$modifiers$$);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68719_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$540$$,$p1__68719_SHARP_$$],null)},$cljs$cst$1779$structure_parent$$.$cljs$core$IFn$_invoke$arity$1$($map__68732_map__68732__$1_modifiers$jscomp$68_p__68728$$))},
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$modif_tree$jscomp$44$$])))};
$app$main$data$workspace$modifiers$set_temporary_selrect$$=function($selrect$jscomp$53$$){typeof $app$main$data$workspace$modifiers$set_temporary_selrect_68733$$==="undefined"&&($app$main$data$workspace$modifiers$set_temporary_selrect_68733$$=function($selrect$jscomp$54$$,$meta68734$$){this.$selrect$=$selrect$jscomp$54$$;this.$meta68734$=$meta68734$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$modifiers$set_temporary_selrect_68733$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_temporary_selrect_68733$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3831$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_temporary_selrect$$},$app$main$data$workspace$modifiers$set_temporary_selrect_68733$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68735$$,$meta68734__$1$$){return new $app$main$data$workspace$modifiers$set_temporary_selrect_68733$$(this.$selrect$,
$meta68734__$1$$)},$app$main$data$workspace$modifiers$set_temporary_selrect_68733$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68734$},$app$main$data$workspace$modifiers$set_temporary_selrect_68733$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_temporary_selrect_68733$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $app$main$streams$workspace_selrect$$.next(this.$selrect$)});return new $app$main$data$workspace$modifiers$set_temporary_selrect_68733$$($selrect$jscomp$53$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$modifiers$set_temporary_modifiers$$=function($modifiers$jscomp$69$$){typeof $app$main$data$workspace$modifiers$set_temporary_modifiers_68738$$==="undefined"&&($app$main$data$workspace$modifiers$set_temporary_modifiers_68738$$=function($modifiers$jscomp$70$$,$meta68739$$){this.modifiers=$modifiers$jscomp$70$$;this.$meta68739$=$meta68739$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$modifiers$set_temporary_modifiers_68738$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_temporary_modifiers_68738$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3832$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_temporary_modifiers$$},$app$main$data$workspace$modifiers$set_temporary_modifiers_68738$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68740$$,$meta68739__$1$$){return new $app$main$data$workspace$modifiers$set_temporary_modifiers_68738$$(this.modifiers,
$meta68739__$1$$)},$app$main$data$workspace$modifiers$set_temporary_modifiers_68738$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68739$},$app$main$data$workspace$modifiers$set_temporary_modifiers_68738$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_temporary_modifiers_68738$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $app$main$streams$wasm_modifiers$$.next($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this.modifiers))});return new $app$main$data$workspace$modifiers$set_temporary_modifiers_68738$$($modifiers$jscomp$69$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$modifiers$translate_selrect$$=function($selrect$jscomp$55$$,$tx$jscomp$6$$,$ty$jscomp$7$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($selrect$jscomp$55$$,$APP.$cljs$cst$1667$center$$,function($c$jscomp$301$$){return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$301$$)+$tx$jscomp$6$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$301$$)+$ty$jscomp$7$$)})};
$app$main$data$workspace$modifiers$cached_translation_selrect$$=function($computed_ids$jscomp$102$$,$first_matrix_ty$jscomp$8$$,$cache$jscomp$104$$){var $tx$jscomp$7$$=$first_matrix_ty$jscomp$8$$.e;$first_matrix_ty$jscomp$8$$=$first_matrix_ty$jscomp$8$$.f;var $temp__5823__auto__$jscomp$178$$=$APP.$cljs$core$_deref$$($cache$jscomp$104$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$178$$))return $app$main$data$workspace$modifiers$translate_selrect$$($temp__5823__auto__$jscomp$178$$,$tx$jscomp$7$$,
$first_matrix_ty$jscomp$8$$);$computed_ids$jscomp$102$$=$app$render_wasm$api$get_selection_rect$$($computed_ids$jscomp$102$$);$APP.$cljs$core$vreset_BANG_$$($cache$jscomp$104$$,$app$main$data$workspace$modifiers$translate_selrect$$($computed_ids$jscomp$102$$,-$tx$jscomp$7$$,-$first_matrix_ty$jscomp$8$$));return $computed_ids$jscomp$102$$};
$APP.$app$main$data$workspace$modifiers$set_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($modif_tree$jscomp$45$$,$p__68757$$){var $map__68758__$1$$=$APP.$cljs$core$__destructure_map$$($p__68757$$),$ignore_constraints$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68758__$1$$,$APP.$cljs$cst$3821$ignore_constraints$$,!1),$ignore_snap_pixel$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68758__$1$$,$cljs$cst$3833$ignore_snap_pixel$$,
!1),$subtree_ids_by_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68758__$1$$,$cljs$cst$3834$subtree_ids_by_id$$),$selection_rect_cache$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68758__$1$$,$cljs$cst$3835$selection_rect_cache$$);typeof $app$main$data$workspace$modifiers$set_wasm_modifiers_68759$$==="undefined"&&($app$main$data$workspace$modifiers$set_wasm_modifiers_68759$$=function($modif_tree$jscomp$46$$,$p__68757$jscomp$1$$,$map__68758$jscomp$1$$,$params$jscomp$272$$,
$ignore_constraints$jscomp$22$$,$ignore_snap_pixel$jscomp$9$$,$subtree_ids_by_id$jscomp$1$$,$selection_rect_cache$jscomp$1$$,$meta68760$$){this.$modif_tree$=$modif_tree$jscomp$46$$;this.$p__68757$=$p__68757$jscomp$1$$;this.$map__68758$=$map__68758$jscomp$1$$;this.params=$params$jscomp$272$$;this.$ignore_constraints$=$ignore_constraints$jscomp$22$$;this.$ignore_snap_pixel$=$ignore_snap_pixel$jscomp$9$$;this.$subtree_ids_by_id$=$subtree_ids_by_id$jscomp$1$$;this.$selection_rect_cache$=$selection_rect_cache$jscomp$1$$;
this.$meta68760$=$meta68760$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$modifiers$set_wasm_modifiers_68759$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_wasm_modifiers_68759$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3836$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_wasm_modifiers$$},$app$main$data$workspace$modifiers$set_wasm_modifiers_68759$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_68761$$,$meta68760__$1$$){return new $app$main$data$workspace$modifiers$set_wasm_modifiers_68759$$(this.$modif_tree$,this.$p__68757$,this.$map__68758$,this.params,this.$ignore_constraints$,this.$ignore_snap_pixel$,this.$subtree_ids_by_id$,this.$selection_rect_cache$,$meta68760__$1$$)},$app$main$data$workspace$modifiers$set_wasm_modifiers_68759$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68760$},$app$main$data$workspace$modifiers$set_wasm_modifiers_68759$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_wasm_modifiers_68759$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2036_property_changes$$,$state$jscomp$447$$){$_$jscomp$2036_property_changes$$=$app$main$data$workspace$modifiers$extract_property_changes$$(this.$modif_tree$);return $APP.$app$common$data$not_empty_QMARK_$$($_$jscomp$2036_property_changes$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$447$$,
$cljs$cst$3827$prev_wasm_props$$,$cljs$cst$3826$wasm_props$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$447$$)),$cljs$cst$3826$wasm_props$$,$_$jscomp$2036_property_changes$$):$state$jscomp$447$$},$app$main$data$workspace$modifiers$set_wasm_modifiers_68759$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_wasm_modifiers_68759$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2037_objects_68997_root_modifiers$$,
$geometry_entries_ids$jscomp$103_selrect$jscomp$56_state$jscomp$448$$){var $self__$jscomp$4561$$=this;$APP.$cljs$core$compare_and_set_BANG_$$($app$render_wasm$gesture$interactive_transform_active_QMARK_$$,!1,!0)&&$app$render_wasm$api$set_modifiers_start$$();var $snap_pixel_QMARK_$jscomp$3$$=$APP.$cljs$core$not$$($self__$jscomp$4561$$.$ignore_snap_pixel$)&&$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$2209$workspace_layout$$.$cljs$core$IFn$_invoke$arity$1$($geometry_entries_ids$jscomp$103_selrect$jscomp$56_state$jscomp$448$$),
$APP.$cljs$cst$2210$snap_pixel_grid$$),$translation_QMARK_$jscomp$10$$=$APP.$cljs$core$every_QMARK_$$(function($p1__68751_SHARP_$$){return $app$common$types$modifiers$only_move_QMARK_$$($APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($p1__68751_SHARP_$$))},$APP.$cljs$core$vals$$($self__$jscomp$4561$$.$modif_tree$));$translation_QMARK_$jscomp$10$$?$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($app$main$data$workspace$modifiers$wasm_structure_modifiers_active_QMARK_$$))&&($app$render_wasm$api$clean_modifiers$$(),
$APP.$cljs$core$_vreset_BANG_$$($app$main$data$workspace$modifiers$wasm_structure_modifiers_active_QMARK_$$,!1)):($_$jscomp$2037_objects_68997_root_modifiers$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($geometry_entries_ids$jscomp$103_selrect$jscomp$56_state$jscomp$448$$),$app$main$data$workspace$modifiers$set_wasm_props_BANG_$$($_$jscomp$2037_objects_68997_root_modifiers$$,$cljs$cst$3827$prev_wasm_props$$.$cljs$core$IFn$_invoke$arity$1$($geometry_entries_ids$jscomp$103_selrect$jscomp$56_state$jscomp$448$$),
$cljs$cst$3826$wasm_props$$.$cljs$core$IFn$_invoke$arity$1$($geometry_entries_ids$jscomp$103_selrect$jscomp$56_state$jscomp$448$$)),$app$render_wasm$api$clean_modifiers$$(),$app$render_wasm$api$set_structure_modifiers$$($app$main$data$workspace$modifiers$parse_structure_modifiers$$($self__$jscomp$4561$$.$modif_tree$)),$APP.$cljs$core$_vreset_BANG_$$($app$main$data$workspace$modifiers$wasm_structure_modifiers_active_QMARK_$$,!0));$geometry_entries_ids$jscomp$103_selrect$jscomp$56_state$jscomp$448$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$main$data$workspace$modifiers$xf_COLON_parse_geometry_modifier$$,$self__$jscomp$4561$$.$modif_tree$);$_$jscomp$2037_objects_68997_root_modifiers$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($data$jscomp$338_p__68774$$){var $id$jscomp$541$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$338_p__68774$$,
0,null);$data$jscomp$338_p__68774$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$338_p__68774$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$541$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$338_p__68774$$)],null)}),$geometry_entries_ids$jscomp$103_selrect$jscomp$56_state$jscomp$448$$);var $modifiers$jscomp$71$$=$translation_QMARK_$jscomp$10$$&&!$snap_pixel_QMARK_$jscomp$3$$?
$_$jscomp$2037_objects_68997_root_modifiers$$:$app$render_wasm$api$propagate_modifiers$$($geometry_entries_ids$jscomp$103_selrect$jscomp$56_state$jscomp$448$$,$snap_pixel_QMARK_$jscomp$3$$);$app$render_wasm$api$set_modifiers$$($modifiers$jscomp$71$$);$geometry_entries_ids$jscomp$103_selrect$jscomp$56_state$jscomp$448$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$main$data$workspace$modifiers$xf_COLON_map_key$$,$geometry_entries_ids$jscomp$103_selrect$jscomp$56_state$jscomp$448$$);
$geometry_entries_ids$jscomp$103_selrect$jscomp$56_state$jscomp$448$$=$APP.$cljs$core$truth_$$(function(){if($translation_QMARK_$jscomp$10$$){var $and__5023__auto____$1$jscomp$85_and__5023__auto____$2$jscomp$34$$=!$snap_pixel_QMARK_$jscomp$3$$;return $and__5023__auto____$1$jscomp$85_and__5023__auto____$2$jscomp$34$$?($and__5023__auto____$1$jscomp$85_and__5023__auto____$2$jscomp$34$$=$self__$jscomp$4561$$.$selection_rect_cache$,$APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$85_and__5023__auto____$2$jscomp$34$$)?
$APP.$cljs$core$seq$$($modifiers$jscomp$71$$):$and__5023__auto____$1$jscomp$85_and__5023__auto____$2$jscomp$34$$):$and__5023__auto____$1$jscomp$85_and__5023__auto____$2$jscomp$34$$}return $translation_QMARK_$jscomp$10$$}())?$app$main$data$workspace$modifiers$cached_translation_selrect$$($geometry_entries_ids$jscomp$103_selrect$jscomp$56_state$jscomp$448$$,$APP.$cljs$core$second$$($APP.$cljs$core$first$$($modifiers$jscomp$71$$)),$self__$jscomp$4561$$.$selection_rect_cache$):$app$render_wasm$api$get_selection_rect$$($geometry_entries_ids$jscomp$103_selrect$jscomp$56_state$jscomp$448$$);
return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$modifiers$set_temporary_selrect$$($geometry_entries_ids$jscomp$103_selrect$jscomp$56_state$jscomp$448$$),$app$main$data$workspace$modifiers$set_temporary_modifiers$$($modifiers$jscomp$71$$))});return new $app$main$data$workspace$modifiers$set_wasm_modifiers_68759$$($modif_tree$jscomp$45$$,$p__68757$$,$map__68758__$1$$,$map__68758__$1$$,$ignore_constraints$jscomp$21$$,$ignore_snap_pixel$jscomp$8$$,$subtree_ids_by_id$$,$selection_rect_cache$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$modifiers$propagate_structure_modifiers$$=function($G__69011_modif_tree$jscomp$47_modif_tree__$1$jscomp$13_vec__68793$$,$objects$jscomp$465$$){function $propagate_children$$($modif_tree__$1$jscomp$14$$,$parent_id$jscomp$83$$,$modifiers$jscomp$73$$){var $new_modifiers$jscomp$2$$=$app$common$types$modifiers$select_structure$$($app$common$types$modifiers$select_child$$($modifiers$jscomp$73$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__68784_SHARP_$$,$p2__68785_SHARP_$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($p1__68784_SHARP_$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p2__68785_SHARP_$$,$APP.$cljs$cst$1810$modifiers$$],null),$app$common$types$modifiers$add_modifiers$$,$new_modifiers$jscomp$2$$)},$modif_tree__$1$jscomp$14$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$465$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent_id$jscomp$83$$,$APP.$cljs$cst$1614$shapes$$],null)))}for(var $pending$jscomp$22_pending__$1$jscomp$3_pending__$2$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keys$$($G__69011_modif_tree$jscomp$47_modif_tree__$1$jscomp$13_vec__68793$$));;){var $next$jscomp$10_temp__5823__auto__$jscomp$179$$=$APP.$cljs$core$first$$($pending$jscomp$22_pending__$1$jscomp$3_pending__$2$$);if($APP.$cljs$core$truth_$$($next$jscomp$10_temp__5823__auto__$jscomp$179$$)){$pending$jscomp$22_pending__$1$jscomp$3_pending__$2$$=$APP.$cljs$core$rest$$($pending$jscomp$22_pending__$1$jscomp$3_pending__$2$$);
var $modifiers$jscomp$72$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($G__69011_modif_tree$jscomp$47_modif_tree__$1$jscomp$13_vec__68793$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$next$jscomp$10_temp__5823__auto__$jscomp$179$$,$APP.$cljs$cst$1810$modifiers$$],null));$G__69011_modif_tree$jscomp$47_modif_tree__$1$jscomp$13_vec__68793$$=$APP.$app$common$data$not_empty_QMARK_$$($modifiers$jscomp$72$$?.$structure_child$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$72$$,
$APP.$cljs$cst$1780$structure_child$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($pending$jscomp$22_pending__$1$jscomp$3_pending__$2$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$465$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$next$jscomp$10_temp__5823__auto__$jscomp$179$$,$APP.$cljs$cst$1614$shapes$$],null))),
$propagate_children$$($G__69011_modif_tree$jscomp$47_modif_tree__$1$jscomp$13_vec__68793$$,$next$jscomp$10_temp__5823__auto__$jscomp$179$$,$modifiers$jscomp$72$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$pending$jscomp$22_pending__$1$jscomp$3_pending__$2$$,$G__69011_modif_tree$jscomp$47_modif_tree__$1$jscomp$13_vec__68793$$],null);$pending$jscomp$22_pending__$1$jscomp$3_pending__$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__69011_modif_tree$jscomp$47_modif_tree__$1$jscomp$13_vec__68793$$,
0,null);$G__69011_modif_tree$jscomp$47_modif_tree__$1$jscomp$13_vec__68793$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__69011_modif_tree$jscomp$47_modif_tree__$1$jscomp$13_vec__68793$$,1,null)}else return $G__69011_modif_tree$jscomp$47_modif_tree__$1$jscomp$13_vec__68793$$}};
$APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$=function($var_args$jscomp$1247$$){for(var $args__5755__auto__$jscomp$228$$=[],$len__5749__auto___69012$$=arguments.length,$i__5750__auto___69013$$=0;;)if($i__5750__auto___69013$$<$len__5749__auto___69012$$)$args__5755__auto__$jscomp$228$$.push(arguments[$i__5750__auto___69013$$]),$i__5750__auto___69013$$+=1;else break;return $APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
1<$args__5755__auto__$jscomp$228$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$228$$.slice(1),0,null):null)};
$APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($modif_tree$jscomp$48$$,$p__68799$$){var $map__68800__$1$$=$APP.$cljs$core$__destructure_map$$($p__68799$$),$ignore_constraints$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68800__$1$$,$APP.$cljs$cst$3821$ignore_constraints$$,!1),$ignore_snap_pixel$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68800__$1$$,$cljs$cst$3833$ignore_snap_pixel$$,
!1),$snap_ignore_axis$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68800__$1$$,$cljs$cst$3824$snap_ignore_axis$$,null),$undo_transation_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68800__$1$$,$cljs$cst$3837$undo_transation_QMARK_$$,!0),$subtree_ids_by_id$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68800__$1$$,$cljs$cst$3834$subtree_ids_by_id$$);typeof $app$main$data$workspace$modifiers$apply_wasm_modifiesr_68801$$==="undefined"&&
($app$main$data$workspace$modifiers$apply_wasm_modifiesr_68801$$=function($p__68799$jscomp$1$$,$modif_tree$jscomp$49$$,$undo_transation_QMARK_$jscomp$1$$,$ignore_snap_pixel$jscomp$11$$,$params$jscomp$274$$,$ignore_constraints$jscomp$24$$,$map__68800$jscomp$1$$,$snap_ignore_axis$jscomp$2$$,$subtree_ids_by_id$jscomp$3$$,$meta68802$$){this.$p__68799$=$p__68799$jscomp$1$$;this.$modif_tree$=$modif_tree$jscomp$49$$;this.$undo_transation_QMARK_$=$undo_transation_QMARK_$jscomp$1$$;this.$ignore_snap_pixel$=
$ignore_snap_pixel$jscomp$11$$;this.params=$params$jscomp$274$$;this.$ignore_constraints$=$ignore_constraints$jscomp$24$$;this.$map__68800$=$map__68800$jscomp$1$$;this.$snap_ignore_axis$=$snap_ignore_axis$jscomp$2$$;this.$subtree_ids_by_id$=$subtree_ids_by_id$jscomp$3$$;this.$meta68802$=$meta68802$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$modifiers$apply_wasm_modifiesr_68801$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$modifiers$apply_wasm_modifiesr_68801$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3838$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_apply_wasm_modifiesr$$},$app$main$data$workspace$modifiers$apply_wasm_modifiesr_68801$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68803$$,$meta68802__$1$$){return new $app$main$data$workspace$modifiers$apply_wasm_modifiesr_68801$$(this.$p__68799$,this.$modif_tree$,this.$undo_transation_QMARK_$,
this.$ignore_snap_pixel$,this.params,this.$ignore_constraints$,this.$map__68800$,this.$snap_ignore_axis$,this.$subtree_ids_by_id$,$meta68802__$1$$)},$app$main$data$workspace$modifiers$apply_wasm_modifiesr_68801$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68802$},$app$main$data$workspace$modifiers$apply_wasm_modifiesr_68801$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$apply_wasm_modifiesr_68801$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2038_options$jscomp$509_translation_QMARK_$jscomp$11$$,$ids$jscomp$104_state$jscomp$449$$){var $self__$jscomp$4565$$=this;$_$jscomp$2038_options$jscomp$509_translation_QMARK_$jscomp$11$$=$APP.$cljs$core$every_QMARK_$$(function($p1__68796_SHARP_$$){return $app$common$types$modifiers$only_move_QMARK_$$($APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($p1__68796_SHARP_$$))},$APP.$cljs$core$vals$$($self__$jscomp$4565$$.$modif_tree$));$app$render_wasm$api$clean_modifiers$$();
$_$jscomp$2038_options$jscomp$509_translation_QMARK_$jscomp$11$$||$app$render_wasm$api$set_structure_modifiers$$($app$main$data$workspace$modifiers$parse_structure_modifiers$$($self__$jscomp$4565$$.$modif_tree$));for(var $G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$=$APP.$cljs$core$seq$$($app$main$data$workspace$modifiers$extract_property_changes$$($self__$jscomp$4565$$.$modif_tree$)),$G__69039_chunk__68813_69021_id_69043_snap_pixel_QMARK_$jscomp$4_undo_id$jscomp$9$$=
null,$G__69040_c__5548__auto___69037_count__68814_69022_map__68831_69044_property_69046_vec__68828_69042$$=0,$i__68815_69023_map__68831_69045__$1_value_69047$$=0;;)if($i__68815_69023_map__68831_69045__$1_value_69047$$<$G__69040_c__5548__auto___69037_count__68814_69022_map__68831_69044_property_69046_vec__68828_69042$$){var $map__68827_69026_property_69028_vec__68824_69024$$=$G__69039_chunk__68813_69021_id_69043_snap_pixel_QMARK_$jscomp$4_undo_id$jscomp$9$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__68815_69023_map__68831_69045__$1_value_69047$$),
$id_69025$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__68827_69026_property_69028_vec__68824_69024$$,0,null);$map__68827_69026_property_69028_vec__68824_69024$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__68827_69026_property_69028_vec__68824_69024$$,1,null);var $map__68827_69027__$1_value_69029$$=$APP.$cljs$core$__destructure_map$$($map__68827_69026_property_69028_vec__68824_69024$$);$map__68827_69026_property_69028_vec__68824_69024$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68827_69027__$1_value_69029$$,
$cljs$cst$827$property$$);$map__68827_69027__$1_value_69029$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68827_69027__$1_value_69029$$,$APP.$cljs$cst$260$value$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__68827_69026_property_69028_vec__68824_69024$$,$APP.$cljs$cst$1770$grow_type$$)&&($APP.$app$render_wasm$api$use_shape$$($id_69025$$),$app$render_wasm$api$set_shape_grow_type$$($map__68827_69027__$1_value_69029$$));$i__68815_69023_map__68831_69045__$1_value_69047$$+=
1}else if($G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$=$APP.$cljs$core$seq$$($G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$)?($G__69040_c__5548__auto___69037_count__68814_69022_map__68831_69044_property_69046_vec__68828_69042$$=
$APP.$cljs$core$_chunked_first$$($G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$),$G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$=$APP.$cljs$core$_chunked_rest$$($G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$),$G__69039_chunk__68813_69021_id_69043_snap_pixel_QMARK_$jscomp$4_undo_id$jscomp$9$$=
$G__69040_c__5548__auto___69037_count__68814_69022_map__68831_69044_property_69046_vec__68828_69042$$,$G__69040_c__5548__auto___69037_count__68814_69022_map__68831_69044_property_69046_vec__68828_69042$$=$APP.$cljs$core$count$$($G__69040_c__5548__auto___69037_count__68814_69022_map__68831_69044_property_69046_vec__68828_69042$$)):($G__69040_c__5548__auto___69037_count__68814_69022_map__68831_69044_property_69046_vec__68828_69042$$=$APP.$cljs$core$first$$($G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$),
$G__69039_chunk__68813_69021_id_69043_snap_pixel_QMARK_$jscomp$4_undo_id$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__69040_c__5548__auto___69037_count__68814_69022_map__68831_69044_property_69046_vec__68828_69042$$,0,null),$G__69040_c__5548__auto___69037_count__68814_69022_map__68831_69044_property_69046_vec__68828_69042$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__69040_c__5548__auto___69037_count__68814_69022_map__68831_69044_property_69046_vec__68828_69042$$,
1,null),$i__68815_69023_map__68831_69045__$1_value_69047$$=$APP.$cljs$core$__destructure_map$$($G__69040_c__5548__auto___69037_count__68814_69022_map__68831_69044_property_69046_vec__68828_69042$$),$G__69040_c__5548__auto___69037_count__68814_69022_map__68831_69044_property_69046_vec__68828_69042$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($i__68815_69023_map__68831_69045__$1_value_69047$$,$cljs$cst$827$property$$),$i__68815_69023_map__68831_69045__$1_value_69047$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($i__68815_69023_map__68831_69045__$1_value_69047$$,
$APP.$cljs$cst$260$value$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__69040_c__5548__auto___69037_count__68814_69022_map__68831_69044_property_69046_vec__68828_69042$$,$APP.$cljs$cst$1770$grow_type$$)&&($APP.$app$render_wasm$api$use_shape$$($G__69039_chunk__68813_69021_id_69043_snap_pixel_QMARK_$jscomp$4_undo_id$jscomp$9$$),$app$render_wasm$api$set_shape_grow_type$$($i__68815_69023_map__68831_69045__$1_value_69047$$)),$G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$=
$APP.$cljs$core$next$$($G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$),$G__69039_chunk__68813_69021_id_69043_snap_pixel_QMARK_$jscomp$4_undo_id$jscomp$9$$=null,$G__69040_c__5548__auto___69037_count__68814_69022_map__68831_69044_property_69046_vec__68828_69042$$=0),$i__68815_69023_map__68831_69045__$1_value_69047$$=0;else break;var $objects$jscomp$466$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($ids$jscomp$104_state$jscomp$449$$);
$G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$main$data$workspace$modifiers$xf_COLON_parse_geometry_modifier$$,$self__$jscomp$4565$$.$modif_tree$);$G__69039_chunk__68813_69021_id_69043_snap_pixel_QMARK_$jscomp$4_undo_id$jscomp$9$$=$APP.$cljs$core$not$$($self__$jscomp$4565$$.$ignore_snap_pixel$)&&$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$2209$workspace_layout$$.$cljs$core$IFn$_invoke$arity$1$($ids$jscomp$104_state$jscomp$449$$),
$APP.$cljs$cst$2210$snap_pixel_grid$$);var $transforms$jscomp$1$$=$_$jscomp$2038_options$jscomp$509_translation_QMARK_$jscomp$11$$&&!$G__69039_chunk__68813_69021_id_69043_snap_pixel_QMARK_$jscomp$4_undo_id$jscomp$9$$?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$129$$,$data$jscomp$339_p__68844_subtree_ids$$){var $id$jscomp$542$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$339_p__68844_subtree_ids$$,0,null);$data$jscomp$339_p__68844_subtree_ids$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$339_p__68844_subtree_ids$$,1,null);var $t$jscomp$94$$=$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$339_p__68844_subtree_ids$$);$data$jscomp$339_p__68844_subtree_ids$$=function(){var $or__5025__auto__$jscomp$773$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4565$$.$subtree_ids_by_id$,$id$jscomp$542$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$773$$)?$or__5025__auto__$jscomp$773$$:
$app$common$files$helpers$get_children_ids_with_self$$($objects$jscomp$466$$,$id$jscomp$542$$)}();return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($a$jscomp$389$$,$sid$jscomp$2$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($a$jscomp$389$$,$sid$jscomp$2$$,$t$jscomp$94$$)},$acc$jscomp$129$$,$data$jscomp$339_p__68844_subtree_ids$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$):
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$app$render_wasm$api$propagate_modifiers$$($G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$,$G__69039_chunk__68813_69021_id_69043_snap_pixel_QMARK_$jscomp$4_undo_id$jscomp$9$$));$G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$=$app$main$data$workspace$modifiers$calculate_ignore_tree_wasm$$($transforms$jscomp$1$$,
$objects$jscomp$466$$);$_$jscomp$2038_options$jscomp$509_translation_QMARK_$jscomp$11$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$4565$$.params,$APP.$cljs$cst$3636$reg_objects_QMARK_$$,!0),$cljs$cst$3522$ignore_tree$$,$G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$),
$cljs$cst$3145$translation_QMARK_$$,$_$jscomp$2038_options$jscomp$509_translation_QMARK_$jscomp$11$$),$APP.$cljs$cst$2645$attrs$$,$app$main$data$workspace$modifiers$transform_attrs$$);var $modif_tree__$1$jscomp$15$$=$app$main$data$workspace$modifiers$propagate_structure_modifiers$$($self__$jscomp$4565$$.$modif_tree$,$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($ids$jscomp$104_state$jscomp$449$$));$ids$jscomp$104_state$jscomp$449$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$set$$($APP.$cljs$core$keys$$($modif_tree__$1$jscomp$15$$)),
$app$main$data$workspace$modifiers$xf_COLON_without_uuid_zero$$,$APP.$cljs$core$keys$$($transforms$jscomp$1$$));$G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$files$helpers$get_parents_with_self$$,
$objects$jscomp$466$$)),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$bool_shape_QMARK_$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$)),$ids$jscomp$104_state$jscomp$449$$);$G__69039_chunk__68813_69021_id_69043_snap_pixel_QMARK_$jscomp$4_undo_id$jscomp$9$$=Symbol();return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$truth_$$($self__$jscomp$4565$$.$undo_transation_QMARK_$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($G__69039_chunk__68813_69021_id_69043_snap_pixel_QMARK_$jscomp$4_undo_id$jscomp$9$$)):
$APP.$beicon$v2$core$empty$$(),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$modifiers$clear_local_transform$$(),$potok$v2$core$event$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$3839$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_move_frame_guides$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1723$ids$$,$ids$jscomp$104_state$jscomp$449$$,$cljs$cst$3840$transforms$$,$transforms$jscomp$1$$],null)),$potok$v2$core$event$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$3841$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_move_frame_comment_threads$$,
$transforms$jscomp$1$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$104_state$jscomp$449$$,function($shape$jscomp$533$$){var $modifiers$jscomp$74_shape_id$jscomp$97$$=$shape$jscomp$533$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$533$$,$APP.$cljs$cst$266$id$$),$transform$jscomp$98$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transforms$jscomp$1$$,$modifiers$jscomp$74_shape_id$jscomp$97$$);$modifiers$jscomp$74_shape_id$jscomp$97$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modif_tree__$1$jscomp$15$$,$modifiers$jscomp$74_shape_id$jscomp$97$$),$APP.$cljs$cst$1810$modifiers$$);return $APP.$app$common$types$modifiers$apply_structure_modifiers$$($APP.$app$common$geom$shapes$transforms$apply_transform$$($shape$jscomp$533$$,$transform$jscomp$98$$),$modifiers$jscomp$74_shape_id$jscomp$97$$)},$_$jscomp$2038_options$jscomp$509_translation_QMARK_$jscomp$11$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__69038_bool_ids_geometry_entries$jscomp$1_ignore_tree$jscomp$13_seq__68812_69020_seq__68812_69035__$1_temp__5825__auto___69034$$,
$APP.$app$common$types$path$update_bool_shape$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$2038_options$jscomp$509_translation_QMARK_$jscomp$11$$,$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0))),$APP.$cljs$core$truth_$$($self__$jscomp$4565$$.$undo_transation_QMARK_$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($G__69039_chunk__68813_69021_id_69043_snap_pixel_QMARK_$jscomp$4_undo_id$jscomp$9$$)):$APP.$beicon$v2$core$empty$$())});
return new $app$main$data$workspace$modifiers$apply_wasm_modifiesr_68801$$($p__68799$$,$modif_tree$jscomp$48$$,$undo_transation_QMARK_$$,$ignore_snap_pixel$jscomp$10$$,$map__68800__$1$$,$ignore_constraints$jscomp$23$$,$map__68800__$1$$,$snap_ignore_axis$jscomp$1$$,$subtree_ids_by_id$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$modifiers$set_delta_rotation_modifiers$$=function($angle$jscomp$32$$,$shapes$jscomp$86$$,$p__68879$$){var $map__68880__$1$$=$APP.$cljs$core$__destructure_map$$($p__68879$$),$center$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68880__$1$$,$APP.$cljs$cst$1667$center$$,null),$delta_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68880__$1$$,$APP.$cljs$cst$3844$delta_QMARK_$$,!1),$page_id$jscomp$158$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68880__$1$$,
$APP.$cljs$cst$2043$page_id$$);typeof $app$main$data$workspace$modifiers$set_delta_rotation_modifiers_68881$$==="undefined"&&($app$main$data$workspace$modifiers$set_delta_rotation_modifiers_68881$$=function($angle$jscomp$33$$,$shapes$jscomp$87$$,$p__68879$jscomp$1$$,$map__68880$jscomp$1$$,$center$jscomp$49$$,$delta_QMARK_$jscomp$1$$,$page_id$jscomp$159$$,$meta68882$$){this.angle=$angle$jscomp$33$$;this.shapes=$shapes$jscomp$87$$;this.$p__68879$=$p__68879$jscomp$1$$;this.$map__68880$=$map__68880$jscomp$1$$;
this.$center$=$center$jscomp$49$$;this.$delta_QMARK_$=$delta_QMARK_$jscomp$1$$;this.$page_id$=$page_id$jscomp$159$$;this.$meta68882$=$meta68882$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$modifiers$set_delta_rotation_modifiers_68881$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_delta_rotation_modifiers_68881$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3845$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_delta_rotation_modifiers$$},$app$main$data$workspace$modifiers$set_delta_rotation_modifiers_68881$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68883$$,$meta68882__$1$$){return new $app$main$data$workspace$modifiers$set_delta_rotation_modifiers_68881$$(this.angle,this.shapes,this.$p__68879$,this.$map__68880$,this.$center$,this.$delta_QMARK_$,this.$page_id$,$meta68882__$1$$)},$app$main$data$workspace$modifiers$set_delta_rotation_modifiers_68881$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta68882$},$app$main$data$workspace$modifiers$set_delta_rotation_modifiers_68881$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_delta_rotation_modifiers_68881$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2041_modif_tree$jscomp$52_objects$jscomp$469_page_id__$1$jscomp$9$$,$state$jscomp$452$$){var $self__$jscomp$4577$$=this;$_$jscomp$2041_modif_tree$jscomp$52_objects$jscomp$469_page_id__$1$jscomp$9$$=
function(){var $or__5025__auto__$jscomp$774$$=$self__$jscomp$4577$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$774$$)?$or__5025__auto__$jscomp$774$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$452$$)}();$_$jscomp$2041_modif_tree$jscomp$52_objects$jscomp$469_page_id__$1$jscomp$9$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$452$$,$_$jscomp$2041_modif_tree$jscomp$52_objects$jscomp$469_page_id__$1$jscomp$9$$);
var $ids$jscomp$107$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68878_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$attrs$editable_attrs$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__68878_SHARP_$$)),$APP.$cljs$cst$1788$rotation$$)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68877_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($p1__68877_SHARP_$$,
$APP.$cljs$cst$1623$blocked$$,!1)},$self__$jscomp$4577$$.shapes)));$_$jscomp$2041_modif_tree$jscomp$52_objects$jscomp$469_page_id__$1$jscomp$9$$=$APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$modifiers$build_modif_tree$$($ids$jscomp$107$$,$_$jscomp$2041_modif_tree$jscomp$52_objects$jscomp$469_page_id__$1$jscomp$9$$,function($shape$jscomp$536$$){var $delta$jscomp$42$$=$APP.$cljs$core$truth_$$($self__$jscomp$4577$$.$delta_QMARK_$)?
$self__$jscomp$4577$$.angle:$self__$jscomp$4577$$.angle-$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$536$$);var $center__$1$jscomp$4_or__5025__auto__$jscomp$inline_6743$$=$self__$jscomp$4577$$.$center$;$center__$1$jscomp$4_or__5025__auto__$jscomp$inline_6743$$=$APP.$cljs$core$truth_$$($center__$1$jscomp$4_or__5025__auto__$jscomp$inline_6743$$)?$center__$1$jscomp$4_or__5025__auto__$jscomp$inline_6743$$:$APP.$app$common$geom$shapes$common$shape__GT_center$$($shape$jscomp$536$$);
return $APP.$app$common$types$modifiers$rotation_modifiers$$($shape$jscomp$536$$,$center__$1$jscomp$4_or__5025__auto__$jscomp$inline_6743$$,$delta$jscomp$42$$)}),$_$jscomp$2041_modif_tree$jscomp$52_objects$jscomp$469_page_id__$1$jscomp$9$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$452$$,$APP.$cljs$cst$1922$workspace_modifiers$$,$_$jscomp$2041_modif_tree$jscomp$52_objects$jscomp$469_page_id__$1$jscomp$9$$)});return new $app$main$data$workspace$modifiers$set_delta_rotation_modifiers_68881$$($angle$jscomp$32$$,
$shapes$jscomp$86$$,$p__68879$$,$map__68880__$1$$,$center$jscomp$48$$,$delta_QMARK_$$,$page_id$jscomp$158$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$modifiers$apply_modifiers_STAR_$$=function($objects$jscomp$470$$,$object_modifiers$$,$text_modifiers$jscomp$1$$,$options$jscomp$510$$){typeof $app$main$data$workspace$modifiers$apply_modifiers_STAR__68885$$==="undefined"&&($app$main$data$workspace$modifiers$apply_modifiers_STAR__68885$$=function($objects$jscomp$471$$,$object_modifiers$jscomp$1$$,$text_modifiers$jscomp$2$$,$options$jscomp$511$$,$meta68886$$){this.objects=$objects$jscomp$471$$;this.$object_modifiers$=$object_modifiers$jscomp$1$$;
this.$text_modifiers$=$text_modifiers$jscomp$2$$;this.options=$options$jscomp$511$$;this.$meta68886$=$meta68886$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$modifiers$apply_modifiers_STAR__68885$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$apply_modifiers_STAR__68885$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3846$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_apply_modifiers_STAR_$$},
$app$main$data$workspace$modifiers$apply_modifiers_STAR__68885$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68887$$,$meta68886__$1$$){return new $app$main$data$workspace$modifiers$apply_modifiers_STAR__68885$$(this.objects,this.$object_modifiers$,this.$text_modifiers$,this.options,$meta68886__$1$$)},$app$main$data$workspace$modifiers$apply_modifiers_STAR__68885$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68886$},$app$main$data$workspace$modifiers$apply_modifiers_STAR__68885$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$apply_modifiers_STAR__68885$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$4581$$=this,$ids$jscomp$108$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$main$data$workspace$modifiers$xf_COLON_without_uuid_zero$$,$APP.$cljs$core$keys$$($self__$jscomp$4581$$.$object_modifiers$)),$ids_with_children$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($ids$jscomp$108$$,
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$helpers$get_children_ids$$,$self__$jscomp$4581$$.objects)),$ids$jscomp$108$$),$ignore_tree$jscomp$14_options__$1$jscomp$69$$=$app$main$data$workspace$modifiers$calculate_ignore_tree$$($self__$jscomp$4581$$.$object_modifiers$,$self__$jscomp$4581$$.objects);$ignore_tree$jscomp$14_options__$1$jscomp$69$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$4581$$.options,
$APP.$cljs$cst$3636$reg_objects_QMARK_$$,!0),$cljs$cst$3522$ignore_tree$$,$ignore_tree$jscomp$14_options__$1$jscomp$69$$),$APP.$cljs$cst$2645$attrs$$,$app$main$data$workspace$modifiers$transform_attrs$$);return(0,$APP.$beicon$v2$core$of$$)($potok$v2$core$event$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$3839$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_move_frame_guides$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1723$ids$$,$ids_with_children$jscomp$1$$,$APP.$cljs$cst$1810$modifiers$$,
$self__$jscomp$4581$$.$object_modifiers$],null)),$potok$v2$core$event$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$3841$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_move_frame_comment_threads$$,$ids_with_children$jscomp$1$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$108$$,function($JSCompiler_temp$jscomp$1160_deltav$jscomp$inline_6748_position_data__$1$jscomp$inline_6749_shape$jscomp$537$$){var $pos_data_shape_id$jscomp$98$$=$JSCompiler_temp$jscomp$1160_deltav$jscomp$inline_6748_position_data__$1$jscomp$inline_6749_shape$jscomp$537$$?.id??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1160_deltav$jscomp$inline_6748_position_data__$1$jscomp$inline_6749_shape$jscomp$537$$,$APP.$cljs$cst$266$id$$),$G__68890_modifiers$jscomp$77$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4581$$.$object_modifiers$,$pos_data_shape_id$jscomp$98$$),$APP.$cljs$cst$1810$modifiers$$);$pos_data_shape_id$jscomp$98$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1160_deltav$jscomp$inline_6748_position_data__$1$jscomp$inline_6749_shape$jscomp$537$$)?
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4581$$.$text_modifiers$,$pos_data_shape_id$jscomp$98$$),$APP.$cljs$cst$1891$position_data$$):null;$G__68890_modifiers$jscomp$77$$=$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1160_deltav$jscomp$inline_6748_position_data__$1$jscomp$inline_6749_shape$jscomp$537$$,$G__68890_modifiers$jscomp$77$$);$APP.$app$common$data$not_empty_QMARK_$$($pos_data_shape_id$jscomp$98$$)?
($JSCompiler_temp$jscomp$1160_deltav$jscomp$inline_6748_position_data__$1$jscomp$inline_6749_shape$jscomp$537$$=$APP.$app$common$geom$point$to_vec$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1160_deltav$jscomp$inline_6748_position_data__$1$jscomp$inline_6749_shape$jscomp$537$$)),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($G__68890_modifiers$jscomp$77$$))),
$JSCompiler_temp$jscomp$1160_deltav$jscomp$inline_6748_position_data__$1$jscomp$inline_6749_shape$jscomp$537$$=$app$common$geom$shapes$transforms$move_position_data$$($pos_data_shape_id$jscomp$98$$,$JSCompiler_temp$jscomp$1160_deltav$jscomp$inline_6748_position_data__$1$jscomp$inline_6749_shape$jscomp$537$$),$JSCompiler_temp$jscomp$1160_deltav$jscomp$inline_6748_position_data__$1$jscomp$inline_6749_shape$jscomp$537$$=$APP.$app$common$data$not_empty_QMARK_$$($JSCompiler_temp$jscomp$1160_deltav$jscomp$inline_6748_position_data__$1$jscomp$inline_6749_shape$jscomp$537$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__68890_modifiers$jscomp$77$$,$APP.$cljs$cst$1891$position_data$$,$JSCompiler_temp$jscomp$1160_deltav$jscomp$inline_6748_position_data__$1$jscomp$inline_6749_shape$jscomp$537$$):$G__68890_modifiers$jscomp$77$$):$JSCompiler_temp$jscomp$1160_deltav$jscomp$inline_6748_position_data__$1$jscomp$inline_6749_shape$jscomp$537$$=$G__68890_modifiers$jscomp$77$$;return $JSCompiler_temp$jscomp$1160_deltav$jscomp$inline_6748_position_data__$1$jscomp$inline_6749_shape$jscomp$537$$},
$ignore_tree$jscomp$14_options__$1$jscomp$69$$))});return new $app$main$data$workspace$modifiers$apply_modifiers_STAR__68885$$($objects$jscomp$470$$,$object_modifiers$$,$text_modifiers$jscomp$1$$,$options$jscomp$510$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$=function($p__68897$$){var $map__68898__$1$$=$APP.$cljs$core$__destructure_map$$($p__68897$$),$modifiers$jscomp$78$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68898__$1$$,$APP.$cljs$cst$1810$modifiers$$),$undo_transation_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68898__$1$$,$cljs$cst$3837$undo_transation_QMARK_$$,!0),$ignore_constraints$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68898__$1$$,
$APP.$cljs$cst$3821$ignore_constraints$$,!1),$ignore_snap_pixel$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__68898__$1$$,$cljs$cst$3833$ignore_snap_pixel$$,!1),$page_id$jscomp$160$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68898__$1$$,$APP.$cljs$cst$2043$page_id$$);typeof $app$main$data$workspace$modifiers$apply_modifiers_68899$$==="undefined"&&($app$main$data$workspace$modifiers$apply_modifiers_68899$$=function($p__68897$jscomp$1$$,$map__68898$jscomp$1$$,
$options$jscomp$513$$,$modifiers$jscomp$79$$,$undo_transation_QMARK_$jscomp$3$$,$ignore_constraints$jscomp$26$$,$ignore_snap_pixel$jscomp$13$$,$page_id$jscomp$161$$,$meta68900$$){this.$p__68897$=$p__68897$jscomp$1$$;this.$map__68898$=$map__68898$jscomp$1$$;this.options=$options$jscomp$513$$;this.modifiers=$modifiers$jscomp$79$$;this.$undo_transation_QMARK_$=$undo_transation_QMARK_$jscomp$3$$;this.$ignore_constraints$=$ignore_constraints$jscomp$26$$;this.$ignore_snap_pixel$=$ignore_snap_pixel$jscomp$13$$;
this.$page_id$=$page_id$jscomp$161$$;this.$meta68900$=$meta68900$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$modifiers$apply_modifiers_68899$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$apply_modifiers_68899$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3847$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_apply_modifiers$$},
$app$main$data$workspace$modifiers$apply_modifiers_68899$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68901$$,$meta68900__$1$$){return new $app$main$data$workspace$modifiers$apply_modifiers_68899$$(this.$p__68897$,this.$map__68898$,this.options,this.modifiers,this.$undo_transation_QMARK_$,this.$ignore_constraints$,this.$ignore_snap_pixel$,this.$page_id$,$meta68900__$1$$)},$app$main$data$workspace$modifiers$apply_modifiers_68899$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68900$},
$app$main$data$workspace$modifiers$apply_modifiers_68899$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$apply_modifiers_68899$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2043_text_modifiers$jscomp$3$$,$state$jscomp$453$$){var $self__$jscomp$4585$$=this;$_$jscomp$2043_text_modifiers$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$453$$,$APP.$cljs$cst$2238$workspace_text_modifier$$);
var $page_id__$1$jscomp$10_undo_id$jscomp$10$$=function(){var $or__5025__auto__$jscomp$776$$=$self__$jscomp$4585$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$776$$)?$or__5025__auto__$jscomp$776$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$453$$)}(),$objects$jscomp$472$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$453$$,$page_id__$1$jscomp$10_undo_id$jscomp$10$$),$object_modifiers$jscomp$2$$=
$self__$jscomp$4585$$.modifiers!=null?$app$main$data$workspace$modifiers$calculate_modifiers$cljs$0core$0IFn$0_invoke$0arity$06$$($state$jscomp$453$$,$self__$jscomp$4585$$.$ignore_constraints$,$self__$jscomp$4585$$.$ignore_snap_pixel$,$self__$jscomp$4585$$.modifiers,$page_id__$1$jscomp$10_undo_id$jscomp$10$$,null):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$453$$,$APP.$cljs$cst$1922$workspace_modifiers$$);$page_id__$1$jscomp$10_undo_id$jscomp$10$$=Symbol();return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$truth_$$($self__$jscomp$4585$$.$undo_transation_QMARK_$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($page_id__$1$jscomp$10_undo_id$jscomp$10$$)):$APP.$beicon$v2$core$empty$$(),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$modifiers$apply_modifiers_STAR_$$($objects$jscomp$472$$,$object_modifiers$jscomp$2$$,$_$jscomp$2043_text_modifiers$jscomp$3$$,$self__$jscomp$4585$$.options),function($state__$1$jscomp$19$$){var $ids$jscomp$109$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$app$main$data$workspace$modifiers$xf_COLON_without_uuid_zero$$,$APP.$cljs$core$keys$$($object_modifiers$jscomp$2$$));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$19$$,$APP.$cljs$cst$2238$workspace_text_modifier$$,function($p1__68892_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$,$p1__68892_SHARP_$$,$ids$jscomp$109$$)})}),$self__$jscomp$4585$$.modifiers==null?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$modifiers$clear_local_transform$$()):
$APP.$beicon$v2$core$empty$$(),$APP.$cljs$core$truth_$$($self__$jscomp$4585$$.$undo_transation_QMARK_$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($page_id__$1$jscomp$10_undo_id$jscomp$10$$)):$APP.$beicon$v2$core$empty$$())});return new $app$main$data$workspace$modifiers$apply_modifiers_68899$$($p__68897$$,$map__68898__$1$$,$map__68898__$1$$,$modifiers$jscomp$78$$,$undo_transation_QMARK_$jscomp$2$$,$ignore_constraints$jscomp$25$$,$ignore_snap_pixel$jscomp$12$$,
$page_id$jscomp$160$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$modifiers$next_grow_type$$=function($current_grow_type$$,$scalev$jscomp$2$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_grow_type$$,$APP.$cljs$cst$1671$fixed$$)?$APP.$cljs$cst$1671$fixed$$:$APP.$cljs$core$not$$($APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($scalev$jscomp$2$$),1))&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_grow_type$$,$APP.$cljs$cst$2036$auto_width$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_grow_type$$,$APP.$cljs$cst$2035$auto_height$$))?$APP.$cljs$cst$1671$fixed$$:$APP.$cljs$core$not$$($APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($scalev$jscomp$2$$),1))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_grow_type$$,$APP.$cljs$cst$2036$auto_width$$)?$APP.$cljs$cst$2035$auto_height$$:$current_grow_type$$};
$APP.$app$common$geom$snap$rect__GT_snap_points$$=function($rect$jscomp$39$$){if($rect$jscomp$39$$!=null){var $x$jscomp$1193$$=$rect$jscomp$39$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$39$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$429$$=$rect$jscomp$39$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$39$$,$APP.$cljs$cst$1511$y$$),$w$jscomp$40$$=$rect$jscomp$39$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$39$$,$APP.$cljs$cst$290$width$$),
$h$jscomp$162$$=$rect$jscomp$39$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$39$$,$APP.$cljs$cst$1522$height$$);return $APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1193$$,$y$jscomp$429$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1193$$+$w$jscomp$40$$,$y$jscomp$429$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1193$$,
$y$jscomp$429$$+$h$jscomp$162$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1193$$+$w$jscomp$40$$,$y$jscomp$429$$+$h$jscomp$162$$),$APP.$app$common$geom$rect$rect__GT_center$$($rect$jscomp$39$$)])}return null};
$$jscomp$scope$236007416$20$recToString$$=function($branch$jscomp$2$$,$result$jscomp$293$$){$branch$jscomp$2$$&&($$jscomp$scope$236007416$20$recToString$$($branch$jscomp$2$$.left,$result$jscomp$293$$),$result$jscomp$293$$.push(`${$branch$jscomp$2$$.value}: [${$branch$jscomp$2$$.data.join(", ")}]`),$$jscomp$scope$236007416$20$recToString$$($branch$jscomp$2$$.right,$result$jscomp$293$$))};
$$jscomp$scope$236007416$19$recHeight$$=function($branch$jscomp$3$$){let $curHeight$$=0;$branch$jscomp$3$$!==null&&($curHeight$$=Math.max($$jscomp$scope$236007416$19$recHeight$$($branch$jscomp$3$$.left),$$jscomp$scope$236007416$19$recHeight$$($branch$jscomp$3$$.right)));return 1+$curHeight$$};
$$jscomp$scope$236007416$18$flipColors$$=function($branch$jscomp$4$$){$branch$jscomp$4$$.color=$branch$jscomp$4$$.color===$$jscomp$scope$236007416$0$Color$RED$$?$$jscomp$scope$236007416$0$Color$BLACK$$:$$jscomp$scope$236007416$0$Color$RED$$;$branch$jscomp$4$$.left&&($branch$jscomp$4$$.left.color=$branch$jscomp$4$$.left.color===$$jscomp$scope$236007416$0$Color$RED$$?$$jscomp$scope$236007416$0$Color$BLACK$$:$$jscomp$scope$236007416$0$Color$RED$$);$branch$jscomp$4$$.right&&($branch$jscomp$4$$.right.color=
$branch$jscomp$4$$.right.color===$$jscomp$scope$236007416$0$Color$RED$$?$$jscomp$scope$236007416$0$Color$BLACK$$:$$jscomp$scope$236007416$0$Color$RED$$)};
$$jscomp$scope$236007416$15$moveRedLeft$$=function($branch$jscomp$6$$){$$jscomp$scope$236007416$18$flipColors$$($branch$jscomp$6$$);$branch$jscomp$6$$.right&&$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$6$$.right.left)&&($branch$jscomp$6$$.right=$$jscomp$scope$236007416$13$rotateRight$$($branch$jscomp$6$$.right),$branch$jscomp$6$$=$$jscomp$scope$236007416$12$rotateLeft$$($branch$jscomp$6$$),$$jscomp$scope$236007416$18$flipColors$$($branch$jscomp$6$$));return $branch$jscomp$6$$};
$$jscomp$scope$236007416$14$balance$$=function($branch$jscomp$7$$){$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$7$$.right)&&($branch$jscomp$7$$=$$jscomp$scope$236007416$12$rotateLeft$$($branch$jscomp$7$$));$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$7$$.left)&&$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$7$$.left.left)&&($branch$jscomp$7$$=$$jscomp$scope$236007416$13$rotateRight$$($branch$jscomp$7$$));$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$7$$.left)&&$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$7$$.right)&&
$$jscomp$scope$236007416$18$flipColors$$($branch$jscomp$7$$);return $branch$jscomp$7$$};$$jscomp$scope$236007416$13$rotateRight$$=function($branch$jscomp$8$$){const $x$jscomp$1195$$=$branch$jscomp$8$$.left;$branch$jscomp$8$$.left=$x$jscomp$1195$$.right;$x$jscomp$1195$$.right=$branch$jscomp$8$$;$x$jscomp$1195$$.color=$x$jscomp$1195$$.right.color;$x$jscomp$1195$$.right.color=$$jscomp$scope$236007416$0$Color$RED$$;return $x$jscomp$1195$$};
$$jscomp$scope$236007416$12$rotateLeft$$=function($branch$jscomp$9$$){const $x$jscomp$1196$$=$branch$jscomp$9$$.right;$branch$jscomp$9$$.right=$x$jscomp$1196$$.left;$x$jscomp$1196$$.left=$branch$jscomp$9$$;$x$jscomp$1196$$.color=$x$jscomp$1196$$.left.color;$x$jscomp$1196$$.left.color=$$jscomp$scope$236007416$0$Color$RED$$;return $x$jscomp$1196$$};
$$jscomp$scope$236007416$11$recRangeQuery$$=function($branch$jscomp$10$$,$fromValue$$,$toValue$$,$result$jscomp$294$$){if(!$branch$jscomp$10$$)return $result$jscomp$294$$;$fromValue$$<$branch$jscomp$10$$.value&&$$jscomp$scope$236007416$11$recRangeQuery$$($branch$jscomp$10$$.left,$fromValue$$,$toValue$$,$result$jscomp$294$$);$fromValue$$<=$branch$jscomp$10$$.value&&$toValue$$>=$branch$jscomp$10$$.value&&$result$jscomp$294$$.push($APP.$cljs$core$vec$$([$branch$jscomp$10$$.value,$APP.$cljs$core$vec$$($branch$jscomp$10$$.data)]));
$toValue$$>$branch$jscomp$10$$.value&&$$jscomp$scope$236007416$11$recRangeQuery$$($branch$jscomp$10$$.right,$fromValue$$,$toValue$$,$result$jscomp$294$$);return $result$jscomp$294$$};
$$jscomp$scope$236007416$10$recUpdate$$=function($branch$jscomp$11$$,$value$jscomp$549$$,$oldData$$,$newData$jscomp$1$$){if($branch$jscomp$11$$){if($branch$jscomp$11$$.value===$value$jscomp$549$$)return $branch$jscomp$11$$.data=$branch$jscomp$11$$.data.map($it$jscomp$170$$=>$APP.$cljs$core$_EQ_$$($it$jscomp$170$$,$oldData$$)?$newData$jscomp$1$$:$it$jscomp$170$$),$branch$jscomp$11$$;if($branch$jscomp$11$$.value>$value$jscomp$549$$)return $$jscomp$scope$236007416$10$recUpdate$$($branch$jscomp$11$$.left,
$value$jscomp$549$$,$oldData$$,$newData$jscomp$1$$);if($branch$jscomp$11$$.value<$value$jscomp$549$$)return $$jscomp$scope$236007416$10$recUpdate$$($branch$jscomp$11$$.right,$value$jscomp$549$$,$oldData$$,$newData$jscomp$1$$)}else return $branch$jscomp$11$$};
$$jscomp$scope$236007416$9$recGet$$=function($branch$jscomp$12$$,$value$jscomp$550$$){if($branch$jscomp$12$$){if($branch$jscomp$12$$.value===$value$jscomp$550$$)return $branch$jscomp$12$$.data;if($branch$jscomp$12$$.value>$value$jscomp$550$$)return $$jscomp$scope$236007416$9$recGet$$($branch$jscomp$12$$.left,$value$jscomp$550$$);if($branch$jscomp$12$$.value<$value$jscomp$550$$)return $$jscomp$scope$236007416$9$recGet$$($branch$jscomp$12$$.right,$value$jscomp$550$$)}else return null};
$$jscomp$scope$236007416$8$recRemoveNode$$=function($branch$jscomp$13_branch$jscomp$inline_6751$$,$value$jscomp$551_x$jscomp$1197$$){if($value$jscomp$551_x$jscomp$1197$$<$branch$jscomp$13_branch$jscomp$inline_6751$$.value)$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$13_branch$jscomp$inline_6751$$.left)||$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$13_branch$jscomp$inline_6751$$.left.left)||($branch$jscomp$13_branch$jscomp$inline_6751$$=$$jscomp$scope$236007416$15$moveRedLeft$$($branch$jscomp$13_branch$jscomp$inline_6751$$)),
$branch$jscomp$13_branch$jscomp$inline_6751$$.left=$$jscomp$scope$236007416$8$recRemoveNode$$($branch$jscomp$13_branch$jscomp$inline_6751$$.left,$value$jscomp$551_x$jscomp$1197$$);else{$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$13_branch$jscomp$inline_6751$$.left)&&($branch$jscomp$13_branch$jscomp$inline_6751$$=$$jscomp$scope$236007416$13$rotateRight$$($branch$jscomp$13_branch$jscomp$inline_6751$$));if($value$jscomp$551_x$jscomp$1197$$===$branch$jscomp$13_branch$jscomp$inline_6751$$.value&&
!$branch$jscomp$13_branch$jscomp$inline_6751$$.right)return null;$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$13_branch$jscomp$inline_6751$$.right)||$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$13_branch$jscomp$inline_6751$$.right.left)||($$jscomp$scope$236007416$18$flipColors$$($branch$jscomp$13_branch$jscomp$inline_6751$$),$branch$jscomp$13_branch$jscomp$inline_6751$$.left&&$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$13_branch$jscomp$inline_6751$$.left.left)&&($branch$jscomp$13_branch$jscomp$inline_6751$$=
$$jscomp$scope$236007416$13$rotateRight$$($branch$jscomp$13_branch$jscomp$inline_6751$$),$$jscomp$scope$236007416$18$flipColors$$($branch$jscomp$13_branch$jscomp$inline_6751$$)));$value$jscomp$551_x$jscomp$1197$$===$branch$jscomp$13_branch$jscomp$inline_6751$$.value?($value$jscomp$551_x$jscomp$1197$$=$$jscomp$scope$236007416$5$searchMin$$($branch$jscomp$13_branch$jscomp$inline_6751$$.right),$branch$jscomp$13_branch$jscomp$inline_6751$$.value=$value$jscomp$551_x$jscomp$1197$$.value,$branch$jscomp$13_branch$jscomp$inline_6751$$.data=
$value$jscomp$551_x$jscomp$1197$$.data,$branch$jscomp$13_branch$jscomp$inline_6751$$.right=$$jscomp$scope$236007416$6$recRemoveMin$$($branch$jscomp$13_branch$jscomp$inline_6751$$.right)):$branch$jscomp$13_branch$jscomp$inline_6751$$.right=$$jscomp$scope$236007416$8$recRemoveNode$$($branch$jscomp$13_branch$jscomp$inline_6751$$.right,$value$jscomp$551_x$jscomp$1197$$)}return $$jscomp$scope$236007416$14$balance$$($branch$jscomp$13_branch$jscomp$inline_6751$$)};
$$jscomp$scope$236007416$7$recRemoveData$$=function($branch$jscomp$14$$,$value$jscomp$552$$,$data$jscomp$340$$){if($branch$jscomp$14$$){if($branch$jscomp$14$$.value===$value$jscomp$552$$)return $branch$jscomp$14$$.data=$branch$jscomp$14$$.data.filter($it$jscomp$171$$=>!$APP.$cljs$core$_EQ_$$($it$jscomp$171$$,$data$jscomp$340$$)),$branch$jscomp$14$$;if($branch$jscomp$14$$.value>$value$jscomp$552$$)return $branch$jscomp$14$$.left=$$jscomp$scope$236007416$7$recRemoveData$$($branch$jscomp$14$$.left,$value$jscomp$552$$,
$data$jscomp$340$$),$branch$jscomp$14$$;if($branch$jscomp$14$$.value<$value$jscomp$552$$)return $branch$jscomp$14$$.right=$$jscomp$scope$236007416$7$recRemoveData$$($branch$jscomp$14$$.right,$value$jscomp$552$$,$data$jscomp$340$$),$branch$jscomp$14$$}else return $branch$jscomp$14$$};
$$jscomp$scope$236007416$6$recRemoveMin$$=function($branch$jscomp$15$$){if(!$branch$jscomp$15$$.left)return null;$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$15$$.left)||$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$15$$.left.left)||($branch$jscomp$15$$=$$jscomp$scope$236007416$15$moveRedLeft$$($branch$jscomp$15$$));$branch$jscomp$15$$.left=$$jscomp$scope$236007416$6$recRemoveMin$$($branch$jscomp$15$$.left);return $$jscomp$scope$236007416$14$balance$$($branch$jscomp$15$$)};
$$jscomp$scope$236007416$5$searchMin$$=function($branch$jscomp$16$$){return $branch$jscomp$16$$.left?$$jscomp$scope$236007416$5$searchMin$$($branch$jscomp$16$$.left):$branch$jscomp$16$$};
$$jscomp$scope$236007416$4$recInsert$$=function($branch$jscomp$17_ret$jscomp$147$$,$value$jscomp$553$$,$data$jscomp$341$$){if(!$branch$jscomp$17_ret$jscomp$147$$)return $branch$jscomp$17_ret$jscomp$147$$=new $$jscomp$scope$236007416$1$Node$$($value$jscomp$553$$,$data$jscomp$341$$),$branch$jscomp$17_ret$jscomp$147$$.color=$$jscomp$scope$236007416$0$Color$RED$$,$branch$jscomp$17_ret$jscomp$147$$;$branch$jscomp$17_ret$jscomp$147$$.value===$value$jscomp$553$$?$branch$jscomp$17_ret$jscomp$147$$.data.push($data$jscomp$341$$):
$branch$jscomp$17_ret$jscomp$147$$.value>$value$jscomp$553$$?$branch$jscomp$17_ret$jscomp$147$$.left=$$jscomp$scope$236007416$4$recInsert$$($branch$jscomp$17_ret$jscomp$147$$.left,$value$jscomp$553$$,$data$jscomp$341$$):$branch$jscomp$17_ret$jscomp$147$$.value<$value$jscomp$553$$&&($branch$jscomp$17_ret$jscomp$147$$.right=$$jscomp$scope$236007416$4$recInsert$$($branch$jscomp$17_ret$jscomp$147$$.right,$value$jscomp$553$$,$data$jscomp$341$$));$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$17_ret$jscomp$147$$.right)&&
!$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$17_ret$jscomp$147$$.left)&&($branch$jscomp$17_ret$jscomp$147$$=$$jscomp$scope$236007416$12$rotateLeft$$($branch$jscomp$17_ret$jscomp$147$$));$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$17_ret$jscomp$147$$.left)&&$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$17_ret$jscomp$147$$.left.left)&&($branch$jscomp$17_ret$jscomp$147$$=$$jscomp$scope$236007416$13$rotateRight$$($branch$jscomp$17_ret$jscomp$147$$));$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$17_ret$jscomp$147$$.left)&&
$$jscomp$scope$236007416$3$isRed$$($branch$jscomp$17_ret$jscomp$147$$.right)&&$$jscomp$scope$236007416$18$flipColors$$($branch$jscomp$17_ret$jscomp$147$$);return $branch$jscomp$17_ret$jscomp$147$$};$$jscomp$scope$236007416$3$isRed$$=function($branch$jscomp$18$$){return $branch$jscomp$18$$&&$branch$jscomp$18$$.color===$$jscomp$scope$236007416$0$Color$RED$$};
$JSCompiler_StaticMethods_insert$$=function($JSCompiler_StaticMethods_insert$self$$,$value$jscomp$555$$,$data$jscomp$343$$){$JSCompiler_StaticMethods_insert$self$$.root=$$jscomp$scope$236007416$4$recInsert$$($JSCompiler_StaticMethods_insert$self$$.root,$value$jscomp$555$$,$data$jscomp$343$$);$JSCompiler_StaticMethods_insert$self$$.root.color=$$jscomp$scope$236007416$0$Color$BLACK$$;return $JSCompiler_StaticMethods_insert$self$$};
$APP.$app$main$snap$remove_from_snap_points$$=function($remove_snap_QMARK_$$){return function($query_result$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($data$jscomp$347_p__68446$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$347_p__68446$$,0,null);$data$jscomp$347_p__68446$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$347_p__68446$$,1,null);return $APP.$cljs$core$seq$$($data$jscomp$347_p__68446$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($data$jscomp$348_p__68451$$){var $value$jscomp$563$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$348_p__68451$$,0,null);$data$jscomp$348_p__68451$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$348_p__68451$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$value$jscomp$563$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($remove_snap_QMARK_$$,$data$jscomp$348_p__68451$$)],null)},$query_result$$))}};
$APP.$app$main$snap$make_remove_snap$$=function($layout$jscomp$7$$,$filter_shapes$$,$objects$jscomp$473$$,$focus$jscomp$9$$){return function($p__68455_type$jscomp$482$$){var $frame_id$jscomp$82_map__68456__$1$$=$APP.$cljs$core$__destructure_map$$($p__68455_type$jscomp$482$$);$p__68455_type$jscomp$482$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$82_map__68456__$1$$,$APP.$cljs$cst$139$type$$);var $id$jscomp$544$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$82_map__68456__$1$$,
$APP.$cljs$cst$266$id$$);$frame_id$jscomp$82_map__68456__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$82_map__68456__$1$$,$APP.$cljs$cst$1607$frame_id$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__68455_type$jscomp$482$$,$APP.$cljs$cst$1615$layout$$)?!$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$7$$,$APP.$cljs$cst$3725$display_guides$$)||!$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$7$$,$APP.$cljs$cst$3720$snap_guides$$)||$APP.$app$common$data$not_empty_QMARK_$$($focus$jscomp$9$$)&&
!$APP.$cljs$core$contains_QMARK_$$($focus$jscomp$9$$,$id$jscomp$544$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__68455_type$jscomp$482$$,$APP.$cljs$cst$3848$guide$$)?!$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$7$$,$APP.$cljs$cst$2211$rulers$$)||!$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$7$$,$APP.$cljs$cst$3723$snap_ruler_guides$$)||$APP.$app$common$data$not_empty_QMARK_$$($focus$jscomp$9$$)&&!$APP.$cljs$core$contains_QMARK_$$($focus$jscomp$9$$,$frame_id$jscomp$82_map__68456__$1$$):
$APP.$cljs$core$contains_QMARK_$$($filter_shapes$$,$id$jscomp$544$$)||!$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$7$$,$APP.$cljs$cst$3724$dynamic_alignment$$)||$APP.$app$common$data$not_empty_QMARK_$$($focus$jscomp$9$$)&&$APP.$cljs$core$not$$($APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$contains_QMARK_$$,$focus$jscomp$9$$),$APP.$cljs$core$cons$$($id$jscomp$544$$,$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$473$$,
$id$jscomp$544$$))))}};
$app$main$snap$calculate_distance$$=function($query_result$jscomp$1$$,$point$jscomp$56$$,$coord$jscomp$5$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__68461$$){var $value$jscomp$564$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68461$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68461$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$math$abs$$($value$jscomp$564$$-($coord$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?
$coord$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$56$$):$coord$jscomp$5$$($point$jscomp$56$$))),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$coord$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$coord$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$56$$):$coord$jscomp$5$$($point$jscomp$56$$),$value$jscomp$564$$],null)],null)},$query_result$jscomp$1$$)};
$app$main$snap$get_min_distance_snap$$=function($points$jscomp$68$$,$coord$jscomp$6$$){return function($query_result$jscomp$2$$){return $APP.$cljs$core$second$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$min_key$$,$APP.$cljs$core$first$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__68465_SHARP_$$){return $app$main$snap$calculate_distance$$($query_result$jscomp$2$$,$p1__68465_SHARP_$$,$coord$jscomp$6$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$points$jscomp$68$$]))))}};
$APP.$app$main$snap$snap_frame_id$$=function($shapes$jscomp$88$$){var $frames$jscomp$13$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1607$frame_id$$,$shapes$jscomp$88$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$cljs$core$count$$($frames$jscomp$13$$))?$APP.$cljs$core$first$$($frames$jscomp$13$$):$APP.$cljs$core$not$$($frames$jscomp$13$$.$cljs$core$IFn$_invoke$arity$1$?
$frames$jscomp$13$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$uuid$zero$$):$frames$jscomp$13$$($APP.$app$common$uuid$zero$$))?$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$88$$)):$APP.$app$common$uuid$zero$$};
$app$main$snap$snap_accuracy_ranges$$=function($points$jscomp$69$$,$coord$jscomp$8$$,$zoom$jscomp$14$$){var $acc$jscomp$130$$=10/$zoom$jscomp$14$$;return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68474_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__68474_SHARP_$$-$acc$jscomp$130$$,$p1__68474_SHARP_$$+$acc$jscomp$130$$],null)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$8$$,$points$jscomp$69$$))};
$app$main$snap$snap__GT_vector$$=function($from_y_p__68479$$){var $to$jscomp$23_to_x_vec__68483$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from_y_p__68479$$,0,null),$from$jscomp$21_from_x$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($to$jscomp$23_to_x_vec__68483$$,0,null);$to$jscomp$23_to_x_vec__68483$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($to$jscomp$23_to_x_vec__68483$$,1,null);var $to_y_vec__68486$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from_y_p__68479$$,
1,null);$from_y_p__68479$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($to_y_vec__68486$$,0,null);$to_y_vec__68486$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($to_y_vec__68486$$,1,null);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($from$jscomp$21_from_x$$)?$from$jscomp$21_from_x$$:$APP.$cljs$core$truth_$$($to$jscomp$23_to_x_vec__68483$$)?$to$jscomp$23_to_x_vec__68483$$:$APP.$cljs$core$truth_$$($from_y_p__68479$$)?$from_y_p__68479$$:$to_y_vec__68486$$)?($from$jscomp$21_from_x$$=
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($from$jscomp$21_from_x$$)?$from$jscomp$21_from_x$$:0,$APP.$cljs$core$truth_$$($from_y_p__68479$$)?$from_y_p__68479$$:0),$to$jscomp$23_to_x_vec__68483$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($to$jscomp$23_to_x_vec__68483$$)?$to$jscomp$23_to_x_vec__68483$$:0,$APP.$cljs$core$truth_$$($to_y_vec__68486$$)?$to_y_vec__68486$$:0),$APP.$app$common$geom$point$subtract$$($to$jscomp$23_to_x_vec__68483$$,
$from$jscomp$21_from_x$$)):null};
$app$main$snap$closest_snap$$=function($page_id$jscomp$163$$,$frame_id$jscomp$84$$,$points$jscomp$70$$,$remove_snap_QMARK_$jscomp$2$$,$y_ranges_zoom$jscomp$15$$){var $vbox$jscomp$19$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$vbox$$),$x_ranges$$=$app$main$snap$snap_accuracy_ranges$$($points$jscomp$70$$,$APP.$cljs$cst$1510$x$$,$y_ranges_zoom$jscomp$15$$);$y_ranges_zoom$jscomp$15$$=$app$main$snap$snap_accuracy_ranges$$($points$jscomp$70$$,$APP.$cljs$cst$1511$y$$,$y_ranges_zoom$jscomp$15$$);var $rm$$=
$APP.$app$main$snap$remove_from_snap_points$$($remove_snap_QMARK_$jscomp$2$$),$gmx$$=$app$main$snap$get_min_distance_snap$$($points$jscomp$70$$,$APP.$cljs$cst$1510$x$$),$gmy$$=$app$main$snap$get_min_distance_snap$$($points$jscomp$70$$,$APP.$cljs$cst$1511$y$$);return $APP.$beicon$v2$core$map$$(function($p__68491_x$jscomp$1198$$){var $map__68492__$1_y$jscomp$431$$=$APP.$cljs$core$__destructure_map$$($p__68491_x$jscomp$1198$$);$p__68491_x$jscomp$1198$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68492__$1_y$jscomp$431$$,
$APP.$cljs$cst$1510$x$$);$map__68492__$1_y$jscomp$431$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68492__$1_y$jscomp$431$$,$APP.$cljs$cst$1511$y$$);return $app$main$snap$snap__GT_vector$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$gmx$$($rm$$($p__68491_x$jscomp$1198$$)),$gmy$$($rm$$($map__68492__$1_y$jscomp$431$$))],null))},$APP.$beicon$v2$core$take$$($APP.$app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$3115$cmd$$,$cljs$cst$3852$index_SLASH_query_snap_xy$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$163$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$84$$,$APP.$cljs$cst$3850$bounds$$,$vbox$jscomp$19$$,$cljs$cst$3853$x_ranges$$,$x_ranges$$,$cljs$cst$3854$y_ranges$$,$y_ranges_zoom$jscomp$15$$],null))))};
$app$main$snap$sr_distance$$=function($c2$jscomp$22_coord$jscomp$9$$,$sr1$$,$sr2$$){var $c1$jscomp$34$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c2$jscomp$22_coord$jscomp$9$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$1523$x1$$:$APP.$cljs$cst$1524$y1$$;$c2$jscomp$22_coord$jscomp$9$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c2$jscomp$22_coord$jscomp$9$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$1525$x2$$:$APP.$cljs$cst$1526$y2$$;return $c1$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$($sr2$$)-
$c2$jscomp$22_coord$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$($sr1$$)};
$app$main$snap$calculate_snap$$=function($coord$jscomp$11$$,$selrect$jscomp$57$$,$lt_dist_md_snap_shapes_lt$$,$gt_dist_shapes_gt$$,$gt_cand_gt_snap_min_snap_snap_list_zoom$jscomp$16$$){function $get_side_snaps$$($candidates$$,$distances$$){var $range_tree__$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__68502_SHARP_$$,$p2__68503_SHARP_$$){return $JSCompiler_StaticMethods_insert$$($p1__68502_SHARP_$$,$p2__68503_SHARP_$$,$p2__68503_SHARP_$$)},new $$jscomp$scope$236007416$2$RangeTree$$,
$candidates$$);return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($cd$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68504_SHARP_$$){return $APP.$cljs$core$first$$($p1__68504_SHARP_$$)-$cd$$},$app$util$range_tree$range_query$$($range_tree__$1$$,$cd$$-$snap_distance_accuracy$$,$cd$$+$snap_distance_accuracy$$))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$distances$$]))}function $inner_distance$$($selrects$jscomp$1$$){return $app$common$data$map_perm$cljs$0core$0IFn$0_invoke$0arity$04$$(function($p1__68498_SHARP_$$,
$p2__68499_SHARP_$$){return $app$main$snap$sr_distance$$($coord$jscomp$11$$,$p1__68498_SHARP_$$,$p2__68499_SHARP_$$)},function($p1__68500_SHARP__s1c2$jscomp$inline_6759$$,$p2__68501_SHARP__s2c2$jscomp$inline_6761$$){var $c1$jscomp$inline_6756_s2c1$jscomp$inline_6760$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$11$$,$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$1524$y1$$:$APP.$cljs$cst$1523$x1$$,$c2$jscomp$inline_6757$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$11$$,
$APP.$cljs$cst$1510$x$$)?$APP.$cljs$cst$1526$y2$$:$APP.$cljs$cst$1525$x2$$,$s1c1$jscomp$inline_6758$$=$c1$jscomp$inline_6756_s2c1$jscomp$inline_6760$$.$cljs$core$IFn$_invoke$arity$1$($p1__68500_SHARP__s1c2$jscomp$inline_6759$$);$p1__68500_SHARP__s1c2$jscomp$inline_6759$$=$c2$jscomp$inline_6757$$.$cljs$core$IFn$_invoke$arity$1$($p1__68500_SHARP__s1c2$jscomp$inline_6759$$);$c1$jscomp$inline_6756_s2c1$jscomp$inline_6760$$=$c1$jscomp$inline_6756_s2c1$jscomp$inline_6760$$.$cljs$core$IFn$_invoke$arity$1$($p2__68501_SHARP__s2c2$jscomp$inline_6761$$);
$p2__68501_SHARP__s2c2$jscomp$inline_6761$$=$c2$jscomp$inline_6757$$.$cljs$core$IFn$_invoke$arity$1$($p2__68501_SHARP__s2c2$jscomp$inline_6761$$);return $c1$jscomp$inline_6756_s2c1$jscomp$inline_6760$$>=$s1c1$jscomp$inline_6758$$&&$c1$jscomp$inline_6756_s2c1$jscomp$inline_6760$$<=$p1__68500_SHARP__s1c2$jscomp$inline_6759$$||$p2__68501_SHARP__s2c2$jscomp$inline_6761$$>=$s1c1$jscomp$inline_6758$$&&$p2__68501_SHARP__s2c2$jscomp$inline_6761$$<=$p1__68500_SHARP__s1c2$jscomp$inline_6759$$||$s1c1$jscomp$inline_6758$$>=
$c1$jscomp$inline_6756_s2c1$jscomp$inline_6760$$&&$s1c1$jscomp$inline_6758$$<=$p2__68501_SHARP__s2c2$jscomp$inline_6761$$||$p1__68500_SHARP__s1c2$jscomp$inline_6759$$>=$c1$jscomp$inline_6756_s2c1$jscomp$inline_6760$$&&$p1__68500_SHARP__s1c2$jscomp$inline_6759$$<=$p2__68501_SHARP__s2c2$jscomp$inline_6761$$},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$11$$,$selrects$jscomp$1$$))}var $snap_distance_accuracy$$=20/$gt_cand_gt_snap_min_snap_snap_list_zoom$jscomp$16$$,
$lt_cand_lt_snap$$=$inner_distance$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1605$selrect$$,$lt_dist_md_snap_shapes_lt$$));$gt_cand_gt_snap_min_snap_snap_list_zoom$jscomp$16$$=$inner_distance$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1605$selrect$$,$gt_dist_shapes_gt$$));$lt_dist_md_snap_shapes_lt$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($other$jscomp$194$$){return $app$main$snap$sr_distance$$($coord$jscomp$11$$,
$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$194$$),$selrect$jscomp$57$$)}),$lt_dist_md_snap_shapes_lt$$);$gt_dist_shapes_gt$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($other$jscomp$195$$){return $app$main$snap$sr_distance$$($coord$jscomp$11$$,$selrect$jscomp$57$$,$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$195$$))}),
$gt_dist_shapes_gt$$);$lt_cand_lt_snap$$=$get_side_snaps$$($lt_cand_lt_snap$$,$lt_dist_md_snap_shapes_lt$$);$gt_cand_gt_snap_min_snap_snap_list_zoom$jscomp$16$$=$get_side_snaps$$($gt_dist_shapes_gt$$,$gt_cand_gt_snap_min_snap_snap_list_zoom$jscomp$16$$);$lt_dist_md_snap_shapes_lt$$=function($lt_dist__$1$$,$gt_dist__$1$$){var $range_tree__$1$jscomp$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__68505_SHARP_$$,$p2__68506_SHARP_$$){return $JSCompiler_StaticMethods_insert$$($p1__68505_SHARP_$$,
$p2__68506_SHARP_$$,$p2__68506_SHARP_$$)},new $$jscomp$scope$236007416$2$RangeTree$$,$lt_dist__$1$$);return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($cd$jscomp$1$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68507_SHARP_$$){return($cd$jscomp$1$$-$APP.$cljs$core$first$$($p1__68507_SHARP_$$))/2},$app$util$range_tree$range_query$$($range_tree__$1$jscomp$1$$,$cd$jscomp$1$$-$snap_distance_accuracy$$*2,$cd$jscomp$1$$+$snap_distance_accuracy$$*
2))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$gt_dist__$1$$]))}($lt_dist_md_snap_shapes_lt$$,$gt_dist_shapes_gt$$);$gt_cand_gt_snap_min_snap_snap_list_zoom$jscomp$16$$=$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($lt_cand_lt_snap$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$gt_cand_gt_snap_min_snap_snap_list_zoom$jscomp$16$$,$lt_dist_md_snap_shapes_lt$$]));$gt_cand_gt_snap_min_snap_snap_list_zoom$jscomp$16$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$min$$,
Infinity,$gt_cand_gt_snap_min_snap_snap_list_zoom$jscomp$16$$);return $APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($gt_cand_gt_snap_min_snap_snap_list_zoom$jscomp$16$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,$gt_cand_gt_snap_min_snap_snap_list_zoom$jscomp$16$$],null):null};
$app$main$snap$search_snap_distance$$=function($selrect$jscomp$58$$,$coord$jscomp$12$$,$shapes_lt$jscomp$1$$,$shapes_gt$jscomp$1$$,$zoom$jscomp$17$$){return $APP.$beicon$v2$core$map$$(function($p__68516_shapes_gt__$1$$){var $shapes_lt__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68516_shapes_gt__$1$$,0,null);$p__68516_shapes_gt__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68516_shapes_gt__$1$$,1,null);return $app$main$snap$calculate_snap$$($coord$jscomp$12$$,
$selrect$jscomp$58$$,$shapes_lt__$1$$,$p__68516_shapes_gt__$1$$,$zoom$jscomp$17$$)},$APP.$beicon$v2$core$combine_latest$$($shapes_lt$jscomp$1$$,$shapes_gt$jscomp$1$$))};
$APP.$app$main$snap$select_shapes_area$$=function($page_id$jscomp$164$$,$frame_id$jscomp$85$$,$selected$jscomp$43$$,$objects$jscomp$474$$,$area$jscomp$3$$){return $APP.$beicon$v2$core$map$$(function($p1__68523_SHARP_$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$474$$),$p1__68523_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($p1__68522_SHARP_$$){return $APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($p1__68522_SHARP_$$,
$selected$jscomp$43$$)},$APP.$beicon$v2$core$map$$(function($p1__68521_SHARP_$$){return $APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$474$$,$p1__68521_SHARP_$$)},$APP.$app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$3115$cmd$$,$APP.$cljs$cst$3605$index_SLASH_query_selection$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$164$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$85$$,$APP.$cljs$cst$3606$include_frames_QMARK_$$,
!0,$APP.$cljs$cst$1611$rect$$,$area$jscomp$3$$],null)))))};
$app$main$snap$closest_distance_snap$$=function($page_id$jscomp$165$$,$shapes$jscomp$89$$,$objects$jscomp$475$$,$zoom$jscomp$18$$,$movev$$){var $frame$jscomp$31_frame_id$jscomp$86$$=$APP.$app$main$snap$snap_frame_id$$($shapes$jscomp$89$$);$frame$jscomp$31_frame_id$jscomp$86$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$475$$,$frame$jscomp$31_frame_id$jscomp$86$$);var $selrect$jscomp$59$$=$APP.$app$common$geom$shapes$shapes__GT_rect$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68524_SHARP_$$){return $app$common$geom$shapes$transforms$move$$($p1__68524_SHARP_$$,$movev$$)},
$shapes$jscomp$89$$));return $APP.$beicon$v2$core$map$$($app$main$snap$snap__GT_vector$$,$APP.$beicon$v2$core$merge_map$$(function($p__68527_selrect__$1$jscomp$3_snap_y$$){var $bounds$jscomp$69_frame__$1$jscomp$4_frame_sr_snap_x$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68527_selrect__$1$jscomp$3_snap_y$$,0,null);$p__68527_selrect__$1$jscomp$3_snap_y$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68527_selrect__$1$jscomp$3_snap_y$$,1,null);var $areas$jscomp$1_vbox$jscomp$20$$=
$APP.$cljs$core$_deref$$($APP.$app$main$refs$vbox$$),$frame_id__$1$jscomp$9$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$89$$));$bounds$jscomp$69_frame__$1$jscomp$4_frame_sr_snap_x$$=$APP.$app$common$files$helpers$root_QMARK_$$($bounds$jscomp$69_frame__$1$jscomp$4_frame_sr_snap_x$$)?null:$bounds$jscomp$69_frame__$1$jscomp$4_frame_sr_snap_x$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$69_frame__$1$jscomp$4_frame_sr_snap_x$$,
$APP.$cljs$cst$1605$selrect$$);$bounds$jscomp$69_frame__$1$jscomp$4_frame_sr_snap_x$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$rect$clip_rect$$($bounds$jscomp$69_frame__$1$jscomp$4_frame_sr_snap_x$$,$areas$jscomp$1_vbox$jscomp$20$$),$areas$jscomp$1_vbox$jscomp$20$$);var $selected$jscomp$44$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$shapes$jscomp$89$$));$areas$jscomp$1_vbox$jscomp$20$$=$APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__68526_SHARP_$$,$p2__68525_SHARP_$$){return $APP.$app$main$snap$select_shapes_area$$($page_id$jscomp$165$$,$frame_id__$1$jscomp$9$$,$selected$jscomp$44$$,$objects$jscomp$475$$,$p2__68525_SHARP_$$)},$APP.$app$common$geom$shapes$get_areas$$($bounds$jscomp$69_frame__$1$jscomp$4_frame_sr_snap_x$$,$p__68527_selrect__$1$jscomp$3_snap_y$$));$bounds$jscomp$69_frame__$1$jscomp$4_frame_sr_snap_x$$=
$app$main$snap$search_snap_distance$$($p__68527_selrect__$1$jscomp$3_snap_y$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($areas$jscomp$1_vbox$jscomp$20$$),$APP.$cljs$cst$258$right$$.$cljs$core$IFn$_invoke$arity$1$($areas$jscomp$1_vbox$jscomp$20$$),$zoom$jscomp$18$$);$p__68527_selrect__$1$jscomp$3_snap_y$$=$app$main$snap$search_snap_distance$$($p__68527_selrect__$1$jscomp$3_snap_y$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($areas$jscomp$1_vbox$jscomp$20$$),
$APP.$cljs$cst$1563$bottom$$.$cljs$core$IFn$_invoke$arity$1$($areas$jscomp$1_vbox$jscomp$20$$),$zoom$jscomp$18$$);return $APP.$beicon$v2$core$combine_latest$$($bounds$jscomp$69_frame__$1$jscomp$4_frame_sr_snap_x$$,$p__68527_selrect__$1$jscomp$3_snap_y$$)},(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame$jscomp$31_frame_id$jscomp$86$$,$selrect$jscomp$59$$],null))))};
$APP.$app$main$snap$closest_snap_point$$=function($page_id$jscomp$166$$,$filter_shapes$jscomp$1_shapes$jscomp$90$$,$objects$jscomp$476$$,$layout$jscomp$8$$,$zoom$jscomp$19$$,$focus$jscomp$10$$,$point$jscomp$58$$){var $frame_id$jscomp$87$$=$APP.$app$main$snap$snap_frame_id$$($filter_shapes$jscomp$1_shapes$jscomp$90$$);$filter_shapes$jscomp$1_shapes$jscomp$90$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$filter_shapes$jscomp$1_shapes$jscomp$90$$));return $APP.$beicon$v2$core$map$$(function($p1__68532_SHARP_$$){return $APP.$app$common$geom$point$add$$($point$jscomp$58$$,$p1__68532_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($p1__68531_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__68531_SHARP_$$)?$p1__68531_SHARP_$$:$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0)},$app$main$snap$closest_snap$$($page_id$jscomp$166$$,$frame_id$jscomp$87$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$point$jscomp$58$$],null),$APP.$app$main$snap$make_remove_snap$$($layout$jscomp$8$$,$filter_shapes$jscomp$1_shapes$jscomp$90$$,$objects$jscomp$476$$,$focus$jscomp$10$$),$zoom$jscomp$19$$)))};
$app$main$snap$closest_snap_move$$=function($page_id$jscomp$167$$,$shapes$jscomp$91$$,$objects$jscomp$477$$,$layout$jscomp$9$$,$zoom$jscomp$20$$,$focus$jscomp$11_remove_snap_QMARK_$jscomp$4$$,$movev$jscomp$1$$){var $frame_id$jscomp$88$$=$APP.$app$main$snap$snap_frame_id$$($shapes$jscomp$91$$),$filter_shapes$jscomp$2_snap_points$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$shapes$jscomp$91$$));$focus$jscomp$11_remove_snap_QMARK_$jscomp$4$$=$APP.$app$main$snap$make_remove_snap$$($layout$jscomp$9$$,$filter_shapes$jscomp$2_snap_points$$,$objects$jscomp$477$$,$focus$jscomp$11_remove_snap_QMARK_$jscomp$4$$);$filter_shapes$jscomp$2_snap_points$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68536_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__68536_SHARP_$$,$movev$jscomp$1$$)},$APP.$app$common$geom$snap$rect__GT_snap_points$$($APP.$app$common$geom$shapes$common$shapes__GT_rect$$($shapes$jscomp$91$$)));
return $APP.$beicon$v2$core$map$$(function($p1__68537_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__68537_SHARP_$$)?$p1__68537_SHARP_$$:$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0)},$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$snap$combine_snaps_points$$,$APP.$beicon$v2$core$merge$$($app$main$snap$closest_snap$$($page_id$jscomp$167$$,$frame_id$jscomp$88$$,$filter_shapes$jscomp$2_snap_points$$,$focus$jscomp$11_remove_snap_QMARK_$jscomp$4$$,$zoom$jscomp$20$$),
$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$9$$,$APP.$cljs$cst$3724$dynamic_alignment$$)?$app$main$snap$closest_distance_snap$$($page_id$jscomp$167$$,$shapes$jscomp$91$$,$objects$jscomp$477$$,$zoom$jscomp$20$$,$movev$jscomp$1$$):null)))};
$app$main$snap$query_delta_point$$=function($ranges$jscomp$1$$,$point$jscomp$60$$,$precision$jscomp$20$$){function $query_coord$$($point__$1$$,$coord$jscomp$15$$){var $pval$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point__$1$$,$coord$jscomp$15$$);return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__68556_points$jscomp$73$$){var $value$jscomp$566$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68556_points$jscomp$73$$,0,null);$p__68556_points$jscomp$73$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68556_points$jscomp$73$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$value$jscomp$566$$-$pval$jscomp$1$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68553_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$point__$1$$,$p1__68553_SHARP_$$],null)},$p__68556_points$jscomp$73$$)],null)},$app$util$range_tree$range_query$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ranges$jscomp$1$$,
$coord$jscomp$15$$),$pval$jscomp$1$$-$precision$jscomp$20$$,$pval$jscomp$1$$+$precision$jscomp$20$$))}return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($query_coord$$($point$jscomp$60$$,$APP.$cljs$cst$1510$x$$),$query_coord$$($point$jscomp$60$$,$APP.$cljs$cst$1511$y$$))};
$app$main$snap$min_match$$=function($default$$jscomp$86$$,$matches$jscomp$10$$){function $min_match_coord$$($matches__$1$jscomp$1$$){return $APP.$cljs$core$seq$$($matches__$1$jscomp$1$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($get_min$$,$matches__$1$jscomp$1$$):$default$$jscomp$86$$}function $get_min$$($p__68571$$,$p__68572$$){var $cur_val$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68571$$,0,null),$other_val$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68572$$,
0,null);return $APP.$app$common$math$abs$$($cur_val$jscomp$1$$)<$APP.$app$common$math$abs$$($other_val$$)?$p__68571$$:$p__68572$$}return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($matches$jscomp$10$$,$APP.$cljs$cst$1510$x$$,$min_match_coord$$),$APP.$cljs$cst$1511$y$$,$min_match_coord$$)};
$APP.$app$main$snap$get_snap_delta_match$$=function($points$jscomp$74$$,$ranges$jscomp$2$$,$accuracy$$){return $app$main$snap$min_match$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,null],null),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$snap$merge_matches$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68581_SHARP_$$){return $app$main$snap$query_delta_point$$($ranges$jscomp$2$$,$p1__68581_SHARP_$$,
$accuracy$$)},$points$jscomp$74$$)))};
$APP.$app$main$snap$get_snap_delta$$=function($points$jscomp$75$$,$ranges$jscomp$3$$,$accuracy$jscomp$1$$){return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$snap$get_snap_delta_match$$($points$jscomp$75$$,$ranges$jscomp$3$$,$accuracy$jscomp$1$$),$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$first$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$first$$))};
$app$main$snap$correct_snap_point$$=function($dx$jscomp$16_p__68584_vec__68588$$){var $position$jscomp$85$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dx$jscomp$16_p__68584_vec__68588$$,0,null);$dx$jscomp$16_p__68584_vec__68588$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dx$jscomp$16_p__68584_vec__68588$$,1,null);var $dy$jscomp$16_dy__$1$jscomp$1_snap_pos$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dx$jscomp$16_p__68584_vec__68588$$,0,null),$snap_delta$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dx$jscomp$16_p__68584_vec__68588$$,1,null);if($snap_delta$$==null)return $position$jscomp$85$$;$dx$jscomp$16_p__68584_vec__68588$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($snap_delta$$))?$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($dy$jscomp$16_dy__$1$jscomp$1_snap_pos$$)+$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($snap_delta$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$85$$):
0;$dy$jscomp$16_dy__$1$jscomp$1_snap_pos$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($snap_delta$$))?$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($dy$jscomp$16_dy__$1$jscomp$1_snap_pos$$)+$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($snap_delta$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$85$$):0;$dy$jscomp$16_dy__$1$jscomp$1_snap_pos$$=$APP.$app$common$math$abs$$($dy$jscomp$16_dy__$1$jscomp$1_snap_pos$$)>
10?0:$dy$jscomp$16_dy__$1$jscomp$1_snap_pos$$;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($position$jscomp$85$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$_PLUS_$$,$APP.$app$common$math$abs$$($dx$jscomp$16_p__68584_vec__68588$$)>10?0:$dx$jscomp$16_p__68584_vec__68588$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_PLUS_$$,$dy$jscomp$16_dy__$1$jscomp$1_snap_pos$$)};
$app$util$array$conj$$=function($a$jscomp$390$$,$v$jscomp$579$$){return[...$a$jscomp$390$$,$v$jscomp$579$$]};
$APP.$app$main$data$workspace$transforms$finish_transform$$=function(){typeof $app$main$data$workspace$transforms$finish_transform_68929$$==="undefined"&&($app$main$data$workspace$transforms$finish_transform_68929$$=function($meta68930$$){this.$meta68930$=$meta68930$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$finish_transform_68929$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$finish_transform_68929$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3855$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_finish_transform$$},$app$main$data$workspace$transforms$finish_transform_68929$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68931$$,$meta68930__$1$$){return new $app$main$data$workspace$transforms$finish_transform_68929$$($meta68930__$1$$)},$app$main$data$workspace$transforms$finish_transform_68929$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68930$},$app$main$data$workspace$transforms$finish_transform_68929$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$finish_transform_68929$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2046$$,$state$jscomp$454$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$454$$,$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1289$transform$$,$cljs$cst$3856$duplicate_move_started_QMARK_$$)},$app$main$data$workspace$transforms$finish_transform_68929$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$finish_transform_68929$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){$app$main$streams$wasm_modifiers$$.next(null);return $app$main$streams$workspace_selrect$$.next(null)});return new $app$main$data$workspace$transforms$finish_transform_68929$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$=function($ids$jscomp$113$$){typeof $app$main$data$workspace$transforms$trigger_bounding_box_cloaking_69061$$==="undefined"&&($app$main$data$workspace$transforms$trigger_bounding_box_cloaking_69061$$=function($ids$jscomp$114$$,$meta69062$$){this.ids=$ids$jscomp$114$$;this.$meta69062$=$meta69062$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$trigger_bounding_box_cloaking_69061$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$trigger_bounding_box_cloaking_69061$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3863$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_trigger_bounding_box_cloaking$$},$app$main$data$workspace$transforms$trigger_bounding_box_cloaking_69061$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69063$$,$meta69062__$1$$){return new $app$main$data$workspace$transforms$trigger_bounding_box_cloaking_69061$$(this.ids,
$meta69062__$1$$)},$app$main$data$workspace$transforms$trigger_bounding_box_cloaking_69061$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69062$},$app$main$data$workspace$transforms$trigger_bounding_box_cloaking_69061$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$trigger_bounding_box_cloaking_69061$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2050$$,$___$1$jscomp$1320$$,$stream$jscomp$48$$){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)(function($p1__69059_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__69059_SHARP_$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1289$transform$$],null),$APP.$cljs$cst$1798$move$$)}),$APP.$beicon$v2$core$take_until$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3863$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_trigger_bounding_box_cloaking$$),$stream$jscomp$48$$),$APP.$beicon$v2$core$map$$(function(){return function($p1__69060_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__69060_SHARP_$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1289$transform$$],null),null)}},(0,$APP.$beicon$v2$core$timer$$)(1E3))))});return new $app$main$data$workspace$transforms$trigger_bounding_box_cloaking_69061$$($ids$jscomp$113$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$update_dimensions$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$115$$,$attr$jscomp$51$$,$value$jscomp$567$$){return $app$main$data$workspace$transforms$update_dimensions$cljs$0core$0IFn$0_invoke$0arity$04$$($ids$jscomp$115$$,$attr$jscomp$51$$,$value$jscomp$567$$,null)};
$app$main$data$workspace$transforms$update_dimensions$cljs$0core$0IFn$0_invoke$0arity$04$$=function($ids$jscomp$116$$,$attr$jscomp$52$$,$value$jscomp$568$$,$p__69073$$){var $map__69077__$1$$=$APP.$cljs$core$__destructure_map$$($p__69073$$),$no_wasm_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69077__$1$$,$cljs$cst$3864$no_wasm_QMARK_$$);typeof $app$main$data$workspace$transforms$update_dimensions_69078$$==="undefined"&&($app$main$data$workspace$transforms$update_dimensions_69078$$=
function($ids$jscomp$117$$,$attr$jscomp$53$$,$value$jscomp$569$$,$p__69073$jscomp$1$$,$map__69077$jscomp$1$$,$options$jscomp$515$$,$no_wasm_QMARK_$jscomp$1$$,$meta69079$$){this.ids=$ids$jscomp$117$$;this.attr=$attr$jscomp$53$$;this.value=$value$jscomp$569$$;this.$p__69073$=$p__69073$jscomp$1$$;this.$map__69077$=$map__69077$jscomp$1$$;this.options=$options$jscomp$515$$;this.$no_wasm_QMARK_$=$no_wasm_QMARK_$jscomp$1$$;this.$meta69079$=$meta69079$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$transforms$update_dimensions_69078$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$update_dimensions_69078$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3865$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_update_dimensions$$},$app$main$data$workspace$transforms$update_dimensions_69078$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69080$$,$meta69079__$1$$){return new $app$main$data$workspace$transforms$update_dimensions_69078$$(this.ids,
this.attr,this.value,this.$p__69073$,this.$map__69077$,this.options,this.$no_wasm_QMARK_$,$meta69079__$1$$)},$app$main$data$workspace$transforms$update_dimensions_69078$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69079$},$app$main$data$workspace$transforms$update_dimensions_69078$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$update_dimensions_69078$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2051_objects$jscomp$480_page_id$jscomp$169$$,
$state$jscomp$457$$){var $self__$jscomp$4602$$=this;$_$jscomp$2051_objects$jscomp$480_page_id$jscomp$169$$=function(){var $or__5025__auto__$jscomp$786$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4602$$.options,$APP.$cljs$cst$2043$page_id$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$786$$)?$or__5025__auto__$jscomp$786$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$457$$,$APP.$cljs$cst$1918$current_page_id$$)}();$_$jscomp$2051_objects$jscomp$480_page_id$jscomp$169$$=
$app$main$data$workspace$shapes$lookup_changed_objects$$($state$jscomp$457$$,$_$jscomp$2051_objects$jscomp$480_page_id$jscomp$169$$);var $modif_tree$jscomp$55_modif_tree__$1$jscomp$16$$=$APP.$app$main$data$workspace$modifiers$build_modif_tree$$($self__$jscomp$4602$$.ids,$_$jscomp$2051_objects$jscomp$480_page_id$jscomp$169$$,function($current_grow_type$jscomp$1_shape$jscomp$543$$){var $modifiers$jscomp$82$$=$APP.$app$common$types$modifiers$change_dimensions_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($current_grow_type$jscomp$1_shape$jscomp$543$$,
$self__$jscomp$4602$$.attr,$self__$jscomp$4602$$.value,null);if($APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($current_grow_type$jscomp$1_shape$jscomp$543$$)){var $map__69085_new_grow_type$jscomp$1_scalev$jscomp$4_sr_width$jscomp$3$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($current_grow_type$jscomp$1_shape$jscomp$543$$),$map__69085__$1_sr_height$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($map__69085_new_grow_type$jscomp$1_scalev$jscomp$4_sr_width$jscomp$3$$);
$map__69085_new_grow_type$jscomp$1_scalev$jscomp$4_sr_width$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69085__$1_sr_height$jscomp$3$$,$APP.$cljs$cst$290$width$$);$map__69085__$1_sr_height$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69085__$1_sr_height$jscomp$3$$,$APP.$cljs$cst$1522$height$$);var $new_width$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4602$$.attr,$APP.$cljs$cst$290$width$$)?$self__$jscomp$4602$$.value:
$map__69085_new_grow_type$jscomp$1_scalev$jscomp$4_sr_width$jscomp$3$$,$new_height$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4602$$.attr,$APP.$cljs$cst$1522$height$$)?$self__$jscomp$4602$$.value:$map__69085__$1_sr_height$jscomp$3$$;$map__69085_new_grow_type$jscomp$1_scalev$jscomp$4_sr_width$jscomp$3$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($new_width$jscomp$2$$/$map__69085_new_grow_type$jscomp$1_scalev$jscomp$4_sr_width$jscomp$3$$,
$new_height$jscomp$2$$/$map__69085__$1_sr_height$jscomp$3$$);$current_grow_type$jscomp$1_shape$jscomp$543$$=$current_grow_type$jscomp$1_shape$jscomp$543$$?.$grow_type$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_grow_type$jscomp$1_shape$jscomp$543$$,$APP.$cljs$cst$1770$grow_type$$);$map__69085_new_grow_type$jscomp$1_scalev$jscomp$4_sr_width$jscomp$3$$=$APP.$app$main$data$workspace$modifiers$next_grow_type$$($current_grow_type$jscomp$1_shape$jscomp$543$$,$map__69085_new_grow_type$jscomp$1_scalev$jscomp$4_sr_width$jscomp$3$$);
return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__69085_new_grow_type$jscomp$1_scalev$jscomp$4_sr_width$jscomp$3$$,$current_grow_type$jscomp$1_shape$jscomp$543$$)?$APP.$app$common$types$modifiers$change_property$$($modifiers$jscomp$82$$,$APP.$cljs$cst$1770$grow_type$$,$map__69085_new_grow_type$jscomp$1_scalev$jscomp$4_sr_width$jscomp$3$$):$modifiers$jscomp$82$$}return $modifiers$jscomp$82$$});if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$457$$,"render-wasm/v1")&&
$APP.$cljs$core$not$$($self__$jscomp$4602$$.$no_wasm_QMARK_$))return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($modif_tree$jscomp$55_modif_tree__$1$jscomp$16$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$4602$$.options,$cljs$cst$3833$ignore_snap_pixel$$,!0)])));$modif_tree$jscomp$55_modif_tree__$1$jscomp$16$$=$APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($modif_tree$jscomp$55_modif_tree__$1$jscomp$16$$,
$_$jscomp$2051_objects$jscomp$480_page_id$jscomp$169$$);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$modifiers$apply_modifiers_STAR_$$($_$jscomp$2051_objects$jscomp$480_page_id$jscomp$169$$,$modif_tree$jscomp$55_modif_tree__$1$jscomp$16$$,null,$self__$jscomp$4602$$.options))});return new $app$main$data$workspace$transforms$update_dimensions_69078$$($ids$jscomp$116$$,$attr$jscomp$52$$,$value$jscomp$568$$,$p__69073$$,$map__69077__$1$$,$map__69077__$1$$,$no_wasm_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$start_move_selected$cljs$0core$0IFn$0_invoke$0arity$02$$=function($id$jscomp$545$$,$shift_QMARK_$jscomp$3$$){typeof $app$main$data$workspace$transforms$start_move_selected_69156$$==="undefined"&&($app$main$data$workspace$transforms$start_move_selected_69156$$=function($id$jscomp$546$$,$shift_QMARK_$jscomp$4$$,$meta69157$$){this.id=$id$jscomp$546$$;this.$shift_QMARK_$=$shift_QMARK_$jscomp$4$$;this.$meta69157$=$meta69157$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$start_move_selected_69156$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$start_move_selected_69156$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3869$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_start_move_selected$$},$app$main$data$workspace$transforms$start_move_selected_69156$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69158$$,$meta69157__$1$$){return new $app$main$data$workspace$transforms$start_move_selected_69156$$(this.id,this.$shift_QMARK_$,$meta69157__$1$$)},$app$main$data$workspace$transforms$start_move_selected_69156$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69157$},$app$main$data$workspace$transforms$start_move_selected_69156$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$start_move_selected_69156$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2057_stopper$jscomp$13$$,$state$jscomp$463$$,$stream$jscomp$50$$){var $self__$jscomp$4620$$=this,$initial$jscomp$18$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);$_$jscomp$2057_stopper$jscomp$13$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stream$jscomp$50$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2168$interrupt_QMARK_$$,!1],null));var $zoom$jscomp$22$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$463$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2196$zoom$$],null),1),$selected$jscomp$45$$=function(){var $G__69163$$=$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$463$$);return $self__$jscomp$4620$$.id!=null?$app$common$data$toggle_selection$$.$cljs$core$IFn$_invoke$arity$3$($G__69163$$,$self__$jscomp$4620$$.id,$self__$jscomp$4620$$.$shift_QMARK_$):$G__69163$$}();
return $APP.$app$common$data$not_empty_QMARK_$$($selected$jscomp$45$$)||$self__$jscomp$4620$$.id!=null?$APP.$beicon$v2$core$take_until$$($_$jscomp$2057_stopper$jscomp$13$$,$APP.$beicon$v2$core$mapcat$$(function($alt_QMARK_$jscomp$1_p__69165$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($alt_QMARK_$jscomp$1_p__69165$$,0,null);$alt_QMARK_$jscomp$1_p__69165$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($alt_QMARK_$jscomp$1_p__69165$$,1,null);return $APP.$beicon$v2$core$concat$$($self__$jscomp$4620$$.id!=
null?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$4620$$.id,$self__$jscomp$4620$$.$shift_QMARK_$)):$APP.$beicon$v2$core$empty$$(),$APP.$cljs$core$truth_$$($alt_QMARK_$jscomp$1_p__69165$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$transforms$start_move_duplicate$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$transforms$start_move_duplicate$$.$cljs$core$IFn$_invoke$arity$1$($initial$jscomp$18$$):
$app$main$data$workspace$transforms$start_move_duplicate$$($initial$jscomp$18$$),$app$main$data$workspace$selection$duplicate_selected$cljs$0core$0IFn$0_invoke$0arity$02$$(!1,!0)):(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$transforms$start_move$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$main$data$workspace$transforms$start_move$cljs$0core$0IFn$0_invoke$0arity$02$$($initial$jscomp$18$$,$selected$jscomp$45$$):$app$main$data$workspace$transforms$start_move$$($initial$jscomp$18$$,$selected$jscomp$45$$)))},
$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$sub$jscomp$inline_5575$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__69151_SHARP_$$){return $p1__69151_SHARP_$$>10/$zoom$jscomp$22$$},$APP.$beicon$v2$core$map$$(function($p1__69150_SHARP_$$){return $APP.$app$common$geom$point$length$$($p1__69150_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($p1__69149_SHARP_$$){return $APP.$app$common$geom$point$subtract$$($p1__69149_SHARP_$$,$initial$jscomp$18$$)},
$APP.$app$main$streams$mouse_position$$))))))):null});return new $app$main$data$workspace$transforms$start_move_selected_69156$$($id$jscomp$545$$,$shift_QMARK_$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$start_move_duplicate$$=function($from_position$$){typeof $app$main$data$workspace$transforms$start_move_duplicate_69169$$==="undefined"&&($app$main$data$workspace$transforms$start_move_duplicate_69169$$=function($from_position$jscomp$1$$,$meta69170$$){this.$from_position$=$from_position$jscomp$1$$;this.$meta69170$=$meta69170$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$start_move_duplicate_69169$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$start_move_duplicate_69169$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3870$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_start_move_duplicate$$},$app$main$data$workspace$transforms$start_move_duplicate_69169$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69171$$,$meta69170__$1$$){return new $app$main$data$workspace$transforms$start_move_duplicate_69169$$(this.$from_position$,
$meta69170__$1$$)},$app$main$data$workspace$transforms$start_move_duplicate_69169$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69170$},$app$main$data$workspace$transforms$start_move_duplicate_69169$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$start_move_duplicate_69169$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2058$$,$state$jscomp$464$$){return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$464$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1289$transform$$],null),$APP.$cljs$cst$1798$move$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$cljs$cst$3856$duplicate_move_started_QMARK_$$],null),!0)},$app$main$data$workspace$transforms$start_move_duplicate_69169$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$transforms$start_move_duplicate_69169$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2059$$,$___$1$jscomp$1329$$,$stream$jscomp$51$$){var $self__$jscomp$4625$$=this;return $APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$transforms$start_move$cljs$0core$0IFn$0_invoke$0arity$03$$?$app$main$data$workspace$transforms$start_move$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$4625$$.$from_position$,null,!0):$app$main$data$workspace$transforms$start_move$$($self__$jscomp$4625$$.$from_position$,
null,!0)},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3625$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_duplicate_selected$$),$stream$jscomp$51$$)))});return new $app$main$data$workspace$transforms$start_move_duplicate_69169$$($from_position$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$set_ghost_displacement$$=function($move_vector$$){typeof $app$main$data$workspace$transforms$set_ghost_displacement_69172$$==="undefined"&&($app$main$data$workspace$transforms$set_ghost_displacement_69172$$=function($move_vector$jscomp$1$$,$meta69173$$){this.$move_vector$=$move_vector$jscomp$1$$;this.$meta69173$=$meta69173$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$set_ghost_displacement_69172$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$set_ghost_displacement_69172$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3871$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_set_ghost_displacement$$},$app$main$data$workspace$transforms$set_ghost_displacement_69172$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69174$$,$meta69173__$1$$){return new $app$main$data$workspace$transforms$set_ghost_displacement_69172$$(this.$move_vector$,
$meta69173__$1$$)},$app$main$data$workspace$transforms$set_ghost_displacement_69172$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69173$},$app$main$data$workspace$transforms$set_ghost_displacement_69172$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$set_ghost_displacement_69172$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){var $temp__5825__auto__$jscomp$204$$=$APP.$goog$dom$getElementByClass$$("ghost-outline");
return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$204$$)?$APP.$app$util$dom$set_property_BANG_$$($temp__5825__auto__$jscomp$204$$,"transform",$APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$(this.$move_vector$)):null});return new $app$main$data$workspace$transforms$set_ghost_displacement_69172$$($move_vector$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$start_move$$=function($var_args$jscomp$1258$$){switch(arguments.length){case 1:return $app$main$data$workspace$transforms$start_move$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],null,!1);case 2:return $app$main$data$workspace$transforms$start_move$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);case 3:return $app$main$data$workspace$transforms$start_move$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$data$workspace$transforms$start_move$cljs$0core$0IFn$0_invoke$0arity$02$$=function($from_position$jscomp$3$$,$ids$jscomp$123$$){return $app$main$data$workspace$transforms$start_move$cljs$0core$0IFn$0_invoke$0arity$03$$($from_position$jscomp$3$$,$ids$jscomp$123$$,!1)};
$app$main$data$workspace$transforms$start_move$cljs$0core$0IFn$0_invoke$0arity$03$$=function($from_position$jscomp$4$$,$ids$jscomp$124$$,$from_duplicate_QMARK_$$){typeof $app$main$data$workspace$transforms$start_move_69181$$==="undefined"&&($app$main$data$workspace$transforms$start_move_69181$$=function($from_position$jscomp$5$$,$ids$jscomp$125$$,$from_duplicate_QMARK_$jscomp$1$$,$meta69182$$){this.$from_position$=$from_position$jscomp$5$$;this.ids=$ids$jscomp$125$$;this.$from_duplicate_QMARK_$=$from_duplicate_QMARK_$jscomp$1$$;
this.$meta69182$=$meta69182$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$start_move_69181$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$start_move_69181$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3872$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_start_move$$},$app$main$data$workspace$transforms$start_move_69181$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69183$$,$meta69182__$1$$){return new $app$main$data$workspace$transforms$start_move_69181$$(this.$from_position$,this.ids,this.$from_duplicate_QMARK_$,$meta69182__$1$$)},$app$main$data$workspace$transforms$start_move_69181$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69182$},$app$main$data$workspace$transforms$start_move_69181$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$start_move_69181$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2061$$,$state$jscomp$465$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$465$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1289$transform$$],null),$APP.$cljs$cst$1798$move$$)},$app$main$data$workspace$transforms$start_move_69181$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$start_move_69181$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2062_move_stream_stopper$jscomp$14$$,$duplicate_stopper_state$jscomp$466$$,$modifiers_stream$jscomp$1_position$jscomp$87_stream$jscomp$52$$){var $self__$jscomp$4634$$=this,$prev_cell_data$$=$APP.$cljs$core$volatile_BANG_$$(null),$page_id$jscomp$171$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($duplicate_stopper_state$jscomp$466$$),$libraries$jscomp$68$$=$APP.$app$main$data$helpers$lookup_libraries$$($duplicate_stopper_state$jscomp$466$$),$objects$jscomp$485$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($duplicate_stopper_state$jscomp$466$$,$page_id$jscomp$171$$),$selected$jscomp$46$$=$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($duplicate_stopper_state$jscomp$466$$),$ids__$1$jscomp$15$$=$self__$jscomp$4634$$.ids==null?$selected$jscomp$46$$:$self__$jscomp$4634$$.ids,$shapes$jscomp$97$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$getf$$($objects$jscomp$485$$)),
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69175_SHARP__parent$jscomp$263$$){$p1__69175_SHARP__parent$jscomp$263$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$485$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__69175_SHARP__parent$jscomp$263$$));return $APP.$app$common$types$component$in_component_copy_QMARK_$$($p1__69175_SHARP__parent$jscomp$263$$)&&$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__69175_SHARP__parent$jscomp$263$$)})),
$ids__$1$jscomp$15$$),$duplicate_move_started_QMARK_$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($duplicate_stopper_state$jscomp$466$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$cljs$cst$3856$duplicate_move_started_QMARK_$$],null),!1);$_$jscomp$2062_move_stream_stopper$jscomp$14$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($modifiers_stream$jscomp$1_position$jscomp$87_stream$jscomp$52$$,
null);var $layout$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($duplicate_stopper_state$jscomp$466$$,$APP.$cljs$cst$2209$workspace_layout$$),$zoom$jscomp$23$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($duplicate_stopper_state$jscomp$466$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2196$zoom$$],null),1),$focus$jscomp$13$$=$APP.$cljs$cst$2226$workspace_focus_selected$$.$cljs$core$IFn$_invoke$arity$1$($duplicate_stopper_state$jscomp$466$$),
$exclude_frames$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,$objects$jscomp$485$$)),$APP.$app$common$files$helpers$selected_with_children$$($objects$jscomp$485$$,$selected$jscomp$46$$)),$exclude_frames_siblings$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($exclude_frames$$,
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$files$helpers$get_siblings_ids$$,$objects$jscomp$485$$)),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$any_layout_immediate_child_id_QMARK_$$,$objects$jscomp$485$$))),$selected$jscomp$46$$);$modifiers_stream$jscomp$1_position$jscomp$87_stream$jscomp$52$$=
$APP.$beicon$v2$core$map$$(function($p1__69176_SHARP_$$){return $APP.$app$common$geom$point$subtract$$($p1__69176_SHARP_$$,$self__$jscomp$4634$$.$from_position$)},$APP.$app$main$streams$mouse_position$$);var $snap_delta$jscomp$1$$=$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)(null),$APP.$beicon$v2$core$switch_map$$(function($pos$jscomp$110$$){return $APP.$beicon$v2$core$map$$(function($p1__69177_SHARP_$$){return[$pos$jscomp$110$$,$p1__69177_SHARP_$$]},$app$main$snap$closest_snap_move$$($page_id$jscomp$171$$,
$shapes$jscomp$97$$,$objects$jscomp$485$$,$layout$jscomp$12$$,$zoom$jscomp$23$$,$focus$jscomp$13$$,$pos$jscomp$110$$))},$APP.$beicon$v2$core$throttle$cljs$0core$0IFn$0_invoke$0arity$02$$(20,$modifiers_stream$jscomp$1_position$jscomp$87_stream$jscomp$52$$)));if($APP.$cljs$core$empty_QMARK_$$($shapes$jscomp$97$$))return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$transforms$finish_transform$$());var $parent_validation_cache$$=$app$common$types$container$parent_validation_cache$$($objects$jscomp$485$$,
$shapes$jscomp$97$$,$libraries$jscomp$68$$),$subtree_ids_by_id$jscomp$4$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($id$jscomp$547$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$547$$,$app$common$files$helpers$get_children_ids_with_self$$($objects$jscomp$485$$,$id$jscomp$547$$)],null)}),$ids__$1$jscomp$15$$),$selection_rect_cache$jscomp$2$$=
$APP.$cljs$core$volatile_BANG_$$(null);$_$jscomp$2062_move_stream_stopper$jscomp$14$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2062_move_stream_stopper$jscomp$14$$,$APP.$beicon$v2$core$map$$(function($code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$){var $cause54391$jscomp$inline_14427_move_vector$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$,
0,null),$fn_54390$jscomp$inline_14426_heapi32$jscomp$inline_14432_mod_QMARK_$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$,1,null),$position__$1$jscomp$3_row$jscomp$inline_14433$$=$APP.$app$common$geom$point$add$$($self__$jscomp$4634$$.$from_position$,$cause54391$jscomp$inline_14427_move_vector$jscomp$2$$);
$code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$=$APP.$app$common$types$shape_tree$top_nested_frame$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$485$$,$position__$1$jscomp$3_row$jscomp$inline_14433$$,$APP.$cljs$core$truth_$$($fn_54390$jscomp$inline_14426_heapi32$jscomp$inline_14432_mod_QMARK_$jscomp$3$$)?$exclude_frames$$:$exclude_frames_siblings$$,!1);var $drop_index$jscomp$1_flex_layout_QMARK_$jscomp$1_vec__69203$$=
$app$common$types$container$find_valid_parent_and_frame_ids$cljs$0core$0IFn$0_invoke$0arity$06$$($code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$,$objects$jscomp$485$$,$shapes$jscomp$97$$,!1,$libraries$jscomp$68$$,$parent_validation_cache$$);$code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drop_index$jscomp$1_flex_layout_QMARK_$jscomp$1_vec__69203$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drop_index$jscomp$1_flex_layout_QMARK_$jscomp$1_vec__69203$$,1,null);$drop_index$jscomp$1_flex_layout_QMARK_$jscomp$1_vec__69203$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$485$$,$code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$);
var $grid_layout_QMARK_$jscomp$1$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$485$$,$code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$);$drop_index$jscomp$1_flex_layout_QMARK_$jscomp$1_vec__69203$$=$APP.$cljs$core$truth_$$($drop_index$jscomp$1_flex_layout_QMARK_$jscomp$1_vec__69203$$)?$app$common$geom$shapes$flex_layout$drop_area$get_drop_index$$($code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$,
$objects$jscomp$485$$,$position__$1$jscomp$3_row$jscomp$inline_14433$$):null;if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($grid_layout_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($fn_54390$jscomp$inline_14426_heapi32$jscomp$inline_14432_mod_QMARK_$jscomp$3$$):$grid_layout_QMARK_$jscomp$1$$))if($APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")){$APP.$app$render_wasm$api$use_shape$$($code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$);
$fn_54390$jscomp$inline_14426_heapi32$jscomp$inline_14432_mod_QMARK_$jscomp$3$$=$APP.$app$render_wasm$wasm$internal_module$$._get_grid_coords;try{var $JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$=$fn_54390$jscomp$inline_14426_heapi32$jscomp$inline_14432_mod_QMARK_$jscomp$3$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position__$1$jscomp$3_row$jscomp$inline_14433$$,$APP.$cljs$cst$1510$x$$),
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position__$1$jscomp$3_row$jscomp$inline_14433$$,$APP.$cljs$cst$1511$y$$))}catch($e54392$jscomp$inline_14435$$){throw $cause54391$jscomp$inline_14427_move_vector$jscomp$2$$=$e54392$jscomp$inline_14435$$,$code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,
$code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$)?$code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$.$cljs$core$IFn$_invoke$arity$0$?
$code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$.$cljs$core$IFn$_invoke$arity$0$():$code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$():null,$code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$,$APP.$cljs$cst$2971$wasm_critical$$),$JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_get_grid_coords",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$],null),$cause54391$jscomp$inline_14427_move_vector$jscomp$2$$);}$fn_54390$jscomp$inline_14426_heapi32$jscomp$inline_14432_mod_QMARK_$jscomp$3$$=$APP.$app$render_wasm$wasm$internal_module$$.HEAP32;$position__$1$jscomp$3_row$jscomp$inline_14433$$=$fn_54390$jscomp$inline_14426_heapi32$jscomp$inline_14432_mod_QMARK_$jscomp$3$$[$JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$+
0>>2];$JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$=$fn_54390$jscomp$inline_14426_heapi32$jscomp$inline_14432_mod_QMARK_$jscomp$3$$[$JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$+4>>2];$APP.$app$render_wasm$mem$free$$();$JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$=
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$position__$1$jscomp$3_row$jscomp$inline_14433$$,$JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$],null);$JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[-1,-1],null))?$JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$:null}else $JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$=$app$common$geom$shapes$grid_layout$positions$get_drop_cell$$($code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$,
$objects$jscomp$485$$,$position__$1$jscomp$3_row$jscomp$inline_14433$$);else $JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$=null;return[$cause54391$jscomp$inline_14427_move_vector$jscomp$2$$,$code__52999__auto__$jscomp$inline_14430_code_num__52998__auto__$jscomp$inline_14429_p__69199_read_code_fn__52997__auto__$jscomp$inline_14428_target_frame$jscomp$2_target_frame__$1$$,$drop_index$jscomp$1_flex_layout_QMARK_$jscomp$1_vec__69203$$,
$JSCompiler_temp$jscomp$10872_cell$jscomp$inline_12653_column$jscomp$inline_14434_hint__53000__auto__$jscomp$inline_14431_offset$jscomp$inline_14425$$]},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$streams$mouse_position_mod$$,$APP.$beicon$v2$core$map$$($app$main$snap$correct_snap_point$$,$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($snap_delta$jscomp$1$$,$modifiers_stream$jscomp$1_position$jscomp$87_stream$jscomp$52$$))))));
$modifiers_stream$jscomp$1_position$jscomp$87_stream$jscomp$52$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$map$$(function($p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$){var $move_vector$jscomp$3_move_vector__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$,0,null),$target_frame$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$,
1,null),$drop_index$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$,2,null),$cell_data$jscomp$7_cell_data__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$,3,null);$p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$,
4,null);$cell_data$jscomp$7_cell_data__$1$$=$APP.$cljs$core$truth_$$($cell_data$jscomp$7_cell_data__$1$$)?$cell_data$jscomp$7_cell_data__$1$$:$APP.$cljs$core$_deref$$($prev_cell_data$$);var $x_disp_QMARK_$$=$APP.$app$common$math$abs$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($move_vector$jscomp$3_move_vector__$1$$))>$APP.$app$common$math$abs$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($move_vector$jscomp$3_move_vector__$1$$));$p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$=
$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$)?$x_disp_QMARK_$$:$p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($move_vector$jscomp$3_move_vector__$1$$,$APP.$cljs$cst$1511$y$$,0),$APP.$cljs$cst$1511$y$$],null):$APP.$cljs$core$truth_$$($p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$)?
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($move_vector$jscomp$3_move_vector__$1$$,$APP.$cljs$cst$1510$x$$,0),$APP.$cljs$cst$1510$x$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$move_vector$jscomp$3_move_vector__$1$$,null],null);$move_vector$jscomp$3_move_vector__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$,
0,null);$p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$main$data$workspace$modifiers$build_change_frame_modifiers$$($APP.$app$main$data$workspace$modifiers$create_modif_tree$$($ids__$1$jscomp$15$$,$APP.$app$common$types$modifiers$move_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$($move_vector$jscomp$3_move_vector__$1$$)),
$objects$jscomp$485$$,$selected$jscomp$46$$,$target_frame$jscomp$3$$,$drop_index$jscomp$2$$,$cell_data$jscomp$7_cell_data__$1$$),$p__69209_shift_QMARK_$jscomp$5_snap_ignore_axis$jscomp$3_vec__69213$$],null)},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__69219$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69219$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69219$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69219$$,
2,null);var $cell_data$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69219$$,3,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69219$$,4,null);return $cell_data$jscomp$8$$!=null?$APP.$cljs$core$_vreset_BANG_$$($prev_cell_data$$,$cell_data$jscomp$8$$):null},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$03$$($app$util$array$conj$$,$APP.$sub$jscomp$inline_5572$$,$_$jscomp$2062_move_stream_stopper$jscomp$14$$))));return $APP.$app$main$features$active_feature_QMARK_$$($duplicate_stopper_state$jscomp$466$$,
"render-wasm/v1")?($duplicate_stopper_state$jscomp$466$$=$APP.$beicon$v2$core$mapcat$$(function($alt_QMARK_$jscomp$2$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($alt_QMARK_$jscomp$2$$)?$APP.$cljs$core$not$$($self__$jscomp$4634$$.$from_duplicate_QMARK_$):$alt_QMARK_$jscomp$2$$)?(0,$APP.$beicon$v2$core$of$$)(!0):$APP.$beicon$v2$core$empty$$()},$APP.$sub$jscomp$inline_5575$$),$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$(function($p__69229_snap_ignore_axis$jscomp$4$$){var $modifiers$jscomp$83$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69229_snap_ignore_axis$jscomp$4$$,0,null);$p__69229_snap_ignore_axis$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69229_snap_ignore_axis$jscomp$4$$,1,null);return $APP.$app$main$data$workspace$modifiers$set_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($modifiers$jscomp$83$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3824$snap_ignore_axis$$,$p__69229_snap_ignore_axis$jscomp$4$$,
$cljs$cst$3834$subtree_ids_by_id$$,$subtree_ids_by_id$jscomp$4$$,$cljs$cst$3835$selection_rect_cache$$,$selection_rect_cache$jscomp$2$$]))},$beicon$v2$core$sample$$(16,$APP.$beicon$v2$core$take_until$$($duplicate_stopper_state$jscomp$466$$,$modifiers_stream$jscomp$1_position$jscomp$87_stream$jscomp$52$$))),$APP.$beicon$v2$core$mapcat$$(function($alt_QMARK_$jscomp$3_p__69234$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($alt_QMARK_$jscomp$3_p__69234$$,0,null);$alt_QMARK_$jscomp$3_p__69234$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($alt_QMARK_$jscomp$3_p__69234$$,1,null);var $and__5023__auto__$jscomp$inline_6769$$=$APP.$cljs$core$not$$($self__$jscomp$4634$$.$from_duplicate_QMARK_$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_6769$$?$alt_QMARK_$jscomp$3_p__69234$$:$and__5023__auto__$jscomp$inline_6769$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$transforms$start_move_duplicate$$($self__$jscomp$4634$$.$from_position$),$app$main$data$workspace$selection$duplicate_selected$cljs$0core$0IFn$0_invoke$0arity$02$$(!1,
!0)):$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p__69243$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69243$$,0,null);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69243$$,1,null)},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$sub$jscomp$inline_5575$$,$_$jscomp$2062_move_stream_stopper$jscomp$14$$)))),$APP.$beicon$v2$core$mapcat$$(function($modifiers$jscomp$84_p__69251$$){var $drop_cell_vec__69255$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$84_p__69251$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drop_cell_vec__69255$$,0,null);var $target_frame$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drop_cell_vec__69255$$,1,null),$drop_index$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drop_cell_vec__69255$$,2,null);$drop_cell_vec__69255$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drop_cell_vec__69255$$,
3,null);var $snap_ignore_axis$jscomp$5_vec__69258$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$84_p__69251$$,1,null);$modifiers$jscomp$84_p__69251$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($snap_ignore_axis$jscomp$5_vec__69258$$,0,null);$snap_ignore_axis$jscomp$5_vec__69258$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($snap_ignore_axis$jscomp$5_vec__69258$$,1,null);var $undo_id$jscomp$11$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$11$$),
$APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($modifiers$jscomp$84_p__69251$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3824$snap_ignore_axis$$,$snap_ignore_axis$jscomp$5_vec__69258$$,$cljs$cst$3837$undo_transation_QMARK_$$,!1,$cljs$cst$3834$subtree_ids_by_id$$,$subtree_ids_by_id$jscomp$4$$])),$APP.$app$main$data$workspace$transforms$move_shapes_to_frame$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$main$data$workspace$transforms$move_shapes_to_frame$$.$cljs$core$IFn$_invoke$arity$4$($ids__$1$jscomp$15$$,
$target_frame$jscomp$4$$,$drop_index$jscomp$3$$,$drop_cell_vec__69255$$):$APP.$app$main$data$workspace$transforms$move_shapes_to_frame$$($ids__$1$jscomp$15$$,$target_frame$jscomp$4$$,$drop_index$jscomp$3$$,$drop_cell_vec__69255$$),$APP.$app$main$data$workspace$transforms$finish_transform$$(),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$11$$))},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($modifiers_stream$jscomp$1_position$jscomp$87_stream$jscomp$52$$,
$APP.$beicon$v2$core$take_until$$($duplicate_stopper_state$jscomp$466$$,$APP.$beicon$v2$core$last$$($_$jscomp$2062_move_stream_stopper$jscomp$14$$)))))):$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$(function($p__69261_snap_ignore_axis$jscomp$6$$){var $modifiers$jscomp$85$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69261_snap_ignore_axis$jscomp$6$$,0,null);$p__69261_snap_ignore_axis$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69261_snap_ignore_axis$jscomp$6$$,
1,null);return $APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($modifiers$jscomp$85$$,!1,!1,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3824$snap_ignore_axis$$,$p__69261_snap_ignore_axis$jscomp$6$$],null))},$modifiers_stream$jscomp$1_position$jscomp$87_stream$jscomp$52$$),$APP.$beicon$v2$core$mapcat$$(function($alt_QMARK_$jscomp$5_p__69266$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($alt_QMARK_$jscomp$5_p__69266$$,0,null);$alt_QMARK_$jscomp$5_p__69266$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($alt_QMARK_$jscomp$5_p__69266$$,1,null);var $and__5023__auto__$jscomp$inline_6771$$=$APP.$cljs$core$not$$($duplicate_move_started_QMARK_$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_6771$$?$alt_QMARK_$jscomp$5_p__69266$$:$and__5023__auto__$jscomp$inline_6771$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$transforms$start_move_duplicate$$($self__$jscomp$4634$$.$from_position$),$app$main$data$workspace$selection$duplicate_selected$cljs$0core$0IFn$0_invoke$0arity$02$$(!1,
!0)):$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p__69272$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69272$$,0,null);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69272$$,1,null)},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$sub$jscomp$inline_5575$$,$_$jscomp$2062_move_stream_stopper$jscomp$14$$)))),$APP.$beicon$v2$core$map$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$transforms$set_ghost_displacement$$,
$APP.$cljs$core$first$$),$_$jscomp$2062_move_stream_stopper$jscomp$14$$),$APP.$beicon$v2$core$mapcat$$(function($drop_cell$jscomp$1_p__69282$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drop_cell$jscomp$1_p__69282$$,0,null);var $target_frame$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drop_cell$jscomp$1_p__69282$$,1,null),$drop_index$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drop_cell$jscomp$1_p__69282$$,2,null);$drop_cell$jscomp$1_p__69282$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drop_cell$jscomp$1_p__69282$$,3,null);var $undo_id$jscomp$12$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$12$$),$APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3837$undo_transation_QMARK_$$,!1],null)),$APP.$app$main$data$workspace$transforms$move_shapes_to_frame$$.$cljs$core$IFn$_invoke$arity$4$?
$APP.$app$main$data$workspace$transforms$move_shapes_to_frame$$.$cljs$core$IFn$_invoke$arity$4$($ids__$1$jscomp$15$$,$target_frame$jscomp$5$$,$drop_index$jscomp$4$$,$drop_cell$jscomp$1_p__69282$$):$APP.$app$main$data$workspace$transforms$move_shapes_to_frame$$($ids__$1$jscomp$15$$,$target_frame$jscomp$5$$,$drop_index$jscomp$4$$,$drop_cell$jscomp$1_p__69282$$),$APP.$app$main$data$workspace$transforms$finish_transform$$(),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$12$$))},
$APP.$beicon$v2$core$last$$($_$jscomp$2062_move_stream_stopper$jscomp$14$$)))});return new $app$main$data$workspace$transforms$start_move_69181$$($from_position$jscomp$4$$,$ids$jscomp$124$$,$from_duplicate_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$reorder_selected_layout_child$$=function($direction$jscomp$15$$){typeof $app$main$data$workspace$transforms$reorder_layout_child_69292$$==="undefined"&&($app$main$data$workspace$transforms$reorder_layout_child_69292$$=function($direction$jscomp$16$$,$meta69293$$){this.direction=$direction$jscomp$16$$;this.$meta69293$=$meta69293$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$reorder_layout_child_69292$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$reorder_layout_child_69292$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3873$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_reorder_layout_child$$},$app$main$data$workspace$transforms$reorder_layout_child_69292$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69294$$,$meta69293__$1$$){return new $app$main$data$workspace$transforms$reorder_layout_child_69292$$(this.direction,
$meta69293__$1$$)},$app$main$data$workspace$transforms$reorder_layout_child_69292$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69293$},$app$main$data$workspace$transforms$reorder_layout_child_69292$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$reorder_layout_child_69292$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$172_selected$jscomp$47$$,$changes$jscomp$190_page_id$jscomp$172_state$jscomp$467$$){function $move_grid_children$$($changes$jscomp$192$$,
$key_prop_parent_id$jscomp$86$$,$children$jscomp$241_map__69313_map__69313__$1$$){var $parent$jscomp$265$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$486$$,$key_prop_parent_id$jscomp$86$$);$key_prop_parent_id$jscomp$86$$=function(){var $G__69314_G__69314__$1$$=$self__$jscomp$4638$$.direction;$G__69314_G__69314__$1$$=$G__69314_G__69314__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__69314_G__69314__$1$$.$fqn$:null;switch($G__69314_G__69314__$1$$){case "up":case "down":return $APP.$cljs$cst$1656$row$$;
case "right":case "left":return $APP.$cljs$cst$216$column$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__69314_G__69314__$1$$)].join(""));}}();var $key_comp$$=function(){var $G__69316_G__69316__$1$$=$self__$jscomp$4638$$.direction;$G__69316_G__69316__$1$$=$G__69316_G__69316__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__69316_G__69316__$1$$.$fqn$:null;switch($G__69316_G__69316__$1$$){case "up":case "left":return $APP.$cljs$core$_LT_$$;case "down":case "right":return $APP.$cljs$core$_GT_$$;
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__69316_G__69316__$1$$)].join(""));}}();$children$jscomp$241_map__69313_map__69313__$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($parent__$1$jscomp$57$$,$id$jscomp$549_p__69317$$){var $map__69318__$1_next_cell_next_row$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$549_p__69317$$);$id$jscomp$549_p__69317$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69318__$1_next_cell_next_row$$,
$APP.$cljs$cst$266$id$$);var $row$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69318__$1_next_cell_next_row$$,$APP.$cljs$cst$1656$row$$),$column$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69318__$1_next_cell_next_row$$,$APP.$cljs$cst$216$column$$),$row_span$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69318__$1_next_cell_next_row$$,$APP.$cljs$cst$1657$row_span$$),$column_span$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69318__$1_next_cell_next_row$$,
$APP.$cljs$cst$1658$column_span$$),$next_column_vec__69319$$=function(){var $G__69322_G__69322__$1$$=$self__$jscomp$4638$$.direction;$G__69322_G__69322__$1$$=$G__69322_G__69322__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__69322_G__69322__$1$$.$fqn$:null;switch($G__69322_G__69322__$1$$){case "up":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$row$jscomp$31$$-1,$column$jscomp$36$$],null);case "right":return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$row$jscomp$31$$,$column$jscomp$36$$+$column_span$jscomp$11$$],null);case "down":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$row$jscomp$31$$+$row_span$jscomp$11$$,$column$jscomp$36$$],null);case "left":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$row$jscomp$31$$,$column$jscomp$36$$-1],null);default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__69322_G__69322__$1$$)].join(""));}}();$map__69318__$1_next_cell_next_row$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($next_column_vec__69319$$,0,null);$next_column_vec__69319$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($next_column_vec__69319$$,1,null);$map__69318__$1_next_cell_next_row$$=$APP.$app$common$types$shape$layout$get_cell_by_position$$($parent__$1$jscomp$57$$,$map__69318__$1_next_cell_next_row$$,$next_column_vec__69319$$);
return $map__69318__$1_next_cell_next_row$$!=null?$app$common$types$shape$layout$swap_shapes$$($parent__$1$jscomp$57$$,$id$jscomp$549_p__69317$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__69318__$1_next_cell_next_row$$)):$parent__$1$jscomp$57$$},$parent$jscomp$265$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($key_prop_parent_id$jscomp$86$$,$key_comp$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__69288_SHARP_$$){return $APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($parent$jscomp$265$$,
$p1__69288_SHARP_$$)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69287_SHARP_$$){return $app$common$types$component$in_component_copy_not_head_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$486$$,$p1__69287_SHARP_$$))},$children$jscomp$241_map__69313_map__69313__$1$$))));$children$jscomp$241_map__69313_map__69313__$1$$=$APP.$cljs$core$__destructure_map$$($children$jscomp$241_map__69313_map__69313__$1$$);var $layout_grid_cells$jscomp$4$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$241_map__69313_map__69313__$1$$,$APP.$cljs$cst$1696$layout_grid_cells$$);return $APP.$app$common$files$changes_builder$reorder_grid_children$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$192$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$265$$)],null),
function($shape$jscomp$547$$){return $APP.$app$common$types$shape$layout$assign_cells$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$547$$,$APP.$cljs$cst$1696$layout_grid_cells$$,$layout_grid_cells$jscomp$4$$),$objects$jscomp$486$$)}),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$265$$)],null))}function $move_flex_children$$($changes$jscomp$191$$,$parent_id$jscomp$85$$,
$children$jscomp$240$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$72$$,$index$jscomp$287_p__69308$$){var $child_id$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($index$jscomp$287_p__69308$$,0,null);$index$jscomp$287_p__69308$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($index$jscomp$287_p__69308$$,1,null);return $APP.$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$04$$($changes__$1$jscomp$72$$,
$parent_id$jscomp$85$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$486$$,$child_id$jscomp$8$$)],null),$index$jscomp$287_p__69308$$)},$changes$jscomp$191$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$second$$,$APP.$cljs$core$_GT_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$548$$){var $JSCompiler_inline_result$jscomp$1169_position$jscomp$89$$=
$app$common$files$helpers$get_position_on_parent$$($objects$jscomp$486$$,$id$jscomp$548$$),$JSCompiler_temp_const$jscomp$1168$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$parent$jscomp$inline_6775$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$486$$,$parent_id$jscomp$85$$);$JSCompiler_inline_result$jscomp$1169_position$jscomp$89$$=$APP.$app$common$types$shape$layout$reverse_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$inline_6775$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4638$$.direction,
$APP.$cljs$cst$257$left$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4638$$.direction,$APP.$cljs$cst$1954$up$$))||!$APP.$app$common$types$shape$layout$reverse_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($parent$jscomp$inline_6775$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4638$$.direction,$APP.$cljs$cst$258$right$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4638$$.direction,$APP.$cljs$cst$1953$down$$))?$JSCompiler_inline_result$jscomp$1169_position$jscomp$89$$-
1:$JSCompiler_inline_result$jscomp$1169_position$jscomp$89$$+2;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$1168$$,[$id$jscomp$548$$,$JSCompiler_inline_result$jscomp$1169_position$jscomp$89$$],null)},$children$jscomp$240$$)))}var $self__$jscomp$4638$$=this;$it$jscomp$172_selected$jscomp$47$$=$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($changes$jscomp$190_page_id$jscomp$172_state$jscomp$467$$);var $objects$jscomp$486$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$190_page_id$jscomp$172_state$jscomp$467$$);
$changes$jscomp$190_page_id$jscomp$172_state$jscomp$467$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$190_page_id$jscomp$172_state$jscomp$467$$);$changes$jscomp$190_page_id$jscomp$172_state$jscomp$467$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($G__69328__$1_changes$jscomp$193$$,$children$jscomp$242_p__69324$$){var $parent_id$jscomp$87$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$242_p__69324$$,0,null);
$children$jscomp$242_p__69324$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$242_p__69324$$,1,null);$G__69328__$1_changes$jscomp$193$$=$APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$486$$,$parent_id$jscomp$87$$))?$move_flex_children$$($G__69328__$1_changes$jscomp$193$$,$parent_id$jscomp$87$$,$children$jscomp$242_p__69324$$):$G__69328__$1_changes$jscomp$193$$;return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$486$$,
$parent_id$jscomp$87$$))?$move_grid_children$$($G__69328__$1_changes$jscomp$193$$,$parent_id$jscomp$87$$,$children$jscomp$242_p__69324$$):$G__69328__$1_changes$jscomp$193$$},$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$changes$jscomp$190_page_id$jscomp$172_state$jscomp$467$$),$objects$jscomp$486$$),$APP.$cljs$core$group_by$$(function($p1__69290_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$486$$,
$p1__69290_SHARP_$$),$APP.$cljs$cst$1619$parent_id$$)},$it$jscomp$172_selected$jscomp$47$$));var $undo_id$jscomp$13$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$13$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$190_page_id$jscomp$172_state$jscomp$467$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1723$ids$$,$it$jscomp$172_selected$jscomp$47$$],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$13$$))});return new $app$main$data$workspace$transforms$reorder_layout_child_69292$$($direction$jscomp$15$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$move_selected$$=function($direction$jscomp$19$$,$shift_QMARK_$jscomp$8$$){typeof $app$main$data$workspace$transforms$move_selected_69355$$==="undefined"&&($app$main$data$workspace$transforms$move_selected_69355$$=function($direction$jscomp$20$$,$shift_QMARK_$jscomp$9$$,$meta69356$$){this.direction=$direction$jscomp$20$$;this.$shift_QMARK_$=$shift_QMARK_$jscomp$9$$;this.$meta69356$=$meta69356$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$transforms$move_selected_69355$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$move_selected_69355$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3878$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_move_selected$$},$app$main$data$workspace$transforms$move_selected_69355$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69357$$,$meta69356__$1$$){return new $app$main$data$workspace$transforms$move_selected_69355$$(this.direction,
this.$shift_QMARK_$,$meta69356__$1$$)},$app$main$data$workspace$transforms$move_selected_69355$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69356$},$app$main$data$workspace$transforms$move_selected_69355$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$move_selected_69355$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2067_selected$jscomp$49_selected_shapes$jscomp$1$$,$state$jscomp$470$$){var $objects$jscomp$487$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$470$$);$_$jscomp$2067_selected$jscomp$49_selected_shapes$jscomp$1$$=$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$470$$);$_$jscomp$2067_selected$jscomp$49_selected_shapes$jscomp$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$487$$),$_$jscomp$2067_selected$jscomp$49_selected_shapes$jscomp$1$$);return $APP.$cljs$core$every_QMARK_$$(function($p1__69353_SHARP_$$){return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$487$$,
$p1__69353_SHARP_$$)&&$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__69353_SHARP_$$))},$_$jscomp$2067_selected$jscomp$49_selected_shapes$jscomp$1$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$transforms$reorder_selected_layout_child$$(this.direction)):(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$transforms$nudge_selected_shapes$$(this.direction,this.$shift_QMARK_$))});return new $app$main$data$workspace$transforms$move_selected_69355$$($direction$jscomp$19$$,
$shift_QMARK_$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$calculate_delta$$=function($position$jscomp$90$$,$bbox$$,$relative_to$jscomp$7$$){var $current$jscomp$46$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bbox$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bbox$$)),$position__$1$jscomp$4$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $G__69362$jscomp$inline_6777_or__5025__auto__$jscomp$792$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$90$$);
$G__69362$jscomp$inline_6777_or__5025__auto__$jscomp$792$$=$G__69362$jscomp$inline_6777_or__5025__auto__$jscomp$792$$==null?null:$G__69362$jscomp$inline_6777_or__5025__auto__$jscomp$792$$+($relative_to$jscomp$7$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($relative_to$jscomp$7$$,$APP.$cljs$cst$1510$x$$));return $APP.$cljs$core$truth_$$($G__69362$jscomp$inline_6777_or__5025__auto__$jscomp$792$$)?$G__69362$jscomp$inline_6777_or__5025__auto__$jscomp$792$$:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bbox$$)}(),
function(){var $G__69363$jscomp$inline_6779_or__5025__auto__$jscomp$793$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$90$$);$G__69363$jscomp$inline_6779_or__5025__auto__$jscomp$793$$=$G__69363$jscomp$inline_6779_or__5025__auto__$jscomp$793$$==null?null:$G__69363$jscomp$inline_6779_or__5025__auto__$jscomp$793$$+($relative_to$jscomp$7$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($relative_to$jscomp$7$$,$APP.$cljs$cst$1511$y$$));return $APP.$cljs$core$truth_$$($G__69363$jscomp$inline_6779_or__5025__auto__$jscomp$793$$)?
$G__69363$jscomp$inline_6779_or__5025__auto__$jscomp$793$$:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bbox$$)}());return $APP.$app$common$geom$point$subtract$$($position__$1$jscomp$4$$,$current$jscomp$46$$)};
$app$main$data$workspace$transforms$update_position$cljs$0core$0IFn$0_invoke$0arity$03$$=function($id$jscomp$551$$,$position$jscomp$92$$,$p__69366$$){var $map__69367__$1$$=$APP.$cljs$core$__destructure_map$$($p__69366$$),$no_wasm_QMARK_$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69367__$1$$,$cljs$cst$3864$no_wasm_QMARK_$$);typeof $app$main$data$workspace$transforms$update_position_69368$$==="undefined"&&($app$main$data$workspace$transforms$update_position_69368$$=function($id$jscomp$552$$,
$position$jscomp$93$$,$p__69366$jscomp$1$$,$map__69367$jscomp$1$$,$options$jscomp$519$$,$no_wasm_QMARK_$jscomp$5$$,$meta69369$$){this.id=$id$jscomp$552$$;this.position=$position$jscomp$93$$;this.$p__69366$=$p__69366$jscomp$1$$;this.$map__69367$=$map__69367$jscomp$1$$;this.options=$options$jscomp$519$$;this.$no_wasm_QMARK_$=$no_wasm_QMARK_$jscomp$5$$;this.$meta69369$=$meta69369$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$update_position_69368$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$update_position_69368$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3879$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_update_position$$},$app$main$data$workspace$transforms$update_position_69368$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69370$$,$meta69369__$1$$){return new $app$main$data$workspace$transforms$update_position_69368$$(this.id,this.position,this.$p__69366$,
this.$map__69367$,this.options,this.$no_wasm_QMARK_$,$meta69369__$1$$)},$app$main$data$workspace$transforms$update_position_69368$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69369$},$app$main$data$workspace$transforms$update_position_69368$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$update_position_69368$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2068_or__5025__auto__$jscomp$inline_6781_page_id$jscomp$173$$,
$state$jscomp$471$$){$_$jscomp$2068_or__5025__auto__$jscomp$inline_6781_page_id$jscomp$173$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this.options,$APP.$cljs$cst$2043$page_id$$);$_$jscomp$2068_or__5025__auto__$jscomp$inline_6781_page_id$jscomp$173$$=$APP.$cljs$core$truth_$$($_$jscomp$2068_or__5025__auto__$jscomp$inline_6781_page_id$jscomp$173$$)?$_$jscomp$2068_or__5025__auto__$jscomp$inline_6781_page_id$jscomp$173$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$471$$,
$APP.$cljs$cst$1918$current_page_id$$);var $JSCompiler_temp$jscomp$10749_objects$jscomp$488$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$471$$,$_$jscomp$2068_or__5025__auto__$jscomp$inline_6781_page_id$jscomp$173$$),$G__46796__$1$jscomp$inline_12657_shape$jscomp$548$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10749_objects$jscomp$488$$,this.id),$bbox$jscomp$1_delta$jscomp$44_modifiers$jscomp$86$$=$APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($G__46796__$1$jscomp$inline_12657_shape$jscomp$548$$));
$APP.$cljs$core$truth_$$($APP.$cljs$cst$3880$absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(this.options))?$JSCompiler_temp$jscomp$10749_objects$jscomp$488$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10749_objects$jscomp$488$$,$APP.$app$common$uuid$zero$$):$APP.$cljs$core$map_QMARK_$$($G__46796__$1$jscomp$inline_12657_shape$jscomp$548$$)?$JSCompiler_temp$jscomp$10749_objects$jscomp$488$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10749_objects$jscomp$488$$,
$G__46796__$1$jscomp$inline_12657_shape$jscomp$548$$?.$frame_id$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__46796__$1$jscomp$inline_12657_shape$jscomp$548$$,$APP.$cljs$cst$1607$frame_id$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$G__46796__$1$jscomp$inline_12657_shape$jscomp$548$$)?$JSCompiler_temp$jscomp$10749_objects$jscomp$488$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10749_objects$jscomp$488$$,$APP.$app$common$uuid$zero$$):
($G__46796__$1$jscomp$inline_12657_shape$jscomp$548$$=$G__46796__$1$jscomp$inline_12657_shape$jscomp$548$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10749_objects$jscomp$488$$,$G__46796__$1$jscomp$inline_12657_shape$jscomp$548$$),$JSCompiler_temp$jscomp$10749_objects$jscomp$488$$=$G__46796__$1$jscomp$inline_12657_shape$jscomp$548$$==null?null:$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$10749_objects$jscomp$488$$,
$G__46796__$1$jscomp$inline_12657_shape$jscomp$548$$));$bbox$jscomp$1_delta$jscomp$44_modifiers$jscomp$86$$=$app$main$data$workspace$transforms$calculate_delta$$(this.position,$bbox$jscomp$1_delta$jscomp$44_modifiers$jscomp$86$$,$JSCompiler_temp$jscomp$10749_objects$jscomp$488$$);$bbox$jscomp$1_delta$jscomp$44_modifiers$jscomp$86$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.id],null),
$APP.$app$common$types$modifiers$move_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$($bbox$jscomp$1_delta$jscomp$44_modifiers$jscomp$86$$));return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$471$$,"render-wasm/v1")&&$APP.$cljs$core$not$$(this.$no_wasm_QMARK_$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($bbox$jscomp$1_delta$jscomp$44_modifiers$jscomp$86$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$3821$ignore_constraints$$,!1,$APP.$cljs$cst$2556$ignore_touched$$,$APP.$cljs$cst$2556$ignore_touched$$.$cljs$core$IFn$_invoke$arity$1$(this.options),$cljs$cst$3833$ignore_snap_pixel$$,!0],null)]))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1810$modifiers$$,$bbox$jscomp$1_delta$jscomp$44_modifiers$jscomp$86$$,$APP.$cljs$cst$2043$page_id$$,
$_$jscomp$2068_or__5025__auto__$jscomp$inline_6781_page_id$jscomp$173$$,$APP.$cljs$cst$3821$ignore_constraints$$,!1,$APP.$cljs$cst$2556$ignore_touched$$,$APP.$cljs$cst$2556$ignore_touched$$.$cljs$core$IFn$_invoke$arity$1$(this.options),$cljs$cst$3833$ignore_snap_pixel$$,!0],null)))});return new $app$main$data$workspace$transforms$update_position_69368$$($id$jscomp$551$$,$position$jscomp$92$$,$p__69366$$,$map__69367__$1$$,$map__69367__$1$$,$no_wasm_QMARK_$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$update_positions$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$127$$,$position$jscomp$95$$,$options$jscomp$520$$){typeof $app$main$data$workspace$transforms$update_positions_69373$$==="undefined"&&($app$main$data$workspace$transforms$update_positions_69373$$=function($ids$jscomp$128$$,$position$jscomp$96$$,$options$jscomp$521$$,$meta69374$$){this.ids=$ids$jscomp$128$$;this.position=$position$jscomp$96$$;this.options=$options$jscomp$521$$;this.$meta69374$=
$meta69374$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$update_positions_69373$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$update_positions_69373$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3881$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_update_positions$$},$app$main$data$workspace$transforms$update_positions_69373$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69375$$,$meta69374__$1$$){return new $app$main$data$workspace$transforms$update_positions_69373$$(this.ids,this.position,this.options,$meta69374__$1$$)},$app$main$data$workspace$transforms$update_positions_69373$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69374$},$app$main$data$workspace$transforms$update_positions_69373$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$update_positions_69373$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$4656$$=this;return $APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$553$$){return $app$main$data$workspace$transforms$update_position$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$553$$,$self__$jscomp$4656$$.position,$self__$jscomp$4656$$.options)},$self__$jscomp$4656$$.ids))});return new $app$main$data$workspace$transforms$update_positions_69373$$($ids$jscomp$127$$,$position$jscomp$95$$,$options$jscomp$520$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$position_shapes$$=function($shapes$jscomp$98$$){typeof $app$main$data$workspace$transforms$position_shapes_69376$$==="undefined"&&($app$main$data$workspace$transforms$position_shapes_69376$$=function($shapes$jscomp$99$$,$meta69377$$){this.shapes=$shapes$jscomp$99$$;this.$meta69377$=$meta69377$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$position_shapes_69376$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$position_shapes_69376$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3882$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_position_shapes$$},$app$main$data$workspace$transforms$position_shapes_69376$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69378$$,$meta69377__$1$$){return new $app$main$data$workspace$transforms$position_shapes_69376$$(this.shapes,$meta69377__$1$$)},
$app$main$data$workspace$transforms$position_shapes_69376$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69377$},$app$main$data$workspace$transforms$position_shapes_69376$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$position_shapes_69376$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2070_modif_tree$jscomp$59_objects$jscomp$489$$,$state$jscomp$472$$){$_$jscomp$2070_modif_tree$jscomp$59_objects$jscomp$489$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$472$$);var $shapes__$1$jscomp$12$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,this.shapes);$_$jscomp$2070_modif_tree$jscomp$59_objects$jscomp$489$$=$APP.$app$main$data$workspace$modifiers$build_modif_tree$$($APP.$cljs$core$keys$$($shapes__$1$jscomp$12$$),$_$jscomp$2070_modif_tree$jscomp$59_objects$jscomp$489$$,function($cpos_cshape$$){var $opos_oshape$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shapes__$1$jscomp$12$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cpos_cshape$$));$cpos_cshape$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($cpos_cshape$$)));$opos_oshape$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($opos_oshape$$)));
return $APP.$app$common$types$modifiers$move_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$geom$point$subtract$$($opos_oshape$$,$cpos_cshape$$))});return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$472$$,"render-wasm/v1")?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($_$jscomp$2070_modif_tree$jscomp$59_objects$jscomp$489$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$3821$ignore_constraints$$,!1,$cljs$cst$3833$ignore_snap_pixel$$,!0],null)]))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1810$modifiers$$,$_$jscomp$2070_modif_tree$jscomp$59_objects$jscomp$489$$,$APP.$cljs$cst$3821$ignore_constraints$$,!1,$cljs$cst$3833$ignore_snap_pixel$$,!0],null)))});return new $app$main$data$workspace$transforms$position_shapes_69376$$($shapes$jscomp$98$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$cleanup_invalid_moving_shapes$$=function($ids$jscomp$129_shapes__$1$jscomp$13$$,$objects$jscomp$490$$,$frame_id$jscomp$89$$){var $lookup$jscomp$19$$=$APP.$app$common$data$getf$$($objects$jscomp$490$$),$frame$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$490$$,$frame_id$jscomp$89$$),$layout_QMARK_$$=$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$33$$),$shapes$jscomp$100$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69380_SHARP_$$){var $and__5023__auto__$jscomp$471$$=
$APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__69380_SHARP_$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$471$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$89$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__69380_SHARP_$$)):$and__5023__auto__$jscomp$471$$},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69379_SHARP_$$){return $APP.$app$common$types$component$in_component_copy_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$490$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__69379_SHARP_$$)))},$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($lookup$jscomp$19$$,$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$490$$,$APP.$cljs$core$set$$($ids$jscomp$129_shapes__$1$jscomp$13$$)))));$ids$jscomp$129_shapes__$1$jscomp$13$$=function(){var $G__69383__$1$$=$APP.$cljs$core$not$$($layout_QMARK_$$)?$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69381_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__69381_SHARP_$$),
$frame_id$jscomp$89$$)},$shapes$jscomp$100$$):$shapes$jscomp$100$$;return $APP.$cljs$core$truth_$$($layout_QMARK_$$)?$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69382_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__69382_SHARP_$$),$frame_id$jscomp$89$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__69382_SHARP_$$),
$frame_id$jscomp$89$$)},$G__69383__$1$$):$G__69383__$1$$}();return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$ids$jscomp$129_shapes__$1$jscomp$13$$)};
$APP.$app$main$data$workspace$transforms$move_shapes_to_frame$$=function($ids$jscomp$130$$,$frame_id$jscomp$90$$,$drop_index$jscomp$5$$,$cell$jscomp$36$$){typeof $app$main$data$workspace$transforms$move_shapes_to_frame_69386$$==="undefined"&&($app$main$data$workspace$transforms$move_shapes_to_frame_69386$$=function($ids$jscomp$131$$,$frame_id$jscomp$91$$,$drop_index$jscomp$6$$,$cell$jscomp$37$$,$meta69387$$){this.ids=$ids$jscomp$131$$;this.$frame_id$=$frame_id$jscomp$91$$;this.$drop_index$=$drop_index$jscomp$6$$;
this.cell=$cell$jscomp$37$$;this.$meta69387$=$meta69387$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$move_shapes_to_frame_69386$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$move_shapes_to_frame_69386$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3883$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_move_shapes_to_frame$$},
$app$main$data$workspace$transforms$move_shapes_to_frame_69386$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69388$$,$meta69387__$1$$){return new $app$main$data$workspace$transforms$move_shapes_to_frame_69386$$(this.ids,this.$frame_id$,this.$drop_index$,this.cell,$meta69387__$1$$)},$app$main$data$workspace$transforms$move_shapes_to_frame_69386$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69387$},$app$main$data$workspace$transforms$move_shapes_to_frame_69386$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$move_shapes_to_frame_69386$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($add_component_to_variant_QMARK_$jscomp$1_it$jscomp$173_page_id$jscomp$174$$,$changes$jscomp$194_data$jscomp$349_state$jscomp$473$$){var $self__$jscomp$4664$$=this;$add_component_to_variant_QMARK_$jscomp$1_it$jscomp$173_page_id$jscomp$174$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$194_data$jscomp$349_state$jscomp$473$$);
var $objects$jscomp$491$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$194_data$jscomp$349_state$jscomp$473$$,$add_component_to_variant_QMARK_$jscomp$1_it$jscomp$173_page_id$jscomp$174$$);$changes$jscomp$194_data$jscomp$349_state$jscomp$473$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$194_data$jscomp$349_state$jscomp$473$$);var $ids__$1$jscomp$16$$=$app$main$data$workspace$transforms$cleanup_invalid_moving_shapes$$($self__$jscomp$4664$$.ids,
$objects$jscomp$491$$,$self__$jscomp$4664$$.$frame_id$);$changes$jscomp$194_data$jscomp$349_state$jscomp$473$$=$app$common$logic$shapes$generate_relocate$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$,
$add_component_to_variant_QMARK_$jscomp$1_it$jscomp$173_page_id$jscomp$174$$),$objects$jscomp$491$$),$changes$jscomp$194_data$jscomp$349_state$jscomp$473$$),$self__$jscomp$4664$$.$frame_id$,$self__$jscomp$4664$$.$drop_index$,$ids__$1$jscomp$16$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3525$cell$$,$self__$jscomp$4664$$.cell]));$add_component_to_variant_QMARK_$jscomp$1_it$jscomp$173_page_id$jscomp$174$$=function(){var $and__5023__auto__$jscomp$472$$=$APP.$cljs$core$some$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$instance_head_QMARK_$$,
$objects$jscomp$491$$),$ids__$1$jscomp$16$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$472$$)?$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$app$common$files$helpers$get_parents_with_self$$($objects$jscomp$491$$,$self__$jscomp$4664$$.$frame_id$)):$and__5023__auto__$jscomp$472$$}();var $add_new_variant_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$473$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($objects$jscomp$491$$.$cljs$core$IFn$_invoke$arity$1$?
$objects$jscomp$491$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4664$$.$frame_id$):$objects$jscomp$491$$($self__$jscomp$4664$$.$frame_id$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$473$$)?$APP.$cljs$core$some$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$main_instance_QMARK_$$,$objects$jscomp$491$$),$ids__$1$jscomp$16$$):$and__5023__auto__$jscomp$473$$}();return $APP.$beicon$v2$core$concat$$(function(){var $moved_count_shapes$jscomp$101$$=
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69384_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$491$$,$p1__69384_SHARP_$$)},$ids__$1$jscomp$16$$);$moved_count_shapes$jscomp$101$$=$APP.$cljs$core$count$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69385_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__69385_SHARP_$$),
$self__$jscomp$4664$$.$frame_id$)},$moved_count_shapes$jscomp$101$$));return $app$common$files$helpers$has_layout_QMARK_$$($objects$jscomp$491$$,$self__$jscomp$4664$$.$frame_id$)&&$moved_count_shapes$jscomp$101$$>0?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"layout-add-element",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:move-shapes-to-frame",
$cljs$cst$3884$element_type$$,$app$common$files$helpers$get_selected_type$$($objects$jscomp$491$$,$ids__$1$jscomp$16$$),$cljs$cst$3885$moved$$,$moved_count_shapes$jscomp$101$$],null))):null}(),$self__$jscomp$4664$$.$frame_id$!=null&&$APP.$app$common$data$not_empty_QMARK_$$($changes$jscomp$194_data$jscomp$349_state$jscomp$473$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$194_data$jscomp$349_state$jscomp$473$$),$app$main$data$workspace$collapse$expand_collapse$$($self__$jscomp$4664$$.$frame_id$)):
null,$APP.$cljs$core$truth_$$($add_component_to_variant_QMARK_$jscomp$1_it$jscomp$173_page_id$jscomp$174$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-component-to-variant"],null))):null,$APP.$cljs$core$truth_$$($add_new_variant_QMARK_$jscomp$1$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"add-new-variant",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:move-shapes-to-frame"],null))):null)});return new $app$main$data$workspace$transforms$move_shapes_to_frame_69386$$($ids$jscomp$130$$,$frame_id$jscomp$90$$,$drop_index$jscomp$5$$,$cell$jscomp$36$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$get_displacement$$=function($G__69389__$1_direction$jscomp$21$$){$G__69389__$1_direction$jscomp$21$$=$G__69389__$1_direction$jscomp$21$$ instanceof $APP.$cljs$core$Keyword$$?$G__69389__$1_direction$jscomp$21$$.$fqn$:null;switch($G__69389__$1_direction$jscomp$21$$){case "up":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,-1);case "down":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,1);case "left":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,
0);case "right":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,0);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__69389__$1_direction$jscomp$21$$)].join(""));}};
$app$main$data$workspace$transforms$flip_horizontal_selected$cljs$0core$0IFn$0_invoke$0arity$01$$=function($ids$jscomp$132$$){typeof $app$main$data$workspace$transforms$flip_horizontal_selected_69392$$==="undefined"&&($app$main$data$workspace$transforms$flip_horizontal_selected_69392$$=function($ids$jscomp$133$$,$meta69393$$){this.ids=$ids$jscomp$133$$;this.$meta69393$=$meta69393$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$flip_horizontal_selected_69392$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$flip_horizontal_selected_69392$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3886$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_flip_horizontal_selected$$},$app$main$data$workspace$transforms$flip_horizontal_selected_69392$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69394$$,$meta69393__$1$$){return new $app$main$data$workspace$transforms$flip_horizontal_selected_69392$$(this.ids,
$meta69393__$1$$)},$app$main$data$workspace$transforms$flip_horizontal_selected_69392$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69393$},$app$main$data$workspace$transforms$flip_horizontal_selected_69392$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$flip_horizontal_selected_69392$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2072_modifiers$jscomp$87_objects$jscomp$492_selected__$1$jscomp$3$$,
$state$jscomp$474$$){$_$jscomp$2072_modifiers$jscomp$87_objects$jscomp$492_selected__$1$jscomp$3$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$474$$);var $center$jscomp$53_or__5025__auto__$jscomp$inline_6783_selected$jscomp$50_selrect$jscomp$63_shapes$jscomp$102$$=this.ids;$center$jscomp$53_or__5025__auto__$jscomp$inline_6783_selected$jscomp$50_selrect$jscomp$63_shapes$jscomp$102$$=$APP.$cljs$core$truth_$$($center$jscomp$53_or__5025__auto__$jscomp$inline_6783_selected$jscomp$50_selrect$jscomp$63_shapes$jscomp$102$$)?
$center$jscomp$53_or__5025__auto__$jscomp$inline_6783_selected$jscomp$50_selrect$jscomp$63_shapes$jscomp$102$$:$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$474$$);$center$jscomp$53_or__5025__auto__$jscomp$inline_6783_selected$jscomp$50_selrect$jscomp$63_shapes$jscomp$102$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$is_variant_container_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($_$jscomp$2072_modifiers$jscomp$87_objects$jscomp$492_selected__$1$jscomp$3$$),
$center$jscomp$53_or__5025__auto__$jscomp$inline_6783_selected$jscomp$50_selrect$jscomp$63_shapes$jscomp$102$$));$_$jscomp$2072_modifiers$jscomp$87_objects$jscomp$492_selected__$1$jscomp$3$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$center$jscomp$53_or__5025__auto__$jscomp$inline_6783_selected$jscomp$50_selrect$jscomp$63_shapes$jscomp$102$$);$center$jscomp$53_or__5025__auto__$jscomp$inline_6783_selected$jscomp$50_selrect$jscomp$63_shapes$jscomp$102$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($center$jscomp$53_or__5025__auto__$jscomp$inline_6783_selected$jscomp$50_selrect$jscomp$63_shapes$jscomp$102$$);
$center$jscomp$53_or__5025__auto__$jscomp$inline_6783_selected$jscomp$50_selrect$jscomp$63_shapes$jscomp$102$$=$APP.$app$common$geom$rect$rect__GT_center$$($center$jscomp$53_or__5025__auto__$jscomp$inline_6783_selected$jscomp$50_selrect$jscomp$63_shapes$jscomp$102$$);$_$jscomp$2072_modifiers$jscomp$87_objects$jscomp$492_selected__$1$jscomp$3$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$($_$jscomp$2072_modifiers$jscomp$87_objects$jscomp$492_selected__$1$jscomp$3$$,$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,
1),$center$jscomp$53_or__5025__auto__$jscomp$inline_6783_selected$jscomp$50_selrect$jscomp$63_shapes$jscomp$102$$));return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$474$$,"render-wasm/v1")?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($_$jscomp$2072_modifiers$jscomp$87_objects$jscomp$492_selected__$1$jscomp$3$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$3833$ignore_snap_pixel$$,!0],null)]))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1810$modifiers$$,$_$jscomp$2072_modifiers$jscomp$87_objects$jscomp$492_selected__$1$jscomp$3$$,$cljs$cst$3833$ignore_snap_pixel$$,!0],null)))});return new $app$main$data$workspace$transforms$flip_horizontal_selected_69392$$($ids$jscomp$132$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$flip_vertical_selected$cljs$0core$0IFn$0_invoke$0arity$01$$=function($ids$jscomp$134$$){typeof $app$main$data$workspace$transforms$flip_vertical_selected_69398$$==="undefined"&&($app$main$data$workspace$transforms$flip_vertical_selected_69398$$=function($ids$jscomp$135$$,$meta69399$$){this.ids=$ids$jscomp$135$$;this.$meta69399$=$meta69399$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$flip_vertical_selected_69398$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$flip_vertical_selected_69398$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3887$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_flip_vertical_selected$$},$app$main$data$workspace$transforms$flip_vertical_selected_69398$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69400$$,$meta69399__$1$$){return new $app$main$data$workspace$transforms$flip_vertical_selected_69398$$(this.ids,
$meta69399__$1$$)},$app$main$data$workspace$transforms$flip_vertical_selected_69398$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69399$},$app$main$data$workspace$transforms$flip_vertical_selected_69398$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$flip_vertical_selected_69398$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2073_modifiers$jscomp$88_selected$jscomp$51_selected__$1$jscomp$4$$,
$state$jscomp$475$$){var $self__$jscomp$4672$$=this,$objects$jscomp$493$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$475$$);$_$jscomp$2073_modifiers$jscomp$88_selected$jscomp$51_selected__$1$jscomp$4$$=function(){var $or__5025__auto__$jscomp$796$$=$self__$jscomp$4672$$.ids;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$796$$)?$or__5025__auto__$jscomp$796$$:$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$475$$)}();
var $center$jscomp$54_selrect$jscomp$64_shapes$jscomp$103$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$is_variant_container_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69395_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$493$$,$p1__69395_SHARP_$$)},$_$jscomp$2073_modifiers$jscomp$88_selected$jscomp$51_selected__$1$jscomp$4$$));$_$jscomp$2073_modifiers$jscomp$88_selected$jscomp$51_selected__$1$jscomp$4$$=
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$center$jscomp$54_selrect$jscomp$64_shapes$jscomp$103$$);$center$jscomp$54_selrect$jscomp$64_shapes$jscomp$103$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($center$jscomp$54_selrect$jscomp$64_shapes$jscomp$103$$);$center$jscomp$54_selrect$jscomp$64_shapes$jscomp$103$$=$APP.$app$common$geom$rect$rect__GT_center$$($center$jscomp$54_selrect$jscomp$64_shapes$jscomp$103$$);$_$jscomp$2073_modifiers$jscomp$88_selected$jscomp$51_selected__$1$jscomp$4$$=
$APP.$app$main$data$workspace$modifiers$create_modif_tree$$($_$jscomp$2073_modifiers$jscomp$88_selected$jscomp$51_selected__$1$jscomp$4$$,$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,-1),$center$jscomp$54_selrect$jscomp$64_shapes$jscomp$103$$));return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$475$$,"render-wasm/v1")?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($_$jscomp$2073_modifiers$jscomp$88_selected$jscomp$51_selected__$1$jscomp$4$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3833$ignore_snap_pixel$$,!0],null)]))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1810$modifiers$$,$_$jscomp$2073_modifiers$jscomp$88_selected$jscomp$51_selected__$1$jscomp$4$$,$cljs$cst$3833$ignore_snap_pixel$$,!0],null)))});return new $app$main$data$workspace$transforms$flip_vertical_selected_69398$$($ids$jscomp$134$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$wasm_text$get_wasm_text_new_size$cljs$0core$0IFn$0_invoke$0arity$02$$=function($p__68910_selrect$jscomp$65$$,$content$jscomp$169_dimension$$){var $grow_type$jscomp$6_map__68912__$1$$=$APP.$cljs$core$__destructure_map$$($p__68910_selrect$jscomp$65$$),$JSCompiler_inline_result$jscomp$10873_fexpr__68913$jscomp$inline_12659_id$jscomp$556$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$6_map__68912__$1$$,$APP.$cljs$cst$266$id$$);$p__68910_selrect$jscomp$65$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$6_map__68912__$1$$,$APP.$cljs$cst$1605$selrect$$);$grow_type$jscomp$6_map__68912__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$6_map__68912__$1$$,$APP.$cljs$cst$1770$grow_type$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10873_fexpr__68913$jscomp$inline_12659_id$jscomp$556$$)?$APP.$app$render_wasm$api$initialized_QMARK_$$():$JSCompiler_inline_result$jscomp$10873_fexpr__68913$jscomp$inline_12659_id$jscomp$556$$)?
($APP.$app$render_wasm$api$use_shape$$($JSCompiler_inline_result$jscomp$10873_fexpr__68913$jscomp$inline_12659_id$jscomp$556$$),$APP.$app$render_wasm$api$set_shape_text_content$$($JSCompiler_inline_result$jscomp$10873_fexpr__68913$jscomp$inline_12659_id$jscomp$556$$,$content$jscomp$169_dimension$$),$app$render_wasm$api$set_shape_text_images$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$10873_fexpr__68913$jscomp$inline_12659_id$jscomp$556$$,$content$jscomp$169_dimension$$,!1),
$content$jscomp$169_dimension$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1671$fixed$$,$grow_type$jscomp$6_map__68912__$1$$)?$APP.$app$render_wasm$api$get_text_dimensions$cljs$0core$0IFn$0_invoke$0arity$00$$():null,$JSCompiler_inline_result$jscomp$10873_fexpr__68913$jscomp$inline_12659_id$jscomp$556$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2035$auto_height$$,null,$APP.$cljs$cst$1671$fixed$$,null],
null),null),$JSCompiler_inline_result$jscomp$10873_fexpr__68913$jscomp$inline_12659_id$jscomp$556$$=$JSCompiler_inline_result$jscomp$10873_fexpr__68913$jscomp$inline_12659_id$jscomp$556$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$10873_fexpr__68913$jscomp$inline_12659_id$jscomp$556$$.$cljs$core$IFn$_invoke$arity$1$($grow_type$jscomp$6_map__68912__$1$$):$JSCompiler_inline_result$jscomp$10873_fexpr__68913$jscomp$inline_12659_id$jscomp$556$$($grow_type$jscomp$6_map__68912__$1$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10873_fexpr__68913$jscomp$inline_12659_id$jscomp$556$$)?$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($p__68910_selrect$jscomp$65$$):$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$169_dimension$$),$APP.$cljs$cst$1522$height$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1671$fixed$$,$grow_type$jscomp$6_map__68912__$1$$)?
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($p__68910_selrect$jscomp$65$$):$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$169_dimension$$)],null)):null};
$APP.$app$main$data$workspace$wasm_text$resize_wasm_text_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$=function($map__68924__$1_p__68923$$,$content$jscomp$170_width_scale$$){$map__68924__$1_p__68923$$=$APP.$cljs$core$__destructure_map$$($map__68924__$1_p__68923$$);var $id$jscomp$557$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68924__$1_p__68923$$,$APP.$cljs$cst$266$id$$),$origin$jscomp$37_points$jscomp$76$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68924__$1_p__68923$$,
$APP.$cljs$cst$1604$points$$),$height_scale_resize_v$jscomp$2_selrect$jscomp$66$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68924__$1_p__68923$$,$APP.$cljs$cst$1605$selrect$$),$temp__5825__auto__$jscomp$205$$=$APP.$app$main$data$workspace$wasm_text$get_wasm_text_new_size$cljs$0core$0IFn$0_invoke$0arity$02$$($map__68924__$1_p__68923$$,$content$jscomp$170_width_scale$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$205$$)?($content$jscomp$170_width_scale$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto__$jscomp$205$$)/
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($height_scale_resize_v$jscomp$2_selrect$jscomp$66$$),$height_scale_resize_v$jscomp$2_selrect$jscomp$66$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto__$jscomp$205$$)/$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($height_scale_resize_v$jscomp$2_selrect$jscomp$66$$),$height_scale_resize_v$jscomp$2_selrect$jscomp$66$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$170_width_scale$$,
$height_scale_resize_v$jscomp$2_selrect$jscomp$66$$),$origin$jscomp$37_points$jscomp$76$$=$APP.$cljs$core$first$$($origin$jscomp$37_points$jscomp$76$$),$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$id$jscomp$557$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1810$modifiers$$,$APP.$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($height_scale_resize_v$jscomp$2_selrect$jscomp$66$$,$origin$jscomp$37_points$jscomp$76$$,$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$2$($map__68924__$1_p__68923$$,
$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()),$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$2$($map__68924__$1_p__68923$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()))],null)])):null};
$app$main$data$workspace$wasm_text$resize_wasm_text$$=function($id$jscomp$558$$){typeof $app$main$data$workspace$wasm_text$resize_wasm_text_68926$$==="undefined"&&($app$main$data$workspace$wasm_text$resize_wasm_text_68926$$=function($id$jscomp$559$$,$meta68927$$){this.id=$id$jscomp$559$$;this.$meta68927$=$meta68927$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$wasm_text$resize_wasm_text_68926$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$wasm_text$resize_wasm_text_68926$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3890$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text$$},$app$main$data$workspace$wasm_text$resize_wasm_text_68926$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68928$$,$meta68927__$1$$){return new $app$main$data$workspace$wasm_text$resize_wasm_text_68926$$(this.id,$meta68927__$1$$)},$app$main$data$workspace$wasm_text$resize_wasm_text_68926$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta68927$},$app$main$data$workspace$wasm_text$resize_wasm_text_68926$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$wasm_text$resize_wasm_text_68926$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2076_objects$jscomp$497_shape$jscomp$554$$,$state$jscomp$478$$){$_$jscomp$2076_objects$jscomp$497_shape$jscomp$554$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$478$$);
$_$jscomp$2076_objects$jscomp$497_shape$jscomp$554$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2076_objects$jscomp$497_shape$jscomp$554$$,this.id);return $_$jscomp$2076_objects$jscomp$497_shape$jscomp$554$$!=null&&$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2076_objects$jscomp$497_shape$jscomp$554$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1671$fixed$$,$APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2076_objects$jscomp$497_shape$jscomp$554$$))?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2076_objects$jscomp$497_shape$jscomp$554$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2076_objects$jscomp$497_shape$jscomp$554$$)))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$wasm_text$resize_wasm_text_68926$$($id$jscomp$558$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_commit$cljs$0core$0IFn$0_invoke$0arity$02$$=function($undo_group$jscomp$17$$,$undo_id$jscomp$14$$){typeof $app$main$data$workspace$wasm_text$resize_wasm_text_debounce_commit_68947$$==="undefined"&&($app$main$data$workspace$wasm_text$resize_wasm_text_debounce_commit_68947$$=function($undo_group$jscomp$18$$,$undo_id$jscomp$15$$,$meta68948$$){this.$undo_group$=$undo_group$jscomp$18$$;this.$undo_id$=$undo_id$jscomp$15$$;this.$meta68948$=$meta68948$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_commit_68947$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_commit_68947$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3891$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_commit$$},$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_commit_68947$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_68949$$,$meta68948__$1$$){return new $app$main$data$workspace$wasm_text$resize_wasm_text_debounce_commit_68947$$(this.$undo_group$,this.$undo_id$,$meta68948__$1$$)},$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_commit_68947$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68948$},$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_commit_68947$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_commit_68947$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2077_apply_opts_ids$jscomp$136$$,$modifiers$jscomp$92_state$jscomp$479$$){var $self__$jscomp$4688$$=this;$_$jscomp$2077_apply_opts_ids$jscomp$136$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$92_state$jscomp$479$$,$cljs$cst$3892$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_ids$$);var $objects$jscomp$498$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($modifiers$jscomp$92_state$jscomp$479$$);
$modifiers$jscomp$92_state$jscomp$479$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($modifiers$jscomp$93$$,$id$jscomp$560_shape$jscomp$555$$){$id$jscomp$560_shape$jscomp$555$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$498$$,$id$jscomp$560_shape$jscomp$555$$);return $id$jscomp$560_shape$jscomp$555$$!=null&&$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$560_shape$jscomp$555$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1671$fixed$$,
$APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$560_shape$jscomp$555$$))?$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$modifiers$jscomp$93$$,$APP.$app$main$data$workspace$wasm_text$resize_wasm_text_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$560_shape$jscomp$555$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$560_shape$jscomp$555$$))])):$modifiers$jscomp$93$$},
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$_$jscomp$2077_apply_opts_ids$jscomp$136$$);var $extend_tx_QMARK_$$=$self__$jscomp$4688$$.$undo_id$!=null;$_$jscomp$2077_apply_opts_ids$jscomp$136$$=function(){var $G__68955_G__68955__$1$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;$G__68955_G__68955__$1$$=$self__$jscomp$4688$$.$undo_group$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__68955_G__68955__$1$$,$APP.$cljs$cst$3138$undo_group$$,$self__$jscomp$4688$$.$undo_group$):$G__68955_G__68955__$1$$;
return $extend_tx_QMARK_$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__68955_G__68955__$1$$,$cljs$cst$3837$undo_transation_QMARK_$$,!1):$G__68955_G__68955__$1$$}();return $APP.$cljs$core$empty_QMARK_$$($modifiers$jscomp$92_state$jscomp$479$$)?$extend_tx_QMARK_$$?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($self__$jscomp$4688$$.$undo_id$)):$APP.$beicon$v2$core$empty$$():$extend_tx_QMARK_$$?$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($modifiers$jscomp$92_state$jscomp$479$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_$jscomp$2077_apply_opts_ids$jscomp$136$$]))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($self__$jscomp$4688$$.$undo_id$))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($modifiers$jscomp$92_state$jscomp$479$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_$jscomp$2077_apply_opts_ids$jscomp$136$$])))});
return new $app$main$data$workspace$wasm_text$resize_wasm_text_debounce_commit_68947$$($undo_group$jscomp$17$$,$undo_id$jscomp$14$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner$cljs$0core$0IFn$0_invoke$0arity$02$$=function($id$jscomp$562$$,$p__68960$$){var $map__68961__$1$$=$APP.$cljs$core$__destructure_map$$($p__68960$$),$undo_group$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68961__$1$$,$APP.$cljs$cst$3138$undo_group$$),$undo_id$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68961__$1$$,$APP.$cljs$cst$3646$undo_id$$),$cur_event$jscomp$2$$=Symbol();typeof $app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner_68963$$===
"undefined"&&($app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner_68963$$=function($id$jscomp$563$$,$p__68960$jscomp$1$$,$map__68961$jscomp$1$$,$undo_group$jscomp$20$$,$undo_id$jscomp$17$$,$cur_event$jscomp$3$$,$meta68964$$){this.id=$id$jscomp$563$$;this.$p__68960$=$p__68960$jscomp$1$$;this.$map__68961$=$map__68961$jscomp$1$$;this.$undo_group$=$undo_group$jscomp$20$$;this.$undo_id$=$undo_id$jscomp$17$$;this.$cur_event$=$cur_event$jscomp$3$$;this.$meta68964$=$meta68964$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner_68963$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner_68963$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3893$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_inner$$},$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner_68963$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_68965$$,$meta68964__$1$$){return new $app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner_68963$$(this.id,this.$p__68960$,this.$map__68961$,this.$undo_group$,this.$undo_id$,this.$cur_event$,$meta68964__$1$$)},$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner_68963$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68964$},$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner_68963$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner_68963$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($G__68970__$jscomp$2078$$,$state$jscomp$480$$){$G__68970__$jscomp$2078$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$480$$,$cljs$cst$3892$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_ids$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,
$APP.$cljs$core$PersistentVector$EMPTY$$),this.id);return $cljs$cst$3894$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_event$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$480$$)==null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__68970__$jscomp$2078$$,$cljs$cst$3894$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_event$$,this.$cur_event$):$G__68970__$jscomp$2078$$},$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner_68963$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner_68963$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2079_stopper$jscomp$16$$,$state$jscomp$481$$,$stream$jscomp$54$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3894$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_event$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$481$$),this.$cur_event$)?($_$jscomp$2079_stopper$jscomp$16$$=
$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3895$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize$$),$stream$jscomp$54$$),$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2079_stopper$jscomp$16$$,$APP.$beicon$v2$core$map$$(function($evt$jscomp$34$$){return $app$main$data$workspace$wasm_text$resize_wasm_text_debounce_commit$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){var $G__68976__$1$$=
$evt$jscomp$34$$==null?null:$APP.$cljs$core$meta$$($evt$jscomp$34$$);return $G__68976__$1$$==null?null:$APP.$cljs$cst$3138$undo_group$$.$cljs$core$IFn$_invoke$arity$1$($G__68976__$1$$)}(),function(){var $G__68977__$1$$=$evt$jscomp$34$$==null?null:$APP.$cljs$core$meta$$($evt$jscomp$34$$);return $G__68977__$1$$==null?null:$APP.$cljs$cst$3646$undo_id$$.$cljs$core$IFn$_invoke$arity$1$($G__68977__$1$$)}())},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$debounce$$(40,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3893$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_inner$$),
$stream$jscomp$54$$))))),(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$with_meta$$($app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner$cljs$0core$0IFn$0_invoke$0arity$02$$(this.id,null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3138$undo_group$$,this.$undo_group$,$APP.$cljs$cst$3646$undo_id$$,this.$undo_id$],null)))),(0,$APP.$beicon$v2$core$of$$)(function($p1__68956_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__68956_SHARP_$$,
$cljs$cst$3892$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_ids$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3894$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_event$$]))}))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner_68963$$($id$jscomp$562$$,$p__68960$$,$map__68961__$1$$,$undo_group$jscomp$19$$,$undo_id$jscomp$16$$,$cur_event$jscomp$2$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$wasm_text$resize_wasm_text_all$$=function($ids$jscomp$137$$){typeof $app$main$data$workspace$wasm_text$resize_wasm_text_all_68994$$==="undefined"&&($app$main$data$workspace$wasm_text$resize_wasm_text_all_68994$$=function($ids$jscomp$138$$,$meta68995$$){this.ids=$ids$jscomp$138$$;this.$meta68995$=$meta68995$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$wasm_text$resize_wasm_text_all_68994$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$wasm_text$resize_wasm_text_all_68994$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3897$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_all$$},$app$main$data$workspace$wasm_text$resize_wasm_text_all_68994$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_68996$$,$meta68995__$1$$){return new $app$main$data$workspace$wasm_text$resize_wasm_text_all_68994$$(this.ids,$meta68995__$1$$)},$app$main$data$workspace$wasm_text$resize_wasm_text_all_68994$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta68995$},$app$main$data$workspace$wasm_text$resize_wasm_text_all_68994$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$wasm_text$resize_wasm_text_all_68994$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2081_resize_stream$$,$state$jscomp$483$$,$stream$jscomp$55$$){$_$jscomp$2081_resize_stream$$=$APP.$beicon$v2$core$map$$($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$,$APP.$beicon$v2$core$from$$(this.ids));
return $APP.$cljs$core$truth_$$($cljs$cst$3632$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$483$$))?$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$constantly$$($_$jscomp$2081_resize_stream$$),$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3634$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_commit$$),$stream$jscomp$55$$))):
$_$jscomp$2081_resize_stream$$});return new $app$main$data$workspace$wasm_text$resize_wasm_text_all_68994$$($ids$jscomp$137$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$features$pointer_map$resolve_file$$=function($data$jscomp$350_p__68619$$){function $resolve_pointers$$($coll$jscomp$1097$$){return $APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$merge_map$$($resolve_pointer$$,$APP.$beicon$v2$core$from$$($APP.$cljs$core$seq$$($coll$jscomp$1097$$))))}function $resolve_pointer$$($p__68627$$){var $key$jscomp$382$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68627$$,
0,null),$val$jscomp$183$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68627$$,1,null);return $APP.$app$common$transit$pointer_QMARK_$$($val$jscomp$183$$)?$APP.$beicon$v2$core$map$$(function($p1__68618_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$key$jscomp$382$$,$p1__68618_SHARP_$$],null)},$APP.$beicon$v2$core$map$$(function($p1__68617_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__68617_SHARP_$$,
$APP.$cljs$cst$142$data$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3898$get_file_fragment$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$id$jscomp$567$$,$APP.$cljs$cst$3899$fragment_id$$,$APP.$cljs$core$_deref$$($val$jscomp$183$$)],null)))):(0,$APP.$beicon$v2$core$of$$)($p__68627$$)}var $map__68620__$1$$=$APP.$cljs$core$__destructure_map$$($data$jscomp$350_p__68619$$),$id$jscomp$567$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68620__$1$$,
$APP.$cljs$cst$266$id$$);$data$jscomp$350_p__68619$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68620__$1$$,$APP.$cljs$cst$142$data$$);return $APP.$beicon$v2$core$map$$(function($p__68633_pages_index$jscomp$1$$){var $data__$1$jscomp$16_data__$2$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68633_pages_index$jscomp$1$$,0,null);$p__68633_pages_index$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68633_pages_index$jscomp$1$$,1,null);
$data__$1$jscomp$16_data__$2$jscomp$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data__$1$jscomp$16_data__$2$jscomp$1$$,$APP.$cljs$cst$1630$pages_index$$,$p__68633_pages_index$jscomp$1$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__68620__$1$$,$APP.$cljs$cst$142$data$$,$data__$1$jscomp$16_data__$2$jscomp$1$$)},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$zip$$($resolve_pointers$$($data$jscomp$350_p__68619$$),$resolve_pointers$$($APP.$cljs$cst$1630$pages_index$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$350_p__68619$$)))))};
$APP.$app$main$data$workspace$libraries$debug_pretty_file$$=function($file_id$jscomp$129$$,$state$jscomp$484$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$129$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$484$$))?"\x3clocal\x3e":["\x3c",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$484$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1916$files$$,$file_id$jscomp$129$$,$APP.$cljs$cst$725$name$$],null))),"\x3e"].join("")};
$APP.$app$main$data$workspace$libraries$log_changes$$=function($changes$jscomp$195$$,$file$jscomp$63$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($change$jscomp$28$$){var $G__69413__$1$jscomp$inline_6786_G__69413__$2$jscomp$inline_6787_shape$jscomp$556$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$28$$))?$APP.$cljs$core$truth_$$($APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$28$$))?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$63$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$28$$),$APP.$cljs$cst$1631$objects$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$28$$)],null)):$APP.$cljs$core$truth_$$($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$28$$))?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$63$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$28$$),$APP.$cljs$cst$1631$objects$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$28$$)],null)):null:null,$prefix$jscomp$47$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$28$$))?"[C] ":"[P] ",$G__69413$jscomp$inline_6785$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$28$$),$cljs$cst$3900$raw_change$$,$change$jscomp$28$$],null);$G__69413__$1$jscomp$inline_6786_G__69413__$2$jscomp$inline_6787_shape$jscomp$556$$=$APP.$cljs$core$truth_$$($G__69413__$1$jscomp$inline_6786_G__69413__$2$jscomp$inline_6787_shape$jscomp$556$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__69413$jscomp$inline_6785$$,$APP.$cljs$cst$1811$shape$$,
[$prefix$jscomp$47$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($G__69413__$1$jscomp$inline_6786_G__69413__$2$jscomp$inline_6787_shape$jscomp$556$$))].join(""),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__69413__$1$jscomp$inline_6786_G__69413__$2$jscomp$inline_6787_shape$jscomp$556$$))])):
$G__69413$jscomp$inline_6785$$;$G__69413__$1$jscomp$inline_6786_G__69413__$2$jscomp$inline_6787_shape$jscomp$556$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$2611$obj$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$28$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__69413__$1$jscomp$inline_6786_G__69413__$2$jscomp$inline_6787_shape$jscomp$556$$,$APP.$cljs$cst$2611$obj$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2611$obj$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$28$$)),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3901$obj_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2611$obj$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$28$$))])):$G__69413__$1$jscomp$inline_6786_G__69413__$2$jscomp$inline_6787_shape$jscomp$556$$;return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2613$operations$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$28$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__69413__$1$jscomp$inline_6786_G__69413__$2$jscomp$inline_6787_shape$jscomp$556$$,
$APP.$cljs$cst$2613$operations$$,$APP.$cljs$cst$2613$operations$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$28$$)):$G__69413__$1$jscomp$inline_6786_G__69413__$2$jscomp$inline_6787_shape$jscomp$556$$},$changes$jscomp$195$$)};
$APP.$app$main$data$workspace$libraries$extract_path_if_missing$$=function($item$jscomp$86$$){var $name$jscomp$324_vec__69415$$=$app$common$path_names$split_group_name$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$86$$)),$path$jscomp$238$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$324_vec__69415$$,0,null);$name$jscomp$324_vec__69415$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$324_vec__69415$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$86$$),
$name$jscomp$324_vec__69415$$)&&$APP.$cljs$core$contains_QMARK_$$($item$jscomp$86$$,$APP.$cljs$cst$296$path$$)?$item$jscomp$86$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($item$jscomp$86$$,$APP.$cljs$cst$296$path$$,$path$jscomp$238$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,$name$jscomp$324_vec__69415$$]))};
$APP.$app$main$data$workspace$libraries$add_color$cljs$0core$0IFn$0_invoke$0arity$02$$=function($color$jscomp$59$$,$p__69427$$){var $map__69428__$1$$=$APP.$cljs$core$__destructure_map$$($p__69427$$),$rename_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__69428__$1$$,$APP.$cljs$cst$3902$rename_QMARK_$$,!0),$color__$1$jscomp$3$$=(0,$APP.$app$common$types$color$check_library_color$$)($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$59$$,
$APP.$cljs$cst$266$id$$,function($p1__69419_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__69419_SHARP_$$)?$p1__69419_SHARP_$$:$APP.$app$common$uuid$next$$()}),$APP.$cljs$cst$725$name$$,function(){var $or__5025__auto__$jscomp$798_or__5025__auto____$1$jscomp$94$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$59$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1612$image$$,$APP.$cljs$cst$725$name$$],null));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$798_or__5025__auto____$1$jscomp$94$$))return $or__5025__auto__$jscomp$798_or__5025__auto____$1$jscomp$94$$;
$or__5025__auto__$jscomp$798_or__5025__auto____$1$jscomp$94$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$59$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$798_or__5025__auto____$1$jscomp$94$$)?$or__5025__auto__$jscomp$798_or__5025__auto____$1$jscomp$94$$:$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$59$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$cst$139$type$$],null)))}())));typeof $app$main$data$workspace$libraries$add_color_69429$$==="undefined"&&($app$main$data$workspace$libraries$add_color_69429$$=function($color$jscomp$60$$,$p__69427$jscomp$1$$,$map__69428$jscomp$1$$,$rename_QMARK_$jscomp$1$$,$meta69430$$){this.color=$color$jscomp$60$$;this.$p__69427$=$p__69427$jscomp$1$$;this.$map__69428$=$map__69428$jscomp$1$$;this.$rename_QMARK_$=$rename_QMARK_$jscomp$1$$;this.$meta69430$=$meta69430$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$add_color_69429$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$add_color_69429$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3903$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_color$$},$app$main$data$workspace$libraries$add_color_69429$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69431$$,$meta69430__$1$$){return new $app$main$data$workspace$libraries$add_color_69429$$(this.color,
this.$p__69427$,this.$map__69428$,this.$rename_QMARK_$,$meta69430__$1$$)},$app$main$data$workspace$libraries$add_color_69429$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69430$},$app$main$data$workspace$libraries$add_color_69429$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$add_color_69429$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return this.color},$app$main$data$workspace$libraries$add_color_69429$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$add_color_69429$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$4706$$=this,$changes$jscomp$196$$=$APP.$app$common$files$changes_builder$add_color$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$self__$jscomp$4706$$.color);return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$truth_$$($self__$jscomp$4706$$.$rename_QMARK_$)?function($state$jscomp$485$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$485$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$3904$color_for_rename$$],null),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4706$$.color))}:null,$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$196$$))});return new $app$main$data$workspace$libraries$add_color_69429$$($color__$1$jscomp$3$$,$p__69427$$,$map__69428__$1$$,$rename_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$update_color_STAR_$$=function($changes$jscomp$inline_12661_it$jscomp$175_undo_id$jscomp$20$$,$G__69440$jscomp$inline_6795_data$jscomp$351_state$jscomp$487$$,$G__69443$jscomp$inline_6796_color$jscomp$61_color__$1$jscomp$4$$,$JSCompiler_inline_result$jscomp$1173_file_id$jscomp$130$$){$G__69440$jscomp$inline_6795_data$jscomp$351_state$jscomp$487$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($G__69440$jscomp$inline_6795_data$jscomp$351_state$jscomp$487$$);
var $JSCompiler_temp_const$jscomp$1171_changes$jscomp$197_name$jscomp$325_vec__69437$$=$app$common$path_names$split_group_name$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($G__69443$jscomp$inline_6796_color$jscomp$61_color__$1$jscomp$4$$)),$JSCompiler_temp_const$jscomp$1172_library_data$jscomp$inline_12663_path$jscomp$239_prev_color$jscomp$inline_12664$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1171_changes$jscomp$197_name$jscomp$325_vec__69437$$,
0,null);$JSCompiler_temp_const$jscomp$1171_changes$jscomp$197_name$jscomp$325_vec__69437$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1171_changes$jscomp$197_name$jscomp$325_vec__69437$$,1,null);$G__69443$jscomp$inline_6796_color$jscomp$61_color__$1$jscomp$4$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__69443$jscomp$inline_6796_color$jscomp$61_color__$1$jscomp$4$$,$APP.$cljs$cst$296$path$$,$JSCompiler_temp_const$jscomp$1172_library_data$jscomp$inline_12663_path$jscomp$239_prev_color$jscomp$inline_12664$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,$JSCompiler_temp_const$jscomp$1171_changes$jscomp$197_name$jscomp$325_vec__69437$$]));$changes$jscomp$inline_12661_it$jscomp$175_undo_id$jscomp$20$$=$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$($changes$jscomp$inline_12661_it$jscomp$175_undo_id$jscomp$20$$),$G__69440$jscomp$inline_6795_data$jscomp$351_state$jscomp$487$$);
$JSCompiler_temp_const$jscomp$1172_library_data$jscomp$inline_12663_path$jscomp$239_prev_color$jscomp$inline_12664$$=$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$inline_12661_it$jscomp$175_undo_id$jscomp$20$$));$JSCompiler_temp_const$jscomp$1172_library_data$jscomp$inline_12663_path$jscomp$239_prev_color$jscomp$inline_12664$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1172_library_data$jscomp$inline_12663_path$jscomp$239_prev_color$jscomp$inline_12664$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2212$colors$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__69443$jscomp$inline_6796_color$jscomp$61_color__$1$jscomp$4$$)],null));$JSCompiler_temp_const$jscomp$1171_changes$jscomp$197_name$jscomp$325_vec__69437$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$inline_12661_it$jscomp$175_undo_id$jscomp$20$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2626$mod_color$$,$APP.$cljs$cst$1298$color$$,$G__69443$jscomp$inline_6796_color$jscomp$61_color__$1$jscomp$4$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2626$mod_color$$,$APP.$cljs$cst$1298$color$$,$JSCompiler_temp_const$jscomp$1172_library_data$jscomp$inline_12663_path$jscomp$239_prev_color$jscomp$inline_12664$$],
null)));$changes$jscomp$inline_12661_it$jscomp$175_undo_id$jscomp$20$$=Symbol();$JSCompiler_temp_const$jscomp$1172_library_data$jscomp$inline_12663_path$jscomp$239_prev_color$jscomp$inline_12664$$=$APP.$app$main$data$workspace$undo$start_undo_transaction$$($changes$jscomp$inline_12661_it$jscomp$175_undo_id$jscomp$20$$);$JSCompiler_temp_const$jscomp$1171_changes$jscomp$197_name$jscomp$325_vec__69437$$=$APP.$app$main$data$changes$commit_changes$$($JSCompiler_temp_const$jscomp$1171_changes$jscomp$197_name$jscomp$325_vec__69437$$);
$G__69440$jscomp$inline_6795_data$jscomp$351_state$jscomp$487$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__69440$jscomp$inline_6795_data$jscomp$351_state$jscomp$487$$);$G__69443$jscomp$inline_6796_color$jscomp$61_color__$1$jscomp$4$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__69443$jscomp$inline_6796_color$jscomp$61_color__$1$jscomp$4$$);$JSCompiler_inline_result$jscomp$1173_file_id$jscomp$130$$=$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$?
$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($G__69440$jscomp$inline_6795_data$jscomp$351_state$jscomp$487$$,$JSCompiler_inline_result$jscomp$1173_file_id$jscomp$130$$,$APP.$cljs$cst$2212$colors$$,$G__69443$jscomp$inline_6796_color$jscomp$61_color__$1$jscomp$4$$):$APP.$app$main$data$workspace$libraries$sync_file$$($G__69440$jscomp$inline_6795_data$jscomp$351_state$jscomp$487$$,$JSCompiler_inline_result$jscomp$1173_file_id$jscomp$130$$,$APP.$cljs$cst$2212$colors$$,
$G__69443$jscomp$inline_6796_color$jscomp$61_color__$1$jscomp$4$$);return(0,$APP.$beicon$v2$core$of$$)($JSCompiler_temp_const$jscomp$1172_library_data$jscomp$inline_12663_path$jscomp$239_prev_color$jscomp$inline_12664$$,$JSCompiler_temp_const$jscomp$1171_changes$jscomp$197_name$jscomp$325_vec__69437$$,$JSCompiler_inline_result$jscomp$1173_file_id$jscomp$130$$,$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($changes$jscomp$inline_12661_it$jscomp$175_undo_id$jscomp$20$$))};
$APP.$app$main$data$workspace$libraries$update_color$$=function($color$jscomp$62_color__$1$jscomp$5$$,$file_id$jscomp$131$$){$color$jscomp$62_color__$1$jscomp$5$$=(0,$APP.$app$common$types$color$check_library_color$$)($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$62_color__$1$jscomp$5$$));typeof $app$main$data$workspace$libraries$update_color_69444$$==="undefined"&&($app$main$data$workspace$libraries$update_color_69444$$=function($color$jscomp$63$$,$file_id$jscomp$132$$,
$meta69445$$){this.color=$color$jscomp$63$$;this.$file_id$=$file_id$jscomp$132$$;this.$meta69445$=$meta69445$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$update_color_69444$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_color_69444$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3906$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_color$$},
$app$main$data$workspace$libraries$update_color_69444$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69446$$,$meta69445__$1$$){return new $app$main$data$workspace$libraries$update_color_69444$$(this.color,this.$file_id$,$meta69445__$1$$)},$app$main$data$workspace$libraries$update_color_69444$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69445$},$app$main$data$workspace$libraries$update_color_69444$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$libraries$update_color_69444$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$176$$,$state$jscomp$488$$){return $APP.$app$main$data$workspace$libraries$update_color_STAR_$$(this,$state$jscomp$488$$,this.color,this.$file_id$)});return new $app$main$data$workspace$libraries$update_color_69444$$($color$jscomp$62_color__$1$jscomp$5$$,$file_id$jscomp$131$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$rename_color$$=function($file_id$jscomp$135$$,$id$jscomp$568$$,$new_name$jscomp$16$$){typeof $app$main$data$workspace$libraries$rename_color_69455$$==="undefined"&&($app$main$data$workspace$libraries$rename_color_69455$$=function($file_id$jscomp$136$$,$id$jscomp$569$$,$new_name$jscomp$17$$,$meta69456$$){this.$file_id$=$file_id$jscomp$136$$;this.id=$id$jscomp$569$$;this.$new_name$=$new_name$jscomp$17$$;this.$meta69456$=$meta69456$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$rename_color_69455$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$rename_color_69455$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3908$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_rename_color$$},$app$main$data$workspace$libraries$rename_color_69455$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69457$$,
$meta69456__$1$$){return new $app$main$data$workspace$libraries$rename_color_69455$$(this.$file_id$,this.id,this.$new_name$,$meta69456__$1$$)},$app$main$data$workspace$libraries$rename_color_69455$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69456$},$app$main$data$workspace$libraries$rename_color_69455$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$rename_color_69455$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($color$jscomp$66_it$jscomp$178_new_name__$1$jscomp$1$$,$state$jscomp$490$$){$color$jscomp$66_it$jscomp$178_new_name__$1$jscomp$1$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(this.$new_name$);if($APP.$cuerdas$core$empty_QMARK_$$($color$jscomp$66_it$jscomp$178_new_name__$1$jscomp$1$$))return $APP.$beicon$v2$core$empty$$();var $data$jscomp$352$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$490$$);$color$jscomp$66_it$jscomp$178_new_name__$1$jscomp$1$$=
(0,$APP.$app$common$types$color$check_library_color$$)($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$types$library$get_color$$($data$jscomp$352$$,this.id),$APP.$cljs$cst$725$name$$,$color$jscomp$66_it$jscomp$178_new_name__$1$jscomp$1$$)));return $APP.$app$main$data$workspace$libraries$update_color_STAR_$$(this,$state$jscomp$490$$,$color$jscomp$66_it$jscomp$178_new_name__$1$jscomp$1$$,this.$file_id$)});
return new $app$main$data$workspace$libraries$rename_color_69455$$($file_id$jscomp$135$$,$id$jscomp$568$$,$new_name$jscomp$16$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$delete_color$$=function($p__69458$$){var $map__69460__$1$$=$APP.$cljs$core$__destructure_map$$($p__69458$$),$id$jscomp$570$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69460__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$workspace$libraries$delete_color_69461$$==="undefined"&&($app$main$data$workspace$libraries$delete_color_69461$$=function($p__69458$jscomp$1$$,$map__69460$jscomp$1$$,$params$jscomp$278$$,$id$jscomp$571$$,$meta69462$$){this.$p__69458$=
$p__69458$jscomp$1$$;this.$map__69460$=$map__69460$jscomp$1$$;this.params=$params$jscomp$278$$;this.id=$id$jscomp$571$$;this.$meta69462$=$meta69462$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$delete_color_69461$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$delete_color_69461$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3909$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_delete_color$$},
$app$main$data$workspace$libraries$delete_color_69461$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69463$$,$meta69462__$1$$){return new $app$main$data$workspace$libraries$delete_color_69461$$(this.$p__69458$,this.$map__69460$,this.params,this.id,$meta69462__$1$$)},$app$main$data$workspace$libraries$delete_color_69461$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69462$},$app$main$data$workspace$libraries$delete_color_69461$$.prototype.$app$main$data$event$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$delete_color_69461$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,this.id],null)},$app$main$data$workspace$libraries$delete_color_69461$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$delete_color_69461$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$198_changes$jscomp$inline_6798_data$jscomp$353_it$jscomp$179$$,
$color_id$jscomp$inline_6799_state$jscomp$491$$){$changes$jscomp$198_changes$jscomp$inline_6798_data$jscomp$353_it$jscomp$179$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($color_id$jscomp$inline_6799_state$jscomp$491$$);$changes$jscomp$198_changes$jscomp$inline_6798_data$jscomp$353_it$jscomp$179$$=$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$198_changes$jscomp$inline_6798_data$jscomp$353_it$jscomp$179$$);
$color_id$jscomp$inline_6799_state$jscomp$491$$=this.id;var $library_data$jscomp$inline_6800_prev_color$jscomp$inline_6801$$=$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$198_changes$jscomp$inline_6798_data$jscomp$353_it$jscomp$179$$));$library_data$jscomp$inline_6800_prev_color$jscomp$inline_6801$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($library_data$jscomp$inline_6800_prev_color$jscomp$inline_6801$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2212$colors$$,$color_id$jscomp$inline_6799_state$jscomp$491$$],null));$changes$jscomp$198_changes$jscomp$inline_6798_data$jscomp$353_it$jscomp$179$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$198_changes$jscomp$inline_6798_data$jscomp$353_it$jscomp$179$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2627$del_color$$,$APP.$cljs$cst$266$id$$,$color_id$jscomp$inline_6799_state$jscomp$491$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2625$add_color$$,$APP.$cljs$cst$1298$color$$,$library_data$jscomp$inline_6800_prev_color$jscomp$inline_6801$$],null)));
return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$198_changes$jscomp$inline_6798_data$jscomp$353_it$jscomp$179$$))});return new $app$main$data$workspace$libraries$delete_color_69461$$($p__69458$$,$map__69460__$1$$,$map__69460__$1$$,$id$jscomp$570$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$=function($typography$jscomp$13_typography__$1$$,$edit_QMARK_$$){$typography$jscomp$13_typography__$1$$=(0,$APP.$app$common$types$typography$check_typography$$)($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($typography$jscomp$13_typography__$1$$,$APP.$cljs$cst$266$id$$,function($p1__69481_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__69481_SHARP_$$)?$p1__69481_SHARP_$$:$APP.$app$common$uuid$next$$()}));
typeof $app$main$data$workspace$libraries$add_typography_69485$$==="undefined"&&($app$main$data$workspace$libraries$add_typography_69485$$=function($typography$jscomp$14$$,$edit_QMARK_$jscomp$1$$,$meta69486$$){this.typography=$typography$jscomp$14$$;this.$edit_QMARK_$=$edit_QMARK_$jscomp$1$$;this.$meta69486$=$meta69486$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$add_typography_69485$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$add_typography_69485$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3914$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_typography$$},$app$main$data$workspace$libraries$add_typography_69485$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69487$$,$meta69486__$1$$){return new $app$main$data$workspace$libraries$add_typography_69485$$(this.typography,this.$edit_QMARK_$,$meta69486__$1$$)},
$app$main$data$workspace$libraries$add_typography_69485$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69486$},$app$main$data$workspace$libraries$add_typography_69485$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$add_typography_69485$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return this.typography},$app$main$data$workspace$libraries$add_typography_69485$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$add_typography_69485$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$4750$$=this,$changes$jscomp$203$$=$APP.$app$common$files$changes_builder$add_typography$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$self__$jscomp$4750$$.typography);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$203$$),function($p1__69482_SHARP_$$){return $APP.$cljs$core$truth_$$($self__$jscomp$4750$$.$edit_QMARK_$)?
$APP.$cljs$core$assoc_in$$($p1__69482_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$3915$edit_typography$$],null),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4750$$.typography)):$p1__69482_SHARP_$$})});return new $app$main$data$workspace$libraries$add_typography_69485$$($typography$jscomp$13_typography__$1$$,$edit_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$do_update_tipography$$=function($changes$jscomp$inline_12666_it$jscomp$185_undo_id$jscomp$21$$,$G__69489$jscomp$inline_6803_state$jscomp$495$$,$G__69492$jscomp$inline_6804_typography$jscomp$15_typography__$1$jscomp$1$$,$JSCompiler_inline_result$jscomp$1176_file_id$jscomp$139$$){var $JSCompiler_temp_const$jscomp$1175_data$jscomp$357_library_data$jscomp$inline_12668_prev_typography$jscomp$inline_12669$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($G__69489$jscomp$inline_6803_state$jscomp$495$$);
$G__69492$jscomp$inline_6804_typography$jscomp$15_typography__$1$jscomp$1$$=$APP.$app$main$data$workspace$libraries$extract_path_if_missing$$($G__69492$jscomp$inline_6804_typography$jscomp$15_typography__$1$jscomp$1$$);$changes$jscomp$inline_12666_it$jscomp$185_undo_id$jscomp$21$$=$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$($changes$jscomp$inline_12666_it$jscomp$185_undo_id$jscomp$21$$),$JSCompiler_temp_const$jscomp$1175_data$jscomp$357_library_data$jscomp$inline_12668_prev_typography$jscomp$inline_12669$$);
$JSCompiler_temp_const$jscomp$1175_data$jscomp$357_library_data$jscomp$inline_12668_prev_typography$jscomp$inline_12669$$=$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$inline_12666_it$jscomp$185_undo_id$jscomp$21$$));$JSCompiler_temp_const$jscomp$1175_data$jscomp$357_library_data$jscomp$inline_12668_prev_typography$jscomp$inline_12669$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1175_data$jscomp$357_library_data$jscomp$inline_12668_prev_typography$jscomp$inline_12669$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2215$typographies$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__69492$jscomp$inline_6804_typography$jscomp$15_typography__$1$jscomp$1$$)],null));var $JSCompiler_temp_const$jscomp$1174_changes$jscomp$204$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$inline_12666_it$jscomp$185_undo_id$jscomp$21$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2639$mod_typography$$,$APP.$cljs$cst$1981$typography$$,$G__69492$jscomp$inline_6804_typography$jscomp$15_typography__$1$jscomp$1$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2639$mod_typography$$,$APP.$cljs$cst$1981$typography$$,$JSCompiler_temp_const$jscomp$1175_data$jscomp$357_library_data$jscomp$inline_12668_prev_typography$jscomp$inline_12669$$],
null)));$changes$jscomp$inline_12666_it$jscomp$185_undo_id$jscomp$21$$=Symbol();$JSCompiler_temp_const$jscomp$1175_data$jscomp$357_library_data$jscomp$inline_12668_prev_typography$jscomp$inline_12669$$=$APP.$app$main$data$workspace$undo$start_undo_transaction$$($changes$jscomp$inline_12666_it$jscomp$185_undo_id$jscomp$21$$);$JSCompiler_temp_const$jscomp$1174_changes$jscomp$204$$=$APP.$app$main$data$changes$commit_changes$$($JSCompiler_temp_const$jscomp$1174_changes$jscomp$204$$);$G__69489$jscomp$inline_6803_state$jscomp$495$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($G__69489$jscomp$inline_6803_state$jscomp$495$$);$G__69492$jscomp$inline_6804_typography$jscomp$15_typography__$1$jscomp$1$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__69492$jscomp$inline_6804_typography$jscomp$15_typography__$1$jscomp$1$$);$JSCompiler_inline_result$jscomp$1176_file_id$jscomp$139$$=$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$?$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($G__69489$jscomp$inline_6803_state$jscomp$495$$,
$JSCompiler_inline_result$jscomp$1176_file_id$jscomp$139$$,$APP.$cljs$cst$2215$typographies$$,$G__69492$jscomp$inline_6804_typography$jscomp$15_typography__$1$jscomp$1$$):$APP.$app$main$data$workspace$libraries$sync_file$$($G__69489$jscomp$inline_6803_state$jscomp$495$$,$JSCompiler_inline_result$jscomp$1176_file_id$jscomp$139$$,$APP.$cljs$cst$2215$typographies$$,$G__69492$jscomp$inline_6804_typography$jscomp$15_typography__$1$jscomp$1$$);return(0,$APP.$beicon$v2$core$of$$)($JSCompiler_temp_const$jscomp$1175_data$jscomp$357_library_data$jscomp$inline_12668_prev_typography$jscomp$inline_12669$$,
$JSCompiler_temp_const$jscomp$1174_changes$jscomp$204$$,$JSCompiler_inline_result$jscomp$1176_file_id$jscomp$139$$,$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($changes$jscomp$inline_12666_it$jscomp$185_undo_id$jscomp$21$$))};
$APP.$app$main$data$workspace$libraries$update_typography$$=function($typography$jscomp$16_typography__$1$jscomp$2$$,$file_id$jscomp$140$$){$typography$jscomp$16_typography__$1$jscomp$2$$=(0,$APP.$app$common$types$typography$check_typography$$)($typography$jscomp$16_typography__$1$jscomp$2$$);typeof $app$main$data$workspace$libraries$update_typography_69493$$==="undefined"&&($app$main$data$workspace$libraries$update_typography_69493$$=function($typography$jscomp$17$$,$file_id$jscomp$141$$,$meta69494$$){this.typography=
$typography$jscomp$17$$;this.$file_id$=$file_id$jscomp$141$$;this.$meta69494$=$meta69494$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$update_typography_69493$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_typography_69493$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3916$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_typography$$},
$app$main$data$workspace$libraries$update_typography_69493$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69495$$,$meta69494__$1$$){return new $app$main$data$workspace$libraries$update_typography_69493$$(this.typography,this.$file_id$,$meta69494__$1$$)},$app$main$data$workspace$libraries$update_typography_69493$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69494$},$app$main$data$workspace$libraries$update_typography_69493$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_typography_69493$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$186$$,$state$jscomp$496$$){return $app$main$data$workspace$libraries$do_update_tipography$$(this,$state$jscomp$496$$,this.typography,this.$file_id$)});return new $app$main$data$workspace$libraries$update_typography_69493$$($typography$jscomp$16_typography__$1$jscomp$2$$,$file_id$jscomp$140$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$rename_typography$$=function($file_id$jscomp$142$$,$id$jscomp$576$$,$new_name$jscomp$20$$){typeof $app$main$data$workspace$libraries$rename_typography_69496$$==="undefined"&&($app$main$data$workspace$libraries$rename_typography_69496$$=function($file_id$jscomp$143$$,$id$jscomp$577$$,$new_name$jscomp$21$$,$meta69497$$){this.$file_id$=$file_id$jscomp$143$$;this.id=$id$jscomp$577$$;this.$new_name$=$new_name$jscomp$21$$;this.$meta69497$=$meta69497$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$rename_typography_69496$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$rename_typography_69496$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3917$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_rename_typography$$},$app$main$data$workspace$libraries$rename_typography_69496$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69498$$,$meta69497__$1$$){return new $app$main$data$workspace$libraries$rename_typography_69496$$(this.$file_id$,this.id,this.$new_name$,$meta69497__$1$$)},$app$main$data$workspace$libraries$rename_typography_69496$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69497$},$app$main$data$workspace$libraries$rename_typography_69496$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$rename_typography_69496$$.prototype.$app$main$data$event$Event$_data$arity$1$=
function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$725$name$$,this.$new_name$],null)},$app$main$data$workspace$libraries$rename_typography_69496$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$rename_typography_69496$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$187_new_object$jscomp$1_path$jscomp$241$$,$state$jscomp$497$$){if(this.$new_name$!=null&&
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",this.$new_name$)){var $data$jscomp$358_object$jscomp$31$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$497$$),$name$jscomp$327_vec__69502$$=$app$common$path_names$split_group_name$$(this.$new_name$);$it$jscomp$187_new_object$jscomp$1_path$jscomp$241$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$327_vec__69502$$,0,null);$name$jscomp$327_vec__69502$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$327_vec__69502$$,
1,null);$data$jscomp$358_object$jscomp$31$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$358_object$jscomp$31$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2215$typographies$$,this.id],null));$it$jscomp$187_new_object$jscomp$1_path$jscomp$241$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($data$jscomp$358_object$jscomp$31$$,$APP.$cljs$cst$296$path$$,$it$jscomp$187_new_object$jscomp$1_path$jscomp$241$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,$name$jscomp$327_vec__69502$$]));return $app$main$data$workspace$libraries$do_update_tipography$$(this,$state$jscomp$497$$,$it$jscomp$187_new_object$jscomp$1_path$jscomp$241$$,this.$file_id$)}return null});return new $app$main$data$workspace$libraries$rename_typography_69496$$($file_id$jscomp$142$$,$id$jscomp$576$$,$new_name$jscomp$20$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$delete_typography$$=function($id$jscomp$578$$){typeof $app$main$data$workspace$libraries$delete_typography_69505$$==="undefined"&&($app$main$data$workspace$libraries$delete_typography_69505$$=function($id$jscomp$579$$,$meta69506$$){this.id=$id$jscomp$579$$;this.$meta69506$=$meta69506$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$delete_typography_69505$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$delete_typography_69505$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3918$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_delete_typography$$},$app$main$data$workspace$libraries$delete_typography_69505$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69507$$,$meta69506__$1$$){return new $app$main$data$workspace$libraries$delete_typography_69505$$(this.id,$meta69506__$1$$)},
$app$main$data$workspace$libraries$delete_typography_69505$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69506$},$app$main$data$workspace$libraries$delete_typography_69505$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$delete_typography_69505$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,this.id],null)},$app$main$data$workspace$libraries$delete_typography_69505$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$delete_typography_69505$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$205_changes$jscomp$inline_6806_data$jscomp$359_it$jscomp$188$$,$state$jscomp$498_typography_id$jscomp$inline_6807$$){$changes$jscomp$205_changes$jscomp$inline_6806_data$jscomp$359_it$jscomp$188$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$498_typography_id$jscomp$inline_6807$$);
$changes$jscomp$205_changes$jscomp$inline_6806_data$jscomp$359_it$jscomp$188$$=$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$205_changes$jscomp$inline_6806_data$jscomp$359_it$jscomp$188$$);$state$jscomp$498_typography_id$jscomp$inline_6807$$=this.id;var $library_data$jscomp$inline_6808_prev_typography$jscomp$inline_6809$$=$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$205_changes$jscomp$inline_6806_data$jscomp$359_it$jscomp$188$$));
$library_data$jscomp$inline_6808_prev_typography$jscomp$inline_6809$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($library_data$jscomp$inline_6808_prev_typography$jscomp$inline_6809$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2215$typographies$$,$state$jscomp$498_typography_id$jscomp$inline_6807$$],null));$changes$jscomp$205_changes$jscomp$inline_6806_data$jscomp$359_it$jscomp$188$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$205_changes$jscomp$inline_6806_data$jscomp$359_it$jscomp$188$$,
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2640$del_typography$$,$APP.$cljs$cst$266$id$$,$state$jscomp$498_typography_id$jscomp$inline_6807$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2638$add_typography$$,$APP.$cljs$cst$1981$typography$$,$library_data$jscomp$inline_6808_prev_typography$jscomp$inline_6809$$],
null)));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$205_changes$jscomp$inline_6806_data$jscomp$359_it$jscomp$188$$))});return new $app$main$data$workspace$libraries$delete_typography_69505$$($id$jscomp$578$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$add_component2$cljs$0core$0IFn$0_invoke$0arity$02$$=function($id_ref$$,$selected$jscomp$54$$){typeof $app$main$data$workspace$libraries$add_component2_69513$$==="undefined"&&($app$main$data$workspace$libraries$add_component2_69513$$=function($id_ref$jscomp$1$$,$selected$jscomp$55$$,$meta69514$$){this.$id_ref$=$id_ref$jscomp$1$$;this.selected=$selected$jscomp$55$$;this.$meta69514$=$meta69514$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$libraries$add_component2_69513$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$add_component2_69513$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3920$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_component2$$},$app$main$data$workspace$libraries$add_component2_69513$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69515$$,$meta69514__$1$$){return new $app$main$data$workspace$libraries$add_component2_69513$$(this.$id_ref$,
this.selected,$meta69514__$1$$)},$app$main$data$workspace$libraries$add_component2_69513$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69514$},$app$main$data$workspace$libraries$add_component2_69513$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$add_component2_69513$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"add-component",$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$count$$(this.selected)],null)},$app$main$data$workspace$libraries$add_component2_69513$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$add_component2_69513$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($file_id$jscomp$146_it$jscomp$190$$,$state$jscomp$500$$){$file_id$jscomp$146_it$jscomp$190$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$500$$);
var $page_id$jscomp$176$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$500$$),$objects$jscomp$500_root$jscomp$62$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$500$$,$file_id$jscomp$146_it$jscomp$190$$,$page_id$jscomp$176$$),$component_id$jscomp$46_shapes$jscomp$104$$=$app$main$data$workspace$groups$shapes_for_grouping$$($objects$jscomp$500_root$jscomp$62$$,this.selected),$parents$jscomp$12$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1619$parent_id$$),$component_id$jscomp$46_shapes$jscomp$104$$);if($APP.$cljs$core$empty_QMARK_$$($component_id$jscomp$46_shapes$jscomp$104$$))return null;var $changes$jscomp$207_vec__69517$$=$app$common$logic$libraries$generate_add_component$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$component_id$jscomp$46_shapes$jscomp$104$$,$objects$jscomp$500_root$jscomp$62$$,$page_id$jscomp$176$$,
$file_id$jscomp$146_it$jscomp$190$$);$objects$jscomp$500_root$jscomp$62$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$207_vec__69517$$,0,null);$component_id$jscomp$46_shapes$jscomp$104$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$207_vec__69517$$,1,null);$changes$jscomp$207_vec__69517$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$207_vec__69517$$,2,null);$APP.$cljs$core$truth_$$(this.$id_ref$)&&$APP.$cljs$core$reset_BANG_$$(this.$id_ref$,
$component_id$jscomp$46_shapes$jscomp$104$$);return $APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$207_vec__69517$$))?null:$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$207_vec__69517$$),$APP.$app$main$data$workspace$selection$select_shapes$$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$500_root$jscomp$62$$))),
$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$parents$jscomp$12$$],null))),$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$500$$,"render-wasm/v1")?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$thumbnails_wasm$render_thumbnail$$($file_id$jscomp$146_it$jscomp$190$$,$page_id$jscomp$176$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$500_root$jscomp$62$$)),
$app$main$data$workspace$thumbnails_wasm$persist_thumbnail$$($file_id$jscomp$146_it$jscomp$190$$,$page_id$jscomp$176$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$500_root$jscomp$62$$))):$APP.$beicon$v2$core$empty$$())});return new $app$main$data$workspace$libraries$add_component2_69513$$($id_ref$$,$selected$jscomp$54$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$add_component$cljs$0core$0IFn$0_invoke$0arity$02$$=function($id_ref$jscomp$2$$,$ids$jscomp$139$$){typeof $app$main$data$workspace$libraries$add_component_69525$$==="undefined"&&($app$main$data$workspace$libraries$add_component_69525$$=function($id_ref$jscomp$3$$,$ids$jscomp$140$$,$meta69526$$){this.$id_ref$=$id_ref$jscomp$3$$;this.ids=$ids$jscomp$140$$;this.$meta69526$=$meta69526$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$libraries$add_component_69525$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$add_component_69525$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3921$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_component$$},$app$main$data$workspace$libraries$add_component_69525$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69527$$,$meta69526__$1$$){return new $app$main$data$workspace$libraries$add_component_69525$$(this.$id_ref$,
this.ids,$meta69526__$1$$)},$app$main$data$workspace$libraries$add_component_69525$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69526$},$app$main$data$workspace$libraries$add_component_69525$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$add_component_69525$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$191_selected$jscomp$56$$,$selected_objects_state$jscomp$501$$){var $objects$jscomp$501$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($selected_objects_state$jscomp$501$$);$it$jscomp$191_selected$jscomp$56$$=$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$501$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$(this.ids,$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($selected_objects_state$jscomp$501$$)));$selected_objects_state$jscomp$501$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69520_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$501$$,
$p1__69520_SHARP_$$)},$it$jscomp$191_selected$jscomp$56$$);return $APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$true_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69521_SHARP_$$){return $APP.$app$common$types$container$valid_shape_for_component_QMARK_$$($objects$jscomp$501$$,$p1__69521_SHARP_$$)},$selected_objects_state$jscomp$501$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$with_meta$$($APP.$app$main$data$workspace$libraries$add_component2$cljs$0core$0IFn$0_invoke$0arity$02$$(this.$id_ref$,
$it$jscomp$191_selected$jscomp$56$$),$APP.$cljs$core$meta$$(this))):null});return new $app$main$data$workspace$libraries$add_component_69525$$($id_ref$jscomp$2$$,$ids$jscomp$139$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$rename_component$$=function($id$jscomp$581$$,$new_name$jscomp$22$$){typeof $app$main$data$workspace$libraries$rename_component_69535$$==="undefined"&&($app$main$data$workspace$libraries$rename_component_69535$$=function($id$jscomp$582$$,$new_name$jscomp$23$$,$meta69536$$){this.id=$id$jscomp$582$$;this.$new_name$=$new_name$jscomp$23$$;this.$meta69536$=$meta69536$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},
$app$main$data$workspace$libraries$rename_component_69535$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$rename_component_69535$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3923$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_rename_component$$},$app$main$data$workspace$libraries$rename_component_69535$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69537$$,$meta69536__$1$$){return new $app$main$data$workspace$libraries$rename_component_69535$$(this.id,
this.$new_name$,$meta69536__$1$$)},$app$main$data$workspace$libraries$rename_component_69535$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69536$},$app$main$data$workspace$libraries$rename_component_69535$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$rename_component_69535$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$192_new_name__$1$jscomp$3$$,$changes$jscomp$208_data$jscomp$361_state$jscomp$503$$){$it$jscomp$192_new_name__$1$jscomp$3$$=
$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(this.$new_name$);if($APP.$cuerdas$core$empty_QMARK_$$($it$jscomp$192_new_name__$1$jscomp$3$$))return $APP.$beicon$v2$core$empty$$();$changes$jscomp$208_data$jscomp$361_state$jscomp$503$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$208_data$jscomp$361_state$jscomp$503$$);$changes$jscomp$208_data$jscomp$361_state$jscomp$503$$=$APP.$app$common$logic$libraries$generate_rename_component$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
this.id,$it$jscomp$192_new_name__$1$jscomp$3$$,$changes$jscomp$208_data$jscomp$361_state$jscomp$503$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$208_data$jscomp$361_state$jscomp$503$$))});return new $app$main$data$workspace$libraries$rename_component_69535$$($id$jscomp$581$$,$new_name$jscomp$22$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$rename_component_and_main_instance$$=function($component_id$jscomp$47$$,$name$jscomp$328$$){typeof $app$main$data$workspace$libraries$rename_component_and_main_instance_69554$$==="undefined"&&($app$main$data$workspace$libraries$rename_component_and_main_instance_69554$$=function($component_id$jscomp$48$$,$name$jscomp$329$$,$meta69555$$){this.$component_id$=$component_id$jscomp$48$$;this.name=$name$jscomp$329$$;this.$meta69555$=$meta69555$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$rename_component_and_main_instance_69554$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$rename_component_and_main_instance_69554$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3924$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_rename_component_and_main_instance$$},$app$main$data$workspace$libraries$rename_component_and_main_instance_69554$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69556$$,$meta69555__$1$$){return new $app$main$data$workspace$libraries$rename_component_and_main_instance_69554$$(this.$component_id$,this.name,$meta69555__$1$$)},$app$main$data$workspace$libraries$rename_component_and_main_instance_69554$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69555$},$app$main$data$workspace$libraries$rename_component_and_main_instance_69554$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$rename_component_and_main_instance_69554$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2109_name__$1$jscomp$8_shape_id$jscomp$99_valid_QMARK_$jscomp$7$$,$component$jscomp$75_data$jscomp$362_page_id$jscomp$177_state$jscomp$504$$){$_$jscomp$2109_name__$1$jscomp$8_shape_id$jscomp$99_valid_QMARK_$jscomp$7$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(this.name);var $clean_name$$=$APP.$app$common$path_names$join_path$$($APP.$app$common$path_names$split_path$$($_$jscomp$2109_name__$1$jscomp$8_shape_id$jscomp$99_valid_QMARK_$jscomp$7$$));$_$jscomp$2109_name__$1$jscomp$8_shape_id$jscomp$99_valid_QMARK_$jscomp$7$$=
!$APP.$cuerdas$core$ends_with_QMARK_$$($_$jscomp$2109_name__$1$jscomp$8_shape_id$jscomp$99_valid_QMARK_$jscomp$7$$,"/")&&typeof $clean_name$$==="string"&&!$APP.$cuerdas$core$blank_QMARK_$$($clean_name$$);$component$jscomp$75_data$jscomp$362_page_id$jscomp$177_state$jscomp$504$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$75_data$jscomp$362_page_id$jscomp$177_state$jscomp$504$$);$component$jscomp$75_data$jscomp$362_page_id$jscomp$177_state$jscomp$504$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$75_data$jscomp$362_page_id$jscomp$177_state$jscomp$504$$,$APP.$cljs$cst$1638$components$$),this.$component_id$);return $APP.$cljs$core$truth_$$($_$jscomp$2109_name__$1$jscomp$8_shape_id$jscomp$99_valid_QMARK_$jscomp$7$$?$component$jscomp$75_data$jscomp$362_page_id$jscomp$177_state$jscomp$504$$:$_$jscomp$2109_name__$1$jscomp$8_shape_id$jscomp$99_valid_QMARK_$jscomp$7$$)?($_$jscomp$2109_name__$1$jscomp$8_shape_id$jscomp$99_valid_QMARK_$jscomp$7$$=
$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$75_data$jscomp$362_page_id$jscomp$177_state$jscomp$504$$),$component$jscomp$75_data$jscomp$362_page_id$jscomp$177_state$jscomp$504$$=$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$75_data$jscomp$362_page_id$jscomp$177_state$jscomp$504$$),$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$libraries$rename_component$$(this.$component_id$,
$clean_name$$)),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($_$jscomp$2109_name__$1$jscomp$8_shape_id$jscomp$99_valid_QMARK_$jscomp$7$$)?$component$jscomp$75_data$jscomp$362_page_id$jscomp$177_state$jscomp$504$$:$_$jscomp$2109_name__$1$jscomp$8_shape_id$jscomp$99_valid_QMARK_$jscomp$7$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$_$jscomp$2109_name__$1$jscomp$8_shape_id$jscomp$99_valid_QMARK_$jscomp$7$$],null),function($p1__69540_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__69540_SHARP_$$,$APP.$cljs$cst$725$name$$,$clean_name$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2043$page_id$$,$component$jscomp$75_data$jscomp$362_page_id$jscomp$177_state$jscomp$504$$,$APP.$cljs$cst$3141$stack_undo_QMARK_$$,!0],null))):null)):null});return new $app$main$data$workspace$libraries$rename_component_and_main_instance_69554$$($component_id$jscomp$47$$,
$name$jscomp$328$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$delete_component$$=function($p__69565$$){var $map__69566__$1$$=$APP.$cljs$core$__destructure_map$$($p__69565$$),$id$jscomp$583$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69566__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$workspace$libraries$delete_component_69567$$==="undefined"&&($app$main$data$workspace$libraries$delete_component_69567$$=function($p__69565$jscomp$1$$,$map__69566$jscomp$1$$,$id$jscomp$584$$,$meta69568$$){this.$p__69565$=
$p__69565$jscomp$1$$;this.$map__69566$=$map__69566$jscomp$1$$;this.id=$id$jscomp$584$$;this.$meta69568$=$meta69568$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$delete_component_69567$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$delete_component_69567$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3926$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_delete_component$$},
$app$main$data$workspace$libraries$delete_component_69567$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69569$$,$meta69568__$1$$){return new $app$main$data$workspace$libraries$delete_component_69567$$(this.$p__69565$,this.$map__69566$,this.id,$meta69568__$1$$)},$app$main$data$workspace$libraries$delete_component_69567$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69568$},$app$main$data$workspace$libraries$delete_component_69567$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$delete_component_69567$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($file_id$jscomp$147_it$jscomp$194_page_id$jscomp$178$$,$state$jscomp$506$$){$file_id$jscomp$147_it$jscomp$194_page_id$jscomp$178$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$506$$);var $all_parents$jscomp$10_fdata$jscomp$10$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$506$$,
$file_id$jscomp$147_it$jscomp$194_page_id$jscomp$178$$),$component$jscomp$76_root_id$jscomp$6$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($all_parents$jscomp$10_fdata$jscomp$10$$,this.id);$file_id$jscomp$147_it$jscomp$194_page_id$jscomp$178$$=$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$76_root_id$jscomp$6$$);$component$jscomp$76_root_id$jscomp$6$$=$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$76_root_id$jscomp$6$$);
var $changes$jscomp$210_page$jscomp$73_vec__69570$$=$APP.$app$main$data$helpers$get_page$$($all_parents$jscomp$10_fdata$jscomp$10$$,$file_id$jscomp$147_it$jscomp$194_page_id$jscomp$178$$),$objects$jscomp$503$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$210_page$jscomp$73_vec__69570$$),$undo_group$jscomp$23$$=$APP.$app$common$uuid$next$$(),$undo_id$jscomp$23$$=Symbol();$changes$jscomp$210_page$jscomp$73_vec__69570$$=$app$common$logic$shapes$generate_delete_shapes$cljs$0core$0IFn$0_invoke$0arity$06$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
$file_id$jscomp$147_it$jscomp$194_page_id$jscomp$178$$),$all_parents$jscomp$10_fdata$jscomp$10$$,$changes$jscomp$210_page$jscomp$73_vec__69570$$,$objects$jscomp$503$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$component$jscomp$76_root_id$jscomp$6$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3138$undo_group$$,$undo_group$jscomp$23$$,$APP.$cljs$cst$3646$undo_id$$,$undo_id$jscomp$23$$],null));$all_parents$jscomp$10_fdata$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$210_page$jscomp$73_vec__69570$$,
0,null);$changes$jscomp$210_page$jscomp$73_vec__69570$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$210_page$jscomp$73_vec__69570$$,1,null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$23$$),$app$main$data$workspace$thumbnails$clear_thumbnail$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$506$$),$file_id$jscomp$147_it$jscomp$194_page_id$jscomp$178$$,
$component$jscomp$76_root_id$jscomp$6$$,"component"),$app$main$data$comments$detach_comment_thread$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$component$jscomp$76_root_id$jscomp$6$$])),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$210_page$jscomp$73_vec__69570$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1723$ids$$,$all_parents$jscomp$10_fdata$jscomp$10$$,
$APP.$cljs$cst$3138$undo_group$$,$undo_group$jscomp$23$$],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$23$$))});return new $app$main$data$workspace$libraries$delete_component_69567$$($p__69565$$,$map__69566__$1$$,$id$jscomp$583$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$instantiate_component$cljs$0core$0IFn$0_invoke$0arity$04$$=function($file_id$jscomp$149$$,$component_id$jscomp$55$$,$position$jscomp$98$$,$p__69584$$){var $map__69585__$1$$=$APP.$cljs$core$__destructure_map$$($p__69584$$),$start_move_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69585__$1$$,$APP.$cljs$cst$3929$start_move_QMARK_$$),$initial_point$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69585__$1$$,$APP.$cljs$cst$3930$initial_point$$),
$id_ref$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69585__$1$$,$APP.$cljs$cst$3931$id_ref$$),$origin$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69585__$1$$,$APP.$cljs$cst$1786$origin$$);typeof $app$main$data$workspace$libraries$instantiate_component_69586$$==="undefined"&&($app$main$data$workspace$libraries$instantiate_component_69586$$=function($start_move_QMARK_$jscomp$1$$,$file_id$jscomp$150$$,$map__69585$jscomp$1$$,$id_ref$jscomp$5$$,$initial_point$jscomp$1$$,
$p__69584$jscomp$1$$,$component_id$jscomp$56$$,$origin$jscomp$39$$,$position$jscomp$99$$,$meta69587$$){this.$start_move_QMARK_$=$start_move_QMARK_$jscomp$1$$;this.$file_id$=$file_id$jscomp$150$$;this.$map__69585$=$map__69585$jscomp$1$$;this.$id_ref$=$id_ref$jscomp$5$$;this.$initial_point$=$initial_point$jscomp$1$$;this.$p__69584$=$p__69584$jscomp$1$$;this.$component_id$=$component_id$jscomp$56$$;this.origin=$origin$jscomp$39$$;this.position=$position$jscomp$99$$;this.$meta69587$=$meta69587$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$instantiate_component_69586$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$instantiate_component_69586$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3932$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_instantiate_component$$},$app$main$data$workspace$libraries$instantiate_component_69586$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69588$$,$meta69587__$1$$){return new $app$main$data$workspace$libraries$instantiate_component_69586$$(this.$start_move_QMARK_$,this.$file_id$,this.$map__69585$,this.$id_ref$,this.$initial_point$,this.$p__69584$,this.$component_id$,this.origin,this.position,$meta69587__$1$$)},$app$main$data$workspace$libraries$instantiate_component_69586$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69587$},$app$main$data$workspace$libraries$instantiate_component_69586$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$instantiate_component_69586$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($component$jscomp$78_it$jscomp$196_libraries$jscomp$70$$,$current_file_id$jscomp$7_state$jscomp$508$$){var $new_shape$jscomp$17_page$jscomp$74$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($current_file_id$jscomp$7_state$jscomp$508$$);$component$jscomp$78_it$jscomp$196_libraries$jscomp$70$$=$APP.$app$main$data$helpers$lookup_libraries$$($current_file_id$jscomp$7_state$jscomp$508$$);
var $changes__$1$jscomp$73_objects$jscomp$505_vec__69590$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$17_page$jscomp$74$$),$changes$jscomp$212_undo_id$jscomp$25$$=$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$17_page$jscomp$74$$)),$changes__$1$jscomp$73_objects$jscomp$505_vec__69590$$);
$current_file_id$jscomp$7_state$jscomp$508$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($current_file_id$jscomp$7_state$jscomp$508$$);$changes__$1$jscomp$73_objects$jscomp$505_vec__69590$$=$app$common$logic$libraries$generate_instantiate_component$cljs$0core$0IFn$0_invoke$0arity$012$$($changes$jscomp$212_undo_id$jscomp$25$$,$changes__$1$jscomp$73_objects$jscomp$505_vec__69590$$,this.$file_id$,this.$component_id$,this.position,$new_shape$jscomp$17_page$jscomp$74$$,$component$jscomp$78_it$jscomp$196_libraries$jscomp$70$$,
null,null,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);$new_shape$jscomp$17_page$jscomp$74$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$1$jscomp$73_objects$jscomp$505_vec__69590$$,0,null);$changes__$1$jscomp$73_objects$jscomp$505_vec__69590$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$1$jscomp$73_objects$jscomp$505_vec__69590$$,1,null);$component$jscomp$78_it$jscomp$196_libraries$jscomp$70$$=$app$common$types$container$get_component_from_shape$$($new_shape$jscomp$17_page$jscomp$74$$,
$component$jscomp$78_it$jscomp$196_libraries$jscomp$70$$);$changes$jscomp$212_undo_id$jscomp$25$$=Symbol();$APP.$cljs$core$truth_$$(this.$id_ref$)&&$APP.$cljs$core$reset_BANG_$$(this.$id_ref$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$17_page$jscomp$74$$));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"use-library-component",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,this.origin,$APP.$cljs$cst$3933$external_library$$,$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$file_id$,$current_file_id$jscomp$7_state$jscomp$508$$),$cljs$cst$3623$is_variant$$,$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$78_it$jscomp$196_libraries$jscomp$70$$)],null),$APP.$cljs$core$meta$$(this)]))),
$APP.$app$main$data$workspace$undo$start_undo_transaction$$($changes$jscomp$212_undo_id$jscomp$25$$),$APP.$app$main$data$changes$commit_changes$$($changes__$1$jscomp$73_objects$jscomp$505_vec__69590$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$17_page$jscomp$74$$)],
null)],null)),$APP.$app$main$data$workspace$selection$select_shapes$$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$17_page$jscomp$74$$))),$APP.$cljs$core$truth_$$(this.$start_move_QMARK_$)?$app$main$data$workspace$transforms$start_move$cljs$0core$0IFn$0_invoke$0arity$02$$(this.$initial_point$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$17_page$jscomp$74$$)])):
null,$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($changes$jscomp$212_undo_id$jscomp$25$$))});return new $app$main$data$workspace$libraries$instantiate_component_69586$$($start_move_QMARK_$$,$file_id$jscomp$149$$,$map__69585__$1$$,$id_ref$jscomp$4$$,$initial_point$$,$p__69584$$,$component_id$jscomp$55$$,$origin$jscomp$38$$,$position$jscomp$98$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$detach_component$$=function($id$jscomp$585$$){typeof $app$main$data$workspace$libraries$detach_component_69597$$==="undefined"&&($app$main$data$workspace$libraries$detach_component_69597$$=function($id$jscomp$586$$,$meta69598$$){this.id=$id$jscomp$586$$;this.$meta69598$=$meta69598$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$detach_component_69597$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$detach_component_69597$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3934$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_detach_component$$},$app$main$data$workspace$libraries$detach_component_69597$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69599$$,$meta69598__$1$$){return new $app$main$data$workspace$libraries$detach_component_69597$$(this.id,$meta69598__$1$$)},$app$main$data$workspace$libraries$detach_component_69597$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69598$},$app$main$data$workspace$libraries$detach_component_69597$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$detach_component_69597$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$197_page_id$jscomp$180$$,$changes$jscomp$213_libraries$jscomp$71_state$jscomp$509$$){$it$jscomp$197_page_id$jscomp$180$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$213_libraries$jscomp$71_state$jscomp$509$$);
var $fdata$jscomp$11_file_id$jscomp$151$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$213_libraries$jscomp$71_state$jscomp$509$$);$fdata$jscomp$11_file_id$jscomp$151$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$213_libraries$jscomp$71_state$jscomp$509$$,$fdata$jscomp$11_file_id$jscomp$151$$);$changes$jscomp$213_libraries$jscomp$71_state$jscomp$509$$=$APP.$app$main$data$helpers$lookup_libraries$$($changes$jscomp$213_libraries$jscomp$71_state$jscomp$509$$);
$changes$jscomp$213_libraries$jscomp$71_state$jscomp$509$$=$app$common$logic$libraries$generate_detach_component$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),this.id,$fdata$jscomp$11_file_id$jscomp$151$$,$it$jscomp$197_page_id$jscomp$180$$,$changes$jscomp$213_libraries$jscomp$71_state$jscomp$509$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$213_libraries$jscomp$71_state$jscomp$509$$))});return new $app$main$data$workspace$libraries$detach_component_69597$$($id$jscomp$585$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$go_to_local_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__69644$$){var $map__69645__$1$$=$APP.$cljs$core$__destructure_map$$($p__69644$$),$id$jscomp$588$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69645__$1$$,$APP.$cljs$cst$266$id$$),$additional_ids$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69645__$1$$,$APP.$cljs$cst$3939$additional_ids$$),$update_layout_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69645__$1$$,
$cljs$cst$3940$update_layout_QMARK_$$),$retries$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__69645__$1$$,$cljs$cst$3941$retries$$,0);typeof $app$main$data$workspace$libraries$go_to_local_component_69646$$==="undefined"&&($app$main$data$workspace$libraries$go_to_local_component_69646$$=function($p__69644$jscomp$1$$,$map__69645$jscomp$1$$,$options$jscomp$523$$,$id$jscomp$589$$,$additional_ids$jscomp$1$$,$update_layout_QMARK_$jscomp$3$$,$retries$jscomp$1$$,$meta69647$$){this.$p__69644$=
$p__69644$jscomp$1$$;this.$map__69645$=$map__69645$jscomp$1$$;this.options=$options$jscomp$523$$;this.id=$id$jscomp$589$$;this.$additional_ids$=$additional_ids$jscomp$1$$;this.$update_layout_QMARK_$=$update_layout_QMARK_$jscomp$3$$;this.$retries$=$retries$jscomp$1$$;this.$meta69647$=$meta69647$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$go_to_local_component_69646$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$libraries$go_to_local_component_69646$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3942$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_go_to_local_component$$},$app$main$data$workspace$libraries$go_to_local_component_69646$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69648$$,$meta69647__$1$$){return new $app$main$data$workspace$libraries$go_to_local_component_69646$$(this.$p__69644$,this.$map__69645$,this.options,
this.id,this.$additional_ids$,this.$update_layout_QMARK_$,this.$retries$,$meta69647__$1$$)},$app$main$data$workspace$libraries$go_to_local_component_69646$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69647$},$app$main$data$workspace$libraries$go_to_local_component_69646$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$go_to_local_component_69646$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2119_current_page_id$$,
$ids$jscomp$143_shape_id$jscomp$100_state$jscomp$512_temp__5825__auto__$jscomp$206$$,$stream$jscomp$56$$){function $redirect_to_page$$($page_id$jscomp$183$$,$ids$jscomp$145$$){return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$mapcat$$(function(){return $select_and_zoom$$($ids$jscomp$145$$)},$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3943$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_initialize_page$$),
$stream$jscomp$56$$)))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$183$$]))))}function $select_and_zoom$$($ids$jscomp$144$$){var $parent_ids$jscomp$2$$=$APP.$cljs$core$truth_$$($self__$jscomp$4829$$.$update_layout_QMARK_$)?$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__69641_SHARP_$$){return $APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$507$$,
$p1__69641_SHARP_$$))},$ids$jscomp$144$$):null;return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$477$$=$self__$jscomp$4829$$.$update_layout_QMARK_$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$477$$)?$APP.$cljs$core$empty_QMARK_$$($parent_ids$jscomp$2$$)&&$self__$jscomp$4829$$.$retries$<8:$and__5023__auto__$jscomp$477$$}())?$APP.$beicon$v2$core$delay$$(250,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$libraries$go_to_local_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$4829$$.options,
$cljs$cst$3941$retries$$,$self__$jscomp$4829$$.$retries$+1)])))):$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$select_shapes$$($ids$jscomp$144$$),$APP.$app$main$data$workspace$zoom$zoom_to_selected_shape$$),$APP.$cljs$core$truth_$$($self__$jscomp$4829$$.$update_layout_QMARK_$)?(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1723$ids$$,$parent_ids$jscomp$2$$],null))):null)}var $self__$jscomp$4829$$=this;$_$jscomp$2119_current_page_id$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($ids$jscomp$143_shape_id$jscomp$100_state$jscomp$512_temp__5825__auto__$jscomp$206$$);var $data$jscomp$363$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($ids$jscomp$143_shape_id$jscomp$100_state$jscomp$512_temp__5825__auto__$jscomp$206$$),$objects$jscomp$507$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$143_shape_id$jscomp$100_state$jscomp$512_temp__5825__auto__$jscomp$206$$,
$_$jscomp$2119_current_page_id$$);$ids$jscomp$143_shape_id$jscomp$100_state$jscomp$512_temp__5825__auto__$jscomp$206$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$363$$,$APP.$cljs$cst$1638$components$$),$self__$jscomp$4829$$.id);if($APP.$cljs$core$truth_$$($ids$jscomp$143_shape_id$jscomp$100_state$jscomp$512_temp__5825__auto__$jscomp$206$$)){var $page_id$jscomp$182$$=$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($ids$jscomp$143_shape_id$jscomp$100_state$jscomp$512_temp__5825__auto__$jscomp$206$$);
$ids$jscomp$143_shape_id$jscomp$100_state$jscomp$512_temp__5825__auto__$jscomp$206$$=$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($ids$jscomp$143_shape_id$jscomp$100_state$jscomp$512_temp__5825__auto__$jscomp$206$$);var $additional_shape_ids$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($component$jscomp$inline_6833_p1__69642_SHARP_$$){$component$jscomp$inline_6833_p1__69642_SHARP_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$363$$,
$APP.$cljs$cst$1638$components$$),$component$jscomp$inline_6833_p1__69642_SHARP_$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_6833_p1__69642_SHARP_$$),$page_id$jscomp$182$$)?$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_6833_p1__69642_SHARP_$$):null},$self__$jscomp$4829$$.$additional_ids$);$ids$jscomp$143_shape_id$jscomp$100_state$jscomp$512_temp__5825__auto__$jscomp$206$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$1$($ids$jscomp$143_shape_id$jscomp$100_state$jscomp$512_temp__5825__auto__$jscomp$206$$),$additional_shape_ids$$);return $page_id$jscomp$182$$!=null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$182$$,$_$jscomp$2119_current_page_id$$)?$select_and_zoom$$($ids$jscomp$143_shape_id$jscomp$100_state$jscomp$512_temp__5825__auto__$jscomp$206$$):$redirect_to_page$$($page_id$jscomp$182$$,
$ids$jscomp$143_shape_id$jscomp$100_state$jscomp$512_temp__5825__auto__$jscomp$206$$):null}return null});return new $app$main$data$workspace$libraries$go_to_local_component_69646$$($p__69644$$,$map__69645__$1$$,$map__69645__$1$$,$id$jscomp$588$$,$additional_ids$$,$update_layout_QMARK_$jscomp$2$$,$retries$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$library_thumbnails_fetched$$=function($thumbnails$jscomp$9$$){typeof $app$main$data$workspace$libraries$library_thumbnails_fetched_69654$$==="undefined"&&($app$main$data$workspace$libraries$library_thumbnails_fetched_69654$$=function($thumbnails$jscomp$10$$,$meta69655$$){this.$thumbnails$=$thumbnails$jscomp$10$$;this.$meta69655$=$meta69655$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$library_thumbnails_fetched_69654$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$library_thumbnails_fetched_69654$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3944$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_library_thumbnails_fetched$$},$app$main$data$workspace$libraries$library_thumbnails_fetched_69654$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69656$$,$meta69655__$1$$){return new $app$main$data$workspace$libraries$library_thumbnails_fetched_69654$$(this.$thumbnails$,
$meta69655__$1$$)},$app$main$data$workspace$libraries$library_thumbnails_fetched_69654$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69655$},$app$main$data$workspace$libraries$library_thumbnails_fetched_69654$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$library_thumbnails_fetched_69654$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2120$$,$state$jscomp$513$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$513$$,
$APP.$cljs$cst$2229$thumbnails$$,$APP.$cljs$core$merge$$,this.$thumbnails$)});return new $app$main$data$workspace$libraries$library_thumbnails_fetched_69654$$($thumbnails$jscomp$9$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$fetch_library_thumbnails$$=function($library_id$jscomp$36$$){typeof $app$main$data$workspace$libraries$fetch_library_thumbnails_69657$$==="undefined"&&($app$main$data$workspace$libraries$fetch_library_thumbnails_69657$$=function($library_id$jscomp$37$$,$meta69658$$){this.$library_id$=$library_id$jscomp$37$$;this.$meta69658$=$meta69658$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$fetch_library_thumbnails_69657$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$fetch_library_thumbnails_69657$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3945$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_fetch_library_thumbnails$$},$app$main$data$workspace$libraries$fetch_library_thumbnails_69657$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69659$$,$meta69658__$1$$){return new $app$main$data$workspace$libraries$fetch_library_thumbnails_69657$$(this.$library_id$,
$meta69658__$1$$)},$app$main$data$workspace$libraries$fetch_library_thumbnails_69657$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69658$},$app$main$data$workspace$libraries$fetch_library_thumbnails_69657$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$fetch_library_thumbnails_69657$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($app$main$data$workspace$libraries$library_thumbnails_fetched$$,
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3946$get_file_object_thumbnails$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,this.$library_id$,$APP.$cljs$cst$78$tag$$,"component"],null)))});return new $app$main$data$workspace$libraries$fetch_library_thumbnails_69657$$($library_id$jscomp$36$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$ext_library_changed$$=function($library_id$jscomp$38$$,$modified_at$jscomp$10$$,$revn$jscomp$4$$,$changes$jscomp$216$$){typeof $app$main$data$workspace$libraries$ext_library_changed_69660$$==="undefined"&&($app$main$data$workspace$libraries$ext_library_changed_69660$$=function($library_id$jscomp$39$$,$modified_at$jscomp$11$$,$revn$jscomp$5$$,$changes$jscomp$217$$,$meta69661$$){this.$library_id$=$library_id$jscomp$39$$;this.$modified_at$=$modified_at$jscomp$11$$;
this.$revn$=$revn$jscomp$5$$;this.$changes$=$changes$jscomp$217$$;this.$meta69661$=$meta69661$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$ext_library_changed_69660$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$ext_library_changed_69660$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3947$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_ext_library_changed$$},
$app$main$data$workspace$libraries$ext_library_changed_69660$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69662$$,$meta69661__$1$$){return new $app$main$data$workspace$libraries$ext_library_changed_69660$$(this.$library_id$,this.$modified_at$,this.$revn$,this.$changes$,$meta69661__$1$$)},$app$main$data$workspace$libraries$ext_library_changed_69660$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69661$},$app$main$data$workspace$libraries$ext_library_changed_69660$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$ext_library_changed_69660$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2122$$,$state$jscomp$514$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$514$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,this.$library_id$],
null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1737$modified_at$$,this.$modified_at$,$APP.$cljs$cst$2270$revn$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$revn$])),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,this.$library_id$,$APP.$cljs$cst$142$data$$],null),$APP.$app$common$files$changes$process_changes$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$changes$]))},$app$main$data$workspace$libraries$ext_library_changed_69660$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$ext_library_changed_69660$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2123_stopper_s$jscomp$1$$,$___$1$jscomp$1371$$,$stream$jscomp$57$$){$_$jscomp$2123_stopper_s$jscomp$1$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3947$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_ext_library_changed$$),$stream$jscomp$57$$);return $APP.$beicon$v2$core$take_until$$($_$jscomp$2123_stopper_s$jscomp$1$$,
$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$($app$main$data$workspace$libraries$fetch_library_thumbnails$$,$APP.$beicon$v2$core$delay$$(5E3,(0,$APP.$beicon$v2$core$of$$)(this.$library_id$)))))});return new $app$main$data$workspace$libraries$ext_library_changed_69660$$($library_id$jscomp$38$$,$modified_at$jscomp$10$$,$revn$jscomp$4$$,$changes$jscomp$216$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$update_component_thumbnail_sync$$=function($state$jscomp$517$$,$component_id$jscomp$57_page_id$jscomp$187$$,$file_id$jscomp$155$$,$tag$jscomp$87$$){var $component$jscomp$83_data$jscomp$365_root_id$jscomp$7$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$517$$,$file_id$jscomp$155$$);$component$jscomp$83_data$jscomp$365_root_id$jscomp$7$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($component$jscomp$83_data$jscomp$365_root_id$jscomp$7$$,
$component_id$jscomp$57_page_id$jscomp$187$$);$component_id$jscomp$57_page_id$jscomp$187$$=$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$83_data$jscomp$365_root_id$jscomp$7$$);$component$jscomp$83_data$jscomp$365_root_id$jscomp$7$$=$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$83_data$jscomp$365_root_id$jscomp$7$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($tag$jscomp$87$$,"component")&&$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$517$$,
"render-wasm/v1")?$APP.$app$main$data$workspace$thumbnails_wasm$render_thumbnail$$($file_id$jscomp$155$$,$component_id$jscomp$57_page_id$jscomp$187$$,$component$jscomp$83_data$jscomp$365_root_id$jscomp$7$$):$app$main$data$workspace$thumbnails$update_thumbnail$$($file_id$jscomp$155$$,$component_id$jscomp$57_page_id$jscomp$187$$,$component$jscomp$83_data$jscomp$365_root_id$jscomp$7$$,$tag$jscomp$87$$,"update-component-thumbnail-sync")};
$app$main$data$workspace$libraries$render_component_thumbnail_event$$=function($file_id$jscomp$156_file_id__$1$jscomp$3_p__69706$$){var $component_id$jscomp$58$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_id$jscomp$156_file_id__$1$jscomp$3_p__69706$$,0,null);$file_id$jscomp$156_file_id__$1$jscomp$3_p__69706$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_id$jscomp$156_file_id__$1$jscomp$3_p__69706$$,1,null);$file_id$jscomp$156_file_id__$1$jscomp$3_p__69706$$=$APP.$cljs$core$truth_$$($file_id$jscomp$156_file_id__$1$jscomp$3_p__69706$$)?
$file_id$jscomp$156_file_id__$1$jscomp$3_p__69706$$:$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return $APP.$app$main$data$workspace$libraries$update_component_thumbnail_sync$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$component_id$jscomp$58$$,$file_id$jscomp$156_file_id__$1$jscomp$3_p__69706$$,"component")};
$app$main$data$workspace$libraries$launch_component_sync$cljs$0core$0IFn$0_invoke$0arity$03$$=function($component_id$jscomp$61$$,$file_id$jscomp$161$$,$undo_group$jscomp$28$$){typeof $app$main$data$workspace$libraries$launch_component_sync_69734$$==="undefined"&&($app$main$data$workspace$libraries$launch_component_sync_69734$$=function($component_id$jscomp$62$$,$file_id$jscomp$162$$,$undo_group$jscomp$29$$,$meta69735$$){this.$component_id$=$component_id$jscomp$62$$;this.$file_id$=$file_id$jscomp$162$$;
this.$undo_group$=$undo_group$jscomp$29$$;this.$meta69735$=$meta69735$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$launch_component_sync_69734$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$launch_component_sync_69734$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3955$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_launch_component_sync$$},
$app$main$data$workspace$libraries$launch_component_sync_69734$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69736$$,$meta69735__$1$$){return new $app$main$data$workspace$libraries$launch_component_sync_69734$$(this.$component_id$,this.$file_id$,this.$undo_group$,$meta69735__$1$$)},$app$main$data$workspace$libraries$launch_component_sync_69734$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69735$},$app$main$data$workspace$libraries$launch_component_sync_69734$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$launch_component_sync_69734$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2128_current_file_id$jscomp$9$$,$state$jscomp$519_undo_id$jscomp$30$$){$_$jscomp$2128_current_file_id$jscomp$9$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$519_undo_id$jscomp$30$$);$state$jscomp$519_undo_id$jscomp$30$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($state$jscomp$519_undo_id$jscomp$30$$),
$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$?$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$($_$jscomp$2128_current_file_id$jscomp$9$$,this.$file_id$,$APP.$cljs$cst$1638$components$$,this.$component_id$,this.$undo_group$):$APP.$app$main$data$workspace$libraries$sync_file$$($_$jscomp$2128_current_file_id$jscomp$9$$,this.$file_id$,$APP.$cljs$cst$1638$components$$,this.$component_id$,this.$undo_group$),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2128_current_file_id$jscomp$9$$,
this.$file_id$)?$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$?$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$(this.$file_id$,this.$file_id$,$APP.$cljs$cst$1638$components$$,this.$component_id$,this.$undo_group$):$APP.$app$main$data$workspace$libraries$sync_file$$(this.$file_id$,this.$file_id$,$APP.$cljs$cst$1638$components$$,this.$component_id$,this.$undo_group$):null,$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($state$jscomp$519_undo_id$jscomp$30$$))});
return new $app$main$data$workspace$libraries$launch_component_sync_69734$$($component_id$jscomp$61$$,$file_id$jscomp$161$$,$undo_group$jscomp$28$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$update_component_thumbnail$$=function($component_id$jscomp$63$$,$file_id$jscomp$163$$){typeof $app$main$data$workspace$libraries$update_component_thumbnail_69750$$==="undefined"&&($app$main$data$workspace$libraries$update_component_thumbnail_69750$$=function($component_id$jscomp$64$$,$file_id$jscomp$164$$,$meta69751$$){this.$component_id$=$component_id$jscomp$64$$;this.$file_id$=$file_id$jscomp$164$$;this.$meta69751$=$meta69751$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$update_component_thumbnail_69750$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_component_thumbnail_69750$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3956$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_component_thumbnail$$},$app$main$data$workspace$libraries$update_component_thumbnail_69750$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69752$$,$meta69751__$1$$){return new $app$main$data$workspace$libraries$update_component_thumbnail_69750$$(this.$component_id$,this.$file_id$,$meta69751__$1$$)},$app$main$data$workspace$libraries$update_component_thumbnail_69750$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69751$},$app$main$data$workspace$libraries$update_component_thumbnail_69750$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_component_thumbnail_69750$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2129_data$jscomp$366_page_id$jscomp$188$$,$component$jscomp$84_root_id$jscomp$8_state$jscomp$520$$){return $APP.$app$main$features$active_feature_QMARK_$$($component$jscomp$84_root_id$jscomp$8_state$jscomp$520$$,"render-wasm/v1")?($_$jscomp$2129_data$jscomp$366_page_id$jscomp$188$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$84_root_id$jscomp$8_state$jscomp$520$$,this.$file_id$),$component$jscomp$84_root_id$jscomp$8_state$jscomp$520$$=
$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2129_data$jscomp$366_page_id$jscomp$188$$,this.$component_id$),$_$jscomp$2129_data$jscomp$366_page_id$jscomp$188$$=$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$84_root_id$jscomp$8_state$jscomp$520$$),$component$jscomp$84_root_id$jscomp$8_state$jscomp$520$$=$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$84_root_id$jscomp$8_state$jscomp$520$$),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$thumbnails_wasm$render_thumbnail$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(this.$file_id$,$_$jscomp$2129_data$jscomp$366_page_id$jscomp$188$$,$component$jscomp$84_root_id$jscomp$8_state$jscomp$520$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3798$persist_QMARK_$$,!0])))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$libraries$update_component_thumbnail_sync$$($component$jscomp$84_root_id$jscomp$8_state$jscomp$520$$,
this.$component_id$,this.$file_id$,"component"))});return new $app$main$data$workspace$libraries$update_component_thumbnail_69750$$($component_id$jscomp$63$$,$file_id$jscomp$163$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$find_shape_index$$=function($object$jscomp$32_objects$jscomp$508_or__5025__auto__$jscomp$801_shapes$jscomp$105$$,$id$jscomp$595$$,$shape_id$jscomp$104$$){$object$jscomp$32_objects$jscomp$508_or__5025__auto__$jscomp$801_shapes$jscomp$105$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($object$jscomp$32_objects$jscomp$508_or__5025__auto__$jscomp$801_shapes$jscomp$105$$,$id$jscomp$595$$);return $APP.$cljs$core$truth_$$($object$jscomp$32_objects$jscomp$508_or__5025__auto__$jscomp$801_shapes$jscomp$105$$)?
($object$jscomp$32_objects$jscomp$508_or__5025__auto__$jscomp$801_shapes$jscomp$105$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$32_objects$jscomp$508_or__5025__auto__$jscomp$801_shapes$jscomp$105$$),$object$jscomp$32_objects$jscomp$508_or__5025__auto__$jscomp$801_shapes$jscomp$105$$=$APP.$cljs$core$second$$($APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69756_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_id$jscomp$104$$,
$APP.$cljs$core$first$$($p1__69756_SHARP_$$))},$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$288$$,$shape$jscomp$559$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$559$$,$index$jscomp$288$$],null)},$object$jscomp$32_objects$jscomp$508_or__5025__auto__$jscomp$801_shapes$jscomp$105$$)))),$APP.$cljs$core$truth_$$($object$jscomp$32_objects$jscomp$508_or__5025__auto__$jscomp$801_shapes$jscomp$105$$)?
$object$jscomp$32_objects$jscomp$508_or__5025__auto__$jscomp$801_shapes$jscomp$105$$:0):null};
$APP.$app$main$data$workspace$libraries$component_swap$$=function($shape$jscomp$560$$,$file_id$jscomp$165$$,$id_new_component$jscomp$2$$,$keep_touched_QMARK_$$){typeof $app$main$data$workspace$libraries$component_swap_69768$$==="undefined"&&($app$main$data$workspace$libraries$component_swap_69768$$=function($shape$jscomp$561$$,$file_id$jscomp$166$$,$id_new_component$jscomp$3$$,$keep_touched_QMARK_$jscomp$1$$,$meta69769$$){this.shape=$shape$jscomp$561$$;this.$file_id$=$file_id$jscomp$166$$;this.$id_new_component$=
$id_new_component$jscomp$3$$;this.$keep_touched_QMARK_$=$keep_touched_QMARK_$jscomp$1$$;this.$meta69769$=$meta69769$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$component_swap_69768$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$component_swap_69768$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3957$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_component_swap$$},
$app$main$data$workspace$libraries$component_swap_69768$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69770$$,$meta69769__$1$$){return new $app$main$data$workspace$libraries$component_swap_69768$$(this.shape,this.$file_id$,this.$id_new_component$,this.$keep_touched_QMARK_$,$meta69769__$1$$)},$app$main$data$workspace$libraries$component_swap_69768$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69769$},$app$main$data$workspace$libraries$component_swap_69768$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$component_swap_69768$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$201_parent$jscomp$266_undo_id$jscomp$31$$,$state$jscomp$521$$){var $changes__$1$jscomp$74_libraries$jscomp$75$$=$APP.$app$main$data$helpers$lookup_libraries$$($state$jscomp$521$$),$page$jscomp$76_parents_of_swapped$jscomp$2_update_layout_ids$jscomp$1_vec__69780$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$521$$),
$new_shape$jscomp$18_objects$jscomp$509$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$76_parents_of_swapped$jscomp$2_update_layout_ids$jscomp$1_vec__69780$$);$it$jscomp$201_parent$jscomp$266_undo_id$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_shape$jscomp$18_objects$jscomp$509$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$(this.shape));var $ldata$jscomp$4$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$521$$,
this.$file_id$),$orig_shapes$$=$APP.$cljs$core$truth_$$(this.$keep_touched_QMARK_$)?$APP.$app$common$files$helpers$get_children_with_self$$($new_shape$jscomp$18_objects$jscomp$509$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.shape)):null,$all_parents$jscomp$11_target_cell$jscomp$7$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$201_parent$jscomp$266_undo_id$jscomp$31$$)?$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($it$jscomp$201_parent$jscomp$266_undo_id$jscomp$31$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.shape)):null,$index$jscomp$289_new_text_ids_vec__69777$$=$app$main$data$workspace$libraries$find_shape_index$$($new_shape$jscomp$18_objects$jscomp$509$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$(this.shape),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.shape)),$keep_props_values$jscomp$2_new_children_ids$$=$APP.$cljs$core$select_keys$$(this.shape,$APP.$app$common$types$component$swap_keep_attrs$$);$it$jscomp$201_parent$jscomp$266_undo_id$jscomp$31$$=
Symbol();var $undo_group$jscomp$30$$=$APP.$app$common$uuid$next$$();$index$jscomp$289_new_text_ids_vec__69777$$=$app$common$logic$libraries$generate_component_swap$$($APP.$app$common$files$changes_builder$set_undo_group$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$76_parents_of_swapped$jscomp$2_update_layout_ids$jscomp$1_vec__69780$$)),$undo_group$jscomp$30$$),$new_shape$jscomp$18_objects$jscomp$509$$,
this.shape,$ldata$jscomp$4$$,$page$jscomp$76_parents_of_swapped$jscomp$2_update_layout_ids$jscomp$1_vec__69780$$,$changes__$1$jscomp$74_libraries$jscomp$75$$,this.$id_new_component$,$index$jscomp$289_new_text_ids_vec__69777$$,$all_parents$jscomp$11_target_cell$jscomp$7$$,$keep_props_values$jscomp$2_new_children_ids$$,this.$keep_touched_QMARK_$);$new_shape$jscomp$18_objects$jscomp$509$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($index$jscomp$289_new_text_ids_vec__69777$$,0,null);$all_parents$jscomp$11_target_cell$jscomp$7$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($index$jscomp$289_new_text_ids_vec__69777$$,1,null);var $changes$jscomp$220$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($index$jscomp$289_new_text_ids_vec__69777$$,2,null),$updated_objects$$=$APP.$app$common$files$changes_builder$get_objects$$($changes$jscomp$220$$);$keep_props_values$jscomp$2_new_children_ids$$=$app$common$files$helpers$get_children_ids_with_self$$($updated_objects$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$18_objects$jscomp$509$$));
$index$jscomp$289_new_text_ids_vec__69777$$=$APP.$cljs$core$vec$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($id$jscomp$596$$){var $temp__5825__auto__$jscomp$207$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($updated_objects$$,$id$jscomp$596$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$207$$)?$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto__$jscomp$207$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1671$fixed$$,
$APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto__$jscomp$207$$))?$id$jscomp$596$$:null:null},$keep_props_values$jscomp$2_new_children_ids$$));$page$jscomp$76_parents_of_swapped$jscomp$2_update_layout_ids$jscomp$1_vec__69780$$=$APP.$cljs$core$truth_$$(this.$keep_touched_QMARK_$)?$app$common$logic$variants$generate_keep_touched$$($changes$jscomp$220$$,$new_shape$jscomp$18_objects$jscomp$509$$,this.shape,$orig_shapes$$,$page$jscomp$76_parents_of_swapped$jscomp$2_update_layout_ids$jscomp$1_vec__69780$$,
$changes__$1$jscomp$74_libraries$jscomp$75$$,$ldata$jscomp$4$$):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$changes$jscomp$220$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null);$changes__$1$jscomp$74_libraries$jscomp$75$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($page$jscomp$76_parents_of_swapped$jscomp$2_update_layout_ids$jscomp$1_vec__69780$$,0,null);$page$jscomp$76_parents_of_swapped$jscomp$2_update_layout_ids$jscomp$1_vec__69780$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($page$jscomp$76_parents_of_swapped$jscomp$2_update_layout_ids$jscomp$1_vec__69780$$,1,null);$page$jscomp$76_parents_of_swapped$jscomp$2_update_layout_ids$jscomp$1_vec__69780$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($all_parents$jscomp$11_target_cell$jscomp$7$$,$page$jscomp$76_parents_of_swapped$jscomp$2_update_layout_ids$jscomp$1_vec__69780$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$keep_props_values$jscomp$2_new_children_ids$$]));
return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($it$jscomp$201_parent$jscomp$266_undo_id$jscomp$31$$),$APP.$app$main$data$changes$commit_changes$$($changes__$1$jscomp$74_libraries$jscomp$75$$),$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$521$$,"render-wasm/v1")&&$APP.$cljs$core$seq$$($index$jscomp$289_new_text_ids_vec__69777$$)?$APP.$app$main$data$workspace$wasm_text$resize_wasm_text_all$$($index$jscomp$289_new_text_ids_vec__69777$$):
null,$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1723$ids$$,$page$jscomp$76_parents_of_swapped$jscomp$2_update_layout_ids$jscomp$1_vec__69780$$,$APP.$cljs$cst$3138$undo_group$$,$undo_group$jscomp$30$$],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($it$jscomp$201_parent$jscomp$266_undo_id$jscomp$31$$),$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$18_objects$jscomp$509$$),
!1))});return new $app$main$data$workspace$libraries$component_swap_69768$$($shape$jscomp$560$$,$file_id$jscomp$165$$,$id_new_component$jscomp$2$$,$keep_touched_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$set_updating_library$$=function($updating_QMARK_$$){typeof $app$main$data$workspace$libraries$set_updating_library_69801$$==="undefined"&&($app$main$data$workspace$libraries$set_updating_library_69801$$=function($updating_QMARK_$jscomp$1$$,$meta69802$$){this.$updating_QMARK_$=$updating_QMARK_$jscomp$1$$;this.$meta69802$=$meta69802$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$set_updating_library_69801$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$set_updating_library_69801$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3961$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_set_updating_library$$},$app$main$data$workspace$libraries$set_updating_library_69801$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69803$$,$meta69802__$1$$){return new $app$main$data$workspace$libraries$set_updating_library_69801$$(this.$updating_QMARK_$,
$meta69802__$1$$)},$app$main$data$workspace$libraries$set_updating_library_69801$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69802$},$app$main$data$workspace$libraries$set_updating_library_69801$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$set_updating_library_69801$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2133$$,$state$jscomp$523$$){return $APP.$cljs$core$truth_$$(this.$updating_QMARK_$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$523$$,$cljs$cst$2243$updating_library$$,!0):$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$523$$,$cljs$cst$2243$updating_library$$)});return new $app$main$data$workspace$libraries$set_updating_library_69801$$($updating_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$sync_file$$=function($var_args$jscomp$1278$$){switch(arguments.length){case 2:return $APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$(arguments[0],arguments[1],null,null);case 4:return $APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$(arguments[0],arguments[1],arguments[2],arguments[3]);case 5:return $APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$(arguments[0],
arguments[1],arguments[2],arguments[3],arguments[4]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$=function($file_id$jscomp$170$$,$library_id$jscomp$41$$,$asset_type$jscomp$9$$,$asset_id$jscomp$9$$){return $APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$($file_id$jscomp$170$$,$library_id$jscomp$41$$,$asset_type$jscomp$9$$,$asset_id$jscomp$9$$,null)};
$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$=function($file_id$jscomp$171$$,$library_id$jscomp$42$$,$asset_type$jscomp$10$$,$asset_id$jscomp$10$$,$undo_group$jscomp$31$$){typeof $app$main$data$workspace$libraries$sync_file_69822$$==="undefined"&&($app$main$data$workspace$libraries$sync_file_69822$$=function($file_id$jscomp$172$$,$library_id$jscomp$43$$,$asset_type$jscomp$11$$,$asset_id$jscomp$11$$,$undo_group$jscomp$32$$,$meta69823$$){this.$file_id$=$file_id$jscomp$172$$;
this.$library_id$=$library_id$jscomp$43$$;this.$asset_type$=$asset_type$jscomp$11$$;this.$asset_id$=$asset_id$jscomp$11$$;this.$undo_group$=$undo_group$jscomp$32$$;this.$meta69823$=$meta69823$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$sync_file_69822$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$sync_file_69822$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3962$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_sync_file$$},$app$main$data$workspace$libraries$sync_file_69822$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69824$$,$meta69823__$1$$){return new $app$main$data$workspace$libraries$sync_file_69822$$(this.$file_id$,this.$library_id$,this.$asset_type$,this.$asset_id$,this.$undo_group$,$meta69823__$1$$)},$app$main$data$workspace$libraries$sync_file_69822$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69823$},$app$main$data$workspace$libraries$sync_file_69822$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$sync_file_69822$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2134$$,$state$jscomp$524$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$library_id$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$524$$))&&this.$asset_id$==
null?$APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$524$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,this.$library_id$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3963$synced_at$$,$APP.$app$common$time$now$$()])):$state$jscomp$524$$},$app$main$data$workspace$libraries$sync_file_69822$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$sync_file_69822$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$202_libraries$jscomp$76$$,$state$jscomp$525$$){var $self__$jscomp$4884$$=this;if($self__$jscomp$4884$$.$file_id$!=null&&$self__$jscomp$4884$$.$library_id$!=null){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.libraries",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"SYNC-FILE"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$208$file$$,$APP.$app$main$data$workspace$libraries$debug_pretty_file$$($self__$jscomp$4884$$.$file_id$,$state$jscomp$525$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3532$library$$,$APP.$app$main$data$workspace$libraries$debug_pretty_file$$($self__$jscomp$4884$$.$library_id$,$state$jscomp$525$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2545$asset_type$$,$self__$jscomp$4884$$.$asset_type$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2544$asset_id$$,$self__$jscomp$4884$$.$asset_id$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3138$undo_group$$,$self__$jscomp$4884$$.$undo_group$],null)],null)}),null,"app.main.data.workspace.libraries",$APP.$cljs$cst$1161$info$$,!1);var $ldata$jscomp$5$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$525$$,$self__$jscomp$4884$$.$file_id$);$it$jscomp$202_libraries$jscomp$76$$=$APP.$app$main$data$helpers$lookup_libraries$$($state$jscomp$525$$);var $current_file_id$jscomp$10$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$525$$),
$changes$jscomp$221$$=$app$common$logic$libraries$generate_sync_file_changes$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$self__$jscomp$4884$$.$undo_group$,$self__$jscomp$4884$$.$asset_type$,$self__$jscomp$4884$$.$file_id$,$self__$jscomp$4884$$.$asset_id$,$self__$jscomp$4884$$.$library_id$,$it$jscomp$202_libraries$jscomp$76$$,$current_file_id$jscomp$10$$),$updated_frames$$=$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($change$jscomp$29$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69811_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__69811_SHARP_$$,
$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$29$$))},$app$common$files$changes$frames_changed$$.$cljs$core$IFn$_invoke$arity$2$($ldata$jscomp$5$$,$change$jscomp$29$$))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$221$$)])));$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.libraries",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"SYNC-FILE finished"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3949$js_SLASH_rchanges$$,$APP.$app$main$data$workspace$libraries$log_changes$$($APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$221$$),$ldata$jscomp$5$$)],null)],
null)}),null,"app.main.data.workspace.libraries",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$libraries$set_updating_library$$(!1),$APP.$app$main$data$notifications$hide$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$78$tag$$,$cljs$cst$3964$sync_dialog$$],null)]))),$APP.$cljs$core$seq$$($APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$221$$))?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$221$$)):null,$APP.$cljs$core$empty_QMARK_$$($updated_frames$$)?null:function(){var $frames_by_page$$=$APP.$cljs$core$group_by$$($APP.$cljs$cst$2043$page_id$$,$updated_frames$$);return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($frames$jscomp$15_p__69832$$){var $page_id$jscomp$189$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($frames$jscomp$15_p__69832$$,
0,null);$frames$jscomp$15_p__69832$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($frames$jscomp$15_p__69832$$,1,null);return $APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$189$$,$APP.$cljs$cst$1723$ids$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$frames$jscomp$15_p__69832$$),$APP.$cljs$cst$3138$undo_group$$,
$self__$jscomp$4884$$.$undo_group$],null))},$frames_by_page$$)),$APP.$beicon$v2$core$mapcat$$(function($shape$jscomp$562$$){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$thumbnails$clear_thumbnail$cljs$0core$0IFn$0_invoke$0arity$04$$($self__$jscomp$4884$$.$file_id$,$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$562$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$562$$),"frame"),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$562$$),
$APP.$app$common$uuid$zero$$)?null:$app$main$data$workspace$thumbnails$clear_thumbnail$cljs$0core$0IFn$0_invoke$0arity$04$$($self__$jscomp$4884$$.$file_id$,$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$562$$),$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$562$$),"frame"))},$APP.$beicon$v2$core$from$$($updated_frames$$)))}(),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4884$$.$file_id$,$self__$jscomp$4884$$.$library_id$)?
$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$timer$$)(3E3),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3965$update_file_library_sync_status$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$4884$$.$file_id$,$APP.$cljs$cst$3966$library_id$$,$self__$jscomp$4884$$.$library_id$],null))):null)}return null});return new $app$main$data$workspace$libraries$sync_file_69822$$($file_id$jscomp$171$$,$library_id$jscomp$42$$,$asset_type$jscomp$10$$,
$asset_id$jscomp$10$$,$undo_group$jscomp$31$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$assets_need_sync$cljs$0core$0IFn$0_invoke$0arity$03$$=function($library$jscomp$25$$,$file_data$jscomp$72$$,$ignore_until_y__5111__auto__$jscomp$inline_12672$$){if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$25$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$72$$))){var $sync_date_x__5110__auto__$jscomp$inline_12671$$=$cljs$cst$3963$synced_at$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$25$$);
$ignore_until_y__5111__auto__$jscomp$inline_12672$$=$APP.$cljs$core$truth_$$($ignore_until_y__5111__auto__$jscomp$inline_12672$$)?$ignore_until_y__5111__auto__$jscomp$inline_12672$$:0;$sync_date_x__5110__auto__$jscomp$inline_12671$$=$sync_date_x__5110__auto__$jscomp$inline_12671$$>$ignore_until_y__5111__auto__$jscomp$inline_12672$$?$sync_date_x__5110__auto__$jscomp$inline_12671$$:$ignore_until_y__5111__auto__$jscomp$inline_12672$$;return $APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$25$$)>
$sync_date_x__5110__auto__$jscomp$inline_12671$$?$app$common$types$file$used_assets_changed_since$$($file_data$jscomp$72$$,$library$jscomp$25$$,$sync_date_x__5110__auto__$jscomp$inline_12671$$):null}return null};
$app$main$data$workspace$libraries$notify_sync_file$$=function(){typeof $app$main$data$workspace$libraries$notify_sync_file_69861$$==="undefined"&&($app$main$data$workspace$libraries$notify_sync_file_69861$$=function($meta69862$$){this.$meta69862$=$meta69862$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$notify_sync_file_69861$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$notify_sync_file_69861$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3970$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_notify_sync_file$$},$app$main$data$workspace$libraries$notify_sync_file_69861$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69863$$,$meta69862__$1$$){return new $app$main$data$workspace$libraries$notify_sync_file_69861$$($meta69862__$1$$)},$app$main$data$workspace$libraries$notify_sync_file_69861$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69862$},$app$main$data$workspace$libraries$notify_sync_file_69861$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$notify_sync_file_69861$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2138_file$jscomp$66$$,$state$jscomp$528$$){function $do_dismiss$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$libraries$ignore_sync$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$notifications$hide$$()]))}function $do_update$$(){$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$store$emit_BANG_$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($library$jscomp$26_library_id$jscomp$inline_6846$$){var $file_id$jscomp$inline_6845$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$528$$);$library$jscomp$26_library_id$jscomp$inline_6846$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$26_library_id$jscomp$inline_6846$$);return $APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$inline_6845$$,
$library$jscomp$26_library_id$jscomp$inline_6846$$,null,null)},$libraries_need_sync$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$hide$$())}function $do_more_info$$(){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3971$libraries_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3972$starting_tab$$,"updates",$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$175$$],null))}
var $file_id$jscomp$175$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$528$$);$_$jscomp$2138_file$jscomp$66$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$528$$,$file_id$jscomp$175$$);var $file_data$jscomp$73$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2138_file$jscomp$66$$,$APP.$cljs$cst$142$data$$),$ignore_until$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2138_file$jscomp$66$$,
$cljs$cst$2585$ignore_sync_until$$),$permissions$jscomp$12$$=$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$528$$),$libraries_need_sync$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69860_SHARP_$$){return $APP.$cljs$core$seq$$($APP.$app$main$data$workspace$libraries$assets_need_sync$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__69860_SHARP_$$,$file_data$jscomp$73$$,$ignore_until$jscomp$1$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69859_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2180$library_of$$.$cljs$core$IFn$_invoke$arity$1$($p1__69859_SHARP_$$),
$file_id$jscomp$175$$)},$APP.$cljs$core$vals$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$528$$,$APP.$cljs$cst$1916$files$$))));return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$478$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$12$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$478$$)?$APP.$cljs$core$seq$$($libraries_need_sync$$):$and__5023__auto__$jscomp$478$$}())?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$dialog$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.updates.there-are-updates"),$APP.$cljs$cst$2350$controls$$,$APP.$cljs$cst$2352$inline_actions$$,$APP.$cljs$cst$2357$links$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.updates.more-info"),$APP.$cljs$cst$2354$callback$$,$do_more_info$$],null)],
null),$APP.$cljs$cst$2355$cancel$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.updates.dismiss"),$APP.$cljs$cst$2354$callback$$,$do_dismiss$$],null),$APP.$cljs$cst$924$accept$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.updates.update"),$APP.$cljs$cst$2354$callback$$,$do_update$$],null),$APP.$cljs$cst$78$tag$$,
$cljs$cst$3964$sync_dialog$$]))):null});return new $app$main$data$workspace$libraries$notify_sync_file_69861$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$touch_component$$=function($id$jscomp$597$$){typeof $app$main$data$workspace$libraries$touch_component_69873$$==="undefined"&&($app$main$data$workspace$libraries$touch_component_69873$$=function($id$jscomp$598$$,$meta69874$$){this.id=$id$jscomp$598$$;this.$meta69874$=$meta69874$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$touch_component_69873$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$touch_component_69873$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3973$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_touch_component$$},$app$main$data$workspace$libraries$touch_component_69873$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69875$$,$meta69874__$1$$){return new $app$main$data$workspace$libraries$touch_component_69873$$(this.id,$meta69874__$1$$)},$app$main$data$workspace$libraries$touch_component_69873$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69874$},$app$main$data$workspace$libraries$touch_component_69873$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.id],null)},$app$main$data$workspace$libraries$touch_component_69873$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$touch_component_69873$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$222_data$jscomp$367_it$jscomp$203$$,$state$jscomp$529$$){$changes$jscomp$222_data$jscomp$367_it$jscomp$203$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$529$$);$changes$jscomp$222_data$jscomp$367_it$jscomp$203$$=$APP.$app$common$files$changes_builder$update_component$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$222_data$jscomp$367_it$jscomp$203$$),
this.id,function($p1__69871_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__69871_SHARP_$$,$APP.$cljs$cst$1737$modified_at$$,$APP.$app$common$time$now$$())});return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1786$origin$$,this,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$222_data$jscomp$367_it$jscomp$203$$),
$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!1],null)))});return new $app$main$data$workspace$libraries$touch_component_69873$$($id$jscomp$597$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$component_changed$$=function($component_id$jscomp$65$$,$file_id$jscomp$176$$,$undo_group$jscomp$33$$){typeof $app$main$data$workspace$libraries$component_changed_69880$$==="undefined"&&($app$main$data$workspace$libraries$component_changed_69880$$=function($component_id$jscomp$66$$,$file_id$jscomp$177$$,$undo_group$jscomp$34$$,$meta69881$$){this.$component_id$=$component_id$jscomp$66$$;this.$file_id$=$file_id$jscomp$177$$;this.$undo_group$=$undo_group$jscomp$34$$;
this.$meta69881$=$meta69881$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$component_changed_69880$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$component_changed_69880$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3974$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_component_changed$$},$app$main$data$workspace$libraries$component_changed_69880$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69882$$,$meta69881__$1$$){return new $app$main$data$workspace$libraries$component_changed_69880$$(this.$component_id$,this.$file_id$,this.$undo_group$,$meta69881__$1$$)},$app$main$data$workspace$libraries$component_changed_69880$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69881$},$app$main$data$workspace$libraries$component_changed_69880$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[this.$component_id$,this.$file_id$],null)},$app$main$data$workspace$libraries$component_changed_69880$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$component_changed_69880$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$libraries$touch_component$$(this.$component_id$),$app$main$data$workspace$libraries$launch_component_sync$cljs$0core$0IFn$0_invoke$0arity$03$$(this.$component_id$,
this.$file_id$,this.$undo_group$))});return new $app$main$data$workspace$libraries$component_changed_69880$$($component_id$jscomp$65$$,$file_id$jscomp$176$$,$undo_group$jscomp$33$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$watch_component_changes$$=function(){typeof $app$main$data$workspace$libraries$watch_component_changes_69896$$==="undefined"&&($app$main$data$workspace$libraries$watch_component_changes_69896$$=function($meta69897$$){this.$meta69897$=$meta69897$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$watch_component_changes_69896$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$libraries$watch_component_changes_69896$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3975$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_watch_component_changes$$},$app$main$data$workspace$libraries$watch_component_changes_69896$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69898$$,$meta69897__$1$$){return new $app$main$data$workspace$libraries$watch_component_changes_69896$$($meta69897__$1$$)},$app$main$data$workspace$libraries$watch_component_changes_69896$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69897$},$app$main$data$workspace$libraries$watch_component_changes_69896$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$watch_component_changes_69896$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2143_stopper_s$jscomp$2$$,$___$1$jscomp$1386_notifier_s$jscomp$2_workspace_buffer_s_workspace_data_s$jscomp$1$$,$changes_s_changes_s__$1_stream$jscomp$58$$){$_$jscomp$2143_stopper_s$jscomp$2$$=
$APP.$beicon$v2$core$filter$$(function($event_type$jscomp$1$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3629$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_finalize_page$$,$event_type$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3975$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_watch_component_changes$$,$event_type$jscomp$1$$)},$APP.$beicon$v2$core$map$$($APP.$potok$v2$core$type$$,$changes_s_changes_s__$1_stream$jscomp$58$$));
$___$1$jscomp$1386_notifier_s$jscomp$2_workspace_buffer_s_workspace_data_s$jscomp$1$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$refs$workspace_data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!0],null)));$___$1$jscomp$1386_notifier_s$jscomp$2_workspace_buffer_s_workspace_data_s$jscomp$1$$=$APP.$beicon$v2$core$map$$($APP.$cljs$core$first$$,$APP.$beicon$v2$core$buffer$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$take$$($___$1$jscomp$1386_notifier_s$jscomp$2_workspace_buffer_s_workspace_data_s$jscomp$1$$),
$___$1$jscomp$1386_notifier_s$jscomp$2_workspace_buffer_s_workspace_data_s$jscomp$1$$)));$changes_s_changes_s__$1_stream$jscomp$58$$=$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,$APP.$beicon$v2$core$filter$$(function($p1__69891_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2883$local$$,$APP.$cljs$cst$193$source$$.$cljs$core$IFn$_invoke$arity$1$($p1__69891_SHARP_$$))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$app$main$data$changes$commit_QMARK_$$,
$changes_s_changes_s__$1_stream$jscomp$58$$))));$changes_s_changes_s__$1_stream$jscomp$58$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$mapcat$$(function($map__69906__$1_p__69902$$){var $event$jscomp$94_file_id$jscomp$178$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__69906__$1_p__69902$$,0,null),$old_data$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__69906__$1_p__69902$$,1,null);if($old_data$jscomp$1$$==null||$APP.$cljs$core$truth_$$($cljs$cst$3145$translation_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$94_file_id$jscomp$178$$)))return $APP.$beicon$v2$core$empty$$();
$map__69906__$1_p__69902$$=$APP.$cljs$core$__destructure_map$$($event$jscomp$94_file_id$jscomp$178$$);$event$jscomp$94_file_id$jscomp$178$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69906__$1_p__69902$$,$APP.$cljs$cst$1644$file_id$$);var $changes$jscomp$223$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69906__$1_p__69902$$,$APP.$cljs$cst$3131$changes$$),$save_undo_QMARK_$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69906__$1_p__69902$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$),
$undo_group$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69906__$1_p__69902$$,$APP.$cljs$cst$3138$undo_group$$),$changed_components$$=$event$jscomp$94_file_id$jscomp$178$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$94_file_id$jscomp$178$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($old_data$jscomp$1$$))?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$into$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$files$changes$components_changed$$,$old_data$jscomp$1$$),$changes$jscomp$223$$)):null;return $APP.$app$common$data$not_empty_QMARK_$$($changed_components$$)?$APP.$cljs$core$truth_$$($save_undo_QMARK_$jscomp$9$$)?($APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.libraries",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"detected component changes"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1723$ids$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$changed_components$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3138$undo_group$$,$undo_group$jscomp$35$$],null)],null)}),null,"app.main.data.workspace.libraries",$APP.$cljs$cst$1161$info$$,!1),$APP.$beicon$v2$core$map$$(function($p1__69892_SHARP_$$){return $app$main$data$workspace$libraries$component_changed$$($p1__69892_SHARP_$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($old_data$jscomp$1$$),$undo_group$jscomp$35$$)},$APP.$beicon$v2$core$from$$($changed_components$$))):$APP.$beicon$v2$core$map$$($app$main$data$workspace$libraries$touch_component$$,
$APP.$beicon$v2$core$from$$($changed_components$$)):$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($___$1$jscomp$1386_notifier_s$jscomp$2_workspace_buffer_s_workspace_data_s$jscomp$1$$,$changes_s_changes_s__$1_stream$jscomp$58$$)));$___$1$jscomp$1386_notifier_s$jscomp$2_workspace_buffer_s_workspace_data_s$jscomp$1$$=$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.libraries",
$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"buffer initialized"],null)],null)}),null,"app.main.data.workspace.libraries",$APP.$cljs$cst$144$trace$$,!1);return null},$APP.$beicon$v2$core$debounce$$(5E3,$changes_s_changes_s__$1_stream$jscomp$58$$));
return $APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1237$component_thumbnails$$)||$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$beicon$v2$core$take_until$$($_$jscomp$2143_stopper_s$jscomp$2$$,$APP.$beicon$v2$core$merge$$($changes_s_changes_s__$1_stream$jscomp$58$$,$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$beicon$v2$core$map$$($app$main$data$workspace$libraries$render_component_thumbnail_event$$,
$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3974$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_component_changed$$),$changes_s_changes_s__$1_stream$jscomp$58$$))):$APP.$beicon$v2$core$empty$$(),$APP.$beicon$v2$core$map$$(function($file_id$jscomp$179_p__69914$$){var $component_id$jscomp$67$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_id$jscomp$179_p__69914$$,
0,null);$file_id$jscomp$179_p__69914$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_id$jscomp$179_p__69914$$,1,null);return $app$main$data$workspace$libraries$update_component_thumbnail$$($component_id$jscomp$67$$,$file_id$jscomp$179_p__69914$$)},$APP.$beicon$v2$core$mapcat$$(function($p1__69893_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$p1__69893_SHARP_$$)},$APP.$beicon$v2$core$buffer_until$$($___$1$jscomp$1386_notifier_s$jscomp$2_workspace_buffer_s_workspace_data_s$jscomp$1$$,
$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3974$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_component_changed$$),$changes_s_changes_s__$1_stream$jscomp$58$$))))),$APP.$beicon$v2$core$map$$($app$main$data$workspace$libraries$render_component_thumbnail_event$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3973$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_touch_component$$),
$changes_s_changes_s__$1_stream$jscomp$58$$))))):null});return new $app$main$data$workspace$libraries$watch_component_changes_69896$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$libraries_fetched$$=function($file_id$jscomp$180$$,$libraries$jscomp$77$$){typeof $app$main$data$workspace$libraries$libraries_fetched_69932$$==="undefined"&&($app$main$data$workspace$libraries$libraries_fetched_69932$$=function($file_id$jscomp$181$$,$libraries$jscomp$78$$,$meta69933$$){this.$file_id$=$file_id$jscomp$181$$;this.libraries=$libraries$jscomp$78$$;this.$meta69933$=$meta69933$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$libraries$libraries_fetched_69932$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$libraries_fetched_69932$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3979$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_libraries_fetched$$},$app$main$data$workspace$libraries$libraries_fetched_69932$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69934$$,$meta69933__$1$$){return new $app$main$data$workspace$libraries$libraries_fetched_69932$$(this.$file_id$,
this.libraries,$meta69933__$1$$)},$app$main$data$workspace$libraries$libraries_fetched_69932$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69933$},$app$main$data$workspace$libraries$libraries_fetched_69932$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$libraries_fetched_69932$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2147$$,$state$jscomp$532$$){var $self__$jscomp$4917$$=this;
return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$532$$,$APP.$cljs$cst$1916$files$$,$APP.$cljs$core$merge$$,$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69931_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__69931_SHARP_$$,$APP.$cljs$cst$2180$library_of$$,$self__$jscomp$4917$$.$file_id$)},$self__$jscomp$4917$$.libraries)))});return new $app$main$data$workspace$libraries$libraries_fetched_69932$$($file_id$jscomp$180$$,
$libraries$jscomp$77$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$load_library_file$$=function($file_id$jscomp$182$$,$library_id$jscomp$44$$){typeof $app$main$data$workspace$libraries$load_library_file_69936$$==="undefined"&&($app$main$data$workspace$libraries$load_library_file_69936$$=function($file_id$jscomp$183$$,$library_id$jscomp$45$$,$meta69937$$){this.$file_id$=$file_id$jscomp$183$$;this.$library_id$=$library_id$jscomp$45$$;this.$meta69937$=$meta69937$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$libraries$load_library_file_69936$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$load_library_file_69936$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3980$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_load_library_file$$},$app$main$data$workspace$libraries$load_library_file_69936$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69938$$,$meta69937__$1$$){return new $app$main$data$workspace$libraries$load_library_file_69936$$(this.$file_id$,
this.$library_id$,$meta69937__$1$$)},$app$main$data$workspace$libraries$load_library_file_69936$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69937$},$app$main$data$workspace$libraries$load_library_file_69936$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$load_library_file_69936$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2148_features__$1$jscomp$15$$,$state$jscomp$533$$){var $self__$jscomp$4921$$=
this;$_$jscomp$2148_features__$1$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$533$$,$APP.$cljs$cst$227$features$$);return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$(function($file$jscomp$67$$){return $app$main$data$workspace$libraries$libraries_fetched$$($self__$jscomp$4921$$.$file_id$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file$jscomp$67$$],null))},$APP.$beicon$v2$core$merge_map$$($app$main$features$pointer_map$resolve_file$$,
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2274$get_file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$self__$jscomp$4921$$.$library_id$,$APP.$cljs$cst$227$features$$,$_$jscomp$2148_features__$1$jscomp$15$$],null)))),$APP.$beicon$v2$core$map$$(function($thumbnails$jscomp$11$$){return function($state__$1$jscomp$20$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state__$1$jscomp$20$$,$APP.$cljs$cst$2229$thumbnails$$,
$APP.$cljs$core$merge$$,$thumbnails$jscomp$11$$)}},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3946$get_file_object_thumbnails$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$4921$$.$library_id$,$APP.$cljs$cst$78$tag$$,"component"],null))))});return new $app$main$data$workspace$libraries$load_library_file_69936$$($file_id$jscomp$182$$,$library_id$jscomp$44$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$libraries$link_file_to_library$$=function($file_id$jscomp$184$$,$library_id$jscomp$46$$){typeof $app$main$data$workspace$libraries$attach_library_69943$$==="undefined"&&($app$main$data$workspace$libraries$attach_library_69943$$=function($file_id$jscomp$185$$,$library_id$jscomp$47$$,$meta69944$$){this.$file_id$=$file_id$jscomp$185$$;this.$library_id$=$library_id$jscomp$47$$;this.$meta69944$=$meta69944$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$libraries$attach_library_69943$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$attach_library_69943$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3981$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_attach_library$$},$app$main$data$workspace$libraries$attach_library_69943$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69945$$,$meta69944__$1$$){return new $app$main$data$workspace$libraries$attach_library_69943$$(this.$file_id$,
this.$library_id$,$meta69944__$1$$)},$app$main$data$workspace$libraries$attach_library_69943$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69944$},$app$main$data$workspace$libraries$attach_library_69943$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$attach_library_69943$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"attach-library",$APP.$cljs$cst$1644$file_id$$,this.$file_id$,$APP.$cljs$cst$3966$library_id$$,this.$library_id$],null)},$app$main$data$workspace$libraries$attach_library_69943$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$attach_library_69943$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2150$$,$state$jscomp$534$$){var $self__$jscomp$4926$$=this,$___$2$jscomp$400$$=this,$libraries$jscomp$79$$=$APP.$cljs$cst$2179$shared_files$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$534$$),
$library$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$79$$,$self__$jscomp$4926$$.$library_id$),$variants_count$$=$APP.$cljs$core$count$$($APP.$cljs$cst$2676$variants$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3982$library_summary$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$27$$))),$loaded_libraries$$=$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($lib$jscomp$9_p__69949$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lib$jscomp$9_p__69949$$,
0,null);$lib$jscomp$9_p__69949$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lib$jscomp$9_p__69949$$,1,null);return $APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($lib$jscomp$9_p__69949$$)==null||$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($lib$jscomp$9_p__69949$$))},$APP.$app$main$data$helpers$lookup_libraries$$($state$jscomp$534$$))));return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$merge_map$$(function($$__$1$jscomp$19_$__$2$jscomp$4_libraries_to_load$$){$$__$1$jscomp$19_$__$2$jscomp$4_libraries_to_load$$=
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($loaded_libraries$$,$$__$1$jscomp$19_$__$2$jscomp$4_libraries_to_load$$);$$__$1$jscomp$19_$__$2$jscomp$4_libraries_to_load$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($$__$1$jscomp$19_$__$2$jscomp$4_libraries_to_load$$,$self__$jscomp$4926$$.$library_id$);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69942_SHARP_$$){return $app$main$data$workspace$libraries$load_library_file$$($self__$jscomp$4926$$.$file_id$,
$p1__69942_SHARP_$$)},$$__$1$jscomp$19_$__$2$jscomp$4_libraries_to_load$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3983$link_file_to_library$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$4926$$.$file_id$,$APP.$cljs$cst$3966$library_id$$,$self__$jscomp$4926$$.$library_id$],null)))),(0,$APP.$beicon$v2$core$of$$)(function(){typeof $app$main$data$workspace$libraries$attach_library_finished_69953$$==="undefined"&&($app$main$data$workspace$libraries$attach_library_finished_69953$$=
function($loaded_libraries$jscomp$1$$,$file_id$jscomp$186$$,$libraries$jscomp$80$$,$library_id$jscomp$48$$,$_$jscomp$2151$$,$state$jscomp$535$$,$library$jscomp$28$$,$meta69944$jscomp$1$$,$variants_count$jscomp$1$$,$meta69954$$){this.$loaded_libraries$=$loaded_libraries$jscomp$1$$;this.$file_id$=$file_id$jscomp$186$$;this.libraries=$libraries$jscomp$80$$;this.$library_id$=$library_id$jscomp$48$$;this.$_$=$_$jscomp$2151$$;this.state=$state$jscomp$535$$;this.library=$library$jscomp$28$$;this.$meta69944$=
$meta69944$jscomp$1$$;this.$variants_count$=$variants_count$jscomp$1$$;this.$meta69954$=$meta69954$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$attach_library_finished_69953$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$attach_library_finished_69953$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3984$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_attach_library_finished$$},
$app$main$data$workspace$libraries$attach_library_finished_69953$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69955$$,$meta69954__$1$$){return new $app$main$data$workspace$libraries$attach_library_finished_69953$$(this.$loaded_libraries$,this.$file_id$,this.libraries,this.$library_id$,this.$_$,this.state,this.library,this.$meta69944$,this.$variants_count$,$meta69954__$1$$)},$app$main$data$workspace$libraries$attach_library_finished_69953$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69954$});return new $app$main$data$workspace$libraries$attach_library_finished_69953$$($loaded_libraries$$,$self__$jscomp$4926$$.$file_id$,$libraries$jscomp$79$$,$self__$jscomp$4926$$.$library_id$,$___$2$jscomp$400$$,$state$jscomp$534$$,$library$jscomp$27$$,$self__$jscomp$4926$$.$meta69944$,$variants_count$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)}()),$variants_count$$>0?$APP.$beicon$v2$core$map$$(function($library_usage$$){return $APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"attach-library-variants",$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$4926$$.$file_id$,$APP.$cljs$cst$3966$library_id$$,$self__$jscomp$4926$$.$library_id$,$cljs$cst$3985$variants_count$$,$variants_count$$,$cljs$cst$3986$library_used_in$$,$cljs$cst$3987$used_in$$.$cljs$core$IFn$_invoke$arity$1$($library_usage$$)],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3988$get_library_usage$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$4926$$.$library_id$],null))):null)});return new $app$main$data$workspace$libraries$attach_library_69943$$($file_id$jscomp$184$$,$library_id$jscomp$46$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$text$encode_style$$=function($k$jscomp$644_key$jscomp$383$$,$v$jscomp$587_val$jscomp$184$$){$k$jscomp$644_key$jscomp$383$$=$APP.$app$common$data$name$$($k$jscomp$644_key$jscomp$383$$);$v$jscomp$587_val$jscomp$184$$=$APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$587_val$jscomp$184$$,null);return["PENPOT$$$",$k$jscomp$644_key$jscomp$383$$,"$$$",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$587_val$jscomp$184$$)].join("")};
$APP.$app$common$text$attrs_to_styles$$=function($attrs$jscomp$104$$){return $APP.$cljs$core$reduce_kv$$(function($res$jscomp$42$$,$k$jscomp$646$$,$v$jscomp$589$$){return $v$jscomp$589$$!=null?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($res$jscomp$42$$,$app$common$text$encode_style$$($k$jscomp$646$$,$v$jscomp$589$$)):$res$jscomp$42$$},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$attrs$jscomp$104$$)};
$APP.$app$common$text$styles_to_attrs$$=function($styles$jscomp$14$$){return $APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$298$$,$k$jscomp$647_style$jscomp$40$$){if($APP.$cuerdas$core$starts_with_QMARK_$$($k$jscomp$647_style$jscomp$40$$,"PENPOT")){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$647_style$jscomp$40$$,"PENPOT_SELECTION"))return $APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$298$$,
$cljs$cst$3993$penpot_selection$$,!0);var $v$jscomp$590_vec__68656$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$03$$($k$jscomp$647_style$jscomp$40$$,"$$$",3);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$590_vec__68656$$,0,null);$k$jscomp$647_style$jscomp$40$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$590_vec__68656$$,1,null);$v$jscomp$590_vec__68656$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$590_vec__68656$$,2,
null);return $APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$298$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$647_style$jscomp$40$$),$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$590_vec__68656$$))}return $result$jscomp$298$$},$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$APP.$cljs$core$seq$$($styles$jscomp$14$$)))};
$app$common$text$convert_to_draft$$=function($root$jscomp$63$$){function $calc_ranges$$($map__68752__$1_p__68750_xform$jscomp$35$$){$map__68752__$1_p__68750_xform$jscomp$35$$=$APP.$cljs$core$__destructure_map$$($map__68752__$1_p__68750_xform$jscomp$35$$);var $children$jscomp$245$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68752__$1_p__68750_xform$jscomp$35$$,$APP.$cljs$cst$342$children$$);$map__68752__$1_p__68750_xform$jscomp$35$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__68697_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__68697_SHARP_$$,
$APP.$cljs$cst$302$key$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1588$text$$]))}),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$empty_QMARK_$$),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$vec$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$0$()]));return $APP.$cljs$core$persistent_BANG_$$($cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$04$$($map__68752__$1_p__68750_xform$jscomp$35$$,
$cljs$core$completing$cljs$0core$0IFn$0_invoke$0arity$02$$(function($G__68835$jscomp$inline_6865_G__68839$jscomp$inline_6868_G__68843$jscomp$inline_6872_p1__68698_SHARP__ranges__$1$jscomp$inline_6856$$,$p2__68699_SHARP__v$jscomp$inline_6852$$){a:{var $JSCompiler_inline_result$jscomp$1179_k$jscomp$inline_6851$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2__68699_SHARP__v$jscomp$inline_6852$$,0,null);$p2__68699_SHARP__v$jscomp$inline_6852$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2__68699_SHARP__v$jscomp$inline_6852$$,
1,null);for(var $G__68749$jscomp$inline_6873_G__68832$jscomp$inline_6862_G__68836$jscomp$inline_6866_G__68840$jscomp$inline_6869_children__$1$jscomp$inline_6853$$=$APP.$cljs$core$seq$$($children$jscomp$245$$),$G__68833$jscomp$inline_6863_G__68841$jscomp$inline_6870_start$jscomp$inline_6854$$=null,$G__68834$jscomp$inline_6864_G__68842$jscomp$inline_6871_offset$jscomp$inline_6855$$=0;;){var $G__68838$jscomp$inline_6867_cpoints$jscomp$inline_6861_map__68748__$1$jscomp$inline_6858_temp__5823__auto__$jscomp$inline_6857_text$jscomp$inline_6860$$=
$APP.$cljs$core$first$$($G__68749$jscomp$inline_6873_G__68832$jscomp$inline_6862_G__68836$jscomp$inline_6866_G__68840$jscomp$inline_6869_children__$1$jscomp$inline_6853$$);if($APP.$cljs$core$truth_$$($G__68838$jscomp$inline_6867_cpoints$jscomp$inline_6861_map__68748__$1$jscomp$inline_6858_temp__5823__auto__$jscomp$inline_6857_text$jscomp$inline_6860$$)){var $item$jscomp$inline_6859$$=$G__68838$jscomp$inline_6867_cpoints$jscomp$inline_6861_map__68748__$1$jscomp$inline_6858_temp__5823__auto__$jscomp$inline_6857_text$jscomp$inline_6860$$=
$APP.$cljs$core$__destructure_map$$($G__68838$jscomp$inline_6867_cpoints$jscomp$inline_6861_map__68748__$1$jscomp$inline_6858_temp__5823__auto__$jscomp$inline_6857_text$jscomp$inline_6860$$);$G__68838$jscomp$inline_6867_cpoints$jscomp$inline_6861_map__68748__$1$jscomp$inline_6858_temp__5823__auto__$jscomp$inline_6857_text$jscomp$inline_6860$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68838$jscomp$inline_6867_cpoints$jscomp$inline_6861_map__68748__$1$jscomp$inline_6858_temp__5823__auto__$jscomp$inline_6857_text$jscomp$inline_6860$$,
$APP.$cljs$cst$1588$text$$);$G__68838$jscomp$inline_6867_cpoints$jscomp$inline_6861_map__68748__$1$jscomp$inline_6858_temp__5823__auto__$jscomp$inline_6857_text$jscomp$inline_6860$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,Array.from($G__68838$jscomp$inline_6867_cpoints$jscomp$inline_6861_map__68748__$1$jscomp$inline_6858_temp__5823__auto__$jscomp$inline_6857_text$jscomp$inline_6860$$));$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p2__68699_SHARP__v$jscomp$inline_6852$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($item$jscomp$inline_6859$$,$JSCompiler_inline_result$jscomp$1179_k$jscomp$inline_6851$$,$cljs$cst$3996$app_DOT_common_DOT_text_SLASH_novalue$$))?($G__68749$jscomp$inline_6873_G__68832$jscomp$inline_6862_G__68836$jscomp$inline_6866_G__68840$jscomp$inline_6869_children__$1$jscomp$inline_6853$$=$APP.$cljs$core$rest$$($G__68749$jscomp$inline_6873_G__68832$jscomp$inline_6862_G__68836$jscomp$inline_6866_G__68840$jscomp$inline_6869_children__$1$jscomp$inline_6853$$),
$G__68833$jscomp$inline_6863_G__68841$jscomp$inline_6870_start$jscomp$inline_6854$$=$G__68833$jscomp$inline_6863_G__68841$jscomp$inline_6870_start$jscomp$inline_6854$$==null?$G__68834$jscomp$inline_6864_G__68842$jscomp$inline_6871_offset$jscomp$inline_6855$$:$G__68833$jscomp$inline_6863_G__68841$jscomp$inline_6870_start$jscomp$inline_6854$$,$G__68834$jscomp$inline_6864_G__68842$jscomp$inline_6871_offset$jscomp$inline_6855$$+=$APP.$cljs$core$count$$($G__68838$jscomp$inline_6867_cpoints$jscomp$inline_6861_map__68748__$1$jscomp$inline_6858_temp__5823__auto__$jscomp$inline_6857_text$jscomp$inline_6860$$)):
$G__68833$jscomp$inline_6863_G__68841$jscomp$inline_6870_start$jscomp$inline_6854$$!=null?($G__68749$jscomp$inline_6873_G__68832$jscomp$inline_6862_G__68836$jscomp$inline_6866_G__68840$jscomp$inline_6869_children__$1$jscomp$inline_6853$$=$APP.$cljs$core$rest$$($G__68749$jscomp$inline_6873_G__68832$jscomp$inline_6862_G__68836$jscomp$inline_6866_G__68840$jscomp$inline_6869_children__$1$jscomp$inline_6853$$),$G__68838$jscomp$inline_6867_cpoints$jscomp$inline_6861_map__68748__$1$jscomp$inline_6858_temp__5823__auto__$jscomp$inline_6857_text$jscomp$inline_6860$$=
$G__68834$jscomp$inline_6864_G__68842$jscomp$inline_6871_offset$jscomp$inline_6855$$+$APP.$cljs$core$count$$($G__68838$jscomp$inline_6867_cpoints$jscomp$inline_6861_map__68748__$1$jscomp$inline_6858_temp__5823__auto__$jscomp$inline_6857_text$jscomp$inline_6860$$),$G__68835$jscomp$inline_6865_G__68839$jscomp$inline_6868_G__68843$jscomp$inline_6872_p1__68698_SHARP__ranges__$1$jscomp$inline_6856$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__68835$jscomp$inline_6865_G__68839$jscomp$inline_6868_G__68843$jscomp$inline_6872_p1__68698_SHARP__ranges__$1$jscomp$inline_6856$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$195$offset$$,$G__68833$jscomp$inline_6863_G__68841$jscomp$inline_6870_start$jscomp$inline_6854$$,$APP.$cljs$cst$255$length$$,$G__68834$jscomp$inline_6864_G__68842$jscomp$inline_6871_offset$jscomp$inline_6855$$-$G__68833$jscomp$inline_6863_G__68841$jscomp$inline_6870_start$jscomp$inline_6854$$,$APP.$cljs$cst$1904$style$$,$app$common$text$encode_style$$($JSCompiler_inline_result$jscomp$1179_k$jscomp$inline_6851$$,$p2__68699_SHARP__v$jscomp$inline_6852$$)],
null)),$G__68833$jscomp$inline_6863_G__68841$jscomp$inline_6870_start$jscomp$inline_6854$$=null,$G__68834$jscomp$inline_6864_G__68842$jscomp$inline_6871_offset$jscomp$inline_6855$$=$G__68838$jscomp$inline_6867_cpoints$jscomp$inline_6861_map__68748__$1$jscomp$inline_6858_temp__5823__auto__$jscomp$inline_6857_text$jscomp$inline_6860$$):($G__68749$jscomp$inline_6873_G__68832$jscomp$inline_6862_G__68836$jscomp$inline_6866_G__68840$jscomp$inline_6869_children__$1$jscomp$inline_6853$$=$APP.$cljs$core$rest$$($G__68749$jscomp$inline_6873_G__68832$jscomp$inline_6862_G__68836$jscomp$inline_6866_G__68840$jscomp$inline_6869_children__$1$jscomp$inline_6853$$),
$G__68834$jscomp$inline_6864_G__68842$jscomp$inline_6871_offset$jscomp$inline_6855$$+=$APP.$cljs$core$count$$($G__68838$jscomp$inline_6867_cpoints$jscomp$inline_6861_map__68748__$1$jscomp$inline_6858_temp__5823__auto__$jscomp$inline_6857_text$jscomp$inline_6860$$))}else{$G__68749$jscomp$inline_6873_G__68832$jscomp$inline_6862_G__68836$jscomp$inline_6866_G__68840$jscomp$inline_6869_children__$1$jscomp$inline_6853$$=$G__68835$jscomp$inline_6865_G__68839$jscomp$inline_6868_G__68843$jscomp$inline_6872_p1__68698_SHARP__ranges__$1$jscomp$inline_6856$$;
$JSCompiler_inline_result$jscomp$1179_k$jscomp$inline_6851$$=$G__68833$jscomp$inline_6863_G__68841$jscomp$inline_6870_start$jscomp$inline_6854$$!=null?$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__68749$jscomp$inline_6873_G__68832$jscomp$inline_6862_G__68836$jscomp$inline_6866_G__68840$jscomp$inline_6869_children__$1$jscomp$inline_6853$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$195$offset$$,$G__68833$jscomp$inline_6863_G__68841$jscomp$inline_6870_start$jscomp$inline_6854$$,
$APP.$cljs$cst$255$length$$,$G__68834$jscomp$inline_6864_G__68842$jscomp$inline_6871_offset$jscomp$inline_6855$$-$G__68833$jscomp$inline_6863_G__68841$jscomp$inline_6870_start$jscomp$inline_6854$$,$APP.$cljs$cst$1904$style$$,$app$common$text$encode_style$$($JSCompiler_inline_result$jscomp$1179_k$jscomp$inline_6851$$,$p2__68699_SHARP__v$jscomp$inline_6852$$)],null)):$G__68749$jscomp$inline_6873_G__68832$jscomp$inline_6862_G__68836$jscomp$inline_6866_G__68840$jscomp$inline_6869_children__$1$jscomp$inline_6853$$;
break a}}$JSCompiler_inline_result$jscomp$1179_k$jscomp$inline_6851$$=void 0}return $JSCompiler_inline_result$jscomp$1179_k$jscomp$inline_6851$$}),$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$children$jscomp$245$$))}return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3995$blocks$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__68700_SHARP_$$,$JSCompiler_inline_result$jscomp$1182_map__68756__$1$jscomp$inline_6876_p2__68701_SHARP_$$){var $JSCompiler_temp_const$jscomp$1180$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$;$JSCompiler_inline_result$jscomp$1182_map__68756__$1$jscomp$inline_6876_p2__68701_SHARP_$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$1182_map__68756__$1$jscomp$inline_6876_p2__68701_SHARP_$$);var $key$jscomp$inline_6877$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1182_map__68756__$1$jscomp$inline_6876_p2__68701_SHARP_$$,$APP.$cljs$cst$302$key$$),$children$jscomp$inline_6878$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1182_map__68756__$1$jscomp$inline_6876_p2__68701_SHARP_$$,$APP.$cljs$cst$342$children$$);$JSCompiler_inline_result$jscomp$1182_map__68756__$1$jscomp$inline_6876_p2__68701_SHARP_$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$302$key$$,$key$jscomp$inline_6877$$,$APP.$cljs$cst$839$depth$$,0,$APP.$cljs$cst$1588$text$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$children$jscomp$inline_6878$$)),$APP.$cljs$cst$142$data$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_inline_result$jscomp$1182_map__68756__$1$jscomp$inline_6876_p2__68701_SHARP_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$342$children$$,$APP.$cljs$cst$139$type$$])),$APP.$cljs$cst$139$type$$,"unstyled",$cljs$cst$3997$entityRanges$$,
$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$3994$inlineStyleRanges$$,$calc_ranges$$($JSCompiler_inline_result$jscomp$1182_map__68756__$1$jscomp$inline_6876_p2__68701_SHARP_$$)],null);return $JSCompiler_temp_const$jscomp$1180$$.call($APP.$cljs$core$conj$$,$p1__68700_SHARP_$$,$JSCompiler_inline_result$jscomp$1182_map__68756__$1$jscomp$inline_6876_p2__68701_SHARP_$$)},$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__68702_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__68702_SHARP_$$),
"paragraph")},$root$jscomp$63$$)),$cljs$cst$3998$entityMap$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null)};
$app$common$text$content__GT_text_PLUS_styles$$=function($node$jscomp$309$$){return $APP.$cljs$core$reverse$$(function $app$common$text$content__GT_text_PLUS_styles_$_rec_style_text_map$$($acc$jscomp$132$$,$node__$1$jscomp$69$$,$head_style$jscomp$1_style$jscomp$41$$){var $node_style$jscomp$1$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$head_style$jscomp$1_style$jscomp$41$$,$APP.$cljs$core$select_keys$$($node__$1$jscomp$69$$,
$APP.$app$common$types$text$text_all_attrs$$)])),$head_text$jscomp$1_vec__68771$$=function(){var $or__5025__auto__$jscomp$803$$=$APP.$cljs$core$first$$($acc$jscomp$132$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$803$$)?$or__5025__auto__$jscomp$803$$:new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentArrayMap$EMPTY$$,""],null)}();$head_style$jscomp$1_style$jscomp$41$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($head_text$jscomp$1_vec__68771$$,
0,null);$head_text$jscomp$1_vec__68771$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($head_text$jscomp$1_vec__68771$$,1,null);var $new_acc$jscomp$1$$=$APP.$app$common$types$text$is_text_node_QMARK_$$($node__$1$jscomp$69$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($head_style$jscomp$1_style$jscomp$41$$,$node_style$jscomp$1$$)?$APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$node_style$jscomp$1$$,$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$2$($node__$1$jscomp$69$$,
"")],null),$acc$jscomp$132$$):$APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$node_style$jscomp$1$$,""+($head_text$jscomp$1_vec__68771$$??"")+($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($node__$1$jscomp$69$$)??"")],null),$APP.$cljs$core$rest$$($acc$jscomp$132$$)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__68762_SHARP_$$,$p2__68763_SHARP_$$){return $app$common$text$content__GT_text_PLUS_styles_$_rec_style_text_map$$($p1__68762_SHARP_$$,
$p2__68763_SHARP_$$,$node_style$jscomp$1$$)},$acc$jscomp$132$$,$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($node__$1$jscomp$69$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($node__$1$jscomp$69$$),"paragraph")?function(){var $ht$jscomp$5_vec__68778$$=$APP.$cljs$core$first$$($new_acc$jscomp$1$$),$hs$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ht$jscomp$5_vec__68778$$,0,null);$ht$jscomp$5_vec__68778$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ht$jscomp$5_vec__68778$$,1,null);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hs$jscomp$2$$,""+($ht$jscomp$5_vec__68778$$??"")+"\n"],null),$APP.$cljs$core$rest$$($new_acc$jscomp$1$$))}():$new_acc$jscomp$1$$}($APP.$cljs$core$PersistentVector$EMPTY$$,$node$jscomp$309$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$))};
$app$common$text$index_content$cljs$0core$0IFn$0_invoke$0arity$01$$=function($content$jscomp$173$$){return $app$common$text$index_content$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$173$$,null,0)};
$app$common$text$index_content$cljs$0core$0IFn$0_invoke$0arity$03$$=function($node$jscomp$310$$,$path$jscomp$242$$,$index$jscomp$291$$){var $cur_path__$1$$=($APP.$cljs$core$truth_$$($path$jscomp$242$$)?""+($path$jscomp$242$$??"")+"-":"")+($APP.$app$common$data$name$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$310$$,$APP.$cljs$cst$1588$text$$))??"")+"-"+($index$jscomp$291$$??"");return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$310$$,
$cljs$cst$3999$$id$$,$cur_path__$1$$),$APP.$cljs$cst$342$children$$,function($children$jscomp$247$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($node__$1$jscomp$70_p__68786$$){var $idx$jscomp$92$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($node__$1$jscomp$70_p__68786$$,0,null);$node__$1$jscomp$70_p__68786$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($node__$1$jscomp$70_p__68786$$,1,null);return $app$common$text$index_content$cljs$0core$0IFn$0_invoke$0arity$03$$($node__$1$jscomp$70_p__68786$$,
$cur_path__$1$$,$idx$jscomp$92$$)},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($children$jscomp$247$$))})};
$APP.$app$util$text_editor$immutable_map__GT_map$$=function($data$jscomp$371_obj$jscomp$207$$){$data$jscomp$371_obj$jscomp$207$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p__68804_v$jscomp$593$$){var $k$jscomp$650$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68804_v$jscomp$593$$,0,null);$p__68804_v$jscomp$593$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__68804_v$jscomp$593$$,
1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$650$$),$p__68804_v$jscomp$593$$],null)}),$APP.$cljs$core$seq$$($data$jscomp$371_obj$jscomp$207$$));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$371_obj$jscomp$207$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$371_obj$jscomp$207$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!0])))};$APP.$app$util$text_editor$import_content$$=function($content$jscomp$176$$){return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.convertFromRaw($APP.$cljs$core$clj__GT_js$$($app$common$text$convert_to_draft$$($content$jscomp$176$$)))};
$APP.$app$util$text_editor$get_editor_current_block_data$$=function($block$jscomp$4_state$jscomp$541$$){$block$jscomp$4_state$jscomp$541$$=$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.getCurrentBlock($block$jscomp$4_state$jscomp$541$$);return $APP.$app$util$text_editor$immutable_map__GT_map$$($block$jscomp$4_state$jscomp$541$$.getData())};
$APP.$app$util$text_editor$get_editor_current_inline_styles$$=function($state$jscomp$543$$){return $APP.$cljs$core$truth_$$($APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.isCurrentEmpty($state$jscomp$543$$))?$APP.$app$util$text_editor$get_editor_current_block_data$$($state$jscomp$543$$):$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$text$styles_to_attrs$$($state$jscomp$543$$.getCurrentInlineStyle()),$APP.$cljs$cst$1763$text_align$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1764$text_direction$$]))};
$APP.$app$util$text_editor$update_editor_current_block_data$$=function($state$jscomp$544$$,$attrs$jscomp$106$$){return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.updateCurrentBlockData($state$jscomp$544$$,$APP.$cljs$core$clj__GT_js$$($attrs$jscomp$106$$))};
$app$util$text_editor$update_editor_current_inline_styles$$=function($selection_after_apply_state$jscomp$545$$,$attrs$jscomp$107$$){var $state__$1$jscomp$21_state__$2$jscomp$2$$=$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.applyInlineStyle($selection_after_apply_state$jscomp$545$$,$APP.$app$common$text$attrs_to_styles$$($attrs$jscomp$107$$));$selection_after_apply_state$jscomp$545$$=$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.getSelection($state__$1$jscomp$21_state__$2$jscomp$2$$);var $selected$jscomp$59$$=
$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.getSelectedBlocks($state__$1$jscomp$21_state__$2$jscomp$2$$);$state__$1$jscomp$21_state__$2$jscomp$2$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($state__$1$jscomp$22$$,$block_key$$){if($APP.$cljs$core$empty_QMARK_$$($APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.getBlockContent($state__$1$jscomp$22$$,$block_key$$)))return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.updateBlockData($state__$1$jscomp$22$$,$block_key$$,
$APP.$cljs$core$clj__GT_js$$($attrs$jscomp$107$$));var $attrs__$1$jscomp$16$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$text$styles_to_attrs$$($APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.getInlineStyle($state__$1$jscomp$22$$,$block_key$$,0)),$APP.$cljs$cst$1763$text_align$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1764$text_direction$$]));return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.updateBlockData($state__$1$jscomp$22$$,
$block_key$$,$APP.$cljs$core$clj__GT_js$$($attrs__$1$jscomp$16$$))},$state__$1$jscomp$21_state__$2$jscomp$2$$,$selected$jscomp$59$$);return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.setSelection($state__$1$jscomp$21_state__$2$jscomp$2$$,$selection_after_apply_state$jscomp$545$$)};
$app$util$text_editor$update_editor_current_inline_styles_fn$$=function($state$jscomp$546$$,$attrs$jscomp$108_update_fn$jscomp$26$$){var $G__68851$jscomp$inline_6880$$=$APP.$app$common$text$styles_to_attrs$$($state$jscomp$546$$.getCurrentInlineStyle());$attrs$jscomp$108_update_fn$jscomp$26$$=$attrs$jscomp$108_update_fn$jscomp$26$$.$cljs$core$IFn$_invoke$arity$1$?$attrs$jscomp$108_update_fn$jscomp$26$$.$cljs$core$IFn$_invoke$arity$1$($G__68851$jscomp$inline_6880$$):$attrs$jscomp$108_update_fn$jscomp$26$$($G__68851$jscomp$inline_6880$$);
return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.applyInlineStyle($state$jscomp$546$$,$APP.$app$common$text$attrs_to_styles$$($attrs$jscomp$108_update_fn$jscomp$26$$))};
$app$main$data$workspace$texts$v2_content_has_text_QMARK_$$=function($content$jscomp$179$$){return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$truth_$$($content$jscomp$179$$)?$APP.$cljs$core$some$$(function($node$jscomp$311$$){return!$APP.$cuerdas$core$blank_QMARK_$$($APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$311$$,""))},$APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,$content$jscomp$179$$)):null)};
$APP.$app$main$data$workspace$texts$update_editor_state$$=function($p__70034$$,$editor_state$$){var $map__70035__$1$$=$APP.$cljs$core$__destructure_map$$($p__70034$$),$id$jscomp$602$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70035__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$workspace$texts$update_editor_state_70036$$==="undefined"&&($app$main$data$workspace$texts$update_editor_state_70036$$=function($p__70034$jscomp$1$$,$editor_state$jscomp$1$$,$map__70035$jscomp$1$$,$shape$jscomp$564$$,
$id$jscomp$603$$,$meta70037$$){this.$p__70034$=$p__70034$jscomp$1$$;this.$editor_state$=$editor_state$jscomp$1$$;this.$map__70035$=$map__70035$jscomp$1$$;this.shape=$shape$jscomp$564$$;this.id=$id$jscomp$603$$;this.$meta70037$=$meta70037$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_editor_state_70036$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_editor_state_70036$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4004$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_editor_state$$},$app$main$data$workspace$texts$update_editor_state_70036$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70038$$,$meta70037__$1$$){return new $app$main$data$workspace$texts$update_editor_state_70036$$(this.$p__70034$,this.$editor_state$,this.$map__70035$,this.shape,this.id,$meta70037__$1$$)},$app$main$data$workspace$texts$update_editor_state_70036$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70037$},$app$main$data$workspace$texts$update_editor_state_70036$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_editor_state_70036$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2161$$,$state$jscomp$560$$){return this.$editor_state$!=null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$560$$,$APP.$cljs$cst$2222$workspace_editor_state$$,$APP.$cljs$core$assoc$$,
this.id,this.$editor_state$):$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$560$$,$APP.$cljs$cst$2222$workspace_editor_state$$,$APP.$cljs$core$dissoc$$,this.id),$APP.$cljs$cst$3643$workspace_new_text_shapes$$,$APP.$cljs$core$disj$$,this.id)});return new $app$main$data$workspace$texts$update_editor_state_70036$$($p__70034$$,$editor_state$$,$map__70035__$1$$,$map__70035__$1$$,$id$jscomp$602$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$shape_current_values$$=function($root$jscomp$64_shape$jscomp$572$$,$nodes$jscomp$31_pred$jscomp$83$$,$attrs$jscomp$113$$){$root$jscomp$64_shape$jscomp$572$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$64_shape$jscomp$572$$);$nodes$jscomp$31_pred$jscomp$83$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($node$jscomp$312$$){if($APP.$app$common$types$text$is_text_node_QMARK_$$($node$jscomp$312$$)){var $default_text_attrs$$=
$APP.$app$common$types$text$get_default_text_attrs$$(),$fills$jscomp$23$$=$app$common$types$fills$has_valid_fill_attrs_QMARK_$$($node$jscomp$312$$)?$APP.$app$common$types$fills$create$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$select_keys$$($node$jscomp$312$$,$app$common$types$fills$fill_attrs$$))])):$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$312$$)!=
null?$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$312$$):$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($default_text_attrs$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$default_text_attrs$$,$node$jscomp$312$$])),$APP.$cljs$cst$1634$fills$$,$fills$jscomp$23$$)}return $node$jscomp$312$$},$APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($nodes$jscomp$31_pred$jscomp$83$$,
$root$jscomp$64_shape$jscomp$572$$));return $APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$02$$($nodes$jscomp$31_pred$jscomp$83$$,$attrs$jscomp$113$$)};
$APP.$app$main$data$workspace$texts$current_root_values$$=function($attrs$jscomp$114_p__70093$$){var $map__70094__$1_shape$jscomp$573$$=$APP.$cljs$core$__destructure_map$$($attrs$jscomp$114_p__70093$$);$attrs$jscomp$114_p__70093$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70094__$1_shape$jscomp$573$$,$APP.$cljs$cst$2645$attrs$$);$map__70094__$1_shape$jscomp$573$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70094__$1_shape$jscomp$573$$,$APP.$cljs$cst$1811$shape$$);
return $app$main$data$workspace$texts$shape_current_values$$($map__70094__$1_shape$jscomp$573$$,$APP.$app$common$types$text$is_root_node_QMARK_$$,$attrs$jscomp$114_p__70093$$)};
$app$main$data$workspace$texts$v3_current_text_values$$=function($editor_styles_p__70095_result$jscomp$302$$){var $attrs$jscomp$115_map__70097__$1$$=$APP.$cljs$core$__destructure_map$$($editor_styles_p__70095_result$jscomp$302$$);$editor_styles_p__70095_result$jscomp$302$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$115_map__70097__$1$$,$APP.$cljs$cst$4009$editor_styles$$);$attrs$jscomp$115_map__70097__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$115_map__70097__$1$$,
$APP.$cljs$cst$2645$attrs$$);$editor_styles_p__70095_result$jscomp$302$$=$APP.$cljs$core$select_keys$$($editor_styles_p__70095_result$jscomp$302$$,$attrs$jscomp$115_map__70097__$1$$);return $APP.$cljs$core$empty_QMARK_$$($editor_styles_p__70095_result$jscomp$302$$)?$APP.$app$common$types$text$default_text_attrs$$:$editor_styles_p__70095_result$jscomp$302$$};
$app$main$data$workspace$texts$v2_current_text_values$$=function($editor_instance_p__70098_result$jscomp$303$$){var $attrs$jscomp$116_map__70099__$1$$=$APP.$cljs$core$__destructure_map$$($editor_instance_p__70098_result$jscomp$303$$);$editor_instance_p__70098_result$jscomp$303$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$116_map__70099__$1$$,$APP.$cljs$cst$4010$editor_instance$$);$attrs$jscomp$116_map__70099__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$116_map__70099__$1$$,
$APP.$cljs$cst$2645$attrs$$);$editor_instance_p__70098_result$jscomp$303$$=$APP.$cljs$core$select_keys$$($APP.$app$util$text$content$styles$get_styles_from_style_declaration$$($editor_instance_p__70098_result$jscomp$303$$.currentStyle),$attrs$jscomp$116_map__70099__$1$$);return $APP.$cljs$core$empty_QMARK_$$($editor_instance_p__70098_result$jscomp$303$$)?$APP.$app$common$types$text$default_text_attrs$$:$editor_instance_p__70098_result$jscomp$303$$};
$APP.$app$main$data$workspace$texts$current_paragraph_values$$=function($JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$){$JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$);
var $attrs$jscomp$inline_6885_editor_styles$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$,$APP.$cljs$cst$4009$editor_styles$$),$editor_state$jscomp$4_map__70101__$1$jscomp$inline_6883_shape$jscomp$inline_6886$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$,
$APP.$cljs$cst$4011$editor_state$$),$editor_instance$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$,$APP.$cljs$cst$4010$editor_instance$$),$attrs$jscomp$118$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$,
$APP.$cljs$cst$2645$attrs$$),$shape$jscomp$575$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$,$APP.$cljs$cst$1811$shape$$);$attrs$jscomp$inline_6885_editor_styles$jscomp$1$$!=null?$JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$=$app$main$data$workspace$texts$v3_current_text_values$$($JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$):
$editor_instance$jscomp$1$$!=null?$JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$=$app$main$data$workspace$texts$v2_current_text_values$$($JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$):$editor_state$jscomp$4_map__70101__$1$jscomp$inline_6883_shape$jscomp$inline_6886$$!=null?($editor_state$jscomp$4_map__70101__$1$jscomp$inline_6883_shape$jscomp$inline_6886$$=
$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$),$JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($editor_state$jscomp$4_map__70101__$1$jscomp$inline_6883_shape$jscomp$inline_6886$$,$APP.$cljs$cst$4011$editor_state$$),$attrs$jscomp$inline_6885_editor_styles$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($editor_state$jscomp$4_map__70101__$1$jscomp$inline_6883_shape$jscomp$inline_6886$$,$APP.$cljs$cst$2645$attrs$$),$editor_state$jscomp$4_map__70101__$1$jscomp$inline_6883_shape$jscomp$inline_6886$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($editor_state$jscomp$4_map__70101__$1$jscomp$inline_6883_shape$jscomp$inline_6886$$,$APP.$cljs$cst$1811$shape$$),$JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$=
$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$)?$APP.$cljs$core$select_keys$$($APP.$app$util$text_editor$get_editor_current_block_data$$($JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$),$attrs$jscomp$inline_6885_editor_styles$jscomp$1$$):$app$main$data$workspace$texts$shape_current_values$$($editor_state$jscomp$4_map__70101__$1$jscomp$inline_6883_shape$jscomp$inline_6886$$,
$APP.$app$common$types$text$is_paragraph_node_QMARK_$$,$attrs$jscomp$inline_6885_editor_styles$jscomp$1$$)):$JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$=$app$main$data$workspace$texts$shape_current_values$$($shape$jscomp$575$$,$APP.$app$common$types$text$is_paragraph_node_QMARK_$$,$attrs$jscomp$118$$);return $JSCompiler_temp$jscomp$1183_JSCompiler_temp$jscomp$1184_JSCompiler_temp$jscomp$1185_editor_state$jscomp$inline_6884_map__70104__$1_p__70103$$};
$APP.$app$main$data$workspace$texts$current_text_values$$=function($JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$){$JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$);
var $attrs$jscomp$inline_6891_editor_styles$jscomp$2_map__70106__$1$jscomp$inline_6889$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$,$APP.$cljs$cst$4009$editor_styles$$),$editor_state$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$,
$APP.$cljs$cst$4011$editor_state$$),$editor_instance$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$,$APP.$cljs$cst$4010$editor_instance$$),$attrs$jscomp$120$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$,
$APP.$cljs$cst$2645$attrs$$),$shape$jscomp$576$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$,$APP.$cljs$cst$1811$shape$$);$attrs$jscomp$inline_6891_editor_styles$jscomp$2_map__70106__$1$jscomp$inline_6889$$!=null?$JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$=
$app$main$data$workspace$texts$v3_current_text_values$$($JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$):$editor_instance$jscomp$2$$!=null?$JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$=$app$main$data$workspace$texts$v2_current_text_values$$($JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$):
$editor_state$jscomp$6$$!=null?($attrs$jscomp$inline_6891_editor_styles$jscomp$2_map__70106__$1$jscomp$inline_6889$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$),$JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$inline_6891_editor_styles$jscomp$2_map__70106__$1$jscomp$inline_6889$$,
$APP.$cljs$cst$4011$editor_state$$),$attrs$jscomp$inline_6891_editor_styles$jscomp$2_map__70106__$1$jscomp$inline_6889$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$inline_6891_editor_styles$jscomp$2_map__70106__$1$jscomp$inline_6889$$,$APP.$cljs$cst$2645$attrs$$),$JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$=$APP.$cljs$core$select_keys$$($APP.$app$util$text_editor$get_editor_current_inline_styles$$($JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$),
$attrs$jscomp$inline_6891_editor_styles$jscomp$2_map__70106__$1$jscomp$inline_6889$$),$JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$=$APP.$cljs$core$empty_QMARK_$$($JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$)?$APP.$app$common$types$text$get_default_text_attrs$$():
$JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$):$JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$=$app$main$data$workspace$texts$shape_current_values$$($shape$jscomp$576$$,$APP.$app$common$types$text$is_text_node_QMARK_$$,$attrs$jscomp$120$$);return $JSCompiler_temp$jscomp$1186_JSCompiler_temp$jscomp$1187_JSCompiler_temp$jscomp$1188_editor_state$jscomp$inline_6890_map__70108__$1_p__70107_result$jscomp$inline_6892$$};
$app$main$data$workspace$texts$update_root_attrs$$=function($p__70146$$){var $map__70147__$1$$=$APP.$cljs$core$__destructure_map$$($p__70146$$),$id$jscomp$614$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70147__$1$$,$APP.$cljs$cst$266$id$$),$attrs$jscomp$125$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70147__$1$$,$APP.$cljs$cst$2645$attrs$$);typeof $app$main$data$workspace$texts$update_root_attrs_70148$$==="undefined"&&($app$main$data$workspace$texts$update_root_attrs_70148$$=
function($p__70146$jscomp$1$$,$map__70147$jscomp$1$$,$id$jscomp$615$$,$attrs$jscomp$126$$,$meta70149$$){this.$p__70146$=$p__70146$jscomp$1$$;this.$map__70147$=$map__70147$jscomp$1$$;this.id=$id$jscomp$615$$;this.$attrs$=$attrs$jscomp$126$$;this.$meta70149$=$meta70149$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_root_attrs_70148$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_root_attrs_70148$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4013$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_root_attrs$$},$app$main$data$workspace$texts$update_root_attrs_70148$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70150$$,$meta70149__$1$$){return new $app$main$data$workspace$texts$update_root_attrs_70148$$(this.$p__70146$,this.$map__70147$,this.id,this.$attrs$,$meta70149__$1$$)},$app$main$data$workspace$texts$update_root_attrs_70148$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70149$},
$app$main$data$workspace$texts$update_root_attrs_70148$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_root_attrs_70148$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2168_objects$jscomp$512_shape_ids$jscomp$6$$,$shape$jscomp$579_state$jscomp$567$$){var $self__$jscomp$4976$$=this;$_$jscomp$2168_objects$jscomp$512_shape_ids$jscomp$6$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$579_state$jscomp$567$$);
$shape$jscomp$579_state$jscomp$567$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2168_objects$jscomp$512_shape_ids$jscomp$6$$,$self__$jscomp$4976$$.id);$_$jscomp$2168_objects$jscomp$512_shape_ids$jscomp$6$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$579_state$jscomp$567$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4976$$.id],null):$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$579_state$jscomp$567$$)?
$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2168_objects$jscomp$512_shape_ids$jscomp$6$$,$self__$jscomp$4976$$.id):null;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2168_objects$jscomp$512_shape_ids$jscomp$6$$,function($shape__$1$jscomp$43$$){return $APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$43$$)!=null?$app$common$types$text$update_text_content$$($shape__$1$jscomp$43$$,
$APP.$app$common$types$text$is_root_node_QMARK_$$,$APP.$app$common$data$txt_merge$$,$self__$jscomp$4976$$.$attrs$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$43$$,$APP.$cljs$cst$1637$content$$,$APP.$app$common$data$txt_merge$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,"root"],null),$self__$jscomp$4976$$.$attrs$))}))});return new $app$main$data$workspace$texts$update_root_attrs_70148$$($p__70146$$,$map__70147__$1$$,$id$jscomp$614$$,$attrs$jscomp$125$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$update_paragraph_attrs$$=function($p__70166$$){var $map__70167__$1$$=$APP.$cljs$core$__destructure_map$$($p__70166$$),$id$jscomp$616$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70167__$1$$,$APP.$cljs$cst$266$id$$),$attrs$jscomp$127_attrs__$1$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70167__$1$$,$APP.$cljs$cst$2645$attrs$$);$attrs$jscomp$127_attrs__$1$jscomp$17$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$127_attrs__$1$jscomp$17$$);typeof $app$main$data$workspace$texts$update_paragraph_attrs_70168$$===
"undefined"&&($app$main$data$workspace$texts$update_paragraph_attrs_70168$$=function($p__70166$jscomp$1$$,$map__70167$jscomp$1$$,$id$jscomp$617$$,$attrs$jscomp$128$$,$meta70169$$){this.$p__70166$=$p__70166$jscomp$1$$;this.$map__70167$=$map__70167$jscomp$1$$;this.id=$id$jscomp$617$$;this.$attrs$=$attrs$jscomp$128$$;this.$meta70169$=$meta70169$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_paragraph_attrs_70168$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_paragraph_attrs_70168$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4014$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_paragraph_attrs$$},$app$main$data$workspace$texts$update_paragraph_attrs_70168$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70170$$,$meta70169__$1$$){return new $app$main$data$workspace$texts$update_paragraph_attrs_70168$$(this.$p__70166$,this.$map__70167$,
this.id,this.$attrs$,$meta70169__$1$$)},$app$main$data$workspace$texts$update_paragraph_attrs_70168$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70169$},$app$main$data$workspace$texts$update_paragraph_attrs_70168$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_paragraph_attrs_70168$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2169$$,$state$jscomp$568$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$568$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2222$workspace_editor_state$$,this.id],null),$APP.$app$util$text_editor$update_editor_current_block_data$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$attrs$]))},$app$main$data$workspace$texts$update_paragraph_attrs_70168$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_paragraph_attrs_70168$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2170_objects$jscomp$513_shape_ids$jscomp$7$$,$shape$jscomp$580_state$jscomp$569$$){function $merge_fn$$($node$jscomp$319$$,$attrs__$1$jscomp$18$$){return $APP.$cljs$core$reduce_kv$$(function($node__$1$jscomp$72$$,$k$jscomp$651$$,$v$jscomp$594$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($node__$1$jscomp$72$$,$k$jscomp$651$$,$v$jscomp$594$$)},$node$jscomp$319$$,$attrs__$1$jscomp$18$$)}var $self__$jscomp$4981$$=this;if($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$580_state$jscomp$569$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2222$workspace_editor_state$$,$self__$jscomp$4981$$.id],null))!=null)return null;$_$jscomp$2170_objects$jscomp$513_shape_ids$jscomp$7$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$580_state$jscomp$569$$);$shape$jscomp$580_state$jscomp$569$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2170_objects$jscomp$513_shape_ids$jscomp$7$$,
$self__$jscomp$4981$$.id);$_$jscomp$2170_objects$jscomp$513_shape_ids$jscomp$7$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$580_state$jscomp$569$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4981$$.id],null):$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$580_state$jscomp$569$$)?$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2170_objects$jscomp$513_shape_ids$jscomp$7$$,
$self__$jscomp$4981$$.id):null;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2170_objects$jscomp$513_shape_ids$jscomp$7$$,function($p1__70165_SHARP_$$){return $app$common$types$text$update_text_content$$($p1__70165_SHARP_$$,$APP.$app$common$types$text$is_paragraph_node_QMARK_$$,$merge_fn$$,$self__$jscomp$4981$$.$attrs$)}))});return new $app$main$data$workspace$texts$update_paragraph_attrs_70168$$($p__70166$$,$map__70167__$1$$,
$id$jscomp$616$$,$attrs$jscomp$127_attrs__$1$jscomp$17$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$texts$update_text_attrs$$=function($p__70177$$){var $map__70178__$1$$=$APP.$cljs$core$__destructure_map$$($p__70177$$),$id$jscomp$618$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70178__$1$$,$APP.$cljs$cst$266$id$$),$attrs$jscomp$129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70178__$1$$,$APP.$cljs$cst$2645$attrs$$);typeof $app$main$data$workspace$texts$update_text_attrs_70179$$==="undefined"&&($app$main$data$workspace$texts$update_text_attrs_70179$$=
function($p__70177$jscomp$1$$,$map__70178$jscomp$1$$,$id$jscomp$619$$,$attrs$jscomp$130$$,$meta70180$$){this.$p__70177$=$p__70177$jscomp$1$$;this.$map__70178$=$map__70178$jscomp$1$$;this.id=$id$jscomp$619$$;this.$attrs$=$attrs$jscomp$130$$;this.$meta70180$=$meta70180$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_text_attrs_70179$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_attrs_70179$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4015$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_attrs$$},$app$main$data$workspace$texts$update_text_attrs_70179$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70181$$,$meta70180__$1$$){return new $app$main$data$workspace$texts$update_text_attrs_70179$$(this.$p__70177$,this.$map__70178$,this.id,this.$attrs$,$meta70180__$1$$)},$app$main$data$workspace$texts$update_text_attrs_70179$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70180$},
$app$main$data$workspace$texts$update_text_attrs_70179$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_attrs_70179$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2171$$,$state$jscomp$570$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$570$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2222$workspace_editor_state$$,
this.id],null),$app$util$text_editor$update_editor_current_inline_styles$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$attrs$]))},$app$main$data$workspace$texts$update_text_attrs_70179$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_attrs_70179$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2172_objects$jscomp$514$$,$shape_ids$jscomp$8_state$jscomp$571$$){function $update_node_QMARK_$$($node$jscomp$320$$){return $APP.$app$common$types$text$is_text_node_QMARK_$$($node$jscomp$320$$)||
$APP.$app$common$types$text$is_paragraph_node_QMARK_$$($node$jscomp$320$$)}var $self__$jscomp$4986$$=this;if($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape_ids$jscomp$8_state$jscomp$571$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2222$workspace_editor_state$$,$self__$jscomp$4986$$.id],null))!=null)return null;$_$jscomp$2172_objects$jscomp$514$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($shape_ids$jscomp$8_state$jscomp$571$$);
var $shape$jscomp$581$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2172_objects$jscomp$514$$,$self__$jscomp$4986$$.id),$wasm_QMARK_$$=$APP.$app$main$features$active_feature_QMARK_$$($shape_ids$jscomp$8_state$jscomp$571$$,"render-wasm/v1");$shape_ids$jscomp$8_state$jscomp$571$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$581$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4986$$.id],
null):$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$581$$)?$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2172_objects$jscomp$514$$,$self__$jscomp$4986$$.id):null;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_ids$jscomp$8_state$jscomp$571$$,function($sh$jscomp$4_updated_shape$jscomp$2$$){$sh$jscomp$4_updated_shape$jscomp$2$$=
$app$common$types$text$update_text_content$$($sh$jscomp$4_updated_shape$jscomp$2$$,$update_node_QMARK_$$,$APP.$app$common$data$txt_merge$$,$self__$jscomp$4986$$.$attrs$);if($wasm_QMARK_$$){var $shape_id$jscomp$inline_12674$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($sh$jscomp$4_updated_shape$jscomp$2$$),$content$jscomp$inline_12675$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($sh$jscomp$4_updated_shape$jscomp$2$$);$content$jscomp$inline_12675$$!=null&&$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$render_wasm$text_editor$shape_text_contents$$,
$APP.$cljs$core$assoc$$,$shape_id$jscomp$inline_12674$$,$content$jscomp$inline_12675$$)}return $sh$jscomp$4_updated_shape$jscomp$2$$}))});return new $app$main$data$workspace$texts$update_text_attrs_70179$$($p__70177$$,$map__70178__$1$$,$id$jscomp$618$$,$attrs$jscomp$129$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$migrate_node$$=function($node$jscomp$321$$){var $color_attrs$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$select_keys$$($node$jscomp$321$$,$app$common$types$fills$fill_attrs$$)),$G__70197__$1_G__70197__$2$$=$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$321$$)==null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$321$$,$APP.$cljs$cst$1634$fills$$,$APP.$app$common$types$fills$create$$()):$node$jscomp$321$$;$G__70197__$1_G__70197__$2$$=
$APP.$cljs$core$truth_$$($color_attrs$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__70197__$1_G__70197__$2$$,$APP.$cljs$cst$1746$fill_color$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1747$fill_opacity$$,$APP.$cljs$cst$1745$fill_color_ref_id$$,$APP.$cljs$cst$1640$fill_color_ref_file$$,$APP.$cljs$cst$1748$fill_color_gradient$$])),$APP.$cljs$cst$1634$fills$$,$APP.$app$common$types$fills$update$$,
$APP.$cljs$core$conj$$,$color_attrs$$):$G__70197__$1_G__70197__$2$$;return $APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$321$$)==null&&$APP.$cljs$core$empty_QMARK_$$($color_attrs$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70197__$1_G__70197__$2$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$contains_QMARK_$$($APP.$app$common$flags$_STAR_current_STAR_$$,$APP.$cljs$cst$1755$frontend_binary_fills$$)?$APP.$app$common$types$fills$impl$from_plain$$($app$common$types$text$default_text_fills$$):
$app$common$types$text$default_text_fills$$):$G__70197__$1_G__70197__$2$$};
$APP.$app$main$data$workspace$texts$update_text_with_function$cljs$0core$0IFn$0_invoke$0arity$03$$=function($id$jscomp$621$$,$update_node_fn$jscomp$1$$,$options$jscomp$526$$){typeof $app$main$data$workspace$texts$update_text_with_function_70204$$==="undefined"&&($app$main$data$workspace$texts$update_text_with_function_70204$$=function($id$jscomp$622$$,$update_node_fn$jscomp$2$$,$options$jscomp$527$$,$meta70205$$){this.id=$id$jscomp$622$$;this.$update_node_fn$=$update_node_fn$jscomp$2$$;this.options=
$options$jscomp$527$$;this.$meta70205$=$meta70205$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_text_with_function_70204$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_with_function_70204$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4016$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_with_function$$},
$app$main$data$workspace$texts$update_text_with_function_70204$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70206$$,$meta70205__$1$$){return new $app$main$data$workspace$texts$update_text_with_function_70204$$(this.id,this.$update_node_fn$,this.options,$meta70205__$1$$)},$app$main$data$workspace$texts$update_text_with_function_70204$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70205$},$app$main$data$workspace$texts$update_text_with_function_70204$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_with_function_70204$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2173$$,$state$jscomp$572$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$572$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2222$workspace_editor_state$$,this.id],null),$app$util$text_editor$update_editor_current_inline_styles_fn$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$(this.$update_node_fn$,$app$main$data$workspace$texts$migrate_node$$)]))},$app$main$data$workspace$texts$update_text_with_function_70204$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_with_function_70204$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2174_objects$jscomp$515_page_id$jscomp$190_shape_ids$jscomp$9$$,
$state$jscomp$573$$){var $self__$jscomp$4991$$=this;if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$573$$,"text-editor/v2")&&$APP.$cljs$cst$2221$workspace_editor$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$573$$)==null||!$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$573$$,"text-editor/v2")&&$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$573$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2222$workspace_editor_state$$,
$self__$jscomp$4991$$.id],null))==null){$_$jscomp$2174_objects$jscomp$515_page_id$jscomp$190_shape_ids$jscomp$9$$=function(){var $or__5025__auto__$jscomp$804$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4991$$.options,$APP.$cljs$cst$2043$page_id$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$804$$)?$or__5025__auto__$jscomp$804$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$573$$,$APP.$cljs$cst$1918$current_page_id$$)}();$_$jscomp$2174_objects$jscomp$515_page_id$jscomp$190_shape_ids$jscomp$9$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$573$$,$_$jscomp$2174_objects$jscomp$515_page_id$jscomp$190_shape_ids$jscomp$9$$);var $shape$jscomp$582$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2174_objects$jscomp$515_page_id$jscomp$190_shape_ids$jscomp$9$$,$self__$jscomp$4991$$.id),$update_node_QMARK_$jscomp$1$$=$cljs$core$some_fn$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,$APP.$app$common$types$text$is_paragraph_node_QMARK_$$);
$_$jscomp$2174_objects$jscomp$515_page_id$jscomp$190_shape_ids$jscomp$9$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$582$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4991$$.id],null):$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$582$$)?$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2174_objects$jscomp$515_page_id$jscomp$190_shape_ids$jscomp$9$$,
$self__$jscomp$4991$$.id):null;var $update_content$jscomp$1$$=function($content$jscomp$187$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$($update_node_QMARK_$jscomp$1$$,$self__$jscomp$4991$$.$update_node_fn$,$APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$($cljs$core$some_fn$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,$APP.$app$common$types$text$is_paragraph_node_QMARK_$$),$app$main$data$workspace$texts$migrate_node$$,
$content$jscomp$187$$))};return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$2174_objects$jscomp$515_page_id$jscomp$190_shape_ids$jscomp$9$$,function($shape__$1$jscomp$44$$){return $APP.$app$common$data$update_when$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$44$$,$APP.$cljs$cst$1634$fills$$),$APP.$cljs$cst$1637$content$$,$update_content$jscomp$1$$)},$self__$jscomp$4991$$.options)),
$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$573$$,"text-editor-wasm/v1")?function(){var $G__70209$jscomp$inline_6894_JSCompiler_inline_result$jscomp$1190_JSCompiler_temp$jscomp$1189_styles$jscomp$18$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4991$$.$update_node_fn$,$app$main$data$workspace$texts$migrate_node$$)(),$G__70210$jscomp$inline_6895_result$jscomp$306$$=$app$render_wasm$api$apply_styles_to_selection$$($G__70209$jscomp$inline_6894_JSCompiler_inline_result$jscomp$1190_JSCompiler_temp$jscomp$1189_styles$jscomp$18$$);
$APP.$cljs$core$truth_$$($G__70210$jscomp$inline_6895_result$jscomp$306$$)?($G__70209$jscomp$inline_6894_JSCompiler_inline_result$jscomp$1190_JSCompiler_temp$jscomp$1189_styles$jscomp$18$$=$APP.$cljs$cst$2543$shape_id$$.$cljs$core$IFn$_invoke$arity$1$($G__70210$jscomp$inline_6895_result$jscomp$306$$),$G__70210$jscomp$inline_6895_result$jscomp$306$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($G__70210$jscomp$inline_6895_result$jscomp$306$$),$G__70209$jscomp$inline_6894_JSCompiler_inline_result$jscomp$1190_JSCompiler_temp$jscomp$1189_styles$jscomp$18$$=
$app$main$data$workspace$texts$v2_update_text_shape_content$$.$cljs$core$IFn$_invoke$arity$4$?$app$main$data$workspace$texts$v2_update_text_shape_content$$.$cljs$core$IFn$_invoke$arity$4$($G__70209$jscomp$inline_6894_JSCompiler_inline_result$jscomp$1190_JSCompiler_temp$jscomp$1189_styles$jscomp$18$$,$G__70210$jscomp$inline_6895_result$jscomp$306$$,$APP.$cljs$cst$4017$update_name_QMARK_$$,!0):$app$main$data$workspace$texts$v2_update_text_shape_content$$($G__70209$jscomp$inline_6894_JSCompiler_inline_result$jscomp$1190_JSCompiler_temp$jscomp$1189_styles$jscomp$18$$,
$G__70210$jscomp$inline_6895_result$jscomp$306$$,$APP.$cljs$cst$4017$update_name_QMARK_$$,!0),$G__70209$jscomp$inline_6894_JSCompiler_inline_result$jscomp$1190_JSCompiler_temp$jscomp$1189_styles$jscomp$18$$=(0,$APP.$beicon$v2$core$of$$)($G__70209$jscomp$inline_6894_JSCompiler_inline_result$jscomp$1190_JSCompiler_temp$jscomp$1189_styles$jscomp$18$$)):$G__70209$jscomp$inline_6894_JSCompiler_inline_result$jscomp$1190_JSCompiler_temp$jscomp$1189_styles$jscomp$18$$=null;return $G__70209$jscomp$inline_6894_JSCompiler_inline_result$jscomp$1190_JSCompiler_temp$jscomp$1189_styles$jscomp$18$$}():
null)}return null},$app$main$data$workspace$texts$update_text_with_function_70204$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_with_function_70204$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2175_temp__5825__auto__$jscomp$208$$,$G__70214$jscomp$inline_6897_G__70214__$1$jscomp$inline_6898_G__70214__$2$jscomp$inline_6899_state$jscomp$574_styles$jscomp$19$$){return $APP.$app$main$features$active_feature_QMARK_$$($G__70214$jscomp$inline_6897_G__70214__$1$jscomp$inline_6898_G__70214__$2$jscomp$inline_6899_state$jscomp$574_styles$jscomp$19$$,
"text-editor/v2")&&($_$jscomp$2175_temp__5825__auto__$jscomp$208$$=$APP.$cljs$cst$2221$workspace_editor$$.$cljs$core$IFn$_invoke$arity$1$($G__70214$jscomp$inline_6897_G__70214__$1$jscomp$inline_6898_G__70214__$2$jscomp$inline_6899_state$jscomp$574_styles$jscomp$19$$),$APP.$cljs$core$truth_$$($_$jscomp$2175_temp__5825__auto__$jscomp$208$$))?($G__70214$jscomp$inline_6897_G__70214__$1$jscomp$inline_6898_G__70214__$2$jscomp$inline_6899_state$jscomp$574_styles$jscomp$19$$=$shadow$js$shim$module$0$0penpot$0text_editor$$.getCurrentStyle($_$jscomp$2175_temp__5825__auto__$jscomp$208$$),
$G__70214$jscomp$inline_6897_G__70214__$1$jscomp$inline_6898_G__70214__$2$jscomp$inline_6899_state$jscomp$574_styles$jscomp$19$$=$G__70214$jscomp$inline_6897_G__70214__$1$jscomp$inline_6898_G__70214__$2$jscomp$inline_6899_state$jscomp$574_styles$jscomp$19$$==null?null:$app$util$text$content$styles$get_styles_from_style_declaration$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__70214$jscomp$inline_6897_G__70214__$1$jscomp$inline_6898_G__70214__$2$jscomp$inline_6899_state$jscomp$574_styles$jscomp$19$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$3078$removed_mixed$$,!0])),$G__70214$jscomp$inline_6897_G__70214__$1$jscomp$inline_6898_G__70214__$2$jscomp$inline_6899_state$jscomp$574_styles$jscomp$19$$=$G__70214$jscomp$inline_6897_G__70214__$1$jscomp$inline_6898_G__70214__$2$jscomp$inline_6899_state$jscomp$574_styles$jscomp$19$$==null?null:$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$(this.$update_node_fn$,$app$main$data$workspace$texts$migrate_node$$)($G__70214$jscomp$inline_6897_G__70214__$1$jscomp$inline_6898_G__70214__$2$jscomp$inline_6899_state$jscomp$574_styles$jscomp$19$$),
$G__70214$jscomp$inline_6897_G__70214__$1$jscomp$inline_6898_G__70214__$2$jscomp$inline_6899_state$jscomp$574_styles$jscomp$19$$=$G__70214$jscomp$inline_6897_G__70214__$1$jscomp$inline_6898_G__70214__$2$jscomp$inline_6899_state$jscomp$574_styles$jscomp$19$$==null?null:$app$util$text$content$styles$attrs__GT_styles$$($G__70214$jscomp$inline_6897_G__70214__$1$jscomp$inline_6898_G__70214__$2$jscomp$inline_6899_state$jscomp$574_styles$jscomp$19$$),$shadow$js$shim$module$0$0penpot$0text_editor$$.applyStylesToSelection($_$jscomp$2175_temp__5825__auto__$jscomp$208$$,
$G__70214$jscomp$inline_6897_G__70214__$1$jscomp$inline_6898_G__70214__$2$jscomp$inline_6899_state$jscomp$574_styles$jscomp$19$$)):null});return new $app$main$data$workspace$texts$update_text_with_function_70204$$($id$jscomp$621$$,$update_node_fn$jscomp$1$$,$options$jscomp$526$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$texts$apply_text_modifier$$=function($delta_move_shape$jscomp$585$$,$G__70283__$2$jscomp$inline_6911_height$jscomp$128_new_shape$jscomp$19_text_modifier$jscomp$1$$){if($G__70283__$2$jscomp$inline_6911_height$jscomp$128_new_shape$jscomp$19_text_modifier$jscomp$1$$!=null){var $map__70282__$1_position_data$jscomp$8$$=$APP.$cljs$core$__destructure_map$$($G__70283__$2$jscomp$inline_6911_height$jscomp$128_new_shape$jscomp$19_text_modifier$jscomp$1$$),$G__70283__$1$jscomp$inline_6910_width$jscomp$142$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70282__$1_position_data$jscomp$8$$,$APP.$cljs$cst$290$width$$);$G__70283__$2$jscomp$inline_6911_height$jscomp$128_new_shape$jscomp$19_text_modifier$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70282__$1_position_data$jscomp$8$$,$APP.$cljs$cst$1522$height$$);$map__70282__$1_position_data$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70282__$1_position_data$jscomp$8$$,$APP.$cljs$cst$1891$position_data$$);
$G__70283__$1$jscomp$inline_6910_width$jscomp$142$$=$G__70283__$1$jscomp$inline_6910_width$jscomp$142$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($delta_move_shape$jscomp$585$$,$APP.$app$common$types$modifiers$change_dimensions_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($delta_move_shape$jscomp$585$$,$APP.$cljs$cst$290$width$$,$G__70283__$1$jscomp$inline_6910_width$jscomp$142$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1806$ignore_lock_QMARK_$$,
!0],null))):$delta_move_shape$jscomp$585$$;$G__70283__$2$jscomp$inline_6911_height$jscomp$128_new_shape$jscomp$19_text_modifier$jscomp$1$$=$G__70283__$2$jscomp$inline_6911_height$jscomp$128_new_shape$jscomp$19_text_modifier$jscomp$1$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__70283__$1$jscomp$inline_6910_width$jscomp$142$$,$APP.$app$common$types$modifiers$change_dimensions_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($delta_move_shape$jscomp$585$$,
$APP.$cljs$cst$1522$height$$,$G__70283__$2$jscomp$inline_6911_height$jscomp$128_new_shape$jscomp$19_text_modifier$jscomp$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1806$ignore_lock_QMARK_$$,!0],null))):$G__70283__$1$jscomp$inline_6910_width$jscomp$142$$;$G__70283__$2$jscomp$inline_6911_height$jscomp$128_new_shape$jscomp$19_text_modifier$jscomp$1$$=$map__70282__$1_position_data$jscomp$8$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70283__$2$jscomp$inline_6911_height$jscomp$128_new_shape$jscomp$19_text_modifier$jscomp$1$$,
$APP.$cljs$cst$1891$position_data$$,$map__70282__$1_position_data$jscomp$8$$):$G__70283__$2$jscomp$inline_6911_height$jscomp$128_new_shape$jscomp$19_text_modifier$jscomp$1$$;$delta_move_shape$jscomp$585$$=$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($app$common$types$modifiers$safe_size_rect$$($G__70283__$2$jscomp$inline_6911_height$jscomp$128_new_shape$jscomp$19_text_modifier$jscomp$1$$)),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($app$common$types$modifiers$safe_size_rect$$($delta_move_shape$jscomp$585$$)));
return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__70283__$2$jscomp$inline_6911_height$jscomp$128_new_shape$jscomp$19_text_modifier$jscomp$1$$,$APP.$cljs$cst$1891$position_data$$,$app$common$geom$shapes$move_position_data$$,$delta_move_shape$jscomp$585$$)}return $delta_move_shape$jscomp$585$$};
$app$main$data$workspace$texts$font_loaded_event_QMARK_$$=function($font_id$jscomp$31$$){return function($event$jscomp$95$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2974$font_loaded$$,$APP.$potok$v2$core$type$$($event$jscomp$95$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($event$jscomp$95$$)),$font_id$jscomp$31$$)}};
$APP.$app$main$data$workspace$texts$update_attrs$$=function($id$jscomp$635$$,$attrs$jscomp$131$$){typeof $app$main$data$workspace$texts$update_attrs_70334$$==="undefined"&&($app$main$data$workspace$texts$update_attrs_70334$$=function($id$jscomp$636$$,$attrs$jscomp$132$$,$meta70335$$){this.id=$id$jscomp$636$$;this.$attrs$=$attrs$jscomp$132$$;this.$meta70335$=$meta70335$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_attrs_70334$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_attrs_70334$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4033$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_attrs$$},$app$main$data$workspace$texts$update_attrs_70334$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70336$$,$meta70335__$1$$){return new $app$main$data$workspace$texts$update_attrs_70334$$(this.id,this.$attrs$,$meta70335__$1$$)},$app$main$data$workspace$texts$update_attrs_70334$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70335$},$app$main$data$workspace$texts$update_attrs_70334$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_attrs_70334$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2191_text_editor_instance$$,$state$jscomp$589$$,$stream$jscomp$63$$){var $self__$jscomp$5041$$=this;$_$jscomp$2191_text_editor_instance$$=$APP.$cljs$cst$2221$workspace_editor$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$589$$);
return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$589$$,"text-editor/v2")&&$_$jscomp$2191_text_editor_instance$$!=null?$APP.$beicon$v2$core$empty$$():$APP.$beicon$v2$core$concat$$(function(){var $attrs__$1$jscomp$19$$=$APP.$cljs$core$select_keys$$($self__$jscomp$5041$$.$attrs$,$APP.$app$common$types$text$text_valign_attrs$$);return $APP.$cljs$core$empty_QMARK_$$($attrs__$1$jscomp$19$$)?$APP.$beicon$v2$core$empty$$():(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$texts$update_root_attrs$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$266$id$$,$self__$jscomp$5041$$.id,$APP.$cljs$cst$2645$attrs$$,$attrs__$1$jscomp$19$$],null)))}(),function(){var $attrs__$1$jscomp$20$$=$APP.$cljs$core$select_keys$$($self__$jscomp$5041$$.$attrs$,$APP.$app$common$types$text$paragraph_attrs$$);return $APP.$cljs$core$empty_QMARK_$$($attrs__$1$jscomp$20$$)?$APP.$beicon$v2$core$empty$$():(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$texts$update_paragraph_attrs$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,
$self__$jscomp$5041$$.id,$APP.$cljs$cst$2645$attrs$$,$attrs__$1$jscomp$20$$],null)))}(),function(){var $attrs__$1$jscomp$21$$=$APP.$cljs$core$select_keys$$($self__$jscomp$5041$$.$attrs$,$APP.$app$common$types$text$text_node_attrs$$);return $APP.$cljs$core$empty_QMARK_$$($attrs__$1$jscomp$21$$)?$APP.$beicon$v2$core$empty$$():(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$texts$update_text_attrs$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$self__$jscomp$5041$$.id,
$APP.$cljs$cst$2645$attrs$$,$attrs__$1$jscomp$21$$],null)))}(),$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$589$$,"text-editor/v2")&&!$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$589$$,"text-editor-wasm/v1")?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$texts$v2_update_text_editor_styles$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$main$data$workspace$texts$v2_update_text_editor_styles$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5041$$.id,$self__$jscomp$5041$$.$attrs$):
$APP.$app$main$data$workspace$texts$v2_update_text_editor_styles$$($self__$jscomp$5041$$.id,$self__$jscomp$5041$$.$attrs$)):null,$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$589$$,"render-wasm/v1")?$APP.$beicon$v2$core$concat$$(function(){var $G__70337$jscomp$inline_6913_JSCompiler_inline_result$jscomp$1192_JSCompiler_temp$jscomp$1191_has_selection_QMARK_$jscomp$1_span_attrs$$=$app$render_wasm$text_editor$text_editor_has_selection_QMARK_$$.$cljs$core$IFn$_invoke$arity$0$?$app$render_wasm$text_editor$text_editor_has_selection_QMARK_$$.$cljs$core$IFn$_invoke$arity$0$():
$app$render_wasm$text_editor$text_editor_has_selection_QMARK_$$();if($APP.$cljs$core$truth_$$($G__70337$jscomp$inline_6913_JSCompiler_inline_result$jscomp$1192_JSCompiler_temp$jscomp$1191_has_selection_QMARK_$jscomp$1_span_attrs$$)){$G__70337$jscomp$inline_6913_JSCompiler_inline_result$jscomp$1192_JSCompiler_temp$jscomp$1191_has_selection_QMARK_$jscomp$1_span_attrs$$=$APP.$cljs$core$select_keys$$($self__$jscomp$5041$$.$attrs$,$APP.$app$common$types$text$text_node_attrs$$);if($APP.$cljs$core$empty_QMARK_$$($G__70337$jscomp$inline_6913_JSCompiler_inline_result$jscomp$1192_JSCompiler_temp$jscomp$1191_has_selection_QMARK_$jscomp$1_span_attrs$$))return null;
var $G__70338$jscomp$inline_6914_result$jscomp$307$$=$app$render_wasm$api$apply_styles_to_selection$$($G__70337$jscomp$inline_6913_JSCompiler_inline_result$jscomp$1192_JSCompiler_temp$jscomp$1191_has_selection_QMARK_$jscomp$1_span_attrs$$);$APP.$cljs$core$truth_$$($G__70338$jscomp$inline_6914_result$jscomp$307$$)?($G__70337$jscomp$inline_6913_JSCompiler_inline_result$jscomp$1192_JSCompiler_temp$jscomp$1191_has_selection_QMARK_$jscomp$1_span_attrs$$=$APP.$cljs$cst$2543$shape_id$$.$cljs$core$IFn$_invoke$arity$1$($G__70338$jscomp$inline_6914_result$jscomp$307$$),
$G__70338$jscomp$inline_6914_result$jscomp$307$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($G__70338$jscomp$inline_6914_result$jscomp$307$$),$G__70337$jscomp$inline_6913_JSCompiler_inline_result$jscomp$1192_JSCompiler_temp$jscomp$1191_has_selection_QMARK_$jscomp$1_span_attrs$$=$app$main$data$workspace$texts$v2_update_text_shape_content$$.$cljs$core$IFn$_invoke$arity$4$?$app$main$data$workspace$texts$v2_update_text_shape_content$$.$cljs$core$IFn$_invoke$arity$4$($G__70337$jscomp$inline_6913_JSCompiler_inline_result$jscomp$1192_JSCompiler_temp$jscomp$1191_has_selection_QMARK_$jscomp$1_span_attrs$$,
$G__70338$jscomp$inline_6914_result$jscomp$307$$,$APP.$cljs$cst$4017$update_name_QMARK_$$,!0):$app$main$data$workspace$texts$v2_update_text_shape_content$$($G__70337$jscomp$inline_6913_JSCompiler_inline_result$jscomp$1192_JSCompiler_temp$jscomp$1191_has_selection_QMARK_$jscomp$1_span_attrs$$,$G__70338$jscomp$inline_6914_result$jscomp$307$$,$APP.$cljs$cst$4017$update_name_QMARK_$$,!0),$G__70337$jscomp$inline_6913_JSCompiler_inline_result$jscomp$1192_JSCompiler_temp$jscomp$1191_has_selection_QMARK_$jscomp$1_span_attrs$$=
(0,$APP.$beicon$v2$core$of$$)($G__70337$jscomp$inline_6913_JSCompiler_inline_result$jscomp$1192_JSCompiler_temp$jscomp$1191_has_selection_QMARK_$jscomp$1_span_attrs$$)):$G__70337$jscomp$inline_6913_JSCompiler_inline_result$jscomp$1192_JSCompiler_temp$jscomp$1191_has_selection_QMARK_$jscomp$1_span_attrs$$=null;return $G__70337$jscomp$inline_6913_JSCompiler_inline_result$jscomp$1192_JSCompiler_temp$jscomp$1191_has_selection_QMARK_$jscomp$1_span_attrs$$}return null}(),$APP.$cljs$core$contains_QMARK_$$($self__$jscomp$5041$$.$attrs$,
$APP.$cljs$cst$1757$font_id$$)?$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$wasm_text$resize_wasm_text$$($self__$jscomp$5041$$.id)},$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($app$main$data$workspace$texts$font_loaded_event_QMARK_$$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5041$$.$attrs$)),$stream$jscomp$63$$)))):(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$wasm_text$resize_wasm_text$$($self__$jscomp$5041$$.id))):
null)},$app$main$data$workspace$texts$update_attrs_70334$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_attrs_70334$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2192_temp__5825__auto__$jscomp$209$$,$state$jscomp$590_styles$jscomp$20$$){return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$590_styles$jscomp$20$$,"text-editor/v2")&&($_$jscomp$2192_temp__5825__auto__$jscomp$209$$=$APP.$cljs$cst$2221$workspace_editor$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$590_styles$jscomp$20$$),
$APP.$cljs$core$truth_$$($_$jscomp$2192_temp__5825__auto__$jscomp$209$$)&&$APP.$cljs$core$seq$$(this.$attrs$))?($state$jscomp$590_styles$jscomp$20$$=$app$util$text$content$styles$attrs__GT_styles$$(this.$attrs$),$shadow$js$shim$module$0$0penpot$0text_editor$$.applyStylesToSelection($_$jscomp$2192_temp__5825__auto__$jscomp$209$$,$state$jscomp$590_styles$jscomp$20$$)):null});return new $app$main$data$workspace$texts$update_attrs_70334$$($id$jscomp$635$$,$attrs$jscomp$131$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$texts$apply_typography$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$153$$,$typography$jscomp$20$$,$file_id$jscomp$192$$){typeof $app$main$data$workspace$texts$apply_typography_70347$$==="undefined"&&($app$main$data$workspace$texts$apply_typography_70347$$=function($ids$jscomp$154$$,$typography$jscomp$21$$,$file_id$jscomp$193$$,$meta70348$$){this.ids=$ids$jscomp$154$$;this.typography=$typography$jscomp$21$$;this.$file_id$=$file_id$jscomp$193$$;this.$meta70348$=
$meta70348$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$apply_typography_70347$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$apply_typography_70347$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4035$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_apply_typography$$},$app$main$data$workspace$texts$apply_typography_70347$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70349$$,$meta70348__$1$$){return new $app$main$data$workspace$texts$apply_typography_70347$$(this.ids,this.typography,this.$file_id$,$meta70348__$1$$)},$app$main$data$workspace$texts$apply_typography_70347$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70348$},$app$main$data$workspace$texts$apply_typography_70347$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$apply_typography_70347$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2194_ids__$1$jscomp$17$$,$state$jscomp$591_undo_id$jscomp$35$$){var $editor_state$jscomp$7$$=$APP.$cljs$cst$2222$workspace_editor_state$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$591_undo_id$jscomp$35$$);$_$jscomp$2194_ids__$1$jscomp$17$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$(this.ids,$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$591_undo_id$jscomp$35$$));var $attrs$jscomp$135$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.typography,
$APP.$cljs$cst$1642$typography_ref_file$$,this.$file_id$),$APP.$cljs$cst$1756$typography_ref_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.typography)),$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$]));$state$jscomp$591_undo_id$jscomp$35$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($state$jscomp$591_undo_id$jscomp$35$$)),
$APP.$beicon$v2$core$map$$(function($id$jscomp$637$$){var $editor$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($editor_state$jscomp$7$$,$id$jscomp$637$$);return $APP.$app$main$data$workspace$texts$update_text_attrs$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$id$jscomp$637$$,$APP.$cljs$cst$1594$editor$$,$editor$jscomp$6$$,$APP.$cljs$cst$2645$attrs$$,$attrs$jscomp$135$$],null))},$APP.$beicon$v2$core$from$$($APP.$cljs$core$seq$$($_$jscomp$2194_ids__$1$jscomp$17$$))),
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($state$jscomp$591_undo_id$jscomp$35$$)))});return new $app$main$data$workspace$texts$apply_typography_70347$$($ids$jscomp$153$$,$typography$jscomp$20$$,$file_id$jscomp$192$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$texts$v2_update_text_editor_styles$$=function($id$jscomp$638$$,$new_styles$jscomp$2$$){typeof $app$main$data$workspace$texts$v2_update_text_editor_styles_70361$$==="undefined"&&($app$main$data$workspace$texts$v2_update_text_editor_styles_70361$$=function($id$jscomp$639$$,$new_styles$jscomp$3$$,$meta70362$$){this.id=$id$jscomp$639$$;this.$new_styles$=$new_styles$jscomp$3$$;this.$meta70362$=$meta70362$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$texts$v2_update_text_editor_styles_70361$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$v2_update_text_editor_styles_70361$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4037$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_v2_update_text_editor_styles$$},$app$main$data$workspace$texts$v2_update_text_editor_styles_70361$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70363$$,
$meta70362__$1$$){return new $app$main$data$workspace$texts$v2_update_text_editor_styles_70361$$(this.id,this.$new_styles$,$meta70362__$1$$)},$app$main$data$workspace$texts$v2_update_text_editor_styles_70361$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70362$},$app$main$data$workspace$texts$v2_update_text_editor_styles_70361$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$v2_update_text_editor_styles_70361$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2196_merged_styles$jscomp$1$$,$state$jscomp$593$$){$_$jscomp$2196_merged_styles$jscomp$1$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$get_default_text_attrs$$(),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$593$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,
$APP.$cljs$cst$2201$default_font$$],null)),this.$new_styles$]));var $prev$jscomp$19$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$593$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2223$workspace_v2_editor_state$$,this.id],null));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2196_merged_styles$jscomp$1$$,$prev$jscomp$19$$)?$state$jscomp$593$$:$APP.$cljs$core$assoc_in$$($state$jscomp$593$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2223$workspace_v2_editor_state$$,this.id],null),$_$jscomp$2196_merged_styles$jscomp$1$$)});return new $app$main$data$workspace$texts$v2_update_text_editor_styles_70361$$($id$jscomp$638$$,$new_styles$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$add_geometry_undo_to_commit$$=function($base$jscomp$37$$,$objects$jscomp$520_objects_with_old$$,$id$jscomp$642$$,$old_geom$$,$final_geom$$,$attrs$jscomp$136$$){$objects$jscomp$520_objects_with_old$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$520_objects_with_old$$,$id$jscomp$642$$,function($p1__70370_SHARP_$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__70370_SHARP_$$,
$old_geom$$]))});return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$with_objects$$($base$jscomp$37$$,$objects$jscomp$520_objects_with_old$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$642$$],null),function($shape$jscomp$589$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shape$jscomp$589$$,
$final_geom$$]))},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2645$attrs$$,$attrs$jscomp$136$$],null))};
$app$main$data$workspace$texts$build_finalize_commit_changes$$=function($it$jscomp$204$$,$state$jscomp$596$$,$id$jscomp$643$$,$content_has_text_QMARK__old_geom$jscomp$1_p__70371$$){var $base$jscomp$38_map__70372__$1$$=$APP.$cljs$core$__destructure_map$$($content_has_text_QMARK__old_geom$jscomp$1_p__70371$$),$new_shape_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base$jscomp$38_map__70372__$1$$,$cljs$cst$4040$new_shape_QMARK_$$);$content_has_text_QMARK__old_geom$jscomp$1_p__70371$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base$jscomp$38_map__70372__$1$$,$cljs$cst$4041$content_has_text_QMARK_$$);var $content$jscomp$190$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base$jscomp$38_map__70372__$1$$,$APP.$cljs$cst$1637$content$$),$original_content$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base$jscomp$38_map__70372__$1$$,$APP.$cljs$cst$4042$original_content$$),$update_name_QMARK_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base$jscomp$38_map__70372__$1$$,
$APP.$cljs$cst$4017$update_name_QMARK_$$),$name$jscomp$334$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base$jscomp$38_map__70372__$1$$,$APP.$cljs$cst$725$name$$),$page_id$jscomp$191$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$596$$),$objects$jscomp$521$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$596$$,$page_id$jscomp$191$$),$shape_STAR_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$521$$,
$id$jscomp$643$$);$base$jscomp$38_map__70372__$1$$=function(){var $G__70373$$=function(){var $G__70374$$=$app$common$files$changes_builder$set_text_content$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$($it$jscomp$204$$,$page_id$jscomp$191$$),$objects$jscomp$521$$),$id$jscomp$643$$,$content$jscomp$190$$,$original_content$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($update_name_QMARK_$jscomp$3$$)?
$name$jscomp$334$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape_STAR_$$),$name$jscomp$334$$):$update_name_QMARK_$jscomp$3$$)?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($G__70374$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$643$$],null),function($s$jscomp$547$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$547$$,
$APP.$cljs$cst$725$name$$,$name$jscomp$334$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$],null)],null)):$G__70374$$}();return $APP.$cljs$core$truth_$$($new_shape_QMARK_$jscomp$1$$)?$app$common$files$changes_builder$set_stack_undo_QMARK_$$($APP.$app$common$files$changes_builder$set_undo_group$$($G__70373$$,$id$jscomp$643$$),!0):$G__70373$$}();var $final_geom$jscomp$1$$=
$APP.$cljs$core$select_keys$$($shape_STAR_$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1604$points$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$],null)),$geom_keys$$=$APP.$cljs$core$truth_$$($new_shape_QMARK_$jscomp$1$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1604$points$$],null):new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1604$points$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$],null);$content_has_text_QMARK__old_geom$jscomp$1_p__70371$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($content_has_text_QMARK__old_geom$jscomp$1_p__70371$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1671$fixed$$,$APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape_STAR_$$)):$content_has_text_QMARK__old_geom$jscomp$1_p__70371$$)?
function(){var $or__5025__auto__$jscomp$806_r$jscomp$116$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$596$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4043$workspace_text_session_geom$$,$id$jscomp$643$$],null));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$806_r$jscomp$116$$))return $or__5025__auto__$jscomp$806_r$jscomp$116$$;var $sr$jscomp$1$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape_STAR_$$);
$or__5025__auto__$jscomp$806_r$jscomp$116$$=$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$(function(){var $or__5025__auto____$1$jscomp$95$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($sr$jscomp$1$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$95$$)?$or__5025__auto____$1$jscomp$95$$:0}(),function(){var $or__5025__auto____$1$jscomp$96$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($sr$jscomp$1$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$96$$)?
$or__5025__auto____$1$jscomp$96$$:0}(),.01,.01);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1605$selrect$$,$or__5025__auto__$jscomp$806_r$jscomp$116$$,$APP.$cljs$cst$1604$points$$,$APP.$app$common$geom$rect$rect__GT_points$$($or__5025__auto__$jscomp$806_r$jscomp$116$$)],null)}():null;return $content_has_text_QMARK__old_geom$jscomp$1_p__70371$$!=null?$app$main$data$workspace$texts$add_geometry_undo_to_commit$$($base$jscomp$38_map__70372__$1$$,$objects$jscomp$521$$,$id$jscomp$643$$,
$APP.$cljs$core$select_keys$$($content_has_text_QMARK__old_geom$jscomp$1_p__70371$$,$geom_keys$$),$APP.$cljs$core$select_keys$$($final_geom$jscomp$1$$,$geom_keys$$),$geom_keys$$):$base$jscomp$38_map__70372__$1$$};
$app$main$data$workspace$texts$v2_update_text_shape_content$$=function($var_args$jscomp$1286$$){for(var $args__5755__auto__$jscomp$230$$=[],$len__5749__auto___70650$$=arguments.length,$i__5750__auto___70651$$=0;;)if($i__5750__auto___70651$$<$len__5749__auto___70650$$)$args__5755__auto__$jscomp$230$$.push(arguments[$i__5750__auto___70651$$]),$i__5750__auto___70651$$+=1;else break;return $APP.$app$main$data$workspace$texts$v2_update_text_shape_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
arguments[1],2<$args__5755__auto__$jscomp$230$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$230$$.slice(2),0,null):null)};
$APP.$app$main$data$workspace$texts$v2_update_text_shape_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($id$jscomp$644$$,$content$jscomp$191$$,$p__70378$$){var $map__70379__$1$$=$APP.$cljs$core$__destructure_map$$($p__70378$$),$update_name_QMARK_$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__70379__$1$$,$APP.$cljs$cst$4017$update_name_QMARK_$$,!1),$name$jscomp$335$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__70379__$1$$,$APP.$cljs$cst$725$name$$,
null),$finalize_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__70379__$1$$,$APP.$cljs$cst$4044$finalize_QMARK_$$,!1),$save_undo_QMARK_$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__70379__$1$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!0),$original_content$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__70379__$1$$,$APP.$cljs$cst$4042$original_content$$,null);typeof $app$main$data$workspace$texts$v2_update_text_shape_content_70380$$===
"undefined"&&($app$main$data$workspace$texts$v2_update_text_shape_content_70380$$=function($save_undo_QMARK_$jscomp$11$$,$map__70379$jscomp$1$$,$finalize_QMARK_$jscomp$1$$,$original_content$jscomp$2$$,$content$jscomp$192$$,$name$jscomp$336$$,$p__70378$jscomp$1$$,$id$jscomp$645$$,$update_name_QMARK_$jscomp$5$$,$meta70381$$){this.$save_undo_QMARK_$=$save_undo_QMARK_$jscomp$11$$;this.$map__70379$=$map__70379$jscomp$1$$;this.$finalize_QMARK_$=$finalize_QMARK_$jscomp$1$$;this.$original_content$=$original_content$jscomp$2$$;
this.content=$content$jscomp$192$$;this.name=$name$jscomp$336$$;this.$p__70378$=$p__70378$jscomp$1$$;this.id=$id$jscomp$645$$;this.$update_name_QMARK_$=$update_name_QMARK_$jscomp$5$$;this.$meta70381$=$meta70381$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$v2_update_text_shape_content_70380$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$v2_update_text_shape_content_70380$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4045$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_v2_update_text_shape_content$$},$app$main$data$workspace$texts$v2_update_text_shape_content_70380$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70382$$,$meta70381__$1$$){return new $app$main$data$workspace$texts$v2_update_text_shape_content_70380$$(this.$save_undo_QMARK_$,this.$map__70379$,this.$finalize_QMARK_$,this.$original_content$,this.content,this.name,this.$p__70378$,this.id,this.$update_name_QMARK_$,
$meta70381__$1$$)},$app$main$data$workspace$texts$v2_update_text_shape_content_70380$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70381$},$app$main$data$workspace$texts$v2_update_text_shape_content_70380$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$v2_update_text_shape_content_70380$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$205_new_size$jscomp$3_objects$jscomp$522$$,$state$jscomp$597$$){var $self__$jscomp$5071$$=
this;if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$597$$,"render-wasm/v1")){var $finalize_QMARK___$1$$=$APP.$cljs$core$boolean$0$$($self__$jscomp$5071$$.$finalize_QMARK_$);$it$jscomp$205_new_size$jscomp$3_objects$jscomp$522$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$597$$);var $shape$jscomp$590$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$205_new_size$jscomp$3_objects$jscomp$522$$,$self__$jscomp$5071$$.id),
$new_shape_QMARK_$jscomp$2$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$3643$workspace_new_text_shapes$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$597$$),$self__$jscomp$5071$$.id),$prev_content$jscomp$2$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$590$$),$has_prev_content_QMARK_$$=$cljs$cst$4046$prev_content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$590$$)!=null,$session_start_geom$$=function(){var $or__5025__auto__$jscomp$807$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$597$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4043$workspace_text_session_geom$$,$self__$jscomp$5071$$.id],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$807$$)?$or__5025__auto__$jscomp$807$$:$APP.$cljs$core$select_keys$$($shape$jscomp$590$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1604$points$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$],
null))}(),$content_has_text_QMARK_$jscomp$1$$=$app$main$data$workspace$texts$v2_content_has_text_QMARK_$$($self__$jscomp$5071$$.content),$prev_content_has_text_QMARK_$$=$app$main$data$workspace$texts$v2_content_has_text_QMARK_$$($prev_content$jscomp$2$$);$it$jscomp$205_new_size$jscomp$3_objects$jscomp$522$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1671$fixed$$,$APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$590$$))?$APP.$app$main$data$workspace$wasm_text$get_wasm_text_new_size$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$590$$,
$self__$jscomp$5071$$.content):null;var $effective_save_undo_QMARK__finalize_save_undo_first_QMARK_$$=$new_shape_QMARK_$jscomp$2$$?$finalize_QMARK___$1$$:$self__$jscomp$5071$$.$save_undo_QMARK_$,$effective_stack_undo_QMARK_$$=$new_shape_QMARK_$jscomp$2$$&&$finalize_QMARK___$1$$;$effective_save_undo_QMARK__finalize_save_undo_first_QMARK_$$=!$finalize_QMARK___$1$$||$new_shape_QMARK_$jscomp$2$$&&$content_has_text_QMARK_$jscomp$1$$?$effective_save_undo_QMARK__finalize_save_undo_first_QMARK_$$:!1;return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($new_shape_QMARK_$jscomp$2$$||
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$597$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4043$workspace_text_session_geom$$,$self__$jscomp$5071$$.id],null))!=null?null:function($s$jscomp$548$$){return $APP.$cljs$core$assoc_in$$($s$jscomp$548$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4043$workspace_text_session_geom$$,$self__$jscomp$5071$$.id],
null),$session_start_geom$$)},$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$5071$$.id],null),function($shape__$1$jscomp$46$$){var $G__70383$$=function(){var $G__70384_G__70385$jscomp$inline_6916$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$46$$,$APP.$cljs$cst$1637$content$$,$self__$jscomp$5071$$.content);$G__70384_G__70385$jscomp$inline_6916$$=
!$new_shape_QMARK_$jscomp$2$$&&$content_has_text_QMARK_$jscomp$1$$&&$has_prev_content_QMARK_$$?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__70384_G__70385$jscomp$inline_6916$$,$cljs$cst$4046$prev_content$$):$G__70384_G__70385$jscomp$inline_6916$$;return $new_shape_QMARK_$jscomp$2$$||!$prev_content_has_text_QMARK_$$||$content_has_text_QMARK_$jscomp$1$$||$finalize_QMARK___$1$$?$G__70384_G__70385$jscomp$inline_6916$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70384_G__70385$jscomp$inline_6916$$,
$cljs$cst$4046$prev_content$$,$prev_content$jscomp$2$$)}();return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$485$$=$self__$jscomp$5071$$.$update_name_QMARK_$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$485$$)?$self__$jscomp$5071$$.name!=null:$and__5023__auto__$jscomp$485$$}())?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70383$$,$APP.$cljs$cst$725$name$$,$self__$jscomp$5071$$.name):$G__70383$$},new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3140$save_undo_QMARK_$$,
$effective_save_undo_QMARK__finalize_save_undo_first_QMARK_$$,$APP.$cljs$cst$3141$stack_undo_QMARK_$$,$effective_stack_undo_QMARK_$$,$APP.$cljs$cst$3138$undo_group$$,$new_shape_QMARK_$jscomp$2$$?$self__$jscomp$5071$$.id:null],null)),$it$jscomp$205_new_size$jscomp$3_objects$jscomp$522$$!=null?function(){var $temp__5825__auto__$jscomp$210$$=$APP.$app$main$data$workspace$wasm_text$resize_wasm_text_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$590$$,$self__$jscomp$5071$$.content);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$210$$)?
$finalize_QMARK___$1$$?$APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($temp__5825__auto__$jscomp$210$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3138$undo_group$$,$new_shape_QMARK_$jscomp$2$$?$self__$jscomp$5071$$.id:null],null)])):$APP.$app$main$data$workspace$modifiers$set_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($temp__5825__auto__$jscomp$210$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3138$undo_group$$,$new_shape_QMARK_$jscomp$2$$?$self__$jscomp$5071$$.id:null],null)])):null}():null),$finalize_QMARK___$1$$?$APP.$beicon$v2$core$concat$$($content_has_text_QMARK_$jscomp$1$$||$self__$jscomp$5071$$.id==null?$APP.$beicon$v2$core$empty$$():$APP.$beicon$v2$core$concat$$($self__$jscomp$5071$$.$original_content$!=null&&$app$main$data$workspace$texts$v2_content_has_text_QMARK_$$($self__$jscomp$5071$$.$original_content$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$5071$$.id],null),function($s$jscomp$549$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$549$$,$APP.$cljs$cst$1637$content$$,$self__$jscomp$5071$$.$original_content$),$cljs$cst$4046$prev_content$$)},
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3140$save_undo_QMARK_$$,!1],null))):$APP.$beicon$v2$core$empty$$(),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$deselect_shape$$($self__$jscomp$5071$$.id),$APP.$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$self__$jscomp$5071$$.id])))),$APP.$beicon$v2$core$concat$$($content_has_text_QMARK_$jscomp$1$$?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($app$main$data$workspace$texts$build_finalize_commit_changes$$(this,
$state$jscomp$597$$,$self__$jscomp$5071$$.id,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$4040$new_shape_QMARK_$$,$new_shape_QMARK_$jscomp$2$$,$cljs$cst$4041$content_has_text_QMARK_$$,$content_has_text_QMARK_$jscomp$1$$,$APP.$cljs$cst$1637$content$$,$self__$jscomp$5071$$.content,$APP.$cljs$cst$4042$original_content$$,$self__$jscomp$5071$$.$original_content$,$APP.$cljs$cst$4017$update_name_QMARK_$$,$self__$jscomp$5071$$.$update_name_QMARK_$,$APP.$cljs$cst$725$name$$,$self__$jscomp$5071$$.name],
null)))):$APP.$beicon$v2$core$empty$$(),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$transforms$finish_transform$$(),function($state__$1$jscomp$28$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state__$1$jscomp$28$$,$APP.$cljs$cst$3643$workspace_new_text_shapes$$,$APP.$cljs$core$disj$$,$self__$jscomp$5071$$.id),$cljs$cst$4043$workspace_text_session_geom$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$dissoc$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$),$self__$jscomp$5071$$.id)}))):null)}var $modifiers$jscomp$96$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$597$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2238$workspace_text_modifier$$,$self__$jscomp$5071$$.id],null));$new_shape_QMARK_$jscomp$2$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$3643$workspace_new_text_shapes$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$597$$),
$self__$jscomp$5071$$.id);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$5071$$.id],null),function($shape$jscomp$591$$){var $G__70387_map__70386__$1$$=$APP.$cljs$core$__destructure_map$$($modifiers$jscomp$96$$),$width$jscomp$143$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__70387_map__70386__$1$$,$APP.$cljs$cst$290$width$$),
$height$jscomp$129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__70387_map__70386__$1$$,$APP.$cljs$cst$1522$height$$),$position_data$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__70387_map__70386__$1$$,$APP.$cljs$cst$1891$position_data$$);$G__70387_map__70386__$1$$=function(){var $G__70388$$=function(){var $G__70389$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$591$$,$APP.$cljs$cst$1637$content$$,$self__$jscomp$5071$$.content);return $APP.$cljs$core$truth_$$($position_data$jscomp$14$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70389$$,$APP.$cljs$cst$1891$position_data$$,$position_data$jscomp$14$$):$G__70389$$}();return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$486$$=$self__$jscomp$5071$$.$update_name_QMARK_$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$486$$)?$self__$jscomp$5071$$.name!=null:$and__5023__auto__$jscomp$486$$}())?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70388$$,$APP.$cljs$cst$725$name$$,$self__$jscomp$5071$$.name):
$G__70388$$}();return $width$jscomp$143$$!=null||$height$jscomp$129$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__70387_map__70386__$1$$,$APP.$app$common$types$modifiers$change_size$$($shape$jscomp$591$$,$width$jscomp$143$$,$height$jscomp$129$$)):$G__70387_map__70386__$1$$},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3138$undo_group$$,$new_shape_QMARK_$jscomp$2$$?$self__$jscomp$5071$$.id:null],null)))});return new $app$main$data$workspace$texts$v2_update_text_shape_content_70380$$($save_undo_QMARK_$jscomp$10$$,
$map__70379__$1$$,$finalize_QMARK_$$,$original_content$jscomp$1$$,$content$jscomp$191$$,$name$jscomp$335$$,$p__70378$$,$id$jscomp$644$$,$update_name_QMARK_$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$util$code_beautify$format_code$$=function($G__68747__$1_code$jscomp$42$$,$type$jscomp$485_type__$1$jscomp$6$$){$type$jscomp$485_type__$1$jscomp$6$$=$type$jscomp$485_type__$1$jscomp$6$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$($type$jscomp$485_type__$1$jscomp$6$$):$type$jscomp$485_type__$1$jscomp$6$$;$G__68747__$1_code$jscomp$42$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$485_type__$1$jscomp$6$$,"svg")?$APP.$cuerdas$core$replace$$($APP.$cuerdas$core$replace$$($G__68747__$1_code$jscomp$42$$,
"\x3cdefs\x3e\x3c/defs\x3e",""),"\x3e\x3c","\x3e\n\x3c"):$G__68747__$1_code$jscomp$42$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$485_type__$1$jscomp$6$$,"svg")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$485_type__$1$jscomp$6$$,"html")?$shadow$js$shim$module$0js_beautify$$.html($G__68747__$1_code$jscomp$42$$,{indent_size:2}):$G__68747__$1_code$jscomp$42$$};
$app$util$code_gen$markup_svg$generate_single_svg$$=function($objects$jscomp$523$$,$shape$jscomp$594$$){return $shadow$js$shim$module$0react_dom$0server$$.renderToStaticMarkup($rumext$v2$element$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$render$object_svg$$,{objects:$objects$jscomp$523$$,"object-id":$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$594$$)}))};
$APP.$app$util$code_gen$markup_svg$generate_markup$$=function($objects$jscomp$526$$,$shapes$jscomp$110$$){switch($APP.$cljs$core$count$$($shapes$jscomp$110$$)){case 0:return"";case 1:return $app$util$code_gen$markup_svg$generate_single_svg$$($objects$jscomp$526$$,$APP.$cljs$core$first$$($shapes$jscomp$110$$));default:return $shadow$js$shim$module$0react_dom$0server$$.renderToStaticMarkup($rumext$v2$element$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$render$objects_svg$$,{objects:$objects$jscomp$526$$,
"object-ids":$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$shapes$jscomp$110$$)}))}};
$app$util$code_gen$common$shape__GT_selector$$=function($id$jscomp$646_selector$jscomp$14_shape$jscomp$596$$){if($APP.$cljs$core$truth_$$($id$jscomp$646_selector$jscomp$14_shape$jscomp$596$$)){var $JSCompiler_temp_const$jscomp$1194_name$jscomp$337_name__$1$jscomp$9$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1193$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$646_selector$jscomp$14_shape$jscomp$596$$),$y__5114__auto__$jscomp$inline_6918$$=
$APP.$cljs$core$count$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$646_selector$jscomp$14_shape$jscomp$596$$));$JSCompiler_temp_const$jscomp$1194_name$jscomp$337_name__$1$jscomp$9$$=$APP.$cuerdas$core$replace$$($JSCompiler_temp_const$jscomp$1194_name$jscomp$337_name__$1$jscomp$9$$.call($APP.$cljs$core$subs$$,$JSCompiler_temp_const$jscomp$1193$$,0,10<$y__5114__auto__$jscomp$inline_6918$$?10:$y__5114__auto__$jscomp$inline_6918$$),/[^a-zA-Z0-9\s:]+/,"");$JSCompiler_temp_const$jscomp$1194_name$jscomp$337_name__$1$jscomp$9$$=
$APP.$cljs$core$truth_$$($APP.$cljs$core$re_matches$$(/^\d.*/,$JSCompiler_temp_const$jscomp$1194_name$jscomp$337_name__$1$jscomp$9$$))?"c-"+($JSCompiler_temp_const$jscomp$1194_name$jscomp$337_name__$1$jscomp$9$$??""):$JSCompiler_temp_const$jscomp$1194_name$jscomp$337_name__$1$jscomp$9$$;$id$jscomp$646_selector$jscomp$14_shape$jscomp$596$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$(""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$646_selector$jscomp$14_shape$jscomp$596$$)??
""),24,36);$id$jscomp$646_selector$jscomp$14_shape$jscomp$596$$=$APP.$cuerdas$core$css_selector$$(""+($JSCompiler_temp_const$jscomp$1194_name$jscomp$337_name__$1$jscomp$9$$??"")+" "+($id$jscomp$646_selector$jscomp$14_shape$jscomp$596$$??""));return $APP.$cuerdas$core$starts_with_QMARK_$$($id$jscomp$646_selector$jscomp$14_shape$jscomp$596$$,"-")?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$646_selector$jscomp$14_shape$jscomp$596$$,1):$id$jscomp$646_selector$jscomp$14_shape$jscomp$596$$}return""};
$app$util$code_gen$common$svg_markup_QMARK_$$=function($shape$jscomp$597$$){return $APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$597$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$597$$)||$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$597$$)||$APP.$cljs$cst$1890$svg_attrs$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$597$$)!=null||$APP.$app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$597$$)||
$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$597$$)&&($APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$597$$))||$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$597$$)))||$APP.$cljs$core$count$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$597$$))>1||$APP.$cljs$core$count$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$597$$))>
1||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$597$$)),1)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1868$stroke_alignment$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$597$$))),$APP.$cljs$cst$2041$inner$$)};
$app$util$code_gen$common$has_wrapper_QMARK_$$=function($objects$jscomp$528$$,$shape$jscomp$598$$){return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$528$$,$shape$jscomp$598$$)&&$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$598$$))&&!$app$common$geom$matrix$unit_QMARK_$$($APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$598$$))};
$app$util$code_gen$style_css_formats$format_color_value$$=function($opacity_color_value$jscomp$570$$,$format$jscomp$32_image_url$jscomp$1_options$jscomp$528$$){$format$jscomp$32_image_url$jscomp$1_options$jscomp$528$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($format$jscomp$32_image_url$jscomp$1_options$jscomp$528$$,$APP.$cljs$cst$954$format$$,$APP.$cljs$cst$2687$hex$$);if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($opacity_color_value$jscomp$570$$)))return $format$jscomp$32_image_url$jscomp$1_options$jscomp$528$$=
$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($opacity_color_value$jscomp$570$$)),$opacity_color_value$jscomp$570$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($opacity_color_value$jscomp$570$$),1)?$app$util$color$gradient__GT_css$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$287$linear$$,$APP.$cljs$cst$1733$stops$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,"#FFFFFF",$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($opacity_color_value$jscomp$570$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,"#FFFFFF",$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($opacity_color_value$jscomp$570$$)],
null)],null)],null)):null,$APP.$cljs$core$truth_$$($opacity_color_value$jscomp$570$$)?""+($opacity_color_value$jscomp$570$$??"")+", url("+($format$jscomp$32_image_url$jscomp$1_options$jscomp$528$$??"")+") no-repeat center center / cover":"url("+($format$jscomp$32_image_url$jscomp$1_options$jscomp$528$$??"")+") no-repeat center center / cover";$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($opacity_color_value$jscomp$570$$),1);
return $app$util$color$color__GT_format__GT_background$$($opacity_color_value$jscomp$570$$,$format$jscomp$32_image_url$jscomp$1_options$jscomp$528$$)};
$app$util$code_gen$style_css_formats$format_shadow__GT_css$$=function($p__68888_style$jscomp$43$$,$css_color_options$jscomp$529$$){var $color$jscomp$68_map__68889__$1$$=$APP.$cljs$core$__destructure_map$$($p__68888_style$jscomp$43$$);$p__68888_style$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$68_map__68889__$1$$,$APP.$cljs$cst$1904$style$$);var $offset_x$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$68_map__68889__$1$$,$APP.$cljs$cst$1650$offset_x$$),
$offset_y$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$68_map__68889__$1$$,$APP.$cljs$cst$1651$offset_y$$),$blur$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$68_map__68889__$1$$,$APP.$cljs$cst$1653$blur$$),$spread$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$68_map__68889__$1$$,$APP.$cljs$cst$1652$spread$$);$color$jscomp$68_map__68889__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$68_map__68889__$1$$,
$APP.$cljs$cst$1298$color$$);$css_color_options$jscomp$529$$=$app$util$code_gen$style_css_formats$format_color_value$$($color$jscomp$68_map__68889__$1$$,$css_color_options$jscomp$529$$);return($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__68888_style$jscomp$43$$,$cljs$cst$1907$inner_shadow$$)?"inset ":"")+(($APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$6$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$6$("%spx %spx %spx %spx %s",$offset_x$jscomp$8$$,$offset_y$jscomp$8$$,
$blur$jscomp$9$$,$spread$jscomp$5$$,$css_color_options$jscomp$529$$):$APP.$cuerdas$core$format$$("%spx %spx %spx %spx %s",$offset_x$jscomp$8$$,$offset_y$jscomp$8$$,$blur$jscomp$9$$,$spread$jscomp$5$$,$css_color_options$jscomp$529$$))??"")};
$app$util$code_gen$style_css_formats$format_color$$=function($value$jscomp$573$$,$options$jscomp$530$$){var $format$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$530$$,$APP.$cljs$cst$954$format$$,$APP.$cljs$cst$2687$hex$$);return $app$util$code_gen$style_css_formats$format_color_value$$($value$jscomp$573$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$530$$,$APP.$cljs$cst$954$format$$,$format$jscomp$33$$))};
$app$util$code_gen$style_css_formats$format_color_array$$=function($value$jscomp$574$$,$options$jscomp$531$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68891_SHARP_$$){return $app$util$code_gen$style_css_formats$format_color_value$$($p1__68891_SHARP_$$,$options$jscomp$531$$)},$value$jscomp$574$$))};
$app$util$code_gen$style_css_formats$format_tracks$$=function($value$jscomp$581$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__68902_type$jscomp$486$$){var $map__68903__$1_value__$1$jscomp$18$$=$APP.$cljs$core$__destructure_map$$($p__68902_type$jscomp$486$$);$p__68902_type$jscomp$486$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68903__$1_value__$1$jscomp$18$$,$APP.$cljs$cst$139$type$$);$map__68903__$1_value__$1$jscomp$18$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68903__$1_value__$1$jscomp$18$$,$APP.$cljs$cst$260$value$$);switch($p__68902_type$jscomp$486$$ instanceof $APP.$cljs$core$Keyword$$?$p__68902_type$jscomp$486$$.$fqn$:null){case "flex":return""+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($map__68903__$1_value__$1$jscomp$18$$)??"")+"fr";case "percent":return $APP.$app$main$ui$formats$format_percent$cljs$0core$0IFn$0_invoke$0arity$02$$($map__68903__$1_value__$1$jscomp$18$$/
100,null);case "auto":return"auto";default:return $APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($map__68903__$1_value__$1$jscomp$18$$)}},$value$jscomp$581$$))};
$app$util$code_gen$style_css_formats$format_shadow$$=function($value$jscomp$582$$,$options$jscomp$534$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68905_SHARP_$$){return $app$util$code_gen$style_css_formats$format_shadow__GT_css$$($p1__68905_SHARP_$$,$options$jscomp$534$$)},$value$jscomp$582$$))};
$app$util$code_gen$style_css_formats$format_value$$=function($G__68906_property$jscomp$32_style$jscomp$inline_6928$$,$color$jscomp$inline_6927_value$jscomp$585$$,$options$jscomp$535$$){$G__68906_property$jscomp$32_style$jscomp$inline_6928$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$util$code_gen$style_css_formats$css_formatters$$,$G__68906_property$jscomp$32_style$jscomp$inline_6928$$);switch($G__68906_property$jscomp$32_style$jscomp$inline_6928$$ instanceof $APP.$cljs$core$Keyword$$?
$G__68906_property$jscomp$32_style$jscomp$inline_6928$$.$fqn$:null){case "position":return typeof $color$jscomp$inline_6927_value$jscomp$585$$==="number"?$APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$inline_6927_value$jscomp$585$$):$color$jscomp$inline_6927_value$jscomp$585$$;case "size":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$inline_6927_value$jscomp$585$$,$APP.$cljs$cst$1403$fill$$)?"100%":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$inline_6927_value$jscomp$585$$,
$APP.$cljs$cst$1672$auto$$)?"auto":typeof $color$jscomp$inline_6927_value$jscomp$585$$==="number"?$APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$inline_6927_value$jscomp$585$$):$color$jscomp$inline_6927_value$jscomp$585$$;case "color":return $app$util$code_gen$style_css_formats$format_color$$($color$jscomp$inline_6927_value$jscomp$585$$,$options$jscomp$535$$);case "color-array":return $app$util$code_gen$style_css_formats$format_color_array$$($color$jscomp$inline_6927_value$jscomp$585$$,
$options$jscomp$535$$);case "border":var $map__68896__$1$jscomp$inline_6926_width$jscomp$inline_6929$$=$APP.$cljs$core$__destructure_map$$($color$jscomp$inline_6927_value$jscomp$585$$);$color$jscomp$inline_6927_value$jscomp$585$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68896__$1$jscomp$inline_6926_width$jscomp$inline_6929$$,$APP.$cljs$cst$1298$color$$);$G__68906_property$jscomp$32_style$jscomp$inline_6928$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68896__$1$jscomp$inline_6926_width$jscomp$inline_6929$$,
$APP.$cljs$cst$1904$style$$);$map__68896__$1$jscomp$inline_6926_width$jscomp$inline_6929$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68896__$1$jscomp$inline_6926_width$jscomp$inline_6929$$,$APP.$cljs$cst$290$width$$);return""+($APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($map__68896__$1$jscomp$inline_6926_width$jscomp$inline_6929$$)??"")+" "+($APP.$app$common$data$name$$($G__68906_property$jscomp$32_style$jscomp$inline_6928$$)??"")+" "+($app$util$code_gen$style_css_formats$format_color_value$$($color$jscomp$inline_6927_value$jscomp$585$$,
$options$jscomp$535$$)??"");case "border-style":return $APP.$app$common$data$name$$($APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$inline_6927_value$jscomp$585$$));case "border-width":return $APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$inline_6927_value$jscomp$585$$));case "border-color":return $app$util$code_gen$style_css_formats$format_color$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$inline_6927_value$jscomp$585$$),
$options$jscomp$535$$);case "size-array":return $APP.$cljs$core$coll_QMARK_$$($color$jscomp$inline_6927_value$jscomp$585$$)&&$APP.$app$common$data$not_empty_QMARK_$$($color$jscomp$inline_6927_value$jscomp$585$$)?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$ui$formats$format_pixels$$,$color$jscomp$inline_6927_value$jscomp$585$$)):$color$jscomp$inline_6927_value$jscomp$585$$!=null?$color$jscomp$inline_6927_value$jscomp$585$$:
null;case "string-or-size-array":return typeof $color$jscomp$inline_6927_value$jscomp$585$$==="string"?$color$jscomp$inline_6927_value$jscomp$585$$:$APP.$cljs$core$coll_QMARK_$$($color$jscomp$inline_6927_value$jscomp$585$$)&&$APP.$app$common$data$not_empty_QMARK_$$($color$jscomp$inline_6927_value$jscomp$585$$)?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$ui$formats$format_pixels$$,$color$jscomp$inline_6927_value$jscomp$585$$)):
$color$jscomp$inline_6927_value$jscomp$585$$!=null?$color$jscomp$inline_6927_value$jscomp$585$$:null;case "keyword":return $APP.$app$common$data$name$$($color$jscomp$inline_6927_value$jscomp$585$$);case "tracks":return $app$util$code_gen$style_css_formats$format_tracks$$($color$jscomp$inline_6927_value$jscomp$585$$);case "shadows":return $app$util$code_gen$style_css_formats$format_shadow$$($color$jscomp$inline_6927_value$jscomp$585$$,$options$jscomp$535$$);case "blur":return"blur("+($APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$inline_6927_value$jscomp$585$$)??
"")+")";case "matrix":return $app$main$ui$formats$format_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$inline_6927_value$jscomp$585$$);default:return $color$jscomp$inline_6927_value$jscomp$585$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$app$common$data$name$$($color$jscomp$inline_6927_value$jscomp$585$$):$color$jscomp$inline_6927_value$jscomp$585$$}};
$app$util$code_gen$style_css_values$get_shape_position$$=function($param49239$jscomp$inline_12677_shape$jscomp$599_vec__68919$$,$objects$jscomp$529_parent_value$$,$coord$jscomp$16$$){var $JSCompiler_inline_result$jscomp$1203_and__5023__auto__$jscomp$inline_6938_or__5025__auto__$jscomp$inline_6939_parent$jscomp$267_selrect$jscomp$68$$;if($JSCompiler_inline_result$jscomp$1203_and__5023__auto__$jscomp$inline_6938_or__5025__auto__$jscomp$inline_6939_parent$jscomp$267_selrect$jscomp$68$$=!$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($param49239$jscomp$inline_12677_shape$jscomp$599_vec__68919$$))$JSCompiler_inline_result$jscomp$1203_and__5023__auto__$jscomp$inline_6938_or__5025__auto__$jscomp$inline_6939_parent$jscomp$267_selrect$jscomp$68$$=
($JSCompiler_inline_result$jscomp$1203_and__5023__auto__$jscomp$inline_6938_or__5025__auto__$jscomp$inline_6939_parent$jscomp$267_selrect$jscomp$68$$=!$APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$529_parent_value$$,$param49239$jscomp$inline_12677_shape$jscomp$599_vec__68919$$))?$JSCompiler_inline_result$jscomp$1203_and__5023__auto__$jscomp$inline_6938_or__5025__auto__$jscomp$inline_6939_parent$jscomp$267_selrect$jscomp$68$$:$APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($param49239$jscomp$inline_12677_shape$jscomp$599_vec__68919$$);
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1203_and__5023__auto__$jscomp$inline_6938_or__5025__auto__$jscomp$inline_6939_parent$jscomp$267_selrect$jscomp$68$$)?($JSCompiler_inline_result$jscomp$1203_and__5023__auto__$jscomp$inline_6938_or__5025__auto__$jscomp$inline_6939_parent$jscomp$267_selrect$jscomp$68$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$529_parent_value$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($param49239$jscomp$inline_12677_shape$jscomp$599_vec__68919$$)),
$objects$jscomp$529_parent_value$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1203_and__5023__auto__$jscomp$inline_6938_or__5025__auto__$jscomp$inline_6939_parent$jscomp$267_selrect$jscomp$68$$,$APP.$cljs$cst$1605$selrect$$),$coord$jscomp$16$$),$param49239$jscomp$inline_12677_shape$jscomp$599_vec__68919$$=$app$common$geom$shapes$transform_points$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($param49239$jscomp$inline_12677_shape$jscomp$599_vec__68919$$),
$APP.$app$common$geom$shapes$common$shape__GT_center$$($JSCompiler_inline_result$jscomp$1203_and__5023__auto__$jscomp$inline_6938_or__5025__auto__$jscomp$inline_6939_parent$jscomp$267_selrect$jscomp$68$$),$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1203_and__5023__auto__$jscomp$inline_6938_or__5025__auto__$jscomp$inline_6939_parent$jscomp$267_selrect$jscomp$68$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$())),$param49239$jscomp$inline_12677_shape$jscomp$599_vec__68919$$=
$app$common$geom$shapes$transforms$calculate_geometry$$($param49239$jscomp$inline_12677_shape$jscomp$599_vec__68919$$),$JSCompiler_inline_result$jscomp$1203_and__5023__auto__$jscomp$inline_6938_or__5025__auto__$jscomp$inline_6939_parent$jscomp$267_selrect$jscomp$68$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($param49239$jscomp$inline_12677_shape$jscomp$599_vec__68919$$,0,null),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($param49239$jscomp$inline_12677_shape$jscomp$599_vec__68919$$,
1,null),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($param49239$jscomp$inline_12677_shape$jscomp$599_vec__68919$$,2,null),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1203_and__5023__auto__$jscomp$inline_6938_or__5025__auto__$jscomp$inline_6939_parent$jscomp$267_selrect$jscomp$68$$,$coord$jscomp$16$$)-$objects$jscomp$529_parent_value$$):null};
$app$util$code_gen$style_css_values$get_shape_size$$=function($G__68932_shape$jscomp$600$$,$objects$jscomp$530$$,$type$jscomp$487$$){var $parent$jscomp$268$$=$app$common$files$helpers$get_parent$$($objects$jscomp$530$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__68932_shape$jscomp$600$$)),$sizing$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$487$$,$APP.$cljs$cst$290$width$$)?$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($G__68932_shape$jscomp$600$$):
$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($G__68932_shape$jscomp$600$$);return $APP.$app$common$types$shape$layout$flex_layout_immediate_child_QMARK_$$($objects$jscomp$530$$,$G__68932_shape$jscomp$600$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$487$$,$APP.$cljs$cst$1522$height$$)&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1661$row_reverse$$,
null,$APP.$cljs$cst$1656$row$$,null],null),null),$APP.$cljs$cst$1679$layout_flex_dir$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$268$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($G__68932_shape$jscomp$600$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$487$$,$APP.$cljs$cst$290$width$$)&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$216$column$$,null,$APP.$cljs$cst$1662$column_reverse$$,null],null),null),$APP.$cljs$cst$1679$layout_flex_dir$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$268$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($G__68932_shape$jscomp$600$$)))?$APP.$cljs$cst$1403$fill$$:$APP.$app$common$types$shape$layout$flex_layout_immediate_child_QMARK_$$($objects$jscomp$530$$,
$G__68932_shape$jscomp$600$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($sizing$jscomp$2$$,$APP.$cljs$cst$1403$fill$$)?null:$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__68932_shape$jscomp$600$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($sizing$jscomp$2$$,$APP.$cljs$cst$1672$auto$$)&&!$app$util$code_gen$common$svg_markup_QMARK_$$($G__68932_shape$jscomp$600$$)||$APP.$app$common$types$shape$layout$grid_layout_immediate_child_QMARK_$$($objects$jscomp$530$$,
$G__68932_shape$jscomp$600$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($sizing$jscomp$2$$,$APP.$cljs$cst$1403$fill$$)?$sizing$jscomp$2$$:$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($G__68932_shape$jscomp$600$$)!=null?($G__68932_shape$jscomp$600$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($G__68932_shape$jscomp$600$$),$type$jscomp$487$$.$cljs$core$IFn$_invoke$arity$1$?$type$jscomp$487$$.$cljs$core$IFn$_invoke$arity$1$($G__68932_shape$jscomp$600$$):
$type$jscomp$487$$($G__68932_shape$jscomp$600$$)):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68932_shape$jscomp$600$$,$type$jscomp$487$$)!=null?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__68932_shape$jscomp$600$$,$type$jscomp$487$$):null};
$app$util$code_gen$style_css_values$get_stroke_data$$=function($stroke$jscomp$14$$){var $width$jscomp$145$$=$APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$14$$),$style$jscomp$45$$=$APP.$cljs$cst$1866$stroke_style$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$14$$),$color$jscomp$70$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1739$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$14$$),$APP.$cljs$cst$1734$opacity$$,
$APP.$cljs$cst$1740$stroke_opacity$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$14$$),$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$cst$1741$stroke_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$14$$)],null);return $stroke$jscomp$14$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$226$none$$,$APP.$cljs$cst$1866$stroke_style$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$14$$))?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1298$color$$,
$color$jscomp$70$$,$APP.$cljs$cst$1904$style$$,$style$jscomp$45$$,$APP.$cljs$cst$290$width$$,$width$jscomp$145$$],null):null};
$app$util$code_gen$style_css_values$area_cell_QMARK_$$=function($p__68933_position$jscomp$101$$){var $area_name$jscomp$1_map__68934__$1$$=$APP.$cljs$core$__destructure_map$$($p__68933_position$jscomp$101$$);$p__68933_position$jscomp$101$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($area_name$jscomp$1_map__68934__$1$$,$APP.$cljs$cst$1676$position$$);$area_name$jscomp$1_map__68934__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($area_name$jscomp$1_map__68934__$1$$,$APP.$cljs$cst$1675$area_name$$);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__68933_position$jscomp$101$$,$APP.$cljs$cst$1674$area$$)&&$APP.$app$common$data$not_empty_QMARK_$$($area_name$jscomp$1_map__68934__$1$$)};
$app$util$code_gen$style_css_values$get_grid_coord$$=function($cell$jscomp$38_shape$jscomp$601$$,$objects$jscomp$531_parent$jscomp$269$$,$prop$jscomp$30$$,$span_prop$$){return $APP.$app$common$types$shape$layout$grid_layout_immediate_child_QMARK_$$($objects$jscomp$531_parent$jscomp$269$$,$cell$jscomp$38_shape$jscomp$601$$)&&$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$38_shape$jscomp$601$$))?($objects$jscomp$531_parent$jscomp$269$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$531_parent$jscomp$269$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$38_shape$jscomp$601$$)),$cell$jscomp$38_shape$jscomp$601$$=$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($objects$jscomp$531_parent$jscomp$269$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$38_shape$jscomp$601$$)),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$38_shape$jscomp$601$$),
$APP.$cljs$cst$1674$area$$)&&$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1675$area_name$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$38_shape$jscomp$601$$))||!($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$38_shape$jscomp$601$$),$APP.$cljs$cst$1673$manual$$)||$APP.$cljs$cst$1657$row_span$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$38_shape$jscomp$601$$)>1||$APP.$cljs$cst$1658$column_span$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$38_shape$jscomp$601$$)>
1)?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$38_shape$jscomp$601$$,$span_prop$$)>1?""+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$38_shape$jscomp$601$$,$prop$jscomp$30$$)??"")+" / "+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$38_shape$jscomp$601$$,$prop$jscomp$30$$)+$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$38_shape$jscomp$601$$,$span_prop$$)??""):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$38_shape$jscomp$601$$,
$prop$jscomp$30$$)):null};
$app$util$code_gen$style_css_values$get_grid_template_areas$$=function($shape$jscomp$634$$){return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$496$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$634$$);return $and__5023__auto__$jscomp$496$$?$APP.$cljs$core$some$$($app$util$code_gen$style_css_values$area_cell_QMARK_$$,$APP.$cljs$core$vals$$($APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$634$$))):$and__5023__auto__$jscomp$496$$}())?
$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__69098$$){var $row$jscomp$32$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69098$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69098$$,1,null);return'"'+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($cell$jscomp$39_p__69105$$){var $column$jscomp$37$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell$jscomp$39_p__69105$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell$jscomp$39_p__69105$$,1,null);$cell$jscomp$39_p__69105$$=$APP.$app$common$types$shape$layout$get_cell_by_position$$($shape$jscomp$634$$,$row$jscomp$32$$+1,$column$jscomp$37$$+1);return $APP.$cuerdas$core$replace$$($APP.$cljs$cst$1675$area_name$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$39_p__69105$$,".")," ","-")},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1695$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$634$$))))??
"")+'"'},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1694$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$634$$)))):null};
$app$util$code_gen$style_css_values$get_value$$=function($property$jscomp$33$$,$shape$jscomp$652$$,$objects$jscomp$555$$,$options$jscomp$539$$){switch($property$jscomp$33$$ instanceof $APP.$cljs$core$Keyword$$?$property$jscomp$33$$.$fqn$:null){case "position":return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$shape$jscomp$652$$)&&$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))&&
($APP.$app$common$files$helpers$group_like_shape_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$652$$)||$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)||$app$util$code_gen$common$svg_markup_QMARK_$$($shape$jscomp$652$$))||$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)?$cljs$cst$1887$relative$$:$APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,
$shape$jscomp$652$$)&&$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))?null:$APP.$cljs$cst$4078$absolute$$;case "left":return $app$util$code_gen$style_css_values$get_shape_position$$($shape$jscomp$652$$,$objects$jscomp$555$$,$APP.$cljs$cst$1510$x$$);case "top":return $app$util$code_gen$style_css_values$get_shape_position$$($shape$jscomp$652$$,$objects$jscomp$555$$,$APP.$cljs$cst$1511$y$$);case "z-index":var $map__69145__$1$jscomp$inline_6966$$=
$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$),$layout_item_z_index$jscomp$inline_6967$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69145__$1$jscomp$inline_6966$$,$APP.$cljs$cst$1712$layout_item_z_index$$);return $APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__69145__$1$jscomp$inline_6966$$)?0:$APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$map__69145__$1$jscomp$inline_6966$$)?$layout_item_z_index$jscomp$inline_6967$$:
null;case "transform":if($app$util$code_gen$common$svg_markup_QMARK_$$($shape$jscomp$652$$))var $parent$jscomp$inline_6971$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$555$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)),$transform$jscomp$inline_6972$$=$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$inline_6971$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()),$transform_str$jscomp$inline_6973$$=
$app$common$geom$matrix$unit_QMARK_$$($transform$jscomp$inline_6972$$)?null:$app$main$ui$formats$format_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$($transform$jscomp$inline_6972$$);else $parent$jscomp$inline_6971$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$555$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)),$transform$jscomp$inline_6972$$=$APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$652$$,
$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()),$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$inline_6971$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$())),$transform_str$jscomp$inline_6973$$=$app$common$geom$matrix$unit_QMARK_$$($transform$jscomp$inline_6972$$)?null:$app$main$ui$formats$format_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$($transform$jscomp$inline_6972$$);return $app$util$code_gen$common$has_wrapper_QMARK_$$($objects$jscomp$555$$,
$shape$jscomp$652$$)?"translate(-50%, -50%) "+($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($transform_str$jscomp$inline_6973$$,"")??""):$transform_str$jscomp$inline_6973$$;case "width":return $APP.$cljs$core$contains_QMARK_$$($cljs$cst$4079$root_shapes$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$539$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))&&$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)?
$APP.$cljs$cst$1403$fill$$:$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$),$APP.$cljs$cst$2036$auto_width$$)?null:$app$util$code_gen$style_css_values$get_shape_size$$($shape$jscomp$652$$,$objects$jscomp$555$$,$APP.$cljs$cst$290$width$$);case "height":return $APP.$cljs$core$contains_QMARK_$$($cljs$cst$4079$root_shapes$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$539$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))&&$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)?null:$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1770$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$),$APP.$cljs$cst$2035$auto_height$$)?null:$app$util$code_gen$style_css_values$get_shape_size$$($shape$jscomp$652$$,
$objects$jscomp$555$$,$APP.$cljs$cst$1522$height$$);case "max-width":case "max-inline-size":return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$shape$jscomp$652$$)?$APP.$cljs$cst$1706$layout_item_max_w$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$):null;case "min-width":case "min-inline-size":return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$shape$jscomp$652$$)&&$APP.$cljs$cst$1707$layout_item_min_w$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)!=
null?$APP.$cljs$cst$1707$layout_item_min_w$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$):$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$652$$)&&$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)&&$APP.$cljs$core$not$$($APP.$cljs$cst$1876$show_content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))?$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)):
null;case "max-height":case "max-block-size":return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$shape$jscomp$652$$)?$APP.$cljs$cst$1704$layout_item_max_h$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$):null;case "min-height":case "min-block-size":return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$shape$jscomp$652$$)&&$APP.$cljs$cst$1705$layout_item_min_h$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)!=
null?$APP.$cljs$cst$1705$layout_item_min_h$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$):$APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$652$$)&&$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)&&$APP.$cljs$core$not$$($APP.$cljs$cst$1876$show_content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))?$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)):
null;case "margin":var $map__69120__$1$jscomp$inline_6997$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$),$layout_item_margin$jscomp$inline_6998$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69120__$1$jscomp$inline_6997$$,$APP.$cljs$cst$1699$layout_item_margin$$);if($APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$map__69120__$1$jscomp$inline_6997$$)){var $map__69121$jscomp$inline_6999$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1700$m1$$,0,$APP.$cljs$cst$1701$m2$$,0,$APP.$cljs$cst$1702$m3$$,0,$APP.$cljs$cst$1703$m4$$,0],null),$layout_item_margin$jscomp$inline_6998$$])),$map__69121__$1$jscomp$inline_7000$$=$APP.$cljs$core$__destructure_map$$($map__69121$jscomp$inline_6999$$),$m1$jscomp$inline_7001$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69121__$1$jscomp$inline_7000$$,$APP.$cljs$cst$1700$m1$$),$m2$jscomp$inline_7002$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69121__$1$jscomp$inline_7000$$,
$APP.$cljs$cst$1701$m2$$),$m3$jscomp$inline_7003$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69121__$1$jscomp$inline_7000$$,$APP.$cljs$cst$1702$m3$$),$m4$jscomp$inline_7004$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69121__$1$jscomp$inline_7000$$,$APP.$cljs$cst$1703$m4$$);var $JSCompiler_inline_result$jscomp$1232$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m1$jscomp$inline_7001$$,0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m2$jscomp$inline_7002$$,
0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m3$jscomp$inline_7003$$,0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m4$jscomp$inline_7004$$,0)?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$m1$jscomp$inline_7001$$,$m2$jscomp$inline_7002$$,$m3$jscomp$inline_7003$$,$m4$jscomp$inline_7004$$],null):null}else $JSCompiler_inline_result$jscomp$1232$$=null;return $JSCompiler_inline_result$jscomp$1232$$;case "margin-block-start":var $map__69123__$1$jscomp$inline_12681$$=
$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$),$layout_item_margin$jscomp$inline_12682$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69123__$1$jscomp$inline_12681$$,$APP.$cljs$cst$1699$layout_item_margin$$);var $and__5023__auto__$jscomp$inline_12684$$=$APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$map__69123__$1$jscomp$inline_12681$$);if($and__5023__auto__$jscomp$inline_12684$$){var $and__5023__auto____$1$jscomp$inline_12685$$=
$APP.$cljs$cst$1700$m1$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12682$$);var $JSCompiler_inline_result$jscomp$inline_12683$$=$APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$inline_12685$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1700$m1$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12682$$),0):$and__5023__auto____$1$jscomp$inline_12685$$}else $JSCompiler_inline_result$jscomp$inline_12683$$=$and__5023__auto__$jscomp$inline_12684$$;
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_12683$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1700$m1$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12682$$)],null):null;case "margin-inline-end":var $map__69125__$1$jscomp$inline_12690$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$),$layout_item_margin$jscomp$inline_12691$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69125__$1$jscomp$inline_12690$$,
$APP.$cljs$cst$1699$layout_item_margin$$);var $and__5023__auto__$jscomp$inline_12693$$=$APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$map__69125__$1$jscomp$inline_12690$$);if($and__5023__auto__$jscomp$inline_12693$$){var $and__5023__auto____$1$jscomp$inline_12694$$=$APP.$cljs$cst$1701$m2$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12691$$);var $JSCompiler_inline_result$jscomp$inline_12692$$=$APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$inline_12694$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1701$m2$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12691$$),0):$and__5023__auto____$1$jscomp$inline_12694$$}else $JSCompiler_inline_result$jscomp$inline_12692$$=$and__5023__auto__$jscomp$inline_12693$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_12692$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1701$m2$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12691$$)],
null):null;case "margin-block-end":var $map__69134__$1$jscomp$inline_12699$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$),$layout_item_margin$jscomp$inline_12700$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69134__$1$jscomp$inline_12699$$,$APP.$cljs$cst$1699$layout_item_margin$$);var $and__5023__auto__$jscomp$inline_12702$$=$APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$map__69134__$1$jscomp$inline_12699$$);if($and__5023__auto__$jscomp$inline_12702$$){var $and__5023__auto____$1$jscomp$inline_12703$$=
$APP.$cljs$cst$1702$m3$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12700$$);var $JSCompiler_inline_result$jscomp$inline_12701$$=$APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$inline_12703$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1702$m3$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12700$$),0):$and__5023__auto____$1$jscomp$inline_12703$$}else $JSCompiler_inline_result$jscomp$inline_12701$$=$and__5023__auto__$jscomp$inline_12702$$;
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_12701$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1702$m3$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12700$$)],null):null;case "margin-inline-start":var $map__69136__$1$jscomp$inline_12708$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$),$layout_item_margin$jscomp$inline_12709$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69136__$1$jscomp$inline_12708$$,
$APP.$cljs$cst$1699$layout_item_margin$$);var $and__5023__auto__$jscomp$inline_12711$$=$APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$map__69136__$1$jscomp$inline_12708$$);if($and__5023__auto__$jscomp$inline_12711$$){var $and__5023__auto____$1$jscomp$inline_12712$$=$APP.$cljs$cst$1703$m4$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12709$$);var $JSCompiler_inline_result$jscomp$inline_12710$$=$APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$inline_12712$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1703$m4$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12709$$),0):$and__5023__auto____$1$jscomp$inline_12712$$}else $JSCompiler_inline_result$jscomp$inline_12710$$=$and__5023__auto__$jscomp$inline_12711$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_12710$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1703$m4$$.$cljs$core$IFn$_invoke$arity$1$($layout_item_margin$jscomp$inline_12709$$)],
null):null;case "padding":var $map__69082__$1$jscomp$inline_7007$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$),$layout_padding$jscomp$inline_7008$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69082__$1$jscomp$inline_7007$$,$APP.$cljs$cst$1686$layout_padding$$);if($layout_padding$jscomp$inline_7008$$!=null){var $map__69083$jscomp$inline_7009$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1093$p1$$,0,$APP.$cljs$cst$1091$p2$$,0,$APP.$cljs$cst$1687$p3$$,0,$APP.$cljs$cst$1688$p4$$,0],null),$layout_padding$jscomp$inline_7008$$])),$map__69083__$1$jscomp$inline_7010$$=$APP.$cljs$core$__destructure_map$$($map__69083$jscomp$inline_7009$$),$p1$jscomp$inline_7011$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69083__$1$jscomp$inline_7010$$,$APP.$cljs$cst$1093$p1$$),$p2$jscomp$inline_7012$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69083__$1$jscomp$inline_7010$$,
$APP.$cljs$cst$1091$p2$$),$p3$jscomp$inline_7013$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69083__$1$jscomp$inline_7010$$,$APP.$cljs$cst$1687$p3$$),$p4$jscomp$inline_7014$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69083__$1$jscomp$inline_7010$$,$APP.$cljs$cst$1688$p4$$);var $JSCompiler_inline_result$jscomp$1225$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$inline_7011$$,0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$inline_7012$$,
0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p3$jscomp$inline_7013$$,0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p4$jscomp$inline_7014$$,0)?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1$jscomp$inline_7011$$,$p2$jscomp$inline_7012$$,$p3$jscomp$inline_7013$$,$p4$jscomp$inline_7014$$],null):null}else $JSCompiler_inline_result$jscomp$1225$$=null;return $JSCompiler_inline_result$jscomp$1225$$;case "padding-block-start":var $map__69087__$1$jscomp$inline_12716$$=
$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$),$layout_padding$jscomp$inline_12717$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69087__$1$jscomp$inline_12716$$,$APP.$cljs$cst$1686$layout_padding$$),$and__5023__auto__$jscomp$inline_12719$$=$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$inline_12717$$);var $JSCompiler_inline_result$jscomp$inline_12718$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_12719$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$inline_12717$$),
0):$and__5023__auto__$jscomp$inline_12719$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_12718$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$inline_12717$$)],null):null;case "padding-inline-end":var $map__69090__$1$jscomp$inline_12722$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$),$layout_padding$jscomp$inline_12723$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69090__$1$jscomp$inline_12722$$,
$APP.$cljs$cst$1686$layout_padding$$),$and__5023__auto__$jscomp$inline_12725$$=$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$inline_12723$$);var $JSCompiler_inline_result$jscomp$inline_12724$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_12725$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$inline_12723$$),0):$and__5023__auto__$jscomp$inline_12725$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_12724$$)?
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$inline_12723$$)],null):null;case "padding-block-end":var $map__69092__$1$jscomp$inline_12728$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$),$layout_padding$jscomp$inline_12729$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69092__$1$jscomp$inline_12728$$,$APP.$cljs$cst$1686$layout_padding$$),$and__5023__auto__$jscomp$inline_12731$$=
$APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$inline_12729$$);var $JSCompiler_inline_result$jscomp$inline_12730$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_12731$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$inline_12729$$),0):$and__5023__auto__$jscomp$inline_12731$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_12730$$)?new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1687$p3$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$inline_12729$$)],null):null;case "padding-inline-start":var $map__69097__$1$jscomp$inline_12734$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$),$layout_padding$jscomp$inline_12735$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69097__$1$jscomp$inline_12734$$,$APP.$cljs$cst$1686$layout_padding$$),$and__5023__auto__$jscomp$inline_12737$$=$APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$inline_12735$$);
var $JSCompiler_inline_result$jscomp$inline_12736$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_12737$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$inline_12735$$),0):$and__5023__auto__$jscomp$inline_12737$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_12736$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1688$p4$$.$cljs$core$IFn$_invoke$arity$1$($layout_padding$jscomp$inline_12735$$)],
null):null;case "border":return $app$util$code_gen$common$svg_markup_QMARK_$$($shape$jscomp$652$$)?null:$app$util$code_gen$style_css_values$get_stroke_data$$($APP.$cljs$core$first$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)));case "border-style":return $app$util$code_gen$common$svg_markup_QMARK_$$($shape$jscomp$652$$)?null:$app$util$code_gen$style_css_values$get_stroke_data$$($shape$jscomp$652$$);case "border-width":return $app$util$code_gen$common$svg_markup_QMARK_$$($shape$jscomp$652$$)?
null:$app$util$code_gen$style_css_values$get_stroke_data$$($shape$jscomp$652$$);case "border-color":return $app$util$code_gen$common$svg_markup_QMARK_$$($shape$jscomp$652$$)?null:$app$util$code_gen$style_css_values$get_stroke_data$$($shape$jscomp$652$$);case "border-radius":var $map__68993__$1$jscomp$inline_7025$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$),$rx$jscomp$inline_7026$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68993__$1$jscomp$inline_7025$$,$APP.$cljs$cst$1881$rx$$),
$r1$jscomp$inline_7027$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68993__$1$jscomp$inline_7025$$,$APP.$cljs$cst$1646$r1$$),$r2$jscomp$inline_7028$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68993__$1$jscomp$inline_7025$$,$APP.$cljs$cst$1647$r2$$),$r3$jscomp$inline_7029$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68993__$1$jscomp$inline_7025$$,$APP.$cljs$cst$1648$r3$$),$r4$jscomp$inline_7030$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68993__$1$jscomp$inline_7025$$,
$APP.$cljs$cst$1649$r4$$);return $APP.$app$common$files$helpers$circle_shape_QMARK_$$($map__68993__$1$jscomp$inline_7025$$)?"50%":$rx$jscomp$inline_7026$$!=null?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$rx$jscomp$inline_7026$$],null):$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$some_QMARK_$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r1$jscomp$inline_7027$$,$r2$jscomp$inline_7028$$,$r3$jscomp$inline_7029$$,
$r4$jscomp$inline_7030$$],null))?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r1$jscomp$inline_7027$$,$r2$jscomp$inline_7028$$,$r3$jscomp$inline_7029$$,$r4$jscomp$inline_7030$$],null):null;case "border-start-start-radius":var $map__68999__$1$jscomp$inline_12740$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68999__$1$jscomp$inline_12740$$,$APP.$cljs$cst$1102$_$$);var $r1$jscomp$inline_12741$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68999__$1$jscomp$inline_12740$$,$APP.$cljs$cst$1646$r1$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($r1$jscomp$inline_12741$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($r1$jscomp$inline_12741$$,0):$r1$jscomp$inline_12741$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r1$jscomp$inline_12741$$],null):null;case "border-start-end-radius":var $map__69008__$1$jscomp$inline_12744$$=
$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69008__$1$jscomp$inline_12744$$,$APP.$cljs$cst$1102$_$$);var $r2$jscomp$inline_12745$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69008__$1$jscomp$inline_12744$$,$APP.$cljs$cst$1647$r2$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($r2$jscomp$inline_12745$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($r2$jscomp$inline_12745$$,0):$r2$jscomp$inline_12745$$)?
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r2$jscomp$inline_12745$$],null):null;case "border-end-start-radius":var $map__69016__$1$jscomp$inline_12748$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69016__$1$jscomp$inline_12748$$,$APP.$cljs$cst$1102$_$$);var $r3$jscomp$inline_12749$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69016__$1$jscomp$inline_12748$$,
$APP.$cljs$cst$1648$r3$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($r3$jscomp$inline_12749$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($r3$jscomp$inline_12749$$,0):$r3$jscomp$inline_12749$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r3$jscomp$inline_12749$$],null):null;case "border-end-end-radius":var $map__69019__$1$jscomp$inline_12752$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69019__$1$jscomp$inline_12752$$,
$APP.$cljs$cst$1102$_$$);var $r4$jscomp$inline_12753$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69019__$1$jscomp$inline_12752$$,$APP.$cljs$cst$1649$r4$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($r4$jscomp$inline_12753$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($r4$jscomp$inline_12753$$,0):$r4$jscomp$inline_12753$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r4$jscomp$inline_12753$$],null):null;
case "background":var $map__68986__$1$jscomp$inline_7033$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$652$$),$fills$jscomp$inline_7034$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68986__$1$jscomp$inline_7033$$,$APP.$cljs$cst$1634$fills$$),$single_fill_QMARK_$jscomp$inline_7035$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($fills$jscomp$inline_7034$$),1);if($app$util$code_gen$common$svg_markup_QMARK_$$($map__68986__$1$jscomp$inline_7033$$)||
$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__68986__$1$jscomp$inline_7033$$)||!$single_fill_QMARK_$jscomp$inline_7035$$)var $JSCompiler_temp$jscomp$10874$$=null;else{var $p__68917$jscomp$inline_12755$$=$APP.$cljs$core$first$$($fills$jscomp$inline_7034$$),$map__68918__$1$jscomp$inline_12756$$=$APP.$cljs$core$__destructure_map$$($p__68917$jscomp$inline_12755$$),$fill_color$jscomp$inline_12757$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68918__$1$jscomp$inline_12756$$,
$APP.$cljs$cst$1746$fill_color$$),$fill_opacity$jscomp$inline_12758$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68918__$1$jscomp$inline_12756$$,$APP.$cljs$cst$1747$fill_opacity$$),$fill_color_gradient$jscomp$inline_12759$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68918__$1$jscomp$inline_12756$$,$APP.$cljs$cst$1748$fill_color_gradient$$),$fill_image$jscomp$inline_12760$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68918__$1$jscomp$inline_12756$$,
$APP.$cljs$cst$1632$fill_image$$);$JSCompiler_temp$jscomp$10874$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1298$color$$,$fill_color$jscomp$inline_12757$$,$APP.$cljs$cst$1734$opacity$$,$fill_opacity$jscomp$inline_12758$$,$APP.$cljs$cst$1724$gradient$$,$fill_color_gradient$jscomp$inline_12759$$,$APP.$cljs$cst$1612$image$$,$fill_image$jscomp$inline_12760$$],null)}return $JSCompiler_temp$jscomp$10874$$;case "opacity":return $APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)<
1?$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$):null;case "box-shadow":return $app$util$code_gen$common$svg_markup_QMARK_$$($shape$jscomp$652$$)?null:$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$);case "filter":return $app$util$code_gen$common$svg_markup_QMARK_$$($shape$jscomp$652$$)?null:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1908$layer_blur$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$652$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$139$type$$],null)))?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$652$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$260$value$$],null)):null;case "backdrop-filter":return $app$util$code_gen$common$svg_markup_QMARK_$$($shape$jscomp$652$$)?null:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1197$background_blur$$,
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$652$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$139$type$$],null)))?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$652$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$260$value$$],null)):null;case "overflow":return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)&&
!$app$util$code_gen$common$svg_markup_QMARK_$$($shape$jscomp$652$$)&&$APP.$cljs$core$not$$($APP.$cljs$cst$1876$show_content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))?"hidden":null;case "display":return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))?"none":$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)?"flex":$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)?
"grid":null;case "flex":var $parent$jscomp$inline_7051$$=$app$common$files$helpers$get_parent$$($objects$jscomp$555$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$));return $APP.$app$common$types$shape$layout$flex_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$shape$jscomp$652$$)&&($APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1661$row_reverse$$,null,$APP.$cljs$cst$1656$row$$,
null],null),null),$APP.$cljs$cst$1679$layout_flex_dir$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$inline_7051$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))||$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$216$column$$,null,$APP.$cljs$cst$1662$column_reverse$$,null],
null),null),$APP.$cljs$cst$1679$layout_flex_dir$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$inline_7051$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)))?1:null;case "flex-grow":return $APP.$cljs$core$contains_QMARK_$$($cljs$cst$4079$root_shapes$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$539$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))&&
$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)?1:null;case "flex-shrink":return!$APP.$app$common$types$shape$layout$flex_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$shape$jscomp$652$$)||$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$4080$reverse_row$$,null,$APP.$cljs$cst$1656$row$$,null],null),null),$APP.$cljs$cst$1679$layout_flex_dir$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))||$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$4081$column_row$$,null,$APP.$cljs$cst$216$column$$,null],null),null),$APP.$cljs$cst$1679$layout_flex_dir$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1403$fill$$,
$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))||!$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))||!$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))?null:0;case "flex-direction":return $APP.$cljs$cst$1679$layout_flex_dir$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$);
case "flex-wrap":return $APP.$cljs$cst$1684$layout_wrap_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$);case "align-items":return $APP.$cljs$cst$1692$layout_align_items$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$);case "align-content":return $APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$);case "align-self":if($APP.$app$common$types$shape$layout$flex_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$shape$jscomp$652$$))var $JSCompiler_inline_result$jscomp$1242$$=
$APP.$cljs$cst$1710$layout_item_align_self$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$);else if($APP.$app$common$types$shape$layout$grid_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$shape$jscomp$652$$)){var $parent$jscomp$inline_7061$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$555$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)),$cell$jscomp$inline_7062$$=$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($parent$jscomp$inline_7061$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)),$align_self$jscomp$inline_7063$$=$APP.$cljs$cst$1677$align_self$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_7062$$);$JSCompiler_inline_result$jscomp$1242$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align_self$jscomp$inline_7063$$,$APP.$cljs$cst$1672$auto$$)?$align_self$jscomp$inline_7063$$:null}else $JSCompiler_inline_result$jscomp$1242$$=null;return $JSCompiler_inline_result$jscomp$1242$$;case "justify-content":return $APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$);
case "justify-items":return $APP.$cljs$cst$1690$layout_justify_items$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$);case "justify-self":if($APP.$app$common$types$shape$layout$grid_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$shape$jscomp$652$$)){var $parent$jscomp$inline_7067$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$555$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)),$cell$jscomp$inline_7068$$=$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($parent$jscomp$inline_7067$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)),$justify_self$jscomp$inline_7069$$=$APP.$cljs$cst$1678$justify_self$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_7068$$);var $JSCompiler_inline_result$jscomp$1243$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($justify_self$jscomp$inline_7069$$,$APP.$cljs$cst$1672$auto$$)?$justify_self$jscomp$inline_7069$$:null}else $JSCompiler_inline_result$jscomp$1243$$=null;return $JSCompiler_inline_result$jscomp$1243$$;
case "grid-template-rows":return $APP.$cljs$cst$1694$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$);case "grid-template-columns":return $APP.$cljs$cst$1695$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$);case "grid-template-areas":return $app$util$code_gen$style_css_values$get_grid_template_areas$$($shape$jscomp$652$$);case "grid-column":return $app$util$code_gen$style_css_values$get_grid_coord$$($shape$jscomp$652$$,$objects$jscomp$555$$,$APP.$cljs$cst$216$column$$,
$APP.$cljs$cst$1658$column_span$$);case "grid-row":return $app$util$code_gen$style_css_values$get_grid_coord$$($shape$jscomp$652$$,$objects$jscomp$555$$,$APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$1657$row_span$$);case "grid-area":if($APP.$app$common$types$shape$layout$grid_layout_immediate_child_QMARK_$$($objects$jscomp$555$$,$shape$jscomp$652$$)&&$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$))){var $parent$jscomp$inline_7073$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$555$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)),$cell$jscomp$inline_7074$$=$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($parent$jscomp$inline_7073$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$));var $JSCompiler_inline_result$jscomp$1230$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_7074$$),
$APP.$cljs$cst$1674$area$$)&&$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1675$area_name$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_7074$$))?$APP.$cuerdas$core$replace$$($APP.$cljs$cst$1675$area_name$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_7074$$)," ","-"):null}else $JSCompiler_inline_result$jscomp$1230$$=null;return $JSCompiler_inline_result$jscomp$1230$$;case "grid-auto-flow":return $APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1693$layout_grid_dir$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$652$$),$APP.$cljs$cst$216$column$$)?"column":null;case "gap":var $vec__69065$jscomp$inline_7079$$=$APP.$app$common$types$shape$layout$gaps$$($shape$jscomp$652$$),$g1$jscomp$inline_7080$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__69065$jscomp$inline_7079$$,0,null),$g2$jscomp$inline_7081$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__69065$jscomp$inline_7079$$,
1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($g1$jscomp$inline_7080$$,$g2$jscomp$inline_7081$$)&&($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($g1$jscomp$inline_7080$$,0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($g2$jscomp$inline_7081$$,0))?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$g1$jscomp$inline_7080$$],null):null;case "row-gap":var $vec__69070$jscomp$inline_7084$$=$APP.$app$common$types$shape$layout$gaps$$($shape$jscomp$652$$),
$g1$jscomp$inline_7085$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__69070$jscomp$inline_7084$$,0,null),$g2$jscomp$inline_7086$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__69070$jscomp$inline_7084$$,1,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($g1$jscomp$inline_7085$$,$g2$jscomp$inline_7086$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($g1$jscomp$inline_7085$$,0)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$g1$jscomp$inline_7085$$],null):null;case "column-gap":var $vec__69074$jscomp$inline_7089$$=$APP.$app$common$types$shape$layout$gaps$$($shape$jscomp$652$$),$g1$jscomp$inline_7090$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__69074$jscomp$inline_7089$$,0,null),$g2$jscomp$inline_7091$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__69074$jscomp$inline_7089$$,1,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($g1$jscomp$inline_7090$$,$g2$jscomp$inline_7091$$)&&
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($g2$jscomp$inline_7091$$,0)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$g2$jscomp$inline_7091$$],null):null;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$652$$,$property$jscomp$33$$)}};
$app$util$code_gen$style_css$shape__GT_css_property$$=function($shape$jscomp$653_temp__5825__auto__$jscomp$211$$,$objects$jscomp$556$$,$property$jscomp$34$$){$shape$jscomp$653_temp__5825__auto__$jscomp$211$$=$app$util$code_gen$style_css_values$get_value$$($property$jscomp$34$$,$shape$jscomp$653_temp__5825__auto__$jscomp$211$$,$objects$jscomp$556$$,null);return $APP.$cljs$core$truth_$$($shape$jscomp$653_temp__5825__auto__$jscomp$211$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$property$jscomp$34$$,$shape$jscomp$653_temp__5825__auto__$jscomp$211$$],null):null};
$app$util$code_gen$style_css$shape__GT_css_properties$$=function($shape$jscomp$657$$,$objects$jscomp$560$$,$properties$jscomp$96$$,$options$jscomp$541$$){return $APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($property$jscomp$35$$){var $temp__5825__auto__$jscomp$212$$=$app$util$code_gen$style_css_values$get_value$$($property$jscomp$35$$,$shape$jscomp$657$$,$objects$jscomp$560$$,$options$jscomp$541$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$212$$)?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$property$jscomp$35$$,$temp__5825__auto__$jscomp$212$$],null):null},$properties$jscomp$96$$)};
$app$util$code_gen$style_css$format_css_property$$=function($p__69190_value$jscomp$590$$,$formatted_value_options$jscomp$544$$){var $property$jscomp$38$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69190_value$jscomp$590$$,0,null);$p__69190_value$jscomp$590$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69190_value$jscomp$590$$,1,null);return $p__69190_value$jscomp$590$$!=null?($formatted_value_options$jscomp$544$$=$p__69190_value$jscomp$590$$!=null?$app$util$code_gen$style_css_formats$format_value$$($property$jscomp$38$$,
$p__69190_value$jscomp$590$$,$formatted_value_options$jscomp$544$$):null,""+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($property$jscomp$38$$,$APP.$cljs$cst$1867$blend_mode$$)?"mix-"+($APP.$app$common$data$name$$($property$jscomp$38$$)??""):$APP.$app$common$data$name$$($property$jscomp$38$$))??"")+": "+($formatted_value_options$jscomp$544$$??"")+";"):null};
$app$util$code_gen$style_css$format_css_properties$$=function($properties$jscomp$97$$,$options$jscomp$545$$){return $APP.$cljs$core$truth_$$($properties$jscomp$97$$)?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69194_SHARP_$$){return"  "+($app$util$code_gen$style_css$format_css_property$$($p1__69194_SHARP_$$,$options$jscomp$545$$)??"")},$properties$jscomp$97$$)):null};
$app$util$code_gen$style_css$get_shape_properties_css$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$561$$,$shape$jscomp$658$$,$properties$jscomp$98$$){return $app$util$code_gen$style_css$get_shape_properties_css$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$561$$,$shape$jscomp$658$$,$properties$jscomp$98$$,null)};
$app$util$code_gen$style_css$get_shape_properties_css$cljs$0core$0IFn$0_invoke$0arity$04$$=function($objects$jscomp$562$$,$shape$jscomp$659$$,$properties$jscomp$99$$,$options$jscomp$546$$){return $app$util$code_gen$style_css$format_css_properties$$($app$util$code_gen$style_css$shape__GT_css_properties$$($shape$jscomp$659$$,$objects$jscomp$562$$,$properties$jscomp$99$$,$options$jscomp$546$$),$options$jscomp$546$$)};
$app$util$code_gen$style_css$format_js_styles$$=function($properties$jscomp$100$$){return $app$util$code_gen$style_css$format_css_properties$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($key$jscomp$386$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cuerdas$core$kebab$$($key$jscomp$386$$),$properties$jscomp$100$$[$key$jscomp$386$$]],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69197_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($p1__69197_SHARP_$$,
"--")},Object.keys($properties$jscomp$100$$))),null)};
$app$util$code_gen$style_css$generate_text_css$$=function($shape$jscomp$661$$){var $selector$jscomp$15$$=$app$util$code_gen$common$shape__GT_selector$$($shape$jscomp$661$$);return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69206_SHARP_$$){var $G__69198$jscomp$inline_12766_properties$jscomp$inline_12765$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__69206_SHARP_$$);$G__69198$jscomp$inline_12766_properties$jscomp$inline_12765$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1617$root$$,$G__69198$jscomp$inline_12766_properties$jscomp$inline_12765$$)?$app$main$ui$shapes$text$styles$generate_root_styles$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$661$$,$p1__69206_SHARP_$$,!0):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("root",$G__69198$jscomp$inline_12766_properties$jscomp$inline_12765$$)?$app$main$ui$shapes$text$styles$generate_root_styles$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$661$$,
$p1__69206_SHARP_$$,!0):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$4096$paragraph_set$$,$G__69198$jscomp$inline_12766_properties$jscomp$inline_12765$$)?$app$main$ui$shapes$text$styles$generate_paragraph_set_styles$$($shape$jscomp$661$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("paragraph-set",$G__69198$jscomp$inline_12766_properties$jscomp$inline_12765$$)?$app$main$ui$shapes$text$styles$generate_paragraph_set_styles$$($shape$jscomp$661$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3030$paragraph$$,
$G__69198$jscomp$inline_12766_properties$jscomp$inline_12765$$)?$APP.$app$main$ui$shapes$text$styles$generate_paragraph_styles$$($p1__69206_SHARP_$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("paragraph",$G__69198$jscomp$inline_12766_properties$jscomp$inline_12765$$)?$APP.$app$main$ui$shapes$text$styles$generate_paragraph_styles$$($p1__69206_SHARP_$$):$APP.$app$main$ui$shapes$text$styles$generate_text_styles$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$661$$,$p1__69206_SHARP_$$,
null);return"."+(($selector$jscomp$15$$??"")+" ."+($cljs$cst$3999$$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__69206_SHARP_$$)??""))+" {\n"+($app$util$code_gen$style_css$format_js_styles$$($G__69198$jscomp$inline_12766_properties$jscomp$inline_12765$$)??"")+"\n}"},$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$text$index_content$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$661$$)))))};
$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$=function($objects$jscomp$566$$,$shape$jscomp$665$$,$property$jscomp$40$$){return $app$util$code_gen$style_css$format_css_property$$($app$util$code_gen$style_css$shape__GT_css_property$$($shape$jscomp$665$$,$objects$jscomp$566$$,$property$jscomp$40$$),null)};
$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$=function($JSCompiler_temp$jscomp$1245_objects$jscomp$568_property$jscomp$inline_7099$$,$shape$jscomp$667_temp__5825__auto__$jscomp$213_value$jscomp$inline_7100$$,$property$jscomp$42$$){$shape$jscomp$667_temp__5825__auto__$jscomp$213_value$jscomp$inline_7100$$=$app$util$code_gen$style_css$shape__GT_css_property$$($shape$jscomp$667_temp__5825__auto__$jscomp$213_value$jscomp$inline_7100$$,$JSCompiler_temp$jscomp$1245_objects$jscomp$568_property$jscomp$inline_7099$$,
$property$jscomp$42$$);$APP.$cljs$core$truth_$$($shape$jscomp$667_temp__5825__auto__$jscomp$213_value$jscomp$inline_7100$$)?($JSCompiler_temp$jscomp$1245_objects$jscomp$568_property$jscomp$inline_7099$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$667_temp__5825__auto__$jscomp$213_value$jscomp$inline_7100$$,0,null),$shape$jscomp$667_temp__5825__auto__$jscomp$213_value$jscomp$inline_7100$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$667_temp__5825__auto__$jscomp$213_value$jscomp$inline_7100$$,
1,null),$JSCompiler_temp$jscomp$1245_objects$jscomp$568_property$jscomp$inline_7099$$=$shape$jscomp$667_temp__5825__auto__$jscomp$213_value$jscomp$inline_7100$$!=null?$app$util$code_gen$style_css_formats$format_value$$($JSCompiler_temp$jscomp$1245_objects$jscomp$568_property$jscomp$inline_7099$$,$shape$jscomp$667_temp__5825__auto__$jscomp$213_value$jscomp$inline_7100$$,null):null):$JSCompiler_temp$jscomp$1245_objects$jscomp$568_property$jscomp$inline_7099$$=null;return $JSCompiler_temp$jscomp$1245_objects$jscomp$568_property$jscomp$inline_7099$$};
$APP.$app$main$data$workspace$clipboard$copy_selected$$=function(){function $advance_copy$$($file$jscomp$71$$,$libraries$jscomp$85$$,$page$jscomp$79$$,$objects$jscomp$576$$,$shape$jscomp$671$$){if($APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$671$$)&&!$APP.$app$common$types$component$main_instance_QMARK_$$($shape$jscomp$671$$)){var $level_delta$jscomp$4$$=$APP.$app$common$types$component$get_swap_slot$$($shape$jscomp$671$$)==null?$app$common$types$container$get_nesting_level_delta$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$79$$),
$shape$jscomp$671$$,$APP.$app$common$uuid$zero$$):0;return $level_delta$jscomp$4$$>0?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($advance_shape$$,$file$jscomp$71$$,$libraries$jscomp$85$$,$page$jscomp$79$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$level_delta$jscomp$4$$])),$objects$jscomp$576$$,$APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$576$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$671$$))):
$objects$jscomp$576$$}return $objects$jscomp$576$$}function $advance_shape$$($file$jscomp$70_new_shape_ref$jscomp$1$$,$libraries$jscomp$84_new_touched$jscomp$3$$,$container$jscomp$72_page$jscomp$78$$,$level_delta$jscomp$3$$,$objects$jscomp$575$$,$shape$jscomp$670$$){$file$jscomp$70_new_shape_ref$jscomp$1$$=$app$common$types$file$advance_shape_ref$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($file$jscomp$70_new_shape_ref$jscomp$1$$,$container$jscomp$72_page$jscomp$78$$,$libraries$jscomp$84_new_touched$jscomp$3$$,
$shape$jscomp$670$$,$level_delta$jscomp$3$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0],null)]));$container$jscomp$72_page$jscomp$78$$=$app$common$types$container$make_container$$($container$jscomp$72_page$jscomp$78$$,$APP.$cljs$cst$1624$page$$);$libraries$jscomp$84_new_touched$jscomp$3$$=$app$common$types$file$get_touched_from_ref_chain_until_target_ref$$($container$jscomp$72_page$jscomp$78$$,
$libraries$jscomp$84_new_touched$jscomp$3$$,$shape$jscomp$670$$,$file$jscomp$70_new_shape_ref$jscomp$1$$);return $file$jscomp$70_new_shape_ref$jscomp$1$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$70_new_shape_ref$jscomp$1$$,$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$670$$))?$APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($objects$jscomp$575$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$670$$),$APP.$cljs$cst$2047$shape_ref$$],null),$file$jscomp$70_new_shape_ref$jscomp$1$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$670$$),$APP.$cljs$cst$1626$touched$$],null),$libraries$jscomp$84_new_touched$jscomp$3$$):$objects$jscomp$575$$}function $collect_variants$$($data$jscomp$378_state$jscomp$601$$,$components$jscomp$6_shape$jscomp$669$$){var $objects$jscomp$573_page_id$jscomp$192$$=
$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$378_state$jscomp$601$$);$data$jscomp$378_state$jscomp$601$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$378_state$jscomp$601$$);$objects$jscomp$573_page_id$jscomp$192$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$378_state$jscomp$601$$,$objects$jscomp$573_page_id$jscomp$192$$),$APP.$cljs$cst$1631$objects$$);
$components$jscomp$6_shape$jscomp$669$$=$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$378_state$jscomp$601$$,$objects$jscomp$573_page_id$jscomp$192$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$6_shape$jscomp$669$$));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,
$APP.$cljs$cst$2001$variant_properties$$),$components$jscomp$6_shape$jscomp$669$$))}function $fetch_image$$($entry$jscomp$54$$){var $url$jscomp$92$$=$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$54$$);return $APP.$beicon$v2$core$map$$(function($p1__70414_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($entry$jscomp$54$$,$APP.$cljs$cst$142$data$$,$p1__70414_SHARP_$$)},$APP.$beicon$v2$core$mapcat$$($APP.$app$util$webapi$read_file_as_data_url$$,
$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1581$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$,$APP.$cljs$cst$1579$uri$$,$url$jscomp$92$$,$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$1591$blob$$],null)))))}function $maybe_translate$$($shape$jscomp$668$$,$frame$jscomp$36_objects$jscomp$572$$,$parent_frame_id$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parent_frame_id$$,$APP.$app$common$uuid$zero$$))return $shape$jscomp$668$$;
$frame$jscomp$36_objects$jscomp$572$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$36_objects$jscomp$572$$,$parent_frame_id$$);return $APP.$app$common$geom$shapes$translate_to_frame$$($shape$jscomp$668$$,$frame$jscomp$36_objects$jscomp$572$$)}typeof $app$main$data$workspace$clipboard$copy_selected_70494$$==="undefined"&&($app$main$data$workspace$clipboard$copy_selected_70494$$=function($sort_selected$jscomp$1$$,$maybe_translate$jscomp$1$$,$advance_copies$jscomp$1$$,$fetch_image$jscomp$1$$,
$collect_variants$jscomp$1$$,$collect_data$jscomp$1$$,$on_copy_error$jscomp$1$$,$prepare_object$jscomp$1$$,$advance_shape$jscomp$1$$,$advance_copy$jscomp$1$$,$meta70495$$){this.$sort_selected$=$sort_selected$jscomp$1$$;this.$maybe_translate$=$maybe_translate$jscomp$1$$;this.$advance_copies$=$advance_copies$jscomp$1$$;this.$fetch_image$=$fetch_image$jscomp$1$$;this.$collect_variants$=$collect_variants$jscomp$1$$;this.$collect_data$=$collect_data$jscomp$1$$;this.$on_copy_error$=$on_copy_error$jscomp$1$$;
this.$prepare_object$=$prepare_object$jscomp$1$$;this.$advance_shape$=$advance_shape$jscomp$1$$;this.$advance_copy$=$advance_copy$jscomp$1$$;this.$meta70495$=$meta70495$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$copy_selected_70494$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_70494$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4100$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected$$},
$app$main$data$workspace$clipboard$copy_selected_70494$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70496$$,$meta70495__$1$$){return new $app$main$data$workspace$clipboard$copy_selected_70494$$(this.$sort_selected$,this.$maybe_translate$,this.$advance_copies$,this.$fetch_image$,this.$collect_variants$,this.$collect_data$,this.$on_copy_error$,this.$prepare_object$,this.$advance_shape$,this.$advance_copy$,$meta70495__$1$$)},$app$main$data$workspace$clipboard$copy_selected_70494$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70495$},$app$main$data$workspace$clipboard$copy_selected_70494$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_70494$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2209_e$jscomp$325_features__$1$jscomp$16_resolve_data_promise_text$jscomp$53$$,$state$jscomp$603$$){var $self__$jscomp$5083$$=this;$_$jscomp$2209_e$jscomp$325_features__$1$jscomp$16_resolve_data_promise_text$jscomp$53$$=
window.getSelection().toString();if($APP.$cuerdas$core$empty_QMARK_$$($_$jscomp$2209_e$jscomp$325_features__$1$jscomp$16_resolve_data_promise_text$jscomp$53$$)){var $objects$jscomp$577$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$603$$),$selected$jscomp$64$$=$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$577$$,$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$603$$));$_$jscomp$2209_e$jscomp$325_features__$1$jscomp$16_resolve_data_promise_text$jscomp$53$$=
$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$603$$,$APP.$cljs$cst$227$features$$),$APP.$app$common$features$frontend_only_features$$);var $file_id$jscomp$197$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$603$$),$frame_id$jscomp$92$$=$APP.$app$common$files$helpers$common_parent_frame$$($objects$jscomp$577$$,$selected$jscomp$64$$),$file$jscomp$72_version$jscomp$17$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$603$$,
$file_id$jscomp$197$$);$file$jscomp$72_version$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$72_version$jscomp$17$$,$APP.$cljs$cst$2289$version$$);var $initial$jscomp$19$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$139$type$$,$cljs$cst$4101$copied_shapes$$,$APP.$cljs$cst$227$features$$,$_$jscomp$2209_e$jscomp$325_features__$1$jscomp$16_resolve_data_promise_text$jscomp$53$$,$APP.$cljs$cst$2289$version$$,$file$jscomp$72_version$jscomp$17$$,$APP.$cljs$cst$1644$file_id$$,
$file_id$jscomp$197$$,$APP.$cljs$cst$1921$selected$$,$selected$jscomp$64$$,$APP.$cljs$cst$1631$objects$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$4099$images$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$],null),$shapes$jscomp$112$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$data$getf$$($objects$jscomp$577$$),$APP.$app$common$files$helpers$selected_with_children$$($objects$jscomp$577$$,$selected$jscomp$64$$));return $APP.$app$util$globals$global$$.ClipboardItem!=
null?($_$jscomp$2209_e$jscomp$325_features__$1$jscomp$16_resolve_data_promise_text$jscomp$53$$=$promesa$core$create$cljs$0core$0IFn$0_invoke$0arity$01$$(function($resolve$jscomp$33$$,$reject$jscomp$22$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$33$$,$reject$jscomp$22$$,$APP.$beicon$v2$core$map$$(function($p1__70418_SHARP_$$){return $APP.$app$util$webapi$create_blob$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__70418_SHARP_$$,"text/plain")},$APP.$beicon$v2$core$map$$(function($p1__70417_SHARP_$$){return $APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__70417_SHARP_$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$1589$json_verbose$$],null))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5083$$.$advance_copies$,$state$jscomp$603$$,$selected$jscomp$64$$),$APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5083$$.$sort_selected$,$state$jscomp$603$$),$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5083$$.$collect_data$,
$state$jscomp$603$$),$initial$jscomp$19$$,$APP.$beicon$v2$core$merge_map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5083$$.$prepare_object$,$objects$jscomp$577$$,$frame_id$jscomp$92$$),$APP.$beicon$v2$core$from$$($shapes$jscomp$112$$))))))))}),$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5083$$.$on_copy_error$,$APP.$beicon$v2$core$from$$($APP.$app$util$clipboard$to_clipboard_promise$$("text/plain",
$_$jscomp$2209_e$jscomp$325_features__$1$jscomp$16_resolve_data_promise_text$jscomp$53$$))))):$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5083$$.$on_copy_error$,$APP.$beicon$v2$core$map$$($APP.$app$util$clipboard$to_clipboard$$,$APP.$beicon$v2$core$map$$(function($p1__70419_SHARP_$$){return $APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__70419_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,
$cljs$cst$1589$json_verbose$$],null))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5083$$.$advance_copies$,$state$jscomp$603$$,$selected$jscomp$64$$),$APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5083$$.$sort_selected$,$state$jscomp$603$$),$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5083$$.$collect_data$,
$state$jscomp$603$$),$initial$jscomp$19$$,$APP.$beicon$v2$core$merge_map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5083$$.$prepare_object$,$objects$jscomp$577$$,$frame_id$jscomp$92$$),$APP.$beicon$v2$core$from$$($shapes$jscomp$112$$)))))))))}try{return $APP.$app$util$clipboard$to_clipboard$$($_$jscomp$2209_e$jscomp$325_features__$1$jscomp$16_resolve_data_promise_text$jscomp$53$$)}catch($e70505$$){return $_$jscomp$2209_e$jscomp$325_features__$1$jscomp$16_resolve_data_promise_text$jscomp$53$$=
$e70505$$,$self__$jscomp$5083$$.$on_copy_error$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$5083$$.$on_copy_error$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2209_e$jscomp$325_features__$1$jscomp$16_resolve_data_promise_text$jscomp$53$$):$self__$jscomp$5083$$.$on_copy_error$($_$jscomp$2209_e$jscomp$325_features__$1$jscomp$16_resolve_data_promise_text$jscomp$53$$)}});return new $app$main$data$workspace$clipboard$copy_selected_70494$$(function($objects$jscomp$571_objects__$1$jscomp$21_state$jscomp$599$$,
$data$jscomp$376$$){var $selected$jscomp$62_selected__$1$jscomp$5$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($objects$jscomp$571_objects__$1$jscomp$21_state$jscomp$599$$);$objects$jscomp$571_objects__$1$jscomp$21_state$jscomp$599$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$571_objects__$1$jscomp$21_state$jscomp$599$$);$objects$jscomp$571_objects__$1$jscomp$21_state$jscomp$599$$=$APP.$app$common$files$helpers$selected_subtree$$($objects$jscomp$571_objects__$1$jscomp$21_state$jscomp$599$$,
$selected$jscomp$62_selected__$1$jscomp$5$$);$selected$jscomp$62_selected__$1$jscomp$5$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$reverse$$($APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$571_objects__$1$jscomp$21_state$jscomp$599$$,$selected$jscomp$62_selected__$1$jscomp$5$$)));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$376$$,
$APP.$cljs$cst$1921$selected$$,$selected$jscomp$62_selected__$1$jscomp$5$$)},$maybe_translate$$,function($state$jscomp$600$$,$selected$jscomp$63$$,$data$jscomp$377$$){var $file$jscomp$69$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$600$$),$libraries$jscomp$83$$=$APP.$cljs$cst$1916$files$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$600$$),$page$jscomp$77$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$600$$),
$heads$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__70415_SHARP_$$){return $app$common$types$container$get_child_heads$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$377$$),$p1__70415_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$selected$jscomp$63$$]));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$377$$,$APP.$cljs$cst$1631$objects$$,function($p1__70416_SHARP_$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($advance_copy$$,
$file$jscomp$69$$,$libraries$jscomp$83$$,$page$jscomp$77$$),$p1__70416_SHARP_$$,$heads$$)})},$fetch_image$$,$collect_variants$$,function($state$jscomp$602$$,$G__70480__$1_G__70480__$2_result$jscomp$309$$,$map__70479__$1_p__70478$$){$map__70479__$1_p__70478$$=$APP.$cljs$core$__destructure_map$$($map__70479__$1_p__70478$$);var $id$jscomp$647$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70479__$1_p__70478$$,$APP.$cljs$cst$266$id$$),$images$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70479__$1_p__70478$$,
$cljs$cst$4098$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_images$$);$G__70480__$1_G__70480__$2_result$jscomp$309$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($G__70480__$1_G__70480__$2_result$jscomp$309$$,$APP.$cljs$cst$1631$objects$$,$APP.$cljs$core$assoc$$,$id$jscomp$647$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($map__70479__$1_p__70478$$,$cljs$cst$4098$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_images$$));$G__70480__$1_G__70480__$2_result$jscomp$309$$=
$images$jscomp$1$$!=null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__70480__$1_G__70480__$2_result$jscomp$309$$,$cljs$cst$4099$images$$,$APP.$cljs$core$into$$,$images$jscomp$1$$):$G__70480__$1_G__70480__$2_result$jscomp$309$$;return $APP.$cljs$core$truth_$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($map__70479__$1_p__70478$$))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__70480__$1_G__70480__$2_result$jscomp$309$$,$APP.$cljs$cst$2001$variant_properties$$,
$APP.$cljs$core$merge$$,$collect_variants$$($state$jscomp$602$$,$map__70479__$1_p__70478$$)):$G__70480__$1_G__70480__$2_result$jscomp$309$$},function($error$jscomp$71$$){console.error("clipboard blocked:",$error$jscomp$71$$);return $APP.$beicon$v2$core$empty$$()},function($imgdata_objects$jscomp$574$$,$parent_frame_id$jscomp$1$$,$obj$jscomp$208$$){var $obj__$1$jscomp$3$$=$maybe_translate$$($obj$jscomp$208$$,$imgdata_objects$jscomp$574$$,$parent_frame_id$jscomp$1$$);$imgdata_objects$jscomp$574$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1632$fill_image$$,
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([function(){var $or__5025__auto__$jscomp$809$$=$APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($obj__$1$jscomp$3$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$809$$)?$or__5025__auto__$jscomp$809$$:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$obj__$1$jscomp$3$$],
null)}()]))),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1635$stroke_image$$,$APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($obj__$1$jscomp$3$$)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$files$helpers$image_shape_QMARK_$$($obj__$1$jscomp$3$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1633$metadata$$.$cljs$core$IFn$_invoke$arity$1$($obj__$1$jscomp$3$$)],null):
null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($obj__$1$jscomp$3$$))?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($obj__$1$jscomp$3$$)],null):null]));return $APP.$cljs$core$seq$$($imgdata_objects$jscomp$574$$)?$APP.$beicon$v2$core$map$$(function($images$jscomp$2$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($obj__$1$jscomp$3$$,
$cljs$cst$4098$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_images$$,$images$jscomp$2$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$mapcat$$($fetch_image$$,$APP.$beicon$v2$core$from$$($imgdata_objects$jscomp$574$$)))):(0,$APP.$beicon$v2$core$of$$)($obj__$1$jscomp$3$$)},$advance_shape$$,$advance_copy$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$clipboard$create_paste_from_blob$$=function($in_viewport_QMARK_$$,$replace_QMARK_$$){return function($blob$jscomp$33$$){var $type$jscomp$488$$=$blob$jscomp$33$$.type;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$488$$,"image/svg+xml")?$APP.$beicon$v2$core$map$$($app$main$data$workspace$clipboard$paste_svg_text$$,$APP.$beicon$v2$core$from$$($blob$jscomp$33$$.text())):$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__70515_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$488$$,
$p1__70515_SHARP_$$)},$app$util$clipboard$image_types$$))?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$clipboard$paste_image$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$clipboard$paste_image$$.$cljs$core$IFn$_invoke$arity$1$($blob$jscomp$33$$):$app$main$data$workspace$clipboard$paste_image$$($blob$jscomp$33$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$488$$,"text/html")?$APP.$beicon$v2$core$map$$($app$main$data$workspace$clipboard$paste_html_text$$,
$APP.$beicon$v2$core$from$$($blob$jscomp$33$$.text())):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$488$$,"application/transit+json")?$APP.$beicon$v2$core$mapcat$$(function($pdata$jscomp$4$$){var $G__70516$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($pdata$jscomp$4$$);switch($G__70516$$ instanceof $APP.$cljs$core$Keyword$$?$G__70516$$.$fqn$:null){case "copied-props":return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$clipboard$paste_transit_props$$.$cljs$core$IFn$_invoke$arity$1$?
$app$main$data$workspace$clipboard$paste_transit_props$$.$cljs$core$IFn$_invoke$arity$1$($pdata$jscomp$4$$):$app$main$data$workspace$clipboard$paste_transit_props$$($pdata$jscomp$4$$));case "copied-shapes":return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$clipboard$paste_transit_shapes$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$clipboard$paste_transit_shapes$$.$cljs$core$IFn$_invoke$arity$1$($pdata$jscomp$4$$):$app$main$data$workspace$clipboard$paste_transit_shapes$$($pdata$jscomp$4$$));
default:return $APP.$beicon$v2$core$empty$$()}},$APP.$beicon$v2$core$map$$(function($pdata$jscomp$5$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($pdata$jscomp$5$$,$cljs$cst$4102$in_viewport$$,$in_viewport_QMARK_$$),$APP.$cljs$cst$2368$replace$$,$replace_QMARK_$$)},$APP.$beicon$v2$core$filter$$($APP.$cljs$core$map_QMARK_$$,$APP.$beicon$v2$core$map$$($APP.$app$common$transit$decode_str$$,$APP.$beicon$v2$core$from$$($blob$jscomp$33$$.text()))))):
$APP.$beicon$v2$core$map$$($app$main$data$workspace$clipboard$paste_text$$,$APP.$beicon$v2$core$from$$($blob$jscomp$33$$.text()))}};$app$main$data$workspace$clipboard$clipboard_permission_error_QMARK_$$=function($cause$jscomp$85$$){return $cause$jscomp$85$$ instanceof DOMException&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cause$jscomp$85$$.name,"NotAllowedError")};
$app$main$data$workspace$clipboard$on_clipboard_permission_error$$=function($cause$jscomp$86$$){return $app$main$data$workspace$clipboard$clipboard_permission_error_QMARK_$$($cause$jscomp$86$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.clipboard-permission-denied"),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,
$APP.$cljs$cst$2343$warning$$,$APP.$cljs$cst$2353$timeout$$,5E3],null))):$APP.$beicon$v2$core$throw$0$$($cause$jscomp$86$$)};
$app$main$data$workspace$clipboard$paste_from_clipboard$cljs$0core$0IFn$0_invoke$0arity$01$$=function($p__70528$$){var $map__70529__$1$$=$APP.$cljs$core$__destructure_map$$($p__70528$$),$replace_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70529__$1$$,$cljs$cst$4103$replace_QMARK_$$);typeof $app$main$data$workspace$clipboard$paste_from_clipboard_70530$$==="undefined"&&($app$main$data$workspace$clipboard$paste_from_clipboard_70530$$=function($p__70528$jscomp$1$$,$map__70529$jscomp$1$$,
$replace_QMARK_$jscomp$2$$,$meta70531$$){this.$p__70528$=$p__70528$jscomp$1$$;this.$map__70529$=$map__70529$jscomp$1$$;this.$replace_QMARK_$=$replace_QMARK_$jscomp$2$$;this.$meta70531$=$meta70531$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$paste_from_clipboard_70530$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_from_clipboard_70530$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4104$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_from_clipboard$$},$app$main$data$workspace$clipboard$paste_from_clipboard_70530$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70532$$,$meta70531__$1$$){return new $app$main$data$workspace$clipboard$paste_from_clipboard_70530$$(this.$p__70528$,this.$map__70529$,this.$replace_QMARK_$,$meta70531__$1$$)},$app$main$data$workspace$clipboard$paste_from_clipboard_70530$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70531$},$app$main$data$workspace$clipboard$paste_from_clipboard_70530$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_from_clipboard_70530$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$workspace$clipboard$on_clipboard_permission_error$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$mapcat$$($APP.$app$main$data$workspace$clipboard$create_paste_from_blob$$(!1,
$APP.$cljs$core$boolean$0$$(this.$replace_QMARK_$)),$APP.$app$util$clipboard$from_navigator$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$main$data$workspace$clipboard$default_options$$))))});return new $app$main$data$workspace$clipboard$paste_from_clipboard_70530$$($p__70528$$,$map__70529__$1$$,$replace_QMARK_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$clipboard$copy_selected_props$$=function(){typeof $app$main$data$workspace$clipboard$copy_selected_props_70638$$==="undefined"&&($app$main$data$workspace$clipboard$copy_selected_props_70638$$=function($meta70639$$){this.$meta70639$=$meta70639$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$copy_selected_props_70638$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$clipboard$copy_selected_props_70638$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4110$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_props$$},$app$main$data$workspace$clipboard$copy_selected_props_70638$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70640$$,$meta70639__$1$$){return new $app$main$data$workspace$clipboard$copy_selected_props_70638$$($meta70639__$1$$)},$app$main$data$workspace$clipboard$copy_selected_props_70638$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70639$},$app$main$data$workspace$clipboard$copy_selected_props_70638$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_props_70638$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2216_props$jscomp$198_selected$jscomp$69_selected__$1$jscomp$7_temp__5825__auto__$jscomp$214$$,$resolve_data_promise$jscomp$1_state$jscomp$609_version$jscomp$18$$){function $on_copy_error$jscomp$2$$($error$jscomp$72$$){console.error("clipboard blocked:",
$error$jscomp$72$$);return $APP.$beicon$v2$core$empty$$()}function $resolve_images$$($data$jscomp$379$$){var $images$jscomp$3$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1632$fill_image$$,$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$379$$))),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1635$stroke_image$$,
$APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$379$$))));return $APP.$cljs$core$seq$$($images$jscomp$3$$)?$APP.$beicon$v2$core$map$$(function($p1__70631_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$379$$,$cljs$cst$4099$images$$,$p1__70631_SHARP_$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$beicon$v2$core$mapcat$$($fetch_image$jscomp$2$$,$APP.$beicon$v2$core$from$$($images$jscomp$3$$)))):(0,$APP.$beicon$v2$core$of$$)($data$jscomp$379$$)}function $fetch_image$jscomp$2$$($entry$jscomp$55$$){var $url$jscomp$93$$=$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$55$$);return $APP.$beicon$v2$core$map$$(function($p1__70630_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($entry$jscomp$55$$,$APP.$cljs$cst$142$data$$,$p1__70630_SHARP_$$)},
$APP.$beicon$v2$core$mapcat$$($APP.$app$util$webapi$read_file_as_data_url$$,$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1581$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$,$APP.$cljs$cst$1579$uri$$,$url$jscomp$93$$,$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$1591$blob$$],null)))))}$_$jscomp$2216_props$jscomp$198_selected$jscomp$69_selected__$1$jscomp$7_temp__5825__auto__$jscomp$214$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($resolve_data_promise$jscomp$1_state$jscomp$609_version$jscomp$18$$);
if($APP.$cljs$core$count$$($_$jscomp$2216_props$jscomp$198_selected$jscomp$69_selected__$1$jscomp$7_temp__5825__auto__$jscomp$214$$)>1)return $APP.$beicon$v2$core$empty$$();$_$jscomp$2216_props$jscomp$198_selected$jscomp$69_selected__$1$jscomp$7_temp__5825__auto__$jscomp$214$$=$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($resolve_data_promise$jscomp$1_state$jscomp$609_version$jscomp$18$$));var $features__$1$jscomp$17_objects$jscomp$583$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($resolve_data_promise$jscomp$1_state$jscomp$609_version$jscomp$18$$);$_$jscomp$2216_props$jscomp$198_selected$jscomp$69_selected__$1$jscomp$7_temp__5825__auto__$jscomp$214$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($features__$1$jscomp$17_objects$jscomp$583$$,$_$jscomp$2216_props$jscomp$198_selected$jscomp$69_selected__$1$jscomp$7_temp__5825__auto__$jscomp$214$$);if($APP.$cljs$core$truth_$$($_$jscomp$2216_props$jscomp$198_selected$jscomp$69_selected__$1$jscomp$7_temp__5825__auto__$jscomp$214$$)){$_$jscomp$2216_props$jscomp$198_selected$jscomp$69_selected__$1$jscomp$7_temp__5825__auto__$jscomp$214$$=
$app$common$types$shape$extract_props$$($_$jscomp$2216_props$jscomp$198_selected$jscomp$69_selected__$1$jscomp$7_temp__5825__auto__$jscomp$214$$);$features__$1$jscomp$17_objects$jscomp$583$$=$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolve_data_promise$jscomp$1_state$jscomp$609_version$jscomp$18$$,$APP.$cljs$cst$227$features$$),$APP.$app$common$features$frontend_only_features$$);$resolve_data_promise$jscomp$1_state$jscomp$609_version$jscomp$18$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($resolve_data_promise$jscomp$1_state$jscomp$609_version$jscomp$18$$),$APP.$cljs$cst$2289$version$$);var $copy_data$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$4111$copied_props$$,$APP.$cljs$cst$227$features$$,$features__$1$jscomp$17_objects$jscomp$583$$,$APP.$cljs$cst$2289$version$$,$resolve_data_promise$jscomp$1_state$jscomp$609_version$jscomp$18$$,
$APP.$cljs$cst$575$props$$,$_$jscomp$2216_props$jscomp$198_selected$jscomp$69_selected__$1$jscomp$7_temp__5825__auto__$jscomp$214$$,$cljs$cst$4099$images$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$],null);return $APP.$app$util$globals$global$$.ClipboardItem!=null?($resolve_data_promise$jscomp$1_state$jscomp$609_version$jscomp$18$$=$promesa$core$create$cljs$0core$0IFn$0_invoke$0arity$01$$(function($resolve$jscomp$34$$,$reject$jscomp$23$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$34$$,
$reject$jscomp$23$$,$APP.$beicon$v2$core$map$$(function($p1__70636_SHARP_$$){return $APP.$app$util$webapi$create_blob$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__70636_SHARP_$$,"text/plain")},$APP.$beicon$v2$core$map$$(function($p1__70635_SHARP_$$){return $APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__70635_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$1589$json_verbose$$],null))},$APP.$beicon$v2$core$mapcat$$($resolve_images$$,
(0,$APP.$beicon$v2$core$of$$)($copy_data$$)))))}),$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($on_copy_error$jscomp$2$$,$APP.$beicon$v2$core$from$$($APP.$app$util$clipboard$to_clipboard_promise$$("text/plain",$resolve_data_promise$jscomp$1_state$jscomp$609_version$jscomp$18$$))))):$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($on_copy_error$jscomp$2$$,$APP.$beicon$v2$core$map$$(function($p1__70637_SHARP_$$){return $APP.$app$util$clipboard$to_clipboard$$($APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__70637_SHARP_$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$1589$json_verbose$$],null)))},$APP.$beicon$v2$core$mapcat$$($resolve_images$$,(0,$APP.$beicon$v2$core$of$$)($copy_data$$)))))}return null});return new $app$main$data$workspace$clipboard$copy_selected_props_70638$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$clipboard$paste_selected_props$$=function(){typeof $app$main$data$workspace$clipboard$paste_selected_props_70686$$==="undefined"&&($app$main$data$workspace$clipboard$paste_selected_props_70686$$=function($meta70687$$){this.$meta70687$=$meta70687$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$paste_selected_props_70686$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$clipboard$paste_selected_props_70686$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4112$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_selected_props$$},$app$main$data$workspace$clipboard$paste_selected_props_70686$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70688$$,$meta70687__$1$$){return new $app$main$data$workspace$clipboard$paste_selected_props_70686$$($meta70687__$1$$)},$app$main$data$workspace$clipboard$paste_selected_props_70686$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70687$},$app$main$data$workspace$clipboard$paste_selected_props_70686$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_selected_props_70686$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2217$$,$state$jscomp$610$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2217$read_only_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2188$workspace_global$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$610$$)))?
null:$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$87$$){if($app$main$data$workspace$clipboard$clipboard_permission_error_QMARK_$$($cause$jscomp$87$$))return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.clipboard-permission-denied"),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,
$APP.$cljs$cst$2343$warning$$,$APP.$cljs$cst$2353$timeout$$,5E3],null)));if($APP.$cljs$core$truth_$$($cljs$cst$2666$not_implemented$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($cause$jscomp$87$$))))return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$warn$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.clipboard-not-implemented")));console.error("Clipboard error:",$cause$jscomp$87$$);return $APP.$beicon$v2$core$empty$$()},
$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$map$$(function($G__70696_entry$jscomp$56$$){$G__70696_entry$jscomp$56$$=$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($G__70696_entry$jscomp$56$$);return $app$main$data$workspace$clipboard$paste_transit_props$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$clipboard$paste_transit_props$$.$cljs$core$IFn$_invoke$arity$1$($G__70696_entry$jscomp$56$$):$app$main$data$workspace$clipboard$paste_transit_props$$($G__70696_entry$jscomp$56$$)},
$APP.$beicon$v2$core$mapcat$$(function($p1__70685_SHARP_$$){return $p1__70685_SHARP_$$.text()},$APP.$app$util$clipboard$from_navigator$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$main$data$workspace$clipboard$default_options$$)))))});return new $app$main$data$workspace$clipboard$paste_selected_props_70686$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$clipboard$selected_frame_QMARK_$$=function($objects$jscomp$584_state$jscomp$611$$){var $selected$jscomp$70$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($objects$jscomp$584_state$jscomp$611$$);$objects$jscomp$584_state$jscomp$611$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$584_state$jscomp$611$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($selected$jscomp$70$$))&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$584_state$jscomp$611$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($selected$jscomp$70$$),$APP.$cljs$cst$139$type$$],null)))};
$app$main$data$workspace$clipboard$get_tree_root_shapes$$=function($shape_ids$jscomp$10_tree$jscomp$18$$){var $shapes_in_tree$$=$APP.$cljs$core$vals$$($shape_ids$jscomp$10_tree$jscomp$18$$);$shape_ids$jscomp$10_tree$jscomp$18$$=$APP.$cljs$core$keys$$($shape_ids$jscomp$10_tree$jscomp$18$$);var $parent_ids$jscomp$3$$=$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70724_SHARP_$$){return $APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__70724_SHARP_$$)},
$shapes_in_tree$$));return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70725_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($parent_ids$jscomp$3$$,$p1__70725_SHARP_$$)},$shape_ids$jscomp$10_tree$jscomp$18$$)};
$app$main$data$workspace$clipboard$any_same_frame_from_selected_QMARK_$$=function($state$jscomp$612$$,$frame_ids$jscomp$2$$){var $selected$jscomp$71$$=$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$612$$));return 0<$APP.$cljs$core$count$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70739_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__70739_SHARP_$$,$selected$jscomp$71$$)},
$frame_ids$jscomp$2$$))};
$app$main$data$workspace$clipboard$frame_same_size_QMARK_$$=function($paste_obj$$,$frame_obj$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$vals$$($paste_obj$$)))),$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($frame_obj$$)))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$vals$$($paste_obj$$)))),
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($frame_obj$$)))};
$app$main$data$workspace$clipboard$paste_transit_shapes$$=function($p__70770$$){var $map__70772__$1$$=$APP.$cljs$core$__destructure_map$$($p__70770$$),$images$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70772__$1$$,$cljs$cst$4099$images$$);typeof $app$main$data$workspace$clipboard$paste_transit_shapes_70775$$==="undefined"&&($app$main$data$workspace$clipboard$paste_transit_shapes_70775$$=function($p__70770$jscomp$1$$,$map__70772$jscomp$1$$,$pdata$jscomp$7$$,$images$jscomp$5$$,
$upload_media$jscomp$1$$,$meta70776$$){this.$p__70770$=$p__70770$jscomp$1$$;this.$map__70772$=$map__70772$jscomp$1$$;this.$pdata$=$pdata$jscomp$7$$;this.images=$images$jscomp$5$$;this.$upload_media$=$upload_media$jscomp$1$$;this.$meta70776$=$meta70776$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$paste_transit_shapes_70775$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_transit_shapes_70775$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4114$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_transit_shapes$$},$app$main$data$workspace$clipboard$paste_transit_shapes_70775$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70777$$,$meta70776__$1$$){return new $app$main$data$workspace$clipboard$paste_transit_shapes_70775$$(this.$p__70770$,this.$map__70772$,this.$pdata$,this.images,this.$upload_media$,$meta70776__$1$$)},$app$main$data$workspace$clipboard$paste_transit_shapes_70775$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70776$},$app$main$data$workspace$clipboard$paste_transit_shapes_70775$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_transit_shapes_70775$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2218_file_id$jscomp$199_pdata__$1$$,$G__70789_features__$1$jscomp$18_state$jscomp$613$$){var $self__$jscomp$5119$$=this;$_$jscomp$2218_file_id$jscomp$199_pdata__$1$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($G__70789_features__$1$jscomp$18_state$jscomp$613$$);
$G__70789_features__$1$jscomp$18_state$jscomp$613$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__70789_features__$1$jscomp$18_state$jscomp$613$$,$APP.$cljs$cst$227$features$$);if(!$APP.$cljs$core$truth_$$((0,$APP.$app$main$data$workspace$clipboard$paste_data_valid_QMARK_$$)($self__$jscomp$5119$$.$pdata$)))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("validation",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2252$validation$$,$APP.$cljs$cst$273$code$$,$cljs$cst$3368$invalid_paste_data$$,$cljs$cst$4115$hibt$$,"invalid paste data found"],null),null])),null);$app$common$features$check_paste_features_BANG_$$($G__70789_features__$1$jscomp$18_state$jscomp$613$$,$APP.$cljs$cst$227$features$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5119$$.$pdata$));$G__70789_features__$1$jscomp$18_state$jscomp$613$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5119$$.$pdata$);
switch($G__70789_features__$1$jscomp$18_state$jscomp$613$$ instanceof $APP.$cljs$core$Keyword$$?$G__70789_features__$1$jscomp$18_state$jscomp$613$$.$fqn$:null){case "copied-shapes":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2218_file_id$jscomp$199_pdata__$1$$,$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5119$$.$pdata$))?($_$jscomp$2218_file_id$jscomp$199_pdata__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$5119$$.$pdata$,
$cljs$cst$4099$images$$,$APP.$cljs$core$PersistentVector$EMPTY$$),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$clipboard$paste_shapes$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$clipboard$paste_shapes$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2218_file_id$jscomp$199_pdata__$1$$):$app$main$data$workspace$clipboard$paste_shapes$$($_$jscomp$2218_file_id$jscomp$199_pdata__$1$$))):$APP.$beicon$v2$core$map$$($app$main$data$workspace$clipboard$paste_shapes$$,$APP.$beicon$v2$core$map$$(function($p1__70760_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$5119$$.$pdata$,
$cljs$cst$4099$images$$,$p1__70760_SHARP_$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$merge_map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5119$$.$upload_media$,$_$jscomp$2218_file_id$jscomp$199_pdata__$1$$),$APP.$beicon$v2$core$from$$($self__$jscomp$5119$$.images)))));default:return null}});return new $app$main$data$workspace$clipboard$paste_transit_shapes_70775$$($p__70770$$,
$map__70772__$1$$,$map__70772__$1$$,$images$jscomp$4$$,function($file_id$jscomp$198$$,$imgpart$$){return $APP.$beicon$v2$core$map$$(function($p1__70758_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__70758_SHARP_$$,$cljs$cst$4113$prev_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($imgpart$$))},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$repo$cmd_BANG_$$,$APP.$cljs$cst$2282$upload_file_media_object$$),
$APP.$beicon$v2$core$map$$(function($blob$jscomp$34$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($imgpart$$),$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$198$$,$APP.$cljs$cst$1637$content$$,$blob$jscomp$34$$,$APP.$cljs$cst$2574$is_local$$,!0],null)},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1581$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1579$uri$$,
$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($imgpart$$),$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$1591$blob$$,$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$],null))))))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$clipboard$paste_transit_props$$=function($pdata$jscomp$8$$){function $update_image_data$$($pdata__$1$jscomp$1$$,$media_map$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($pdata__$1$jscomp$1$$,$APP.$cljs$cst$575$props$$,function($props$jscomp$199$$){return $APP.$app$common$data$update_when$$($APP.$app$common$data$update_when$$($props$jscomp$199$$,$APP.$cljs$cst$1634$fills$$,function($fills$jscomp$25$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($fill$jscomp$16$$){return $APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$16$$)!=
null?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($fill$jscomp$16$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1632$fill_image$$,$APP.$cljs$cst$266$id$$],null),function($p1__70795_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($media_map$$,$p1__70795_SHARP_$$,$p1__70795_SHARP_$$)}):$fill$jscomp$16$$},$fills$jscomp$25$$)}),$APP.$cljs$cst$1636$strokes$$,function($strokes$jscomp$7$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($stroke$jscomp$18$$){return $APP.$cljs$cst$1635$stroke_image$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$18$$)!=
null?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($stroke$jscomp$18$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1635$stroke_image$$,$APP.$cljs$cst$266$id$$],null),function($p1__70796_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($media_map$$,$p1__70796_SHARP_$$,$p1__70796_SHARP_$$)}):$stroke$jscomp$18$$},$strokes$jscomp$7$$)})})}function $upload_media$jscomp$2$$($file_id$jscomp$200$$,$imgpart$jscomp$1$$){return $APP.$beicon$v2$core$map$$(function($p1__70793_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($imgpart$jscomp$1$$),$p1__70793_SHARP_$$],null)},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$repo$cmd_BANG_$$,$APP.$cljs$cst$2282$upload_file_media_object$$),$APP.$beicon$v2$core$map$$(function($blob$jscomp$35$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($imgpart$jscomp$1$$),
$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$200$$,$APP.$cljs$cst$1637$content$$,$blob$jscomp$35$$,$APP.$cljs$cst$2574$is_local$$,!0],null)},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1581$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1579$uri$$,$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($imgpart$jscomp$1$$),$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$1591$blob$$,$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$],
null))))))}typeof $app$main$data$workspace$clipboard$paste_transit_props_70835$$==="undefined"&&($app$main$data$workspace$clipboard$paste_transit_props_70835$$=function($pdata$jscomp$9$$,$upload_media$jscomp$3$$,$update_image_data$jscomp$1$$,$upload_images$jscomp$2$$,$meta70836$$){this.$pdata$=$pdata$jscomp$9$$;this.$upload_media$=$upload_media$jscomp$3$$;this.$update_image_data$=$update_image_data$jscomp$1$$;this.$upload_images$=$upload_images$jscomp$2$$;this.$meta70836$=$meta70836$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$paste_transit_props_70835$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_transit_props_70835$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4116$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_transit_props$$},$app$main$data$workspace$clipboard$paste_transit_props_70835$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70837$$,$meta70836__$1$$){return new $app$main$data$workspace$clipboard$paste_transit_props_70835$$(this.$pdata$,this.$upload_media$,this.$update_image_data$,this.$upload_images$,$meta70836__$1$$)},$app$main$data$workspace$clipboard$paste_transit_props_70835$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70836$},$app$main$data$workspace$clipboard$paste_transit_props_70835$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_transit_props_70835$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($G__70849__$jscomp$2219_features__$1$jscomp$19$$,$state$jscomp$614$$){var $self__$jscomp$5123$$=this;$G__70849__$jscomp$2219_features__$1$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$614$$,$APP.$cljs$cst$227$features$$);var $selected$jscomp$72$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$614$$);if($APP.$cljs$core$truth_$$((0,$APP.$app$main$data$workspace$clipboard$paste_data_valid_QMARK_$$)($self__$jscomp$5123$$.$pdata$)))switch($app$common$features$check_paste_features_BANG_$$($G__70849__$jscomp$2219_features__$1$jscomp$19$$,
$APP.$cljs$cst$227$features$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5123$$.$pdata$)),$G__70849__$jscomp$2219_features__$1$jscomp$19$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5123$$.$pdata$),$G__70849__$jscomp$2219_features__$1$jscomp$19$$ instanceof $APP.$cljs$core$Keyword$$?$G__70849__$jscomp$2219_features__$1$jscomp$19$$.$fqn$:null){case "copied-props":return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($selected$jscomp$72$$,
function($shape$jscomp$674$$,$objects$jscomp$585$$){return $app$common$types$shape$patch_props$$($shape$jscomp$674$$,$APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5123$$.$pdata$),$objects$jscomp$585$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null))},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5123$$.$upload_images$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$614$$)),
(0,$APP.$beicon$v2$core$of$$)($self__$jscomp$5123$$.$pdata$))),(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$selected$jscomp$72$$],null))));default:return $APP.$beicon$v2$core$empty$$()}else return null});return new $app$main$data$workspace$clipboard$paste_transit_props_70835$$($pdata$jscomp$8$$,$upload_media$jscomp$2$$,$update_image_data$$,
function($file_id$jscomp$201$$,$pdata__$1$jscomp$2$$){return $APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($update_image_data$$,$pdata__$1$jscomp$2$$),$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$merge_map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($upload_media$jscomp$2$$,$file_id$jscomp$201$$),$APP.$beicon$v2$core$from$$($cljs$cst$4099$images$$.$cljs$core$IFn$_invoke$arity$1$($pdata__$1$jscomp$2$$)))))},
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$clipboard$paste_shapes$$=function($p__70881$$){function $process_rchange_shape$$($obj$jscomp$209$$,$media_idx$jscomp$1$$){function $process_text_node$jscomp$1$$($p1__70864_SHARP_$$){return $APP.$app$common$data$update_when$$($p1__70864_SHARP_$$,$APP.$cljs$cst$1634$fills$$,$translate_fills$$)}function $translate_fills$$($p1__70859_SHARP_$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($translate_fill_image$$,$p1__70859_SHARP_$$)}function $translate_stroke_image$$($p1__70858_SHARP_$$){return $translate_media$$($p1__70858_SHARP_$$,
$media_idx$jscomp$1$$,$APP.$cljs$cst$1635$stroke_image$$)}function $translate_fill_image$$($p1__70857_SHARP_$$){return $translate_media$$($p1__70857_SHARP_$$,$media_idx$jscomp$1$$,$APP.$cljs$cst$1632$fill_image$$)}return $APP.$app$common$data$update_when$$($APP.$app$common$data$update_when$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($obj$jscomp$209$$,$APP.$cljs$cst$1634$fills$$,$translate_fills$$),$APP.$cljs$cst$1636$strokes$$,
function($p1__70863_SHARP_$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($translate_stroke_image$$,$p1__70863_SHARP_$$)}),$APP.$cljs$cst$1637$content$$,function($p1__70865_SHARP_$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$02$$($process_text_node$jscomp$1$$,$p1__70865_SHARP_$$)}),$APP.$cljs$cst$1891$position_data$$,function($p1__70866_SHARP_$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($process_text_node$jscomp$1$$,$p1__70866_SHARP_$$)})}
function $add_obj_QMARK_$$($chg$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($chg$$),$APP.$cljs$cst$2610$add_obj$$)}function $translate_media$$($mdata$jscomp$3$$,$media_idx_mobj$$,$attr$jscomp$54$$){var $id$jscomp$649$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$3$$,$attr$jscomp$54$$));$media_idx_mobj$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($media_idx_mobj$$,
$id$jscomp$649$$);return $APP.$cljs$core$truth_$$($media_idx_mobj$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($mdata$jscomp$3$$,$attr$jscomp$54$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($media_idx_mobj$$)):$mdata$jscomp$3$$}var $map__70882__$1$$=$APP.$cljs$core$__destructure_map$$($p__70881$$),$in_viewport_QMARK_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70882__$1$$,$cljs$cst$4102$in_viewport$$);
typeof $app$main$data$workspace$clipboard$paste_shapes_70992$$==="undefined"&&($app$main$data$workspace$clipboard$paste_shapes_70992$$=function($p__70881$jscomp$1$$,$calculate_paste_position$jscomp$1$$,$map__70882$jscomp$1$$,$in_viewport_QMARK_$jscomp$4$$,$process_rchange$jscomp$1$$,$process_rchange_shape$jscomp$1$$,$pdata$jscomp$11$$,$add_obj_QMARK_$jscomp$1$$,$process_shape$jscomp$2$$,$translate_media$jscomp$1$$,$change_add_obj_index$jscomp$1$$,$meta70993$$){this.$p__70881$=$p__70881$jscomp$1$$;
this.$calculate_paste_position$=$calculate_paste_position$jscomp$1$$;this.$map__70882$=$map__70882$jscomp$1$$;this.$in_viewport_QMARK_$=$in_viewport_QMARK_$jscomp$4$$;this.$process_rchange$=$process_rchange$jscomp$1$$;this.$process_rchange_shape$=$process_rchange_shape$jscomp$1$$;this.$pdata$=$pdata$jscomp$11$$;this.$add_obj_QMARK_$=$add_obj_QMARK_$jscomp$1$$;this.$process_shape$=$process_shape$jscomp$2$$;this.$translate_media$=$translate_media$jscomp$1$$;this.$change_add_obj_index$=$change_add_obj_index$jscomp$1$$;
this.$meta70993$=$meta70993$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$paste_shapes_70992$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_shapes_70992$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4117$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_shapes$$},$app$main$data$workspace$clipboard$paste_shapes_70992$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70994$$,$meta70993__$1$$){return new $app$main$data$workspace$clipboard$paste_shapes_70992$$(this.$p__70881$,this.$calculate_paste_position$,this.$map__70882$,this.$in_viewport_QMARK_$,this.$process_rchange$,this.$process_rchange_shape$,this.$pdata$,this.$add_obj_QMARK_$,this.$process_shape$,this.$translate_media$,this.$change_add_obj_index$,$meta70993__$1$$)},$app$main$data$workspace$clipboard$paste_shapes_70992$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70993$},
$app$main$data$workspace$clipboard$paste_shapes_70992$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_shapes_70992$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes__$3$jscomp$9_it$jscomp$206_replace_id$jscomp$2$$,$frame_id$jscomp$95_state$jscomp$616_vec__71014$$){var $self__$jscomp$5127$$=this,$file_id$jscomp$203$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$95_state$jscomp$616_vec__71014$$),
$add_component_to_variant_QMARK_$jscomp$2_changes$jscomp$224_changes__$1$jscomp$75_page$jscomp$80$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$95_state$jscomp$616_vec__71014$$),$media_idx$jscomp$3_undo_id$jscomp$36$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$4113$prev_id$$,$cljs$cst$4099$images$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5127$$.$pdata$)),$selected$jscomp$75_selected__$1$jscomp$8$$=$APP.$cljs$cst$1921$selected$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5127$$.$pdata$),
$objects$jscomp$587$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5127$$.$pdata$),$variant_props$jscomp$4$$=$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5127$$.$pdata$),$position$jscomp$103$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$),$page_selected$jscomp$1$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($frame_id$jscomp$95_state$jscomp$616_vec__71014$$);$changes__$3$jscomp$9_it$jscomp$206_replace_id$jscomp$2$$=
$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$503$$=$APP.$cljs$cst$2368$replace$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5127$$.$pdata$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$503$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($page_selected$jscomp$1$$)):$and__5023__auto__$jscomp$503$$}())?$APP.$cljs$core$first$$($page_selected$jscomp$1$$):null;var $ldata$jscomp$6_vec__71011$$=$self__$jscomp$5127$$.$calculate_paste_position$.$cljs$core$IFn$_invoke$arity$5$?
$self__$jscomp$5127$$.$calculate_paste_position$.$cljs$core$IFn$_invoke$arity$5$($frame_id$jscomp$95_state$jscomp$616_vec__71014$$,$objects$jscomp$587$$,$selected$jscomp$75_selected__$1$jscomp$8$$,$position$jscomp$103$$,$changes__$3$jscomp$9_it$jscomp$206_replace_id$jscomp$2$$):$self__$jscomp$5127$$.$calculate_paste_position$($frame_id$jscomp$95_state$jscomp$616_vec__71014$$,$objects$jscomp$587$$,$selected$jscomp$75_selected__$1$jscomp$8$$,$position$jscomp$103$$,$changes__$3$jscomp$9_it$jscomp$206_replace_id$jscomp$2$$),
$candidate_parent_id_index__$1$jscomp$8_index__$2$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ldata$jscomp$6_vec__71011$$,0,null),$delta$jscomp$46$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ldata$jscomp$6_vec__71011$$,1,null),$index$jscomp$294$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ldata$jscomp$6_vec__71011$$,2,null),$page_objects$jscomp$3$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($add_component_to_variant_QMARK_$jscomp$2_changes$jscomp$224_changes__$1$jscomp$75_page$jscomp$80$$),
$libraries$jscomp$86$$=$APP.$app$main$data$helpers$lookup_libraries$$($frame_id$jscomp$95_state$jscomp$616_vec__71014$$);$ldata$jscomp$6_vec__71011$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$95_state$jscomp$616_vec__71014$$,$file_id$jscomp$203$$);$frame_id$jscomp$95_state$jscomp$616_vec__71014$$=$app$common$types$container$find_valid_parent_and_frame_ids$cljs$0core$0IFn$0_invoke$0arity$05$$($candidate_parent_id_index__$1$jscomp$8_index__$2$jscomp$1$$,
$page_objects$jscomp$3$$,$APP.$cljs$core$vals$$($objects$jscomp$587$$),!0,$libraries$jscomp$86$$);var $parent_id$jscomp$90$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($frame_id$jscomp$95_state$jscomp$616_vec__71014$$,0,null);$frame_id$jscomp$95_state$jscomp$616_vec__71014$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($frame_id$jscomp$95_state$jscomp$616_vec__71014$$,1,null);$candidate_parent_id_index__$1$jscomp$8_index__$2$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($candidate_parent_id_index__$1$jscomp$8_index__$2$jscomp$1$$,
$parent_id$jscomp$90$$)?$index$jscomp$294$$:0;$candidate_parent_id_index__$1$jscomp$8_index__$2$jscomp$1$$=$APP.$cljs$core$truth_$$($candidate_parent_id_index__$1$jscomp$8_index__$2$jscomp$1$$)?$candidate_parent_id_index__$1$jscomp$8_index__$2$jscomp$1$$:$APP.$cljs$core$count$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page_objects$jscomp$3$$,$parent_id$jscomp$90$$),$APP.$cljs$cst$1614$shapes$$))-1;$selected$jscomp$75_selected__$1$jscomp$8$$=
$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$504$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($page_objects$jscomp$3$$,$parent_id$jscomp$90$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$504$$)?$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$reverse_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page_objects$jscomp$3$$,$parent_id$jscomp$90$$))):$and__5023__auto__$jscomp$504$$}())?
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$reverse$$($selected$jscomp$75_selected__$1$jscomp$8$$)):$selected$jscomp$75_selected__$1$jscomp$8$$;var $objects__$1$jscomp$23$$=$APP.$cljs$core$update_vals$$($objects$jscomp$587$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($self__$jscomp$5127$$.$process_shape$,$file_id$jscomp$203$$,$frame_id$jscomp$95_state$jscomp$616_vec__71014$$,$parent_id$jscomp$90$$)),
$all_objects$jscomp$1$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$page_objects$jscomp$3$$,$objects__$1$jscomp$23$$])),$drop_cell$jscomp$2$$=$APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($all_objects$jscomp$1$$,$parent_id$jscomp$90$$))?$app$common$geom$shapes$grid_layout$positions$get_drop_cell$$($frame_id$jscomp$95_state$jscomp$616_vec__71014$$,$all_objects$jscomp$1$$,
$position$jscomp$103$$):null;$add_component_to_variant_QMARK_$jscomp$2_changes$jscomp$224_changes__$1$jscomp$75_page$jscomp$80$$=$app$common$files$changes_builder$amend_changes$$($app$common$files$changes_builder$amend_changes$$($APP.$app$common$logic$libraries$generate_duplicate_changes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$all_objects$jscomp$1$$,$add_component_to_variant_QMARK_$jscomp$2_changes$jscomp$224_changes__$1$jscomp$75_page$jscomp$80$$,
$selected$jscomp$75_selected__$1$jscomp$8$$,$delta$jscomp$46$$,$libraries$jscomp$86$$,$ldata$jscomp$6_vec__71011$$,$file_id$jscomp$203$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3544$variant_props$$,$variant_props$jscomp$4$$],null)])),$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5127$$.$process_rchange$,$media_idx$jscomp$3_undo_id$jscomp$36$$)),$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($self__$jscomp$5127$$.$change_add_obj_index$,
$objects__$1$jscomp$23$$,$selected$jscomp$75_selected__$1$jscomp$8$$,$candidate_parent_id_index__$1$jscomp$8_index__$2$jscomp$1$$));$add_component_to_variant_QMARK_$jscomp$2_changes$jscomp$224_changes__$1$jscomp$75_page$jscomp$80$$=$APP.$app$common$files$changes_builder$resize_parents$$($add_component_to_variant_QMARK_$jscomp$2_changes$jscomp$224_changes__$1$jscomp$75_page$jscomp$80$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5127$$.$add_obj_QMARK_$,
$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($add_component_to_variant_QMARK_$jscomp$2_changes$jscomp$224_changes__$1$jscomp$75_page$jscomp$80$$))));var $changes__$2$jscomp$33$$=$changes__$3$jscomp$9_it$jscomp$206_replace_id$jscomp$2$$!=null?$APP.$cljs$core$second$$($app$common$logic$shapes$generate_delete_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($add_component_to_variant_QMARK_$jscomp$2_changes$jscomp$224_changes__$1$jscomp$75_page$jscomp$80$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$changes__$3$jscomp$9_it$jscomp$206_replace_id$jscomp$2$$]),
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)):$add_component_to_variant_QMARK_$jscomp$2_changes$jscomp$224_changes__$1$jscomp$75_page$jscomp$80$$,$orig_shapes$jscomp$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($all_objects$jscomp$1$$),$selected$jscomp$75_selected__$1$jscomp$8$$),$children_after$$=$APP.$cljs$core$set$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$changes_builder$get_objects$$($changes__$2$jscomp$33$$),
$parent_id$jscomp$90$$),$APP.$cljs$cst$1614$shapes$$)),$selected__$2$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5127$$.$add_obj_QMARK_$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$cst$2611$obj$$)),
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__70876_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($children_after$$,$p1__70876_SHARP_$$)})),$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes__$2$jscomp$33$$));$changes__$3$jscomp$9_it$jscomp$206_replace_id$jscomp$2$$=function(){return $drop_cell$jscomp$2$$!=null?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$2$jscomp$33$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent_id$jscomp$90$$],null),function($p1__70877_SHARP_$$){return $app$common$types$shape$layout$add_children_to_cell$$($p1__70877_SHARP_$$,$selected__$2$jscomp$1$$,$all_objects$jscomp$1$$,$drop_cell$jscomp$2$$)}):$changes__$2$jscomp$33$$}();$add_component_to_variant_QMARK_$jscomp$2_changes$jscomp$224_changes__$1$jscomp$75_page$jscomp$80$$=function(){var $and__5023__auto__$jscomp$505$$=$APP.$cljs$core$some$$($APP.$app$common$types$component$instance_head_QMARK_$$,
$orig_shapes$jscomp$1$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$505$$)?$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$app$common$files$helpers$get_parents_with_self$$($page_objects$jscomp$3$$,$parent_id$jscomp$90$$)):$and__5023__auto__$jscomp$505$$}();$media_idx$jscomp$3_undo_id$jscomp$36$$=Symbol();return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$map$$(function($shape$jscomp$676$$){var $parent_type$jscomp$2$$=$app$common$files$helpers$get_shape_type$$($all_objects$jscomp$1$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$676$$)),$external_lib_QMARK_$jscomp$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$203$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$676$$)),$component$jscomp$86$$=$app$common$types$container$get_component_from_shape$$($shape$jscomp$676$$,$libraries$jscomp$86$$);return $APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$676$$)?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"use-library-component",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:paste",$cljs$cst$3621$is_external_library$$,$external_lib_QMARK_$jscomp$1$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$676$$,$APP.$cljs$cst$139$type$$),$APP.$cljs$cst$3622$parent_type$$,$parent_type$jscomp$2$$,$cljs$cst$3623$is_variant$$,$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$86$$)],
null)):$app$common$files$helpers$has_layout_QMARK_$$($objects__$1$jscomp$23$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$676$$))?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"layout-add-element",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:paste",$APP.$cljs$cst$139$type$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$676$$,
$APP.$cljs$cst$139$type$$),$APP.$cljs$cst$3622$parent_type$$,$parent_type$jscomp$2$$],null)):$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-shape",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:paste",$APP.$cljs$cst$139$type$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$676$$,$APP.$cljs$cst$139$type$$),$APP.$cljs$cst$3622$parent_type$$,
$parent_type$jscomp$2$$],null))},$APP.$beicon$v2$core$from$$($orig_shapes$jscomp$1$$)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($media_idx$jscomp$3_undo_id$jscomp$36$$),$APP.$app$main$data$changes$commit_changes$$($changes__$3$jscomp$9_it$jscomp$206_replace_id$jscomp$2$$),$APP.$app$main$data$workspace$selection$select_shapes$$($selected__$2$jscomp$1$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$95_state$jscomp$616_vec__71014$$],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($media_idx$jscomp$3_undo_id$jscomp$36$$),$APP.$cljs$core$truth_$$($add_component_to_variant_QMARK_$jscomp$2_changes$jscomp$224_changes__$1$jscomp$75_page$jscomp$80$$)?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-component-to-variant"],null)):null))});return new $app$main$data$workspace$clipboard$paste_shapes_70992$$($p__70881$$,function($state$jscomp$615$$,$pobjects$$,$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$,$position$jscomp$102_selected_frame_obj$$,$margin_y$jscomp$3_paste_y_replace_id$jscomp$1$$){var $margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$615$$);
$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($pobjects$$),$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$);var $first_selected_obj$$=$APP.$cljs$core$first$$($delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$),$page_selected$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$615$$),
$wrapper$jscomp$8$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$);$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($wrapper$jscomp$8$$),$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($wrapper$jscomp$8$$));var $frame_id$jscomp$93_frame_id__$1$jscomp$10_parent_id$jscomp$88$$=
$APP.$cljs$core$first$$($page_selected$$),$frame_object$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$,$frame_id$jscomp$93_frame_id__$1$jscomp$10_parent_id$jscomp$88$$),$base$jscomp$39$$=$app$common$files$helpers$get_base_shape$$($margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$,$page_selected$$),$index$jscomp$292_origin_frame_id$$=$app$common$files$helpers$get_position_on_parent$$($margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$39$$)),$tree_root$$=$app$main$data$workspace$clipboard$get_tree_root_shapes$$($pobjects$$),$only_one_root_shape_QMARK_$$=1<$APP.$cljs$core$count$$($pobjects$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($tree_root$$)),$replaced$$=$margin_y$jscomp$3_paste_y_replace_id$jscomp$1$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$,
$margin_y$jscomp$3_paste_y_replace_id$jscomp$1$$);if($replaced$$!=null)return $delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$=$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$shapes$common$shape__GT_center$$($replaced$$),$APP.$app$common$geom$rect$rect__GT_center$$($wrapper$jscomp$8$$)),$frame_id$jscomp$93_frame_id__$1$jscomp$10_parent_id$jscomp$88$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($replaced$$),$margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$=
$app$common$files$helpers$get_position_on_parent$$($margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$,$margin_y$jscomp$3_paste_y_replace_id$jscomp$1$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$93_frame_id__$1$jscomp$10_parent_id$jscomp$88$$,$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$,$margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$],null);if($app$main$data$workspace$clipboard$selected_frame_QMARK_$$($state$jscomp$615$$)&&
($app$main$data$workspace$clipboard$any_same_frame_from_selected_QMARK_$$($state$jscomp$615$$,$APP.$cljs$core$keys$$($pobjects$$))||$only_one_root_shape_QMARK_$$&&$app$main$data$workspace$clipboard$frame_same_size_QMARK_$$($pobjects$$,$APP.$cljs$core$first$$($tree_root$$))))return $position$jscomp$102_selected_frame_obj$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$,$APP.$cljs$core$first$$($page_selected$$)),$frame_id$jscomp$93_frame_id__$1$jscomp$10_parent_id$jscomp$88$$=
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$39$$),$margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$102_selected_frame_obj$$)+$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$102_selected_frame_obj$$)+50,$margin_y$jscomp$3_paste_y_replace_id$jscomp$1$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$102_selected_frame_obj$$),
$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$=$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$,$margin_y$jscomp$3_paste_y_replace_id$jscomp$1$$),$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$93_frame_id__$1$jscomp$10_parent_id$jscomp$88$$,
$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$,$index$jscomp$292_origin_frame_id$$],null);if($app$main$data$workspace$clipboard$selected_frame_QMARK_$$($state$jscomp$615$$)){$position$jscomp$102_selected_frame_obj$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$,$APP.$cljs$core$first$$($page_selected$$));$index$jscomp$292_origin_frame_id$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($first_selected_obj$$);
var $origin_frame_object$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$,$index$jscomp$292_origin_frame_id$$);$margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$=function(){var $x__5113__auto__$jscomp$60$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($origin_frame_object$$)-($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($wrapper$jscomp$8$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($wrapper$jscomp$8$$)),
$y__5114__auto__$jscomp$60$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame_object$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($wrapper$jscomp$8$$);return $x__5113__auto__$jscomp$60$$<$y__5114__auto__$jscomp$60$$?$x__5113__auto__$jscomp$60$$:$y__5114__auto__$jscomp$60$$}();$margin_y$jscomp$3_paste_y_replace_id$jscomp$1$$=function(){var $x__5113__auto__$jscomp$61$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($origin_frame_object$$)-($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($wrapper$jscomp$8$$)+
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($wrapper$jscomp$8$$)),$y__5114__auto__$jscomp$61$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($frame_object$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($wrapper$jscomp$8$$);return $x__5113__auto__$jscomp$61$$<$y__5114__auto__$jscomp$61$$?$x__5113__auto__$jscomp$61$$:$y__5114__auto__$jscomp$61$$}();$margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($wrapper$jscomp$8$$)+
$APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($wrapper$jscomp$8$$)>$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame_object$$)?$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame_object$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$)+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame_object$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($wrapper$jscomp$8$$)-
$margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$):$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame_object$$);$margin_y$jscomp$3_paste_y_replace_id$jscomp$1$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($wrapper$jscomp$8$$)+$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($wrapper$jscomp$8$$)>$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($frame_object$$)?$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame_object$$)-
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$)+($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($frame_object$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($wrapper$jscomp$8$$)-$margin_y$jscomp$3_paste_y_replace_id$jscomp$1$$):$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame_object$$);$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$292_origin_frame_id$$,
$APP.$app$common$uuid$zero$$)?$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$shapes$common$shape__GT_center$$($frame_object$$),$APP.$app$common$geom$rect$rect__GT_center$$($wrapper$jscomp$8$$)):$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$,$margin_y$jscomp$3_paste_y_replace_id$jscomp$1$$);$margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$102_selected_frame_obj$$)&&
$APP.$app$common$types$shape$layout$reverse_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($position$jscomp$102_selected_frame_obj$$)?-1:$APP.$cljs$core$count$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$102_selected_frame_obj$$));return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$93_frame_id__$1$jscomp$10_parent_id$jscomp$88$$,$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$,
$margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$],null)}if($APP.$cljs$core$empty_QMARK_$$($page_selected$$))return $frame_id$jscomp$93_frame_id__$1$jscomp$10_parent_id$jscomp$88$$=$APP.$app$common$types$shape_tree$top_nested_frame$cljs$0core$0IFn$0_invoke$0arity$04$$($margin_x$jscomp$3_page_objects$jscomp$2_paste_x_target_index$jscomp$2$$,$position$jscomp$102_selected_frame_obj$$,null,!1),$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$=$APP.$app$common$geom$point$subtract$$($position$jscomp$102_selected_frame_obj$$,
$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$93_frame_id__$1$jscomp$10_parent_id$jscomp$88$$,$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$],null);$frame_id$jscomp$93_frame_id__$1$jscomp$10_parent_id$jscomp$88$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$39$$);$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$=
$APP.$cljs$core$truth_$$($in_viewport_QMARK_$jscomp$3$$)?$APP.$app$common$geom$point$subtract$$($position$jscomp$102_selected_frame_obj$$,$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$):$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$39$$)),$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$);return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$93_frame_id__$1$jscomp$10_parent_id$jscomp$88$$,$delta$jscomp$45_orig_pos$jscomp$3_selected$jscomp$73_selected_objs$jscomp$1$$,$index$jscomp$292_origin_frame_id$$],null)},$map__70882__$1$$,$in_viewport_QMARK_$jscomp$3$$,function($media_idx$jscomp$2$$,$change$jscomp$30$$){return $APP.$cljs$core$truth_$$($add_obj_QMARK_$$($change$jscomp$30$$))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($change$jscomp$30$$,$APP.$cljs$cst$2611$obj$$,
$process_rchange_shape$$,$media_idx$jscomp$2$$):$change$jscomp$30$$},$process_rchange_shape$$,$map__70882__$1$$,$add_obj_QMARK_$$,function($file_id$jscomp$202$$,$G__70988__$1_G__70988__$2_frame_id$jscomp$94$$,$parent_id$jscomp$89$$,$shape$jscomp$675$$){$G__70988__$1_G__70988__$2_frame_id$jscomp$94$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape$jscomp$675$$,$APP.$cljs$cst$1607$frame_id$$,$G__70988__$1_G__70988__$2_frame_id$jscomp$94$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$parent_id$$,
$parent_id$jscomp$89$$]));$G__70988__$1_G__70988__$2_frame_id$jscomp$94$$=($APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$675$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$675$$))&&$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$675$$)==null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70988__$1_G__70988__$2_frame_id$jscomp$94$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$):
$G__70988__$1_G__70988__$2_frame_id$jscomp$94$$;return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$675$$)?$app$common$types$typography$remove_external_typographies$$($G__70988__$1_G__70988__$2_frame_id$jscomp$94$$,$file_id$jscomp$202$$):$G__70988__$1_G__70988__$2_frame_id$jscomp$94$$},$translate_media$$,function($objects$jscomp$586$$,$selected$jscomp$74$$,$index$jscomp$293_index__$1$jscomp$7$$,$change$jscomp$31$$){$index$jscomp$293_index__$1$jscomp$7$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$293_index__$1$jscomp$7$$,-1);var $map_ids$$=$APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($index__$2_p__70984$$,$id$jscomp$650$$){var $result$jscomp$310$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($index__$2_p__70984$$,0,null);$index__$2_p__70984$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($index__$2_p__70984$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$310$$,$id$jscomp$650$$,$index__$2_p__70984$$),$index__$2_p__70984$$+1],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$index$jscomp$293_index__$1$jscomp$7$$+1],null),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70871_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$586$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__70871_SHARP_$$,$APP.$cljs$cst$266$id$$],null))},$selected$jscomp$74$$)));return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$502$$=$add_obj_QMARK_$$($change$jscomp$31$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$502$$)?$APP.$cljs$core$contains_QMARK_$$($map_ids$$,$APP.$cljs$cst$3531$old_id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$31$$)):$and__5023__auto__$jscomp$502$$}())?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($change$jscomp$31$$,$APP.$cljs$cst$1795$index$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map_ids$$,$APP.$cljs$cst$3531$old_id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$31$$))):$change$jscomp$31$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$clipboard$as_content$$=function($paragraphs$jscomp$7_text$jscomp$55$$){$paragraphs$jscomp$7_text$jscomp$55$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71022_SHARP_$$){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$342$children$$],["paragraph",new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$get_default_text_attrs$$(),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1588$text$$,$p1__71022_SHARP_$$],null)]))],null)])},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$trim$$,$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($paragraphs$jscomp$7_text$jscomp$55$$,/\n|\r\n/)));return $APP.$app$common$data$not_empty_QMARK_$$($paragraphs$jscomp$7_text$jscomp$55$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"root",$APP.$cljs$cst$342$children$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"paragraph-set",$APP.$cljs$cst$342$children$$,$paragraphs$jscomp$7_text$jscomp$55$$],null)],null)],null):null};
$app$main$data$workspace$clipboard$calculate_paste_position$$=function($page_objects$jscomp$4_state$jscomp$617$$){if($app$main$data$workspace$clipboard$selected_frame_QMARK_$$($page_objects$jscomp$4_state$jscomp$617$$)){var $frame_id$jscomp$96_frame_object$jscomp$1_page_selected$jscomp$2$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($page_objects$jscomp$4_state$jscomp$617$$);$page_objects$jscomp$4_state$jscomp$617$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($page_objects$jscomp$4_state$jscomp$617$$);
$frame_id$jscomp$96_frame_object$jscomp$1_page_selected$jscomp$2$$=$APP.$cljs$core$first$$($frame_id$jscomp$96_frame_object$jscomp$1_page_selected$jscomp$2$$);$frame_id$jscomp$96_frame_object$jscomp$1_page_selected$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page_objects$jscomp$4_state$jscomp$617$$,$frame_id$jscomp$96_frame_object$jscomp$1_page_selected$jscomp$2$$);return $APP.$app$common$geom$shapes$common$shape__GT_center$$($frame_id$jscomp$96_frame_object$jscomp$1_page_selected$jscomp$2$$)}return $APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$)};
$app$main$data$workspace$clipboard$paste_html_text$$=function($html$jscomp$19$$){typeof $app$main$data$workspace$clipboard$paste_html_text_71029$$==="undefined"&&($app$main$data$workspace$clipboard$paste_html_text_71029$$=function($html$jscomp$20$$,$meta71030$$){this.html=$html$jscomp$20$$;this.$meta71030$=$meta71030$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$paste_html_text_71029$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_html_text_71029$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4118$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_html_text$$},$app$main$data$workspace$clipboard$paste_html_text_71029$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71031$$,$meta71030__$1$$){return new $app$main$data$workspace$clipboard$paste_html_text_71029$$(this.html,$meta71030__$1$$)},$app$main$data$workspace$clipboard$paste_html_text_71029$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71030$},$app$main$data$workspace$clipboard$paste_html_text_71029$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_html_text_71029$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2221_id$jscomp$651_root$jscomp$65_style$jscomp$46$$,$skip_edition_QMARK_$jscomp$4_state$jscomp$618$$){$_$jscomp$2221_id$jscomp$651_root$jscomp$65_style$jscomp$46$$=$APP.$cljs$core$_deref$$($app$main$refs$workspace_clipboard_style$$);
$_$jscomp$2221_id$jscomp$651_root$jscomp$65_style$jscomp$46$$=$app$main$data$workspace$texts$create_root_from_html$$(this.html,$_$jscomp$2221_id$jscomp$651_root$jscomp$65_style$jscomp$46$$,$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2-html-paste"));var $shape$jscomp$677_text$jscomp$56$$=$_$jscomp$2221_id$jscomp$651_root$jscomp$65_style$jscomp$46$$.textContent,$content$jscomp$193_undo_id$jscomp$37$$=$APP.$app$util$text$content$dom__GT_cljs$$($_$jscomp$2221_id$jscomp$651_root$jscomp$65_style$jscomp$46$$);
if($APP.$cljs$core$truth_$$($app$common$types$shape$text$valid_content_QMARK_$$($content$jscomp$193_undo_id$jscomp$37$$))){$_$jscomp$2221_id$jscomp$651_root$jscomp$65_style$jscomp$46$$=$APP.$app$common$uuid$next$$();var $map__71032_x$jscomp$1200_x__5113__auto__$jscomp$inline_12786_y__5111__auto__$jscomp$inline_12785$$=7*$APP.$cljs$core$count$$($shape$jscomp$677_text$jscomp$56$$);$map__71032_x$jscomp$1200_x__5113__auto__$jscomp$inline_12786_y__5111__auto__$jscomp$inline_12785$$=$map__71032_x$jscomp$1200_x__5113__auto__$jscomp$inline_12786_y__5111__auto__$jscomp$inline_12785$$<
700?$map__71032_x$jscomp$1200_x__5113__auto__$jscomp$inline_12786_y__5111__auto__$jscomp$inline_12785$$:700;var $width$jscomp$147$$=8>$map__71032_x$jscomp$1200_x__5113__auto__$jscomp$inline_12786_y__5111__auto__$jscomp$inline_12785$$?8:$map__71032_x$jscomp$1200_x__5113__auto__$jscomp$inline_12786_y__5111__auto__$jscomp$inline_12785$$;$map__71032_x$jscomp$1200_x__5113__auto__$jscomp$inline_12786_y__5111__auto__$jscomp$inline_12785$$=$app$main$data$workspace$clipboard$calculate_paste_position$$($skip_edition_QMARK_$jscomp$4_state$jscomp$618$$);
var $map__71032__$1_y$jscomp$433$$=$APP.$cljs$core$__destructure_map$$($map__71032_x$jscomp$1200_x__5113__auto__$jscomp$inline_12786_y__5111__auto__$jscomp$inline_12785$$);$map__71032_x$jscomp$1200_x__5113__auto__$jscomp$inline_12786_y__5111__auto__$jscomp$inline_12785$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71032__$1_y$jscomp$433$$,$APP.$cljs$cst$1510$x$$);$map__71032__$1_y$jscomp$433$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71032__$1_y$jscomp$433$$,$APP.$cljs$cst$1511$y$$);
$skip_edition_QMARK_$jscomp$4_state$jscomp$618$$=$APP.$app$main$features$active_feature_QMARK_$$($skip_edition_QMARK_$jscomp$4_state$jscomp$618$$,"text-editor-wasm/v1");$shape$jscomp$677_text$jscomp$56$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1770$grow_type$$,$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1522$height$$],[$map__71032__$1_y$jscomp$433$$,
$APP.$cljs$core$count$$($shape$jscomp$677_text$jscomp$56$$)>100?$APP.$cljs$cst$2035$auto_height$$:$APP.$cljs$cst$2036$auto_width$$,$content$jscomp$193_undo_id$jscomp$37$$,$APP.$app$common$types$text$generate_shape_name$$($shape$jscomp$677_text$jscomp$56$$),$width$jscomp$147$$,$APP.$cljs$cst$1588$text$$,$_$jscomp$2221_id$jscomp$651_root$jscomp$65_style$jscomp$46$$,$map__71032_x$jscomp$1200_x__5113__auto__$jscomp$inline_12786_y__5111__auto__$jscomp$inline_12785$$,16]);$content$jscomp$193_undo_id$jscomp$37$$=
Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($content$jscomp$193_undo_id$jscomp$37$$),$app$main$data$workspace$shapes$create_and_add_shape$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$cljs$cst$1588$text$$,$map__71032_x$jscomp$1200_x__5113__auto__$jscomp$inline_12786_y__5111__auto__$jscomp$inline_12785$$,$map__71032__$1_y$jscomp$433$$,$shape$jscomp$677_text$jscomp$56$$,$skip_edition_QMARK_$jscomp$4_state$jscomp$618$$?
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3641$skip_edition_QMARK_$$,!0],null):null)),$skip_edition_QMARK_$jscomp$4_state$jscomp$618$$?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2221_id$jscomp$651_root$jscomp$65_style$jscomp$46$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3138$undo_group$$,$_$jscomp$2221_id$jscomp$651_root$jscomp$65_style$jscomp$46$$,$APP.$cljs$cst$3646$undo_id$$,
$content$jscomp$193_undo_id$jscomp$37$$],null))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($content$jscomp$193_undo_id$jscomp$37$$)))}return null});return new $app$main$data$workspace$clipboard$paste_html_text_71029$$($html$jscomp$19$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$clipboard$paste_text$$=function($text$jscomp$57$$){typeof $app$main$data$workspace$clipboard$paste_text_71036$$==="undefined"&&($app$main$data$workspace$clipboard$paste_text_71036$$=function($text$jscomp$58$$,$meta71037$$){this.text=$text$jscomp$58$$;this.$meta71037$=$meta71037$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$paste_text_71036$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$clipboard$paste_text_71036$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4119$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_text$$},$app$main$data$workspace$clipboard$paste_text_71036$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71038$$,$meta71037__$1$$){return new $app$main$data$workspace$clipboard$paste_text_71036$$(this.text,$meta71037__$1$$)},$app$main$data$workspace$clipboard$paste_text_71036$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71037$},$app$main$data$workspace$clipboard$paste_text_71036$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_text_71036$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2222_id$jscomp$652$$,$skip_edition_QMARK_$jscomp$5_state$jscomp$619$$){$_$jscomp$2222_id$jscomp$652$$=$APP.$app$common$uuid$next$$();var $map__71043_x$jscomp$1201_x__5113__auto__$jscomp$inline_12789_y__5111__auto__$jscomp$inline_12788$$=
7*$APP.$cljs$core$count$$(this.text);$map__71043_x$jscomp$1201_x__5113__auto__$jscomp$inline_12789_y__5111__auto__$jscomp$inline_12788$$=$map__71043_x$jscomp$1201_x__5113__auto__$jscomp$inline_12789_y__5111__auto__$jscomp$inline_12788$$<700?$map__71043_x$jscomp$1201_x__5113__auto__$jscomp$inline_12789_y__5111__auto__$jscomp$inline_12788$$:700;var $shape$jscomp$678_width$jscomp$148$$=8>$map__71043_x$jscomp$1201_x__5113__auto__$jscomp$inline_12789_y__5111__auto__$jscomp$inline_12788$$?8:$map__71043_x$jscomp$1201_x__5113__auto__$jscomp$inline_12789_y__5111__auto__$jscomp$inline_12788$$;
$map__71043_x$jscomp$1201_x__5113__auto__$jscomp$inline_12789_y__5111__auto__$jscomp$inline_12788$$=$app$main$data$workspace$clipboard$calculate_paste_position$$($skip_edition_QMARK_$jscomp$5_state$jscomp$619$$);var $map__71043__$1_y$jscomp$434$$=$APP.$cljs$core$__destructure_map$$($map__71043_x$jscomp$1201_x__5113__auto__$jscomp$inline_12789_y__5111__auto__$jscomp$inline_12788$$);$map__71043_x$jscomp$1201_x__5113__auto__$jscomp$inline_12789_y__5111__auto__$jscomp$inline_12788$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71043__$1_y$jscomp$434$$,
$APP.$cljs$cst$1510$x$$);$map__71043__$1_y$jscomp$434$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71043__$1_y$jscomp$434$$,$APP.$cljs$cst$1511$y$$);$skip_edition_QMARK_$jscomp$5_state$jscomp$619$$=$APP.$app$main$features$active_feature_QMARK_$$($skip_edition_QMARK_$jscomp$5_state$jscomp$619$$,"text-editor-wasm/v1");$shape$jscomp$678_width$jscomp$148$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1770$grow_type$$,$APP.$cljs$cst$1637$content$$,
$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1522$height$$],[$map__71043__$1_y$jscomp$434$$,$APP.$cljs$core$count$$(this.text)>100?$APP.$cljs$cst$2035$auto_height$$:$APP.$cljs$cst$2036$auto_width$$,$app$main$data$workspace$clipboard$as_content$$(this.text),$APP.$app$common$types$text$generate_shape_name$$(this.text),$shape$jscomp$678_width$jscomp$148$$,$APP.$cljs$cst$1588$text$$,$_$jscomp$2222_id$jscomp$652$$,
$map__71043_x$jscomp$1201_x__5113__auto__$jscomp$inline_12789_y__5111__auto__$jscomp$inline_12788$$,16]);var $undo_id$jscomp$38$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$38$$),$app$main$data$workspace$shapes$create_and_add_shape$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$cljs$cst$1588$text$$,$map__71043_x$jscomp$1201_x__5113__auto__$jscomp$inline_12789_y__5111__auto__$jscomp$inline_12788$$,
$map__71043__$1_y$jscomp$434$$,$shape$jscomp$678_width$jscomp$148$$,$skip_edition_QMARK_$jscomp$5_state$jscomp$619$$?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3641$skip_edition_QMARK_$$,!0],null):null)),$skip_edition_QMARK_$jscomp$5_state$jscomp$619$$?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2222_id$jscomp$652$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3138$undo_group$$,
$_$jscomp$2222_id$jscomp$652$$,$APP.$cljs$cst$3646$undo_id$$,$undo_id$jscomp$38$$],null))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$38$$)))});return new $app$main$data$workspace$clipboard$paste_text_71036$$($text$jscomp$57$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$clipboard$paste_svg_text$$=function($text$jscomp$59$$){typeof $app$main$data$workspace$clipboard$paste_svg_text_71045$$==="undefined"&&($app$main$data$workspace$clipboard$paste_svg_text_71045$$=function($text$jscomp$60$$,$meta71046$$){this.text=$text$jscomp$60$$;this.$meta71046$=$meta71046$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$paste_svg_text_71045$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_svg_text_71045$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4120$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_svg_text$$},$app$main$data$workspace$clipboard$paste_svg_text_71045$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71047$$,$meta71046__$1$$){return new $app$main$data$workspace$clipboard$paste_svg_text_71045$$(this.text,$meta71046__$1$$)},$app$main$data$workspace$clipboard$paste_svg_text_71045$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71046$},$app$main$data$workspace$clipboard$paste_svg_text_71045$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_svg_text_71045$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2223$$,$state$jscomp$620$$){var $position$jscomp$104$$=$app$main$data$workspace$clipboard$calculate_paste_position$$($state$jscomp$620$$),$file_id$jscomp$204$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$620$$);
return $APP.$beicon$v2$core$map$$(function($p1__71044_SHARP_$$){return $app$main$data$workspace$media$svg_uploaded$$($p1__71044_SHARP_$$,$file_id$jscomp$204$$,$position$jscomp$104$$)},$APP.$app$main$data$workspace$media$svg__GT_clj$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["svg",this.text],null)))});return new $app$main$data$workspace$clipboard$paste_svg_text_71045$$($text$jscomp$59$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$clipboard$paste_image$$=function($image$jscomp$24$$){typeof $app$main$data$workspace$clipboard$paste_image_71050$$==="undefined"&&($app$main$data$workspace$clipboard$paste_image_71050$$=function($image$jscomp$25$$,$meta71051$$){this.image=$image$jscomp$25$$;this.$meta71051$=$meta71051$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$paste_image_71050$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$clipboard$paste_image_71050$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4121$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_image$$},$app$main$data$workspace$clipboard$paste_image_71050$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71052$$,$meta71051__$1$$){return new $app$main$data$workspace$clipboard$paste_image_71050$$(this.image,$meta71051__$1$$)},$app$main$data$workspace$clipboard$paste_image_71050$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71051$},$app$main$data$workspace$clipboard$paste_image_71050$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_image_71050$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2224_file_id$jscomp$205$$,$position$jscomp$105_state$jscomp$621$$){$_$jscomp$2224_file_id$jscomp$205$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$105_state$jscomp$621$$);
$position$jscomp$105_state$jscomp$621$$=$app$main$data$workspace$clipboard$calculate_paste_position$$($position$jscomp$105_state$jscomp$621$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$media$upload_media_workspace$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1644$file_id$$,$_$jscomp$2224_file_id$jscomp$205$$,$APP.$cljs$cst$3698$blobs$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.image],null),$APP.$cljs$cst$1676$position$$,
$position$jscomp$105_state$jscomp$621$$],null)))});return new $app$main$data$workspace$clipboard$paste_image_71050$$($image$jscomp$24$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$clipboard$copy_link_to_clipboard$$=function(){typeof $app$main$data$workspace$clipboard$copy_link_to_clipboard_71058$$==="undefined"&&($app$main$data$workspace$clipboard$copy_link_to_clipboard_71058$$=function($meta71059$$){this.$meta71059$=$meta71059$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$copy_link_to_clipboard_71058$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$clipboard$copy_link_to_clipboard_71058$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4122$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_link_to_clipboard$$},$app$main$data$workspace$clipboard$copy_link_to_clipboard_71058$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71060$$,$meta71059__$1$$){return new $app$main$data$workspace$clipboard$copy_link_to_clipboard_71058$$($meta71059__$1$$)},$app$main$data$workspace$clipboard$copy_link_to_clipboard_71058$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71059$},$app$main$data$workspace$clipboard$copy_link_to_clipboard_71058$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_link_to_clipboard_71058$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$app$util$clipboard$to_clipboard$$($APP.$app$util$globals$location$$.href)});return new $app$main$data$workspace$clipboard$copy_link_to_clipboard_71058$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$split_text_shapes$$=function($objects$jscomp$588$$,$G__71084_G__71087_ids$jscomp$159_ids__$1$jscomp$18$$){$G__71084_G__71087_ids$jscomp$159_ids__$1$jscomp$18$$=$APP.$cljs$core$seq$$($G__71084_G__71087_ids$jscomp$159_ids__$1$jscomp$18$$);for(var $G__71085_G__71088_text_ids$jscomp$2$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$G__71086_G__71089_shape_ids$jscomp$11$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $id$jscomp$653_temp__5823__auto__$jscomp$183$$=$APP.$cljs$core$first$$($G__71084_G__71087_ids$jscomp$159_ids__$1$jscomp$18$$);
if($APP.$cljs$core$truth_$$($id$jscomp$653_temp__5823__auto__$jscomp$183$$)){var $shape$jscomp$679$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$588$$,$id$jscomp$653_temp__5823__auto__$jscomp$183$$);$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$679$$)?($G__71084_G__71087_ids$jscomp$159_ids__$1$jscomp$18$$=$APP.$cljs$core$rest$$($G__71084_G__71087_ids$jscomp$159_ids__$1$jscomp$18$$),$G__71085_G__71088_text_ids$jscomp$2$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__71085_G__71088_text_ids$jscomp$2$$,$id$jscomp$653_temp__5823__auto__$jscomp$183$$)):($G__71084_G__71087_ids$jscomp$159_ids__$1$jscomp$18$$=$APP.$cljs$core$rest$$($G__71084_G__71087_ids$jscomp$159_ids__$1$jscomp$18$$),$G__71086_G__71089_shape_ids$jscomp$11$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__71086_G__71089_shape_ids$jscomp$11$$,$id$jscomp$653_temp__5823__auto__$jscomp$183$$))}else return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__71085_G__71088_text_ids$jscomp$2$$,$G__71086_G__71089_shape_ids$jscomp$11$$],null)}};
$APP.$app$main$data$workspace$colors$transform_fill_STAR_$$=function($state$jscomp$628$$,$ids$jscomp$160_text_ids$jscomp$3$$,$transform$jscomp$100$$,$options$jscomp$551$$){var $objects$jscomp$589_page_id$jscomp$194_shape_ids$jscomp$12_vec__70446$$=function(){var $or__5025__auto__$jscomp$810$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$551$$,$APP.$cljs$cst$2043$page_id$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$810$$)?$or__5025__auto__$jscomp$810$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$628$$,
$APP.$cljs$cst$1918$current_page_id$$)}();$objects$jscomp$589_page_id$jscomp$194_shape_ids$jscomp$12_vec__70446$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$628$$,$objects$jscomp$589_page_id$jscomp$194_shape_ids$jscomp$12_vec__70446$$);$objects$jscomp$589_page_id$jscomp$194_shape_ids$jscomp$12_vec__70446$$=$app$main$data$workspace$colors$split_text_shapes$$($objects$jscomp$589_page_id$jscomp$194_shape_ids$jscomp$12_vec__70446$$,$ids$jscomp$160_text_ids$jscomp$3$$);
$ids$jscomp$160_text_ids$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$589_page_id$jscomp$194_shape_ids$jscomp$12_vec__70446$$,0,null);$objects$jscomp$589_page_id$jscomp$194_shape_ids$jscomp$12_vec__70446$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$589_page_id$jscomp$194_shape_ids$jscomp$12_vec__70446$$,1,null);return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$map$$(function($p1__70444_SHARP_$$){return $APP.$app$main$data$workspace$texts$update_text_with_function$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__70444_SHARP_$$,
$transform$jscomp$100$$,$options$jscomp$551$$)},$APP.$beicon$v2$core$from$$($ids$jscomp$160_text_ids$jscomp$3$$)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$589_page_id$jscomp$194_shape_ids$jscomp$12_vec__70446$$,$transform$jscomp$100$$,$options$jscomp$551$$)))};
$APP.$app$main$data$workspace$colors$transform_fill$cljs$0core$0IFn$0_invoke$0arity$05$$=function($state$jscomp$630$$,$ids$jscomp$162$$,$color$jscomp$72$$,$transform$jscomp$102$$,$options$jscomp$552$$){var $fill$jscomp$18$$=function(){var $G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;$G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$=$APP.$cljs$core$contains_QMARK_$$($color$jscomp$72$$,
$APP.$cljs$cst$1298$color$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$,$APP.$cljs$cst$1746$fill_color$$,$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$72$$)):$G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$;$G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$=
$APP.$cljs$core$contains_QMARK_$$($color$jscomp$72$$,$APP.$cljs$cst$1735$ref_id$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$,$APP.$cljs$cst$1745$fill_color_ref_id$$,$APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$72$$)):$G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$;$G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$=
$APP.$cljs$core$contains_QMARK_$$($color$jscomp$72$$,$APP.$cljs$cst$1736$ref_file$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$,$APP.$cljs$cst$1640$fill_color_ref_file$$,$APP.$cljs$cst$1736$ref_file$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$72$$)):$G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$;$G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$=
$APP.$cljs$core$contains_QMARK_$$($color$jscomp$72$$,$APP.$cljs$cst$1724$gradient$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$,$APP.$cljs$cst$1748$fill_color_gradient$$,$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$72$$)):$G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$;$G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$=
$APP.$cljs$core$contains_QMARK_$$($color$jscomp$72$$,$APP.$cljs$cst$1734$opacity$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$,$APP.$cljs$cst$1747$fill_opacity$$,$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$72$$)):$G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$;$G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$=
$APP.$cljs$core$contains_QMARK_$$($color$jscomp$72$$,$APP.$cljs$cst$1612$image$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$,$APP.$cljs$cst$1632$fill_image$$,$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$72$$)):$G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$;$G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$=
$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$);return $app$common$types$fills$check_fill$$($G__70456_G__70456__$1_G__70456__$2_G__70456__$3_G__70456__$4_G__70456__$5_G__70456__$6_G__70456__$7$$)}();return $APP.$app$main$data$workspace$colors$transform_fill_STAR_$$($state$jscomp$630$$,$ids$jscomp$162$$,function($p1__70449_SHARP_$$){return $transform$jscomp$102$$.$cljs$core$IFn$_invoke$arity$2$?
$transform$jscomp$102$$.$cljs$core$IFn$_invoke$arity$2$($p1__70449_SHARP_$$,$fill$jscomp$18$$):$transform$jscomp$102$$($p1__70449_SHARP_$$,$fill$jscomp$18$$)},$options$jscomp$552$$)};
$APP.$app$main$data$workspace$colors$change_fill$cljs$0core$0IFn$0_invoke$0arity$04$$=function($ids$jscomp$166$$,$color$jscomp$74_color__$1$jscomp$8$$,$position$jscomp$108$$){$color$jscomp$74_color__$1$jscomp$8$$=(0,$APP.$app$common$types$color$check_color$$)($color$jscomp$74_color__$1$jscomp$8$$);typeof $app$main$data$workspace$colors$change_fill_70475$$==="undefined"&&($app$main$data$workspace$colors$change_fill_70475$$=function($ids$jscomp$167$$,$color$jscomp$75$$,$position$jscomp$109$$,$options$jscomp$554$$,
$meta70476$$){this.ids=$ids$jscomp$167$$;this.color=$color$jscomp$75$$;this.position=$position$jscomp$109$$;this.options=$options$jscomp$554$$;this.$meta70476$=$meta70476$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$change_fill_70475$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_fill_70475$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4138$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_fill$$},
$app$main$data$workspace$colors$change_fill_70475$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70477$$,$meta70476__$1$$){return new $app$main$data$workspace$colors$change_fill_70475$$(this.ids,this.color,this.position,this.options,$meta70476__$1$$)},$app$main$data$workspace$colors$change_fill_70475$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70476$},$app$main$data$workspace$colors$change_fill_70475$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$colors$change_fill_70475$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2234_undo_id$jscomp$39$$,$state$jscomp$632$$){var $self__$jscomp$5180$$=this;$_$jscomp$2234_undo_id$jscomp$39$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($_$jscomp$2234_undo_id$jscomp$39$$)),$APP.$app$main$data$workspace$colors$transform_fill$cljs$0core$0IFn$0_invoke$0arity$05$$($state$jscomp$632$$,
$self__$jscomp$5180$$.ids,$self__$jscomp$5180$$.color,function($p1__70471_SHARP_$$,$p2__70472_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__70471_SHARP_$$,$APP.$cljs$cst$1634$fills$$,$app$common$types$fills$assoc$$,$self__$jscomp$5180$$.position,$p2__70472_SHARP_$$)},$self__$jscomp$5180$$.options),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($_$jscomp$2234_undo_id$jscomp$39$$)))});return new $app$main$data$workspace$colors$change_fill_70475$$($ids$jscomp$166$$,
$color$jscomp$74_color__$1$jscomp$8$$,$position$jscomp$108$$,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$colors$remove_all_fills$cljs$0core$0IFn$0_invoke$0arity$02$$=function($ids$jscomp$181$$,$options$jscomp$563$$){typeof $app$main$data$workspace$colors$remove_all_fills_70543$$==="undefined"&&($app$main$data$workspace$colors$remove_all_fills_70543$$=function($ids$jscomp$182$$,$options$jscomp$564$$,$meta70544$$){this.ids=$ids$jscomp$182$$;this.options=$options$jscomp$564$$;this.$meta70544$=$meta70544$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$colors$remove_all_fills_70543$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_all_fills_70543$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4143$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_all_fills$$},$app$main$data$workspace$colors$remove_all_fills_70543$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70545$$,$meta70544__$1$$){return new $app$main$data$workspace$colors$remove_all_fills_70543$$(this.ids,
this.options,$meta70544__$1$$)},$app$main$data$workspace$colors$remove_all_fills_70543$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70544$},$app$main$data$workspace$colors$remove_all_fills_70543$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_all_fills_70543$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2239_undo_id$jscomp$44$$,$state$jscomp$637$$){$_$jscomp$2239_undo_id$jscomp$44$$=
Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($_$jscomp$2239_undo_id$jscomp$44$$)),$APP.$app$main$data$workspace$colors$transform_fill_STAR_$$($state$jscomp$637$$,this.ids,function($node$jscomp$326$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$326$$,$APP.$cljs$cst$1634$fills$$,$APP.$app$common$types$fills$create$$())},this.options),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($_$jscomp$2239_undo_id$jscomp$44$$)))});
return new $app$main$data$workspace$colors$remove_all_fills_70543$$($ids$jscomp$181$$,$options$jscomp$563$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$colors$build_stroke_style_attrs$$=function($G__70575__$3_attrs$jscomp$140_stroke$jscomp$19$$){$G__70575__$3_attrs$jscomp$140_stroke$jscomp$19$$=$APP.$cljs$core$select_keys$$($G__70575__$3_attrs$jscomp$140_stroke$jscomp$19$$,$app$main$data$workspace$colors$stroke_style_attrs$$);var $G__70575__$1_G__70575__$2$$=$APP.$cljs$core$contains_QMARK_$$($G__70575__$3_attrs$jscomp$140_stroke$jscomp$19$$,$APP.$cljs$cst$1655$stroke_width$$)?$G__70575__$3_attrs$jscomp$140_stroke$jscomp$19$$:
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70575__$3_attrs$jscomp$140_stroke$jscomp$19$$,$APP.$cljs$cst$1655$stroke_width$$,1);$G__70575__$1_G__70575__$2$$=$APP.$cljs$core$contains_QMARK_$$($G__70575__$3_attrs$jscomp$140_stroke$jscomp$19$$,$APP.$cljs$cst$1866$stroke_style$$)?$G__70575__$1_G__70575__$2$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70575__$1_G__70575__$2$$,$APP.$cljs$cst$1866$stroke_style$$,$APP.$cljs$cst$2037$solid$$);$G__70575__$3_attrs$jscomp$140_stroke$jscomp$19$$=
$APP.$cljs$core$contains_QMARK_$$($G__70575__$3_attrs$jscomp$140_stroke$jscomp$19$$,$APP.$cljs$cst$1868$stroke_alignment$$)?$G__70575__$1_G__70575__$2$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70575__$1_G__70575__$2$$,$APP.$cljs$cst$1868$stroke_alignment$$,$APP.$cljs$cst$2041$inner$$);return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($G__70575__$3_attrs$jscomp$140_stroke$jscomp$19$$)};
$app$main$data$workspace$colors$update_shape_stroke_color$$=function($shape$jscomp$683$$,$position$jscomp$116$$,$color$jscomp$82$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$683$$,$APP.$cljs$cst$1636$strokes$$,function($strokes$jscomp$8$$){var $G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$=
$strokes$jscomp$8$$==null?$APP.$app$main$data$workspace$colors$build_stroke_style_attrs$$(null):$APP.$app$main$data$workspace$colors$build_stroke_style_attrs$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($strokes$jscomp$8$$,$position$jscomp$116$$));$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$=
$APP.$app$main$data$workspace$colors$build_stroke_style_attrs$$($G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$);$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$=
$APP.$cljs$core$contains_QMARK_$$($color$jscomp$82$$,$APP.$cljs$cst$1298$color$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$,$APP.$cljs$cst$1739$stroke_color$$,$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$82$$)):
$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$;$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$=
$APP.$cljs$core$contains_QMARK_$$($color$jscomp$82$$,$APP.$cljs$cst$1735$ref_id$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$,$APP.$cljs$cst$1742$stroke_color_ref_id$$,$APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$82$$)):
$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$;$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$=
$APP.$cljs$core$contains_QMARK_$$($color$jscomp$82$$,$APP.$cljs$cst$1736$ref_file$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$,$APP.$cljs$cst$1641$stroke_color_ref_file$$,$APP.$cljs$cst$1736$ref_file$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$82$$)):
$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$;$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$=
$APP.$cljs$core$contains_QMARK_$$($color$jscomp$82$$,$APP.$cljs$cst$1724$gradient$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$,$APP.$cljs$cst$1741$stroke_color_gradient$$,$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$82$$)):
$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$;$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$=
$APP.$cljs$core$contains_QMARK_$$($color$jscomp$82$$,$APP.$cljs$cst$1734$opacity$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$,$APP.$cljs$cst$1740$stroke_opacity$$,$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$82$$)):
$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$;$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$=
$APP.$cljs$core$contains_QMARK_$$($color$jscomp$82$$,$APP.$cljs$cst$1612$image$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$,$APP.$cljs$cst$1635$stroke_image$$,$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$82$$)):
$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$;$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$=
$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$);return $strokes$jscomp$8$$==null?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$],
null):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($strokes$jscomp$8$$,$position$jscomp$116$$,$G__70580$jscomp$inline_7106_G__70580__$1$jscomp$inline_7107_G__70580__$2$jscomp$inline_7108_G__70580__$3$jscomp$inline_7109_G__70580__$4$jscomp$inline_7110_G__70580__$5$jscomp$inline_7111_G__70580__$6$jscomp$inline_7112_stroke$jscomp$20_stroke__$1$$)})};
$APP.$app$main$data$workspace$colors$change_stroke_color$cljs$0core$0IFn$0_invoke$0arity$04$$=function($ids$jscomp$186$$,$color$jscomp$84$$,$index$jscomp$298$$){typeof $app$main$data$workspace$colors$change_stroke_color_70599$$==="undefined"&&($app$main$data$workspace$colors$change_stroke_color_70599$$=function($ids$jscomp$187$$,$color$jscomp$85$$,$index$jscomp$299$$,$options$jscomp$566$$,$meta70600$$){this.ids=$ids$jscomp$187$$;this.color=$color$jscomp$85$$;this.index=$index$jscomp$299$$;this.options=
$options$jscomp$566$$;this.$meta70600$=$meta70600$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$change_stroke_color_70599$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_stroke_color_70599$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4145$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_stroke_color$$},$app$main$data$workspace$colors$change_stroke_color_70599$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70601$$,$meta70600__$1$$){return new $app$main$data$workspace$colors$change_stroke_color_70599$$(this.ids,this.color,this.index,this.options,$meta70600__$1$$)},$app$main$data$workspace$colors$change_stroke_color_70599$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70600$},$app$main$data$workspace$colors$change_stroke_color_70599$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_stroke_color_70599$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$5208$$=this;return(0,$APP.$beicon$v2$core$of$$)(function(){var $options__$1$jscomp$72$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$5208$$.options,$APP.$cljs$cst$3521$changed_sub_attr$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1739$stroke_color$$],null));return $APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5208$$.ids,
function($p1__70593_SHARP_$$){return $app$main$data$workspace$colors$update_shape_stroke_color$$($p1__70593_SHARP_$$,$self__$jscomp$5208$$.index,$self__$jscomp$5208$$.color)},$options__$1$jscomp$72$$)}())});return new $app$main$data$workspace$colors$change_stroke_color_70599$$($ids$jscomp$186$$,$color$jscomp$84$$,$index$jscomp$298$$,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$change_shadow$$=function($ids$jscomp$191$$,$attrs$jscomp$144$$,$index$jscomp$303$$){typeof $app$main$data$workspace$colors$change_shadow_70661$$==="undefined"&&($app$main$data$workspace$colors$change_shadow_70661$$=function($ids$jscomp$192$$,$attrs$jscomp$145$$,$index$jscomp$304$$,$update_shadow$jscomp$1$$,$meta70662$$){this.ids=$ids$jscomp$192$$;this.$attrs$=$attrs$jscomp$145$$;this.index=$index$jscomp$304$$;this.$update_shadow$=$update_shadow$jscomp$1$$;this.$meta70662$=
$meta70662$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$change_shadow_70661$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_shadow_70661$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4147$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_shadow$$},$app$main$data$workspace$colors$change_shadow_70661$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70663$$,$meta70662__$1$$){return new $app$main$data$workspace$colors$change_shadow_70661$$(this.ids,this.$attrs$,this.index,this.$update_shadow$,$meta70662__$1$$)},$app$main$data$workspace$colors$change_shadow_70661$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70662$},$app$main$data$workspace$colors$change_shadow_70661$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_shadow_70661$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(this.ids,this.$update_shadow$))});return new $app$main$data$workspace$colors$change_shadow_70661$$($ids$jscomp$191$$,$attrs$jscomp$144$$,$index$jscomp$303$$,function($shape$jscomp$685$$){var $attrs_SINGLEQUOTE__attrs__$1$jscomp$23$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$144$$))?$APP.$cljs$core$select_keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$144$$,
$APP.$cljs$cst$1724$gradient$$),$APP.$cljs$cst$1733$stops$$),0),$app$common$types$shape$shadow$color_attrs$$):$attrs$jscomp$144$$;$attrs_SINGLEQUOTE__attrs__$1$jscomp$23$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$685$$,
$APP.$cljs$cst$1654$shadow$$),$index$jscomp$303$$),$APP.$cljs$cst$1298$color$$),$attrs_SINGLEQUOTE__attrs__$1$jscomp$23$$])));return $APP.$cljs$core$assoc_in$$($shape$jscomp$685$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1654$shadow$$,$index$jscomp$303$$,$APP.$cljs$cst$1298$color$$],null),$attrs_SINGLEQUOTE__attrs__$1$jscomp$23$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$colors$add_stroke$$=function($ids$jscomp$195$$,$stroke$jscomp$22$$){typeof $app$main$data$workspace$colors$add_stroke_70682$$==="undefined"&&($app$main$data$workspace$colors$add_stroke_70682$$=function($ids$jscomp$196$$,$stroke$jscomp$23$$,$meta70683$$){this.ids=$ids$jscomp$196$$;this.stroke=$stroke$jscomp$23$$;this.$meta70683$=$meta70683$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$add_stroke_70682$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_stroke_70682$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4149$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_add_stroke$$},$app$main$data$workspace$colors$add_stroke_70682$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70684$$,$meta70683__$1$$){return new $app$main$data$workspace$colors$add_stroke_70682$$(this.ids,this.stroke,$meta70683__$1$$)},$app$main$data$workspace$colors$add_stroke_70682$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70683$},$app$main$data$workspace$colors$add_stroke_70682$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_stroke_70682$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$5224$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5224$$.ids,function($shape$jscomp$687$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$687$$,
$APP.$cljs$cst$1636$strokes$$,function($p1__70677_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$5224$$.stroke],null),$p1__70677_SHARP_$$)})},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$],null)],null)))});return new $app$main$data$workspace$colors$add_stroke_70682$$($ids$jscomp$195$$,
$stroke$jscomp$22$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$picker_for_selected_shape$$=function(){var $sub$jscomp$17$$=$APP.$beicon$v2$core$subject$$();typeof $app$main$data$workspace$colors$picker_for_selected_shape_70781$$==="undefined"&&($app$main$data$workspace$colors$picker_for_selected_shape_70781$$=function($sub$jscomp$18$$,$meta70782$$){this.sub=$sub$jscomp$18$$;this.$meta70782$=$meta70782$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$picker_for_selected_shape_70781$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$picker_for_selected_shape_70781$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4154$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_picker_for_selected_shape$$},$app$main$data$workspace$colors$picker_for_selected_shape_70781$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70783$$,$meta70782__$1$$){return new $app$main$data$workspace$colors$picker_for_selected_shape_70781$$(this.sub,
$meta70782__$1$$)},$app$main$data$workspace$colors$picker_for_selected_shape_70781$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70782$},$app$main$data$workspace$colors$picker_for_selected_shape_70781$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$picker_for_selected_shape_70781$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2250_stop_QMARK_$$,$state$jscomp$639$$,$stream$jscomp$64$$){var $ids$jscomp$205$$=
$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$639$$);$_$jscomp$2250_stop_QMARK_$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4131$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_stop_picker$$),$stream$jscomp$64$$);return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$merge_map$$(function($color$jscomp$86$$){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$colors$change_fill$cljs$0core$0IFn$0_invoke$0arity$04$$($ids$jscomp$205$$,
$color$jscomp$86$$,0))},$APP.$beicon$v2$core$take_until$$($_$jscomp$2250_stop_QMARK_$$,this.sub)),$APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$modal$hide$$()},$APP.$beicon$v2$core$take$$($_$jscomp$2250_stop_QMARK_$$)))},$app$main$data$workspace$colors$picker_for_selected_shape_70781$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$picker_for_selected_shape_70781$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2251$$,
$state$jscomp$640$$){var $self__$jscomp$5245$$=this;return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc_in$$($state$jscomp$640$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,$APP.$cljs$cst$4130$picking_color_QMARK_$$],null),!0),$APP.$cljs$cst$2338$app_DOT_main_DOT_data_DOT_modal_SLASH_modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$cljs$core$random_uuid$$(),
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2239$colorpicker$$,$APP.$cljs$cst$575$props$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,"#000000",$APP.$cljs$cst$1734$opacity$$,1],null),$APP.$cljs$cst$4155$disable_opacity$$,!1,$APP.$cljs$cst$4156$disable_gradient$$,!1,$APP.$cljs$cst$4157$on_change$$,function($color$jscomp$87$$){return $self__$jscomp$5245$$.sub.next($color$jscomp$87$$)}],null),$APP.$cljs$cst$2339$allow_click_outside$$,
!0],null))});return new $app$main$data$workspace$colors$picker_for_selected_shape_70781$$($sub$jscomp$17$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$color_att__GT_text$$=function($color$jscomp$88$$){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1746$fill_color$$,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$88$$))?$APP.$cuerdas$core$lower$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$88$$)):null,$APP.$cljs$cst$1747$fill_opacity$$,$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$88$$),
$APP.$cljs$cst$1745$fill_color_ref_id$$,$APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$88$$),$APP.$cljs$cst$1640$fill_color_ref_file$$,$APP.$cljs$cst$1736$ref_file$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$88$$),$APP.$cljs$cst$1748$fill_color_gradient$$,$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$88$$)],null))};
$app$main$data$workspace$colors$change_text_color$$=function($old_color$$,$new_color$jscomp$1$$,$index$jscomp$306$$,$node$jscomp$327$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($node$jscomp$327$$,$APP.$cljs$cst$1634$fills$$,$APP.$app$common$types$fills$update$$,function($fills$jscomp$28$$){var $fills_SINGLEQUOTE_$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70801_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__70801_SHARP_$$,
$APP.$cljs$cst$1745$fill_color_ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1640$fill_color_ref_file$$]))},$fills$jscomp$28$$),$parsed_color$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$color_att__GT_text$$($old_color$$),$APP.$cljs$cst$1745$fill_color_ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1640$fill_color_ref_file$$])),$parsed_new_color$$=$app$main$data$workspace$colors$color_att__GT_text$$($new_color$jscomp$1$$);
return $APP.$app$common$data$index_of$$($fills_SINGLEQUOTE_$$,$parsed_color$$)!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($fills$jscomp$28$$,$index$jscomp$306$$,$parsed_new_color$$):$fills$jscomp$28$$})};
$APP.$app$main$data$workspace$colors$change_color_in_selected$$=function($operations$jscomp$9$$,$new_color$jscomp$2$$,$old_color$jscomp$1$$){typeof $app$main$data$workspace$colors$change_color_in_selected_70813$$==="undefined"&&($app$main$data$workspace$colors$change_color_in_selected_70813$$=function($operations$jscomp$10$$,$new_color$jscomp$3$$,$old_color$jscomp$2$$,$meta70814$$){this.$operations$=$operations$jscomp$10$$;this.$new_color$=$new_color$jscomp$3$$;this.$old_color$=$old_color$jscomp$2$$;
this.$meta70814$=$meta70814$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$change_color_in_selected_70813$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_color_in_selected_70813$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4159$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_color_in_selected$$},$app$main$data$workspace$colors$change_color_in_selected_70813$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70815$$,$meta70814__$1$$){return new $app$main$data$workspace$colors$change_color_in_selected_70813$$(this.$operations$,this.$new_color$,this.$old_color$,$meta70814__$1$$)},$app$main$data$workspace$colors$change_color_in_selected_70813$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70814$},$app$main$data$workspace$colors$change_color_in_selected_70813$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_color_in_selected_70813$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$5249$$=this,$undo_id$jscomp$45$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$45$$)),$APP.$beicon$v2$core$map$$(function($p__70827_shape_id$jscomp$107$$){var $G__70833_G__70833__$1_map__70829__$1$$=$APP.$cljs$core$__destructure_map$$($p__70827_shape_id$jscomp$107$$);$p__70827_shape_id$jscomp$107$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__70833_G__70833__$1_map__70829__$1$$,
$APP.$cljs$cst$2543$shape_id$$);var $index$jscomp$307$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__70833_G__70833__$1_map__70829__$1$$,$APP.$cljs$cst$1795$index$$);$G__70833_G__70833__$1_map__70829__$1$$=$APP.$cljs$cst$4158$prop$$.$cljs$core$IFn$_invoke$arity$1$($G__70833_G__70833__$1_map__70829__$1$$);$G__70833_G__70833__$1_map__70829__$1$$=$G__70833_G__70833__$1_map__70829__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__70833_G__70833__$1_map__70829__$1$$.$fqn$:null;switch($G__70833_G__70833__$1_map__70829__$1$$){case "fill":return $APP.$app$main$data$workspace$colors$change_fill$cljs$0core$0IFn$0_invoke$0arity$04$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p__70827_shape_id$jscomp$107$$],null),$self__$jscomp$5249$$.$new_color$,$index$jscomp$307$$);case "stroke":return $APP.$app$main$data$workspace$colors$change_stroke_color$cljs$0core$0IFn$0_invoke$0arity$04$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p__70827_shape_id$jscomp$107$$],null),$self__$jscomp$5249$$.$new_color$,$index$jscomp$307$$);case "shadow":return $app$main$data$workspace$colors$change_shadow$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p__70827_shape_id$jscomp$107$$],null),$self__$jscomp$5249$$.$new_color$,$index$jscomp$307$$);case "content":return $APP.$app$main$data$workspace$texts$update_text_with_function$cljs$0core$0IFn$0_invoke$0arity$03$$($p__70827_shape_id$jscomp$107$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$data$workspace$colors$change_text_color$$,$self__$jscomp$5249$$.$old_color$,$self__$jscomp$5249$$.$new_color$,$index$jscomp$307$$),null);
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__70833_G__70833__$1_map__70829__$1$$)].join(""));}},$APP.$beicon$v2$core$from$$($self__$jscomp$5249$$.$operations$)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$45$$)))});return new $app$main$data$workspace$colors$change_color_in_selected_70813$$($operations$jscomp$9$$,$new_color$jscomp$2$$,$old_color$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$stroke__GT_color_att$$=function($stroke$jscomp$24$$,$attrs$jscomp$146_base_attrs$jscomp$1_file_id$jscomp$210$$,$colors$jscomp$5_libraries$jscomp$87_shared_QMARK_$$){var $ref_file$jscomp$7$$=$APP.$cljs$cst$1641$stroke_color_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$24$$),$has_color_QMARK_$jscomp$1_ref_id$jscomp$8$$=$APP.$cljs$cst$1742$stroke_color_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$24$$);$colors$jscomp$5_libraries$jscomp$87_shared_QMARK_$$=
$app$common$types$library$get_colors$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($colors$jscomp$5_libraries$jscomp$87_shared_QMARK_$$,$ref_file$jscomp$7$$),$APP.$cljs$cst$142$data$$));$colors$jscomp$5_libraries$jscomp$87_shared_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($colors$jscomp$5_libraries$jscomp$87_shared_QMARK_$$,$has_color_QMARK_$jscomp$1_ref_id$jscomp$8$$);$has_color_QMARK_$jscomp$1_ref_id$jscomp$8$$=$APP.$cljs$cst$1739$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$24$$);
var $G__71048$jscomp$inline_12791$$=$APP.$app$common$types$color$stroke__GT_color$$($stroke$jscomp$24$$);$attrs$jscomp$146_base_attrs$jscomp$1_file_id$jscomp$210$$=$colors$jscomp$5_libraries$jscomp$87_shared_QMARK_$$||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ref_file$jscomp$7$$,$attrs$jscomp$146_base_attrs$jscomp$1_file_id$jscomp$210$$)?$G__71048$jscomp$inline_12791$$:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71048$jscomp$inline_12791$$,$APP.$cljs$cst$1736$ref_file$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1735$ref_id$$]));$attrs$jscomp$146_base_attrs$jscomp$1_file_id$jscomp$210$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$4185$has_token_applied$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$24$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($attrs$jscomp$146_base_attrs$jscomp$1_file_id$jscomp$210$$,$APP.$cljs$cst$4185$has_token_applied$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4186$token_name$$,
$APP.$cljs$cst$4186$token_name$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$24$$)])):$attrs$jscomp$146_base_attrs$jscomp$1_file_id$jscomp$210$$;return $APP.$cljs$core$truth_$$($has_color_QMARK_$jscomp$1_ref_id$jscomp$8$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2645$attrs$$,$attrs$jscomp$146_base_attrs$jscomp$1_file_id$jscomp$210$$,$APP.$cljs$cst$4158$prop$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$2543$shape_id$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$24$$),
$APP.$cljs$cst$1795$index$$,$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$24$$)],null):null};
$app$main$data$workspace$colors$shadow__GT_color_attr$$=function($shadow__$1$jscomp$11$$,$attrs$jscomp$147_file_id$jscomp$211$$,$colors$jscomp$6_libraries$jscomp$88_shared_QMARK_$jscomp$1$$){var $G__71053$jscomp$inline_7122_color$jscomp$102_ref_id$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadow__$1$jscomp$11$$,$APP.$cljs$cst$1298$color$$),$ref_file$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__71053$jscomp$inline_7122_color$jscomp$102_ref_id$jscomp$9$$,
$APP.$cljs$cst$1736$ref_file$$);$G__71053$jscomp$inline_7122_color$jscomp$102_ref_id$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__71053$jscomp$inline_7122_color$jscomp$102_ref_id$jscomp$9$$,$APP.$cljs$cst$1735$ref_id$$);$colors$jscomp$6_libraries$jscomp$88_shared_QMARK_$jscomp$1$$=$app$common$types$library$get_colors$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($colors$jscomp$6_libraries$jscomp$88_shared_QMARK_$jscomp$1$$,
$ref_file$jscomp$8$$),$APP.$cljs$cst$142$data$$));$colors$jscomp$6_libraries$jscomp$88_shared_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($colors$jscomp$6_libraries$jscomp$88_shared_QMARK_$jscomp$1$$,$G__71053$jscomp$inline_7122_color$jscomp$102_ref_id$jscomp$9$$);$G__71053$jscomp$inline_7122_color$jscomp$102_ref_id$jscomp$9$$=$app$common$types$color$shadow__GT_color$$($shadow__$1$jscomp$11$$);$attrs$jscomp$147_file_id$jscomp$211$$=$colors$jscomp$6_libraries$jscomp$88_shared_QMARK_$jscomp$1$$||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ref_file$jscomp$8$$,$attrs$jscomp$147_file_id$jscomp$211$$)?$G__71053$jscomp$inline_7122_color$jscomp$102_ref_id$jscomp$9$$:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71053$jscomp$inline_7122_color$jscomp$102_ref_id$jscomp$9$$,$APP.$cljs$cst$1736$ref_file$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1735$ref_id$$]));return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2645$attrs$$,
$attrs$jscomp$147_file_id$jscomp$211$$,$APP.$cljs$cst$4158$prop$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$2543$shape_id$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$11$$),$APP.$cljs$cst$1795$index$$,$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$11$$)],null)};
$app$main$data$workspace$colors$extract_text_colors$$=function($text$jscomp$61$$,$file_id$jscomp$213$$,$libraries$jscomp$90$$){function $treat_node$$($node$jscomp$328$$,$shape_id$jscomp$109$$){return $APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($idx$jscomp$94$$,$fill$jscomp$20$$){var $G__71070$jscomp$inline_12793_args$jscomp$247$$=$APP.$cljs$core$PersistentVector$EMPTY$$;var $and__5023__auto__$jscomp$inline_12795$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$94$$,
0);$G__71070$jscomp$inline_12793_args$jscomp$247$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_12795$$?$applied_fill_token$$:$and__5023__auto__$jscomp$inline_12795$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71070$jscomp$inline_12793_args$jscomp$247$$,$APP.$cljs$cst$4185$has_token_applied$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([!0,$APP.$cljs$cst$4186$token_name$$,$applied_fill_token$$])):$G__71070$jscomp$inline_12793_args$jscomp$247$$;
return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($app$main$data$workspace$colors$text__GT_color_att$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($fill$jscomp$20$$,$APP.$cljs$cst$2543$shape_id$$,$shape_id$jscomp$109$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1795$index$$,$idx$jscomp$94$$])),$file_id$jscomp$213$$,$libraries$jscomp$90$$,$G__71070$jscomp$inline_12793_args$jscomp$247$$)},$node$jscomp$328$$)}var $applied_fill_token$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($text$jscomp$61$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1873$applied_tokens$$,$APP.$cljs$cst$1403$fill$$],null));return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__71069_SHARP_$$){return $treat_node$$($p1__71069_SHARP_$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($text$jscomp$61$$))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1634$fills$$,
$APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($text$jscomp$61$$)))]))};
$app$main$data$workspace$colors$fill__GT_color_att$$=function($fill$jscomp$21$$,$file_id$jscomp$214$$,$attrs$jscomp$149_base_attrs$jscomp$3_colors$jscomp$8_libraries$jscomp$91$$){var $ref_file$jscomp$10$$=$APP.$cljs$cst$1640$fill_color_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$21$$),$has_color_QMARK_$jscomp$2_ref_id$jscomp$11$$=$APP.$cljs$cst$1745$fill_color_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$21$$);$attrs$jscomp$149_base_attrs$jscomp$3_colors$jscomp$8_libraries$jscomp$91$$=
$app$common$types$library$get_colors$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$149_base_attrs$jscomp$3_colors$jscomp$8_libraries$jscomp$91$$,$ref_file$jscomp$10$$),$APP.$cljs$cst$142$data$$));var $shared_QMARK_$jscomp$3$$=$APP.$cljs$core$contains_QMARK_$$($attrs$jscomp$149_base_attrs$jscomp$3_colors$jscomp$8_libraries$jscomp$91$$,$has_color_QMARK_$jscomp$2_ref_id$jscomp$11$$);$has_color_QMARK_$jscomp$2_ref_id$jscomp$11$$=
function(){var $or__5025__auto__$jscomp$817$$=$APP.$cljs$cst$1746$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$21$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$817$$)?$or__5025__auto__$jscomp$817$$:$APP.$cljs$cst$1748$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$21$$)}();$attrs$jscomp$149_base_attrs$jscomp$3_colors$jscomp$8_libraries$jscomp$91$$=function(){var $G__71071$$=$APP.$app$common$types$fills$fill__GT_color$$($fill$jscomp$21$$);return $shared_QMARK_$jscomp$3$$||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ref_file$jscomp$10$$,$file_id$jscomp$214$$)?$G__71071$$:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71071$$,$APP.$cljs$cst$1736$ref_file$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1735$ref_id$$]))}();$attrs$jscomp$149_base_attrs$jscomp$3_colors$jscomp$8_libraries$jscomp$91$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$4185$has_token_applied$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$21$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($attrs$jscomp$149_base_attrs$jscomp$3_colors$jscomp$8_libraries$jscomp$91$$,$APP.$cljs$cst$4185$has_token_applied$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4186$token_name$$,$APP.$cljs$cst$4186$token_name$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$21$$)])):$attrs$jscomp$149_base_attrs$jscomp$3_colors$jscomp$8_libraries$jscomp$91$$;return $APP.$cljs$core$truth_$$($has_color_QMARK_$jscomp$2_ref_id$jscomp$11$$)?
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2645$attrs$$,$attrs$jscomp$149_base_attrs$jscomp$3_colors$jscomp$8_libraries$jscomp$91$$,$APP.$cljs$cst$4158$prop$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$2543$shape_id$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$21$$),$APP.$cljs$cst$1795$index$$,$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$21$$)],null):null};
$APP.$app$main$data$workspace$colors$extract_all_colors$$=function($shapes$jscomp$114$$,$file_id$jscomp$215$$,$libraries$jscomp$92$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$312$$,$shape$jscomp$689$$){var $applied_tokens$jscomp$2_shadows$jscomp$2_shadows_STAR_$$=$APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$689$$),$applied_fill$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$2_shadows$jscomp$2_shadows_STAR_$$,
$APP.$cljs$cst$1403$fill$$),$applied_stroke$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$2_shadows$jscomp$2_shadows_STAR_$$,$APP.$cljs$cst$1739$stroke_color$$),$fills$jscomp$29_fills_STAR_$$=$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$689$$),$strokes$jscomp$9_strokes_STAR_$$=$APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$689$$);$applied_tokens$jscomp$2_shadows$jscomp$2_shadows_STAR_$$=$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$689$$);
var $shape_id$jscomp$110$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$689$$);$fills$jscomp$29_fills_STAR_$$=$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($and__5023__auto__$jscomp$inline_7126_index$jscomp$313$$,$G__71082_fill$jscomp$22$$){$G__71082_fill$jscomp$22$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71082_fill$jscomp$22$$,$APP.$cljs$cst$2543$shape_id$$,$shape_id$jscomp$110$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1795$index$$,
$and__5023__auto__$jscomp$inline_7126_index$jscomp$313$$]));$and__5023__auto__$jscomp$inline_7126_index$jscomp$313$$=$and__5023__auto__$jscomp$inline_7126_index$jscomp$313$$===0;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_7126_index$jscomp$313$$?$applied_fill$$:$and__5023__auto__$jscomp$inline_7126_index$jscomp$313$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71082_fill$jscomp$22$$,$APP.$cljs$cst$4185$has_token_applied$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4186$token_name$$,
$applied_fill$$])):$G__71082_fill$jscomp$22$$},$fills$jscomp$29_fills_STAR_$$);$strokes$jscomp$9_strokes_STAR_$$=$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($and__5023__auto__$jscomp$inline_7128_index$jscomp$314$$,$G__71083_stroke$jscomp$25$$){$G__71083_stroke$jscomp$25$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71083_stroke$jscomp$25$$,$APP.$cljs$cst$2543$shape_id$$,$shape_id$jscomp$110$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1795$index$$,
$and__5023__auto__$jscomp$inline_7128_index$jscomp$314$$]));$and__5023__auto__$jscomp$inline_7128_index$jscomp$314$$=$and__5023__auto__$jscomp$inline_7128_index$jscomp$314$$===0;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_7128_index$jscomp$314$$?$applied_stroke$$:$and__5023__auto__$jscomp$inline_7128_index$jscomp$314$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71083_stroke$jscomp$25$$,$APP.$cljs$cst$4185$has_token_applied$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4186$token_name$$,
$applied_stroke$$])):$G__71083_stroke$jscomp$25$$},$strokes$jscomp$9_strokes_STAR_$$);$applied_tokens$jscomp$2_shadows$jscomp$2_shadows_STAR_$$=$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__71076_SHARP_$$,$p2__71075_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p2__71075_SHARP_$$,$APP.$cljs$cst$2543$shape_id$$,$shape_id$jscomp$110$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1795$index$$,$p1__71076_SHARP_$$]))},
$applied_tokens$jscomp$2_shadows$jscomp$2_shadows_STAR_$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$689$$))?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$312$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__71077_SHARP_$$){return $app$main$data$workspace$colors$stroke__GT_color_att$$($p1__71077_SHARP_$$,
$file_id$jscomp$215$$,$libraries$jscomp$92$$)}),$strokes$jscomp$9_strokes_STAR_$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__71078_SHARP_$$){return $app$main$data$workspace$colors$shadow__GT_color_attr$$($p1__71078_SHARP_$$,$file_id$jscomp$215$$,$libraries$jscomp$92$$)}),$applied_tokens$jscomp$2_shadows$jscomp$2_shadows_STAR_$$),$app$main$data$workspace$colors$extract_text_colors$$($shape$jscomp$689$$,$file_id$jscomp$215$$,$libraries$jscomp$92$$)):$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$312$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__71079_SHARP_$$){return $app$main$data$workspace$colors$fill__GT_color_att$$($p1__71079_SHARP_$$,$file_id$jscomp$215$$,$libraries$jscomp$92$$)}),$fills$jscomp$29_fills_STAR_$$),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__71080_SHARP_$$){return $app$main$data$workspace$colors$stroke__GT_color_att$$($p1__71080_SHARP_$$,$file_id$jscomp$215$$,$libraries$jscomp$92$$)}),$strokes$jscomp$9_strokes_STAR_$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__71081_SHARP_$$){return $app$main$data$workspace$colors$shadow__GT_color_attr$$($p1__71081_SHARP_$$,$file_id$jscomp$215$$,$libraries$jscomp$92$$)}),$applied_tokens$jscomp$2_shadows$jscomp$2_shadows_STAR_$$)},$APP.$cljs$core$PersistentVector$EMPTY$$,$shapes$jscomp$114$$)};
$APP.$app$main$data$workspace$drawing$common$clear_drawing$$=function(){typeof $app$main$data$workspace$drawing$common$clear_drawing_69146$$==="undefined"&&($app$main$data$workspace$drawing$common$clear_drawing_69146$$=function($meta69147$$){this.$meta69147$=$meta69147$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$drawing$common$clear_drawing_69146$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$common$clear_drawing_69146$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4187$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_common_SLASH_clear_drawing$$},$app$main$data$workspace$drawing$common$clear_drawing_69146$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69148$$,$meta69147__$1$$){return new $app$main$data$workspace$drawing$common$clear_drawing_69146$$($meta69147__$1$$)},$app$main$data$workspace$drawing$common$clear_drawing_69146$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69147$},$app$main$data$workspace$drawing$common$clear_drawing_69146$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$common$clear_drawing_69146$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2277$$,$state$jscomp$663$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$663$$,$APP.$cljs$cst$2189$workspace_drawing$$)});return new $app$main$data$workspace$drawing$common$clear_drawing_69146$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$drawing$common$handle_finish_drawing$$=function(){typeof $app$main$data$workspace$drawing$common$handle_finish_drawing_69159$$==="undefined"&&($app$main$data$workspace$drawing$common$handle_finish_drawing_69159$$=function($meta69160$$){this.$meta69160$=$meta69160$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$drawing$common$handle_finish_drawing_69159$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$drawing$common$handle_finish_drawing_69159$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4188$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_common_SLASH_handle_finish_drawing$$},$app$main$data$workspace$drawing$common$handle_finish_drawing_69159$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69161$$,$meta69160__$1$$){return new $app$main$data$workspace$drawing$common$handle_finish_drawing_69159$$($meta69160__$1$$)},$app$main$data$workspace$drawing$common$handle_finish_drawing_69159$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69160$},$app$main$data$workspace$drawing$common$handle_finish_drawing_69159$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$common$handle_finish_drawing_69159$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2278$$,$state$jscomp$664$$){var $drawing_state$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$664$$,$APP.$cljs$cst$2189$workspace_drawing$$),$shape$jscomp$690$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($drawing_state$$,$APP.$cljs$cst$2198$object$$),$tool$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($drawing_state$$,$APP.$cljs$cst$2197$tool$$),$objects$jscomp$593$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$664$$),$page_id$jscomp$196$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$664$$);return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$truth_$$($cljs$cst$4189$initialized_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$690$$))?
function(){var $click_draw_QMARK_$$=$cljs$cst$4190$click_draw_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$690$$),$text_QMARK_$jscomp$1$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$690$$),$width$jscomp$149$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($drawing_state$$,$APP.$cljs$cst$290$width$$,100),$height$jscomp$133$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($drawing_state$$,$APP.$cljs$cst$1522$height$$,100),
$shape__$1$jscomp$47$$=function(){var $G__69164__$1_G__69164__$2_G__69164__$3$$=$APP.$cljs$core$not$$($click_draw_QMARK_$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$690$$,$APP.$cljs$cst$1770$grow_type$$,$APP.$cljs$cst$1671$fixed$$):$shape$jscomp$690$$;$G__69164__$1_G__69164__$2_G__69164__$3$$=$click_draw_QMARK_$$&&!$text_QMARK_$jscomp$1$$?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__69164__$1_G__69164__$2_G__69164__$3$$,
$APP.$cljs$cst$290$width$$,$width$jscomp$149$$),$APP.$cljs$cst$1522$height$$,$height$jscomp$133$$),$APP.$cljs$cst$1605$selrect$$,null),$APP.$cljs$cst$1604$points$$,null)),$APP.$app$common$types$modifiers$move$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$modifiers$empty$$(),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-($width$jscomp$149$$/2),-($height$jscomp$133$$/2)))):$G__69164__$1_G__69164__$2_G__69164__$3$$;$G__69164__$1_G__69164__$2_G__69164__$3$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($click_draw_QMARK_$$)?
$text_QMARK_$jscomp$1$$:$click_draw_QMARK_$$)?$APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__69164__$1_G__69164__$2_G__69164__$3$$,$APP.$cljs$cst$1522$height$$,17,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$290$width$$,4,$APP.$cljs$cst$1770$grow_type$$,$APP.$cljs$cst$2036$auto_width$$]))):$G__69164__$1_G__69164__$2_G__69164__$3$$;return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__69164__$1_G__69164__$2_G__69164__$3$$,
$cljs$cst$4189$initialized_QMARK_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$4190$click_draw_QMARK_$$]))}();return $APP.$beicon$v2$core$concat$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$47$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$47$$))):$APP.$beicon$v2$core$empty$$(),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$shapes$add_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($shape__$1$jscomp$47$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3639$no_select_QMARK_$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($tool$$,$APP.$cljs$cst$2052$curve$$)],null))),$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$47$$)?$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$map$$(function($p1__69155_SHARP_$$){return $app$main$data$workspace$shapes$move_shapes_into_frame$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$47$$),
$p1__69155_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($p1__69154_SHARP_$$){return $APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$593$$,$p1__69154_SHARP_$$)},$APP.$app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$3115$cmd$$,$APP.$cljs$cst$3605$index_SLASH_query_selection$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$196$$,$APP.$cljs$cst$1611$rect$$,$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$47$$),
$APP.$cljs$cst$3606$include_frames_QMARK_$$,!0,$APP.$cljs$cst$3608$full_frame_QMARK_$$,!0,$APP.$cljs$cst$3609$using_selrect_QMARK_$$,!0],null)))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$47$$)))):$APP.$beicon$v2$core$empty$$())}():null,$APP.$beicon$v2$core$delay$$(0,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$drawing$common$clear_drawing$$())))});return new $app$main$data$workspace$drawing$common$handle_finish_drawing_69159$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$drawing$box$resize_shape$$=function($map__69235__$1_p__69233$$,$G__69250$jscomp$inline_12801_initial$jscomp$21_p1$jscomp$76$$,$JSCompiler_temp$jscomp$14075_p2$jscomp$57_point$jscomp$65$$,$dx$jscomp$inline_14456_lock_QMARK_$jscomp$1$$,$mod_QMARK_$jscomp$4$$,$draw_rect_movev$jscomp$2_snap_pixel_QMARK_$jscomp$5$$){$map__69235__$1_p__69233$$=$APP.$cljs$core$__destructure_map$$($map__69235__$1_p__69233$$);var $x$jscomp$1202$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69235__$1_p__69233$$,
$APP.$cljs$cst$1510$x$$),$y$jscomp$435$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69235__$1_p__69233$$,$APP.$cljs$cst$1511$y$$),$scalev$jscomp$5_width$jscomp$150$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69235__$1_p__69233$$,$APP.$cljs$cst$290$width$$),$height$jscomp$134_shape_rect$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69235__$1_p__69233$$,$APP.$cljs$cst$1522$height$$);if($x$jscomp$1202$$!=null&&$y$jscomp$435$$!=null&&$scalev$jscomp$5_width$jscomp$150$$!=
null&&$height$jscomp$134_shape_rect$$!=null){if($APP.$cljs$core$truth_$$($dx$jscomp$inline_14456_lock_QMARK_$jscomp$1$$)){var $G__69224__$1$jscomp$inline_14460_sy$jscomp$inline_14459_v$jscomp$inline_14455$$=$APP.$app$common$geom$point$subtract$$($G__69250$jscomp$inline_12801_initial$jscomp$21_p1$jscomp$76$$,$JSCompiler_temp$jscomp$14075_p2$jscomp$57_point$jscomp$65$$);$dx$jscomp$inline_14456_lock_QMARK_$jscomp$1$$=$APP.$app$common$math$abs$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($G__69224__$1$jscomp$inline_14460_sy$jscomp$inline_14459_v$jscomp$inline_14455$$));
var $dy$jscomp$inline_14457$$=$APP.$app$common$math$abs$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($G__69224__$1$jscomp$inline_14460_sy$jscomp$inline_14459_v$jscomp$inline_14455$$));var $sx$jscomp$inline_14458$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($G__69224__$1$jscomp$inline_14460_sy$jscomp$inline_14459_v$jscomp$inline_14455$$)<0?-1:1;$G__69224__$1$jscomp$inline_14460_sy$jscomp$inline_14459_v$jscomp$inline_14455$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($G__69224__$1$jscomp$inline_14460_sy$jscomp$inline_14459_v$jscomp$inline_14455$$)<
0?-1:1;$G__69224__$1$jscomp$inline_14460_sy$jscomp$inline_14459_v$jscomp$inline_14455$$=$dx$jscomp$inline_14456_lock_QMARK_$jscomp$1$$>$dy$jscomp$inline_14457$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$14075_p2$jscomp$57_point$jscomp$65$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$14075_p2$jscomp$57_point$jscomp$65$$)-$G__69224__$1$jscomp$inline_14460_sy$jscomp$inline_14459_v$jscomp$inline_14455$$*
($dx$jscomp$inline_14456_lock_QMARK_$jscomp$1$$-$dy$jscomp$inline_14457$$)):$JSCompiler_temp$jscomp$14075_p2$jscomp$57_point$jscomp$65$$;$JSCompiler_temp$jscomp$14075_p2$jscomp$57_point$jscomp$65$$=$dy$jscomp$inline_14457$$>$dx$jscomp$inline_14456_lock_QMARK_$jscomp$1$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__69224__$1$jscomp$inline_14460_sy$jscomp$inline_14459_v$jscomp$inline_14455$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$14075_p2$jscomp$57_point$jscomp$65$$)-
$sx$jscomp$inline_14458$$*($dy$jscomp$inline_14457$$-$dx$jscomp$inline_14456_lock_QMARK_$jscomp$1$$)):$G__69224__$1$jscomp$inline_14460_sy$jscomp$inline_14459_v$jscomp$inline_14455$$}$G__69250$jscomp$inline_12801_initial$jscomp$21_p1$jscomp$76$$=$APP.$cljs$core$truth_$$($mod_QMARK_$jscomp$4$$)?$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(2*$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($G__69250$jscomp$inline_12801_initial$jscomp$21_p1$jscomp$76$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$14075_p2$jscomp$57_point$jscomp$65$$),
2*$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($G__69250$jscomp$inline_12801_initial$jscomp$21_p1$jscomp$76$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$14075_p2$jscomp$57_point$jscomp$65$$)):$G__69250$jscomp$inline_12801_initial$jscomp$21_p1$jscomp$76$$;$G__69250$jscomp$inline_12801_initial$jscomp$21_p1$jscomp$76$$=$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$2$($G__69250$jscomp$inline_12801_initial$jscomp$21_p1$jscomp$76$$,
$JSCompiler_temp$jscomp$14075_p2$jscomp$57_point$jscomp$65$$);$draw_rect_movev$jscomp$2_snap_pixel_QMARK_$jscomp$5$$=$APP.$cljs$core$truth_$$($draw_rect_movev$jscomp$2_snap_pixel_QMARK_$jscomp$5$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__69250$jscomp$inline_12801_initial$jscomp$21_p1$jscomp$76$$,$APP.$cljs$cst$290$width$$,$APP.$app$common$data$max$$,1),$APP.$cljs$cst$1522$height$$,$APP.$app$common$data$max$$,1):$G__69250$jscomp$inline_12801_initial$jscomp$21_p1$jscomp$76$$;
$height$jscomp$134_shape_rect$$=$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($x$jscomp$1202$$,$y$jscomp$435$$,$scalev$jscomp$5_width$jscomp$150$$,$height$jscomp$134_shape_rect$$);$scalev$jscomp$5_width$jscomp$150$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($draw_rect_movev$jscomp$2_snap_pixel_QMARK_$jscomp$5$$)/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($height$jscomp$134_shape_rect$$),
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($draw_rect_movev$jscomp$2_snap_pixel_QMARK_$jscomp$5$$)/$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($height$jscomp$134_shape_rect$$));$draw_rect_movev$jscomp$2_snap_pixel_QMARK_$jscomp$5$$=$APP.$app$common$geom$point$to_vec$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($height$jscomp$134_shape_rect$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($draw_rect_movev$jscomp$2_snap_pixel_QMARK_$jscomp$5$$));
return $APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__69235__$1_p__69233$$,$cljs$cst$4190$click_draw_QMARK_$$,!1),$APP.$app$common$types$modifiers$move$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$03$$($scalev$jscomp$5_width$jscomp$150$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1202$$,$y$jscomp$435$$)),$draw_rect_movev$jscomp$2_snap_pixel_QMARK_$jscomp$5$$))}return $map__69235__$1_p__69233$$};
$app$main$data$workspace$drawing$box$move_drawing$$=function($map__69271__$1_p__69267$$){$map__69271__$1_p__69267$$=$APP.$cljs$core$__destructure_map$$($map__69271__$1_p__69267$$);var $x$jscomp$1203$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69271__$1_p__69267$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$436$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69271__$1_p__69267$$,$APP.$cljs$cst$1511$y$$);return function($state$jscomp$666$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$666$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$cst$2198$object$$],null),$app$common$geom$shapes$absolute_move$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1203$$,$y$jscomp$436$$))}};
$app$main$data$workspace$drawing$box$handle_drawing$$=function($type$jscomp$495$$){typeof $app$main$data$workspace$drawing$box$handle_drawing_69279$$==="undefined"&&($app$main$data$workspace$drawing$box$handle_drawing_69279$$=function($type$jscomp$496$$,$meta69280$$){this.type=$type$jscomp$496$$;this.$meta69280$=$meta69280$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$drawing$box$handle_drawing_69279$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$box$handle_drawing_69279$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4191$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_box_SLASH_handle_drawing$$},$app$main$data$workspace$drawing$box$handle_drawing_69279$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69281$$,$meta69280__$1$$){return new $app$main$data$workspace$drawing$box$handle_drawing_69279$$(this.type,$meta69280__$1$$)},
$app$main$data$workspace$drawing$box$handle_drawing_69279$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69280$},$app$main$data$workspace$drawing$box$handle_drawing_69279$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$box$handle_drawing_69279$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2279_stopper$jscomp$21$$,$flex_layout_QMARK_$jscomp$2_state$jscomp$667$$,$grid_layout_QMARK_$jscomp$2_stream$jscomp$66$$){var $self__$jscomp$5345$$=
this;$_$jscomp$2279_stopper$jscomp$21$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($grid_layout_QMARK_$jscomp$2_stream$jscomp$66$$,null);var $layout$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($flex_layout_QMARK_$jscomp$2_state$jscomp$667$$,$APP.$cljs$cst$2209$workspace_layout$$),$zoom$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($flex_layout_QMARK_$jscomp$2_state$jscomp$667$$,
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2196$zoom$$,1),$snap_pixel_QMARK_$jscomp$7$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$13$$,$APP.$cljs$cst$2210$snap_pixel_grid$$),$initial$jscomp$23$$=function(){var $G__69291$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);return $snap_pixel_QMARK_$jscomp$7$$?$app$common$geom$point$round_step$$($G__69291$$,1):$G__69291$$}(),$page_id$jscomp$197$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($flex_layout_QMARK_$jscomp$2_state$jscomp$667$$),
$objects$jscomp$594$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($flex_layout_QMARK_$jscomp$2_state$jscomp$667$$,$page_id$jscomp$197$$),$focus$jscomp$14$$=$APP.$cljs$cst$2226$workspace_focus_selected$$.$cljs$core$IFn$_invoke$arity$1$($flex_layout_QMARK_$jscomp$2_state$jscomp$667$$),$fid$jscomp$1$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$common$types$container$get_first_valid_parent$$($objects$jscomp$594$$,$APP.$app$common$types$shape_tree$top_nested_frame$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$594$$,
$initial$jscomp$23$$,null,!1)));$flex_layout_QMARK_$jscomp$2_state$jscomp$667$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$594$$,$fid$jscomp$1$$);$grid_layout_QMARK_$jscomp$2_stream$jscomp$66$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$594$$,$fid$jscomp$1$$);var $drop_index$jscomp$7$$=$APP.$cljs$core$truth_$$($flex_layout_QMARK_$jscomp$2_state$jscomp$667$$)?$app$common$geom$shapes$flex_layout$drop_area$get_drop_index$$($fid$jscomp$1$$,
$objects$jscomp$594$$,$initial$jscomp$23$$):null,$drop_cell$jscomp$3$$=$APP.$cljs$core$truth_$$($grid_layout_QMARK_$jscomp$2_stream$jscomp$66$$)?$app$common$geom$shapes$grid_layout$positions$get_drop_cell$$($fid$jscomp$1$$,$objects$jscomp$594$$,$initial$jscomp$23$$):null,$shape$jscomp$692$$=function(){var $G__69295_G__69296$jscomp$inline_7130$$=$APP.$app$common$types$shape$setup_shape$$(new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$139$type$$,$self__$jscomp$5345$$.type,$APP.$cljs$cst$1510$x$$,
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($initial$jscomp$23$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($initial$jscomp$23$$),$APP.$cljs$cst$1607$frame_id$$,$fid$jscomp$1$$,$APP.$cljs$cst$1619$parent_id$$,$fid$jscomp$1$$,$cljs$cst$4189$initialized_QMARK_$$,!0,$cljs$cst$4190$click_draw_QMARK_$$,!0,$APP.$cljs$cst$1875$hide_in_viewer$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5345$$.type,$APP.$cljs$cst$1606$frame$$)&&
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($fid$jscomp$1$$,$APP.$app$common$uuid$zero$$)],null));$G__69295_G__69296$jscomp$inline_7130$$=$drop_index$jscomp$7$$!=null?$APP.$cljs$core$with_meta$$($G__69295_G__69296$jscomp$inline_7130$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1795$index$$,$drop_index$jscomp$7$$],null)):$G__69295_G__69296$jscomp$inline_7130$$;return $drop_cell$jscomp$3$$!=null?$APP.$cljs$core$with_meta$$($G__69295_G__69296$jscomp$inline_7130$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3525$cell$$,$drop_cell$jscomp$3$$],null)):$G__69295_G__69296$jscomp$inline_7130$$}();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)(function($p1__69273_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__69273_SHARP_$$,$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2198$object$$,$shape$jscomp$692$$)}),$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$map$$($app$main$data$workspace$drawing$box$move_drawing$$,
$APP.$app$main$snap$closest_snap_point$$($page_id$jscomp$197$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$692$$],null),$objects$jscomp$594$$,$layout$jscomp$13$$,$zoom$jscomp$24$$,$focus$jscomp$14$$,$initial$jscomp$23$$)),$APP.$beicon$v2$core$map$$(function($p__69297$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69297$$,0,null);var $shift_QMARK_$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69297$$,
1,null),$mod_QMARK_$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69297$$,2,null),$point$jscomp$67$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69297$$,3,null);return function($p1__69278_SHARP_$$){var $point$jscomp$inline_12805$$=$snap_pixel_QMARK_$jscomp$7$$?$app$common$geom$point$round_step$$($point$jscomp$67$$,1):$point$jscomp$67$$;return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__69278_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$cst$2198$object$$],null),$app$main$data$workspace$drawing$box$resize_shape$$,$initial$jscomp$23$$,$point$jscomp$inline_12805$$,$shift_QMARK_$jscomp$12$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$mod_QMARK_$jscomp$6$$,$snap_pixel_QMARK_$jscomp$7$$]))}},$APP.$beicon$v2$core$switch_map$$(function($p__69303$$){var $point$jscomp$68$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69303$$,
0,null);return $APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$util$array$conj$$,$p__69303$$),$APP.$app$main$snap$closest_snap_point$$($page_id$jscomp$197$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$692$$],null),$objects$jscomp$594$$,$layout$jscomp$13$$,$zoom$jscomp$24$$,$focus$jscomp$14$$,$point$jscomp$68$$))},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$sub$jscomp$inline_5572$$,
$APP.$sub$jscomp$inline_5575$$,$APP.$beicon$v2$core$take_until$$($_$jscomp$2279_stopper$jscomp$21$$,$APP.$beicon$v2$core$filter$$(function($p1__69274_SHARP_$$){return $APP.$app$common$geom$point$distance$$($p1__69274_SHARP_$$,$initial$jscomp$23$$)*$zoom$jscomp$24$$>10},$APP.$app$main$streams$mouse_position$$)))))),$APP.$beicon$v2$core$delay$$(100,(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$drawing$common$handle_finish_drawing$$())))});return new $app$main$data$workspace$drawing$box$handle_drawing_69279$$($type$jscomp$495$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$$jscomp$scope$m1503283874$3$simplifyDPStep$$=function($points$jscomp$79$$,$first$jscomp$14$$,$last$jscomp$3$$,$sqTolerance$jscomp$2$$,$simplified$jscomp$1$$){let $maxSqDist$$=$sqTolerance$jscomp$2$$,$index$jscomp$315$$;for(let $i$jscomp$507$$=$first$jscomp$14$$+1;$i$jscomp$507$$<$last$jscomp$3$$;$i$jscomp$507$$++){var $p$jscomp$inline_7132_sqDist$$=$points$jscomp$79$$[$i$jscomp$507$$],$p1$jscomp$inline_7133_y$jscomp$inline_7136$$=$points$jscomp$79$$[$first$jscomp$14$$],$p2$jscomp$inline_7134$$=$points$jscomp$79$$[$last$jscomp$3$$];
let $x$jscomp$inline_7135$$=$p1$jscomp$inline_7133_y$jscomp$inline_7136$$.x;$p1$jscomp$inline_7133_y$jscomp$inline_7136$$=$p1$jscomp$inline_7133_y$jscomp$inline_7136$$.y;let $dx$jscomp$inline_7137$$=$p2$jscomp$inline_7134$$.x-$x$jscomp$inline_7135$$,$dy$jscomp$inline_7138$$=$p2$jscomp$inline_7134$$.y-$p1$jscomp$inline_7133_y$jscomp$inline_7136$$;if($dx$jscomp$inline_7137$$!==0||$dy$jscomp$inline_7138$$!==0){const $t$jscomp$inline_7139$$=(($p$jscomp$inline_7132_sqDist$$.x-$x$jscomp$inline_7135$$)*
$dx$jscomp$inline_7137$$+($p$jscomp$inline_7132_sqDist$$.y-$p1$jscomp$inline_7133_y$jscomp$inline_7136$$)*$dy$jscomp$inline_7138$$)/($dx$jscomp$inline_7137$$*$dx$jscomp$inline_7137$$+$dy$jscomp$inline_7138$$*$dy$jscomp$inline_7138$$);$t$jscomp$inline_7139$$>1?($x$jscomp$inline_7135$$=$p2$jscomp$inline_7134$$.x,$p1$jscomp$inline_7133_y$jscomp$inline_7136$$=$p2$jscomp$inline_7134$$.y):$t$jscomp$inline_7139$$>0&&($x$jscomp$inline_7135$$+=$dx$jscomp$inline_7137$$*$t$jscomp$inline_7139$$,$p1$jscomp$inline_7133_y$jscomp$inline_7136$$+=
$dy$jscomp$inline_7138$$*$t$jscomp$inline_7139$$)}$dx$jscomp$inline_7137$$=$p$jscomp$inline_7132_sqDist$$.x-$x$jscomp$inline_7135$$;$dy$jscomp$inline_7138$$=$p$jscomp$inline_7132_sqDist$$.y-$p1$jscomp$inline_7133_y$jscomp$inline_7136$$;$p$jscomp$inline_7132_sqDist$$=$dx$jscomp$inline_7137$$*$dx$jscomp$inline_7137$$+$dy$jscomp$inline_7138$$*$dy$jscomp$inline_7138$$;$p$jscomp$inline_7132_sqDist$$>$maxSqDist$$&&($index$jscomp$315$$=$i$jscomp$507$$,$maxSqDist$$=$p$jscomp$inline_7132_sqDist$$)}$maxSqDist$$>
$sqTolerance$jscomp$2$$&&($index$jscomp$315$$-$first$jscomp$14$$>1&&$$jscomp$scope$m1503283874$3$simplifyDPStep$$($points$jscomp$79$$,$first$jscomp$14$$,$index$jscomp$315$$,$sqTolerance$jscomp$2$$,$simplified$jscomp$1$$),$simplified$jscomp$1$$.push($points$jscomp$79$$[$index$jscomp$315$$]),$last$jscomp$3$$-$index$jscomp$315$$>1&&$$jscomp$scope$m1503283874$3$simplifyDPStep$$($points$jscomp$79$$,$index$jscomp$315$$,$last$jscomp$3$$,$sqTolerance$jscomp$2$$,$simplified$jscomp$1$$))};
$app$main$data$workspace$drawing$curve$setup_frame$$=function(){typeof $app$main$data$workspace$drawing$curve$setup_frame_69329$$==="undefined"&&($app$main$data$workspace$drawing$curve$setup_frame_69329$$=function($meta69330$$){this.$meta69330$=$meta69330$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$drawing$curve$setup_frame_69329$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$curve$setup_frame_69329$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4192$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_setup_frame$$},$app$main$data$workspace$drawing$curve$setup_frame_69329$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69331$$,$meta69330__$1$$){return new $app$main$data$workspace$drawing$curve$setup_frame_69329$$($meta69330__$1$$)},$app$main$data$workspace$drawing$curve$setup_frame_69329$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69330$},$app$main$data$workspace$drawing$curve$setup_frame_69329$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$curve$setup_frame_69329$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2280_objects$jscomp$595$$,$state$jscomp$668$$){$_$jscomp$2280_objects$jscomp$595$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$668$$);var $content$jscomp$194_position$jscomp$119$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$668$$,
$APP.$cljs$cst$2189$workspace_drawing$$),$APP.$cljs$cst$2198$object$$),$APP.$cljs$cst$1637$content$$);$content$jscomp$194_position$jscomp$119$$=$APP.$app$common$types$path$get_handler_point$$($content$jscomp$194_position$jscomp$119$$,0,null);var $frame_id$jscomp$97$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$common$types$container$get_first_valid_parent$$($_$jscomp$2280_objects$jscomp$595$$,$APP.$app$common$types$shape_tree$top_nested_frame$cljs$0core$0IFn$0_invoke$0arity$04$$($_$jscomp$2280_objects$jscomp$595$$,
$content$jscomp$194_position$jscomp$119$$,null,!1))),$flex_layout_QMARK_$jscomp$3$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2280_objects$jscomp$595$$,$frame_id$jscomp$97$$),$grid_layout_QMARK_$jscomp$3$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2280_objects$jscomp$595$$,$frame_id$jscomp$97$$),$drop_index$jscomp$8$$=$APP.$cljs$core$truth_$$($flex_layout_QMARK_$jscomp$3$$)?$app$common$geom$shapes$flex_layout$drop_area$get_drop_index$$($frame_id$jscomp$97$$,
$_$jscomp$2280_objects$jscomp$595$$,$content$jscomp$194_position$jscomp$119$$):null,$drop_cell$jscomp$4$$=$APP.$cljs$core$truth_$$($grid_layout_QMARK_$jscomp$3$$)?$app$common$geom$shapes$grid_layout$positions$get_drop_cell$$($frame_id$jscomp$97$$,$_$jscomp$2280_objects$jscomp$595$$,$content$jscomp$194_position$jscomp$119$$):null;return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$668$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$cst$2198$object$$],null),function($G__69343_G__69344$jscomp$inline_7146_object$jscomp$34$$){$G__69343_G__69344$jscomp$inline_7146_object$jscomp$34$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__69343_G__69344$jscomp$inline_7146_object$jscomp$34$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$97$$),$APP.$cljs$cst$1619$parent_id$$,$frame_id$jscomp$97$$);$G__69343_G__69344$jscomp$inline_7146_object$jscomp$34$$=
$drop_index$jscomp$8$$!=null?$APP.$cljs$core$with_meta$$($G__69343_G__69344$jscomp$inline_7146_object$jscomp$34$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1795$index$$,$drop_index$jscomp$8$$],null)):$G__69343_G__69344$jscomp$inline_7146_object$jscomp$34$$;return $drop_cell$jscomp$4$$!=null?$APP.$cljs$core$with_meta$$($G__69343_G__69344$jscomp$inline_7146_object$jscomp$34$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3525$cell$$,$drop_cell$jscomp$4$$],null)):
$G__69343_G__69344$jscomp$inline_7146_object$jscomp$34$$})});return new $app$main$data$workspace$drawing$curve$setup_frame_69329$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$drawing$curve$insert_point$$=function($point$jscomp$70$$){typeof $app$main$data$workspace$drawing$curve$insert_point_69345$$==="undefined"&&($app$main$data$workspace$drawing$curve$insert_point_69345$$=function($point$jscomp$71$$,$meta69346$$){this.point=$point$jscomp$71$$;this.$meta69346$=$meta69346$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$drawing$curve$insert_point_69345$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$curve$insert_point_69345$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4193$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_insert_point$$},$app$main$data$workspace$drawing$curve$insert_point_69345$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69347$$,$meta69346__$1$$){return new $app$main$data$workspace$drawing$curve$insert_point_69345$$(this.point,$meta69346__$1$$)},
$app$main$data$workspace$drawing$curve$insert_point_69345$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69346$},$app$main$data$workspace$drawing$curve$insert_point_69345$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$curve$insert_point_69345$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2281$$,$state$jscomp$669$$){var $self__$jscomp$5353$$=this;return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$669$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$cst$2198$object$$],null),function($object$jscomp$35$$){var $points$jscomp$83$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$4194$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_points$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$35$$),$self__$jscomp$5353$$.point),$content$jscomp$195$$=$app$common$types$path$points__GT_content$$($points$jscomp$83$$),
$selrect$jscomp$69$$=$APP.$app$common$types$path$calc_selrect$$($content$jscomp$195$$),$points_SINGLEQUOTE_$jscomp$1$$=$APP.$app$common$geom$rect$rect__GT_points$$($selrect$jscomp$69$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($object$jscomp$35$$,$cljs$cst$4194$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_points$$,
$points$jscomp$83$$),$APP.$cljs$cst$1637$content$$,$content$jscomp$195$$),$APP.$cljs$cst$1605$selrect$$,$selrect$jscomp$69$$),$APP.$cljs$cst$1604$points$$,$points_SINGLEQUOTE_$jscomp$1$$)})});return new $app$main$data$workspace$drawing$curve$insert_point_69345$$($point$jscomp$70$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$drawing$curve$finish_drawing$$=function(){typeof $app$main$data$workspace$drawing$curve$finish_drawing_69348$$==="undefined"&&($app$main$data$workspace$drawing$curve$finish_drawing_69348$$=function($meta69349$$){this.$meta69349$=$meta69349$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$drawing$curve$finish_drawing_69348$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$curve$finish_drawing_69348$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4195$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_finish_drawing$$},$app$main$data$workspace$drawing$curve$finish_drawing_69348$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69350$$,$meta69349__$1$$){return new $app$main$data$workspace$drawing$curve$finish_drawing_69348$$($meta69349__$1$$)},$app$main$data$workspace$drawing$curve$finish_drawing_69348$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69349$},$app$main$data$workspace$drawing$curve$finish_drawing_69348$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$curve$finish_drawing_69348$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2282$$,$state$jscomp$670$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$670$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$cst$2198$object$$],null),function($G__69354_map__69352__$1_p__69351$$){$G__69354_map__69352__$1_p__69351$$=
$APP.$cljs$core$__destructure_map$$($G__69354_map__69352__$1_p__69351$$);var $JSCompiler_temp_const$jscomp$10893_content$jscomp$196_points$jscomp$84_points__$1$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__69354_map__69352__$1_p__69351$$,$cljs$cst$4194$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_points$$),$points$jscomp$inline_12810_points$jscomp$inline_14462_points__$1$jscomp$inline_7150_points__$2$$=$APP.$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp_const$jscomp$10893_content$jscomp$196_points$jscomp$84_points__$1$jscomp$8$$);
$JSCompiler_temp_const$jscomp$10893_content$jscomp$196_points$jscomp$84_points__$1$jscomp$8$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$;var $JSCompiler_temp_const$jscomp$10892_selrect$jscomp$70$$=$APP.$cljs$core$PersistentVector$EMPTY$$;if(!($points$jscomp$inline_12810_points$jscomp$inline_14462_points__$1$jscomp$inline_7150_points__$2$$.length<=2)){let $last$jscomp$inline_14464$$=$points$jscomp$inline_12810_points$jscomp$inline_14462_points__$1$jscomp$inline_7150_points__$2$$.length-
1,$simplified$jscomp$inline_14465$$=[$points$jscomp$inline_12810_points$jscomp$inline_14462_points__$1$jscomp$inline_7150_points__$2$$[0]];$$jscomp$scope$m1503283874$3$simplifyDPStep$$($points$jscomp$inline_12810_points$jscomp$inline_14462_points__$1$jscomp$inline_7150_points__$2$$,0,$last$jscomp$inline_14464$$,.09,$simplified$jscomp$inline_14465$$);$simplified$jscomp$inline_14465$$.push($points$jscomp$inline_12810_points$jscomp$inline_14462_points__$1$jscomp$inline_7150_points__$2$$[$last$jscomp$inline_14464$$]);
$points$jscomp$inline_12810_points$jscomp$inline_14462_points__$1$jscomp$inline_7150_points__$2$$=$simplified$jscomp$inline_14465$$}$JSCompiler_temp_const$jscomp$10893_content$jscomp$196_points$jscomp$84_points__$1$jscomp$8$$=$JSCompiler_temp_const$jscomp$10893_content$jscomp$196_points$jscomp$84_points__$1$jscomp$8$$.call($APP.$cljs$core$into$$,$JSCompiler_temp_const$jscomp$10892_selrect$jscomp$70$$,$points$jscomp$inline_12810_points$jscomp$inline_14462_points__$1$jscomp$inline_7150_points__$2$$);
$JSCompiler_temp_const$jscomp$10893_content$jscomp$196_points$jscomp$84_points__$1$jscomp$8$$=$app$common$types$path$points__GT_content$$($JSCompiler_temp_const$jscomp$10893_content$jscomp$196_points$jscomp$84_points__$1$jscomp$8$$);$JSCompiler_temp_const$jscomp$10892_selrect$jscomp$70$$=$APP.$app$common$types$path$calc_selrect$$($JSCompiler_temp_const$jscomp$10893_content$jscomp$196_points$jscomp$84_points__$1$jscomp$8$$);$points$jscomp$inline_12810_points$jscomp$inline_14462_points__$1$jscomp$inline_7150_points__$2$$=
$APP.$app$common$geom$rect$rect__GT_points$$($JSCompiler_temp_const$jscomp$10892_selrect$jscomp$70$$);$G__69354_map__69352__$1_p__69351$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__69354_map__69352__$1_p__69351$$,$cljs$cst$4194$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_points$$),$APP.$cljs$cst$1637$content$$,
$JSCompiler_temp_const$jscomp$10893_content$jscomp$196_points$jscomp$84_points__$1$jscomp$8$$),$APP.$cljs$cst$1605$selrect$$,$JSCompiler_temp_const$jscomp$10892_selrect$jscomp$70$$),$APP.$cljs$cst$1604$points$$,$points$jscomp$inline_12810_points$jscomp$inline_14462_points__$1$jscomp$inline_7150_points__$2$$);return $APP.$cljs$core$empty_QMARK_$$($points$jscomp$inline_12810_points$jscomp$inline_14462_points__$1$jscomp$inline_7150_points__$2$$)||$JSCompiler_temp_const$jscomp$10892_selrect$jscomp$70$$==
null||$APP.$cljs$core$count$$($JSCompiler_temp_const$jscomp$10893_content$jscomp$196_points$jscomp$84_points__$1$jscomp$8$$)<=1?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__69354_map__69352__$1_p__69351$$,$cljs$cst$4189$initialized_QMARK_$$,!1):$G__69354_map__69352__$1_p__69351$$})});return new $app$main$data$workspace$drawing$curve$finish_drawing_69348$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$drawing$curve$handle_drawing$$=function(){typeof $app$main$data$workspace$drawing$curve$handle_drawing_69359$$==="undefined"&&($app$main$data$workspace$drawing$curve$handle_drawing_69359$$=function($meta69360$$){this.$meta69360$=$meta69360$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$drawing$curve$handle_drawing_69359$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$curve$handle_drawing_69359$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4196$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_handle_drawing$$},$app$main$data$workspace$drawing$curve$handle_drawing_69359$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69361$$,$meta69360__$1$$){return new $app$main$data$workspace$drawing$curve$handle_drawing_69359$$($meta69360__$1$$)},$app$main$data$workspace$drawing$curve$handle_drawing_69359$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69360$},$app$main$data$workspace$drawing$curve$handle_drawing_69359$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$curve$handle_drawing_69359$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2283_stopper$jscomp$22$$,$___$1$jscomp$1516_mouse$$,$stream$jscomp$67$$){$_$jscomp$2283_stopper$jscomp$22$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stream$jscomp$67$$,null);$___$1$jscomp$1516_mouse$$=$beicon$v2$core$sample$$(10,$APP.$app$main$streams$mouse_position$$);var $shape$jscomp$694$$=$APP.$app$common$types$shape$setup_shape$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$296$path$$,$cljs$cst$4189$initialized_QMARK_$$,!0,$APP.$cljs$cst$1607$frame_id$$,$APP.$app$common$uuid$zero$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$app$common$uuid$zero$$,$cljs$cst$4194$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_points$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null));return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)(function($p1__69358_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__69358_SHARP_$$,
$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2198$object$$,$shape$jscomp$694$$)}),$APP.$beicon$v2$core$take_until$$($_$jscomp$2283_stopper$jscomp$22$$,$APP.$beicon$v2$core$map$$($app$main$data$workspace$drawing$curve$insert_point$$,$___$1$jscomp$1516_mouse$$)),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$drawing$curve$setup_frame$$(),$app$main$data$workspace$drawing$curve$finish_drawing$$(),$app$main$data$workspace$drawing$common$handle_finish_drawing$$()))});
return new $app$main$data$workspace$drawing$curve$handle_drawing_69359$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$changes$generate_path_changes$$=function($changes$jscomp$229_it$jscomp$207$$,$objects$jscomp$596_objects__$1$jscomp$24$$,$page_id$jscomp$198$$,$shape$jscomp$695_shape_id$jscomp$111$$,$old_content$jscomp$1$$,$new_content$jscomp$7$$){$shape$jscomp$695_shape_id$jscomp$111$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$695_shape_id$jscomp$111$$);$objects$jscomp$596_objects__$1$jscomp$24$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$596_objects__$1$jscomp$24$$,
$shape$jscomp$695_shape_id$jscomp$111$$,function($shape__$1$jscomp$48$$){return $app$common$types$path$update_geometry$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$48$$,$APP.$cljs$cst$1637$content$$,$old_content$jscomp$1$$))});$changes$jscomp$229_it$jscomp$207$$=$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$($changes$jscomp$229_it$jscomp$207$$,
$page_id$jscomp$198$$),$objects$jscomp$596_objects__$1$jscomp$24$$);var $new_content__$1$$=$APP.$app$common$types$path$impl$path_data$$($new_content$jscomp$7$$);return $shape$jscomp$695_shape_id$jscomp$111$$==null?$changes$jscomp$229_it$jscomp$207$$:$APP.$cljs$core$empty_QMARK_$$($new_content__$1$$)?$APP.$app$common$files$changes_builder$resize_parents$$($app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($changes$jscomp$229_it$jscomp$207$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$695_shape_id$jscomp$111$$],null)),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$695_shape_id$jscomp$111$$],null)):$APP.$app$common$files$changes_builder$resize_parents$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$229_it$jscomp$207$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape$jscomp$695_shape_id$jscomp$111$$],null),function($shape__$1$jscomp$49$$){return $app$common$types$path$update_geometry$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$49$$,$APP.$cljs$cst$1637$content$$,$new_content__$1$$))}),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$695_shape_id$jscomp$111$$],null))};
$APP.$app$main$data$workspace$path$changes$save_path_content$cljs$0core$0IFn$0_invoke$0arity$01$$=function($p__69420$$){var $map__69421__$1$$=$APP.$cljs$core$__destructure_map$$($p__69420$$),$preserve_move_to$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__69421__$1$$,$APP.$cljs$cst$4197$preserve_move_to$$,!1);typeof $app$main$data$workspace$path$changes$save_path_content_69422$$==="undefined"&&($app$main$data$workspace$path$changes$save_path_content_69422$$=function($p__69420$jscomp$1$$,
$map__69421$jscomp$1$$,$preserve_move_to$jscomp$1$$,$meta69423$$){this.$p__69420$=$p__69420$jscomp$1$$;this.$map__69421$=$map__69421$jscomp$1$$;this.$preserve_move_to$=$preserve_move_to$jscomp$1$$;this.$meta69423$=$meta69423$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$changes$save_path_content_69422$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$changes$save_path_content_69422$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4198$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_changes_SLASH_save_path_content$$},$app$main$data$workspace$path$changes$save_path_content_69422$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69424$$,$meta69423__$1$$){return new $app$main$data$workspace$path$changes$save_path_content_69422$$(this.$p__69420$,this.$map__69421$,this.$preserve_move_to$,$meta69423__$1$$)},$app$main$data$workspace$path$changes$save_path_content_69422$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69423$},$app$main$data$workspace$path$changes$save_path_content_69422$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$changes$save_path_content_69422$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($JSCompiler_temp$jscomp$10774__$jscomp$2284_content$jscomp$197_data$jscomp$inline_12814$$,$state$jscomp$671$$){$JSCompiler_temp$jscomp$10774__$jscomp$2284_content$jscomp$197_data$jscomp$inline_12814$$=
$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$671$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]));$APP.$cljs$core$not$$(this.$preserve_move_to$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($JSCompiler_temp$jscomp$10774__$jscomp$2284_content$jscomp$197_data$jscomp$inline_12814$$)),$APP.$cljs$cst$1813$move_to$$)?
($JSCompiler_temp$jscomp$10774__$jscomp$2284_content$jscomp$197_data$jscomp$inline_12814$$=$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($JSCompiler_temp$jscomp$10774__$jscomp$2284_content$jscomp$197_data$jscomp$inline_12814$$)-1,$JSCompiler_temp$jscomp$10774__$jscomp$2284_content$jscomp$197_data$jscomp$inline_12814$$),$JSCompiler_temp$jscomp$10774__$jscomp$2284_content$jscomp$197_data$jscomp$inline_12814$$=$APP.$app$common$types$path$impl$path_data$$($JSCompiler_temp$jscomp$10774__$jscomp$2284_content$jscomp$197_data$jscomp$inline_12814$$)):
$JSCompiler_temp$jscomp$10774__$jscomp$2284_content$jscomp$197_data$jscomp$inline_12814$$=$APP.$app$common$types$path$impl$path_data$$($JSCompiler_temp$jscomp$10774__$jscomp$2284_content$jscomp$197_data$jscomp$inline_12814$$);return $APP.$app$main$data$workspace$path$state$set_content$$($state$jscomp$671$$,$JSCompiler_temp$jscomp$10774__$jscomp$2284_content$jscomp$197_data$jscomp$inline_12814$$)},$app$main$data$workspace$path$changes$save_path_content_69422$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$changes$save_path_content_69422$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$230_it$jscomp$208_page_id$jscomp$199$$,$objects$jscomp$597_state$jscomp$672$$){$changes$jscomp$230_it$jscomp$208_page_id$jscomp$199$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$597_state$jscomp$672$$);var $local$jscomp$6_temp__5825__auto____$1$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$597_state$jscomp$672$$,
$APP.$cljs$cst$1920$workspace_local$$),$id$jscomp$654_new_content$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$6_temp__5825__auto____$1$jscomp$11$$,$APP.$cljs$cst$2199$edition$$);$objects$jscomp$597_state$jscomp$672$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$597_state$jscomp$672$$,$changes$jscomp$230_it$jscomp$208_page_id$jscomp$199$$);var $temp__5825__auto__$jscomp$217$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$597_state$jscomp$672$$,
$id$jscomp$654_new_content$jscomp$8$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$217$$)&&($local$jscomp$6_temp__5825__auto____$1$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$6_temp__5825__auto____$1$jscomp$11$$,$APP.$cljs$cst$1923$edit_path$$),$id$jscomp$654_new_content$jscomp$8$$),$APP.$cljs$cst$4199$old_content$$),$APP.$cljs$core$truth_$$($local$jscomp$6_temp__5825__auto____$1$jscomp$11$$))?
($id$jscomp$654_new_content$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5825__auto__$jscomp$217$$,$APP.$cljs$cst$1637$content$$),$changes$jscomp$230_it$jscomp$208_page_id$jscomp$199$$=$app$main$data$workspace$path$changes$generate_path_changes$$(this,$objects$jscomp$597_state$jscomp$672$$,$changes$jscomp$230_it$jscomp$208_page_id$jscomp$199$$,$temp__5825__auto__$jscomp$217$$,$local$jscomp$6_temp__5825__auto____$1$jscomp$11$$,$id$jscomp$654_new_content$jscomp$8$$),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$230_it$jscomp$208_page_id$jscomp$199$$))):
null});return new $app$main$data$workspace$path$changes$save_path_content_69422$$($p__69420$$,$map__69421__$1$$,$preserve_move_to$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$helpers$append_node$$=function($shape$jscomp$697$$,$position$jscomp$120_segment$jscomp$42$$,$prev_point$jscomp$7$$,$prev_handler$jscomp$2$$){var $content$jscomp$inline_12816_content__$1$jscomp$inline_12820$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$697$$);$content$jscomp$inline_12816_content__$1$jscomp$inline_12820$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$inline_12816_content__$1$jscomp$inline_12820$$);$position$jscomp$120_segment$jscomp$42$$=
$app$common$types$path$segment$next_node$$($content$jscomp$inline_12816_content__$1$jscomp$inline_12820$$,$position$jscomp$120_segment$jscomp$42$$,$prev_point$jscomp$7$$,$prev_handler$jscomp$2$$);return $app$common$types$path$update_geometry$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$697$$,$APP.$cljs$cst$1637$content$$,$app$common$types$path$append_segment$$,$position$jscomp$120_segment$jscomp$42$$))};
$APP.$app$main$data$workspace$path$helpers$move_handler_modifiers$$=function($content$jscomp$198_ocx$$,$G__69553_G__69553__$1_index$jscomp$316$$,$opposite$jscomp$1_prefix$jscomp$48$$,$JSCompiler_inline_result$jscomp$1259_match_distance_QMARK_$jscomp$1$$,$match_angle_QMARK_$jscomp$1$$,$and__5023__auto__$jscomp$inline_7156_and__5023__auto____$1$jscomp$inline_7157_dx$jscomp$21$$,$dy$jscomp$21$$){var $op_idx_vec__69541$$=$app$common$types$path$helpers$prefix__GT_coords$$($opposite$jscomp$1_prefix$jscomp$48$$),
$cx$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($op_idx_vec__69541$$,0,null),$cy$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($op_idx_vec__69541$$,1,null),$content$jscomp$inline_12829_node$jscomp$330_vec__69544$$=$APP.$app$common$types$path$opposite_index$$($content$jscomp$198_ocx$$,$G__69553_G__69553__$1_index$jscomp$316$$,$opposite$jscomp$1_prefix$jscomp$48$$);$op_idx_vec__69541$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$inline_12829_node$jscomp$330_vec__69544$$,
0,null);var $ocy_op_prefix_vec__69547$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$inline_12829_node$jscomp$330_vec__69544$$,1,null);$content$jscomp$inline_12829_node$jscomp$330_vec__69544$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$198_ocx$$);$content$jscomp$inline_12829_node$jscomp$330_vec__69544$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($opposite$jscomp$1_prefix$jscomp$48$$,$APP.$cljs$cst$1821$c1$$)?$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$inline_12829_node$jscomp$330_vec__69544$$,
$G__69553_G__69553__$1_index$jscomp$316$$-1)):$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$inline_12829_node$jscomp$330_vec__69544$$,$G__69553_G__69553__$1_index$jscomp$316$$));var $handler$jscomp$37_hnv$$=$APP.$app$common$types$path$get_handler_point$$($content$jscomp$198_ocx$$,$G__69553_G__69553__$1_index$jscomp$316$$,$opposite$jscomp$1_prefix$jscomp$48$$);$opposite$jscomp$1_prefix$jscomp$48$$=
$APP.$app$common$types$path$get_handler_point$$($content$jscomp$198_ocx$$,$op_idx_vec__69541$$,$ocy_op_prefix_vec__69547$$);$ocy_op_prefix_vec__69547$$=$app$common$types$path$helpers$prefix__GT_coords$$($ocy_op_prefix_vec__69547$$);$content$jscomp$198_ocx$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ocy_op_prefix_vec__69547$$,0,null);$ocy_op_prefix_vec__69547$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ocy_op_prefix_vec__69547$$,1,null);if($handler$jscomp$37_hnv$$!=
null&&$opposite$jscomp$1_prefix$jscomp$48$$!=null){var $angle_handlers$jscomp$inline_14474_match_distance_QMARK___$1$jscomp$inline_14476_new_opposite$jscomp$inline_14483_odx$$=$APP.$app$common$math$abs$$($APP.$app$common$geom$point$angle_with_other$$($APP.$app$common$geom$point$subtract$$($handler$jscomp$37_hnv$$,$content$jscomp$inline_12829_node$jscomp$330_vec__69544$$),$APP.$app$common$geom$point$subtract$$($opposite$jscomp$1_prefix$jscomp$48$$,$content$jscomp$inline_12829_node$jscomp$330_vec__69544$$)));
var $G__69539__$1$jscomp$inline_14484_match_angle_QMARK___$1$jscomp$inline_14475_ody_vec__69550$$=$APP.$cljs$core$truth_$$($match_angle_QMARK_$jscomp$1$$)?$APP.$app$common$math$abs$$(180-$angle_handlers$jscomp$inline_14474_match_distance_QMARK___$1$jscomp$inline_14476_new_opposite$jscomp$inline_14483_odx$$)<=.1:$match_angle_QMARK_$jscomp$1$$;$angle_handlers$jscomp$inline_14474_match_distance_QMARK___$1$jscomp$inline_14476_new_opposite$jscomp$inline_14483_odx$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1259_match_distance_QMARK_$jscomp$1$$)?
$APP.$app$common$math$almost_zero_QMARK_$$($APP.$app$common$geom$point$distance$$($content$jscomp$inline_12829_node$jscomp$330_vec__69544$$,$handler$jscomp$37_hnv$$)-$APP.$app$common$geom$point$distance$$($content$jscomp$inline_12829_node$jscomp$330_vec__69544$$,$opposite$jscomp$1_prefix$jscomp$48$$)):$JSCompiler_inline_result$jscomp$1259_match_distance_QMARK_$jscomp$1$$;var $distance_scale$jscomp$inline_14482_new_handler$jscomp$inline_14477$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($handler$jscomp$37_hnv$$,
$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$_PLUS_$$,$and__5023__auto__$jscomp$inline_7156_and__5023__auto____$1$jscomp$inline_7157_dx$jscomp$21$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_PLUS_$$,$dy$jscomp$21$$),$delta_sign$jscomp$inline_14481_v1$jscomp$inline_14478$$=$APP.$app$common$geom$point$subtract$$($handler$jscomp$37_hnv$$,$content$jscomp$inline_12829_node$jscomp$330_vec__69544$$),$v2$jscomp$inline_14479$$=$APP.$app$common$geom$point$subtract$$($distance_scale$jscomp$inline_14482_new_handler$jscomp$inline_14477$$,
$content$jscomp$inline_12829_node$jscomp$330_vec__69544$$),$delta_angle$jscomp$inline_14480$$=$APP.$app$common$geom$point$angle_with_other$$($delta_sign$jscomp$inline_14481_v1$jscomp$inline_14478$$,$v2$jscomp$inline_14479$$);$delta_sign$jscomp$inline_14481_v1$jscomp$inline_14478$$=$APP.$app$common$geom$point$angle_sign$$($delta_sign$jscomp$inline_14481_v1$jscomp$inline_14478$$,$v2$jscomp$inline_14479$$);$distance_scale$jscomp$inline_14482_new_handler$jscomp$inline_14477$$=$APP.$app$common$geom$point$distance$$($content$jscomp$inline_12829_node$jscomp$330_vec__69544$$,
$handler$jscomp$37_hnv$$)/$APP.$app$common$geom$point$distance$$($content$jscomp$inline_12829_node$jscomp$330_vec__69544$$,$distance_scale$jscomp$inline_14482_new_handler$jscomp$inline_14477$$);$G__69539__$1$jscomp$inline_14484_match_angle_QMARK___$1$jscomp$inline_14475_ody_vec__69550$$=$APP.$cljs$core$truth_$$($G__69539__$1$jscomp$inline_14484_match_angle_QMARK___$1$jscomp$inline_14475_ody_vec__69550$$)?$APP.$app$common$geom$point$rotate$$($opposite$jscomp$1_prefix$jscomp$48$$,$content$jscomp$inline_12829_node$jscomp$330_vec__69544$$,
$delta_sign$jscomp$inline_14481_v1$jscomp$inline_14478$$*$delta_angle$jscomp$inline_14480$$):$opposite$jscomp$1_prefix$jscomp$48$$;$angle_handlers$jscomp$inline_14474_match_distance_QMARK___$1$jscomp$inline_14476_new_opposite$jscomp$inline_14483_odx$$=$APP.$cljs$core$truth_$$($angle_handlers$jscomp$inline_14474_match_distance_QMARK___$1$jscomp$inline_14476_new_opposite$jscomp$inline_14483_odx$$)?$APP.$app$common$geom$point$add$$($G__69539__$1$jscomp$inline_14484_match_angle_QMARK___$1$jscomp$inline_14475_ody_vec__69550$$,
$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($G__69539__$1$jscomp$inline_14484_match_angle_QMARK___$1$jscomp$inline_14475_ody_vec__69550$$,$content$jscomp$inline_12829_node$jscomp$330_vec__69544$$)),$distance_scale$jscomp$inline_14482_new_handler$jscomp$inline_14477$$)):$G__69539__$1$jscomp$inline_14484_match_angle_QMARK___$1$jscomp$inline_14475_ody_vec__69550$$;$G__69539__$1$jscomp$inline_14484_match_angle_QMARK___$1$jscomp$inline_14475_ody_vec__69550$$=
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($angle_handlers$jscomp$inline_14474_match_distance_QMARK___$1$jscomp$inline_14476_new_opposite$jscomp$inline_14483_odx$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($opposite$jscomp$1_prefix$jscomp$48$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($angle_handlers$jscomp$inline_14474_match_distance_QMARK___$1$jscomp$inline_14476_new_opposite$jscomp$inline_14483_odx$$)-
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($opposite$jscomp$1_prefix$jscomp$48$$)],null)}else $G__69539__$1$jscomp$inline_14484_match_angle_QMARK___$1$jscomp$inline_14475_ody_vec__69550$$=null;$angle_handlers$jscomp$inline_14474_match_distance_QMARK___$1$jscomp$inline_14476_new_opposite$jscomp$inline_14483_odx$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__69539__$1$jscomp$inline_14484_match_angle_QMARK___$1$jscomp$inline_14475_ody_vec__69550$$,0,null);$G__69539__$1$jscomp$inline_14484_match_angle_QMARK___$1$jscomp$inline_14475_ody_vec__69550$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__69539__$1$jscomp$inline_14484_match_angle_QMARK___$1$jscomp$inline_14475_ody_vec__69550$$,1,null);$handler$jscomp$37_hnv$$=$handler$jscomp$37_hnv$$!=null?$APP.$app$common$geom$point$to_vec$$($content$jscomp$inline_12829_node$jscomp$330_vec__69544$$,$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($handler$jscomp$37_hnv$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$_PLUS_$$,$and__5023__auto__$jscomp$inline_7156_and__5023__auto____$1$jscomp$inline_7157_dx$jscomp$21$$),
$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_PLUS_$$,$dy$jscomp$21$$)):$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$inline_7156_and__5023__auto____$1$jscomp$inline_7157_dx$jscomp$21$$,$dy$jscomp$21$$);$G__69553_G__69553__$1_index$jscomp$316$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$G__69553_G__69553__$1_index$jscomp$316$$,$APP.$cljs$core$assoc$$,$cx$jscomp$17$$,$and__5023__auto__$jscomp$inline_7156_and__5023__auto____$1$jscomp$inline_7157_dx$jscomp$21$$,
$cy$jscomp$18$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$dy$jscomp$21$$]));$G__69553_G__69553__$1_index$jscomp$316$$=$op_idx_vec__69541$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($opposite$jscomp$1_prefix$jscomp$48$$,$content$jscomp$inline_12829_node$jscomp$330_vec__69544$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($G__69553_G__69553__$1_index$jscomp$316$$,$op_idx_vec__69541$$,$APP.$cljs$core$assoc$$,$content$jscomp$198_ocx$$,$angle_handlers$jscomp$inline_14474_match_distance_QMARK___$1$jscomp$inline_14476_new_opposite$jscomp$inline_14483_odx$$,
$ocy_op_prefix_vec__69547$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__69539__$1$jscomp$inline_14484_match_angle_QMARK___$1$jscomp$inline_14475_ody_vec__69550$$])):$G__69553_G__69553__$1_index$jscomp$316$$;$JSCompiler_inline_result$jscomp$1259_match_distance_QMARK_$jscomp$1$$=($and__5023__auto__$jscomp$inline_7156_and__5023__auto____$1$jscomp$inline_7157_dx$jscomp$21$$=$op_idx_vec__69541$$!=null)?($and__5023__auto__$jscomp$inline_7156_and__5023__auto____$1$jscomp$inline_7157_dx$jscomp$21$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($opposite$jscomp$1_prefix$jscomp$48$$,$content$jscomp$inline_12829_node$jscomp$330_vec__69544$$))?$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1259_match_distance_QMARK_$jscomp$1$$)?$match_angle_QMARK_$jscomp$1$$:$JSCompiler_inline_result$jscomp$1259_match_distance_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$inline_7156_and__5023__auto____$1$jscomp$inline_7157_dx$jscomp$21$$:$and__5023__auto__$jscomp$inline_7156_and__5023__auto____$1$jscomp$inline_7157_dx$jscomp$21$$;
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1259_match_distance_QMARK_$jscomp$1$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($G__69553_G__69553__$1_index$jscomp$316$$,$op_idx_vec__69541$$,$APP.$cljs$core$assoc$$,$content$jscomp$198_ocx$$,-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($handler$jscomp$37_hnv$$),$ocy_op_prefix_vec__69547$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($handler$jscomp$37_hnv$$)])):
$G__69553_G__69553__$1_index$jscomp$316$$};$app$main$data$workspace$path$streams$dragging_QMARK_$$=function($start$jscomp$227$$,$zoom$jscomp$25$$){return function($current$jscomp$48$$){return $APP.$app$common$geom$point$distance$$($start$jscomp$227$$,$current$jscomp$48$$)>=5/$zoom$jscomp$25$$}};
$APP.$app$main$data$workspace$path$streams$finish_edition_QMARK_$$=function($event$jscomp$98$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$potok$v2$core$type$$($event$jscomp$98$$),$cljs$cst$4200$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_clear_edition_mode$$)};
$APP.$app$main$data$workspace$path$streams$to_pixel_snap$$=function($position$jscomp$121$$){var $layout$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$2209$workspace_layout$$);return $APP.$cljs$core$contains_QMARK_$$($layout$jscomp$14$$,$APP.$cljs$cst$2210$snap_pixel_grid$$)&&$app$common$geom$point$point_QMARK_$$($position$jscomp$121$$)?$APP.$app$common$geom$point$pos__GT_Point$$($APP.$app$common$math$precision$$($position$jscomp$121$$?.x??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$121$$,$APP.$cljs$cst$1510$x$$),0),$APP.$app$common$math$precision$$($position$jscomp$121$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$121$$,$APP.$cljs$cst$1511$y$$),0)):$position$jscomp$121$$};
$APP.$app$main$data$workspace$path$streams$drag_stream$cljs$0core$0IFn$0_invoke$0arity$01$$=function($to_stream$$){return $APP.$app$main$data$workspace$path$streams$drag_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($to_stream$$,$APP.$beicon$v2$core$empty$$())};
$APP.$app$main$data$workspace$path$streams$drag_stream$cljs$0core$0IFn$0_invoke$0arity$02$$=function($to_stream$jscomp$1$$,$not_drag_stream$$){var $position_stream_zoom$jscomp$26$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2196$zoom$$],null),1),$start$jscomp$228$$=$APP.$app$main$data$workspace$path$streams$to_pixel_snap$$($APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$)),
$stopper$jscomp$23$$=$APP.$beicon$v2$core$merge$$($APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$store$stream$$,null),$APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$path$streams$finish_edition_QMARK_$$,$APP.$app$main$store$stream$$));$position_stream_zoom$jscomp$26$$=$APP.$beicon$v2$core$take_until$$($stopper$jscomp$23$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($app$main$data$workspace$path$streams$dragging_QMARK_$$($start$jscomp$228$$,
$position_stream_zoom$jscomp$26$$),$APP.$beicon$v2$core$map$$($APP.$app$main$data$workspace$path$streams$to_pixel_snap$$,$APP.$app$main$streams$mouse_position$$))));return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$merge_map$$(function($value$jscomp$594$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$594$$,$cljs$cst$4201$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_streams_SLASH_empty$$)?$not_drag_stream$$:$APP.$beicon$v2$core$empty$$()},$beicon$v2$core$if_empty$$($position_stream_zoom$jscomp$26$$)),
$APP.$beicon$v2$core$merge_map$$(function(){return $to_stream$jscomp$1$$},$position_stream_zoom$jscomp$26$$))};
$APP.$app$main$data$workspace$path$streams$snap_toggled_stream$$=function(){return $APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$673$$){var $id$jscomp$655$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$673$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$673$$,$APP.$cljs$cst$1920$workspace_local$$),
$APP.$cljs$cst$1923$edit_path$$),$id$jscomp$655$$),$APP.$cljs$cst$4202$snap_toggled$$)},$APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!0],null))};
$APP.$app$main$data$workspace$path$streams$position_stream$$=function($content_stream_ranges_stream_state$jscomp$674$$){var $d_pos$jscomp$2$$=10/$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($content_stream_ranges_stream_state$jscomp$674$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2196$zoom$$],null),1);$content_stream_ranges_stream_state$jscomp$674$$=$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__69630_SHARP_$$){return $APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($p1__69630_SHARP_$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]))},$APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!0],null));$content_stream_ranges_stream_state$jscomp$674$$=$APP.$beicon$v2$core$map$$($APP.$app$main$snap$create_ranges$$,$APP.$beicon$v2$core$map$$($APP.$app$common$types$path$get_points$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,$content_stream_ranges_stream_state$jscomp$674$$)));
return $APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$04$$(function($position$jscomp$126$$,$shift_QMARK_$jscomp$15$$,$alt_QMARK_$jscomp$9$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($position$jscomp$126$$,$APP.$cljs$cst$4203$shift_QMARK_$$,$shift_QMARK_$jscomp$15$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4204$alt_QMARK_$$,$alt_QMARK_$jscomp$9$$]))},$APP.$sub$jscomp$inline_5572$$,$APP.$sub$jscomp$inline_5575$$,
$APP.$beicon$v2$core$map$$(function($p__69633_snap_toggled$jscomp$2$$){var $position$jscomp$127$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69633_snap_toggled$jscomp$2$$,0,null),$ranges$jscomp$8_snap$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69633_snap_toggled$jscomp$2$$,1,null);$p__69633_snap_toggled$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69633_snap_toggled$jscomp$2$$,2,null);return $APP.$cljs$core$truth_$$($p__69633_snap_toggled$jscomp$2$$)?
($ranges$jscomp$8_snap$jscomp$2$$=$APP.$app$main$snap$get_snap_delta$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$position$jscomp$127$$],null),$ranges$jscomp$8_snap$jscomp$2$$,$d_pos$jscomp$2$$),$APP.$app$common$geom$point$add$$($position$jscomp$127$$,$ranges$jscomp$8_snap$jscomp$2$$)):$position$jscomp$127$$},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$03$$($content_stream_ranges_stream_state$jscomp$674$$,$APP.$app$main$data$workspace$path$streams$snap_toggled_stream$$(),
$APP.$beicon$v2$core$map$$($APP.$app$main$data$workspace$path$streams$to_pixel_snap$$,$APP.$app$main$streams$mouse_position$$))))};
$app$common$data$undo_stack$peek$$=function($index$jscomp$317_p__69600$$){var $items$jscomp$45_map__69601__$1$$=$APP.$cljs$core$__destructure_map$$($index$jscomp$317_p__69600$$);$index$jscomp$317_p__69600$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$45_map__69601__$1$$,$APP.$cljs$cst$1795$index$$);$items$jscomp$45_map__69601__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$45_map__69601__$1$$,$APP.$cljs$cst$1838$items$$);return $index$jscomp$317_p__69600$$>=
0&&$index$jscomp$317_p__69600$$<$APP.$cljs$core$count$$($items$jscomp$45_map__69601__$1$$)?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($items$jscomp$45_map__69601__$1$$,$index$jscomp$317_p__69600$$):null};
$app$common$data$undo_stack$append$$=function($items__$1$jscomp$5_map__69603__$1_p__69602$$,$value$jscomp$595$$){$items__$1$jscomp$5_map__69603__$1_p__69602$$=$APP.$cljs$core$__destructure_map$$($items__$1$jscomp$5_map__69603__$1_p__69602$$);var $index$jscomp$318$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($items__$1$jscomp$5_map__69603__$1_p__69602$$,$APP.$cljs$cst$1795$index$$),$items$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($items__$1$jscomp$5_map__69603__$1_p__69602$$,
$APP.$cljs$cst$1838$items$$);return $items__$1$jscomp$5_map__69603__$1_p__69602$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$595$$,$app$common$data$undo_stack$peek$$($items__$1$jscomp$5_map__69603__$1_p__69602$$))?($items__$1$jscomp$5_map__69603__$1_p__69602$$=function(){var $G__69607__$1_G__69607__$2$$=$index$jscomp$318$$>0?$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($items$jscomp$46$$,0,$index$jscomp$318$$+1):$items$jscomp$46$$;$G__69607__$1_G__69607__$2$$=
$index$jscomp$318$$+2>100?$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($G__69607__$1_G__69607__$2$$,1,$index$jscomp$318$$+1):$G__69607__$1_G__69607__$2$$;return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__69607__$1_G__69607__$2$$,$value$jscomp$595$$)}(),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1795$index$$,function(){var $y__5114__auto__$jscomp$64$$=$index$jscomp$318$$+1;return 99<$y__5114__auto__$jscomp$64$$?99:$y__5114__auto__$jscomp$64$$}(),
$APP.$cljs$cst$1838$items$$,$items__$1$jscomp$5_map__69603__$1_p__69602$$],null)):$items__$1$jscomp$5_map__69603__$1_p__69602$$};$app$common$data$undo_stack$undo$$=function($stack$jscomp$30$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($stack$jscomp$30$$,$APP.$cljs$cst$1795$index$$,function($p1__69621_SHARP__y__5111__auto__$jscomp$122$$){--$p1__69621_SHARP__y__5111__auto__$jscomp$122$$;return 0>$p1__69621_SHARP__y__5111__auto__$jscomp$122$$?0:$p1__69621_SHARP__y__5111__auto__$jscomp$122$$})};
$app$main$data$workspace$path$undo$load_entry$$=function($state$jscomp$676$$,$content$jscomp$199_p__69649$$){var $map__69650__$1_prev_handler$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($content$jscomp$199_p__69649$$);$content$jscomp$199_p__69649$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69650__$1_prev_handler$jscomp$3$$,$APP.$cljs$cst$1637$content$$);var $selrect$jscomp$71$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69650__$1_prev_handler$jscomp$3$$,$APP.$cljs$cst$1605$selrect$$),
$points$jscomp$87$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69650__$1_prev_handler$jscomp$3$$,$APP.$cljs$cst$1604$points$$),$preview$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69650__$1_prev_handler$jscomp$3$$,$APP.$cljs$cst$3556$preview$$),$last_point$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69650__$1_prev_handler$jscomp$3$$,$APP.$cljs$cst$3553$last_point$$);$map__69650__$1_prev_handler$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69650__$1_prev_handler$jscomp$3$$,
$APP.$cljs$cst$3554$prev_handler$$);var $id$jscomp$657$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$676$$),$old_content$jscomp$3$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$676$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]));return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$data$assoc_in_when$$($app$common$data$assoc_in_when$$($app$common$data$assoc_in_when$$($state$jscomp$676$$,
$app$main$data$workspace$path$state$get_path_location$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$676$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$])),$content$jscomp$199_p__69649$$),$app$main$data$workspace$path$state$get_path_location$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$676$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1605$selrect$$])),$selrect$jscomp$71$$),$app$main$data$workspace$path$state$get_path_location$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$676$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1604$points$$])),$points$jscomp$87$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$id$jscomp$657$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3556$preview$$,$preview$$,$APP.$cljs$cst$3553$last_point$$,$last_point$jscomp$1$$,$APP.$cljs$cst$3554$prev_handler$$,
$map__69650__$1_prev_handler$jscomp$3$$,$APP.$cljs$cst$4199$old_content$$,$old_content$jscomp$3$$]))};
$app$main$data$workspace$path$undo$undo_path$$=function(){typeof $app$main$data$workspace$path$undo$undo_path_69651$$==="undefined"&&($app$main$data$workspace$path$undo$undo_path_69651$$=function($meta69652$$){this.$meta69652$=$meta69652$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$undo$undo_path_69651$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$undo$undo_path_69651$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4206$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_undo_path$$},$app$main$data$workspace$path$undo$undo_path_69651$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69653$$,$meta69652__$1$$){return new $app$main$data$workspace$path$undo$undo_path_69651$$($meta69652__$1$$)},$app$main$data$workspace$path$undo$undo_path_69651$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69652$},$app$main$data$workspace$path$undo$undo_path_69651$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$undo$undo_path_69651$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2286_id$jscomp$658$$,$state$jscomp$677$$){$_$jscomp$2286_id$jscomp$658$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$677$$);var $undo_stack$$=$app$common$data$undo_stack$undo$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$677$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2286_id$jscomp$658$$,$cljs$cst$4207$undo_stack$$],null))),$entry$jscomp$57$$=$app$common$data$undo_stack$peek$$($undo_stack$$);return $entry$jscomp$57$$!=null?$app$common$data$assoc_in_when$$($app$main$data$workspace$path$undo$load_entry$$($state$jscomp$677$$,$entry$jscomp$57$$),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,
$_$jscomp$2286_id$jscomp$658$$,$cljs$cst$4207$undo_stack$$],null),$undo_stack$$):$state$jscomp$677$$},$app$main$data$workspace$path$undo$undo_path_69651$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$undo$undo_path_69651$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2287_id$jscomp$659$$,$state$jscomp$678_undo_stack$jscomp$1$$){$_$jscomp$2287_id$jscomp$659$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$678_undo_stack$jscomp$1$$);
$state$jscomp$678_undo_stack$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$678_undo_stack$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2287_id$jscomp$659$$,$cljs$cst$4207$undo_stack$$],null));return $APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$678_undo_stack$jscomp$1$$)>0?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$changes$save_path_content$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$4197$preserve_move_to$$,!0],null))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$changes$save_path_content$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4197$preserve_move_to$$,!0],null)),$APP.$app$main$data$workspace$path$common$finish_path$$(),$app$main$data$workspace$common$show_toolbar$$())});return new $app$main$data$workspace$path$undo$undo_path_69651$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$undo$redo_path$$=function(){typeof $app$main$data$workspace$path$undo$redo_path_69671$$==="undefined"&&($app$main$data$workspace$path$undo$redo_path_69671$$=function($meta69672$$){this.$meta69672$=$meta69672$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$undo$redo_path_69671$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$undo$redo_path_69671$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4208$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_redo_path$$},$app$main$data$workspace$path$undo$redo_path_69671$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69673$$,$meta69672__$1$$){return new $app$main$data$workspace$path$undo$redo_path_69671$$($meta69672__$1$$)},$app$main$data$workspace$path$undo$redo_path_69671$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69672$},$app$main$data$workspace$path$undo$redo_path_69671$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$undo$redo_path_69671$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2288_id$jscomp$660$$,$state$jscomp$679$$){$_$jscomp$2288_id$jscomp$660$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$679$$);var $map__69623__$1$jscomp$inline_7160_p__69622$jscomp$inline_7159_undo_stack$jscomp$2$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$679$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2288_id$jscomp$660$$,$cljs$cst$4207$undo_stack$$],null));$map__69623__$1$jscomp$inline_7160_p__69622$jscomp$inline_7159_undo_stack$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__69623__$1$jscomp$inline_7160_p__69622$jscomp$inline_7159_undo_stack$jscomp$2$$);var $entry$jscomp$58_index$jscomp$inline_7161$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69623__$1$jscomp$inline_7160_p__69622$jscomp$inline_7159_undo_stack$jscomp$2$$,
$APP.$cljs$cst$1795$index$$),$items$jscomp$inline_7162$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69623__$1$jscomp$inline_7160_p__69622$jscomp$inline_7159_undo_stack$jscomp$2$$,$APP.$cljs$cst$1838$items$$);$map__69623__$1$jscomp$inline_7160_p__69622$jscomp$inline_7159_undo_stack$jscomp$2$$=$entry$jscomp$58_index$jscomp$inline_7161$$<$APP.$cljs$core$count$$($items$jscomp$inline_7162$$)-1?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($map__69623__$1$jscomp$inline_7160_p__69622$jscomp$inline_7159_undo_stack$jscomp$2$$,
$APP.$cljs$cst$1795$index$$,$APP.$cljs$core$inc$$):$map__69623__$1$jscomp$inline_7160_p__69622$jscomp$inline_7159_undo_stack$jscomp$2$$;$entry$jscomp$58_index$jscomp$inline_7161$$=$app$common$data$undo_stack$peek$$($map__69623__$1$jscomp$inline_7160_p__69622$jscomp$inline_7159_undo_stack$jscomp$2$$);return $app$common$data$assoc_in_when$$($app$main$data$workspace$path$undo$load_entry$$($state$jscomp$679$$,$entry$jscomp$58_index$jscomp$inline_7161$$),new $APP.$cljs$core$PersistentVector$$(null,4,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2288_id$jscomp$660$$,$cljs$cst$4207$undo_stack$$],null),$map__69623__$1$jscomp$inline_7160_p__69622$jscomp$inline_7159_undo_stack$jscomp$2$$)},$app$main$data$workspace$path$undo$redo_path_69671$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$undo$redo_path_69671$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$changes$save_path_content$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$))});return new $app$main$data$workspace$path$undo$redo_path_69671$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$undo$merge_head$$=function(){typeof $app$main$data$workspace$path$undo$merge_head_69682$$==="undefined"&&($app$main$data$workspace$path$undo$merge_head_69682$$=function($meta69683$$){this.$meta69683$=$meta69683$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$undo$merge_head_69682$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$undo$merge_head_69682$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4209$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_merge_head$$},$app$main$data$workspace$path$undo$merge_head_69682$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69684$$,$meta69683__$1$$){return new $app$main$data$workspace$path$undo$merge_head_69682$$($meta69683__$1$$)},$app$main$data$workspace$path$undo$merge_head_69682$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69683$},$app$main$data$workspace$path$undo$merge_head_69682$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$undo$merge_head_69682$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2290_id$jscomp$661$$,$state$jscomp$680$$){$_$jscomp$2290_id$jscomp$661$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$680$$);var $map__69620__$1$jscomp$inline_7166_p__69619$jscomp$inline_7164_stack$jscomp$33$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$680$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2290_id$jscomp$661$$,$cljs$cst$4207$undo_stack$$],null)),$head$jscomp$21_stack__$1$jscomp$1$$=$app$common$data$undo_stack$peek$$($map__69620__$1$jscomp$inline_7166_p__69619$jscomp$inline_7164_stack$jscomp$33$$);$map__69620__$1$jscomp$inline_7166_p__69619$jscomp$inline_7164_stack$jscomp$33$$=$app$common$data$undo_stack$undo$$($map__69620__$1$jscomp$inline_7166_p__69619$jscomp$inline_7164_stack$jscomp$33$$);
$map__69620__$1$jscomp$inline_7166_p__69619$jscomp$inline_7164_stack$jscomp$33$$=$APP.$cljs$core$__destructure_map$$($map__69620__$1$jscomp$inline_7166_p__69619$jscomp$inline_7164_stack$jscomp$33$$);var $index$jscomp$inline_7167$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69620__$1$jscomp$inline_7166_p__69619$jscomp$inline_7164_stack$jscomp$33$$,$APP.$cljs$cst$1795$index$$);$head$jscomp$21_stack__$1$jscomp$1$$=$APP.$cljs$core$assoc_in$$($map__69620__$1$jscomp$inline_7166_p__69619$jscomp$inline_7164_stack$jscomp$33$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1838$items$$,$index$jscomp$inline_7167$$],null),$head$jscomp$21_stack__$1$jscomp$1$$);return $app$common$data$assoc_in_when$$($state$jscomp$680$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2290_id$jscomp$661$$,$cljs$cst$4207$undo_stack$$],null),$head$jscomp$21_stack__$1$jscomp$1$$)});
return new $app$main$data$workspace$path$undo$merge_head_69682$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$undo$add_undo_entry$$=function(){typeof $app$main$data$workspace$path$undo$add_undo_entry_69688$$==="undefined"&&($app$main$data$workspace$path$undo$add_undo_entry_69688$$=function($meta69689$$){this.$meta69689$=$meta69689$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$undo$add_undo_entry_69688$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$undo$add_undo_entry_69688$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4210$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_add_undo_entry$$},$app$main$data$workspace$path$undo$add_undo_entry_69688$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69690$$,$meta69689__$1$$){return new $app$main$data$workspace$path$undo$add_undo_entry_69688$$($meta69689__$1$$)},$app$main$data$workspace$path$undo$add_undo_entry_69688$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69689$},$app$main$data$workspace$path$undo$add_undo_entry_69688$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$undo$add_undo_entry_69688$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2291_id$jscomp$662$$,$state$jscomp$681$$){$_$jscomp$2291_id$jscomp$662$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$681$$);var $entry$jscomp$59_id$jscomp$inline_7170$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$681$$);var $shape$jscomp$inline_7171$$=$app$main$data$workspace$path$state$get_path$$($state$jscomp$681$$);
$entry$jscomp$59_id$jscomp$inline_7170$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_7171$$),$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_7171$$),$APP.$cljs$cst$1604$points$$,$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_7171$$),$APP.$cljs$cst$3556$preview$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$681$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$entry$jscomp$59_id$jscomp$inline_7170$$,$APP.$cljs$cst$3556$preview$$],null)),$APP.$cljs$cst$3553$last_point$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$681$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,
$entry$jscomp$59_id$jscomp$inline_7170$$,$APP.$cljs$cst$3553$last_point$$],null)),$APP.$cljs$cst$3554$prev_handler$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$681$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$entry$jscomp$59_id$jscomp$inline_7170$$,$APP.$cljs$cst$3554$prev_handler$$],null))],null);return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$681$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2291_id$jscomp$662$$,$cljs$cst$4207$undo_stack$$],null),$app$common$data$undo_stack$append$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$entry$jscomp$59_id$jscomp$inline_7170$$]))});return new $app$main$data$workspace$path$undo$add_undo_entry_69688$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$undo$end_path_undo$$=function(){typeof $app$main$data$workspace$path$undo$end_path_undo_69697$$==="undefined"&&($app$main$data$workspace$path$undo$end_path_undo_69697$$=function($meta69698$$){this.$meta69698$=$meta69698$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$undo$end_path_undo_69697$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$undo$end_path_undo_69697$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4211$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_end_path_undo$$},$app$main$data$workspace$path$undo$end_path_undo_69697$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69699$$,$meta69698__$1$$){return new $app$main$data$workspace$path$undo$end_path_undo_69697$$($meta69698__$1$$)},$app$main$data$workspace$path$undo$end_path_undo_69697$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69698$},$app$main$data$workspace$path$undo$end_path_undo_69697$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$undo$end_path_undo_69697$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2292$$,$state$jscomp$682$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$682$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$682$$)],
null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$4212$undo_lock$$,$cljs$cst$4207$undo_stack$$]))});return new $app$main$data$workspace$path$undo$end_path_undo_69697$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$undo$stop_undo_QMARK_$$=function($event$jscomp$101_type$jscomp$497$$){$event$jscomp$101_type$jscomp$497$$=$APP.$potok$v2$core$type$$($event$jscomp$101_type$jscomp$497$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3559$app_DOT_main_DOT_data_DOT_workspace_DOT_edition_SLASH_clear_edition_mode$$,$event$jscomp$101_type$jscomp$497$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3629$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_finalize_page$$,
$event$jscomp$101_type$jscomp$497$$)};
$app$main$data$workspace$path$undo$start_path_undo$$=function(){var $lock$jscomp$7$$=$APP.$app$common$uuid$next$$();typeof $app$main$data$workspace$path$undo$start_path_undo_69710$$==="undefined"&&($app$main$data$workspace$path$undo$start_path_undo_69710$$=function($lock$jscomp$8$$,$meta69711$$){this.lock=$lock$jscomp$8$$;this.$meta69711$=$meta69711$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$undo$start_path_undo_69710$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$path$undo$start_path_undo_69710$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4213$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_start_path_undo$$},$app$main$data$workspace$path$undo$start_path_undo_69710$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69712$$,$meta69711__$1$$){return new $app$main$data$workspace$path$undo$start_path_undo_69710$$(this.lock,$meta69711__$1$$)},$app$main$data$workspace$path$undo$start_path_undo_69710$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69711$},$app$main$data$workspace$path$undo$start_path_undo_69710$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$undo$start_path_undo_69710$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2293_undo_lock$$,$state$jscomp$684$$){$_$jscomp$2293_undo_lock$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$684$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$684$$),$cljs$cst$4212$undo_lock$$],null));return $APP.$cljs$core$not$$($_$jscomp$2293_undo_lock$$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$684$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$684$$)],
null),$APP.$cljs$core$assoc$$,$cljs$cst$4212$undo_lock$$,this.lock,$cljs$cst$4207$undo_stack$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1795$index$$,-1,$APP.$cljs$cst$1838$items$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null)])):$state$jscomp$684$$},$app$main$data$workspace$path$undo$start_path_undo_69710$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$undo$start_path_undo_69710$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2294_undo_lock$jscomp$1$$,$state$jscomp$685$$,$stop_undo_stream_stream$jscomp$68$$){$_$jscomp$2294_undo_lock$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$685$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$685$$),$cljs$cst$4212$undo_lock$$],null));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2294_undo_lock$jscomp$1$$,
this.lock)?($stop_undo_stream_stream$jscomp$68$$=$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($app$main$data$workspace$path$undo$stop_undo_QMARK_$$,$stop_undo_stream_stream$jscomp$68$$)),$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$path$undo$add_undo_entry$$()},$APP.$beicon$v2$core$filter$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$not$$,$APP.$cljs$core$nil_QMARK_$$),$APP.$beicon$v2$core$take_until$$($stop_undo_stream_stream$jscomp$68$$,
$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$workspace$path$undo$path_content_ref$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!0],null))))),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$undo$end_path_undo$$()))):null});return new $app$main$data$workspace$path$undo$start_path_undo_69710$$($lock$jscomp$7$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$path$drawing$end_path_event_QMARK_$$=function($event$jscomp$102$$){var $type$jscomp$498$$=$APP.$potok$v2$core$type$$($event$jscomp$102$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$498$$,$cljs$cst$3557$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_common_SLASH_finish_path$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$498$$,$cljs$cst$4214$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_shortcuts_SLASH_esc_pressed$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$498$$,$cljs$cst$4200$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_clear_edition_mode$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$498$$,$cljs$cst$3559$app_DOT_main_DOT_data_DOT_workspace_DOT_edition_SLASH_clear_edition_mode$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$498$$,$APP.$cljs$cst$3629$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_finalize_page$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$102$$,
$APP.$cljs$cst$2169$interrupt$$)||$APP.$app$util$mouse$mouse_event_QMARK_$$($event$jscomp$102$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2165$double_click$$,$event$jscomp$102$$.type)};
$app$main$data$workspace$path$drawing$preview_next_point$$=function($p__69772$$){var $map__69773__$1$$=$APP.$cljs$core$__destructure_map$$($p__69772$$),$x$jscomp$1205$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69773__$1$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$438$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69773__$1$$,$APP.$cljs$cst$1511$y$$),$shift_QMARK_$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69773__$1$$,$APP.$cljs$cst$4203$shift_QMARK_$$);
typeof $app$main$data$workspace$path$drawing$preview_next_point_69774$$==="undefined"&&($app$main$data$workspace$path$drawing$preview_next_point_69774$$=function($p__69772$jscomp$1$$,$map__69773$jscomp$1$$,$x$jscomp$1206$$,$y$jscomp$439$$,$shift_QMARK_$jscomp$17$$,$meta69775$$){this.$p__69772$=$p__69772$jscomp$1$$;this.$map__69773$=$map__69773$jscomp$1$$;this.x=$x$jscomp$1206$$;this.y=$y$jscomp$439$$;this.$shift_QMARK_$=$shift_QMARK_$jscomp$17$$;this.$meta69775$=$meta69775$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$preview_next_point_69774$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$preview_next_point_69774$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4215$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_preview_next_point$$},$app$main$data$workspace$path$drawing$preview_next_point_69774$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69776$$,$meta69775__$1$$){return new $app$main$data$workspace$path$drawing$preview_next_point_69774$$(this.$p__69772$,this.$map__69773$,this.x,this.y,this.$shift_QMARK_$,$meta69775__$1$$)},$app$main$data$workspace$path$drawing$preview_next_point_69774$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69775$},$app$main$data$workspace$path$drawing$preview_next_point_69774$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$preview_next_point_69774$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2295_id$jscomp$663$$,$state$jscomp$686$$){$_$jscomp$2295_id$jscomp$663$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$686$$);var $fix_angle_QMARK__position$jscomp$128_segment$jscomp$43$$=this.$shift_QMARK_$,$content$jscomp$200_content__$1$jscomp$inline_12837_last_point$jscomp$2$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$686$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2295_id$jscomp$663$$,$APP.$cljs$cst$3553$last_point$$],null)),$G__69788$jscomp$inline_7173_last_point__$1_map__69787$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(this.x,this.y);$fix_angle_QMARK__position$jscomp$128_segment$jscomp$43$$=$APP.$cljs$core$truth_$$($fix_angle_QMARK__position$jscomp$128_segment$jscomp$43$$)?$APP.$app$common$types$path$helpers$position_fixed_angle$$($G__69788$jscomp$inline_7173_last_point__$1_map__69787$$,
$content$jscomp$200_content__$1$jscomp$inline_12837_last_point$jscomp$2$$):$G__69788$jscomp$inline_7173_last_point__$1_map__69787$$;$content$jscomp$200_content__$1$jscomp$inline_12837_last_point$jscomp$2$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$686$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]));$G__69788$jscomp$inline_7173_last_point__$1_map__69787$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$686$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2295_id$jscomp$663$$],null));var $map__69787__$1_prev_handler$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($G__69788$jscomp$inline_7173_last_point__$1_map__69787$$);$G__69788$jscomp$inline_7173_last_point__$1_map__69787$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69787__$1_prev_handler$jscomp$4$$,$APP.$cljs$cst$3553$last_point$$);
$map__69787__$1_prev_handler$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69787__$1_prev_handler$jscomp$4$$,$APP.$cljs$cst$3554$prev_handler$$);$content$jscomp$200_content__$1$jscomp$inline_12837_last_point$jscomp$2$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$200_content__$1$jscomp$inline_12837_last_point$jscomp$2$$);$fix_angle_QMARK__position$jscomp$128_segment$jscomp$43$$=$app$common$types$path$segment$next_node$$($content$jscomp$200_content__$1$jscomp$inline_12837_last_point$jscomp$2$$,
$fix_angle_QMARK__position$jscomp$128_segment$jscomp$43$$,$G__69788$jscomp$inline_7173_last_point__$1_map__69787$$,$map__69787__$1_prev_handler$jscomp$4$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$686$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2295_id$jscomp$663$$,$APP.$cljs$cst$3556$preview$$],null),$fix_angle_QMARK__position$jscomp$128_segment$jscomp$43$$)});
return new $app$main$data$workspace$path$drawing$preview_next_point_69774$$($p__69772$$,$map__69773__$1$$,$x$jscomp$1205$$,$y$jscomp$438$$,$shift_QMARK_$jscomp$16$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$path$drawing$add_node$$=function($p__69791$$){var $map__69792__$1$$=$APP.$cljs$core$__destructure_map$$($p__69791$$),$x$jscomp$1207$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69792__$1$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$440$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69792__$1$$,$APP.$cljs$cst$1511$y$$),$shift_QMARK_$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69792__$1$$,$APP.$cljs$cst$4203$shift_QMARK_$$);
typeof $app$main$data$workspace$path$drawing$add_node_69793$$==="undefined"&&($app$main$data$workspace$path$drawing$add_node_69793$$=function($p__69791$jscomp$1$$,$map__69792$jscomp$1$$,$x$jscomp$1208$$,$y$jscomp$441$$,$shift_QMARK_$jscomp$19$$,$meta69794$$){this.$p__69791$=$p__69791$jscomp$1$$;this.$map__69792$=$map__69792$jscomp$1$$;this.x=$x$jscomp$1208$$;this.y=$y$jscomp$441$$;this.$shift_QMARK_$=$shift_QMARK_$jscomp$19$$;this.$meta69794$=$meta69794$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$add_node_69793$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$add_node_69793$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4216$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_add_node$$},$app$main$data$workspace$path$drawing$add_node_69793$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69795$$,
$meta69794__$1$$){return new $app$main$data$workspace$path$drawing$add_node_69793$$(this.$p__69791$,this.$map__69792$,this.x,this.y,this.$shift_QMARK_$,$meta69794__$1$$)},$app$main$data$workspace$path$drawing$add_node_69793$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69794$},$app$main$data$workspace$path$drawing$add_node_69793$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$add_node_69793$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2296_id$jscomp$664$$,$state$jscomp$687$$){$_$jscomp$2296_id$jscomp$664$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$687$$);var $fix_angle_QMARK_$jscomp$1_position$jscomp$129$$=this.$shift_QMARK_$,$last_point$jscomp$3_map__69799$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$687$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,
$_$jscomp$2296_id$jscomp$664$$],null)),$map__69799__$1_prev_handler$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($last_point$jscomp$3_map__69799$$);$last_point$jscomp$3_map__69799$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69799__$1_prev_handler$jscomp$5$$,$APP.$cljs$cst$3553$last_point$$);$map__69799__$1_prev_handler$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69799__$1_prev_handler$jscomp$5$$,$APP.$cljs$cst$3554$prev_handler$$);var $G__69800$jscomp$inline_7175$$=
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(this.x,this.y);$fix_angle_QMARK_$jscomp$1_position$jscomp$129$$=$APP.$cljs$core$truth_$$($fix_angle_QMARK_$jscomp$1_position$jscomp$129$$)?$APP.$app$common$types$path$helpers$position_fixed_angle$$($G__69800$jscomp$inline_7175$$,$last_point$jscomp$3_map__69799$$):$G__69800$jscomp$inline_7175$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($last_point$jscomp$3_map__69799$$,$fix_angle_QMARK_$jscomp$1_position$jscomp$129$$)?
$state$jscomp$687$$:$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$6$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc_in$$($state$jscomp$687$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2296_id$jscomp$664$$,$APP.$cljs$cst$3553$last_point$$],null),$fix_angle_QMARK_$jscomp$1_position$jscomp$129$$),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2296_id$jscomp$664$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3554$prev_handler$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2296_id$jscomp$664$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3556$preview$$),
$app$main$data$workspace$path$state$get_path_location$$($state$jscomp$687$$),$app$main$data$workspace$path$helpers$append_node$$,$fix_angle_QMARK_$jscomp$1_position$jscomp$129$$,$last_point$jscomp$3_map__69799$$,$map__69799__$1_prev_handler$jscomp$5$$)});return new $app$main$data$workspace$path$drawing$add_node_69793$$($p__69791$$,$map__69792__$1$$,$x$jscomp$1207$$,$y$jscomp$440$$,$shift_QMARK_$jscomp$18$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$path$drawing$drag_handler$cljs$0core$0IFn$0_invoke$0arity$04$$=function($position$jscomp$131$$,$index$jscomp$322$$,$prefix$jscomp$49$$,$p__69806$$){var $map__69807__$1$$=$APP.$cljs$core$__destructure_map$$($p__69806$$),$x$jscomp$1209$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69807__$1$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$442$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69807__$1$$,$APP.$cljs$cst$1511$y$$),$alt_QMARK_$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69807__$1$$,
$APP.$cljs$cst$4204$alt_QMARK_$$),$shift_QMARK_$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69807__$1$$,$APP.$cljs$cst$4203$shift_QMARK_$$);typeof $app$main$data$workspace$path$drawing$drag_handler_69808$$==="undefined"&&($app$main$data$workspace$path$drawing$drag_handler_69808$$=function($x$jscomp$1210$$,$y$jscomp$443$$,$alt_QMARK_$jscomp$11$$,$map__69807$jscomp$1$$,$p__69806$jscomp$1$$,$index$jscomp$323$$,$prefix$jscomp$50$$,$shift_QMARK_$jscomp$21$$,$position$jscomp$132$$,
$meta69809$$){this.x=$x$jscomp$1210$$;this.y=$y$jscomp$443$$;this.$alt_QMARK_$=$alt_QMARK_$jscomp$11$$;this.$map__69807$=$map__69807$jscomp$1$$;this.$p__69806$=$p__69806$jscomp$1$$;this.index=$index$jscomp$323$$;this.prefix=$prefix$jscomp$50$$;this.$shift_QMARK_$=$shift_QMARK_$jscomp$21$$;this.position=$position$jscomp$132$$;this.$meta69809$=$meta69809$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$drag_handler_69808$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$drag_handler_69808$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4217$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_drag_handler$$},$app$main$data$workspace$path$drawing$drag_handler_69808$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69810$$,$meta69809__$1$$){return new $app$main$data$workspace$path$drawing$drag_handler_69808$$(this.x,this.y,this.$alt_QMARK_$,
this.$map__69807$,this.$p__69806$,this.index,this.prefix,this.$shift_QMARK_$,this.position,$meta69809__$1$$)},$app$main$data$workspace$path$drawing$drag_handler_69808$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69809$},$app$main$data$workspace$path$drawing$drag_handler_69808$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$drag_handler_69808$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2297_id$jscomp$665$$,
$state$jscomp$688$$){var $self__$jscomp$5405$$=this;$_$jscomp$2297_id$jscomp$665$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$688$$);var $content$jscomp$201$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$688$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$])),$index__$1$jscomp$10$$=function(){var $or__5025__auto__$jscomp$819$$=$self__$jscomp$5405$$.index;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$819$$)?
$or__5025__auto__$jscomp$819$$:$APP.$cljs$core$count$$($content$jscomp$201$$)}(),$modifiers$jscomp$98_prefix__$1$jscomp$2$$=function(){var $or__5025__auto__$jscomp$820$$=$self__$jscomp$5405$$.prefix;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$820$$)?$or__5025__auto__$jscomp$820$$:$APP.$cljs$cst$1821$c1$$}(),$position__$1$jscomp$5$$=function(){var $or__5025__auto__$jscomp$821$$=$self__$jscomp$5405$$.position;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$821$$)?$or__5025__auto__$jscomp$821$$:
$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$201$$,$index__$1$jscomp$10$$-1))}(),$dx$jscomp$22_map__69817_old_handler$$=$APP.$app$common$types$path$get_handler_point$$($content$jscomp$201$$,$index__$1$jscomp$10$$,$modifiers$jscomp$98_prefix__$1$jscomp$2$$),$handler_position$$=function(){var $G__69818$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5405$$.x,
$self__$jscomp$5405$$.y);return $APP.$cljs$core$truth_$$($self__$jscomp$5405$$.$shift_QMARK_$)?$APP.$app$common$types$path$helpers$position_fixed_angle$$($G__69818$$,$position__$1$jscomp$5$$):$G__69818$$}();$dx$jscomp$22_map__69817_old_handler$$=$dx$jscomp$22_map__69817_old_handler$$!=null?$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$subtract$$($position__$1$jscomp$5$$,$dx$jscomp$22_map__69817_old_handler$$),$APP.$app$common$geom$point$subtract$$($handler_position$$,$position__$1$jscomp$5$$)):
$APP.$app$common$geom$point$subtract$$($handler_position$$,$position__$1$jscomp$5$$);var $dy$jscomp$22_map__69817__$1$$=$APP.$cljs$core$__destructure_map$$($dx$jscomp$22_map__69817_old_handler$$);$dx$jscomp$22_map__69817_old_handler$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dy$jscomp$22_map__69817__$1$$,$APP.$cljs$cst$1510$x$$);$dy$jscomp$22_map__69817__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dy$jscomp$22_map__69817__$1$$,$APP.$cljs$cst$1511$y$$);var $match_opposite_QMARK_$$=
$APP.$cljs$core$not$$($self__$jscomp$5405$$.$alt_QMARK_$);$modifiers$jscomp$98_prefix__$1$jscomp$2$$=$APP.$app$main$data$workspace$path$helpers$move_handler_modifiers$$($content$jscomp$201$$,$index__$1$jscomp$10$$,$modifiers$jscomp$98_prefix__$1$jscomp$2$$,$match_opposite_QMARK_$$,$match_opposite_QMARK_$$,$dx$jscomp$22_map__69817_old_handler$$,$dy$jscomp$22_map__69817__$1$$);return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$688$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2297_id$jscomp$665$$,$APP.$cljs$cst$1924$content_modifiers$$],null),$APP.$cljs$core$merge$$,$modifiers$jscomp$98_prefix__$1$jscomp$2$$),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2297_id$jscomp$665$$,$APP.$cljs$cst$3555$drag_handler$$],null),
$handler_position$$)});return new $app$main$data$workspace$path$drawing$drag_handler_69808$$($x$jscomp$1209$$,$y$jscomp$442$$,$alt_QMARK_$jscomp$10$$,$map__69807__$1$$,$p__69806$$,$index$jscomp$322$$,$prefix$jscomp$49$$,$shift_QMARK_$jscomp$20$$,$position$jscomp$131$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$path$drawing$finish_drag$$=function(){typeof $app$main$data$workspace$path$drawing$finish_drag_69825$$==="undefined"&&($app$main$data$workspace$path$drawing$finish_drag_69825$$=function($meta69826$$){this.$meta69826$=$meta69826$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$finish_drag_69825$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$finish_drag_69825$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4218$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_finish_drag$$},$app$main$data$workspace$path$drawing$finish_drag_69825$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69827$$,$meta69826__$1$$){return new $app$main$data$workspace$path$drawing$finish_drag_69825$$($meta69826__$1$$)},$app$main$data$workspace$path$drawing$finish_drag_69825$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69826$},$app$main$data$workspace$path$drawing$finish_drag_69825$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$finish_drag_69825$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2298_id$jscomp$666$$,$state$jscomp$689$$){$_$jscomp$2298_id$jscomp$666$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$689$$);var $content$jscomp$202_modifiers$jscomp$99$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$689$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2298_id$jscomp$666$$,$APP.$cljs$cst$1924$content_modifiers$$],null));$content$jscomp$202_modifiers$jscomp$99$$=$APP.$app$common$types$path$apply_content_modifiers$$($APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$689$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$])),$content$jscomp$202_modifiers$jscomp$99$$);var $handler$jscomp$40$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$689$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2298_id$jscomp$666$$,$APP.$cljs$cst$3555$drag_handler$$],null));return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$main$data$workspace$path$state$set_content$$($state$jscomp$689$$,
$content$jscomp$202_modifiers$jscomp$99$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2298_id$jscomp$666$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3555$drag_handler$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2298_id$jscomp$666$$],
null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1924$content_modifiers$$),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2298_id$jscomp$666$$,$APP.$cljs$cst$3554$prev_handler$$],null),$handler$jscomp$40$$),$app$main$data$workspace$path$state$get_path_location$$($state$jscomp$689$$),$app$common$types$path$update_geometry$$)},$app$main$data$workspace$path$drawing$finish_drag_69825$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$finish_drag_69825$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2299_id$jscomp$667$$,$handler$jscomp$41_state$jscomp$690$$){$_$jscomp$2299_id$jscomp$667$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($handler$jscomp$41_state$jscomp$690$$);$handler$jscomp$41_state$jscomp$690$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($handler$jscomp$41_state$jscomp$690$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2299_id$jscomp$667$$,$APP.$cljs$cst$3554$prev_handler$$],null));return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$drawing$preview_next_point$$($handler$jscomp$41_state$jscomp$690$$),$app$main$data$workspace$path$undo$merge_head$$())});return new $app$main$data$workspace$path$drawing$finish_drag_69825$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$drawing$make_node_events_stream$$=function($stream$jscomp$71$$){return $APP.$beicon$v2$core$merge_map$$(function(){return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4219$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_close_path_drag_start$$),$stream$jscomp$71$$)))};
$app$main$data$workspace$path$drawing$make_drag_stream$$=function($drag_events$jscomp$1_state$jscomp$694$$,$stopper$jscomp$25_stream$jscomp$72$$,$down_event$$){$stopper$jscomp$25_stream$jscomp$72$$=$APP.$beicon$v2$core$merge$$($APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stopper$jscomp$25_stream$jscomp$72$$,null),$APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$path$drawing$end_path_event_QMARK_$$,$stopper$jscomp$25_stream$jscomp$72$$));$drag_events$jscomp$1_state$jscomp$694$$=
$APP.$beicon$v2$core$take_until$$($stopper$jscomp$25_stream$jscomp$72$$,$APP.$beicon$v2$core$map$$(function($p1__69876_SHARP_$$){return $APP.$app$main$data$workspace$path$drawing$drag_handler$cljs$0core$0IFn$0_invoke$0arity$04$$(null,null,$APP.$cljs$cst$1821$c1$$,$p1__69876_SHARP_$$)},$APP.$app$main$data$workspace$path$streams$position_stream$$($drag_events$jscomp$1_state$jscomp$694$$)));return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$drawing$add_node$$($down_event$$)),
$APP.$app$main$data$workspace$path$streams$drag_stream$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$beicon$v2$core$concat$$($drag_events$jscomp$1_state$jscomp$694$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$drawing$finish_drag$$()))))};
$app$main$data$workspace$path$drawing$start_edition$$=function($_id$jscomp$1$$){typeof $app$main$data$workspace$path$drawing$start_edition_69887$$==="undefined"&&($app$main$data$workspace$path$drawing$start_edition_69887$$=function($_id$jscomp$2$$,$meta69888$$){this.$_id$=$_id$jscomp$2$$;this.$meta69888$=$meta69888$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$start_edition_69887$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$start_edition_69887$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4222$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_start_edition$$},$app$main$data$workspace$path$drawing$start_edition_69887$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69889$$,$meta69888__$1$$){return new $app$main$data$workspace$path$drawing$start_edition_69887$$(this.$_id$,$meta69888__$1$$)},
$app$main$data$workspace$path$drawing$start_edition_69887$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69888$},$app$main$data$workspace$path$drawing$start_edition_69887$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$start_edition_69887$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2303_id$jscomp$669$$,$state$jscomp$695$$){$_$jscomp$2303_id$jscomp$669$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$695$$);
return $APP.$cljs$core$assoc_in$$($state$jscomp$695$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2303_id$jscomp$669$$,$APP.$cljs$cst$4223$edit_mode$$],null),$APP.$cljs$cst$4224$draw$$)},$app$main$data$workspace$path$drawing$start_edition_69887$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$start_edition_69887$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2304_stoper_stream$$,$state$jscomp$696$$,$stream$jscomp$73$$){var $mouse_down_mousedown_events$$=$APP.$beicon$v2$core$filter$$($app$util$mouse$mouse_down_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($APP.$app$util$mouse$mouse_event_QMARK_$$,$stream$jscomp$73$$)),$end_stream$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$path$drawing$end_path_event_QMARK_$$,$stream$jscomp$73$$));$_$jscomp$2304_stoper_stream$$=$APP.$beicon$v2$core$merge$$($end_stream$$,
$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4222$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_start_edition$$),$stream$jscomp$73$$));var $mousemove_events$$=$APP.$beicon$v2$core$map$$(function($p1__69883_SHARP_$$){return $app$main$data$workspace$path$drawing$preview_next_point$$($p1__69883_SHARP_$$)},$APP.$app$main$data$workspace$path$streams$position_stream$$($state$jscomp$696$$));$mouse_down_mousedown_events$$=$APP.$beicon$v2$core$take_until$$($end_stream$$,
$APP.$beicon$v2$core$switch_map$$(function($p1__69886_SHARP_$$){return $beicon$v2$core$race$$($app$main$data$workspace$path$drawing$make_node_events_stream$$($stream$jscomp$73$$),$app$main$data$workspace$path$drawing$make_drag_stream$$($state$jscomp$696$$,$stream$jscomp$73$$,$p1__69886_SHARP_$$))},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__69885_SHARP_$$,$p2__69884_SHARP_$$){return $p2__69884_SHARP_$$},$APP.$app$main$data$workspace$path$streams$position_stream$$($state$jscomp$696$$),
$mouse_down_mousedown_events$$)));return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$undo$start_path_undo$$()),$APP.$beicon$v2$core$take_until$$($_$jscomp$2304_stoper_stream$$,$APP.$beicon$v2$core$merge$$($mousemove_events$$,$mouse_down_mousedown_events$$)),(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$4225$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_end_edition$$)))});return new $app$main$data$workspace$path$drawing$start_edition_69887$$($_id$jscomp$1$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$drawing$setup_frame$$=function(){typeof $app$main$data$workspace$path$drawing$setup_frame_69907$$==="undefined"&&($app$main$data$workspace$path$drawing$setup_frame_69907$$=function($meta69908$$){this.$meta69908$=$meta69908$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$setup_frame_69907$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$setup_frame_69907$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4226$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_setup_frame$$},$app$main$data$workspace$path$drawing$setup_frame_69907$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69909$$,$meta69908__$1$$){return new $app$main$data$workspace$path$drawing$setup_frame_69907$$($meta69908__$1$$)},$app$main$data$workspace$path$drawing$setup_frame_69907$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69908$},$app$main$data$workspace$path$drawing$setup_frame_69907$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$setup_frame_69907$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2305_objects$jscomp$598$$,$state$jscomp$697$$){$_$jscomp$2305_objects$jscomp$598$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$697$$);var $content$jscomp$204_position$jscomp$137$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$697$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$cst$2198$object$$,$APP.$cljs$cst$1637$content$$],null),$APP.$cljs$core$PersistentVector$EMPTY$$);$content$jscomp$204_position$jscomp$137$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$204_position$jscomp$137$$,0),$APP.$cljs$cst$1430$params$$));var $frame_id$jscomp$98$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$common$types$container$get_first_valid_parent$$($_$jscomp$2305_objects$jscomp$598$$,$APP.$app$common$types$shape_tree$top_nested_frame$cljs$0core$0IFn$0_invoke$0arity$04$$($_$jscomp$2305_objects$jscomp$598$$,$content$jscomp$204_position$jscomp$137$$,null,!1))),$flex_layout_QMARK_$jscomp$4$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2305_objects$jscomp$598$$,$frame_id$jscomp$98$$),
$drop_index$jscomp$9$$=$APP.$cljs$core$truth_$$($flex_layout_QMARK_$jscomp$4$$)?$app$common$geom$shapes$flex_layout$drop_area$get_drop_index$$($frame_id$jscomp$98$$,$_$jscomp$2305_objects$jscomp$598$$,$content$jscomp$204_position$jscomp$137$$):null;return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$697$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$cst$2198$object$$],
null),function($G__69918_object$jscomp$36$$){$G__69918_object$jscomp$36$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__69918_object$jscomp$36$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$98$$),$APP.$cljs$cst$1619$parent_id$$,$frame_id$jscomp$98$$);return $drop_index$jscomp$9$$!=null?$APP.$cljs$core$with_meta$$($G__69918_object$jscomp$36$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1795$index$$,$drop_index$jscomp$9$$],
null)):$G__69918_object$jscomp$36$$})});return new $app$main$data$workspace$path$drawing$setup_frame_69907$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$drawing$handle_drawing_end$$=function($shape_id$jscomp$112$$){typeof $app$main$data$workspace$path$drawing$handle_drawing_end_69923$$==="undefined"&&($app$main$data$workspace$path$drawing$handle_drawing_end_69923$$=function($shape_id$jscomp$113$$,$meta69924$$){this.$shape_id$=$shape_id$jscomp$113$$;this.$meta69924$=$meta69924$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$handle_drawing_end_69923$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$handle_drawing_end_69923$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4227$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_handle_drawing_end$$},$app$main$data$workspace$path$drawing$handle_drawing_end_69923$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69925$$,$meta69924__$1$$){return new $app$main$data$workspace$path$drawing$handle_drawing_end_69923$$(this.$shape_id$,
$meta69924__$1$$)},$app$main$data$workspace$path$drawing$handle_drawing_end_69923$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69924$},$app$main$data$workspace$path$drawing$handle_drawing_end_69923$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$handle_drawing_end_69923$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($G__69935$jscomp$inline_7177__$jscomp$2306_content$jscomp$205$$,$state$jscomp$698$$){$G__69935$jscomp$inline_7177__$jscomp$2306_content$jscomp$205$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$698$$,$APP.$cljs$cst$2189$workspace_drawing$$),$APP.$cljs$cst$2198$object$$),$APP.$cljs$cst$1637$content$$);$G__69935$jscomp$inline_7177__$jscomp$2306_content$jscomp$205$$=$G__69935$jscomp$inline_7177__$jscomp$2306_content$jscomp$205$$==null?null:$app$common$types$path$impl$check_content$$($G__69935$jscomp$inline_7177__$jscomp$2306_content$jscomp$205$$);
return $APP.$cljs$core$count$$($G__69935$jscomp$inline_7177__$jscomp$2306_content$jscomp$205$$)>1?$APP.$cljs$core$assoc_in$$($state$jscomp$698$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$cst$2198$object$$,$cljs$cst$4189$initialized_QMARK_$$],null),!0):$state$jscomp$698$$},$app$main$data$workspace$path$drawing$handle_drawing_end_69923$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$path$drawing$handle_drawing_end_69923$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2307_temp__5825__auto__$jscomp$218$$,$state$jscomp$699$$){$_$jscomp$2307_temp__5825__auto__$jscomp$218$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$699$$,$APP.$cljs$cst$2189$workspace_drawing$$),$APP.$cljs$cst$2198$object$$),$APP.$cljs$cst$1637$content$$);
return $APP.$cljs$core$truth_$$($_$jscomp$2307_temp__5825__auto__$jscomp$218$$)?$APP.$cljs$core$count$$($_$jscomp$2307_temp__5825__auto__$jscomp$218$$)>1?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$drawing$setup_frame$$(),$app$main$data$workspace$drawing$common$handle_finish_drawing$$(),$APP.$app$main$data$workspace$edition$start_edition_mode$$(this.$shape_id$),$APP.$app$main$data$workspace$path$drawing$change_edit_mode$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$data$workspace$path$drawing$change_edit_mode$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4224$draw$$):
$APP.$app$main$data$workspace$path$drawing$change_edit_mode$$($APP.$cljs$cst$4224$draw$$)):(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$drawing$common$handle_finish_drawing$$()):null});return new $app$main$data$workspace$path$drawing$handle_drawing_end_69923$$($shape_id$jscomp$112$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$drawing$handle_drawing$$=function(){typeof $app$main$data$workspace$path$drawing$handle_new_shape_69939$$==="undefined"&&($app$main$data$workspace$path$drawing$handle_new_shape_69939$$=function($meta69940$$){this.$meta69940$=$meta69940$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$handle_new_shape_69939$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$handle_new_shape_69939$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4228$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_handle_new_shape$$},$app$main$data$workspace$path$drawing$handle_new_shape_69939$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69941$$,$meta69940__$1$$){return new $app$main$data$workspace$path$drawing$handle_new_shape_69939$$($meta69940__$1$$)},$app$main$data$workspace$path$drawing$handle_new_shape_69939$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69940$},
$app$main$data$workspace$path$drawing$handle_new_shape_69939$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$handle_new_shape_69939$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2308_shape$jscomp$699$$,$state$jscomp$700$$){$_$jscomp$2308_shape$jscomp$699$$=$APP.$app$common$types$shape$setup_shape$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$296$path$$],null));
return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$700$$,$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2198$object$$,$_$jscomp$2308_shape$jscomp$699$$)},$app$main$data$workspace$path$drawing$handle_new_shape_69939$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$handle_new_shape_69939$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2309_shape_id$jscomp$114$$,
$state$jscomp$701$$,$stream$jscomp$74$$){$_$jscomp$2309_shape_id$jscomp$114$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$701$$,$APP.$cljs$cst$2189$workspace_drawing$$),$APP.$cljs$cst$2198$object$$),$APP.$cljs$cst$266$id$$);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$drawing$start_edition$$($_$jscomp$2309_shape_id$jscomp$114$$)),
$APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$workspace$path$drawing$handle_drawing_end$$,$_$jscomp$2309_shape_id$jscomp$114$$),$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4225$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_end_edition$$),$stream$jscomp$74$$)))))});return new $app$main$data$workspace$path$drawing$handle_new_shape_69939$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$drawing$start_draw_mode$$=function(){typeof $app$main$data$workspace$path$drawing$start_draw_mode_69956$$==="undefined"&&($app$main$data$workspace$path$drawing$start_draw_mode_69956$$=function($meta69957$$){this.$meta69957$=$meta69957$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$start_draw_mode_69956$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$start_draw_mode_69956$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4229$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_start_draw_mode$$},$app$main$data$workspace$path$drawing$start_draw_mode_69956$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69958$$,$meta69957__$1$$){return new $app$main$data$workspace$path$drawing$start_draw_mode_69956$$($meta69957__$1$$)},$app$main$data$workspace$path$drawing$start_draw_mode_69956$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69957$},$app$main$data$workspace$path$drawing$start_draw_mode_69956$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$start_draw_mode_69956$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2310_id$jscomp$670$$,$state$jscomp$702$$){$_$jscomp$2310_id$jscomp$670$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$702$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2199$edition$$);var $content$jscomp$207_objects$jscomp$599$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$702$$);
$content$jscomp$207_objects$jscomp$599$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$207_objects$jscomp$599$$,$_$jscomp$2310_id$jscomp$670$$),$APP.$cljs$cst$1637$content$$);return $APP.$cljs$core$truth_$$($content$jscomp$207_objects$jscomp$599$$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$702$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2310_id$jscomp$670$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4199$old_content$$,$content$jscomp$207_objects$jscomp$599$$):$state$jscomp$702$$},$app$main$data$workspace$path$drawing$start_draw_mode_69956$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$start_draw_mode_69956$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$drawing$start_draw_mode_STAR_$$.$cljs$core$IFn$_invoke$arity$0$?
$app$main$data$workspace$path$drawing$start_draw_mode_STAR_$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$workspace$path$drawing$start_draw_mode_STAR_$$())});return new $app$main$data$workspace$path$drawing$start_draw_mode_69956$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$path$drawing$change_edit_mode$$=function($mode$jscomp$29$$){typeof $app$main$data$workspace$path$drawing$change_edit_mode_69979$$==="undefined"&&($app$main$data$workspace$path$drawing$change_edit_mode_69979$$=function($mode$jscomp$30$$,$meta69980$$){this.mode=$mode$jscomp$30$$;this.$meta69980$=$meta69980$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$change_edit_mode_69979$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$change_edit_mode_69979$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4231$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_change_edit_mode$$},$app$main$data$workspace$path$drawing$change_edit_mode_69979$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69981$$,$meta69980__$1$$){return new $app$main$data$workspace$path$drawing$change_edit_mode_69979$$(this.mode,$meta69980__$1$$)},
$app$main$data$workspace$path$drawing$change_edit_mode_69979$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69980$},$app$main$data$workspace$path$drawing$change_edit_mode_69979$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$change_edit_mode_69979$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2313_temp__5823__auto__$jscomp$186$$,$state$jscomp$704$$){$_$jscomp$2313_temp__5823__auto__$jscomp$186$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$704$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2199$edition$$);return $APP.$cljs$core$truth_$$($_$jscomp$2313_temp__5823__auto__$jscomp$186$$)?$APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$704$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2313_temp__5823__auto__$jscomp$186$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4223$edit_mode$$,this.mode])):$state$jscomp$704$$},$app$main$data$workspace$path$drawing$change_edit_mode_69979$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$change_edit_mode_69979$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2314_temp__5825__auto__$jscomp$219$$,
$G__69985_state$jscomp$705$$){$_$jscomp$2314_temp__5825__auto__$jscomp$219$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__69985_state$jscomp$705$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2199$edition$$);if($APP.$cljs$core$truth_$$($_$jscomp$2314_temp__5825__auto__$jscomp$219$$))switch($G__69985_state$jscomp$705$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__69985_state$jscomp$705$$,
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1923$edit_path$$),$_$jscomp$2314_temp__5825__auto__$jscomp$219$$),$APP.$cljs$cst$4223$edit_mode$$),$G__69985_state$jscomp$705$$ instanceof $APP.$cljs$core$Keyword$$?$G__69985_state$jscomp$705$$.$fqn$:null){case "move":return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$common$finish_path$$());case "draw":return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$drawing$start_draw_mode$$());default:return $APP.$beicon$v2$core$empty$$()}else return null});
return new $app$main$data$workspace$path$drawing$change_edit_mode_69979$$($mode$jscomp$29$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$drawing$check_changed_content$$=function(){typeof $app$main$data$workspace$path$drawing$check_changed_content_69995$$==="undefined"&&($app$main$data$workspace$path$drawing$check_changed_content_69995$$=function($meta69996$$){this.$meta69996$=$meta69996$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$check_changed_content_69995$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$path$drawing$check_changed_content_69995$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4233$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_check_changed_content$$},$app$main$data$workspace$path$drawing$check_changed_content_69995$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69997$$,$meta69996__$1$$){return new $app$main$data$workspace$path$drawing$check_changed_content_69995$$($meta69996__$1$$)},$app$main$data$workspace$path$drawing$check_changed_content_69995$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69996$},$app$main$data$workspace$path$drawing$check_changed_content_69995$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$check_changed_content_69995$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2316_content$jscomp$208$$,$mode$jscomp$31_state$jscomp$707$$){var $empty_content_QMARK__id$jscomp$675$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($mode$jscomp$31_state$jscomp$707$$);
$_$jscomp$2316_content$jscomp$208$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($mode$jscomp$31_state$jscomp$707$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]));var $old_content$jscomp$4$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$31_state$jscomp$707$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$APP.$cljs$cst$1923$edit_path$$,$empty_content_QMARK__id$jscomp$675$$,$APP.$cljs$cst$4199$old_content$$],null));$mode$jscomp$31_state$jscomp$707$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$31_state$jscomp$707$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$empty_content_QMARK__id$jscomp$675$$,$APP.$cljs$cst$4223$edit_mode$$],null));$empty_content_QMARK__id$jscomp$675$$=
$APP.$cljs$core$empty_QMARK_$$($_$jscomp$2316_content$jscomp$208$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2316_content$jscomp$208$$,$old_content$jscomp$4$$)&&!$empty_content_QMARK__id$jscomp$675$$?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$changes$save_path_content$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$31_state$jscomp$707$$,$APP.$cljs$cst$4224$draw$$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2169$interrupt$$):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$common$finish_path$$(),$APP.$app$main$data$workspace$drawing$common$clear_drawing$$())});return new $app$main$data$workspace$path$drawing$check_changed_content_69995$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$update_selection$$=function($point_change$$){typeof $app$main$data$workspace$path$selection$update_selection_69783$$==="undefined"&&($app$main$data$workspace$path$selection$update_selection_69783$$=function($point_change$jscomp$1$$,$meta69784$$){this.$point_change$=$point_change$jscomp$1$$;this.$meta69784$=$meta69784$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$update_selection_69783$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$update_selection_69783$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4247$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_update_selection$$},$app$main$data$workspace$path$selection$update_selection_69783$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69785$$,$meta69784__$1$$){return new $app$main$data$workspace$path$selection$update_selection_69783$$(this.$point_change$,
$meta69784__$1$$)},$app$main$data$workspace$path$selection$update_selection_69783$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69784$},$app$main$data$workspace$path$selection$update_selection_69783$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$update_selection_69783$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2327_id$jscomp$684$$,$state$jscomp$718$$){$_$jscomp$2327_id$jscomp$684$$=
$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$718$$);var $selected_points$jscomp$3_selected_points__$1$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$718$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1923$edit_path$$),$_$jscomp$2327_id$jscomp$684$$),$APP.$cljs$cst$4241$selected_points$$,
$APP.$cljs$core$PersistentHashSet$EMPTY$$);$selected_points$jscomp$3_selected_points__$1$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(this.$point_change$),$selected_points$jscomp$3_selected_points__$1$jscomp$2$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$718$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2327_id$jscomp$684$$,$APP.$cljs$cst$4241$selected_points$$],null),$selected_points$jscomp$3_selected_points__$1$jscomp$2$$)});return new $app$main$data$workspace$path$selection$update_selection_69783$$($point_change$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$path$edition$apply_content_modifiers$$=function(){typeof $app$main$data$workspace$path$edition$apply_content_modifiers_69828$$==="undefined"&&($app$main$data$workspace$path$edition$apply_content_modifiers_69828$$=function($meta69829$$){this.$meta69829$=$meta69829$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$apply_content_modifiers_69828$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$path$edition$apply_content_modifiers_69828$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4250$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_apply_content_modifiers$$},$app$main$data$workspace$path$edition$apply_content_modifiers_69828$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69830$$,$meta69829__$1$$){return new $app$main$data$workspace$path$edition$apply_content_modifiers_69828$$($meta69829__$1$$)},$app$main$data$workspace$path$edition$apply_content_modifiers_69828$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69829$},$app$main$data$workspace$path$edition$apply_content_modifiers_69828$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$apply_content_modifiers_69828$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$231_it$jscomp$209_shape$jscomp$700$$,$objects$jscomp$600_state$jscomp$720$$){var $id$jscomp$687$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($objects$jscomp$600_state$jscomp$720$$);
$changes$jscomp$231_it$jscomp$209_shape$jscomp$700$$=$app$main$data$workspace$path$state$get_path$$($objects$jscomp$600_state$jscomp$720$$);var $content_modifiers$jscomp$1_new_content$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$600_state$jscomp$720$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1923$edit_path$$),
$id$jscomp$687$$),$APP.$cljs$cst$1924$content_modifiers$$);if($changes$jscomp$231_it$jscomp$209_shape$jscomp$700$$==null||$content_modifiers$jscomp$1_new_content$jscomp$9$$==null)return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$edition$clear_edition_mode$$());var $page_id$jscomp$200$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$600_state$jscomp$720$$,$APP.$cljs$cst$1918$current_page_id$$,$objects$jscomp$600_state$jscomp$720$$);$objects$jscomp$600_state$jscomp$720$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$600_state$jscomp$720$$);var $content$jscomp$211_old_points_point_change$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$231_it$jscomp$209_shape$jscomp$700$$,$APP.$cljs$cst$1637$content$$);$content_modifiers$jscomp$1_new_content$jscomp$9$$=$APP.$app$common$types$path$apply_content_modifiers$$($content$jscomp$211_old_points_point_change$jscomp$2$$,$content_modifiers$jscomp$1_new_content$jscomp$9$$);
$content$jscomp$211_old_points_point_change$jscomp$2$$=$APP.$app$common$types$path$get_points$$($content$jscomp$211_old_points_point_change$jscomp$2$$);var $new_points$jscomp$2$$=$APP.$app$common$types$path$get_points$$($content_modifiers$jscomp$1_new_content$jscomp$9$$);$content$jscomp$211_old_points_point_change$jscomp$2$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$merge$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$hash_map$$,$content$jscomp$211_old_points_point_change$jscomp$2$$,
$new_points$jscomp$2$$));return $content_modifiers$jscomp$1_new_content$jscomp$9$$!=null&&$changes$jscomp$231_it$jscomp$209_shape$jscomp$700$$!=null?($changes$jscomp$231_it$jscomp$209_shape$jscomp$700$$=$app$main$data$workspace$path$changes$generate_path_changes$$(this,$objects$jscomp$600_state$jscomp$720$$,$page_id$jscomp$200$$,$changes$jscomp$231_it$jscomp$209_shape$jscomp$700$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$231_it$jscomp$209_shape$jscomp$700$$),$content_modifiers$jscomp$1_new_content$jscomp$9$$),
$APP.$cljs$core$empty_QMARK_$$($content_modifiers$jscomp$1_new_content$jscomp$9$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$231_it$jscomp$209_shape$jscomp$700$$),$APP.$app$main$data$workspace$edition$clear_edition_mode$$()):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$231_it$jscomp$209_shape$jscomp$700$$),$app$main$data$workspace$path$selection$update_selection$$($content$jscomp$211_old_points_point_change$jscomp$2$$),
function($state__$1$jscomp$44$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$6$($state__$1$jscomp$44$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$id$jscomp$687$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1924$content_modifiers$$,$APP.$cljs$cst$4251$moving_nodes$$,$APP.$cljs$cst$4249$moving_handler$$)})):null});return new $app$main$data$workspace$path$edition$apply_content_modifiers_69828$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$path$edition$modify_content_point$$=function($content$jscomp$212_handler_indices$$,$map__69846__$1_p__69845_point_indices$$,$$__$1$jscomp$21_modifiers$jscomp$101$$,$point$jscomp$73$$){$map__69846__$1_p__69845_point_indices$$=$APP.$cljs$core$__destructure_map$$($map__69846__$1_p__69845_point_indices$$);var $dx$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69846__$1_p__69845_point_indices$$,$APP.$cljs$cst$1510$x$$),$dy$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69846__$1_p__69845_point_indices$$,
$APP.$cljs$cst$1511$y$$);$map__69846__$1_p__69845_point_indices$$=$app$common$types$path$point_indices$$($content$jscomp$212_handler_indices$$,$point$jscomp$73$$);$content$jscomp$212_handler_indices$$=$app$common$types$path$handler_indices$$($content$jscomp$212_handler_indices$$,$point$jscomp$73$$);$$__$1$jscomp$21_modifiers$jscomp$101$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($modifiers__$1$jscomp$14$$,$index$jscomp$330$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($modifiers__$1$jscomp$14$$,
$index$jscomp$330$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1510$x$$,$dx$jscomp$25$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$dy$jscomp$25$$]))},$$__$1$jscomp$21_modifiers$jscomp$101$$,$map__69846__$1_p__69845_point_indices$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($modifiers__$1$jscomp$15$$,$cx$jscomp$19_p__69847$$){var $index$jscomp$331$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cx$jscomp$19_p__69847$$,
0,null),$cy$jscomp$20_prefix$jscomp$58$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cx$jscomp$19_p__69847$$,1,null);$cx$jscomp$19_p__69847$$=$APP.$app$common$data$prefix_keyword$$($cy$jscomp$20_prefix$jscomp$58$$,$APP.$cljs$cst$1510$x$$);$cy$jscomp$20_prefix$jscomp$58$$=$APP.$app$common$data$prefix_keyword$$($cy$jscomp$20_prefix$jscomp$58$$,$APP.$cljs$cst$1511$y$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($modifiers__$1$jscomp$15$$,$index$jscomp$331$$,
$APP.$cljs$core$assoc$$,$cx$jscomp$19_p__69847$$,$dx$jscomp$25$$,$cy$jscomp$20_prefix$jscomp$58$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$dy$jscomp$25$$]))},$$__$1$jscomp$21_modifiers$jscomp$101$$,$content$jscomp$212_handler_indices$$)};
$app$main$data$workspace$path$edition$set_move_modifier$$=function($points$jscomp$88$$,$move_modifier$$){typeof $app$main$data$workspace$path$edition$set_modifiers_69856$$==="undefined"&&($app$main$data$workspace$path$edition$set_modifiers_69856$$=function($points$jscomp$89$$,$move_modifier$jscomp$1$$,$meta69857$$){this.points=$points$jscomp$89$$;this.$move_modifier$=$move_modifier$jscomp$1$$;this.$meta69857$=$meta69857$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$path$edition$set_modifiers_69856$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$set_modifiers_69856$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4252$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_set_modifiers$$},$app$main$data$workspace$path$edition$set_modifiers_69856$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69858$$,$meta69857__$1$$){return new $app$main$data$workspace$path$edition$set_modifiers_69856$$(this.points,
this.$move_modifier$,$meta69857__$1$$)},$app$main$data$workspace$path$edition$set_modifiers_69856$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69857$},$app$main$data$workspace$path$edition$set_modifiers_69856$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$set_modifiers_69856$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2330_id$jscomp$688$$,$state$jscomp$721$$){$_$jscomp$2330_id$jscomp$688$$=
$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$721$$);var $content$jscomp$213_content_modifiers__$1_modifiers_reducer$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$721$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]));$content$jscomp$213_content_modifiers__$1_modifiers_reducer$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$main$data$workspace$path$edition$modify_content_point$$,
$content$jscomp$213_content_modifiers__$1_modifiers_reducer$$,this.$move_modifier$);var $content_modifiers$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$721$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1923$edit_path$$),$_$jscomp$2330_id$jscomp$688$$),$APP.$cljs$cst$1924$content_modifiers$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);
$content$jscomp$213_content_modifiers__$1_modifiers_reducer$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$213_content_modifiers__$1_modifiers_reducer$$,$content_modifiers$jscomp$2$$,this.points);return $APP.$cljs$core$assoc_in$$($state$jscomp$721$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2330_id$jscomp$688$$,$APP.$cljs$cst$1924$content_modifiers$$],
null),$content$jscomp$213_content_modifiers__$1_modifiers_reducer$$)});return new $app$main$data$workspace$path$edition$set_modifiers_69856$$($points$jscomp$88$$,$move_modifier$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$get_displacement$$=function($G__69910__$1_direction$jscomp$22$$){$G__69910__$1_direction$jscomp$22$$=$G__69910__$1_direction$jscomp$22$$ instanceof $APP.$cljs$core$Keyword$$?$G__69910__$1_direction$jscomp$22$$.$fqn$:null;switch($G__69910__$1_direction$jscomp$22$$){case "up":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,-1);case "down":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,1);case "left":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,
0);case "right":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,0);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__69910__$1_direction$jscomp$22$$)].join(""));}};
$app$main$data$workspace$path$edition$finish_move_selected$$=function(){typeof $app$main$data$workspace$path$edition$finish_move_selected_69911$$==="undefined"&&($app$main$data$workspace$path$edition$finish_move_selected_69911$$=function($meta69912$$){this.$meta69912$=$meta69912$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$finish_move_selected_69911$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$path$edition$finish_move_selected_69911$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4256$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_finish_move_selected$$},$app$main$data$workspace$path$edition$finish_move_selected_69911$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69913$$,$meta69912__$1$$){return new $app$main$data$workspace$path$edition$finish_move_selected_69911$$($meta69912__$1$$)},$app$main$data$workspace$path$edition$finish_move_selected_69911$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69912$},$app$main$data$workspace$path$edition$finish_move_selected_69911$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$finish_move_selected_69911$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2334_id$jscomp$692$$,$state$jscomp$725$$){$_$jscomp$2334_id$jscomp$692$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$725$$,
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2199$edition$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$725$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2334_id$jscomp$692$$],null),$APP.$cljs$core$dissoc$$,$cljs$cst$4257$current_move$$)});return new $app$main$data$workspace$path$edition$finish_move_selected_69911$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$start_path_edit$$=function($id$jscomp$696$$){typeof $app$main$data$workspace$path$edition$start_path_edit_69973$$==="undefined"&&($app$main$data$workspace$path$edition$start_path_edit_69973$$=function($id$jscomp$697$$,$meta69974$$){this.id=$id$jscomp$697$$;this.$meta69974$=$meta69974$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$start_path_edit_69973$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$start_path_edit_69973$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4260$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_start_path_edit$$},$app$main$data$workspace$path$edition$start_path_edit_69973$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69975$$,$meta69974__$1$$){return new $app$main$data$workspace$path$edition$start_path_edit_69973$$(this.id,$meta69974__$1$$)},
$app$main$data$workspace$path$edition$start_path_edit_69973$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69974$},$app$main$data$workspace$path$edition$start_path_edit_69973$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$start_path_edit_69973$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2339_objects$jscomp$601$$,$state$jscomp$729$$){$_$jscomp$2339_objects$jscomp$601$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$729$$);
var $shape$jscomp$701$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2339_objects$jscomp$601$$,this.id);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$data$workspace$path$state$set_content$$($state$jscomp$729$$,$app$common$types$path$close_subpaths$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$701$$))),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$APP.$cljs$cst$1923$edit_path$$,this.id],null),function($state__$1$jscomp$45_state__$2$jscomp$4$$){$state__$1$jscomp$45_state__$2$jscomp$4$$=$APP.$cljs$core$truth_$$($state__$1$jscomp$45_state__$2$jscomp$4$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1798$move$$,$APP.$cljs$cst$4223$edit_mode$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$45_state__$2$jscomp$4$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$45_state__$2$jscomp$4$$,$APP.$cljs$cst$4223$edit_mode$$,
$APP.$cljs$cst$4224$draw$$):$state__$1$jscomp$45_state__$2$jscomp$4$$:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4223$edit_mode$$,$APP.$cljs$cst$1798$move$$,$APP.$cljs$cst$1921$selected$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$cst$4202$snap_toggled$$,!1],null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$45_state__$2$jscomp$4$$,$APP.$cljs$cst$4199$old_content$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$701$$))})},
$app$main$data$workspace$path$edition$start_path_edit_69973$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$start_path_edit_69973$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2340_stopper$jscomp$29$$,$___$1$jscomp$1571$$,$stream$jscomp$80$$){var $self__$jscomp$5550$$=this;$_$jscomp$2340_stopper$jscomp$29$$=$APP.$beicon$v2$core$filter$$(function($p1__69971_SHARP__type$jscomp$499$$){$p1__69971_SHARP__type$jscomp$499$$=
$APP.$potok$v2$core$type$$($p1__69971_SHARP__type$jscomp$499$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__69971_SHARP__type$jscomp$499$$,$cljs$cst$3559$app_DOT_main_DOT_data_DOT_workspace_DOT_edition_SLASH_clear_edition_mode$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__69971_SHARP__type$jscomp$499$$,$cljs$cst$4260$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_start_path_edit$$)},$stream$jscomp$80$$);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$undo$start_path_undo$$()),
$APP.$beicon$v2$core$take_until$$($_$jscomp$2340_stopper$jscomp$29$$,$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$path$edition$stop_path_edit$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$path$edition$stop_path_edit$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5550$$.id):$app$main$data$workspace$path$edition$stop_path_edit$$($self__$jscomp$5550$$.id)},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__69972_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__69972_SHARP_$$,
$APP.$cljs$cst$2169$interrupt$$)},$stream$jscomp$80$$)))))});return new $app$main$data$workspace$path$edition$start_path_edit_69973$$($id$jscomp$696$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$stop_path_edit$$=function($id$jscomp$698$$){typeof $app$main$data$workspace$path$edition$stop_path_edit_69982$$==="undefined"&&($app$main$data$workspace$path$edition$stop_path_edit_69982$$=function($id$jscomp$699$$,$meta69983$$){this.id=$id$jscomp$699$$;this.$meta69983$=$meta69983$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$stop_path_edit_69982$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$stop_path_edit_69982$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4261$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_stop_path_edit$$},$app$main$data$workspace$path$edition$stop_path_edit_69982$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69984$$,$meta69983__$1$$){return new $app$main$data$workspace$path$edition$stop_path_edit_69982$$(this.id,$meta69983__$1$$)},
$app$main$data$workspace$path$edition$stop_path_edit_69982$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69983$},$app$main$data$workspace$path$edition$stop_path_edit_69982$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$stop_path_edit_69982$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2341$$,$state$jscomp$730$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$730$$,
$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1923$edit_path$$,this.id)},$app$main$data$workspace$path$edition$stop_path_edit_69982$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$stop_path_edit_69982$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.id],null)],null)))});return new $app$main$data$workspace$path$edition$stop_path_edit_69982$$($id$jscomp$698$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$=function($points$jscomp$94$$,$tool_fn$jscomp$1$$){typeof $app$main$data$workspace$path$tools$process_path_tool_69728$$==="undefined"&&($app$main$data$workspace$path$tools$process_path_tool_69728$$=function($points$jscomp$95$$,$tool_fn$jscomp$2$$,$meta69729$$){this.points=$points$jscomp$95$$;this.$tool_fn$=$tool_fn$jscomp$2$$;this.$meta69729$=$meta69729$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$tools$process_path_tool_69728$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$tools$process_path_tool_69728$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4264$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_tools_SLASH_process_path_tool$$},$app$main$data$workspace$path$tools$process_path_tool_69728$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69730$$,$meta69729__$1$$){return new $app$main$data$workspace$path$tools$process_path_tool_69728$$(this.points,this.$tool_fn$,$meta69729__$1$$)},$app$main$data$workspace$path$tools$process_path_tool_69728$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69729$},$app$main$data$workspace$path$tools$process_path_tool_69728$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$tools$process_path_tool_69728$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($id$jscomp$703_it$jscomp$210$$,$new_content$jscomp$10_state$jscomp$733$$){var $self__$jscomp$5568$$=this,$changes$jscomp$232_page_id$jscomp$201$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_content$jscomp$10_state$jscomp$733$$,$APP.$cljs$cst$1918$current_page_id$$),$objects$jscomp$602$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($new_content$jscomp$10_state$jscomp$733$$,$changes$jscomp$232_page_id$jscomp$201$$),$shape$jscomp$702$$=$app$main$data$workspace$path$state$get_path$$($new_content$jscomp$10_state$jscomp$733$$);
$id$jscomp$703_it$jscomp$210$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($new_content$jscomp$10_state$jscomp$733$$);var $selected_points$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_content$jscomp$10_state$jscomp$733$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1923$edit_path$$),$id$jscomp$703_it$jscomp$210$$),
$APP.$cljs$cst$4241$selected_points$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$points__$1$jscomp$9$$=function(){var $or__5025__auto__$jscomp$824$$=$self__$jscomp$5568$$.points;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$824$$)?$or__5025__auto__$jscomp$824$$:$selected_points$jscomp$6$$}();return $APP.$cljs$core$seq$$($points__$1$jscomp$9$$)&&$shape$jscomp$702$$!=null?($new_content$jscomp$10_state$jscomp$733$$=$app$common$types$path$close_subpaths$$(function(){var $G__69737$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$702$$);
return $self__$jscomp$5568$$.$tool_fn$.$cljs$core$IFn$_invoke$arity$2$?$self__$jscomp$5568$$.$tool_fn$.$cljs$core$IFn$_invoke$arity$2$($G__69737$$,$points__$1$jscomp$9$$):$self__$jscomp$5568$$.$tool_fn$($G__69737$$,$points__$1$jscomp$9$$)}()),$changes$jscomp$232_page_id$jscomp$201$$=$app$main$data$workspace$path$changes$generate_path_changes$$(this,$objects$jscomp$602$$,$changes$jscomp$232_page_id$jscomp$201$$,$shape$jscomp$702$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$702$$),
$new_content$jscomp$10_state$jscomp$733$$),$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$703_it$jscomp$210$$],null),$APP.$app$common$types$path$convert_to_path$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$232_page_id$jscomp$201$$)),$APP.$cljs$core$empty_QMARK_$$($new_content$jscomp$10_state$jscomp$733$$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$edition$clear_edition_mode$$()):null)):null});return new $app$main$data$workspace$path$tools$process_path_tool_69728$$($points$jscomp$94$$,$tool_fn$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$tools$make_corner$cljs$0core$0IFn$0_invoke$0arity$01$$=function($point$jscomp$75$$){return $APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$truth_$$($point$jscomp$75$$)?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$point$jscomp$75$$]):null,function($content$jscomp$218$$,$points$jscomp$96$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$path$make_corner_point$$,
$content$jscomp$218$$,$points$jscomp$96$$)})};
$app$main$data$workspace$path$tools$make_curve$cljs$0core$0IFn$0_invoke$0arity$01$$=function($point$jscomp$76$$){return $APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$truth_$$($point$jscomp$76$$)?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$point$jscomp$76$$]):null,function($content$jscomp$219$$,$points$jscomp$97$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$path$make_curve_point$$,$content$jscomp$219$$,
$points$jscomp$97$$)})};
$APP.$app$main$data$workspace$path$tools$add_node$$=function(){return $APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$(null,function($content$jscomp$220_content__$1$jscomp$inline_7182$$,$points$jscomp$98$$){$content$jscomp$220_content__$1$jscomp$inline_7182$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$220_content__$1$jscomp$inline_7182$$);return $APP.$app$common$types$path$segment$split_segments$$($content$jscomp$220_content__$1$jscomp$inline_7182$$,$points$jscomp$98$$,
.5)})};
$APP.$app$main$data$workspace$path$tools$toggle_snap$$=function(){typeof $app$main$data$workspace$path$tools$toggle_snap_69758$$==="undefined"&&($app$main$data$workspace$path$tools$toggle_snap_69758$$=function($meta69759$$){this.$meta69759$=$meta69759$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$tools$toggle_snap_69758$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$tools$toggle_snap_69758$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4265$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_tools_SLASH_toggle_snap$$},
$app$main$data$workspace$path$tools$toggle_snap_69758$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69760$$,$meta69759__$1$$){return new $app$main$data$workspace$path$tools$toggle_snap_69758$$($meta69759__$1$$)},$app$main$data$workspace$path$tools$toggle_snap_69758$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69759$},$app$main$data$workspace$path$tools$toggle_snap_69758$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$tools$toggle_snap_69758$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2347_id$jscomp$704$$,$state$jscomp$734$$){$_$jscomp$2347_id$jscomp$704$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$734$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$734$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2347_id$jscomp$704$$,$APP.$cljs$cst$4202$snap_toggled$$],null),$APP.$cljs$core$not$$)});
return new $app$main$data$workspace$path$tools$toggle_snap_69758$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$drawing$start_drawing$$=function($type$jscomp$500$$){var $lock_id$$=$APP.$app$common$uuid$next$$();typeof $app$main$data$workspace$drawing$start_drawing_70061$$==="undefined"&&($app$main$data$workspace$drawing$start_drawing_70061$$=function($type$jscomp$501$$,$lock_id$jscomp$1$$,$meta70062$$){this.type=$type$jscomp$501$$;this.$lock_id$=$lock_id$jscomp$1$$;this.$meta70062$=$meta70062$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$drawing$start_drawing_70061$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$start_drawing_70061$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4268$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_start_drawing$$},$app$main$data$workspace$drawing$start_drawing_70061$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70063$$,$meta70062__$1$$){return new $app$main$data$workspace$drawing$start_drawing_70061$$(this.type,
this.$lock_id$,$meta70062__$1$$)},$app$main$data$workspace$drawing$start_drawing_70061$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70062$},$app$main$data$workspace$drawing$start_drawing_70061$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$start_drawing_70061$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2350$$,$state$jscomp$736$$){var $self__$jscomp$5581$$=this;return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$736$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2189$workspace_drawing$$,$cljs$cst$3560$lock$$],null),function($p1__70060_SHARP_$$){return $p1__70060_SHARP_$$==null?$self__$jscomp$5581$$.$lock_id$:$p1__70060_SHARP_$$})},$app$main$data$workspace$drawing$start_drawing_70061$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$start_drawing_70061$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2351_lock$jscomp$9$$,$state$jscomp$737$$,$stream$jscomp$82$$){$_$jscomp$2351_lock$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$737$$,$APP.$cljs$cst$2189$workspace_drawing$$),$cljs$cst$3560$lock$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2351_lock$jscomp$9$$,this.$lock_id$)?$APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$drawing$handle_drawing$$.$cljs$core$IFn$_invoke$arity$1$?
$app$main$data$workspace$drawing$handle_drawing$$.$cljs$core$IFn$_invoke$arity$1$(this.type):$app$main$data$workspace$drawing$handle_drawing$$(this.type)),$APP.$beicon$v2$core$map$$(function(){return function($state__$1$jscomp$46$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state__$1$jscomp$46$$,$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$core$dissoc$$,$cljs$cst$3560$lock$$)}},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4188$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_common_SLASH_handle_finish_drawing$$),
$stream$jscomp$82$$)))):null});return new $app$main$data$workspace$drawing$start_drawing_70061$$($type$jscomp$500$$,$lock_id$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$drawing$handle_drawing$$=function($type$jscomp$502$$){typeof $app$main$data$workspace$drawing$handle_drawing_70070$$==="undefined"&&($app$main$data$workspace$drawing$handle_drawing_70070$$=function($type$jscomp$503$$,$meta70071$$){this.type=$type$jscomp$503$$;this.$meta70071$=$meta70071$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$drawing$handle_drawing_70070$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$drawing$handle_drawing_70070$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4269$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_handle_drawing$$},$app$main$data$workspace$drawing$handle_drawing_70070$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70072$$,$meta70071__$1$$){return new $app$main$data$workspace$drawing$handle_drawing_70070$$(this.type,$meta70071__$1$$)},$app$main$data$workspace$drawing$handle_drawing_70070$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70071$},$app$main$data$workspace$drawing$handle_drawing_70070$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$handle_drawing_70070$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$5586$$=this;return(0,$APP.$beicon$v2$core$of$$)(function(){var $G__70075$$=$self__$jscomp$5586$$.type;switch($G__70075$$ instanceof $APP.$cljs$core$Keyword$$?$G__70075$$.$fqn$:null){case "path":return $app$main$data$workspace$path$drawing$handle_drawing$$();
case "curve":return $app$main$data$workspace$drawing$curve$handle_drawing$$();default:return $app$main$data$workspace$drawing$box$handle_drawing$$($self__$jscomp$5586$$.type)}}())});return new $app$main$data$workspace$drawing$handle_drawing_70070$$($type$jscomp$502$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$comments$center_to_comment_thread$$=function($p__70138$$){var $map__70139__$1$$=$APP.$cljs$core$__destructure_map$$($p__70138$$),$position$jscomp$148$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70139__$1$$,$APP.$cljs$cst$1676$position$$);typeof $app$main$data$workspace$comments$center_to_comment_thread_70140$$==="undefined"&&($app$main$data$workspace$comments$center_to_comment_thread_70140$$=function($p__70138$jscomp$1$$,$map__70139$jscomp$1$$,$thread$jscomp$24$$,
$position$jscomp$149$$,$meta70141$$){this.$p__70138$=$p__70138$jscomp$1$$;this.$map__70139$=$map__70139$jscomp$1$$;this.thread=$thread$jscomp$24$$;this.position=$position$jscomp$149$$;this.$meta70141$=$meta70141$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$comments$center_to_comment_thread_70140$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$center_to_comment_thread_70140$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4276$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_center_to_comment_thread$$},$app$main$data$workspace$comments$center_to_comment_thread_70140$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70142$$,$meta70141__$1$$){return new $app$main$data$workspace$comments$center_to_comment_thread_70140$$(this.$p__70138$,this.$map__70139$,this.thread,this.position,$meta70141__$1$$)},$app$main$data$workspace$comments$center_to_comment_thread_70140$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70141$},$app$main$data$workspace$comments$center_to_comment_thread_70140$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$center_to_comment_thread_70140$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2358$$,$state$jscomp$742$$){var $self__$jscomp$5610$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$742$$,$APP.$cljs$cst$1920$workspace_local$$,function($map__70145__$1_p__70144$$){$map__70145__$1_p__70144$$=
$APP.$cljs$core$__destructure_map$$($map__70145__$1_p__70144$$);var $nh_ny$jscomp$2_vbox$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70145__$1_p__70144$$,$APP.$cljs$cst$1925$vbox$$),$ph$jscomp$1_zoom$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70145__$1_p__70144$$,$APP.$cljs$cst$2196$zoom$$),$nw_nx$jscomp$2_pw$$=160/$ph$jscomp$1_zoom$jscomp$32$$;$ph$jscomp$1_zoom$jscomp$32$$=160/$ph$jscomp$1_zoom$jscomp$32$$;$nw_nx$jscomp$2_pw$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($nh_ny$jscomp$2_vbox$jscomp$21$$)/
2-$nw_nx$jscomp$2_pw$$;$nh_ny$jscomp$2_vbox$jscomp$21$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($nh_ny$jscomp$2_vbox$jscomp$21$$)/2-$ph$jscomp$1_zoom$jscomp$32$$;$nw_nx$jscomp$2_pw$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5610$$.position)-$nw_nx$jscomp$2_pw$$;$nh_ny$jscomp$2_vbox$jscomp$21$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5610$$.position)-$nh_ny$jscomp$2_vbox$jscomp$21$$;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($map__70145__$1_p__70144$$,
$APP.$cljs$cst$1925$vbox$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1510$x$$,$nw_nx$jscomp$2_pw$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$nh_ny$jscomp$2_vbox$jscomp$21$$]))})});return new $app$main$data$workspace$comments$center_to_comment_thread_70140$$($p__70138$$,$map__70139__$1$$,$map__70139__$1$$,$position$jscomp$148$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$comments$update_comment_thread_position$cljs$0core$0IFn$0_invoke$0arity$02$$=function($thread$jscomp$25$$,$new_y_p__70154$$){var $new_x$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_y_p__70154$$,0,null);$new_y_p__70154$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_y_p__70154$$,1,null);return $app$main$data$workspace$comments$update_comment_thread_position$cljs$0core$0IFn$0_invoke$0arity$03$$($thread$jscomp$25$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_x$$,$new_y_p__70154$$],null),null)};
$app$main$data$workspace$comments$update_comment_thread_position$cljs$0core$0IFn$0_invoke$0arity$03$$=function($thread$jscomp$26$$,$p__70158$$,$frame_id$jscomp$99$$){var $new_x$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__70158$$,0,null),$new_y$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__70158$$,1,null);typeof $app$main$data$workspace$comments$update_comment_thread_position_70162$$==="undefined"&&($app$main$data$workspace$comments$update_comment_thread_position_70162$$=
function($thread$jscomp$27$$,$p__70158$jscomp$1$$,$frame_id$jscomp$100$$,$vec__70159$jscomp$1$$,$new_x$jscomp$2$$,$new_y$jscomp$2$$,$meta70163$$){this.thread=$thread$jscomp$27$$;this.$p__70158$=$p__70158$jscomp$1$$;this.$frame_id$=$frame_id$jscomp$100$$;this.$vec__70159$=$vec__70159$jscomp$1$$;this.$new_x$=$new_x$jscomp$2$$;this.$new_y$=$new_y$jscomp$2$$;this.$meta70163$=$meta70163$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$comments$update_comment_thread_position_70162$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$update_comment_thread_position_70162$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4277$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_update_comment_thread_position$$},$app$main$data$workspace$comments$update_comment_thread_position_70162$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70164$$,$meta70163__$1$$){return new $app$main$data$workspace$comments$update_comment_thread_position_70162$$(this.thread,
this.$p__70158$,this.$frame_id$,this.$vec__70159$,this.$new_x$,this.$new_y$,$meta70163__$1$$)},$app$main$data$workspace$comments$update_comment_thread_position_70162$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70163$},$app$main$data$workspace$comments$update_comment_thread_position_70162$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$update_comment_thread_position_70162$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2359_page$jscomp$81_page_id$jscomp$203$$,$frame_id__$1$jscomp$11_objects$jscomp$603_state$jscomp$743$$){$_$jscomp$2359_page$jscomp$81_page_id$jscomp$203$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($frame_id__$1$jscomp$11_objects$jscomp$603_state$jscomp$743$$);$_$jscomp$2359_page$jscomp$81_page_id$jscomp$203$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2359_page$jscomp$81_page_id$jscomp$203$$);$frame_id__$1$jscomp$11_objects$jscomp$603_state$jscomp$743$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($frame_id__$1$jscomp$11_objects$jscomp$603_state$jscomp$743$$,$_$jscomp$2359_page$jscomp$81_page_id$jscomp$203$$);$frame_id__$1$jscomp$11_objects$jscomp$603_state$jscomp$743$$=this.$frame_id$==null?$app$common$types$shape_tree$get_frame_id_by_position$cljs$0core$0IFn$0_invoke$0arity$02$$($frame_id__$1$jscomp$11_objects$jscomp$603_state$jscomp$743$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(this.$new_x$,
this.$new_y$)):$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$(this.thread);var $thread__$1$jscomp$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.thread,$APP.$cljs$cst$1676$position$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(this.$new_x$,this.$new_y$)),$APP.$cljs$cst$1607$frame_id$$,$frame_id__$1$jscomp$11_objects$jscomp$603_state$jscomp$743$$),$thread_id$jscomp$10$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($thread__$1$jscomp$1$$);
return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)(function($p1__70151_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__70151_SHARP_$$,$APP.$cljs$cst$2175$comment_threads$$,$APP.$cljs$core$assoc$$,$thread_id$jscomp$10$$,$thread__$1$jscomp$1$$)}),$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,
$cljs$cst$4278$update_comment_thread_position$$],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$4278$update_comment_thread_position$$,$thread__$1$jscomp$1$$))))});return new $app$main$data$workspace$comments$update_comment_thread_position_70162$$($thread$jscomp$26$$,$p__70158$$,$frame_id$jscomp$99$$,$p__70158$$,$new_x$jscomp$1$$,$new_y$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$comments$move_frame_comment_threads$$=function($ids$jscomp$207$$,$transforms$jscomp$2$$){typeof $app$main$data$workspace$comments$move_frame_comment_threads_70173$$==="undefined"&&($app$main$data$workspace$comments$move_frame_comment_threads_70173$$=function($ids$jscomp$208$$,$transforms$jscomp$3$$,$meta70174$$){this.ids=$ids$jscomp$208$$;this.$transforms$=$transforms$jscomp$3$$;this.$meta70174$=$meta70174$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$comments$move_frame_comment_threads_70173$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$move_frame_comment_threads_70173$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3841$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_move_frame_comment_threads$$},$app$main$data$workspace$comments$move_frame_comment_threads_70173$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70175$$,
$meta70174__$1$$){return new $app$main$data$workspace$comments$move_frame_comment_threads_70173$$(this.ids,this.$transforms$,$meta70174__$1$$)},$app$main$data$workspace$comments$move_frame_comment_threads_70173$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70174$},$app$main$data$workspace$comments$move_frame_comment_threads_70173$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$move_frame_comment_threads_70173$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2360_page$jscomp$82$$,$state$jscomp$744$$){var $self__$jscomp$5618$$=this;$_$jscomp$2360_page$jscomp$82$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$744$$);var $objects$jscomp$604$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2360_page$jscomp$82$$,$APP.$cljs$cst$1631$objects$$),$frame_ids_QMARK_$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($id$jscomp$705$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$604$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$705$$,$APP.$cljs$cst$139$type$$],null)))}),$self__$jscomp$5618$$.ids),$threads_position_map$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2360_page$jscomp$82$$,$APP.$cljs$cst$2061$comment_thread_positions$$),$object_modifiers$jscomp$3$$=$APP.$cljs$cst$1922$workspace_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$744$$);
return $APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($comment_thread$$){var $frame_id$jscomp$101_moved$jscomp$2_new_y$jscomp$3_transform$jscomp$103$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($comment_thread$$),$frame$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$604$$,$frame_id$jscomp$101_moved$jscomp$2_new_y$jscomp$3_transform$jscomp$103$$),$G__70176__$1$jscomp$inline_7184_frame_SINGLEQUOTE__modifiers$jscomp$104_new_x$jscomp$3$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($object_modifiers$jscomp$3$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$101_moved$jscomp$2_new_y$jscomp$3_transform$jscomp$103$$,$APP.$cljs$cst$1810$modifiers$$],null));$frame_id$jscomp$101_moved$jscomp$2_new_y$jscomp$3_transform$jscomp$103$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5618$$.$transforms$,$frame_id$jscomp$101_moved$jscomp$2_new_y$jscomp$3_transform$jscomp$103$$);
$G__70176__$1$jscomp$inline_7184_frame_SINGLEQUOTE__modifiers$jscomp$104_new_x$jscomp$3$$=$G__70176__$1$jscomp$inline_7184_frame_SINGLEQUOTE__modifiers$jscomp$104_new_x$jscomp$3$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$37$$,$G__70176__$1$jscomp$inline_7184_frame_SINGLEQUOTE__modifiers$jscomp$104_new_x$jscomp$3$$):$frame$jscomp$37$$;$G__70176__$1$jscomp$inline_7184_frame_SINGLEQUOTE__modifiers$jscomp$104_new_x$jscomp$3$$=$frame_id$jscomp$101_moved$jscomp$2_new_y$jscomp$3_transform$jscomp$103$$!=
null?$APP.$app$common$geom$shapes$transforms$apply_transform$$($G__70176__$1$jscomp$inline_7184_frame_SINGLEQUOTE__modifiers$jscomp$104_new_x$jscomp$3$$,$frame_id$jscomp$101_moved$jscomp$2_new_y$jscomp$3_transform$jscomp$103$$):$G__70176__$1$jscomp$inline_7184_frame_SINGLEQUOTE__modifiers$jscomp$104_new_x$jscomp$3$$;$frame_id$jscomp$101_moved$jscomp$2_new_y$jscomp$3_transform$jscomp$103$$=$APP.$app$common$geom$point$to_vec$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$37$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$37$$)),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($G__70176__$1$jscomp$inline_7184_frame_SINGLEQUOTE__modifiers$jscomp$104_new_x$jscomp$3$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($G__70176__$1$jscomp$inline_7184_frame_SINGLEQUOTE__modifiers$jscomp$104_new_x$jscomp$3$$)));var $position$jscomp$150$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($threads_position_map$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($comment_thread$$),$APP.$cljs$cst$1676$position$$],null));$G__70176__$1$jscomp$inline_7184_frame_SINGLEQUOTE__modifiers$jscomp$104_new_x$jscomp$3$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$150$$)+$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$101_moved$jscomp$2_new_y$jscomp$3_transform$jscomp$103$$);
$frame_id$jscomp$101_moved$jscomp$2_new_y$jscomp$3_transform$jscomp$103$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$150$$)+$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$101_moved$jscomp$2_new_y$jscomp$3_transform$jscomp$103$$);return $app$main$data$workspace$comments$update_comment_thread_position$cljs$0core$0IFn$0_invoke$0arity$03$$($comment_thread$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$G__70176__$1$jscomp$inline_7184_frame_SINGLEQUOTE__modifiers$jscomp$104_new_x$jscomp$3$$,$frame_id$jscomp$101_moved$jscomp$2_new_y$jscomp$3_transform$jscomp$103$$],null),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$37$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($frame_ids_QMARK_$jscomp$1$$,$APP.$cljs$cst$1607$frame_id$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70172_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__70172_SHARP_$$,
$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($threads_position_map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__70172_SHARP_$$),$APP.$cljs$cst$1607$frame_id$$],null)))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70171_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__70171_SHARP_$$,$APP.$cljs$cst$1676$position$$,
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($threads_position_map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__70171_SHARP_$$),$APP.$cljs$cst$1676$position$$],null)))},$APP.$cljs$core$vals$$($APP.$cljs$cst$2175$comment_threads$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$744$$)))))))});return new $app$main$data$workspace$comments$move_frame_comment_threads_70173$$($ids$jscomp$207$$,
$transforms$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$comments$overlap_bubbles_QMARK_$$=function($zoom$jscomp$33$$,$thread_1$$,$thread_2$$){return $APP.$app$common$geom$point$distance$$($APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($thread_1$$),$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($thread_2$$))*$zoom$jscomp$33$$<32};
$app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles$$=function($thread$jscomp$29$$){typeof $app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles_70188$$==="undefined"&&($app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles_70188$$=function($thread$jscomp$30$$,$meta70189$$){this.thread=$thread$jscomp$30$$;this.$meta70189$=$meta70189$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles_70188$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles_70188$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4279$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_set_zoom_to_separate_grouped_bubbles$$},$app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles_70188$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70190$$,$meta70189__$1$$){return new $app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles_70188$$(this.thread,
$meta70189__$1$$)},$app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles_70188$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70189$},$app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles_70188$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles_70188$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2362_local$jscomp$11_scale_zoom_zoom$jscomp$35$$,
$state$jscomp$745_threads$jscomp$7_threads_all_threads_map$$){$_$jscomp$2362_local$jscomp$11_scale_zoom_zoom$jscomp$35$$=$APP.$cljs$cst$1920$workspace_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$745_threads$jscomp$7_threads_all_threads_map$$);$_$jscomp$2362_local$jscomp$11_scale_zoom_zoom$jscomp$35$$=$APP.$cljs$cst$2196$zoom$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2362_local$jscomp$11_scale_zoom_zoom$jscomp$35$$);var $page_id$jscomp$204$$=$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$(this.thread);
$state$jscomp$745_threads$jscomp$7_threads_all_threads_map$$=$APP.$cljs$cst$2175$comment_threads$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$745_threads$jscomp$7_threads_all_threads_map$$);$state$jscomp$745_threads$jscomp$7_threads_all_threads_map$$=$APP.$cljs$core$vals$$($state$jscomp$745_threads$jscomp$7_threads_all_threads_map$$);$state$jscomp$745_threads$jscomp$7_threads_all_threads_map$$=$APP.$cljs$core$filterv$$(function($p1__70187_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__70187_SHARP_$$),
$page_id$jscomp$204$$)},$state$jscomp$745_threads$jscomp$7_threads_all_threads_map$$);$_$jscomp$2362_local$jscomp$11_scale_zoom_zoom$jscomp$35$$=$app$main$data$workspace$comments$calculate_zoom_scale_to_ungroup_current_bubble$$($_$jscomp$2362_local$jscomp$11_scale_zoom_zoom$jscomp$35$$,this.thread,$state$jscomp$745_threads$jscomp$7_threads_all_threads_map$$)/$_$jscomp$2362_local$jscomp$11_scale_zoom_zoom$jscomp$35$$;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$zoom$set_zoom$cljs$0core$0IFn$0_invoke$0arity$02$$(null,
$_$jscomp$2362_local$jscomp$11_scale_zoom_zoom$jscomp$35$$))});return new $app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles_70188$$($thread$jscomp$29$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$comments$navigate_to_comment_from_dashboard$$=function($thread$jscomp$31$$){typeof $app$main$data$workspace$comments$navigate_to_comment_from_dashboard_70191$$==="undefined"&&($app$main$data$workspace$comments$navigate_to_comment_from_dashboard_70191$$=function($thread$jscomp$32$$,$meta70192$$){this.thread=$thread$jscomp$32$$;this.$meta70192$=$meta70192$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$comments$navigate_to_comment_from_dashboard_70191$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$navigate_to_comment_from_dashboard_70191$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4280$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_navigate_to_comment_from_dashboard$$},$app$main$data$workspace$comments$navigate_to_comment_from_dashboard_70191$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70193$$,$meta70192__$1$$){return new $app$main$data$workspace$comments$navigate_to_comment_from_dashboard_70191$$(this.thread,
$meta70192__$1$$)},$app$main$data$workspace$comments$navigate_to_comment_from_dashboard_70191$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70192$},$app$main$data$workspace$comments$navigate_to_comment_from_dashboard_70191$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$navigate_to_comment_from_dashboard_70191$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2363$$,$___$1$jscomp$1592$$,$stream$jscomp$84$$){var $self__$jscomp$5626$$=
this;return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5626$$.thread),$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5626$$.thread)]))),$APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$drawing$select_for_drawing$$($APP.$cljs$cst$3436$comments$$),
$app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles$$($self__$jscomp$5626$$.thread),$app$main$data$workspace$comments$center_to_comment_thread$$($self__$jscomp$5626$$.thread),$APP.$cljs$core$with_meta$$($APP.$app$main$data$comments$open_thread$$($self__$jscomp$5626$$.thread),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace"],null)))},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,
$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4281$app_DOT_main_DOT_data_DOT_workspace_SLASH_workspace_initialized$$),$stream$jscomp$84$$)))))});return new $app$main$data$workspace$comments$navigate_to_comment_from_dashboard_70191$$($thread$jscomp$31$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$comments$navigate_to_comment$$=function($thread$jscomp$33$$){typeof $app$main$data$workspace$comments$navigate_to_comment_70194$$==="undefined"&&($app$main$data$workspace$comments$navigate_to_comment_70194$$=function($thread$jscomp$34$$,$meta70195$$){this.thread=$thread$jscomp$34$$;this.$meta70195$=$meta70195$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$comments$navigate_to_comment_70194$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$navigate_to_comment_70194$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4282$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_navigate_to_comment$$},$app$main$data$workspace$comments$navigate_to_comment_70194$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70196$$,$meta70195__$1$$){return new $app$main$data$workspace$comments$navigate_to_comment_70194$$(this.thread,$meta70195__$1$$)},
$app$main$data$workspace$comments$navigate_to_comment_70194$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70195$},$app$main$data$workspace$comments$navigate_to_comment_70194$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$navigate_to_comment_70194$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2364$$,$state$jscomp$746$$){return $APP.$beicon$v2$core$concat$$(this.thread!=null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2532$workspace$$,
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$router$get_params$$($state$jscomp$746$$),$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$(this.thread)),$cljs$cst$4283$comment_id$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2455$app_DOT_main_DOT_router_SLASH_replace$$,!0],null)]))):$APP.$beicon$v2$core$empty$$(),
$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$drawing$select_for_drawing$$($APP.$cljs$cst$3436$comments$$),$app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles$$(this.thread),$app$main$data$workspace$comments$center_to_comment_thread$$(this.thread),$APP.$cljs$core$with_meta$$($APP.$app$main$data$comments$open_thread$$(this.thread),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"workspace"],null)))))});return new $app$main$data$workspace$comments$navigate_to_comment_70194$$($thread$jscomp$33$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$comments$navigate_to_comment_id$$=function($thread_id$jscomp$11$$){typeof $app$main$data$workspace$comments$navigate_to_comment_id_70200$$==="undefined"&&($app$main$data$workspace$comments$navigate_to_comment_id_70200$$=function($thread_id$jscomp$12$$,$meta70201$$){this.$thread_id$=$thread_id$jscomp$12$$;this.$meta70201$=$meta70201$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$comments$navigate_to_comment_id_70200$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$navigate_to_comment_id_70200$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4284$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_navigate_to_comment_id$$},$app$main$data$workspace$comments$navigate_to_comment_id_70200$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70202$$,$meta70201__$1$$){return new $app$main$data$workspace$comments$navigate_to_comment_id_70200$$(this.$thread_id$,
$meta70201__$1$$)},$app$main$data$workspace$comments$navigate_to_comment_id_70200$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70201$},$app$main$data$workspace$comments$navigate_to_comment_id_70200$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$navigate_to_comment_id_70200$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2365_temp__5823__auto__$jscomp$187$$,$state$jscomp$747$$){var $self__$jscomp$5634$$=
this;$_$jscomp$2365_temp__5823__auto__$jscomp$187$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$747$$);return $APP.$cljs$core$truth_$$($_$jscomp$2365_temp__5823__auto__$jscomp$187$$)?$APP.$beicon$v2$core$map$$($app$main$data$workspace$comments$navigate_to_comment$$,$APP.$beicon$v2$core$map$$(function($p1__70198_SHARP_$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($id$jscomp$706_map__70208__$1_p__70207$$){$id$jscomp$706_map__70208__$1_p__70207$$=
$APP.$cljs$core$__destructure_map$$($id$jscomp$706_map__70208__$1_p__70207$$);$id$jscomp$706_map__70208__$1_p__70207$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$706_map__70208__$1_p__70207$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5634$$.$thread_id$,$id$jscomp$706_map__70208__$1_p__70207$$)},$p1__70198_SHARP_$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3460$get_comment_threads$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$_$jscomp$2365_temp__5823__auto__$jscomp$187$$],null)))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$comments$navigate_to_comment_id_70200$$($thread_id$jscomp$11$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$fix_deleted_fonts$calculate_alternative_font_id$$=function($value$jscomp$597$$){var $fonts$jscomp$23$$=$APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$);return $APP.$cljs$core$reduce_kv$$(function($_$jscomp$2366$$,$___$1$jscomp$1595$$,$font$jscomp$40$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2675$family$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$40$$),$value$jscomp$597$$)?$APP.$cljs$core$reduced$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$40$$)):
null},null,$fonts$jscomp$23$$)};$app$main$data$workspace$fix_deleted_fonts$has_invalid_font_family_QMARK_$$=function($node$jscomp$333$$){var $fonts$jscomp$24$$=$APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$);return $APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$333$$)!=null&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fonts$jscomp$24$$,$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$333$$))==null};
$app$main$data$workspace$fix_deleted_fonts$fix_deleted_font$$=function($node$jscomp$334$$){var $temp__5823__auto__$jscomp$188$$=$app$main$data$workspace$fix_deleted_fonts$calculate_alternative_font_id$$($APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$334$$));return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$188$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$334$$,$APP.$cljs$cst$1757$font_id$$,$temp__5823__auto__$jscomp$188$$):$node$jscomp$334$$};
$app$main$data$workspace$fix_deleted_fonts$generate_page_changes$$=function($map__70216__$1_p__70215$$){$map__70216__$1_p__70215$$=$APP.$cljs$core$__destructure_map$$($map__70216__$1_p__70215$$);var $objects$jscomp$605$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70216__$1_p__70215$$,$APP.$cljs$cst$1631$objects$$),$id$jscomp$707$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70216__$1_p__70215$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$reduce_kv$$(function($changes$jscomp$233$$,
$shape_id$jscomp$115$$,$shape$jscomp$705$$){var $JSCompiler_inline_result$jscomp$1260_and__5023__auto__$jscomp$inline_7187$$=($JSCompiler_inline_result$jscomp$1260_and__5023__auto__$jscomp$inline_7187$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$705$$))?$APP.$cljs$core$some$$($app$main$data$workspace$fix_deleted_fonts$has_invalid_font_family_QMARK_$$,$APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,
$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$705$$))):$JSCompiler_inline_result$jscomp$1260_and__5023__auto__$jscomp$inline_7187$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1260_and__5023__auto__$jscomp$inline_7187$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$233$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$shape_id$jscomp$115$$,
$APP.$cljs$cst$2043$page_id$$,$id$jscomp$707$$,$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$108$val$$,$APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$data$workspace$fix_deleted_fonts$has_invalid_font_family_QMARK_$$,
$app$main$data$workspace$fix_deleted_fonts$fix_deleted_font$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$705$$))],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1891$position_data$$,$APP.$cljs$cst$108$val$$,null],null)],null)],null)):$changes$jscomp$233$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$objects$jscomp$605$$)};
$app$main$data$workspace$fix_deleted_fonts$generate_library_changes$$=function($fdata$jscomp$14$$){return $APP.$cljs$core$reduce_kv$$(function($JSCompiler_temp$jscomp$1261_changes$jscomp$234$$,$JSCompiler_temp_const$jscomp$1263__$jscomp$2367$$,$JSCompiler_inline_result$jscomp$1265_typography$jscomp$24$$){if($app$main$data$workspace$fix_deleted_fonts$has_invalid_font_family_QMARK_$$($JSCompiler_inline_result$jscomp$1265_typography$jscomp$24$$)){$JSCompiler_temp_const$jscomp$1263__$jscomp$2367$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$;
var $JSCompiler_temp_const$jscomp$1262$$=$APP.$cljs$cst$139$type$$,$temp__5823__auto__$jscomp$inline_7190$$=$app$main$data$workspace$fix_deleted_fonts$calculate_alternative_font_id$$($APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1265_typography$jscomp$24$$));$JSCompiler_inline_result$jscomp$1265_typography$jscomp$24$$=$APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_7190$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1265_typography$jscomp$24$$,
$APP.$cljs$cst$1757$font_id$$,$temp__5823__auto__$jscomp$inline_7190$$):$JSCompiler_inline_result$jscomp$1265_typography$jscomp$24$$;$JSCompiler_temp$jscomp$1261_changes$jscomp$234$$=$JSCompiler_temp_const$jscomp$1263__$jscomp$2367$$.call($APP.$cljs$core$conj$$,$JSCompiler_temp$jscomp$1261_changes$jscomp$234$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$JSCompiler_temp_const$jscomp$1262$$,$cljs$cst$2639$mod_typography$$,$APP.$cljs$cst$1981$typography$$,$JSCompiler_inline_result$jscomp$1265_typography$jscomp$24$$],
null))}return $JSCompiler_temp$jscomp$1261_changes$jscomp$234$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$2215$typographies$$.$cljs$core$IFn$_invoke$arity$1$($fdata$jscomp$14$$))};
$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_local_library$$=function($file_id$jscomp$220$$){typeof $app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_local_library_70221$$==="undefined"&&($app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_local_library_70221$$=function($file_id$jscomp$221$$,$meta70222$$){this.$file_id$=$file_id$jscomp$221$$;this.$meta70222$=$meta70222$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_local_library_70221$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_local_library_70221$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4285$app_DOT_main_DOT_data_DOT_workspace_DOT_fix_deleted_fonts_SLASH_fix_deleted_fonts_for_local_library$$},$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_local_library_70221$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70223$$,$meta70222__$1$$){return new $app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_local_library_70221$$(this.$file_id$,$meta70222__$1$$)},$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_local_library_70221$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70222$},$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_local_library_70221$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_local_library_70221$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($fdata$jscomp$15_it$jscomp$211_temp__5825__auto__$jscomp$220$$,$state$jscomp$748$$){$fdata$jscomp$15_it$jscomp$211_temp__5825__auto__$jscomp$220$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$748$$,this.$file_id$);$fdata$jscomp$15_it$jscomp$211_temp__5825__auto__$jscomp$220$$=$APP.$cljs$core$not_empty$$($app$main$data$workspace$fix_deleted_fonts$generate_library_changes$$($fdata$jscomp$15_it$jscomp$211_temp__5825__auto__$jscomp$220$$));return $APP.$cljs$core$truth_$$($fdata$jscomp$15_it$jscomp$211_temp__5825__auto__$jscomp$220$$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1786$origin$$,this,$APP.$cljs$cst$3133$redo_changes$$,$fdata$jscomp$15_it$jscomp$211_temp__5825__auto__$jscomp$220$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!1,$cljs$cst$3135$ignore_wasm_QMARK_$$,!0],null))):null});return new $app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_local_library_70221$$($file_id$jscomp$220$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_page$$=function($file_id$jscomp$222$$,$page_id$jscomp$205$$){typeof $app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_page_70225$$==="undefined"&&($app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_page_70225$$=function($file_id$jscomp$223$$,$page_id$jscomp$206$$,$meta70226$$){this.$file_id$=$file_id$jscomp$223$$;this.$page_id$=$page_id$jscomp$206$$;this.$meta70226$=$meta70226$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_page_70225$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_page_70225$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4286$app_DOT_main_DOT_data_DOT_workspace_DOT_fix_deleted_fonts_SLASH_fix_deleted_fonts_for_page$$},$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_page_70225$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70227$$,$meta70226__$1$$){return new $app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_page_70225$$(this.$file_id$,this.$page_id$,$meta70226__$1$$)},$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_page_70225$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70226$},$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_page_70225$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_page_70225$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($it$jscomp$212_page$jscomp$83_temp__5825__auto__$jscomp$221$$,$state$jscomp$749$$){$it$jscomp$212_page$jscomp$83_temp__5825__auto__$jscomp$221$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$749$$,this.$file_id$,this.$page_id$);$it$jscomp$212_page$jscomp$83_temp__5825__auto__$jscomp$221$$=$APP.$cljs$core$not_empty$$($app$main$data$workspace$fix_deleted_fonts$generate_page_changes$$($it$jscomp$212_page$jscomp$83_temp__5825__auto__$jscomp$221$$));return $APP.$cljs$core$truth_$$($it$jscomp$212_page$jscomp$83_temp__5825__auto__$jscomp$221$$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1786$origin$$,this,$APP.$cljs$cst$3133$redo_changes$$,$it$jscomp$212_page$jscomp$83_temp__5825__auto__$jscomp$221$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!1,$cljs$cst$3135$ignore_wasm_QMARK_$$,!0],null))):null});return new $app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_page_70225$$($file_id$jscomp$222$$,
$page_id$jscomp$205$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$guides$update_guides$$=function($p__70245$$){var $map__70246__$1$$=$APP.$cljs$core$__destructure_map$$($p__70245$$),$id$jscomp$708$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70246__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$workspace$guides$update_guides_70247$$==="undefined"&&($app$main$data$workspace$guides$update_guides_70247$$=function($p__70245$jscomp$1$$,$map__70246$jscomp$1$$,$guide$jscomp$4$$,$id$jscomp$709$$,$meta70248$$){this.$p__70245$=
$p__70245$jscomp$1$$;this.$map__70246$=$map__70246$jscomp$1$$;this.guide=$guide$jscomp$4$$;this.id=$id$jscomp$709$$;this.$meta70248$=$meta70248$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$guides$update_guides_70247$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$update_guides_70247$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4287$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_update_guides$$},
$app$main$data$workspace$guides$update_guides_70247$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70249$$,$meta70248__$1$$){return new $app$main$data$workspace$guides$update_guides_70247$$(this.$p__70245$,this.$map__70246$,this.guide,this.id,$meta70248__$1$$)},$app$main$data$workspace$guides$update_guides_70247$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70248$},$app$main$data$workspace$guides$update_guides_70247$$.prototype.$app$main$data$event$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$update_guides_70247$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.guide,$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"update-guide")},$app$main$data$workspace$guides$update_guides_70247$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$update_guides_70247$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$237_it$jscomp$213_page$jscomp$84$$,$state$jscomp$750$$){$changes$jscomp$237_it$jscomp$213_page$jscomp$84$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$750$$);$changes$jscomp$237_it$jscomp$213_page$jscomp$84$$=$APP.$app$common$files$changes_builder$set_guide$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$237_it$jscomp$213_page$jscomp$84$$),
this.id,this.guide);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$237_it$jscomp$213_page$jscomp$84$$))});return new $app$main$data$workspace$guides$update_guides_70247$$($p__70245$$,$map__70246__$1$$,$map__70246__$1$$,$id$jscomp$708$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$guides$remove_guide$$=function($p__70258$$){var $map__70259__$1$$=$APP.$cljs$core$__destructure_map$$($p__70258$$),$id$jscomp$710$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70259__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$workspace$guides$remove_guide_70260$$==="undefined"&&($app$main$data$workspace$guides$remove_guide_70260$$=function($p__70258$jscomp$1$$,$map__70259$jscomp$1$$,$guide$jscomp$6$$,$id$jscomp$711$$,$meta70261$$){this.$p__70258$=
$p__70258$jscomp$1$$;this.$map__70259$=$map__70259$jscomp$1$$;this.guide=$guide$jscomp$6$$;this.id=$id$jscomp$711$$;this.$meta70261$=$meta70261$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$guides$remove_guide_70260$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$remove_guide_70260$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4288$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_remove_guide$$},
$app$main$data$workspace$guides$remove_guide_70260$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70262$$,$meta70261__$1$$){return new $app$main$data$workspace$guides$remove_guide_70260$$(this.$p__70258$,this.$map__70259$,this.guide,this.id,$meta70261__$1$$)},$app$main$data$workspace$guides$remove_guide_70260$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70261$},$app$main$data$workspace$guides$remove_guide_70260$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$guides$remove_guide_70260$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return this.guide},$app$main$data$workspace$guides$remove_guide_70260$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$remove_guide_70260$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2373$$,$state$jscomp$751$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$751$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4289$workspace_guides$$,$APP.$cljs$cst$2204$hover$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$disj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),this.id)},$app$main$data$workspace$guides$remove_guide_70260$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$remove_guide_70260$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$238_it$jscomp$214_page$jscomp$85$$,$state$jscomp$752$$){$changes$jscomp$238_it$jscomp$214_page$jscomp$85$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$752$$);$changes$jscomp$238_it$jscomp$214_page$jscomp$85$$=$APP.$app$common$files$changes_builder$set_guide$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$238_it$jscomp$214_page$jscomp$85$$),
this.id,null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$238_it$jscomp$214_page$jscomp$85$$))});return new $app$main$data$workspace$guides$remove_guide_70260$$($p__70258$$,$map__70259__$1$$,$map__70259__$1$$,$id$jscomp$710$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$guides$remove_guides$$=function($ids$jscomp$209$$){typeof $app$main$data$workspace$guides$remove_guides_70268$$==="undefined"&&($app$main$data$workspace$guides$remove_guides_70268$$=function($ids$jscomp$210$$,$meta70269$$){this.ids=$ids$jscomp$210$$;this.$meta70269$=$meta70269$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$guides$remove_guides_70268$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$guides$remove_guides_70268$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4290$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_remove_guides$$},$app$main$data$workspace$guides$remove_guides_70268$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70270$$,$meta70269__$1$$){return new $app$main$data$workspace$guides$remove_guides_70268$$(this.ids,$meta70269__$1$$)},$app$main$data$workspace$guides$remove_guides_70268$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70269$},$app$main$data$workspace$guides$remove_guides_70268$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$remove_guides_70268$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2375_guides$jscomp$4_guides__$1$jscomp$1_map__70275_map__70275__$1$$,$state$jscomp$753$$){$_$jscomp$2375_guides$jscomp$4_guides__$1$jscomp$1_map__70275_map__70275__$1$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$753$$);
$_$jscomp$2375_guides$jscomp$4_guides__$1$jscomp$1_map__70275_map__70275__$1$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$2375_guides$jscomp$4_guides__$1$jscomp$1_map__70275_map__70275__$1$$);$_$jscomp$2375_guides$jscomp$4_guides__$1$jscomp$1_map__70275_map__70275__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2375_guides$jscomp$4_guides__$1$jscomp$1_map__70275_map__70275__$1$$,$APP.$cljs$cst$2057$guides$$);$_$jscomp$2375_guides$jscomp$4_guides__$1$jscomp$1_map__70275_map__70275__$1$$=
$APP.$cljs$core$vals$$($APP.$cljs$core$select_keys$$($_$jscomp$2375_guides$jscomp$4_guides__$1$jscomp$1_map__70275_map__70275__$1$$,this.ids));return $APP.$beicon$v2$core$from$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$guides$remove_guide$$,$_$jscomp$2375_guides$jscomp$4_guides__$1$jscomp$1_map__70275_map__70275__$1$$))});return new $app$main$data$workspace$guides$remove_guides_70268$$($ids$jscomp$209$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$highlight$highlight_shape$$=function($id$jscomp$716$$){typeof $app$main$data$workspace$highlight$highlight_shape_70314$$==="undefined"&&($app$main$data$workspace$highlight$highlight_shape_70314$$=function($id$jscomp$717$$,$meta70315$$){this.id=$id$jscomp$717$$;this.$meta70315$=$meta70315$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$highlight$highlight_shape_70314$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$highlight$highlight_shape_70314$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4294$app_DOT_main_DOT_data_DOT_workspace_DOT_highlight_SLASH_highlight_shape$$},$app$main$data$workspace$highlight$highlight_shape_70314$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70316$$,$meta70315__$1$$){return new $app$main$data$workspace$highlight$highlight_shape_70314$$(this.id,$meta70315__$1$$)},$app$main$data$workspace$highlight$highlight_shape_70314$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70315$},$app$main$data$workspace$highlight$highlight_shape_70314$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$highlight$highlight_shape_70314$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2382$$,$state$jscomp$759$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$759$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4295$highlighted$$],null),$APP.$clojure$set$union$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([this.id]))});return new $app$main$data$workspace$highlight$highlight_shape_70314$$($id$jscomp$716$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$highlight$dehighlight_shape$$=function($id$jscomp$718$$){typeof $app$main$data$workspace$highlight$dehighlight_shape_70321$$==="undefined"&&($app$main$data$workspace$highlight$dehighlight_shape_70321$$=function($id$jscomp$719$$,$meta70322$$){this.id=$id$jscomp$719$$;this.$meta70322$=$meta70322$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$highlight$dehighlight_shape_70321$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$highlight$dehighlight_shape_70321$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4296$app_DOT_main_DOT_data_DOT_workspace_DOT_highlight_SLASH_dehighlight_shape$$},$app$main$data$workspace$highlight$dehighlight_shape_70321$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70323$$,$meta70322__$1$$){return new $app$main$data$workspace$highlight$dehighlight_shape_70321$$(this.id,$meta70322__$1$$)},
$app$main$data$workspace$highlight$dehighlight_shape_70321$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70322$},$app$main$data$workspace$highlight$dehighlight_shape_70321$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$highlight$dehighlight_shape_70321$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2383$$,$state$jscomp$760$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$760$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4295$highlighted$$],null),$APP.$cljs$core$disj$$,this.id)});return new $app$main$data$workspace$highlight$dehighlight_shape_70321$$($id$jscomp$718$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$interactions$add_flow$cljs$0core$0IFn$0_invoke$0arity$04$$=function($flow_id$jscomp$2$$,$page_id$jscomp$207$$,$name$jscomp$338$$,$starting_frame$jscomp$2$$){typeof $app$main$data$workspace$interactions$add_flow_70399$$==="undefined"&&($app$main$data$workspace$interactions$add_flow_70399$$=function($flow_id$jscomp$3$$,$page_id$jscomp$208$$,$name$jscomp$339$$,$starting_frame$jscomp$3$$,$meta70400$$){this.$flow_id$=$flow_id$jscomp$3$$;this.$page_id$=$page_id$jscomp$208$$;
this.name=$name$jscomp$339$$;this.$starting_frame$=$starting_frame$jscomp$3$$;this.$meta70400$=$meta70400$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$add_flow_70399$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$add_flow_70399$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4300$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_add_flow$$},
$app$main$data$workspace$interactions$add_flow_70399$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70401$$,$meta70400__$1$$){return new $app$main$data$workspace$interactions$add_flow_70399$$(this.$flow_id$,this.$page_id$,this.name,this.$starting_frame$,$meta70400__$1$$)},$app$main$data$workspace$interactions$add_flow_70399$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70400$},$app$main$data$workspace$interactions$add_flow_70399$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$add_flow_70399$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$217_page$jscomp$89$$,$flow_id__$1_state$jscomp$763$$){var $self__$jscomp$5694$$=this;$it$jscomp$217_page$jscomp$89$$=$APP.$cljs$core$truth_$$($self__$jscomp$5694$$.$page_id$)?$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$2$($flow_id__$1_state$jscomp$763$$,$self__$jscomp$5694$$.$page_id$):$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($flow_id__$1_state$jscomp$763$$);
var $unames$jscomp$10$$=$APP.$app$common$files$helpers$get_used_names$$($APP.$cljs$core$vals$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$217_page$jscomp$89$$,$APP.$cljs$cst$2056$flows$$))),$flow$jscomp$2_name__$1$jscomp$10$$=function(){var $or__5025__auto__$jscomp$827$$=$self__$jscomp$5694$$.name;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$827$$)?$or__5025__auto__$jscomp$827$$:$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$("Flow",
$unames$jscomp$10$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1629$immediate_suffix_QMARK_$$,!0]))}();$flow_id__$1_state$jscomp$763$$=function(){var $or__5025__auto__$jscomp$828$$=$self__$jscomp$5694$$.$flow_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$828$$)?$or__5025__auto__$jscomp$828$$:$APP.$app$common$uuid$next$$()}();$flow$jscomp$2_name__$1$jscomp$10$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$flow_id__$1_state$jscomp$763$$,
$APP.$cljs$cst$725$name$$,$flow$jscomp$2_name__$1$jscomp$10$$,$APP.$cljs$cst$2053$starting_frame$$,$self__$jscomp$5694$$.$starting_frame$],null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($app$common$files$changes_builder$set_flow$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$it$jscomp$217_page$jscomp$89$$),$flow_id__$1_state$jscomp$763$$,$flow$jscomp$2_name__$1$jscomp$10$$)))});
return new $app$main$data$workspace$interactions$add_flow_70399$$($flow_id$jscomp$2$$,$page_id$jscomp$207$$,$name$jscomp$338$$,$starting_frame$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$02$$=function($page_id$jscomp$209$$,$flow_id$jscomp$5$$){typeof $app$main$data$workspace$interactions$remove_flow_70422$$==="undefined"&&($app$main$data$workspace$interactions$remove_flow_70422$$=function($page_id$jscomp$210$$,$flow_id$jscomp$6$$,$meta70423$$){this.$page_id$=$page_id$jscomp$210$$;this.$flow_id$=$flow_id$jscomp$6$$;this.$meta70423$=$meta70423$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$interactions$remove_flow_70422$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$remove_flow_70422$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4302$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_remove_flow$$},$app$main$data$workspace$interactions$remove_flow_70422$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70424$$,$meta70423__$1$$){return new $app$main$data$workspace$interactions$remove_flow_70422$$(this.$page_id$,
this.$flow_id$,$meta70423__$1$$)},$app$main$data$workspace$interactions$remove_flow_70422$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70423$},$app$main$data$workspace$interactions$remove_flow_70422$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$remove_flow_70422$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$218_page$jscomp$90$$,$state$jscomp$765$$){$it$jscomp$218_page$jscomp$90$$=
$APP.$cljs$core$truth_$$(this.$page_id$)?$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$765$$,this.$page_id$):$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$765$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($app$common$files$changes_builder$set_flow$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$it$jscomp$218_page$jscomp$90$$),this.$flow_id$,null)))});return new $app$main$data$workspace$interactions$remove_flow_70422$$($page_id$jscomp$209$$,$flow_id$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$interactions$update_flow$$=function($page_id$jscomp$211$$,$flow_id$jscomp$7$$,$update_fn$jscomp$31$$){typeof $app$main$data$workspace$interactions$update_flow_70433$$==="undefined"&&($app$main$data$workspace$interactions$update_flow_70433$$=function($page_id$jscomp$212$$,$flow_id$jscomp$8$$,$update_fn$jscomp$32$$,$meta70434$$){this.$page_id$=$page_id$jscomp$212$$;this.$flow_id$=$flow_id$jscomp$8$$;this.$update_fn$=$update_fn$jscomp$32$$;this.$meta70434$=$meta70434$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$update_flow_70433$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$update_flow_70433$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4303$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_update_flow$$},$app$main$data$workspace$interactions$update_flow_70433$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70435$$,$meta70434__$1$$){return new $app$main$data$workspace$interactions$update_flow_70433$$(this.$page_id$,this.$flow_id$,this.$update_fn$,$meta70434__$1$$)},$app$main$data$workspace$interactions$update_flow_70433$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70434$},$app$main$data$workspace$interactions$update_flow_70433$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$update_flow_70433$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($it$jscomp$219_page$jscomp$91$$,$flow$jscomp$3_flow__$1_state$jscomp$766$$){$it$jscomp$219_page$jscomp$91$$=$APP.$cljs$core$truth_$$(this.$page_id$)?$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$2$($flow$jscomp$3_flow__$1_state$jscomp$766$$,this.$page_id$):$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$3_flow__$1_state$jscomp$766$$);$flow$jscomp$3_flow__$1_state$jscomp$766$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$219_page$jscomp$91$$,
$APP.$cljs$cst$2056$flows$$),this.$flow_id$);$flow$jscomp$3_flow__$1_state$jscomp$766$$=$flow$jscomp$3_flow__$1_state$jscomp$766$$==null?null:this.$update_fn$.$cljs$core$IFn$_invoke$arity$1$?this.$update_fn$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$3_flow__$1_state$jscomp$766$$):this.$update_fn$($flow$jscomp$3_flow__$1_state$jscomp$766$$);return $flow$jscomp$3_flow__$1_state$jscomp$766$$!=null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($app$common$files$changes_builder$set_flow$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$it$jscomp$219_page$jscomp$91$$),this.$flow_id$,$flow$jscomp$3_flow__$1_state$jscomp$766$$))):null});return new $app$main$data$workspace$interactions$update_flow_70433$$($page_id$jscomp$211$$,$flow_id$jscomp$7$$,$update_fn$jscomp$31$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$interactions$remove_interaction$cljs$0core$0IFn$0_invoke$0arity$03$$=function($shape$jscomp$711$$,$index$jscomp$335$$){typeof $app$main$data$workspace$interactions$remove_interaction_70485$$==="undefined"&&($app$main$data$workspace$interactions$remove_interaction_70485$$=function($page_id$jscomp$217$$,$shape$jscomp$712$$,$index$jscomp$336$$,$meta70486$$){this.$page_id$=$page_id$jscomp$217$$;this.shape=$shape$jscomp$712$$;this.index=$index$jscomp$336$$;this.$meta70486$=
$meta70486$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$remove_interaction_70485$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$remove_interaction_70485$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4307$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_remove_interaction$$},$app$main$data$workspace$interactions$remove_interaction_70485$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70487$$,$meta70486__$1$$){return new $app$main$data$workspace$interactions$remove_interaction_70485$$(this.$page_id$,this.shape,this.index,$meta70486__$1$$)},$app$main$data$workspace$interactions$remove_interaction_70485$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70486$},$app$main$data$workspace$interactions$remove_interaction_70485$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$remove_interaction_70485$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$5723$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5723$$.shape)],null),function($shape__$1$jscomp$51$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape__$1$jscomp$51$$,$APP.$cljs$cst$2051$interactions$$,
$app$common$types$shape$interactions$remove_interaction$$,$self__$jscomp$5723$$.index)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2043$page_id$$,$self__$jscomp$5723$$.$page_id$],null)))});return new $app$main$data$workspace$interactions$remove_interaction_70485$$(null,$shape$jscomp$711$$,$index$jscomp$335$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$interactions$update_interaction$cljs$0core$0IFn$0_invoke$0arity$04$$=function($shape$jscomp$714$$,$index$jscomp$338$$,$update_fn$jscomp$34$$,$options$jscomp$569$$){typeof $app$main$data$workspace$interactions$update_interaction_70499$$==="undefined"&&($app$main$data$workspace$interactions$update_interaction_70499$$=function($shape$jscomp$715$$,$index$jscomp$339$$,$update_fn$jscomp$35$$,$options$jscomp$570$$,$meta70500$$){this.shape=$shape$jscomp$715$$;this.index=$index$jscomp$339$$;
this.$update_fn$=$update_fn$jscomp$35$$;this.options=$options$jscomp$570$$;this.$meta70500$=$meta70500$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$update_interaction_70499$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$update_interaction_70499$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4308$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_update_interaction$$},
$app$main$data$workspace$interactions$update_interaction_70499$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70501$$,$meta70500__$1$$){return new $app$main$data$workspace$interactions$update_interaction_70499$$(this.shape,this.index,this.$update_fn$,this.options,$meta70500__$1$$)},$app$main$data$workspace$interactions$update_interaction_70499$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70500$},$app$main$data$workspace$interactions$update_interaction_70499$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$update_interaction_70499$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$5727$$=this,$interaction$jscomp$40_interactions$jscomp$11$$=$app$common$types$shape$interactions$update_interaction$$($APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5727$$.shape),$self__$jscomp$5727$$.index,$self__$jscomp$5727$$.$update_fn$);$interaction$jscomp$40_interactions$jscomp$11$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($interaction$jscomp$40_interactions$jscomp$11$$,$self__$jscomp$5727$$.index);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5727$$.shape)],null),function($shape__$1$jscomp$52$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($shape__$1$jscomp$52$$,
$APP.$cljs$cst$2051$interactions$$,$app$common$types$shape$interactions$update_interaction$$,$self__$jscomp$5727$$.index,$self__$jscomp$5727$$.$update_fn$)},$self__$jscomp$5727$$.options),$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$40_interactions$jscomp$11$$)!=null?$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$40_interactions$jscomp$11$$)],
null),$APP.$app$common$logic$shapes$show_in_viewer$$,$self__$jscomp$5727$$.options):null)});return new $app$main$data$workspace$interactions$update_interaction_70499$$($shape$jscomp$714$$,$index$jscomp$338$$,$update_fn$jscomp$34$$,$options$jscomp$569$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$layers$calculate_opacity$$=function($e$jscomp$inline_7195_numbers$jscomp$1$$){var $JSCompiler_temp$jscomp$278_total$jscomp$13$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("",$e$jscomp$inline_7195_numbers$jscomp$1$$));$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$inline_7195_numbers$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[0],null))?$JSCompiler_temp$jscomp$278_total$jscomp$13$$=1:($e$jscomp$inline_7195_numbers$jscomp$1$$=$APP.$cljs$core$count$$($e$jscomp$inline_7195_numbers$jscomp$1$$),$JSCompiler_temp$jscomp$278_total$jscomp$13$$/=Math.pow(10,$e$jscomp$inline_7195_numbers$jscomp$1$$));return $JSCompiler_temp$jscomp$278_total$jscomp$13$$};
$app$main$data$workspace$layers$set_opacity$$=function($opacity$jscomp$32$$){typeof $app$main$data$workspace$layers$set_opacity_70535$$==="undefined"&&($app$main$data$workspace$layers$set_opacity_70535$$=function($opacity$jscomp$33$$,$meta70536$$){this.opacity=$opacity$jscomp$33$$;this.$meta70536$=$meta70536$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$layers$set_opacity_70535$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$layers$set_opacity_70535$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4321$app_DOT_main_DOT_data_DOT_workspace_DOT_layers_SLASH_set_opacity$$},$app$main$data$workspace$layers$set_opacity_70535$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70537$$,$meta70536__$1$$){return new $app$main$data$workspace$layers$set_opacity_70535$$(this.opacity,$meta70536__$1$$)},$app$main$data$workspace$layers$set_opacity_70535$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70536$},$app$main$data$workspace$layers$set_opacity_70535$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layers$set_opacity_70535$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2407_selected$jscomp$83_shapes$jscomp$115_shapes_ids$$,$state$jscomp$782$$){var $self__$jscomp$5763$$=this,$objects$jscomp$613$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$782$$);
$_$jscomp$2407_selected$jscomp$83_shapes$jscomp$115_shapes_ids$$=$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$782$$);$_$jscomp$2407_selected$jscomp$83_shapes$jscomp$115_shapes_ids$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70533_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$613$$,$p1__70533_SHARP_$$)},$_$jscomp$2407_selected$jscomp$83_shapes$jscomp$115_shapes_ids$$);$_$jscomp$2407_selected$jscomp$83_shapes$jscomp$115_shapes_ids$$=
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$_$jscomp$2407_selected$jscomp$83_shapes$jscomp$115_shapes_ids$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2407_selected$jscomp$83_shapes$jscomp$115_shapes_ids$$,function($p1__70534_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__70534_SHARP_$$,$APP.$cljs$cst$1734$opacity$$,$self__$jscomp$5763$$.opacity)}))});
return new $app$main$data$workspace$layers$set_opacity_70535$$($opacity$jscomp$32$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$mcp$finalize_workspace_QMARK_$$=function($event$jscomp$103$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$potok$v2$core$type$$($event$jscomp$103$$),$APP.$cljs$cst$4324$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize_workspace$$)};
$app$main$data$workspace$mcp$set_mcp_active$$=function($value$jscomp$598$$){typeof $app$main$data$workspace$mcp$set_mcp_active_70546$$==="undefined"&&($app$main$data$workspace$mcp$set_mcp_active_70546$$=function($value$jscomp$599$$,$meta70547$$){this.value=$value$jscomp$599$$;this.$meta70547$=$meta70547$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$mcp$set_mcp_active_70546$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$mcp$set_mcp_active_70546$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4325$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_set_mcp_active$$},$app$main$data$workspace$mcp$set_mcp_active_70546$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70548$$,$meta70547__$1$$){return new $app$main$data$workspace$mcp$set_mcp_active_70546$$(this.value,$meta70547__$1$$)},$app$main$data$workspace$mcp$set_mcp_active_70546$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70547$},$app$main$data$workspace$mcp$set_mcp_active_70546$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$set_mcp_active_70546$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2411$$,$state$jscomp$785$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$785$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1236$mcp$$,$cljs$cst$4326$active$$],
null),this.value)});return new $app$main$data$workspace$mcp$set_mcp_active_70546$$($value$jscomp$598$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$mcp$start_reconnect_watcher_BANG_$$=function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$mcp$set_mcp_active$$(!0));$APP.$cljs$core$_deref$$($app$main$data$workspace$mcp$interval_sub$$)==null&&$APP.$cljs$core$reset_BANG_$$($app$main$data$workspace$mcp$interval_sub$$,$APP.$app$util$timers$interval$$(1E4,function(){if($APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,["connected",null,"connecting",null],null),null),$APP.$cljs$cst$4327$connection_status$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1236$mcp$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))))return null;console.log("Reconnecting to MCP...");return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$4328$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_connect$$))}))};
$app$main$data$workspace$mcp$handle_pong$$=function($p__70565$$){var $map__70566__$1$$=$APP.$cljs$core$__destructure_map$$($p__70565$$),$id$jscomp$720$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70566__$1$$,$APP.$cljs$cst$266$id$$),$data$jscomp$387$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70566__$1$$,$APP.$cljs$cst$142$data$$);typeof $app$main$data$workspace$mcp$handle_pong_70567$$==="undefined"&&($app$main$data$workspace$mcp$handle_pong_70567$$=function($p__70565$jscomp$1$$,
$map__70566$jscomp$1$$,$id$jscomp$721$$,$data$jscomp$388$$,$meta70568$$){this.$p__70565$=$p__70565$jscomp$1$$;this.$map__70566$=$map__70566$jscomp$1$$;this.id=$id$jscomp$721$$;this.data=$data$jscomp$388$$;this.$meta70568$=$meta70568$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$mcp$handle_pong_70567$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$handle_pong_70567$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4329$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_handle_pong$$},$app$main$data$workspace$mcp$handle_pong_70567$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70569$$,$meta70568__$1$$){return new $app$main$data$workspace$mcp$handle_pong_70567$$(this.$p__70565$,this.$map__70566$,this.id,this.data,$meta70568__$1$$)},$app$main$data$workspace$mcp$handle_pong_70567$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70568$},$app$main$data$workspace$mcp$handle_pong_70567$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$handle_pong_70567$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2412_mcp_state$$,$state$jscomp$786$$){$_$jscomp$2412_mcp_state$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$786$$,$APP.$cljs$cst$1236$mcp$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("connected",$APP.$cljs$cst$4327$connection_status$$.$cljs$core$IFn$_invoke$arity$1$(this.data))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$786$$,
$APP.$cljs$cst$1236$mcp$$,$APP.$cljs$core$assoc$$,$cljs$cst$4330$connected_tab$$,this.id):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("disconnected",$APP.$cljs$cst$4327$connection_status$$.$cljs$core$IFn$_invoke$arity$1$(this.data))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.id,$cljs$cst$4330$connected_tab$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2412_mcp_state$$))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$786$$,$APP.$cljs$cst$1236$mcp$$,
$APP.$cljs$core$dissoc$$,$cljs$cst$4330$connected_tab$$):$state$jscomp$786$$},$app$main$data$workspace$mcp$handle_pong_70567$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$handle_pong_70567$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$mcp$manage_mcp_notification$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$workspace$mcp$manage_mcp_notification$$.$cljs$core$IFn$_invoke$arity$0$():
$app$main$data$workspace$mcp$manage_mcp_notification$$())});return new $app$main$data$workspace$mcp$handle_pong_70567$$($p__70565$$,$map__70566__$1$$,$id$jscomp$720$$,$data$jscomp$387$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$mcp$handle_ping$$=function(){typeof $app$main$data$workspace$mcp$handle_ping_70583$$==="undefined"&&($app$main$data$workspace$mcp$handle_ping_70583$$=function($meta70584$$){this.$meta70584$=$meta70584$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$mcp$handle_ping_70583$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$handle_ping_70583$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4331$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_handle_ping$$},$app$main$data$workspace$mcp$handle_ping_70583$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70585$$,$meta70584__$1$$){return new $app$main$data$workspace$mcp$handle_ping_70583$$($meta70584__$1$$)},$app$main$data$workspace$mcp$handle_ping_70583$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70584$},$app$main$data$workspace$mcp$handle_ping_70583$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$handle_ping_70583$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2414_conn_status$$,$state$jscomp$787$$){$_$jscomp$2414_conn_status$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$787$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1236$mcp$$,$APP.$cljs$cst$4327$connection_status$$],null));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$broadcast$event$$($cljs$cst$4332$mcp_SLASH_pong$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4327$connection_status$$,$_$jscomp$2414_conn_status$$],null)))});return new $app$main$data$workspace$mcp$handle_ping_70583$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$mcp$notify_other_tabs_disconnect$$=function(){typeof $app$main$data$workspace$mcp$notify_other_tabs_disconnect_70602$$==="undefined"&&($app$main$data$workspace$mcp$notify_other_tabs_disconnect_70602$$=function($meta70603$$){this.$meta70603$=$meta70603$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$mcp$notify_other_tabs_disconnect_70602$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$mcp$notify_other_tabs_disconnect_70602$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4333$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_notify_other_tabs_disconnect$$},$app$main$data$workspace$mcp$notify_other_tabs_disconnect_70602$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70604$$,$meta70603__$1$$){return new $app$main$data$workspace$mcp$notify_other_tabs_disconnect_70602$$($meta70603__$1$$)},$app$main$data$workspace$mcp$notify_other_tabs_disconnect_70602$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70603$},$app$main$data$workspace$mcp$notify_other_tabs_disconnect_70602$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$notify_other_tabs_disconnect_70602$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$broadcast$event$$($cljs$cst$4332$mcp_SLASH_pong$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4327$connection_status$$,"disconnected"],
null)))});return new $app$main$data$workspace$mcp$notify_other_tabs_disconnect_70602$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$mcp$update_mcp_status$$=function($value$jscomp$600$$){typeof $app$main$data$workspace$mcp$update_mcp_status_70613$$==="undefined"&&($app$main$data$workspace$mcp$update_mcp_status_70613$$=function($value$jscomp$601$$,$meta70614$$){this.value=$value$jscomp$601$$;this.$meta70614$=$meta70614$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$mcp$update_mcp_status_70613$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$mcp$update_mcp_status_70613$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4334$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_update_mcp_status$$},$app$main$data$workspace$mcp$update_mcp_status_70613$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70615$$,$meta70614__$1$$){return new $app$main$data$workspace$mcp$update_mcp_status_70613$$(this.value,$meta70614__$1$$)},$app$main$data$workspace$mcp$update_mcp_status_70613$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70614$},$app$main$data$workspace$mcp$update_mcp_status_70613$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$update_mcp_status_70613$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2416$$,$state$jscomp$788$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$788$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1914$profile$$,$APP.$cljs$cst$575$props$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4335$mcp_enabled$$,this.value)},$app$main$data$workspace$mcp$update_mcp_status_70613$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$update_mcp_status_70613$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $JSCompiler_temp_const$jscomp$1274$$=(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$mcp$manage_mcp_notification$$.$cljs$core$IFn$_invoke$arity$0$?
$app$main$data$workspace$mcp$manage_mcp_notification$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$workspace$mcp$manage_mcp_notification$$());var $G__70629$jscomp$inline_7197_JSCompiler_inline_result$jscomp$1275$$=this.value;$G__70629$jscomp$inline_7197_JSCompiler_inline_result$jscomp$1275$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!0,$G__70629$jscomp$inline_7197_JSCompiler_inline_result$jscomp$1275$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$4328$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_connect$$)):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!1,$G__70629$jscomp$inline_7197_JSCompiler_inline_result$jscomp$1275$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$4336$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_disconnect$$)):null;return $APP.$beicon$v2$core$merge$$($JSCompiler_temp_const$jscomp$1274$$,$G__70629$jscomp$inline_7197_JSCompiler_inline_result$jscomp$1275$$)});return new $app$main$data$workspace$mcp$update_mcp_status_70613$$($value$jscomp$600$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$mcp$update_mcp_connection_status$$=function($value$jscomp$602$$){typeof $app$main$data$workspace$mcp$update_mcp_plugin_connection_70632$$==="undefined"&&($app$main$data$workspace$mcp$update_mcp_plugin_connection_70632$$=function($value$jscomp$603$$,$meta70633$$){this.value=$value$jscomp$603$$;this.$meta70633$=$meta70633$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$mcp$update_mcp_plugin_connection_70632$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$mcp$update_mcp_plugin_connection_70632$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4337$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_update_mcp_plugin_connection$$},$app$main$data$workspace$mcp$update_mcp_plugin_connection_70632$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70634$$,$meta70633__$1$$){return new $app$main$data$workspace$mcp$update_mcp_plugin_connection_70632$$(this.value,$meta70633__$1$$)},$app$main$data$workspace$mcp$update_mcp_plugin_connection_70632$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70633$},$app$main$data$workspace$mcp$update_mcp_plugin_connection_70632$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$update_mcp_plugin_connection_70632$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2418$$,$state$jscomp$789$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$789$$,$APP.$cljs$cst$1236$mcp$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4327$connection_status$$,
this.value)},$app$main$data$workspace$mcp$update_mcp_plugin_connection_70632$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$update_mcp_plugin_connection_70632$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$mcp$manage_mcp_notification$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$workspace$mcp$manage_mcp_notification$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$workspace$mcp$manage_mcp_notification$$(),
$APP.$app$main$broadcast$event$$($cljs$cst$4332$mcp_SLASH_pong$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4327$connection_status$$,this.value],null)))});return new $app$main$data$workspace$mcp$update_mcp_plugin_connection_70632$$($value$jscomp$602$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$mcp$connect_mcp$$=function(){typeof $app$main$data$workspace$mcp$connect_mcp_70654$$==="undefined"&&($app$main$data$workspace$mcp$connect_mcp_70654$$=function($meta70655$$){this.$meta70655$=$meta70655$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$mcp$connect_mcp_70654$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$connect_mcp_70654$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4338$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_connect_mcp$$},$app$main$data$workspace$mcp$connect_mcp_70654$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70656$$,$meta70655__$1$$){return new $app$main$data$workspace$mcp$connect_mcp_70654$$($meta70655__$1$$)},$app$main$data$workspace$mcp$connect_mcp_70654$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70655$},$app$main$data$workspace$mcp$connect_mcp_70654$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$connect_mcp_70654$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2420$$,$state$jscomp$790$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$790$$,$APP.$cljs$cst$1236$mcp$$,$APP.$cljs$core$assoc$$,$cljs$cst$4330$connected_tab$$,$APP.$cljs$cst$2332$session_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$790$$))},$app$main$data$workspace$mcp$connect_mcp_70654$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$connect_mcp_70654$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$broadcast$event$$($cljs$cst$4339$mcp_SLASH_force_disconect$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$4328$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_connect$$))});return new $app$main$data$workspace$mcp$connect_mcp_70654$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$mcp$user_disconnect_mcp$$=function(){typeof $app$main$data$workspace$mcp$user_disconnect_mcp_70667$$==="undefined"&&($app$main$data$workspace$mcp$user_disconnect_mcp_70667$$=function($meta70668$$){this.$meta70668$=$meta70668$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$mcp$user_disconnect_mcp_70667$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$user_disconnect_mcp_70667$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4340$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_user_disconnect_mcp$$},$app$main$data$workspace$mcp$user_disconnect_mcp_70667$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70669$$,$meta70668__$1$$){return new $app$main$data$workspace$mcp$user_disconnect_mcp_70667$$($meta70668__$1$$)},$app$main$data$workspace$mcp$user_disconnect_mcp_70667$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70668$},$app$main$data$workspace$mcp$user_disconnect_mcp_70667$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$user_disconnect_mcp_70667$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$4336$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_disconnect$$),$app$main$data$workspace$mcp$update_mcp_connection_status$$("disconnected"))},$app$main$data$workspace$mcp$user_disconnect_mcp_70667$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$user_disconnect_mcp_70667$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$mcp$set_mcp_active$$(!1));if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($app$main$data$workspace$mcp$interval_sub$$))){$APP.$beicon$v2$core$dispose_BANG_$$($APP.$cljs$core$_deref$$($app$main$data$workspace$mcp$interval_sub$$));var $JSCompiler_inline_result$jscomp$1273$$=
$APP.$cljs$core$reset_BANG_$$($app$main$data$workspace$mcp$interval_sub$$,null)}else $JSCompiler_inline_result$jscomp$1273$$=null;return $JSCompiler_inline_result$jscomp$1273$$});return new $app$main$data$workspace$mcp$user_disconnect_mcp_70667$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$mcp$manage_mcp_notification$$=function(){typeof $app$main$data$workspace$mcp$manage_mcp_notification_70678$$==="undefined"&&($app$main$data$workspace$mcp$manage_mcp_notification_70678$$=function($meta70679$$){this.$meta70679$=$meta70679$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$mcp$manage_mcp_notification_70678$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$manage_mcp_notification_70678$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4341$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_manage_mcp_notification$$},$app$main$data$workspace$mcp$manage_mcp_notification_70678$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70680$$,$meta70679__$1$$){return new $app$main$data$workspace$mcp$manage_mcp_notification_70678$$($meta70679__$1$$)},$app$main$data$workspace$mcp$manage_mcp_notification_70678$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70679$},$app$main$data$workspace$mcp$manage_mcp_notification_70678$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$manage_mcp_notification_70678$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2424_mcp_enabled_QMARK_$$,$current_tab_id_state$jscomp$791$$){var $connected_tab_id_mcp_state$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_tab_id_state$jscomp$791$$,$APP.$cljs$cst$1236$mcp$$);$_$jscomp$2424_mcp_enabled_QMARK_$$=$APP.$cljs$cst$4335$mcp_enabled$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1914$profile$$.$cljs$core$IFn$_invoke$arity$1$($current_tab_id_state$jscomp$791$$)));
$current_tab_id_state$jscomp$791$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_tab_id_state$jscomp$791$$,$APP.$cljs$cst$2332$session_id$$);$connected_tab_id_mcp_state$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($connected_tab_id_mcp_state$jscomp$1$$,$cljs$cst$4330$connected_tab$$);return $APP.$cljs$core$truth_$$($_$jscomp$2424_mcp_enabled_QMARK_$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($connected_tab_id_mcp_state$jscomp$1$$,$current_tab_id_state$jscomp$791$$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$hide$$()):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$dialog$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("notifications.mcp.active-in-another-tab"),$APP.$cljs$cst$2355$cancel$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.dismiss"),$APP.$cljs$cst$2354$callback$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"dismiss-mcp-tab-switch",
$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-notification"],null))]))}],null),$APP.$cljs$cst$924$accept$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.switch"),$APP.$cljs$cst$2354$callback$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$mcp$connect_mcp$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"confirm-mcp-tab-switch",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-notification"],null))]))}],null)],null)]))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$hide$$())});return new $app$main$data$workspace$mcp$manage_mcp_notification_70678$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$mcp$init_mcp$$=function($stream$jscomp$88$$){return $APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($map__70705__$1_p__70704_token$jscomp$67$$){$map__70705__$1_p__70704_token$jscomp$67$$=$APP.$cljs$core$__destructure_map$$($map__70705__$1_p__70704_token$jscomp$67$$);$map__70705__$1_p__70704_token$jscomp$67$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70705__$1_p__70704_token$jscomp$67$$,$APP.$cljs$cst$1136$token$$);
return $APP.$cljs$core$truth_$$($map__70705__$1_p__70704_token$jscomp$67$$)?$app$main$data$plugins$start_plugin_BANG_$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$mcp$default_manifest$$,$APP.$cljs$cst$1975$url$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"plugins/mcp/manifest.json"]))),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$744$host$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"plugins/mcp/"])))])),{mcp:{getToken:$APP.$cljs$core$constantly$$($map__70705__$1_p__70704_token$jscomp$67$$),getServerUrl:function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$config$mcp_ws_uri$$)},
setMcpStatus:function($status$jscomp$16$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($status$jscomp$16$$,"connected")&&$app$main$data$workspace$mcp$start_reconnect_watcher_BANG_$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$mcp$update_mcp_connection_status$$($status$jscomp$16$$));$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.mcp",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"MCP STATUS"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$109$status$$,$status$jscomp$16$$],null)],null)}),null,"app.main.data.workspace.mcp",$APP.$cljs$cst$1161$info$$,!1);return null},on:function($event$jscomp$104$$,$cb$jscomp$13$$){var $temp__5825__auto__$jscomp$222$$=
function(){switch($event$jscomp$104$$){case "disconnect":return $cljs$cst$4336$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_disconnect$$;case "connect":return $cljs$cst$4328$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_connect$$;default:return null}}();if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$222$$)){var $stopper$jscomp$34$$=$APP.$beicon$v2$core$filter$$($app$main$data$workspace$mcp$finalize_workspace_QMARK_$$,$stream$jscomp$88$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $cb$jscomp$13$$.$cljs$core$IFn$_invoke$arity$0$?
$cb$jscomp$13$$.$cljs$core$IFn$_invoke$arity$0$():$cb$jscomp$13$$()},$APP.$beicon$v2$core$take_until$$($stopper$jscomp$34$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($temp__5825__auto__$jscomp$222$$),$stream$jscomp$88$$)))}return null}}}):null},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$4342$get_current_mcp_token$$)))};
$app$main$data$workspace$notifications$initialize$$=function($team_id$jscomp$79$$,$file_id$jscomp$224$$){typeof $app$main$data$workspace$notifications$initialize_70587$$==="undefined"&&($app$main$data$workspace$notifications$initialize_70587$$=function($team_id$jscomp$80$$,$file_id$jscomp$225$$,$meta70588$$){this.$team_id$=$team_id$jscomp$80$$;this.$file_id$=$file_id$jscomp$225$$;this.$meta70588$=$meta70588$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$notifications$initialize_70587$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$initialize_70587$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4347$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_initialize$$},$app$main$data$workspace$notifications$initialize_70587$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70589$$,$meta70588__$1$$){return new $app$main$data$workspace$notifications$initialize_70587$$(this.$team_id$,
this.$file_id$,$meta70588__$1$$)},$app$main$data$workspace$notifications$initialize_70587$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70588$},$app$main$data$workspace$notifications$initialize_70587$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$initialize_70587$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2427_endmsg$$,$state$jscomp$794$$,$stream$jscomp$90_stream__$1$$){var $self__$jscomp$5819$$=
this,$stopper$jscomp$35$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4348$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_finalize$$),$stream$jscomp$90_stream__$1$$),$profile_id$jscomp$11$$=$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$794$$),$initmsg$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$cljs$cst$4349$subscribe_file$$,$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$5819$$.$file_id$,$APP.$cljs$cst$2289$version$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"penpotVersion")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$4350$subscribe_team$$,$APP.$cljs$cst$1927$team_id$$,$self__$jscomp$5819$$.$team_id$],null)],null);$_$jscomp$2427_endmsg$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$cljs$cst$4351$unsubscribe_file$$,$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$5819$$.$file_id$],null);$stream$jscomp$90_stream__$1$$=$APP.$beicon$v2$core$take_until$$($stopper$jscomp$35$$,$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$($app$main$data$websocket$send$$,$APP.$beicon$v2$core$from$$($initmsg$$)),$APP.$beicon$v2$core$map$$($app$main$data$workspace$notifications$process_message$$,$APP.$beicon$v2$core$filter$$(function($map__70606__$1_p__70605_topic$$){$map__70606__$1_p__70605_topic$$=
$APP.$cljs$core$__destructure_map$$($map__70606__$1_p__70605_topic$$);$map__70606__$1_p__70605_topic$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70606__$1_p__70605_topic$$,$APP.$cljs$cst$4352$topic$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__70606__$1_p__70605_topic$$,$APP.$app$common$uuid$zero$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__70606__$1_p__70605_topic$$,$profile_id$jscomp$11$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__70606__$1_p__70605_topic$$,
$self__$jscomp$5819$$.$team_id$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__70606__$1_p__70605_topic$$,$self__$jscomp$5819$$.$file_id$)},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3338$app_DOT_main_DOT_data_DOT_websocket_SLASH_message$$),$stream$jscomp$90_stream__$1$$)))),$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$beicon$v2$core$map$$($app$main$data$websocket$send$$,
$APP.$beicon$v2$core$from$$($initmsg$$))},$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3339$app_DOT_main_DOT_data_DOT_websocket_SLASH_opened$$),$stream$jscomp$90_stream__$1$$)),(0,$APP.$beicon$v2$core$of$$)(function(){var $G__70610$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$4353$connect$$,$APP.$cljs$cst$2332$session_id$$,$APP.$cljs$cst$2332$session_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$794$$),
$APP.$cljs$cst$2313$profile_id$$,$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$794$$)],null);return $app$main$data$workspace$notifications$handle_presence$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$notifications$handle_presence$$.$cljs$core$IFn$_invoke$arity$1$($G__70610$$):$app$main$data$workspace$notifications$handle_presence$$($G__70610$$)}()),$APP.$beicon$v2$core$map$$(function($G__70612_p1__70582_SHARP_$$){var $G__70611$$=$self__$jscomp$5819$$.$file_id$;
$G__70612_p1__70582_SHARP_$$=$APP.$cljs$cst$2159$pt$$.$cljs$core$IFn$_invoke$arity$1$($G__70612_p1__70582_SHARP_$$);return $app$main$data$workspace$notifications$handle_pointer_send$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$data$workspace$notifications$handle_pointer_send$$.$cljs$core$IFn$_invoke$arity$2$($G__70611$$,$G__70612_p1__70582_SHARP_$$):$app$main$data$workspace$notifications$handle_pointer_send$$($G__70611$$,$G__70612_p1__70582_SHARP_$$)},$APP.$beicon$v2$operators$pipe$$($app$util$rxops$throttle$$(),
$APP.$beicon$v2$core$filter$$(function($p1__70581_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2170$viewport$$,$p1__70581_SHARP_$$.source)},$APP.$beicon$v2$core$filter$$($APP.$app$util$mouse$pointer_event_QMARK_$$,$stream$jscomp$90_stream__$1$$))))));return $APP.$beicon$v2$core$concat$$($stream$jscomp$90_stream__$1$$,(0,$APP.$beicon$v2$core$of$$)($app$main$data$websocket$send$$($_$jscomp$2427_endmsg$$)))});return new $app$main$data$workspace$notifications$initialize_70587$$($team_id$jscomp$79$$,
$file_id$jscomp$224$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$notifications$handle_change_team_role$$=function($p__70618$$){var $map__70619__$1$$=$APP.$cljs$core$__destructure_map$$($p__70618$$),$role$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70619__$1$$,$APP.$cljs$cst$2490$role$$);typeof $app$main$data$workspace$notifications$handle_change_team_role_70620$$==="undefined"&&($app$main$data$workspace$notifications$handle_change_team_role_70620$$=function($p__70618$jscomp$1$$,$map__70619$jscomp$1$$,$msg$jscomp$33$$,
$role$jscomp$12$$,$meta70621$$){this.$p__70618$=$p__70618$jscomp$1$$;this.$map__70619$=$map__70619$jscomp$1$$;this.$msg$=$msg$jscomp$33$$;this.role=$role$jscomp$12$$;this.$meta70621$=$meta70621$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$notifications$handle_change_team_role_70620$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_change_team_role_70620$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4354$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_change_team_role$$},$app$main$data$workspace$notifications$handle_change_team_role_70620$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70622$$,$meta70621__$1$$){return new $app$main$data$workspace$notifications$handle_change_team_role_70620$$(this.$p__70618$,this.$map__70619$,this.$msg$,this.role,$meta70621__$1$$)},$app$main$data$workspace$notifications$handle_change_team_role_70620$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70621$},$app$main$data$workspace$notifications$handle_change_team_role_70620$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_change_team_role_70620$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2169$interrupt$$,$APP.$app$main$data$workspace$edition$clear_edition_mode$$(),$APP.$app$main$data$workspace$common$set_workspace_read_only$$(!1)),
$APP.$beicon$v2$core$delay$$(100,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$change_team_role$$(this.$msg$),$cljs$cst$4004$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_editor_state$$)),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1592$viewer$$,this.role)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$modal$hide$$(),$APP.$app$main$data$workspace$layout$set_options_mode$$($APP.$cljs$cst$2672$inspect$$),$app$main$data$plugins$close_current_plugin$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$3403$close_only_edition_plugins_QMARK_$$,!0],null)]))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$layout$set_options_mode$$($APP.$cljs$cst$3732$design$$)))});return new $app$main$data$workspace$notifications$handle_change_team_role_70620$$($p__70618$$,$map__70619__$1$$,$map__70619__$1$$,$role$jscomp$11$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$notifications$process_message$$=function($map__70648__$1_p__70647$$){$map__70648__$1_p__70647$$=$APP.$cljs$core$__destructure_map$$($map__70648__$1_p__70647$$);var $G__70649$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70648__$1_p__70647$$,$APP.$cljs$cst$139$type$$);switch($G__70649$$ instanceof $APP.$cljs$core$Keyword$$?$G__70649$$.$fqn$:null){case "join-file":return $app$main$data$workspace$notifications$handle_presence$$.$cljs$core$IFn$_invoke$arity$1$?
$app$main$data$workspace$notifications$handle_presence$$.$cljs$core$IFn$_invoke$arity$1$($map__70648__$1_p__70647$$):$app$main$data$workspace$notifications$handle_presence$$($map__70648__$1_p__70647$$);case "leave-file":return $app$main$data$workspace$notifications$handle_presence$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$notifications$handle_presence$$.$cljs$core$IFn$_invoke$arity$1$($map__70648__$1_p__70647$$):$app$main$data$workspace$notifications$handle_presence$$($map__70648__$1_p__70647$$);
case "presence":return $app$main$data$workspace$notifications$handle_presence$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$notifications$handle_presence$$.$cljs$core$IFn$_invoke$arity$1$($map__70648__$1_p__70647$$):$app$main$data$workspace$notifications$handle_presence$$($map__70648__$1_p__70647$$);case "disconnect":return $app$main$data$workspace$notifications$handle_presence$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$notifications$handle_presence$$.$cljs$core$IFn$_invoke$arity$1$($map__70648__$1_p__70647$$):
$app$main$data$workspace$notifications$handle_presence$$($map__70648__$1_p__70647$$);case "pointer-update":return $app$main$data$workspace$notifications$handle_pointer_update$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$notifications$handle_pointer_update$$.$cljs$core$IFn$_invoke$arity$1$($map__70648__$1_p__70647$$):$app$main$data$workspace$notifications$handle_pointer_update$$($map__70648__$1_p__70647$$);case "file-change":return $app$main$data$workspace$notifications$handle_file_change$$.$cljs$core$IFn$_invoke$arity$1$?
$app$main$data$workspace$notifications$handle_file_change$$.$cljs$core$IFn$_invoke$arity$1$($map__70648__$1_p__70647$$):$app$main$data$workspace$notifications$handle_file_change$$($map__70648__$1_p__70647$$);case "file-deleted":return $app$main$data$workspace$notifications$handle_file_deleted$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$notifications$handle_file_deleted$$.$cljs$core$IFn$_invoke$arity$1$($map__70648__$1_p__70647$$):$app$main$data$workspace$notifications$handle_file_deleted$$($map__70648__$1_p__70647$$);
case "file-restored":return $app$main$data$workspace$notifications$handle_file_restored$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$notifications$handle_file_restored$$.$cljs$core$IFn$_invoke$arity$1$($map__70648__$1_p__70647$$):$app$main$data$workspace$notifications$handle_file_restored$$($map__70648__$1_p__70647$$);case "library-change":return $app$main$data$workspace$notifications$handle_library_change$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$notifications$handle_library_change$$.$cljs$core$IFn$_invoke$arity$1$($map__70648__$1_p__70647$$):
$app$main$data$workspace$notifications$handle_library_change$$($map__70648__$1_p__70647$$);case "notification":return $APP.$app$main$data$common$handle_notification$$($map__70648__$1_p__70647$$);case "team-role-change":return $app$main$data$workspace$notifications$handle_change_team_role$$($map__70648__$1_p__70647$$);case "team-membership-change":return $APP.$app$main$data$common$team_membership_change$$($map__70648__$1_p__70647$$);default:return null}};
$app$main$data$workspace$notifications$handle_pointer_send$$=function($file_id$jscomp$226$$,$point$jscomp$77$$){typeof $app$main$data$workspace$notifications$handle_pointer_send_70657$$==="undefined"&&($app$main$data$workspace$notifications$handle_pointer_send_70657$$=function($file_id$jscomp$227$$,$point$jscomp$78$$,$meta70658$$){this.$file_id$=$file_id$jscomp$227$$;this.point=$point$jscomp$78$$;this.$meta70658$=$meta70658$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$notifications$handle_pointer_send_70657$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_pointer_send_70657$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2142$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_pointer_send$$},$app$main$data$workspace$notifications$handle_pointer_send_70657$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70659$$,
$meta70658__$1$$){return new $app$main$data$workspace$notifications$handle_pointer_send_70657$$(this.$file_id$,this.point,$meta70658__$1$$)},$app$main$data$workspace$notifications$handle_pointer_send_70657$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70658$},$app$main$data$workspace$notifications$handle_pointer_send_70657$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_pointer_send_70657$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2429_page_id$jscomp$221$$,$local$jscomp$12_message$jscomp$99_state$jscomp$795$$){$_$jscomp$2429_page_id$jscomp$221$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$12_message$jscomp$99_state$jscomp$795$$);$local$jscomp$12_message$jscomp$99_state$jscomp$795$$=$APP.$cljs$cst$1920$workspace_local$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$12_message$jscomp$99_state$jscomp$795$$);$local$jscomp$12_message$jscomp$99_state$jscomp$795$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
8,[$APP.$cljs$cst$139$type$$,$cljs$cst$4355$pointer_update$$,$APP.$cljs$cst$1644$file_id$$,this.$file_id$,$APP.$cljs$cst$2043$page_id$$,$_$jscomp$2429_page_id$jscomp$221$$,$APP.$cljs$cst$2196$zoom$$,$APP.$cljs$cst$2196$zoom$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$12_message$jscomp$99_state$jscomp$795$$),$APP.$cljs$cst$3577$zoom_inverse$$,$APP.$cljs$cst$3577$zoom_inverse$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$12_message$jscomp$99_state$jscomp$795$$),$APP.$cljs$cst$1925$vbox$$,$APP.$cljs$cst$1925$vbox$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$12_message$jscomp$99_state$jscomp$795$$),
$APP.$cljs$cst$2203$vport$$,$APP.$cljs$cst$2203$vport$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$12_message$jscomp$99_state$jscomp$795$$),$APP.$cljs$cst$1676$position$$,this.point],null);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$websocket$send$$($local$jscomp$12_message$jscomp$99_state$jscomp$795$$))});return new $app$main$data$workspace$notifications$handle_pointer_send_70657$$($file_id$jscomp$226$$,$point$jscomp$77$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$notifications$handle_presence$$=function($p__70675$$){function $update_session$$($session$jscomp$1$$,$presence$jscomp$2$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($session$jscomp$1$$,
$APP.$cljs$cst$266$id$$,$session_id$jscomp$8$$),$APP.$cljs$cst$2313$profile_id$$,$profile_id$jscomp$12$$),$APP.$cljs$cst$3410$updated_at$$,$APP.$app$common$time$now$$()),$APP.$cljs$cst$2289$version$$,$version$jscomp$19$$),$APP.$cljs$cst$1298$color$$,$update_color$jscomp$2$$,$presence$jscomp$2$$),$cljs$cst$4356$text_color$$,"#000000")}function $update_color$jscomp$2$$($color$jscomp$105$$,$presence$jscomp$1$$){return $color$jscomp$105$$!=null?$color$jscomp$105$$:$get_next_color$$($presence$jscomp$1$$)}
function $get_next_color$$($avail_or__5025__auto__$jscomp$831_presence_used$jscomp$4$$){var $xfm$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1298$color$$),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nil_QMARK_$$));$avail_or__5025__auto__$jscomp$831_presence_used$jscomp$4$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$xfm$$,$avail_or__5025__auto__$jscomp$831_presence_used$jscomp$4$$);$avail_or__5025__auto__$jscomp$831_presence_used$jscomp$4$$=$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$notifications$presence_palette$$,$avail_or__5025__auto__$jscomp$831_presence_used$jscomp$4$$);$avail_or__5025__auto__$jscomp$831_presence_used$jscomp$4$$=$APP.$cljs$core$first$$($avail_or__5025__auto__$jscomp$831_presence_used$jscomp$4$$);return $APP.$cljs$core$truth_$$($avail_or__5025__auto__$jscomp$831_presence_used$jscomp$4$$)?
$avail_or__5025__auto__$jscomp$831_presence_used$jscomp$4$$:"#dee563"}var $map__70676__$1$$=$APP.$cljs$core$__destructure_map$$($p__70675$$),$type$jscomp$505$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70676__$1$$,$APP.$cljs$cst$139$type$$),$session_id$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70676__$1$$,$APP.$cljs$cst$2332$session_id$$),$profile_id$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70676__$1$$,$APP.$cljs$cst$2313$profile_id$$),
$version$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70676__$1$$,$APP.$cljs$cst$2289$version$$);typeof $app$main$data$workspace$notifications$handle_presence_70690$$==="undefined"&&($app$main$data$workspace$notifications$handle_presence_70690$$=function($version$jscomp$20$$,$update_color$jscomp$3$$,$message$jscomp$101$$,$session_id$jscomp$9$$,$map__70676$jscomp$1$$,$get_next_color$jscomp$1$$,$p__70675$jscomp$1$$,$update_session$jscomp$1$$,$type$jscomp$506$$,$profile_id$jscomp$13$$,
$update_presence$jscomp$1$$,$meta70691$$){this.version=$version$jscomp$20$$;this.$update_color$=$update_color$jscomp$3$$;this.message=$message$jscomp$101$$;this.$session_id$=$session_id$jscomp$9$$;this.$map__70676$=$map__70676$jscomp$1$$;this.$get_next_color$=$get_next_color$jscomp$1$$;this.$p__70675$=$p__70675$jscomp$1$$;this.$update_session$=$update_session$jscomp$1$$;this.type=$type$jscomp$506$$;this.$profile_id$=$profile_id$jscomp$13$$;this.$update_presence$=$update_presence$jscomp$1$$;this.$meta70691$=
$meta70691$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$notifications$handle_presence_70690$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_presence_70690$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4357$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_presence$$},$app$main$data$workspace$notifications$handle_presence_70690$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70692$$,$meta70691__$1$$){return new $app$main$data$workspace$notifications$handle_presence_70690$$(this.version,this.$update_color$,this.message,this.$session_id$,this.$map__70676$,this.$get_next_color$,this.$p__70675$,this.$update_session$,this.type,this.$profile_id$,this.$update_presence$,$meta70691__$1$$)},$app$main$data$workspace$notifications$handle_presence_70690$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70691$},$app$main$data$workspace$notifications$handle_presence_70690$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_presence_70690$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2432$$,$state$jscomp$796$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$4358$disconnect$$,this.type)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$4359$leave_file$$,this.type)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$796$$,$APP.$cljs$cst$2216$workspace_presence$$,
$APP.$cljs$core$dissoc$$,this.$session_id$):$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$796$$,$APP.$cljs$cst$2216$workspace_presence$$,this.$update_presence$)});return new $app$main$data$workspace$notifications$handle_presence_70690$$($version$jscomp$19$$,$update_color$jscomp$2$$,$map__70676__$1$$,$session_id$jscomp$8$$,$map__70676__$1$$,$get_next_color$$,$p__70675$$,$update_session$$,$type$jscomp$505$$,$profile_id$jscomp$12$$,function($presence$jscomp$3$$){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($presence$jscomp$3$$,
$session_id$jscomp$8$$,$update_session$$,$presence$jscomp$3$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$notifications$handle_pointer_update$$=function($p__70702$$){var $map__70703__$1$$=$APP.$cljs$core$__destructure_map$$($p__70702$$),$page_id$jscomp$222$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70703__$1$$,$APP.$cljs$cst$2043$page_id$$),$session_id$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70703__$1$$,$APP.$cljs$cst$2332$session_id$$),$position$jscomp$155$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70703__$1$$,
$APP.$cljs$cst$1676$position$$),$zoom$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70703__$1$$,$APP.$cljs$cst$2196$zoom$$),$zoom_inverse$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70703__$1$$,$APP.$cljs$cst$3577$zoom_inverse$$),$vbox$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70703__$1$$,$APP.$cljs$cst$1925$vbox$$),$vport$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70703__$1$$,$APP.$cljs$cst$2203$vport$$);
typeof $app$main$data$workspace$notifications$handle_pointer_update_70709$$==="undefined"&&($app$main$data$workspace$notifications$handle_pointer_update_70709$$=function($zoom_inverse$jscomp$1$$,$session_id$jscomp$11$$,$zoom$jscomp$37$$,$vbox$jscomp$23$$,$p__70702$jscomp$1$$,$msg$jscomp$36$$,$map__70703$jscomp$1$$,$page_id$jscomp$223$$,$vport$jscomp$4$$,$position$jscomp$156$$,$meta70710$$){this.$zoom_inverse$=$zoom_inverse$jscomp$1$$;this.$session_id$=$session_id$jscomp$11$$;this.zoom=$zoom$jscomp$37$$;
this.vbox=$vbox$jscomp$23$$;this.$p__70702$=$p__70702$jscomp$1$$;this.$msg$=$msg$jscomp$36$$;this.$map__70703$=$map__70703$jscomp$1$$;this.$page_id$=$page_id$jscomp$223$$;this.vport=$vport$jscomp$4$$;this.position=$position$jscomp$156$$;this.$meta70710$=$meta70710$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$notifications$handle_pointer_update_70709$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$notifications$handle_pointer_update_70709$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2140$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_pointer_update$$},$app$main$data$workspace$notifications$handle_pointer_update_70709$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70711$$,$meta70710__$1$$){return new $app$main$data$workspace$notifications$handle_pointer_update_70709$$(this.$zoom_inverse$,this.$session_id$,
this.zoom,this.vbox,this.$p__70702$,this.$msg$,this.$map__70703$,this.$page_id$,this.vport,this.position,$meta70710__$1$$)},$app$main$data$workspace$notifications$handle_pointer_update_70709$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70710$},$app$main$data$workspace$notifications$handle_pointer_update_70709$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_pointer_update_70709$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2433$$,$state$jscomp$797$$){var $self__$jscomp$5838$$=this;return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$797$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2216$workspace_presence$$,$self__$jscomp$5838$$.$session_id$],null),function($session$jscomp$2$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($session$jscomp$2$$,$APP.$cljs$cst$2196$zoom$$,$self__$jscomp$5838$$.zoom,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3577$zoom_inverse$$,$self__$jscomp$5838$$.$zoom_inverse$,$APP.$cljs$cst$1925$vbox$$,$self__$jscomp$5838$$.vbox,$APP.$cljs$cst$2203$vport$$,$self__$jscomp$5838$$.vport,$APP.$cljs$cst$2163$point$$,$self__$jscomp$5838$$.position,$APP.$cljs$cst$3410$updated_at$$,$APP.$app$common$time$now$$(),$APP.$cljs$cst$2043$page_id$$,$self__$jscomp$5838$$.$page_id$]))})});return new $app$main$data$workspace$notifications$handle_pointer_update_70709$$($zoom_inverse$$,
$session_id$jscomp$10$$,$zoom$jscomp$36$$,$vbox$jscomp$22$$,$p__70702$$,$map__70703__$1$$,$map__70703__$1$$,$page_id$jscomp$222$$,$vport$jscomp$3$$,$position$jscomp$155$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$notifications$handle_file_change$$=function($p__70730$$){var $map__70733__$1$$=$APP.$cljs$core$__destructure_map$$($p__70730$$),$file_id$jscomp$228$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70733__$1$$,$APP.$cljs$cst$1644$file_id$$),$changes$jscomp$241$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70733__$1$$,$APP.$cljs$cst$3131$changes$$),$revn$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70733__$1$$,$APP.$cljs$cst$2270$revn$$),
$vern$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70733__$1$$,$APP.$cljs$cst$2577$vern$$);typeof $app$main$data$workspace$notifications$handle_file_change_70736$$==="undefined"&&($app$main$data$workspace$notifications$handle_file_change_70736$$=function($p__70730$jscomp$1$$,$map__70733$jscomp$1$$,$msg$jscomp$38$$,$file_id$jscomp$229$$,$changes$jscomp$242$$,$revn$jscomp$7$$,$vern$jscomp$1$$,$meta70737$$){this.$p__70730$=$p__70730$jscomp$1$$;this.$map__70733$=$map__70733$jscomp$1$$;
this.$msg$=$msg$jscomp$38$$;this.$file_id$=$file_id$jscomp$229$$;this.$changes$=$changes$jscomp$242$$;this.$revn$=$revn$jscomp$7$$;this.$vern$=$vern$jscomp$1$$;this.$meta70737$=$meta70737$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$notifications$handle_file_change_70736$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_file_change_70736$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4360$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_file_change$$},$app$main$data$workspace$notifications$handle_file_change_70736$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70738$$,$meta70737__$1$$){return new $app$main$data$workspace$notifications$handle_file_change_70736$$(this.$p__70730$,this.$map__70733$,this.$msg$,this.$file_id$,this.$changes$,this.$revn$,this.$vern$,$meta70737__$1$$)},$app$main$data$workspace$notifications$handle_file_change_70736$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70737$},$app$main$data$workspace$notifications$handle_file_change_70736$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3131$changes$$,this.$changes$],null)},$app$main$data$workspace$notifications$handle_file_change_70736$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_file_change_70736$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$changes$commit$$(new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1644$file_id$$,this.$file_id$,$APP.$cljs$cst$3139$file_revn$$,this.$revn$,$APP.$cljs$cst$3143$file_vern$$,this.$vern$,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!1,$APP.$cljs$cst$193$source$$,$APP.$cljs$cst$3164$remote$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$vec$$(this.$changes$),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$],
null)))});return new $app$main$data$workspace$notifications$handle_file_change_70736$$($p__70730$$,$map__70733__$1$$,$map__70733__$1$$,$file_id$jscomp$228$$,$changes$jscomp$241$$,$revn$jscomp$6$$,$vern$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$notifications$handle_file_deleted$$=function($p__70761$$){var $map__70762__$1$$=$APP.$cljs$core$__destructure_map$$($p__70761$$),$file_id$jscomp$230$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70762__$1$$,$APP.$cljs$cst$1644$file_id$$);typeof $app$main$data$workspace$notifications$handle_file_deleted_70766$$==="undefined"&&($app$main$data$workspace$notifications$handle_file_deleted_70766$$=function($p__70761$jscomp$1$$,$map__70762$jscomp$1$$,$msg$jscomp$40$$,
$file_id$jscomp$231$$,$meta70767$$){this.$p__70761$=$p__70761$jscomp$1$$;this.$map__70762$=$map__70762$jscomp$1$$;this.$msg$=$msg$jscomp$40$$;this.$file_id$=$file_id$jscomp$231$$;this.$meta70767$=$meta70767$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$notifications$handle_file_deleted_70766$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_file_deleted_70766$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4361$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_file_deleted$$},$app$main$data$workspace$notifications$handle_file_deleted_70766$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70768$$,$meta70767__$1$$){return new $app$main$data$workspace$notifications$handle_file_deleted_70766$$(this.$p__70761$,this.$map__70762$,this.$msg$,this.$file_id$,$meta70767__$1$$)},$app$main$data$workspace$notifications$handle_file_deleted_70766$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70767$},$app$main$data$workspace$notifications$handle_file_deleted_70766$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_file_deleted_70766$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2436_curr_file_id$$,$state$jscomp$798_team_id$jscomp$81$$){$_$jscomp$2436_curr_file_id$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$798_team_id$jscomp$81$$);
$state$jscomp$798_team_id$jscomp$81$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$798_team_id$jscomp$81$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$file_id$,$_$jscomp$2436_curr_file_id$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2522$dashboard_recent$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1927$team_id$$,$state$jscomp$798_team_id$jscomp$81$$],
null))):null});return new $app$main$data$workspace$notifications$handle_file_deleted_70766$$($p__70761$$,$map__70762__$1$$,$map__70762__$1$$,$file_id$jscomp$230$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$notifications$handle_file_restored$$=function($p__70784$$){var $map__70785__$1$$=$APP.$cljs$core$__destructure_map$$($p__70784$$),$file_id$jscomp$232$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70785__$1$$,$APP.$cljs$cst$1644$file_id$$),$vern$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70785__$1$$,$APP.$cljs$cst$2577$vern$$);typeof $app$main$data$workspace$notifications$handle_file_restored_70786$$==="undefined"&&($app$main$data$workspace$notifications$handle_file_restored_70786$$=
function($p__70784$jscomp$1$$,$map__70785$jscomp$1$$,$msg$jscomp$42$$,$file_id$jscomp$233$$,$vern$jscomp$3$$,$meta70787$$){this.$p__70784$=$p__70784$jscomp$1$$;this.$map__70785$=$map__70785$jscomp$1$$;this.$msg$=$msg$jscomp$42$$;this.$file_id$=$file_id$jscomp$233$$;this.$vern$=$vern$jscomp$3$$;this.$meta70787$=$meta70787$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$notifications$handle_file_restored_70786$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_file_restored_70786$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4362$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_file_restored$$},$app$main$data$workspace$notifications$handle_file_restored_70786$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70788$$,$meta70787__$1$$){return new $app$main$data$workspace$notifications$handle_file_restored_70786$$(this.$p__70784$,
this.$map__70785$,this.$msg$,this.$file_id$,this.$vern$,$meta70787__$1$$)},$app$main$data$workspace$notifications$handle_file_restored_70786$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70787$},$app$main$data$workspace$notifications$handle_file_restored_70786$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_file_restored_70786$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2437_curr_file_id$jscomp$1$$,
$curr_vern_file$jscomp$73_state$jscomp$799$$){$_$jscomp$2437_curr_file_id$jscomp$1$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($curr_vern_file$jscomp$73_state$jscomp$799$$);$curr_vern_file$jscomp$73_state$jscomp$799$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$02$$($curr_vern_file$jscomp$73_state$jscomp$799$$,$_$jscomp$2437_curr_file_id$jscomp$1$$);$curr_vern_file$jscomp$73_state$jscomp$799$$=$APP.$cljs$cst$2577$vern$$.$cljs$core$IFn$_invoke$arity$1$($curr_vern_file$jscomp$73_state$jscomp$799$$);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$file_id$,$_$jscomp$2437_curr_file_id$jscomp$1$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$vern$,$curr_vern_file$jscomp$73_state$jscomp$799$$)?(0,$APP.$beicon$v2$core$of$$)($potok$v2$core$resolve$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3370$app_DOT_main_DOT_data_DOT_workspace_SLASH_reload_current_file$$,null)):null});return new $app$main$data$workspace$notifications$handle_file_restored_70786$$($p__70784$$,
$map__70785__$1$$,$map__70785__$1$$,$file_id$jscomp$232$$,$vern$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$notifications$handle_library_change$$=function($p__70825$$){var $map__70826__$1$$=$APP.$cljs$core$__destructure_map$$($p__70825$$),$file_id$jscomp$234$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70826__$1$$,$APP.$cljs$cst$1644$file_id$$),$modified_at$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70826__$1$$,$APP.$cljs$cst$1737$modified_at$$),$changes$jscomp$243$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70826__$1$$,
$APP.$cljs$cst$3131$changes$$),$revn$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70826__$1$$,$APP.$cljs$cst$2270$revn$$);typeof $app$main$data$workspace$notifications$handle_library_change_70830$$==="undefined"&&($app$main$data$workspace$notifications$handle_library_change_70830$$=function($p__70825$jscomp$1$$,$map__70826$jscomp$1$$,$msg$jscomp$44$$,$file_id$jscomp$235$$,$modified_at$jscomp$13$$,$changes$jscomp$244$$,$revn$jscomp$9$$,$meta70831$$){this.$p__70825$=$p__70825$jscomp$1$$;
this.$map__70826$=$map__70826$jscomp$1$$;this.$msg$=$msg$jscomp$44$$;this.$file_id$=$file_id$jscomp$235$$;this.$modified_at$=$modified_at$jscomp$13$$;this.$changes$=$changes$jscomp$244$$;this.$revn$=$revn$jscomp$9$$;this.$meta70831$=$meta70831$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$notifications$handle_library_change_70830$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_library_change_70830$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4363$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_library_change$$},$app$main$data$workspace$notifications$handle_library_change_70830$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70832$$,$meta70831__$1$$){return new $app$main$data$workspace$notifications$handle_library_change_70830$$(this.$p__70825$,this.$map__70826$,this.$msg$,this.$file_id$,this.$modified_at$,this.$changes$,this.$revn$,$meta70831__$1$$)},$app$main$data$workspace$notifications$handle_library_change_70830$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70831$},$app$main$data$workspace$notifications$handle_library_change_70830$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$notifications$handle_library_change_70830$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2438$$,$state$jscomp$800$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$1916$files$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$800$$),this.$file_id$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$libraries$ext_library_changed$$(this.$file_id$,
this.$modified_at$,this.$revn$,this.$changes$),$app$main$data$workspace$libraries$notify_sync_file$$()):null});return new $app$main$data$workspace$notifications$handle_library_change_70830$$($p__70825$$,$map__70826__$1$$,$map__70826__$1$$,$file_id$jscomp$234$$,$modified_at$jscomp$12$$,$changes$jscomp$243$$,$revn$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$pages$select_frame_tool$$=function($file_id$jscomp$236$$,$page_id$jscomp$224$$){typeof $app$main$data$workspace$pages$select_frame_tool_70706$$==="undefined"&&($app$main$data$workspace$pages$select_frame_tool_70706$$=function($file_id$jscomp$237$$,$page_id$jscomp$225$$,$meta70707$$){this.$file_id$=$file_id$jscomp$237$$;this.$page_id$=$page_id$jscomp$225$$;this.$meta70707$=$meta70707$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$pages$select_frame_tool_70706$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$select_frame_tool_70706$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4364$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_select_frame_tool$$},$app$main$data$workspace$pages$select_frame_tool_70706$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70708$$,$meta70707__$1$$){return new $app$main$data$workspace$pages$select_frame_tool_70706$$(this.$file_id$,
this.$page_id$,$meta70707__$1$$)},$app$main$data$workspace$pages$select_frame_tool_70706$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70707$},$app$main$data$workspace$pages$select_frame_tool_70706$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$select_frame_tool_70706$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2439_page$jscomp$94$$,$state$jscomp$801$$){$_$jscomp$2439_page$jscomp$94$$=
$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$801$$,this.$file_id$,this.$page_id$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2439_page$jscomp$94$$)))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$drawing$select_for_drawing$$($APP.$cljs$cst$1606$frame$$)):null});return new $app$main$data$workspace$pages$select_frame_tool_70706$$($file_id$jscomp$236$$,
$page_id$jscomp$224$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$pages$initialize_page_STAR_$$=function($file_id$jscomp$239$$,$page_id$jscomp$227$$){typeof $app$main$data$workspace$pages$initialize_page_STAR__70748$$==="undefined"&&($app$main$data$workspace$pages$initialize_page_STAR__70748$$=function($file_id$jscomp$240$$,$page_id$jscomp$228$$,$meta70749$$){this.$file_id$=$file_id$jscomp$240$$;this.$page_id$=$page_id$jscomp$228$$;this.$meta70749$=$meta70749$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$pages$initialize_page_STAR__70748$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$initialize_page_STAR__70748$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4366$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_initialize_page_STAR_$$},$app$main$data$workspace$pages$initialize_page_STAR__70748$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70750$$,$meta70749__$1$$){return new $app$main$data$workspace$pages$initialize_page_STAR__70748$$(this.$file_id$,
this.$page_id$,$meta70749__$1$$)},$app$main$data$workspace$pages$initialize_page_STAR__70748$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70749$},$app$main$data$workspace$pages$initialize_page_STAR__70748$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$initialize_page_STAR__70748$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2440_page$jscomp$95$$,$local$jscomp$13_state$jscomp$803$$){var $self__$jscomp$5863$$=
this,$state__$1$jscomp$48$$=$app$main$data$helpers$update_page$cljs$0core$0IFn$0_invoke$0arity$04$$($local$jscomp$13_state$jscomp$803$$,$self__$jscomp$5863$$.$file_id$,$self__$jscomp$5863$$.$page_id$,function($p1__70742_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__70742_SHARP_$$,$APP.$cljs$cst$1631$objects$$,$app$common$types$shape_tree$start_page_index$$)});$_$jscomp$2440_page$jscomp$95$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$48$$,
$self__$jscomp$5863$$.$file_id$,$self__$jscomp$5863$$.$page_id$);$local$jscomp$13_state$jscomp$803$$=function(){var $file_id$jscomp$inline_7201_or__5025__auto__$jscomp$832$$=$self__$jscomp$5863$$.$file_id$;var $page_id$jscomp$inline_7202$$=$self__$jscomp$5863$$.$page_id$;$file_id$jscomp$inline_7201_or__5025__auto__$jscomp$832$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state__$1$jscomp$48$$,$APP.$cljs$cst$4365$workspace_cache$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file_id$jscomp$inline_7201_or__5025__auto__$jscomp$832$$,$page_id$jscomp$inline_7202$$],null));return $APP.$cljs$core$truth_$$($file_id$jscomp$inline_7201_or__5025__auto__$jscomp$832$$)?$file_id$jscomp$inline_7201_or__5025__auto__$jscomp$832$$:$app$main$data$workspace$pages$default_workspace_local$$}();return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$48$$,
$APP.$cljs$cst$1918$current_page_id$$,$self__$jscomp$5863$$.$page_id$),$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($local$jscomp$13_state$jscomp$803$$,$APP.$cljs$cst$1921$selected$$,$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$())),$APP.$cljs$cst$4367$workspace_trimmed_page$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2440_page$jscomp$95$$,
$APP.$cljs$cst$725$name$$),$APP.$cljs$cst$266$id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2440_page$jscomp$95$$,$APP.$cljs$cst$266$id$$)],null)),$APP.$cljs$cst$2209$workspace_layout$$,$app$main$data$workspace$layout$load_layout_flags$$),$APP.$cljs$cst$2188$workspace_global$$,$app$main$data$workspace$layout$load_layout_state$$)},$app$main$data$workspace$pages$initialize_page_STAR__70748$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$initialize_page_STAR__70748$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2441_page$jscomp$96$$,$state$jscomp$804_uris$jscomp$11$$){$_$jscomp$2441_page$jscomp$96$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$804_uris$jscomp$11$$,this.$file_id$,this.$page_id$);$state$jscomp$804_uris$jscomp$11$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$app$main$data$workspace$pages$xf_COLON_collect_file_media$$,$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2441_page$jscomp$96$$));
return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$map$$(function($p1__70744_SHARP_$$){return $app$util$http$fetch_data_uri$$.$cljs$core$IFn$_invoke$arity$2$($p1__70744_SHARP_$$,!1)},$APP.$beicon$v2$core$from$$($state$jscomp$804_uris$jscomp$11$$))),$APP.$beicon$v2$core$ignore$$($APP.$app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3115$cmd$$,$cljs$cst$4368$index_SLASH_initialize$$,$APP.$cljs$cst$1624$page$$,
$_$jscomp$2441_page$jscomp$96$$],null))))});return new $app$main$data$workspace$pages$initialize_page_STAR__70748$$($file_id$jscomp$239$$,$page_id$jscomp$227$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$pages$initialize_page$$=function($file_id$jscomp$241$$,$page_id$jscomp$229$$){typeof $app$main$data$workspace$pages$initialize_page_70778$$==="undefined"&&($app$main$data$workspace$pages$initialize_page_70778$$=function($file_id$jscomp$242$$,$page_id$jscomp$230$$,$meta70779$$){this.$file_id$=$file_id$jscomp$242$$;this.$page_id$=$page_id$jscomp$230$$;this.$meta70779$=$meta70779$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$pages$initialize_page_70778$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$initialize_page_70778$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3943$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_initialize_page$$},$app$main$data$workspace$pages$initialize_page_70778$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70780$$,$meta70779__$1$$){return new $app$main$data$workspace$pages$initialize_page_70778$$(this.$file_id$,
this.$page_id$,$meta70779__$1$$)},$app$main$data$workspace$pages$initialize_page_70778$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70779$},$app$main$data$workspace$pages$initialize_page_70778$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$initialize_page_70778$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_temp$jscomp$1276_JSCompiler_temp_const$jscomp$1279__$jscomp$2442$$,$JSCompiler_inline_result$jscomp$1280_profile$jscomp$inline_7204_props$jscomp$inline_7205_state$jscomp$805$$){if($APP.$cljs$core$truth_$$($APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1280_profile$jscomp$inline_7204_props$jscomp$inline_7205_state$jscomp$805$$,
this.$file_id$,this.$page_id$))){$JSCompiler_temp$jscomp$1276_JSCompiler_temp_const$jscomp$1279__$jscomp$2442$$=(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$pages$initialize_page_STAR_$$(this.$file_id$,this.$page_id$),$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_page$$(this.$file_id$,this.$page_id$));var $JSCompiler_temp_const$jscomp$1278$$=$APP.$app$main$features$active_feature_QMARK_$$($JSCompiler_inline_result$jscomp$1280_profile$jscomp$inline_7204_props$jscomp$inline_7205_state$jscomp$805$$,
"render-wasm/v1")?$APP.$beicon$v2$core$empty$$():(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$thumbnails$watch_state_changes$$(this.$file_id$,this.$page_id$)),$JSCompiler_temp_const$jscomp$1277$$=(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$libraries$watch_component_changes$$());$JSCompiler_inline_result$jscomp$1280_profile$jscomp$inline_7204_props$jscomp$inline_7205_state$jscomp$805$$=$APP.$cljs$cst$1914$profile$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1280_profile$jscomp$inline_7204_props$jscomp$inline_7205_state$jscomp$805$$);
$JSCompiler_inline_result$jscomp$1280_profile$jscomp$inline_7204_props$jscomp$inline_7205_state$jscomp$805$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1280_profile$jscomp$inline_7204_props$jscomp$inline_7205_state$jscomp$805$$,$APP.$cljs$cst$575$props$$);$JSCompiler_inline_result$jscomp$1280_profile$jscomp$inline_7204_props$jscomp$inline_7205_state$jscomp$805$$=$APP.$cljs$core$not$$($APP.$cljs$cst$3750$workspace_visited$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1280_profile$jscomp$inline_7204_props$jscomp$inline_7205_state$jscomp$805$$))?
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$pages$select_frame_tool$$(this.$file_id$,this.$page_id$)):null;$JSCompiler_temp$jscomp$1276_JSCompiler_temp_const$jscomp$1279__$jscomp$2442$$=$APP.$beicon$v2$core$concat$$($JSCompiler_temp$jscomp$1276_JSCompiler_temp_const$jscomp$1279__$jscomp$2442$$,$JSCompiler_temp_const$jscomp$1278$$,$JSCompiler_temp_const$jscomp$1277$$,$JSCompiler_inline_result$jscomp$1280_profile$jscomp$inline_7204_props$jscomp$inline_7205_state$jscomp$805$$)}else $JSCompiler_temp$jscomp$1276_JSCompiler_temp_const$jscomp$1279__$jscomp$2442$$=
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1644$file_id$$,this.$file_id$,$APP.$cljs$cst$2455$app_DOT_main_DOT_router_SLASH_replace$$,!0])));return $JSCompiler_temp$jscomp$1276_JSCompiler_temp_const$jscomp$1279__$jscomp$2442$$});return new $app$main$data$workspace$pages$initialize_page_70778$$($file_id$jscomp$241$$,$page_id$jscomp$229$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$pages$update_page_root$$=function($file_id$jscomp$245$$,$page_id$jscomp$233$$){typeof $app$main$data$workspace$pages$update_page_root_70809$$==="undefined"&&($app$main$data$workspace$pages$update_page_root_70809$$=function($file_id$jscomp$246$$,$page_id$jscomp$234$$,$meta70810$$){this.$file_id$=$file_id$jscomp$246$$;this.$page_id$=$page_id$jscomp$234$$;this.$meta70810$=$meta70810$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$pages$update_page_root_70809$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$update_page_root_70809$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4369$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_update_page_root$$},$app$main$data$workspace$pages$update_page_root_70809$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70811$$,$meta70810__$1$$){return new $app$main$data$workspace$pages$update_page_root_70809$$(this.$file_id$,
this.$page_id$,$meta70810__$1$$)},$app$main$data$workspace$pages$update_page_root_70809$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70810$},$app$main$data$workspace$pages$update_page_root_70809$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$update_page_root_70809$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2444$$,$state$jscomp$807$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$807$$,
new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,this.$file_id$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$1630$pages_index$$,this.$page_id$,$APP.$cljs$cst$1631$objects$$,$APP.$app$common$uuid$zero$$],null),$app$render_wasm$shape$create_shape$$)});return new $app$main$data$workspace$pages$update_page_root_70809$$($file_id$jscomp$245$$,$page_id$jscomp$233$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$pages$create_page$$=function($p__70819$$){var $map__70820__$1$$=$APP.$cljs$core$__destructure_map$$($p__70819$$),$page_id$jscomp$235$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70820__$1$$,$APP.$cljs$cst$2043$page_id$$),$file_id$jscomp$247$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70820__$1$$,$APP.$cljs$cst$1644$file_id$$),$id$jscomp$725$$=$APP.$cljs$core$truth_$$($page_id$jscomp$235$$)?$page_id$jscomp$235$$:$APP.$app$common$uuid$next$$();
typeof $app$main$data$workspace$pages$create_page_70822$$==="undefined"&&($app$main$data$workspace$pages$create_page_70822$$=function($p__70819$jscomp$1$$,$map__70820$jscomp$1$$,$page_id$jscomp$236$$,$file_id$jscomp$248$$,$id$jscomp$726$$,$meta70823$$){this.$p__70819$=$p__70819$jscomp$1$$;this.$map__70820$=$map__70820$jscomp$1$$;this.$page_id$=$page_id$jscomp$236$$;this.$file_id$=$file_id$jscomp$248$$;this.id=$id$jscomp$726$$;this.$meta70823$=$meta70823$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$pages$create_page_70822$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$create_page_70822$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4370$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_create_page$$},$app$main$data$workspace$pages$create_page_70822$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70824$$,$meta70823__$1$$){return new $app$main$data$workspace$pages$create_page_70822$$(this.$p__70819$,
this.$map__70820$,this.$page_id$,this.$file_id$,this.id,$meta70823__$1$$)},$app$main$data$workspace$pages$create_page_70822$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70823$},$app$main$data$workspace$pages$create_page_70822$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$create_page_70822$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,
this.id,$APP.$cljs$cst$1644$file_id$$,this.$file_id$],null)},$app$main$data$workspace$pages$create_page_70822$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$create_page_70822$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$245_it$jscomp$220_name$jscomp$342_pages$jscomp$4_unames$jscomp$11$$,$state$jscomp$808$$){$changes$jscomp$245_it$jscomp$220_name$jscomp$342_pages$jscomp$4_unames$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$808$$),
$APP.$cljs$cst$1630$pages_index$$);$changes$jscomp$245_it$jscomp$220_name$jscomp$342_pages$jscomp$4_unames$jscomp$11$$=$APP.$app$common$files$helpers$get_used_names$$($changes$jscomp$245_it$jscomp$220_name$jscomp$342_pages$jscomp$4_unames$jscomp$11$$);$changes$jscomp$245_it$jscomp$220_name$jscomp$342_pages$jscomp$4_unames$jscomp$11$$=$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$("Page",$changes$jscomp$245_it$jscomp$220_name$jscomp$342_pages$jscomp$4_unames$jscomp$11$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1629$immediate_suffix_QMARK_$$,!0]));var $id$jscomp$inline_7208$$=this.id;$changes$jscomp$245_it$jscomp$220_name$jscomp$342_pages$jscomp$4_unames$jscomp$11$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2620$add_page$$,$APP.$cljs$cst$266$id$$,$id$jscomp$inline_7208$$,$APP.$cljs$cst$725$name$$,$changes$jscomp$245_it$jscomp$220_name$jscomp$342_pages$jscomp$4_unames$jscomp$11$$],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2622$del_page$$,$APP.$cljs$cst$266$id$$,
$id$jscomp$inline_7208$$],null)));return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$245_it$jscomp$220_name$jscomp$342_pages$jscomp$4_unames$jscomp$11$$)),$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$808$$,"render-wasm/v1")?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$pages$update_page_root$$(this.$file_id$,this.id)):$APP.$beicon$v2$core$empty$$())});return new $app$main$data$workspace$pages$create_page_70822$$($p__70819$$,
$map__70820__$1$$,$page_id$jscomp$235$$,$file_id$jscomp$247$$,$id$jscomp$725$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$pages$rename_page$$=function($id$jscomp$730$$,$name$jscomp$344$$){typeof $app$main$data$workspace$pages$rename_page_70958$$==="undefined"&&($app$main$data$workspace$pages$rename_page_70958$$=function($id$jscomp$731$$,$name$jscomp$345$$,$meta70959$$){this.id=$id$jscomp$731$$;this.name=$name$jscomp$345$$;this.$meta70959$=$meta70959$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$pages$rename_page_70958$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$rename_page_70958$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4372$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_rename_page$$},$app$main$data$workspace$pages$rename_page_70958$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70960$$,$meta70959__$1$$){return new $app$main$data$workspace$pages$rename_page_70958$$(this.id,this.name,$meta70959__$1$$)},$app$main$data$workspace$pages$rename_page_70958$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70959$},$app$main$data$workspace$pages$rename_page_70958$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$rename_page_70958$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($empty_page_QMARK__it$jscomp$222_objects$jscomp$615$$,$state$jscomp$810$$){var $changes$jscomp$249_page$jscomp$98$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$810$$,this.id);$empty_page_QMARK__it$jscomp$222_objects$jscomp$615$$=
$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$249_page$jscomp$98$$);$empty_page_QMARK__it$jscomp$222_objects$jscomp$615$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($empty_page_QMARK__it$jscomp$222_objects$jscomp$615$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$APP.$cljs$core$first$$($APP.$cljs$core$keys$$($empty_page_QMARK__it$jscomp$222_objects$jscomp$615$$)));$changes$jscomp$249_page$jscomp$98$$=
$app$common$files$changes_builder$mod_page$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$249_page$jscomp$98$$),$changes$jscomp$249_page$jscomp$98$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,this.name],null));var $next_id_pages$jscomp$6_separator_QMARK_$$=$APP.$cljs$cst$2228$pages$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$810$$)),
$index$jscomp$348$$=$APP.$app$common$data$index_of$$($next_id_pages$jscomp$6_separator_QMARK_$$,this.id),$fallback_page_id_prev_id$$=$index$jscomp$348$$!=null&&$index$jscomp$348$$>0?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($next_id_pages$jscomp$6_separator_QMARK_$$,$index$jscomp$348$$-1,null):null;$next_id_pages$jscomp$6_separator_QMARK_$$=$index$jscomp$348$$!=null?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($next_id_pages$jscomp$6_separator_QMARK_$$,$index$jscomp$348$$+
1,null):null;$fallback_page_id_prev_id$$=$APP.$cljs$core$truth_$$($fallback_page_id_prev_id$$)?$fallback_page_id_prev_id$$:$next_id_pages$jscomp$6_separator_QMARK_$$;$next_id_pages$jscomp$6_separator_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("---",$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(this.name));return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$249_page$jscomp$98$$)),$next_id_pages$jscomp$6_separator_QMARK_$$&&
$empty_page_QMARK__it$jscomp$222_objects$jscomp$615$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.id,$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$810$$))&&$fallback_page_id_prev_id$$!=null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2043$page_id$$,$fallback_page_id_prev_id$$]))):null)});return new $app$main$data$workspace$pages$rename_page_70958$$($id$jscomp$730$$,
$name$jscomp$344$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$path$shapes_to_path$convert_selected_to_path$cljs$0core$0IFn$0_invoke$0arity$01$$=function($ids$jscomp$212$$){typeof $app$main$data$workspace$path$shapes_to_path$convert_selected_to_path_70751$$==="undefined"&&($app$main$data$workspace$path$shapes_to_path$convert_selected_to_path_70751$$=function($ids$jscomp$213$$,$meta70752$$){this.ids=$ids$jscomp$213$$;this.$meta70752$=$meta70752$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$path$shapes_to_path$convert_selected_to_path_70751$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$shapes_to_path$convert_selected_to_path_70751$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4377$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_shapes_to_path_SLASH_convert_selected_to_path$$},$app$main$data$workspace$path$shapes_to_path$convert_selected_to_path_70751$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70753$$,$meta70752__$1$$){return new $app$main$data$workspace$path$shapes_to_path$convert_selected_to_path_70751$$(this.ids,$meta70752__$1$$)},$app$main$data$workspace$path$shapes_to_path$convert_selected_to_path_70751$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70752$},$app$main$data$workspace$path$shapes_to_path$convert_selected_to_path_70751$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$shapes_to_path$convert_selected_to_path_70751$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$252_it$jscomp$224_page_id$jscomp$239$$,$state$jscomp$812$$){var $self__$jscomp$5897$$=this;if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$812$$,"render-wasm/v1")){$changes$jscomp$252_it$jscomp$224_page_id$jscomp$239$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$812$$);var $objects$jscomp$616$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$812$$),$selected$jscomp$84$$=
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70731_SHARP_$$){return $APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$616$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$616$$,$p1__70731_SHARP_$$))},function(){var $or__5025__auto__$jscomp$835$$=$self__$jscomp$5897$$.ids;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$835$$)?$or__5025__auto__$jscomp$835$$:$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$812$$)}()),
$children_ids$jscomp$11$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__70732_SHARP_$$){return $APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$616$$,$p1__70732_SHARP_$$)}),$selected$jscomp$84$$);$changes$jscomp$252_it$jscomp$224_page_id$jscomp$239$$=$app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
$changes$jscomp$252_it$jscomp$224_page_id$jscomp$239$$),$objects$jscomp$616$$),$selected$jscomp$84$$,function($JSCompiler_inline_result$jscomp$10898_shape$jscomp$725$$){a:{var $id$jscomp$inline_14486$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10898_shape$jscomp$725$$);$APP.$app$render_wasm$api$use_shape$$($id$jscomp$inline_14486$$);try{var $fn_54395$jscomp$inline_14488$$=$APP.$app$render_wasm$wasm$internal_module$$._current_to_path;try{var $JSCompiler_inline_result$jscomp$inline_14487$$=
$fn_54395$jscomp$inline_14488$$()}catch($e54397$jscomp$inline_14498$$){var $cause$jscomp$inline_14497_cause54396$jscomp$inline_14489_content$jscomp$221$$=$e54397$jscomp$inline_14498$$;var $JSCompiler_temp_const$jscomp$10896_offset$jscomp$inline_14494_read_code_fn__52997__auto__$jscomp$inline_14490$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$G__70773$jscomp$inline_12839_G__70774$jscomp$inline_12840_code_num__52998__auto__$jscomp$inline_14491$$=$APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$10896_offset$jscomp$inline_14494_read_code_fn__52997__auto__$jscomp$inline_14490$$)?
$JSCompiler_temp_const$jscomp$10896_offset$jscomp$inline_14494_read_code_fn__52997__auto__$jscomp$inline_14490$$.$cljs$core$IFn$_invoke$arity$0$?$JSCompiler_temp_const$jscomp$10896_offset$jscomp$inline_14494_read_code_fn__52997__auto__$jscomp$inline_14490$$.$cljs$core$IFn$_invoke$arity$0$():$JSCompiler_temp_const$jscomp$10896_offset$jscomp$inline_14494_read_code_fn__52997__auto__$jscomp$inline_14490$$():null,$code__52999__auto__$jscomp$inline_14492$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$G__70773$jscomp$inline_12839_G__70774$jscomp$inline_12840_code_num__52998__auto__$jscomp$inline_14491$$,$APP.$cljs$cst$2971$wasm_critical$$),$hint__53000__auto__$jscomp$inline_14493$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$inline_14492$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$inline_14493$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_current_to_path",$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$inline_14493$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$inline_14492$$],null),$cause$jscomp$inline_14497_cause54396$jscomp$inline_14489_content$jscomp$221$$);}$JSCompiler_temp_const$jscomp$10896_offset$jscomp$inline_14494_read_code_fn__52997__auto__$jscomp$inline_14490$$=$JSCompiler_inline_result$jscomp$inline_14487$$>>2;var $heap$jscomp$inline_14495$$=$APP.$app$render_wasm$mem$get_heap_u32$$(),$content$jscomp$inline_14496$$=
$app$common$types$path$impl$from_bytes$$($app$render_wasm$mem$slice$$($heap$jscomp$inline_14495$$,$JSCompiler_temp_const$jscomp$10896_offset$jscomp$inline_14494_read_code_fn__52997__auto__$jscomp$inline_14490$$+1,$heap$jscomp$inline_14495$$[$JSCompiler_temp_const$jscomp$10896_offset$jscomp$inline_14494_read_code_fn__52997__auto__$jscomp$inline_14490$$]*7));$APP.$app$render_wasm$mem$free$$();$cause$jscomp$inline_14497_cause54396$jscomp$inline_14489_content$jscomp$221$$=$content$jscomp$inline_14496$$;
break a}catch($e54393$jscomp$inline_14499$$){throw $cause$jscomp$inline_14497_cause54396$jscomp$inline_14489_content$jscomp$221$$=$e54393$jscomp$inline_14499$$,$APP.$app$render_wasm$mem$free$$(),$cause$jscomp$inline_14497_cause54396$jscomp$inline_14489_content$jscomp$221$$;}$cause$jscomp$inline_14497_cause54396$jscomp$inline_14489_content$jscomp$221$$=void 0}$JSCompiler_temp_const$jscomp$10896_offset$jscomp$inline_14494_read_code_fn__52997__auto__$jscomp$inline_14490$$=$app$common$types$path$update_geometry$$.$cljs$core$IFn$_invoke$arity$2$;
$G__70773$jscomp$inline_12839_G__70774$jscomp$inline_12840_code_num__52998__auto__$jscomp$inline_14491$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$10898_shape$jscomp$725$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$296$path$$);$G__70773$jscomp$inline_12839_G__70774$jscomp$inline_12840_code_num__52998__auto__$jscomp$inline_14491$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10898_shape$jscomp$725$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70773$jscomp$inline_12839_G__70774$jscomp$inline_12840_code_num__52998__auto__$jscomp$inline_14491$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$first$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1634$fills$$,$APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10898_shape$jscomp$725$$))))):
$G__70773$jscomp$inline_12839_G__70774$jscomp$inline_12840_code_num__52998__auto__$jscomp$inline_14491$$;$JSCompiler_inline_result$jscomp$10898_shape$jscomp$725$$=$app$common$files$helpers$image_shape_QMARK_$$($JSCompiler_inline_result$jscomp$10898_shape$jscomp$725$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70773$jscomp$inline_12839_G__70774$jscomp$inline_12840_code_num__52998__auto__$jscomp$inline_14491$$,$APP.$cljs$cst$1632$fill_image$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10898_shape$jscomp$725$$,
$cljs$cst$1633$metadata$$)):$G__70773$jscomp$inline_12839_G__70774$jscomp$inline_12840_code_num__52998__auto__$jscomp$inline_14491$$;return $JSCompiler_temp_const$jscomp$10896_offset$jscomp$inline_14494_read_code_fn__52997__auto__$jscomp$inline_14490$$.call($app$common$types$path$update_geometry$$,$APP.$app$common$data$without_keys$$($JSCompiler_inline_result$jscomp$10898_shape$jscomp$725$$,$app$main$data$workspace$path$shapes_to_path$dissoc_attrs$$),$cause$jscomp$inline_14497_cause54396$jscomp$inline_14489_content$jscomp$221$$)}),
$children_ids$jscomp$11$$)}else $changes$jscomp$252_it$jscomp$224_page_id$jscomp$239$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$812$$),$objects$jscomp$616$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$812$$),$selected$jscomp$84$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70734_SHARP_$$){return $APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$616$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$616$$,$p1__70734_SHARP_$$))},function(){var $or__5025__auto__$jscomp$836$$=$self__$jscomp$5897$$.ids;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$836$$)?$or__5025__auto__$jscomp$836$$:$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$812$$)}()),$children_ids$jscomp$11$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__70735_SHARP_$$){return $APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$616$$,
$p1__70735_SHARP_$$)}),$selected$jscomp$84$$),$changes$jscomp$252_it$jscomp$224_page_id$jscomp$239$$=$app$common$files$changes_builder$remove_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$changes$jscomp$252_it$jscomp$224_page_id$jscomp$239$$),$objects$jscomp$616$$),
$selected$jscomp$84$$,$APP.$app$common$types$path$convert_to_path$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)),$children_ids$jscomp$11$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$252_it$jscomp$224_page_id$jscomp$239$$))});return new $app$main$data$workspace$path$shapes_to_path$convert_selected_to_path_70751$$($ids$jscomp$212$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$shapes_to_path$make_stroke_paths$$=function($shape$jscomp$726$$,$parent_id$jscomp$93$$,$frame_id$jscomp$107$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$cljs$core$keep_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($idx$jscomp$96$$,$JSCompiler_inline_result$jscomp$1286_stroke$jscomp$27$$){a:{var $id$jscomp$inline_12842$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$726$$);$APP.$app$render_wasm$api$use_shape$$($id$jscomp$inline_12842$$);
try{var $fn_54402$jscomp$inline_12845$$=$APP.$app$render_wasm$wasm$internal_module$$._convert_stroke_to_path;try{var $JSCompiler_inline_result$jscomp$inline_12844$$=$fn_54402$jscomp$inline_12845$$($idx$jscomp$96$$)}catch($e54404$jscomp$inline_12856$$){var $JSCompiler_temp$jscomp$1281_cause$jscomp$inline_12855_cause54403$jscomp$inline_12846_content$jscomp$222$$=$e54404$jscomp$inline_12856$$;var $JSCompiler_temp_const$jscomp$1285_offset$jscomp$inline_12851_read_code_fn__52997__auto__$jscomp$inline_12847$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$JSCompiler_temp_const$jscomp$1284_code_num__52998__auto__$jscomp$inline_12848$$=$APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$1285_offset$jscomp$inline_12851_read_code_fn__52997__auto__$jscomp$inline_12847$$)?$JSCompiler_temp_const$jscomp$1285_offset$jscomp$inline_12851_read_code_fn__52997__auto__$jscomp$inline_12847$$.$cljs$core$IFn$_invoke$arity$0$?$JSCompiler_temp_const$jscomp$1285_offset$jscomp$inline_12851_read_code_fn__52997__auto__$jscomp$inline_12847$$.$cljs$core$IFn$_invoke$arity$0$():
$JSCompiler_temp_const$jscomp$1285_offset$jscomp$inline_12851_read_code_fn__52997__auto__$jscomp$inline_12847$$():null,$JSCompiler_temp_const$jscomp$1283_code__52999__auto__$jscomp$inline_12849$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$JSCompiler_temp_const$jscomp$1284_code_num__52998__auto__$jscomp$inline_12848$$,$APP.$cljs$cst$2971$wasm_critical$$),$JSCompiler_temp_const$jscomp$1282_hint__53000__auto__$jscomp$inline_12850$$=["WASM Error (",
$APP.$app$common$data$name$$($JSCompiler_temp_const$jscomp$1283_code__52999__auto__$jscomp$inline_12849$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1282_hint__53000__auto__$jscomp$inline_12850$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_convert_stroke_to_path",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$JSCompiler_temp_const$jscomp$1282_hint__53000__auto__$jscomp$inline_12850$$,
$APP.$cljs$cst$273$code$$,$JSCompiler_temp_const$jscomp$1283_code__52999__auto__$jscomp$inline_12849$$],null),$JSCompiler_temp$jscomp$1281_cause$jscomp$inline_12855_cause54403$jscomp$inline_12846_content$jscomp$222$$);}$JSCompiler_temp_const$jscomp$1285_offset$jscomp$inline_12851_read_code_fn__52997__auto__$jscomp$inline_12847$$=$JSCompiler_inline_result$jscomp$inline_12844$$>>2;var $heap$jscomp$inline_12852$$=$APP.$app$render_wasm$mem$get_heap_u32$$(),$length$jscomp$inline_12853$$=$heap$jscomp$inline_12852$$[$JSCompiler_temp_const$jscomp$1285_offset$jscomp$inline_12851_read_code_fn__52997__auto__$jscomp$inline_12847$$];
if($length$jscomp$inline_12853$$>0){var $content$jscomp$inline_12854$$=$app$common$types$path$impl$from_bytes$$($app$render_wasm$mem$slice$$($heap$jscomp$inline_12852$$,$JSCompiler_temp_const$jscomp$1285_offset$jscomp$inline_12851_read_code_fn__52997__auto__$jscomp$inline_12847$$+1,$length$jscomp$inline_12853$$*7));$APP.$app$render_wasm$mem$free$$();$JSCompiler_temp$jscomp$1281_cause$jscomp$inline_12855_cause54403$jscomp$inline_12846_content$jscomp$222$$=$content$jscomp$inline_12854$$;break a}$APP.$app$render_wasm$mem$free$$();
$JSCompiler_temp$jscomp$1281_cause$jscomp$inline_12855_cause54403$jscomp$inline_12846_content$jscomp$222$$=null;break a}catch($e54401$jscomp$inline_12857$$){throw $JSCompiler_temp$jscomp$1281_cause$jscomp$inline_12855_cause54403$jscomp$inline_12846_content$jscomp$222$$=$e54401$jscomp$inline_12857$$,$APP.$app$render_wasm$mem$free$$(),$JSCompiler_temp$jscomp$1281_cause$jscomp$inline_12855_cause54403$jscomp$inline_12846_content$jscomp$222$$;}$JSCompiler_temp$jscomp$1281_cause$jscomp$inline_12855_cause54403$jscomp$inline_12846_content$jscomp$222$$=
void 0}$JSCompiler_temp$jscomp$1281_cause$jscomp$inline_12855_cause54403$jscomp$inline_12846_content$jscomp$222$$!=null?($JSCompiler_temp_const$jscomp$1285_offset$jscomp$inline_12851_read_code_fn__52997__auto__$jscomp$inline_12847$$=$APP.$cljs$cst$139$type$$,$JSCompiler_temp_const$jscomp$1284_code_num__52998__auto__$jscomp$inline_12848$$=$APP.$app$common$uuid$next$$(),$JSCompiler_temp_const$jscomp$1283_code__52999__auto__$jscomp$inline_12849$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$726$$)),
" (stroke)"].join(""),$JSCompiler_temp_const$jscomp$1282_hint__53000__auto__$jscomp$inline_12850$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$JSCompiler_inline_result$jscomp$1286_stroke$jscomp$27$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1746$fill_color$$,$APP.$cljs$cst$1739$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1286_stroke$jscomp$27$$),$APP.$cljs$cst$1747$fill_opacity$$,
$APP.$cljs$cst$1740$stroke_opacity$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1286_stroke$jscomp$27$$),$APP.$cljs$cst$1748$fill_color_gradient$$,$APP.$cljs$cst$1741$stroke_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1286_stroke$jscomp$27$$),$APP.$cljs$cst$1632$fill_image$$,$APP.$cljs$cst$1635$stroke_image$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1286_stroke$jscomp$27$$),$APP.$cljs$cst$1745$fill_color_ref_id$$,
$APP.$cljs$cst$1742$stroke_color_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1286_stroke$jscomp$27$$),$APP.$cljs$cst$1640$fill_color_ref_file$$,$APP.$cljs$cst$1641$stroke_color_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1286_stroke$jscomp$27$$)],null)),$JSCompiler_temp$jscomp$1281_cause$jscomp$inline_12855_cause54403$jscomp$inline_12846_content$jscomp$222$$=$APP.$app$common$types$shape$setup_shape$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
8,[$JSCompiler_temp_const$jscomp$1285_offset$jscomp$inline_12851_read_code_fn__52997__auto__$jscomp$inline_12847$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$266$id$$,$JSCompiler_temp_const$jscomp$1284_code_num__52998__auto__$jscomp$inline_12848$$,$APP.$cljs$cst$725$name$$,$JSCompiler_temp_const$jscomp$1283_code__52999__auto__$jscomp$inline_12849$$,$APP.$cljs$cst$1619$parent_id$$,$parent_id$jscomp$93$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$107$$,$APP.$cljs$cst$1637$content$$,$JSCompiler_temp$jscomp$1281_cause$jscomp$inline_12855_cause54403$jscomp$inline_12846_content$jscomp$222$$,
$APP.$cljs$cst$1634$fills$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$JSCompiler_temp_const$jscomp$1282_hint__53000__auto__$jscomp$inline_12850$$,[$JSCompiler_inline_result$jscomp$1286_stroke$jscomp$27$$],null),$APP.$cljs$cst$1636$strokes$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null))):$JSCompiler_temp$jscomp$1281_cause$jscomp$inline_12855_cause54403$jscomp$inline_12846_content$jscomp$222$$=null;return $JSCompiler_temp$jscomp$1281_cause$jscomp$inline_12855_cause54403$jscomp$inline_12846_content$jscomp$222$$}),
$APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$726$$))};
$app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path$cljs$0core$0IFn$0_invoke$0arity$01$$=function($ids$jscomp$214$$){typeof $app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path_70804$$==="undefined"&&($app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path_70804$$=function($ids$jscomp$215$$,$meta70805$$){this.ids=$ids$jscomp$215$$;this.$meta70805$=$meta70805$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path_70804$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path_70804$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4378$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_shapes_to_path_SLASH_convert_selected_strokes_to_path$$},$app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path_70804$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70806$$,$meta70805__$1$$){return new $app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path_70804$$(this.ids,$meta70805__$1$$)},$app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path_70804$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70805$},$app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path_70804$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path_70804$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($it$jscomp$225_new_shape_ids_selected$jscomp$85$$,$state$jscomp$813$$){var $self__$jscomp$5901$$=this,$it__$1$jscomp$101$$=this;if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$813$$,"render-wasm/v1")){var $page_id$jscomp$240$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$813$$),$objects$jscomp$617$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$813$$);$it$jscomp$225_new_shape_ids_selected$jscomp$85$$=
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70794_SHARP_$$){return $APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$617$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$617$$,$p1__70794_SHARP_$$))},function(){var $or__5025__auto__$jscomp$837$$=$self__$jscomp$5901$$.ids;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$837$$)?$or__5025__auto__$jscomp$837$$:$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$813$$)}());
var $result$jscomp$313$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$134$$,$group$jscomp$38_selrect$jscomp$73_shape_id$jscomp$119$$){var $shape$jscomp$727$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$617$$,$group$jscomp$38_selrect$jscomp$73_shape_id$jscomp$119$$);if($APP.$cljs$core$seq$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$727$$))){var $position$jscomp$157$$=$app$common$files$helpers$get_position_on_parent$$($objects$jscomp$617$$,
$group$jscomp$38_selrect$jscomp$73_shape_id$jscomp$119$$),$new_shapes$jscomp$9$$=$app$main$data$workspace$path$shapes_to_path$make_stroke_paths$$($shape$jscomp$727$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$727$$),$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$727$$));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($acc$jscomp$134$$,$APP.$cljs$cst$4379$entries$$,
$APP.$cljs$core$into$$,$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__70798_SHARP_$$,$p2__70797_SHARP_$$){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$4380$new_shape$$,$APP.$cljs$cst$1795$index$$],[$p2__70797_SHARP_$$,$position$jscomp$157$$+1+$p1__70798_SHARP_$$])},$new_shapes$jscomp$9$$)),$cljs$cst$4381$updated_ids$$,$APP.$cljs$core$conj$$,$group$jscomp$38_selrect$jscomp$73_shape_id$jscomp$119$$)}var $child_ids$jscomp$4$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70799_SHARP_$$){return $APP.$cljs$core$seq$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$617$$,
$p1__70799_SHARP_$$)))},$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$617$$,$group$jscomp$38_selrect$jscomp$73_shape_id$jscomp$119$$)),$group_id$jscomp$2$$=$APP.$app$common$uuid$next$$();$new_shapes$jscomp$9$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($cid$jscomp$1$$){return $app$main$data$workspace$path$shapes_to_path$make_stroke_paths$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$617$$,
$cid$jscomp$1$$),$group_id$jscomp$2$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$727$$))}),$child_ids$jscomp$4$$);return $APP.$cljs$core$seq$$($new_shapes$jscomp$9$$)?($position$jscomp$157$$=$app$common$files$helpers$get_position_on_parent$$($objects$jscomp$617$$,$group$jscomp$38_selrect$jscomp$73_shape_id$jscomp$119$$),$group$jscomp$38_selrect$jscomp$73_shape_id$jscomp$119$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($new_shapes$jscomp$9$$),$group$jscomp$38_selrect$jscomp$73_shape_id$jscomp$119$$=
$APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1614$shapes$$],[$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$38_selrect$jscomp$73_shape_id$jscomp$119$$),
[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$727$$))," (strokes)"].join(""),$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$38_selrect$jscomp$73_shape_id$jscomp$119$$),$APP.$cljs$cst$1608$group$$,$group_id$jscomp$2$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$727$$),$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$727$$),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$38_selrect$jscomp$73_shape_id$jscomp$119$$),
$group$jscomp$38_selrect$jscomp$73_shape_id$jscomp$119$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$38_selrect$jscomp$73_shape_id$jscomp$119$$),$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$new_shapes$jscomp$9$$)])),$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($acc$jscomp$134$$,$APP.$cljs$cst$4382$groups$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1608$group$$,$group$jscomp$38_selrect$jscomp$73_shape_id$jscomp$119$$,$APP.$cljs$cst$342$children$$,$new_shapes$jscomp$9$$,$APP.$cljs$cst$1795$index$$,$position$jscomp$157$$+1],null)),$cljs$cst$4381$updated_ids$$,$APP.$cljs$core$into$$,$child_ids$jscomp$4$$)):$acc$jscomp$134$$},new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4379$entries$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$4382$groups$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$cljs$cst$4381$updated_ids$$,
$APP.$cljs$core$PersistentVector$EMPTY$$],null),$it$jscomp$225_new_shape_ids_selected$jscomp$85$$);$it$jscomp$225_new_shape_ids_selected$jscomp$85$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$cljs$cst$4380$new_shape$$),$APP.$cljs$cst$4379$entries$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$313$$)),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1608$group$$),$APP.$cljs$cst$4382$groups$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$313$$))));var $changes$jscomp$253$$=function(){var $changes$jscomp$254_changes__$1$jscomp$78_changes__$2$jscomp$34_changes__$3$jscomp$10$$=$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$($it__$1$jscomp$101$$,$page_id$jscomp$240$$);
$changes$jscomp$254_changes__$1$jscomp$78_changes__$2$jscomp$34_changes__$3$jscomp$10$$=$APP.$app$common$files$changes_builder$with_objects$$($changes$jscomp$254_changes__$1$jscomp$78_changes__$2$jscomp$34_changes__$3$jscomp$10$$,$objects$jscomp$617$$);$changes$jscomp$254_changes__$1$jscomp$78_changes__$2$jscomp$34_changes__$3$jscomp$10$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$2$jscomp$35$$,$new_shape$jscomp$22_p__70867$$){var $index$jscomp$350_map__70868__$1$$=
$APP.$cljs$core$__destructure_map$$($new_shape$jscomp$22_p__70867$$);$new_shape$jscomp$22_p__70867$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$350_map__70868__$1$$,$cljs$cst$4380$new_shape$$);$index$jscomp$350_map__70868__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$350_map__70868__$1$$,$APP.$cljs$cst$1795$index$$);return $app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$2$jscomp$35$$,$new_shape$jscomp$22_p__70867$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1795$index$$,$index$jscomp$350_map__70868__$1$$],null))},$changes$jscomp$254_changes__$1$jscomp$78_changes__$2$jscomp$34_changes__$3$jscomp$10$$,$APP.$cljs$cst$4379$entries$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$313$$));$changes$jscomp$254_changes__$1$jscomp$78_changes__$2$jscomp$34_changes__$3$jscomp$10$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$3$jscomp$11_changes__$5$jscomp$1$$,$children$jscomp$251_p__70869$$){var $index$jscomp$351_map__70870__$1$$=
$APP.$cljs$core$__destructure_map$$($children$jscomp$251_p__70869$$),$group$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$351_map__70870__$1$$,$APP.$cljs$cst$1608$group$$);$children$jscomp$251_p__70869$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$351_map__70870__$1$$,$APP.$cljs$cst$342$children$$);$index$jscomp$351_map__70870__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$351_map__70870__$1$$,$APP.$cljs$cst$1795$index$$);
$changes__$3$jscomp$11_changes__$5$jscomp$1$$=$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$3$jscomp$11_changes__$5$jscomp$1$$,$group$jscomp$39$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1795$index$$,$index$jscomp$351_map__70870__$1$$],null));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$6$$,$child$jscomp$120$$){return $app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$6$$,
$child$jscomp$120$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$39$$)],null))},$changes__$3$jscomp$11_changes__$5$jscomp$1$$,$children$jscomp$251_p__70869$$)},$changes$jscomp$254_changes__$1$jscomp$78_changes__$2$jscomp$34_changes__$3$jscomp$10$$,$APP.$cljs$cst$4382$groups$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$313$$));return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$254_changes__$1$jscomp$78_changes__$2$jscomp$34_changes__$3$jscomp$10$$,
$cljs$cst$4381$updated_ids$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$313$$),function($shape$jscomp$728$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$728$$,$APP.$cljs$cst$1636$strokes$$,$APP.$cljs$core$PersistentVector$EMPTY$$)})}();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$253$$),$APP.$app$main$data$workspace$selection$select_shapes$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),
$it$jscomp$225_new_shape_ids_selected$jscomp$85$$)))}return null});return new $app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path_70804$$($ids$jscomp$214$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$grid_layout$editor$clean_selection$$=function($grid_id$jscomp$11$$){typeof $app$main$data$workspace$grid_layout$editor$clean_selection_70913$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$clean_selection_70913$$=function($grid_id$jscomp$12$$,$meta70914$$){this.$grid_id$=$grid_id$jscomp$12$$;this.$meta70914$=$meta70914$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$editor$clean_selection_70913$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$clean_selection_70913$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4388$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_clean_selection$$},$app$main$data$workspace$grid_layout$editor$clean_selection_70913$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70915$$,$meta70914__$1$$){return new $app$main$data$workspace$grid_layout$editor$clean_selection_70913$$(this.$grid_id$,
$meta70914__$1$$)},$app$main$data$workspace$grid_layout$editor$clean_selection_70913$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70914$},$app$main$data$workspace$grid_layout$editor$clean_selection_70913$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$clean_selection_70913$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2457_objects$jscomp$619$$,$state$jscomp$819$$){$_$jscomp$2457_objects$jscomp$619$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$819$$);var $shape$jscomp$729$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2457_objects$jscomp$619$$,this.$grid_id$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$819$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2240$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$1921$selected$$],
null),function($selected$jscomp$87$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__70902_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$729$$),$p1__70902_SHARP_$$)}),$selected$jscomp$87$$)})});return new $app$main$data$workspace$grid_layout$editor$clean_selection_70913$$($grid_id$jscomp$11$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shape_layout$get_layout_initializer$$=function($type$jscomp$509$$,$from_frame_QMARK_$$,$calculate_params_QMARK_$$){var $vec__71093$$=function(){var $G__71096__$1$$=$type$jscomp$509$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$509$$.$fqn$:null;switch($G__71096__$1$$){case "flex":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$main$data$workspace$shape_layout$initial_flex_layout$$,$app$common$geom$shapes$flex_layout$calculate_params$$],
null);case "grid":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$main$data$workspace$shape_layout$initial_grid_layout$$,$app$common$geom$shapes$grid_layout$calculate_params$$],null);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__71096__$1$$)].join(""));}}(),$initial_layout_data$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__71093$$,0,null),$calculate_params$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__71093$$,
1,null);return function($shape$jscomp$730$$,$objects$jscomp$622$$){var $shape__$1$jscomp$55$$=function(){var $G__71097$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shape$jscomp$730$$,$initial_layout_data$$]));return $APP.$cljs$core$not$$($from_frame_QMARK_$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71097$$,$APP.$cljs$cst$1876$show_content$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1875$hide_in_viewer$$,
!0])):$G__71097$$}(),$G__71102_params$jscomp$285$$=$APP.$cljs$core$truth_$$($calculate_params_QMARK_$$)?function(){var $G__71100$$=$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$622$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$55$$));return $calculate_params$$.$cljs$core$IFn$_invoke$arity$3$?$calculate_params$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$622$$,$G__71100$$,$shape__$1$jscomp$55$$):$calculate_params$$($objects$jscomp$622$$,
$G__71100$$,$shape__$1$jscomp$55$$)}():null;$G__71102_params$jscomp$285$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shape__$1$jscomp$55$$,$G__71102_params$jscomp$285$$]));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$509$$,$APP.$cljs$cst$1659$grid$$)?$app$common$types$shape$layout$reorder_grid_children$$($APP.$app$common$types$shape$layout$assign_cells$$($G__71102_params$jscomp$285$$,
$objects$jscomp$622$$)):$G__71102_params$jscomp$285$$}};
$app$main$data$workspace$shape_layout$update_layout_positions$$=function($p__71105$$){var $map__71106__$1$$=$APP.$cljs$core$__destructure_map$$($p__71105$$),$page_id$jscomp$241$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71106__$1$$,$APP.$cljs$cst$2043$page_id$$),$ids$jscomp$216$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71106__$1$$,$APP.$cljs$cst$1723$ids$$),$undo_group$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71106__$1$$,$APP.$cljs$cst$3138$undo_group$$);
typeof $app$main$data$workspace$shape_layout$update_layout_positions_71107$$==="undefined"&&($app$main$data$workspace$shape_layout$update_layout_positions_71107$$=function($p__71105$jscomp$1$$,$map__71106$jscomp$1$$,$page_id$jscomp$242$$,$ids$jscomp$217$$,$undo_group$jscomp$39$$,$meta71108$$){this.$p__71105$=$p__71105$jscomp$1$$;this.$map__71106$=$map__71106$jscomp$1$$;this.$page_id$=$page_id$jscomp$242$$;this.ids=$ids$jscomp$217$$;this.$undo_group$=$undo_group$jscomp$39$$;this.$meta71108$=$meta71108$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$update_layout_positions_71107$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$update_layout_positions_71107$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4392$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_layout_positions$$},$app$main$data$workspace$shape_layout$update_layout_positions_71107$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71109$$,$meta71108__$1$$){return new $app$main$data$workspace$shape_layout$update_layout_positions_71107$$(this.$p__71105$,this.$map__71106$,this.$page_id$,this.ids,this.$undo_group$,$meta71108__$1$$)},$app$main$data$workspace$shape_layout$update_layout_positions_71107$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71108$},$app$main$data$workspace$shape_layout$update_layout_positions_71107$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$shape_layout$update_layout_positions_71107$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2461_page_id__$1$jscomp$12$$,$state$jscomp$823$$){var $self__$jscomp$5941$$=this;$_$jscomp$2461_page_id__$1$jscomp$12$$=function(){var $or__5025__auto__$jscomp$840$$=$self__$jscomp$5941$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$840$$)?$or__5025__auto__$jscomp$840$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$823$$)}();
var $objects$jscomp$623$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$823$$,$_$jscomp$2461_page_id__$1$jscomp$12$$),$ids__$1$jscomp$19_modif_tree$jscomp$61$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71103_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($objects$jscomp$623$$,$p1__71103_SHARP_$$)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($app$common$uuid$zero_QMARK_$$,$self__$jscomp$5941$$.ids));return $APP.$app$common$data$not_empty_QMARK_$$($ids__$1$jscomp$19_modif_tree$jscomp$61$$)?
($ids__$1$jscomp$19_modif_tree$jscomp$61$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$($ids__$1$jscomp$19_modif_tree$jscomp$61$$,$APP.$app$common$types$modifiers$reflow$$()),$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$823$$,"render-wasm/v1")?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($ids__$1$jscomp$19_modif_tree$jscomp$61$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3141$stack_undo_QMARK_$$,
!0,$APP.$cljs$cst$3138$undo_group$$,$self__$jscomp$5941$$.$undo_group$,$APP.$cljs$cst$2556$ignore_touched$$,!0]))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2043$page_id$$,$_$jscomp$2461_page_id__$1$jscomp$12$$,$APP.$cljs$cst$1810$modifiers$$,$ids__$1$jscomp$19_modif_tree$jscomp$61$$,$APP.$cljs$cst$3141$stack_undo_QMARK_$$,!0,$APP.$cljs$cst$2556$ignore_touched$$,
!0,$APP.$cljs$cst$3138$undo_group$$,$self__$jscomp$5941$$.$undo_group$],null)))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$shape_layout$update_layout_positions_71107$$($p__71105$$,$map__71106__$1$$,$page_id$jscomp$241$$,$ids$jscomp$216$$,$undo_group$jscomp$38$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shape_layout$initialize_shape_layout$$=function(){typeof $app$main$data$workspace$shape_layout$initialize_shape_layout_71115$$==="undefined"&&($app$main$data$workspace$shape_layout$initialize_shape_layout_71115$$=function($meta71116$$){this.$meta71116$=$meta71116$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$initialize_shape_layout_71115$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$shape_layout$initialize_shape_layout_71115$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4393$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_initialize_shape_layout$$},$app$main$data$workspace$shape_layout$initialize_shape_layout_71115$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71117$$,$meta71116__$1$$){return new $app$main$data$workspace$shape_layout$initialize_shape_layout_71115$$($meta71116__$1$$)},$app$main$data$workspace$shape_layout$initialize_shape_layout_71115$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71116$},$app$main$data$workspace$shape_layout$initialize_shape_layout_71115$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$initialize_shape_layout_71115$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2462_stopper$jscomp$36$$,$___$1$jscomp$1673$$,$stream$jscomp$91$$){$_$jscomp$2462_stopper$jscomp$36$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4394$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_finalize_shape_layout$$),
$stream$jscomp$91$$);return $APP.$beicon$v2$core$take_until$$($_$jscomp$2462_stopper$jscomp$36$$,$APP.$beicon$v2$core$mapcat$$(function($data$jscomp$389$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($ids$jscomp$218_items$jscomp$48_p__71122$$){var $page_id$jscomp$243$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$218_items$jscomp$48_p__71122$$,0,null);$ids$jscomp$218_items$jscomp$48_p__71122$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$218_items$jscomp$48_p__71122$$,
1,null);$ids$jscomp$218_items$jscomp$48_p__71122$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__71113_SHARP_$$,$p2__71114_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($p1__71113_SHARP_$$,$APP.$cljs$cst$1723$ids$$.$cljs$core$IFn$_invoke$arity$1$($p2__71114_SHARP_$$))},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$ids$jscomp$218_items$jscomp$48_p__71122$$);return $app$main$data$workspace$shape_layout$update_layout_positions$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$243$$,$APP.$cljs$cst$1723$ids$$,$ids$jscomp$218_items$jscomp$48_p__71122$$],null))},$APP.$cljs$core$group_by$$($APP.$cljs$cst$2043$page_id$$,$data$jscomp$389$$))},$APP.$beicon$v2$core$filter$$(function($p1__71112_SHARP_$$){return $APP.$app$common$data$not_empty_QMARK_$$($p1__71112_SHARP_$$)},$APP.$beicon$v2$core$buffer_time$cljs$0core$0IFn$0_invoke$0arity$02$$(100,$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3624$layout_SLASH_update$$),
$stream$jscomp$91$$))))))});return new $app$main$data$workspace$shape_layout$initialize_shape_layout_71115$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shape_layout$create_layout_from_id$$=function($var_args$jscomp$1321$$){for(var $args__5755__auto__$jscomp$232$$=[],$len__5749__auto___71307$$=arguments.length,$i__5750__auto___71308$$=0;;)if($i__5750__auto___71308$$<$len__5749__auto___71307$$)$args__5755__auto__$jscomp$232$$.push(arguments[$i__5750__auto___71308$$]),$i__5750__auto___71308$$+=1;else break;return $APP.$app$main$data$workspace$shape_layout$create_layout_from_id$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
arguments[1],2<$args__5755__auto__$jscomp$232$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$232$$.slice(2),0,null):null)};
$APP.$app$main$data$workspace$shape_layout$create_layout_from_id$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($id$jscomp$734$$,$type$jscomp$510$$,$p__71130$$){var $map__71131__$1$$=$APP.$cljs$core$__destructure_map$$($p__71130$$),$from_frame_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__71131__$1$$,$APP.$cljs$cst$4395$from_frame_QMARK_$$,!1),$calculate_params_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__71131__$1$$,$APP.$cljs$cst$4396$calculate_params_QMARK_$$,
!0);typeof $app$main$data$workspace$shape_layout$create_layout_from_id_71132$$==="undefined"&&($app$main$data$workspace$shape_layout$create_layout_from_id_71132$$=function($id$jscomp$735$$,$type$jscomp$511$$,$p__71130$jscomp$1$$,$map__71131$jscomp$1$$,$from_frame_QMARK_$jscomp$2$$,$calculate_params_QMARK_$jscomp$2$$,$meta71133$$){this.id=$id$jscomp$735$$;this.type=$type$jscomp$511$$;this.$p__71130$=$p__71130$jscomp$1$$;this.$map__71131$=$map__71131$jscomp$1$$;this.$from_frame_QMARK_$=$from_frame_QMARK_$jscomp$2$$;
this.$calculate_params_QMARK_$=$calculate_params_QMARK_$jscomp$2$$;this.$meta71133$=$meta71133$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$create_layout_from_id_71132$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$create_layout_from_id_71132$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4397$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_create_layout_from_id$$},
$app$main$data$workspace$shape_layout$create_layout_from_id_71132$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71134$$,$meta71133__$1$$){return new $app$main$data$workspace$shape_layout$create_layout_from_id_71132$$(this.id,this.type,this.$p__71130$,this.$map__71131$,this.$from_frame_QMARK_$,this.$calculate_params_QMARK_$,$meta71133__$1$$)},$app$main$data$workspace$shape_layout$create_layout_from_id_71132$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71133$},
$app$main$data$workspace$shape_layout$create_layout_from_id_71132$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$create_layout_from_id_71132$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2463_objects$jscomp$624_parent$jscomp$277$$,$state$jscomp$824_undo_id$jscomp$47$$){$_$jscomp$2463_objects$jscomp$624_parent$jscomp$277$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$824_undo_id$jscomp$47$$);
$_$jscomp$2463_objects$jscomp$624_parent$jscomp$277$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2463_objects$jscomp$624_parent$jscomp$277$$,this.id);$state$jscomp$824_undo_id$jscomp$47$$=Symbol();var $layout_initializer$$=$app$main$data$workspace$shape_layout$get_layout_initializer$$(this.type,this.$from_frame_QMARK_$,this.$calculate_params_QMARK_$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($state$jscomp$824_undo_id$jscomp$47$$),
$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.id],null),$layout_initializer$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2463_objects$jscomp$624_parent$jscomp$277$$?.shapes??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2463_objects$jscomp$624_parent$jscomp$277$$,
$APP.$cljs$cst$1614$shapes$$),function($p1__71126_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__71126_SHARP_$$,$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1871$constraints_v$$]))}),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.id],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($state$jscomp$824_undo_id$jscomp$47$$))});return new $app$main$data$workspace$shape_layout$create_layout_from_id_71132$$($id$jscomp$734$$,$type$jscomp$510$$,$p__71130$$,$map__71131__$1$$,$from_frame_QMARK_$jscomp$1$$,$calculate_params_QMARK_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shape_layout$create_layout_from_selection$$=function($type$jscomp$512$$){typeof $app$main$data$workspace$shape_layout$create_layout_from_selection_71137$$==="undefined"&&($app$main$data$workspace$shape_layout$create_layout_from_selection_71137$$=function($type$jscomp$513$$,$meta71138$$){this.type=$type$jscomp$513$$;this.$meta71138$=$meta71138$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$create_layout_from_selection_71137$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$create_layout_from_selection_71137$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4398$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_create_layout_from_selection$$},$app$main$data$workspace$shape_layout$create_layout_from_selection_71137$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71139$$,$meta71138__$1$$){return new $app$main$data$workspace$shape_layout$create_layout_from_selection_71137$$(this.type,
$meta71138__$1$$)},$app$main$data$workspace$shape_layout$create_layout_from_selection_71137$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71138$},$app$main$data$workspace$shape_layout$create_layout_from_selection_71137$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$create_layout_from_selection_71137$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2464_has_layout_QMARK__single_QMARK_$$,
$has_group_QMARK__is_group_QMARK__state$jscomp$825$$){var $self__$jscomp$5953$$=this,$page_id$jscomp$244$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($has_group_QMARK__is_group_QMARK__state$jscomp$825$$),$objects$jscomp$625$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($has_group_QMARK__is_group_QMARK__state$jscomp$825$$,$page_id$jscomp$244$$),$selected$jscomp$89$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($has_group_QMARK__is_group_QMARK__state$jscomp$825$$),
$selected_shapes$jscomp$2$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$625$$),$selected$jscomp$89$$);$_$jscomp$2464_has_layout_QMARK__single_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_shapes$jscomp$2$$),1);$has_group_QMARK__is_group_QMARK__state$jscomp$825$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$group_shape_QMARK_$$,$selected_shapes$jscomp$2$$);
$has_group_QMARK__is_group_QMARK__state$jscomp$825$$=$_$jscomp$2464_has_layout_QMARK__single_QMARK_$$?$has_group_QMARK__is_group_QMARK__state$jscomp$825$$:$_$jscomp$2464_has_layout_QMARK__single_QMARK_$$;var $has_mask_QMARK__is_mask_QMARK_$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$mask_shape_QMARK_$$,$selected_shapes$jscomp$2$$);$has_mask_QMARK__is_mask_QMARK_$$=$_$jscomp$2464_has_layout_QMARK__single_QMARK_$$?$has_mask_QMARK__is_mask_QMARK_$$:
$_$jscomp$2464_has_layout_QMARK__single_QMARK_$$;var $has_component_QMARK__is_component_QMARK_$jscomp$1$$=$APP.$cljs$core$some$$($APP.$cljs$core$true_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$instance_root_QMARK_$$,$selected_shapes$jscomp$2$$));$has_component_QMARK__is_component_QMARK_$jscomp$1$$=$_$jscomp$2464_has_layout_QMARK__single_QMARK_$$?$has_component_QMARK__is_component_QMARK_$jscomp$1$$:$_$jscomp$2464_has_layout_QMARK__single_QMARK_$$;
var $has_variant_QMARK_$$=$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$selected_shapes$jscomp$2$$);$_$jscomp$2464_has_layout_QMARK__single_QMARK_$$=$_$jscomp$2464_has_layout_QMARK__single_QMARK_$$&&$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_shapes$jscomp$2$$));var $new_shape_id$jscomp$2$$=$APP.$app$common$uuid$next$$(),$undo_id$jscomp$48$$=Symbol();return $APP.$cljs$core$truth_$$($has_variant_QMARK_$$)?
$APP.$beicon$v2$core$empty$$():$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$48$$)),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($has_group_QMARK__is_group_QMARK__state$jscomp$825$$)?$APP.$cljs$core$not$$($has_component_QMARK__is_component_QMARK_$jscomp$1$$)&&$APP.$cljs$core$not$$($has_mask_QMARK__is_mask_QMARK_$$):$has_group_QMARK__is_group_QMARK__state$jscomp$825$$)?function(){var $parent_id$jscomp$94$$=
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_shapes$jscomp$2$$)),$ordered_ids$jscomp$1_shapes_ids$jscomp$1$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_shapes$jscomp$2$$));$ordered_ids$jscomp$1_shapes_ids$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$ordered_ids$jscomp$1_shapes_ids$jscomp$1$$);var $group_index$$=
$app$common$files$helpers$get_position_on_parent$$($objects$jscomp$625$$,$APP.$cljs$core$first$$($app$common$files$helpers$order_by_indexed_shapes$$($objects$jscomp$625$$,$selected$jscomp$89$$)))+1;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$select_shapes$$($ordered_ids$jscomp$1_shapes_ids$jscomp$1$$),$app$main$data$workspace$shapes$create_artboard_from_selection$cljs$0core$0IFn$0_invoke$0arity$04$$($new_shape_id$jscomp$2$$,$parent_id$jscomp$94$$,$group_index$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_shapes$jscomp$2$$))),
$APP.$app$main$data$workspace$colors$remove_all_fills$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_shape_id$jscomp$2$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,"#000000",$APP.$cljs$cst$1734$opacity$$,1],null)),$app$main$data$workspace$shape_layout$create_layout_from_id$$($new_shape_id$jscomp$2$$,$self__$jscomp$5953$$.type),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_shape_id$jscomp$2$$],null),function($p1__71135_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__71135_SHARP_$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$,$APP.$cljs$cst$1672$auto$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1672$auto$$]))}),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($selected$jscomp$89$$,
$app$common$types$shape$layout$toggle_fix_if_auto$$),$APP.$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($page_id$jscomp$244$$,$selected$jscomp$89$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_shape_id$jscomp$2$$],null)],null)),
$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$48$$))}():$_$jscomp$2464_has_layout_QMARK__single_QMARK_$$?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$shape_layout$create_layout_from_id$$($APP.$cljs$core$first$$($selected$jscomp$89$$),$self__$jscomp$5953$$.type),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$selected$jscomp$89$$],
null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$48$$)):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$create_artboard_from_selection$cljs$0core$0IFn$0_invoke$0arity$05$$($new_shape_id$jscomp$2$$,null,null,null),$APP.$app$main$data$workspace$colors$remove_all_fills$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_shape_id$jscomp$2$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1298$color$$,"#000000",$APP.$cljs$cst$1734$opacity$$,1],null)),$app$main$data$workspace$shape_layout$create_layout_from_id$$($new_shape_id$jscomp$2$$,$self__$jscomp$5953$$.type),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_shape_id$jscomp$2$$],null),function($p1__71136_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__71136_SHARP_$$,
$APP.$cljs$cst$1708$layout_item_h_sizing$$,$APP.$cljs$cst$1672$auto$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1672$auto$$]))}),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($selected$jscomp$89$$,$app$common$types$shape$layout$toggle_fix_if_auto$$)),(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_shape_id$jscomp$2$$],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$48$$)))});return new $app$main$data$workspace$shape_layout$create_layout_from_selection_71137$$($type$jscomp$512$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$shape_layout$remove_layout$$=function($ids$jscomp$219$$){typeof $app$main$data$workspace$shape_layout$remove_shape_layout_71145$$==="undefined"&&($app$main$data$workspace$shape_layout$remove_shape_layout_71145$$=function($ids$jscomp$220$$,$meta71146$$){this.ids=$ids$jscomp$220$$;this.$meta71146$=$meta71146$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$remove_shape_layout_71145$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$remove_shape_layout_71145$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4399$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_remove_shape_layout$$},$app$main$data$workspace$shape_layout$remove_shape_layout_71145$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71147$$,$meta71146__$1$$){return new $app$main$data$workspace$shape_layout$remove_shape_layout_71145$$(this.ids,
$meta71146__$1$$)},$app$main$data$workspace$shape_layout$remove_shape_layout_71145$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71146$},$app$main$data$workspace$shape_layout$remove_shape_layout_71145$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$remove_shape_layout_71145$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $undo_id$jscomp$49$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$49$$),
$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(this.ids,function($p1__71144_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$,$p1__71144_SHARP_$$,$app$main$data$workspace$shape_layout$layout_keys$$)}),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,this.ids],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$49$$))});
return new $app$main$data$workspace$shape_layout$remove_shape_layout_71145$$($ids$jscomp$219$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$shape_layout$create_layout$$=function($type$jscomp$514$$){typeof $app$main$data$workspace$shape_layout$create_shape_layout_71149$$==="undefined"&&($app$main$data$workspace$shape_layout$create_shape_layout_71149$$=function($type$jscomp$515$$,$meta71150$$){this.type=$type$jscomp$515$$;this.$meta71150$=$meta71150$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$create_shape_layout_71149$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$create_shape_layout_71149$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4400$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_create_shape_layout$$},$app$main$data$workspace$shape_layout$create_shape_layout_71149$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71151$$,$meta71150__$1$$){return new $app$main$data$workspace$shape_layout$create_shape_layout_71149$$(this.type,
$meta71150__$1$$)},$app$main$data$workspace$shape_layout$create_shape_layout_71149$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71150$},$app$main$data$workspace$shape_layout$create_shape_layout_71149$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$create_shape_layout_71149$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1615$layout$$,
$APP.$app$common$data$name$$(this.type)],null)},$app$main$data$workspace$shape_layout$create_shape_layout_71149$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$create_shape_layout_71149$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2467_objects$jscomp$626_page_id$jscomp$245_single_QMARK_$jscomp$1$$,$selected$jscomp$90_state$jscomp$826$$){$_$jscomp$2467_objects$jscomp$626_page_id$jscomp$245_single_QMARK_$jscomp$1$$=
$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$90_state$jscomp$826$$);$_$jscomp$2467_objects$jscomp$626_page_id$jscomp$245_single_QMARK_$jscomp$1$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$90_state$jscomp$826$$,$_$jscomp$2467_objects$jscomp$626_page_id$jscomp$245_single_QMARK_$jscomp$1$$);$selected$jscomp$90_state$jscomp$826$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($selected$jscomp$90_state$jscomp$826$$);
var $has_layout_QMARK_$jscomp$1_selected_shapes$jscomp$3$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($_$jscomp$2467_objects$jscomp$626_page_id$jscomp$245_single_QMARK_$jscomp$1$$),$selected$jscomp$90_state$jscomp$826$$);$_$jscomp$2467_objects$jscomp$626_page_id$jscomp$245_single_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($has_layout_QMARK_$jscomp$1_selected_shapes$jscomp$3$$),1);var $is_frame_QMARK_$jscomp$3$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($has_layout_QMARK_$jscomp$1_selected_shapes$jscomp$3$$)));$has_layout_QMARK_$jscomp$1_selected_shapes$jscomp$3$$=$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($has_layout_QMARK_$jscomp$1_selected_shapes$jscomp$3$$));var $undo_id$jscomp$50$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$50$$),
$_$jscomp$2467_objects$jscomp$626_page_id$jscomp$245_single_QMARK_$jscomp$1$$&&$is_frame_QMARK_$jscomp$3$$&&!$has_layout_QMARK_$jscomp$1_selected_shapes$jscomp$3$$?$APP.$app$main$data$workspace$shape_layout$create_layout_from_id$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$first$$($selected$jscomp$90_state$jscomp$826$$),this.type,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4395$from_frame_QMARK_$$,!0])):$app$main$data$workspace$shape_layout$create_layout_from_selection$$(this.type),
$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$50$$))});return new $app$main$data$workspace$shape_layout$create_shape_layout_71149$$($type$jscomp$514$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shape_layout$toggle_layout$$=function($type$jscomp$516$$){typeof $app$main$data$workspace$shape_layout$toggle_shape_layout_71156$$==="undefined"&&($app$main$data$workspace$shape_layout$toggle_shape_layout_71156$$=function($type$jscomp$517$$,$meta71157$$){this.type=$type$jscomp$517$$;this.$meta71157$=$meta71157$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$toggle_shape_layout_71156$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$toggle_shape_layout_71156$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4401$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_toggle_shape_layout$$},$app$main$data$workspace$shape_layout$toggle_shape_layout_71156$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71158$$,$meta71157__$1$$){return new $app$main$data$workspace$shape_layout$toggle_shape_layout_71156$$(this.type,
$meta71157__$1$$)},$app$main$data$workspace$shape_layout$toggle_shape_layout_71156$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71157$},$app$main$data$workspace$shape_layout$toggle_shape_layout_71156$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$toggle_shape_layout_71156$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($event$jscomp$105_has_layout_QMARK_$jscomp$2_it$jscomp$226_objects$jscomp$627$$,
$selected$jscomp$91_state$jscomp$827$$){$event$jscomp$105_has_layout_QMARK_$jscomp$2_it$jscomp$226_objects$jscomp$627$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$91_state$jscomp$827$$);$selected$jscomp$91_state$jscomp$827$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($selected$jscomp$91_state$jscomp$827$$);var $selected_shapes$jscomp$4$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($event$jscomp$105_has_layout_QMARK_$jscomp$2_it$jscomp$226_objects$jscomp$627$$),
$selected$jscomp$91_state$jscomp$827$$),$single_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_shapes$jscomp$4$$),1);$event$jscomp$105_has_layout_QMARK_$jscomp$2_it$jscomp$226_objects$jscomp$627$$=$single_QMARK_$jscomp$2$$?$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$105_has_layout_QMARK_$jscomp$2_it$jscomp$226_objects$jscomp$627$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_shapes$jscomp$4$$))):
$single_QMARK_$jscomp$2$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$cljs$core$count$$($selected$jscomp$91_state$jscomp$827$$))?($event$jscomp$105_has_layout_QMARK_$jscomp$2_it$jscomp$226_objects$jscomp$627$$=$APP.$cljs$core$truth_$$($event$jscomp$105_has_layout_QMARK_$jscomp$2_it$jscomp$226_objects$jscomp$627$$)?$APP.$app$main$data$workspace$shape_layout$remove_layout$$($selected$jscomp$91_state$jscomp$827$$):$APP.$app$main$data$workspace$shape_layout$create_layout$$(this.type),
(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$with_meta$$($event$jscomp$105_has_layout_QMARK_$jscomp$2_it$jscomp$226_objects$jscomp$627$$,$APP.$cljs$core$meta$$(this)))):null});return new $app$main$data$workspace$shape_layout$toggle_shape_layout_71156$$($type$jscomp$516$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$=function($ids$jscomp$221$$,$changes$jscomp$255$$){return $app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$221$$,$changes$jscomp$255$$,null)};
$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$222$$,$changes$jscomp$256$$,$options$jscomp$571$$){typeof $app$main$data$workspace$shape_layout$update_layout_71167$$==="undefined"&&($app$main$data$workspace$shape_layout$update_layout_71167$$=function($ids$jscomp$223$$,$changes$jscomp$257$$,$options$jscomp$572$$,$meta71168$$){this.ids=$ids$jscomp$223$$;this.$changes$=$changes$jscomp$257$$;this.options=$options$jscomp$572$$;this.$meta71168$=
$meta71168$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$update_layout_71167$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$update_layout_71167$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4402$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_layout$$},$app$main$data$workspace$shape_layout$update_layout_71167$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71169$$,$meta71168__$1$$){return new $app$main$data$workspace$shape_layout$update_layout_71167$$(this.ids,this.$changes$,this.options,$meta71168__$1$$)},$app$main$data$workspace$shape_layout$update_layout_71167$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71168$},$app$main$data$workspace$shape_layout$update_layout_71167$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$update_layout_71167$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$5970$$=this,$undo_id$jscomp$51$$=Symbol(),$padding_attrs$$=$APP.$cljs$core$set$$($APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5970$$.$changes$,$APP.$cljs$cst$1686$layout_padding$$)));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$51$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5970$$.ids,$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5970$$.$changes$),
function(){var $G__71170$$=$self__$jscomp$5970$$.options;return $APP.$cljs$core$seq$$($padding_attrs$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71170$$,$APP.$cljs$cst$3521$changed_sub_attr$$,$padding_attrs$$):$G__71170$$}()),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$self__$jscomp$5970$$.ids],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$51$$),
$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$841$$=$APP.$cljs$cst$1691$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5970$$.$changes$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$841$$)?$or__5025__auto__$jscomp$841$$:$APP.$cljs$cst$1689$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5970$$.$changes$)}())?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"layout-change-alignment"],null)):null,$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$842$$=$APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5970$$.$changes$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$842$$)?$or__5025__auto__$jscomp$842$$:$APP.$cljs$cst$1680$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5970$$.$changes$)}())?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"layout-change-margin"],null)):null)});return new $app$main$data$workspace$shape_layout$update_layout_71167$$($ids$jscomp$222$$,$changes$jscomp$256$$,$options$jscomp$571$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$224$$,$type$jscomp$518$$,$value$jscomp$604$$){return $APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$04$$($ids$jscomp$224$$,$type$jscomp$518$$,$value$jscomp$604$$,null)};
$APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$04$$=function($ids$jscomp$225$$,$type$jscomp$519$$,$value$jscomp$605$$,$index$jscomp$354$$){typeof $app$main$data$workspace$shape_layout$add_layout_track_71175$$==="undefined"&&($app$main$data$workspace$shape_layout$add_layout_track_71175$$=function($ids$jscomp$226$$,$type$jscomp$520$$,$value$jscomp$606$$,$index$jscomp$355$$,$meta71176$$){this.ids=$ids$jscomp$226$$;this.type=$type$jscomp$520$$;this.value=$value$jscomp$606$$;
this.index=$index$jscomp$355$$;this.$meta71176$=$meta71176$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$add_layout_track_71175$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$add_layout_track_71175$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4403$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_add_layout_track$$},
$app$main$data$workspace$shape_layout$add_layout_track_71175$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71177$$,$meta71176__$1$$){return new $app$main$data$workspace$shape_layout$add_layout_track_71175$$(this.ids,this.type,this.value,this.index,$meta71176__$1$$)},$app$main$data$workspace$shape_layout$add_layout_track_71175$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71176$},$app$main$data$workspace$shape_layout$add_layout_track_71175$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$add_layout_track_71175$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$5974$$=this,$undo_id$jscomp$52$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$52$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5974$$.ids,function($shape$jscomp$731$$){var $G__71182_G__71182__$1$$=
$self__$jscomp$5974$$.type;$G__71182_G__71182__$1$$=$G__71182_G__71182__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__71182_G__71182__$1$$.$fqn$:null;switch($G__71182_G__71182__$1$$){case "row":return $APP.$app$common$types$shape$layout$add_grid_row$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$731$$,$self__$jscomp$5974$$.value,$self__$jscomp$5974$$.index);case "column":return $APP.$app$common$types$shape$layout$add_grid_column$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$731$$,$self__$jscomp$5974$$.value,
$self__$jscomp$5974$$.index);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__71182_G__71182__$1$$)].join(""));}}),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$self__$jscomp$5974$$.ids],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$52$$))});return new $app$main$data$workspace$shape_layout$add_layout_track_71175$$($ids$jscomp$225$$,
$type$jscomp$519$$,$value$jscomp$605$$,$index$jscomp$354$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$shape_layout$remove_layout_track$$=function($var_args$jscomp$1324$$){for(var $args__5755__auto__$jscomp$233$$=[],$len__5749__auto___71350$$=arguments.length,$i__5750__auto___71351$$=0;;)if($i__5750__auto___71351$$<$len__5749__auto___71350$$)$args__5755__auto__$jscomp$233$$.push(arguments[$i__5750__auto___71351$$]),$i__5750__auto___71351$$+=1;else break;return $APP.$app$main$data$workspace$shape_layout$remove_layout_track$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],
arguments[2],3<$args__5755__auto__$jscomp$233$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$233$$.slice(3),0,null):null)};
$APP.$app$main$data$workspace$shape_layout$remove_layout_track$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($ids$jscomp$227$$,$type$jscomp$521$$,$index$jscomp$356$$,$p__71190$$){var $map__71191__$1$$=$APP.$cljs$core$__destructure_map$$($p__71190$$),$with_shapes_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__71191__$1$$,$APP.$cljs$cst$4404$with_shapes_QMARK_$$,!1);typeof $app$main$data$workspace$shape_layout$remove_layout_track_71192$$==="undefined"&&($app$main$data$workspace$shape_layout$remove_layout_track_71192$$=
function($ids$jscomp$228$$,$type$jscomp$522$$,$index$jscomp$357$$,$p__71190$jscomp$1$$,$map__71191$jscomp$1$$,$with_shapes_QMARK_$jscomp$1$$,$meta71193$$){this.ids=$ids$jscomp$228$$;this.type=$type$jscomp$522$$;this.index=$index$jscomp$357$$;this.$p__71190$=$p__71190$jscomp$1$$;this.$map__71191$=$map__71191$jscomp$1$$;this.$with_shapes_QMARK_$=$with_shapes_QMARK_$jscomp$1$$;this.$meta71193$=$meta71193$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},
$app$main$data$workspace$shape_layout$remove_layout_track_71192$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$remove_layout_track_71192$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4405$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_remove_layout_track$$},$app$main$data$workspace$shape_layout$remove_layout_track_71192$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71194$$,$meta71193__$1$$){return new $app$main$data$workspace$shape_layout$remove_layout_track_71192$$(this.ids,
this.type,this.index,this.$p__71190$,this.$map__71191$,this.$with_shapes_QMARK_$,$meta71193__$1$$)},$app$main$data$workspace$shape_layout$remove_layout_track_71192$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71193$},$app$main$data$workspace$shape_layout$remove_layout_track_71192$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$remove_layout_track_71192$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2471_undo_id$jscomp$53$$,$shapes_to_delete_state$jscomp$828$$){var $self__$jscomp$5978$$=this,$objects$jscomp$628$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($shapes_to_delete_state$jscomp$828$$);$_$jscomp$2471_undo_id$jscomp$53$$=Symbol();$shapes_to_delete_state$jscomp$828$$=$APP.$cljs$core$truth_$$($self__$jscomp$5978$$.$with_shapes_QMARK_$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($id$jscomp$736_shape$jscomp$732$$){$id$jscomp$736_shape$jscomp$732$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$628$$,$id$jscomp$736_shape$jscomp$732$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5978$$.type,$APP.$cljs$cst$216$column$$)?$APP.$app$common$types$shape$layout$shapes_by_column$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$736_shape$jscomp$732$$,$self__$jscomp$5978$$.index):
$APP.$app$common$types$shape$layout$shapes_by_row$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$736_shape$jscomp$732$$,$self__$jscomp$5978$$.index)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$5978$$.ids]))):null;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($_$jscomp$2471_undo_id$jscomp$53$$),$APP.$cljs$core$truth_$$($shapes_to_delete_state$jscomp$828$$)?$APP.$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$01$$($shapes_to_delete_state$jscomp$828$$):
$APP.$beicon$v2$core$empty$$(),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5978$$.ids,function($shape$jscomp$733$$,$objects__$1$jscomp$26$$){var $G__71195_G__71195__$1$$=$self__$jscomp$5978$$.type;$G__71195_G__71195__$1$$=$G__71195_G__71195__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__71195_G__71195__$1$$.$fqn$:null;switch($G__71195_G__71195__$1$$){case "row":return $app$common$types$shape$layout$remove_grid_row$$($shape$jscomp$733$$,$self__$jscomp$5978$$.index,
$objects__$1$jscomp$26$$);case "column":return $app$common$types$shape$layout$remove_grid_column$$($shape$jscomp$733$$,$self__$jscomp$5978$$.index,$objects__$1$jscomp$26$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__71195_G__71195__$1$$)].join(""));}},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$self__$jscomp$5978$$.ids],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($_$jscomp$2471_undo_id$jscomp$53$$))});return new $app$main$data$workspace$shape_layout$remove_layout_track_71192$$($ids$jscomp$227$$,$type$jscomp$521$$,$index$jscomp$356$$,$p__71190$$,$map__71191__$1$$,$with_shapes_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$shape_layout$change_layout_track$$=function($ids$jscomp$235$$,$type$jscomp$529$$,$index$jscomp$362$$,$props$jscomp$201$$){typeof $app$main$data$workspace$shape_layout$change_layout_track_71227$$==="undefined"&&($app$main$data$workspace$shape_layout$change_layout_track_71227$$=function($ids$jscomp$236$$,$type$jscomp$530$$,$index$jscomp$363$$,$props$jscomp$202$$,$meta71228$$){this.ids=$ids$jscomp$236$$;this.type=$type$jscomp$530$$;this.index=$index$jscomp$363$$;this.props=
$props$jscomp$202$$;this.$meta71228$=$meta71228$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$change_layout_track_71227$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$change_layout_track_71227$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4410$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_change_layout_track$$},
$app$main$data$workspace$shape_layout$change_layout_track_71227$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71229$$,$meta71228__$1$$){return new $app$main$data$workspace$shape_layout$change_layout_track_71227$$(this.ids,this.type,this.index,this.props,$meta71228__$1$$)},$app$main$data$workspace$shape_layout$change_layout_track_71227$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71228$},$app$main$data$workspace$shape_layout$change_layout_track_71227$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$change_layout_track_71227$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$5994$$=this,$undo_id$jscomp$56$$=Symbol(),$property$jscomp$43$$=function(){var $G__71232_G__71232__$1$$=$self__$jscomp$5994$$.type;$G__71232_G__71232__$1$$=$G__71232_G__71232__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__71232_G__71232__$1$$.$fqn$:null;switch($G__71232_G__71232__$1$$){case "row":return $APP.$cljs$cst$1694$layout_grid_rows$$;
case "column":return $APP.$cljs$cst$1695$layout_grid_columns$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__71232_G__71232__$1$$)].join(""));}}();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$56$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5994$$.ids,function($shape$jscomp$737$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$737$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$property$jscomp$43$$,$self__$jscomp$5994$$.index],null),$APP.$cljs$core$merge$$,$self__$jscomp$5994$$.props)}),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$self__$jscomp$5994$$.ids],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$56$$))});
return new $app$main$data$workspace$shape_layout$change_layout_track_71227$$($ids$jscomp$235$$,$type$jscomp$529$$,$index$jscomp$362$$,$props$jscomp$201$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shape_layout$fix_child_sizing$$=function($all_children$jscomp$1_objects$jscomp$631$$,$auto_height_QMARK_$jscomp$7_parent_changes$$,$G__71236__$3_shape$jscomp$738$$){var $G__71236__$1_parent$jscomp$278$$=$APP.$app$common$data$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$($app$common$files$helpers$get_parent$$($all_children$jscomp$1_objects$jscomp$631$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__71236__$3_shape$jscomp$738$$)),$auto_height_QMARK_$jscomp$7_parent_changes$$),
$auto_width_QMARK_$jscomp$8$$=$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($G__71236__$1_parent$jscomp$278$$);$auto_height_QMARK_$jscomp$7_parent_changes$$=$APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($G__71236__$1_parent$jscomp$278$$);var $G__71236__$2_col_QMARK_$jscomp$12$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__71236__$1_parent$jscomp$278$$),$row_QMARK_$jscomp$12$$=
$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($G__71236__$1_parent$jscomp$278$$);$all_children$jscomp$1_objects$jscomp$631$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($all_children$jscomp$1_objects$jscomp$631$$),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($G__71236__$1_parent$jscomp$278$$)));
$G__71236__$1_parent$jscomp$278$$=$G__71236__$2_col_QMARK_$jscomp$12$$&&$auto_width_QMARK_$jscomp$8$$&&$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$shape$layout$fill_width_QMARK_$$,$all_children$jscomp$1_objects$jscomp$631$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71236__$3_shape$jscomp$738$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$,$APP.$cljs$cst$1697$fix$$):$G__71236__$3_shape$jscomp$738$$;$G__71236__$2_col_QMARK_$jscomp$12$$=$G__71236__$2_col_QMARK_$jscomp$12$$&&
$auto_height_QMARK_$jscomp$7_parent_changes$$&&$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__71236__$3_shape$jscomp$738$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71236__$1_parent$jscomp$278$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1697$fix$$):$G__71236__$1_parent$jscomp$278$$;$G__71236__$3_shape$jscomp$738$$=$row_QMARK_$jscomp$12$$&&$auto_width_QMARK_$jscomp$8$$&&$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__71236__$3_shape$jscomp$738$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71236__$2_col_QMARK_$jscomp$12$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$,$APP.$cljs$cst$1697$fix$$):$G__71236__$2_col_QMARK_$jscomp$12$$;return $row_QMARK_$jscomp$12$$&&$auto_height_QMARK_$jscomp$7_parent_changes$$&&$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$shape$layout$fill_height_QMARK_$$,$all_children$jscomp$1_objects$jscomp$631$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71236__$3_shape$jscomp$738$$,
$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1697$fix$$):$G__71236__$3_shape$jscomp$738$$};
$app$main$data$workspace$shape_layout$fix_parent_sizing$$=function($G__71243__$1_parent$jscomp$279$$,$all_children$jscomp$2_objects$jscomp$632$$,$ids_set$jscomp$2$$,$changes$jscomp$259$$){var $G__71243__$3_auto_width_QMARK_$jscomp$9$$=$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($G__71243__$1_parent$jscomp$279$$),$auto_height_QMARK_$jscomp$8$$=$APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($G__71243__$1_parent$jscomp$279$$),$G__71243__$2_col_QMARK_$jscomp$13$$=
$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__71243__$1_parent$jscomp$279$$),$row_QMARK_$jscomp$13$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($G__71243__$1_parent$jscomp$279$$);$all_children$jscomp$2_objects$jscomp$632$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($shape$jscomp$739$$){return $APP.$cljs$core$contains_QMARK_$$($ids_set$jscomp$2$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$739$$))?
$APP.$app$common$data$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$739$$,$changes$jscomp$259$$):$shape$jscomp$739$$},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($all_children$jscomp$2_objects$jscomp$632$$),$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($G__71243__$1_parent$jscomp$279$$)));$G__71243__$1_parent$jscomp$279$$=$G__71243__$2_col_QMARK_$jscomp$13$$&&$G__71243__$3_auto_width_QMARK_$jscomp$9$$&&$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$shape$layout$fill_width_QMARK_$$,
$all_children$jscomp$2_objects$jscomp$632$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71243__$1_parent$jscomp$279$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$,$APP.$cljs$cst$1697$fix$$):$G__71243__$1_parent$jscomp$279$$;$G__71243__$2_col_QMARK_$jscomp$13$$=$APP.$cljs$core$truth_$$($G__71243__$2_col_QMARK_$jscomp$13$$?$auto_height_QMARK_$jscomp$8$$?$APP.$cljs$core$some$$($APP.$app$common$types$shape$layout$fill_height_QMARK_$$,$all_children$jscomp$2_objects$jscomp$632$$):$auto_height_QMARK_$jscomp$8$$:
$G__71243__$2_col_QMARK_$jscomp$13$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71243__$1_parent$jscomp$279$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1697$fix$$):$G__71243__$1_parent$jscomp$279$$;$G__71243__$3_auto_width_QMARK_$jscomp$9$$=$APP.$cljs$core$truth_$$($row_QMARK_$jscomp$13$$?$G__71243__$3_auto_width_QMARK_$jscomp$9$$?$APP.$cljs$core$some$$($APP.$app$common$types$shape$layout$fill_width_QMARK_$$,$all_children$jscomp$2_objects$jscomp$632$$):$G__71243__$3_auto_width_QMARK_$jscomp$9$$:
$row_QMARK_$jscomp$13$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71243__$2_col_QMARK_$jscomp$13$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$,$APP.$cljs$cst$1697$fix$$):$G__71243__$2_col_QMARK_$jscomp$13$$;return $row_QMARK_$jscomp$13$$&&$auto_height_QMARK_$jscomp$8$$&&$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$shape$layout$fill_height_QMARK_$$,$all_children$jscomp$2_objects$jscomp$632$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71243__$3_auto_width_QMARK_$jscomp$9$$,
$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1697$fix$$):$G__71243__$3_auto_width_QMARK_$jscomp$9$$};$APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$=function($ids$jscomp$237$$,$attrs$jscomp$150$$){return $app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$237$$,$attrs$jscomp$150$$,null)};
$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$238$$,$attrs$jscomp$151$$,$options$jscomp$573$$){typeof $app$main$data$workspace$shape_layout$update_layout_child_71248$$==="undefined"&&($app$main$data$workspace$shape_layout$update_layout_child_71248$$=function($ids$jscomp$239$$,$attrs$jscomp$152$$,$options$jscomp$574$$,$meta71249$$){this.ids=$ids$jscomp$239$$;this.$attrs$=$attrs$jscomp$152$$;this.options=$options$jscomp$574$$;this.$meta71249$=
$meta71249$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$update_layout_child_71248$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$update_layout_child_71248$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4411$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_layout_child$$},$app$main$data$workspace$shape_layout$update_layout_child_71248$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71250$$,$meta71249__$1$$){return new $app$main$data$workspace$shape_layout$update_layout_child_71248$$(this.ids,this.$attrs$,this.options,$meta71249__$1$$)},$app$main$data$workspace$shape_layout$update_layout_child_71248$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71249$},$app$main$data$workspace$shape_layout$update_layout_child_71248$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$update_layout_child_71248$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2476_children_ids$jscomp$12_page_id$jscomp$246$$,$state$jscomp$831$$){var $self__$jscomp$5998$$=this;$_$jscomp$2476_children_ids$jscomp$12_page_id$jscomp$246$$=function(){var $or__5025__auto__$jscomp$843$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5998$$.options,$APP.$cljs$cst$2043$page_id$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$843$$)?$or__5025__auto__$jscomp$843$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$831$$,
$APP.$cljs$cst$1918$current_page_id$$)}();var $objects$jscomp$633$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$831$$,$_$jscomp$2476_children_ids$jscomp$12_page_id$jscomp$246$$);$_$jscomp$2476_children_ids$jscomp$12_page_id$jscomp$246$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__71244_SHARP_$$){return $APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$633$$,$p1__71244_SHARP_$$)},
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$5998$$.ids]));var $parent_ids$jscomp$4$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71245_SHARP_$$){return $APP.$app$common$files$helpers$get_parent_id$$($objects$jscomp$633$$,$p1__71245_SHARP_$$)},$self__$jscomp$5998$$.ids),$undo_id$jscomp$57$$=Symbol(),$margin_attrs$$=$APP.$cljs$core$set$$($APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5998$$.$attrs$,
$APP.$cljs$cst$1699$layout_item_margin$$)));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$57$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5998$$.ids,$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5998$$.$attrs$),function(){var $G__71251$$=$self__$jscomp$5998$$.options;return $APP.$cljs$core$seq$$($margin_attrs$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71251$$,
$APP.$cljs$cst$3521$changed_sub_attr$$,$margin_attrs$$):$G__71251$$}()),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$2476_children_ids$jscomp$12_page_id$jscomp$246$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$data$workspace$shape_layout$fix_child_sizing$$,$objects$jscomp$633$$,$self__$jscomp$5998$$.$attrs$),$self__$jscomp$5998$$.options),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($parent_ids$jscomp$4$$,
function($parent$jscomp$280$$,$objects__$1$jscomp$28$$){var $G__71252$$=$app$main$data$workspace$shape_layout$fix_parent_sizing$$($parent$jscomp$280$$,$objects__$1$jscomp$28$$,$APP.$cljs$core$set$$($self__$jscomp$5998$$.ids),$self__$jscomp$5998$$.$attrs$);return $APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$280$$)?$APP.$app$common$types$shape$layout$assign_cells$$($G__71252$$,$objects__$1$jscomp$28$$):$G__71252$$},$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$5998$$.options,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)]))),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$self__$jscomp$5998$$.ids],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$57$$))});return new $app$main$data$workspace$shape_layout$update_layout_child_71248$$($ids$jscomp$238$$,
$attrs$jscomp$151$$,$options$jscomp$573$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$shape_layout$update_grid_cells$$=function($layout_id$jscomp$2$$,$ids$jscomp$240$$,$props$jscomp$203$$){typeof $app$main$data$workspace$shape_layout$update_grid_cells_71256$$==="undefined"&&($app$main$data$workspace$shape_layout$update_grid_cells_71256$$=function($layout_id$jscomp$3$$,$ids$jscomp$241$$,$props$jscomp$204$$,$meta71257$$){this.$layout_id$=$layout_id$jscomp$3$$;this.ids=$ids$jscomp$241$$;this.props=$props$jscomp$204$$;this.$meta71257$=$meta71257$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$update_grid_cells_71256$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$update_grid_cells_71256$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4412$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_grid_cells$$},$app$main$data$workspace$shape_layout$update_grid_cells_71256$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71258$$,$meta71257__$1$$){return new $app$main$data$workspace$shape_layout$update_grid_cells_71256$$(this.$layout_id$,this.ids,this.props,$meta71257__$1$$)},$app$main$data$workspace$shape_layout$update_grid_cells_71256$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71257$},$app$main$data$workspace$shape_layout$update_grid_cells_71256$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$update_grid_cells_71256$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$6002$$=this,$undo_id$jscomp$58$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$58$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6002$$.$layout_id$],null),function($shape$jscomp$740$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($shape__$1$jscomp$57$$,
$cell_id$jscomp$9$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape__$1$jscomp$57$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$cell_id$jscomp$9$$],null),$APP.$app$common$data$patch_object$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$6002$$.props]))},$shape$jscomp$740$$,$self__$jscomp$6002$$.ids)}),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6002$$.$layout_id$],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$58$$))});return new $app$main$data$workspace$shape_layout$update_grid_cells_71256$$($layout_id$jscomp$2$$,$ids$jscomp$240$$,$props$jscomp$203$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$shape_layout$change_cells_mode$$=function($layout_id$jscomp$4$$,$ids$jscomp$242$$,$mode$jscomp$32$$){typeof $app$main$data$workspace$shape_layout$change_cells_mode_71260$$==="undefined"&&($app$main$data$workspace$shape_layout$change_cells_mode_71260$$=function($layout_id$jscomp$5$$,$ids$jscomp$243$$,$mode$jscomp$33$$,$meta71261$$){this.$layout_id$=$layout_id$jscomp$5$$;this.ids=$ids$jscomp$243$$;this.mode=$mode$jscomp$33$$;this.$meta71261$=$meta71261$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$change_cells_mode_71260$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$change_cells_mode_71260$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4413$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_change_cells_mode$$},$app$main$data$workspace$shape_layout$change_cells_mode_71260$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71262$$,$meta71261__$1$$){return new $app$main$data$workspace$shape_layout$change_cells_mode_71260$$(this.$layout_id$,this.ids,this.mode,$meta71261__$1$$)},$app$main$data$workspace$shape_layout$change_cells_mode_71260$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71261$},$app$main$data$workspace$shape_layout$change_cells_mode_71260$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$change_cells_mode_71260$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$6006$$=this,$undo_id$jscomp$59$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$59$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6006$$.$layout_id$],null),function($shape$jscomp$741$$,$objects$jscomp$634$$){var $G__71263_G__71263__$1_first_row$jscomp$10_map__71266_shape__$1$jscomp$58$$=
$self__$jscomp$6006$$.mode;$G__71263_G__71263__$1_first_row$jscomp$10_map__71266_shape__$1$jscomp$58$$=$G__71263_G__71263__$1_first_row$jscomp$10_map__71266_shape__$1$jscomp$58$$ instanceof $APP.$cljs$core$Keyword$$?$G__71263_G__71263__$1_first_row$jscomp$10_map__71266_shape__$1$jscomp$58$$.$fqn$:null;switch($G__71263_G__71263__$1_first_row$jscomp$10_map__71266_shape__$1$jscomp$58$$){case "auto":return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($shape__$1$jscomp$59$$,$cell_id$jscomp$10$$){var $cell$jscomp$43$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$59$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$cell_id$jscomp$10$$],null));return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1673$manual$$,null,$APP.$cljs$cst$1674$area$$,null],null),null),$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$43$$))||
$APP.$cljs$cst$1657$row_span$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$43$$)>1||$APP.$cljs$cst$1658$column_span$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$43$$)>1?$APP.$app$common$types$shape$layout$assign_cells$$($APP.$app$common$types$shape$layout$resize_cell_area$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape__$1$jscomp$59$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$cell_id$jscomp$10$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1672$auto$$])),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$cell_id$jscomp$10$$],null),$APP.$cljs$core$dissoc$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1675$area_name$$])),$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$43$$),$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$43$$),$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$43$$),$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$43$$),1,1),$objects$jscomp$634$$):$shape__$1$jscomp$59$$},$shape$jscomp$741$$,$self__$jscomp$6006$$.ids);
case "manual":return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($shape__$1$jscomp$60$$,$cell_id$jscomp$11$$){var $cell$jscomp$44$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$60$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$cell_id$jscomp$11$$],null));return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1674$area$$,null,$APP.$cljs$cst$1672$auto$$,null],null),null),$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$44$$))?$APP.$app$common$types$shape$layout$assign_cells$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$data$assoc_in_when$$($shape__$1$jscomp$60$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$cell_id$jscomp$11$$,
$APP.$cljs$cst$1676$position$$],null),$APP.$cljs$cst$1673$manual$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$cell_id$jscomp$11$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1675$area_name$$])),$objects$jscomp$634$$):$shape__$1$jscomp$60$$},$shape$jscomp$741$$,$self__$jscomp$6006$$.ids);case "area":$G__71263_G__71263__$1_first_row$jscomp$10_map__71266_shape__$1$jscomp$58$$=
$APP.$app$common$types$shape$layout$cells_coordinates$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71259_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$741$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$p1__71259_SHARP_$$],null))},$self__$jscomp$6006$$.ids));var $map__71266__$1_target_cell$jscomp$8$$=$APP.$cljs$core$__destructure_map$$($G__71263_G__71263__$1_first_row$jscomp$10_map__71266_shape__$1$jscomp$58$$);
$G__71263_G__71263__$1_first_row$jscomp$10_map__71266_shape__$1$jscomp$58$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71266__$1_target_cell$jscomp$8$$,$APP.$cljs$cst$1715$first_row$$);var $first_column$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71266__$1_target_cell$jscomp$8$$,$APP.$cljs$cst$1716$first_column$$),$last_row$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71266__$1_target_cell$jscomp$8$$,$APP.$cljs$cst$1717$last_row$$),
$last_column$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71266__$1_target_cell$jscomp$8$$,$APP.$cljs$cst$1718$last_column$$);$map__71266__$1_target_cell$jscomp$8$$=$APP.$app$common$types$shape$layout$get_cell_by_position$$($shape$jscomp$741$$,$G__71263_G__71263__$1_first_row$jscomp$10_map__71266_shape__$1$jscomp$58$$,$first_column$jscomp$10$$);$G__71263_G__71263__$1_first_row$jscomp$10_map__71266_shape__$1$jscomp$58$$=$APP.$app$common$types$shape$layout$assign_cells$$($APP.$app$common$types$shape$layout$resize_cell_area$$($shape$jscomp$741$$,
$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($map__71266__$1_target_cell$jscomp$8$$),$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($map__71266__$1_target_cell$jscomp$8$$),$G__71263_G__71263__$1_first_row$jscomp$10_map__71266_shape__$1$jscomp$58$$,$first_column$jscomp$10$$,$last_row$jscomp$10$$-$G__71263_G__71263__$1_first_row$jscomp$10_map__71266_shape__$1$jscomp$58$$+1,$last_column$jscomp$10$$-$first_column$jscomp$10$$+1),$objects$jscomp$634$$);return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__71263_G__71263__$1_first_row$jscomp$10_map__71266_shape__$1$jscomp$58$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__71266__$1_target_cell$jscomp$8$$)],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1674$area$$]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__71263_G__71263__$1_first_row$jscomp$10_map__71266_shape__$1$jscomp$58$$)].join(""));
}},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)),$APP.$app$main$data$workspace$grid_layout$editor$clean_selection$$($self__$jscomp$6006$$.$layout_id$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6006$$.$layout_id$],
null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$59$$))});return new $app$main$data$workspace$shape_layout$change_cells_mode_71260$$($layout_id$jscomp$4$$,$ids$jscomp$242$$,$mode$jscomp$32$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$shape_layout$update_grid_cell_position$$=function($layout_id$jscomp$8$$,$cell_id$jscomp$12$$,$props$jscomp$205$$){typeof $app$main$data$workspace$shape_layout$update_grid_cell_position_71274$$==="undefined"&&($app$main$data$workspace$shape_layout$update_grid_cell_position_71274$$=function($layout_id$jscomp$9$$,$cell_id$jscomp$13$$,$props$jscomp$206$$,$meta71275$$){this.$layout_id$=$layout_id$jscomp$9$$;this.$cell_id$=$cell_id$jscomp$13$$;this.props=$props$jscomp$206$$;
this.$meta71275$=$meta71275$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$update_grid_cell_position_71274$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$update_grid_cell_position_71274$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4415$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_grid_cell_position$$},
$app$main$data$workspace$shape_layout$update_grid_cell_position_71274$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71276$$,$meta71275__$1$$){return new $app$main$data$workspace$shape_layout$update_grid_cell_position_71274$$(this.$layout_id$,this.$cell_id$,this.props,$meta71275__$1$$)},$app$main$data$workspace$shape_layout$update_grid_cell_position_71274$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71275$},$app$main$data$workspace$shape_layout$update_grid_cell_position_71274$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$update_grid_cell_position_71274$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6014$$=this,$undo_id$jscomp$61$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$61$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$self__$jscomp$6014$$.$layout_id$],null),function($shape$jscomp$743$$,$objects$jscomp$636$$){var $prev_data$$=$APP.$cljs$core$select_keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$743$$,$APP.$cljs$cst$1696$layout_grid_cells$$),$self__$jscomp$6014$$.$cell_id$),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1657$row_span$$,
$APP.$cljs$cst$1658$column_span$$],null)),$new_data$jscomp$2$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$prev_data$$,$self__$jscomp$6014$$.props]));return $APP.$app$common$types$shape$layout$assign_cells$$($APP.$app$common$types$shape$layout$resize_cell_area$$($shape$jscomp$743$$,$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($prev_data$$),$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($prev_data$$),
$APP.$cljs$cst$1656$row$$.$cljs$core$IFn$_invoke$arity$1$($new_data$jscomp$2$$),$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($new_data$jscomp$2$$),$APP.$cljs$cst$1657$row_span$$.$cljs$core$IFn$_invoke$arity$1$($new_data$jscomp$2$$),$APP.$cljs$cst$1658$column_span$$.$cljs$core$IFn$_invoke$arity$1$($new_data$jscomp$2$$)),$objects$jscomp$636$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6014$$.$layout_id$],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$61$$))});return new $app$main$data$workspace$shape_layout$update_grid_cell_position_71274$$($layout_id$jscomp$8$$,$cell_id$jscomp$12$$,$props$jscomp$205$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$variants$update_properties_names_and_values$$=function($component_id$jscomp$69$$,$variant_id$jscomp$19$$,$previous_properties$$,$updated_properties$$){typeof $app$main$data$workspace$variants$update_properties_names_and_values_71386$$==="undefined"&&($app$main$data$workspace$variants$update_properties_names_and_values_71386$$=function($component_id$jscomp$70$$,$variant_id$jscomp$20$$,$previous_properties$jscomp$1$$,$updated_properties$jscomp$1$$,$meta71387$$){this.$component_id$=
$component_id$jscomp$70$$;this.$variant_id$=$variant_id$jscomp$20$$;this.$previous_properties$=$previous_properties$jscomp$1$$;this.$updated_properties$=$updated_properties$jscomp$1$$;this.$meta71387$=$meta71387$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$update_properties_names_and_values_71386$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$update_properties_names_and_values_71386$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4422$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_update_properties_names_and_values$$},$app$main$data$workspace$variants$update_properties_names_and_values_71386$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71388$$,$meta71387__$1$$){return new $app$main$data$workspace$variants$update_properties_names_and_values_71386$$(this.$component_id$,this.$variant_id$,this.$previous_properties$,this.$updated_properties$,$meta71387__$1$$)},$app$main$data$workspace$variants$update_properties_names_and_values_71386$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71387$},$app$main$data$workspace$variants$update_properties_names_and_values_71386$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$update_properties_names_and_values_71386$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2484$$,$state$jscomp$835$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$835$$,$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$dissoc$$,
$APP.$cljs$cst$4423$shape_for_rename$$)},$app$main$data$workspace$variants$update_properties_names_and_values_71386$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$update_properties_names_and_values_71386$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$230_properties_to_add$$,$properties_to_remove_state$jscomp$836$$){var $self__$jscomp$6031$$=this,$changes$jscomp$262_changes__$1$jscomp$82_changes__$2$jscomp$36_changes__$3$jscomp$12_page_id$jscomp$248$$=
$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($properties_to_remove_state$jscomp$836$$),$data$jscomp$390_undo_id$jscomp$64$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($properties_to_remove_state$jscomp$836$$),$objects$jscomp$640$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$390_undo_id$jscomp$64$$,$changes$jscomp$262_changes__$1$jscomp$82_changes__$2$jscomp$36_changes__$3$jscomp$12_page_id$jscomp$248$$),
$APP.$cljs$cst$1631$objects$$),$properties_to_update_updated_properties__$1$$=$app$common$types$variant$update_number_in_repeated_prop_names$$($self__$jscomp$6031$$.$updated_properties$);$properties_to_remove_state$jscomp$836$$=$app$common$types$variant$find_properties_to_remove$$($self__$jscomp$6031$$.$previous_properties$,$properties_to_update_updated_properties__$1$$);$it$jscomp$230_properties_to_add$$=$app$common$types$variant$find_properties_to_add$$($self__$jscomp$6031$$.$previous_properties$,
$properties_to_update_updated_properties__$1$$);$properties_to_update_updated_properties__$1$$=$app$common$types$variant$find_properties_to_update$$($self__$jscomp$6031$$.$previous_properties$,$properties_to_update_updated_properties__$1$$);$changes$jscomp$262_changes__$1$jscomp$82_changes__$2$jscomp$36_changes__$3$jscomp$12_page_id$jscomp$248$$=$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
$changes$jscomp$262_changes__$1$jscomp$82_changes__$2$jscomp$36_changes__$3$jscomp$12_page_id$jscomp$248$$),$objects$jscomp$640$$),$data$jscomp$390_undo_id$jscomp$64$$);$changes$jscomp$262_changes__$1$jscomp$82_changes__$2$jscomp$36_changes__$3$jscomp$12_page_id$jscomp$248$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$83$$,$map__71392__$1_name$jscomp$346_p__71391$$){$map__71392__$1_name$jscomp$346_p__71391$$=$APP.$cljs$core$__destructure_map$$($map__71392__$1_name$jscomp$346_p__71391$$);
$map__71392__$1_name$jscomp$346_p__71391$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71392__$1_name$jscomp$346_p__71391$$,$APP.$cljs$cst$725$name$$);return $app$common$logic$variant_properties$generate_update_property_value$$($changes__$1$jscomp$83$$,$self__$jscomp$6031$$.$component_id$,$app$common$types$variant$find_index_for_property_name$$($self__$jscomp$6031$$.$previous_properties$,$map__71392__$1_name$jscomp$346_p__71391$$),"")},$changes$jscomp$262_changes__$1$jscomp$82_changes__$2$jscomp$36_changes__$3$jscomp$12_page_id$jscomp$248$$,
$properties_to_remove_state$jscomp$836$$);$changes$jscomp$262_changes__$1$jscomp$82_changes__$2$jscomp$36_changes__$3$jscomp$12_page_id$jscomp$248$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$2$jscomp$37$$,$name$jscomp$347_p__71393$$){var $map__71394__$1_value$jscomp$607$$=$APP.$cljs$core$__destructure_map$$($name$jscomp$347_p__71393$$);$name$jscomp$347_p__71393$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71394__$1_value$jscomp$607$$,$APP.$cljs$cst$725$name$$);
$map__71394__$1_value$jscomp$607$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71394__$1_value$jscomp$607$$,$APP.$cljs$cst$260$value$$);return $app$common$logic$variant_properties$generate_update_property_value$$($changes__$2$jscomp$37$$,$self__$jscomp$6031$$.$component_id$,$app$common$types$variant$find_index_for_property_name$$($self__$jscomp$6031$$.$previous_properties$,$name$jscomp$347_p__71393$$),$map__71394__$1_value$jscomp$607$$)},$changes$jscomp$262_changes__$1$jscomp$82_changes__$2$jscomp$36_changes__$3$jscomp$12_page_id$jscomp$248$$,
$properties_to_update_updated_properties__$1$$);$changes$jscomp$262_changes__$1$jscomp$82_changes__$2$jscomp$36_changes__$3$jscomp$12_page_id$jscomp$248$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$3$jscomp$13$$,$map__71399_name$jscomp$348_p__71395$$){var $idx$jscomp$97$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__71399_name$jscomp$348_p__71395$$,0,null);$map__71399_name$jscomp$348_p__71395$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__71399_name$jscomp$348_p__71395$$,
1,null);var $map__71399__$1_value$jscomp$608$$=$APP.$cljs$core$__destructure_map$$($map__71399_name$jscomp$348_p__71395$$);$map__71399_name$jscomp$348_p__71395$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71399__$1_value$jscomp$608$$,$APP.$cljs$cst$725$name$$);$map__71399__$1_value$jscomp$608$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71399__$1_value$jscomp$608$$,$APP.$cljs$cst$260$value$$);return $app$common$logic$variant_properties$generate_update_property_value$$($app$common$logic$variant_properties$generate_add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($changes__$3$jscomp$13$$,
$self__$jscomp$6031$$.$variant_id$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3519$property_name$$,$map__71399_name$jscomp$348_p__71395$$],null)])),$self__$jscomp$6031$$.$component_id$,$idx$jscomp$97$$+$APP.$cljs$core$count$$($self__$jscomp$6031$$.$previous_properties$),$map__71399__$1_value$jscomp$608$$)},$changes$jscomp$262_changes__$1$jscomp$82_changes__$2$jscomp$36_changes__$3$jscomp$12_page_id$jscomp$248$$,$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,
$it$jscomp$230_properties_to_add$$));$data$jscomp$390_undo_id$jscomp$64$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$seq$$($properties_to_remove_state$jscomp$836$$)||$APP.$cljs$core$seq$$($properties_to_update_updated_properties__$1$$)?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"variant-edit-property-value",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:rename-in-layers"],
null)):null,$APP.$cljs$core$seq$$($it$jscomp$230_properties_to_add$$)?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"variant-add-property",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:rename-in-layers"],null)):null,$APP.$app$main$data$workspace$undo$start_undo_transaction$$($data$jscomp$390_undo_id$jscomp$64$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$262_changes__$1$jscomp$82_changes__$2$jscomp$36_changes__$3$jscomp$12_page_id$jscomp$248$$),
$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($data$jscomp$390_undo_id$jscomp$64$$))});return new $app$main$data$workspace$variants$update_properties_names_and_values_71386$$($component_id$jscomp$69$$,$variant_id$jscomp$19$$,$previous_properties$$,$updated_properties$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$variants$update_property_name$$=function($variant_id$jscomp$21$$,$pos$jscomp$115$$,$new_name$jscomp$25$$,$p__71403$$){var $map__71404__$1$$=$APP.$cljs$core$__destructure_map$$($p__71403$$),$trigger$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71404__$1$$,$APP.$cljs$cst$4424$trigger$$);typeof $app$main$data$workspace$variants$update_property_name_71405$$==="undefined"&&($app$main$data$workspace$variants$update_property_name_71405$$=function($variant_id$jscomp$22$$,
$pos$jscomp$116$$,$new_name$jscomp$26$$,$p__71403$jscomp$1$$,$map__71404$jscomp$1$$,$trigger$jscomp$1$$,$meta71406$$){this.$variant_id$=$variant_id$jscomp$22$$;this.pos=$pos$jscomp$116$$;this.$new_name$=$new_name$jscomp$26$$;this.$p__71403$=$p__71403$jscomp$1$$;this.$map__71404$=$map__71404$jscomp$1$$;this.$trigger$=$trigger$jscomp$1$$;this.$meta71406$=$meta71406$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$update_property_name_71405$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$update_property_name_71405$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4425$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_update_property_name$$},$app$main$data$workspace$variants$update_property_name_71405$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71407$$,$meta71406__$1$$){return new $app$main$data$workspace$variants$update_property_name_71405$$(this.$variant_id$,this.pos,
this.$new_name$,this.$p__71403$,this.$map__71404$,this.$trigger$,$meta71406__$1$$)},$app$main$data$workspace$variants$update_property_name_71405$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71406$},$app$main$data$workspace$variants$update_property_name_71405$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$update_property_name_71405$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2486_data$jscomp$391_related_components$jscomp$4$$,
$state$jscomp$837$$){var $file_id$jscomp$252$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$837$$);$_$jscomp$2486_data$jscomp$391_related_components$jscomp$4$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$837$$);var $objects$jscomp$641$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$837$$);$_$jscomp$2486_data$jscomp$391_related_components$jscomp$4$$=$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$2486_data$jscomp$391_related_components$jscomp$4$$,
$objects$jscomp$641$$,this.$variant_id$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($s$jscomp$552$$,$related_component$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$552$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,$file_id$jscomp$252$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$1638$components$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($related_component$$),
$APP.$cljs$cst$2001$variant_properties$$],null),function($props$jscomp$207$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71401_SHARP_$$){return $APP.$cljs$core$with_meta$$($p1__71401_SHARP_$$,null)},$props$jscomp$207$$)})},$state$jscomp$837$$,$_$jscomp$2486_data$jscomp$391_related_components$jscomp$4$$)},$app$main$data$workspace$variants$update_property_name_71405$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$update_property_name_71405$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$263_it$jscomp$231_page_id$jscomp$249$$,$related_components$jscomp$5_state$jscomp$838_valid_pos_QMARK_$$){$changes$jscomp$263_it$jscomp$231_page_id$jscomp$249$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($related_components$jscomp$5_state$jscomp$838_valid_pos_QMARK_$$);var $data$jscomp$392_undo_id$jscomp$65$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($related_components$jscomp$5_state$jscomp$838_valid_pos_QMARK_$$),
$objects$jscomp$642$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$392_undo_id$jscomp$65$$,$changes$jscomp$263_it$jscomp$231_page_id$jscomp$249$$),$APP.$cljs$cst$1631$objects$$);$related_components$jscomp$5_state$jscomp$838_valid_pos_QMARK_$$=$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$392_undo_id$jscomp$65$$,$objects$jscomp$642$$,this.$variant_id$);var $prop_name_props$jscomp$208$$=
$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($related_components$jscomp$5_state$jscomp$838_valid_pos_QMARK_$$));$prop_name_props$jscomp$208$$=($related_components$jscomp$5_state$jscomp$838_valid_pos_QMARK_$$=$APP.$cljs$core$count$$($prop_name_props$jscomp$208$$)>this.pos)?$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($prop_name_props$jscomp$208$$,this.pos)):null;$changes$jscomp$263_it$jscomp$231_page_id$jscomp$249$$=
$related_components$jscomp$5_state$jscomp$838_valid_pos_QMARK_$$?$app$common$logic$variant_properties$generate_update_property_name$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$changes$jscomp$263_it$jscomp$231_page_id$jscomp$249$$),$objects$jscomp$642$$),$data$jscomp$392_undo_id$jscomp$65$$),this.$variant_id$,this.pos,this.$new_name$):
null;$data$jscomp$392_undo_id$jscomp$65$$=Symbol();return $related_components$jscomp$5_state$jscomp$838_valid_pos_QMARK_$$&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop_name_props$jscomp$208$$,this.$new_name$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($data$jscomp$392_undo_id$jscomp$65$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$263_it$jscomp$231_page_id$jscomp$249$$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($data$jscomp$392_undo_id$jscomp$65$$),
$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"variant-edit-property-name",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,this.$trigger$],null))):null});return new $app$main$data$workspace$variants$update_property_name_71405$$($variant_id$jscomp$21$$,$pos$jscomp$115$$,$new_name$jscomp$25$$,$p__71403$$,$map__71404__$1$$,$trigger$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$variants$update_property_value$$=function($component_id$jscomp$71$$,$pos$jscomp$117$$,$value$jscomp$609$$){typeof $app$main$data$workspace$variants$update_property_value_71412$$==="undefined"&&($app$main$data$workspace$variants$update_property_value_71412$$=function($component_id$jscomp$72$$,$pos$jscomp$118$$,$value$jscomp$610$$,$meta71413$$){this.$component_id$=$component_id$jscomp$72$$;this.pos=$pos$jscomp$118$$;this.value=$value$jscomp$610$$;this.$meta71413$=$meta71413$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$update_property_value_71412$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$update_property_value_71412$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4426$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_update_property_value$$},$app$main$data$workspace$variants$update_property_value_71412$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71414$$,$meta71413__$1$$){return new $app$main$data$workspace$variants$update_property_value_71412$$(this.$component_id$,this.pos,this.value,$meta71413__$1$$)},$app$main$data$workspace$variants$update_property_value_71412$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71413$},$app$main$data$workspace$variants$update_property_value_71412$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$update_property_value_71412$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$264_it$jscomp$232_page_id$jscomp$250$$,$data$jscomp$393_state$jscomp$839_undo_id$jscomp$66$$){$changes$jscomp$264_it$jscomp$232_page_id$jscomp$250$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$393_state$jscomp$839_undo_id$jscomp$66$$);$data$jscomp$393_state$jscomp$839_undo_id$jscomp$66$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$393_state$jscomp$839_undo_id$jscomp$66$$);var $objects$jscomp$643$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$393_state$jscomp$839_undo_id$jscomp$66$$,$changes$jscomp$264_it$jscomp$232_page_id$jscomp$250$$),$APP.$cljs$cst$1631$objects$$);$changes$jscomp$264_it$jscomp$232_page_id$jscomp$250$$=$app$common$logic$variant_properties$generate_update_property_value$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
$changes$jscomp$264_it$jscomp$232_page_id$jscomp$250$$),$data$jscomp$393_state$jscomp$839_undo_id$jscomp$66$$),$objects$jscomp$643$$),this.$component_id$,this.pos,this.value);$data$jscomp$393_state$jscomp$839_undo_id$jscomp$66$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($data$jscomp$393_state$jscomp$839_undo_id$jscomp$66$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$264_it$jscomp$232_page_id$jscomp$250$$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($data$jscomp$393_state$jscomp$839_undo_id$jscomp$66$$))});
return new $app$main$data$workspace$variants$update_property_value_71412$$($component_id$jscomp$71$$,$pos$jscomp$117$$,$value$jscomp$609$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$variants$update_error$cljs$0core$0IFn$0_invoke$0arity$02$$=function($component_id$jscomp$74$$,$value$jscomp$611$$){typeof $app$main$data$workspace$variants$update_error_71418$$==="undefined"&&($app$main$data$workspace$variants$update_error_71418$$=function($component_id$jscomp$75$$,$value$jscomp$612$$,$meta71419$$){this.$component_id$=$component_id$jscomp$75$$;this.value=$value$jscomp$612$$;this.$meta71419$=$meta71419$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$update_error_71418$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$update_error_71418$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4427$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_update_error$$},$app$main$data$workspace$variants$update_error_71418$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71420$$,$meta71419__$1$$){return new $app$main$data$workspace$variants$update_error_71418$$(this.$component_id$,
this.value,$meta71419__$1$$)},$app$main$data$workspace$variants$update_error_71418$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71419$},$app$main$data$workspace$variants$update_error_71418$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$update_error_71418$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$265_it$jscomp$233_page_id$jscomp$251$$,$data$jscomp$394_state$jscomp$840_undo_id$jscomp$67$$){$changes$jscomp$265_it$jscomp$233_page_id$jscomp$251$$=
$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$394_state$jscomp$840_undo_id$jscomp$67$$);$data$jscomp$394_state$jscomp$840_undo_id$jscomp$67$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$394_state$jscomp$840_undo_id$jscomp$67$$);var $objects$jscomp$644$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$394_state$jscomp$840_undo_id$jscomp$67$$,$changes$jscomp$265_it$jscomp$233_page_id$jscomp$251$$),
$APP.$cljs$cst$1631$objects$$);$changes$jscomp$265_it$jscomp$233_page_id$jscomp$251$$=$app$common$logic$variant_properties$generate_set_variant_error$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$changes$jscomp$265_it$jscomp$233_page_id$jscomp$251$$),$data$jscomp$394_state$jscomp$840_undo_id$jscomp$67$$),$objects$jscomp$644$$),this.$component_id$,
this.value);$data$jscomp$394_state$jscomp$840_undo_id$jscomp$67$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($data$jscomp$394_state$jscomp$840_undo_id$jscomp$67$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$265_it$jscomp$233_page_id$jscomp$251$$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($data$jscomp$394_state$jscomp$840_undo_id$jscomp$67$$))});return new $app$main$data$workspace$variants$update_error_71418$$($component_id$jscomp$74$$,
$value$jscomp$611$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$variants$remove_property$$=function($variant_id$jscomp$23$$,$pos$jscomp$119$$){typeof $app$main$data$workspace$variants$remove_property_71423$$==="undefined"&&($app$main$data$workspace$variants$remove_property_71423$$=function($variant_id$jscomp$24$$,$pos$jscomp$120$$,$meta71424$$){this.$variant_id$=$variant_id$jscomp$24$$;this.pos=$pos$jscomp$120$$;this.$meta71424$=$meta71424$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$variants$remove_property_71423$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$remove_property_71423$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4428$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_remove_property$$},$app$main$data$workspace$variants$remove_property_71423$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71425$$,$meta71424__$1$$){return new $app$main$data$workspace$variants$remove_property_71423$$(this.$variant_id$,
this.pos,$meta71424__$1$$)},$app$main$data$workspace$variants$remove_property_71423$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71424$},$app$main$data$workspace$variants$remove_property_71423$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$remove_property_71423$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$266_it$jscomp$234_page_id$jscomp$252$$,$data$jscomp$395_state$jscomp$841_undo_id$jscomp$68$$){$changes$jscomp$266_it$jscomp$234_page_id$jscomp$252$$=
$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$395_state$jscomp$841_undo_id$jscomp$68$$);$data$jscomp$395_state$jscomp$841_undo_id$jscomp$68$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$395_state$jscomp$841_undo_id$jscomp$68$$);var $objects$jscomp$645$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$395_state$jscomp$841_undo_id$jscomp$68$$,$changes$jscomp$266_it$jscomp$234_page_id$jscomp$252$$),
$APP.$cljs$cst$1631$objects$$);$changes$jscomp$266_it$jscomp$234_page_id$jscomp$252$$=$app$common$logic$variant_properties$generate_remove_property$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$changes$jscomp$266_it$jscomp$234_page_id$jscomp$252$$),$data$jscomp$395_state$jscomp$841_undo_id$jscomp$68$$),$objects$jscomp$645$$),this.$variant_id$,
this.pos);$data$jscomp$395_state$jscomp$841_undo_id$jscomp$68$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($data$jscomp$395_state$jscomp$841_undo_id$jscomp$68$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$266_it$jscomp$234_page_id$jscomp$252$$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($data$jscomp$395_state$jscomp$841_undo_id$jscomp$68$$))});return new $app$main$data$workspace$variants$remove_property_71423$$($variant_id$jscomp$23$$,
$pos$jscomp$119$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$variants$remove_empty_properties$$=function($variant_id$jscomp$25$$){typeof $app$main$data$workspace$variants$remove_empty_properties_71426$$==="undefined"&&($app$main$data$workspace$variants$remove_empty_properties_71426$$=function($variant_id$jscomp$26$$,$meta71427$$){this.$variant_id$=$variant_id$jscomp$26$$;this.$meta71427$=$meta71427$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$remove_empty_properties_71426$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$remove_empty_properties_71426$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4429$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_remove_empty_properties$$},$app$main$data$workspace$variants$remove_empty_properties_71426$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71428$$,$meta71427__$1$$){return new $app$main$data$workspace$variants$remove_empty_properties_71426$$(this.$variant_id$,
$meta71427__$1$$)},$app$main$data$workspace$variants$remove_empty_properties_71426$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71427$},$app$main$data$workspace$variants$remove_empty_properties_71426$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$remove_empty_properties_71426$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$267_changes__$1$jscomp$84_it$jscomp$235_page_id$jscomp$253$$,
$data$jscomp$396_state$jscomp$842_undo_id$jscomp$69$$){var $self__$jscomp$6052$$=this;$changes$jscomp$267_changes__$1$jscomp$84_it$jscomp$235_page_id$jscomp$253$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$396_state$jscomp$842_undo_id$jscomp$69$$);$data$jscomp$396_state$jscomp$842_undo_id$jscomp$69$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$396_state$jscomp$842_undo_id$jscomp$69$$);var $objects$jscomp$646$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$396_state$jscomp$842_undo_id$jscomp$69$$,$changes$jscomp$267_changes__$1$jscomp$84_it$jscomp$235_page_id$jscomp$253$$),$APP.$cljs$cst$1631$objects$$),$properties_empty_pos_variant_components$$=$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$396_state$jscomp$842_undo_id$jscomp$69$$,$objects$jscomp$646$$,$self__$jscomp$6052$$.$variant_id$);
$properties_empty_pos_variant_components$$=$APP.$cljs$core$reverse$$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($i$jscomp$509$$,$p__71434_v$jscomp$597$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71434_v$jscomp$597$$,0,null);$p__71434_v$jscomp$597$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71434_v$jscomp$597$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$i$jscomp$509$$,
$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$empty_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$p__71434_v$jscomp$597$$)))],null)},$APP.$cljs$core$group_by$$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2001$variant_properties$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$properties_empty_pos_variant_components$$])))));
$changes$jscomp$267_changes__$1$jscomp$84_it$jscomp$235_page_id$jscomp$253$$=$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$changes$jscomp$267_changes__$1$jscomp$84_it$jscomp$235_page_id$jscomp$253$$),$data$jscomp$396_state$jscomp$842_undo_id$jscomp$69$$),$objects$jscomp$646$$);$changes$jscomp$267_changes__$1$jscomp$84_it$jscomp$235_page_id$jscomp$253$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$85$$,$p__71438_property_empty_QMARK_$$){var $pos$jscomp$121$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71438_property_empty_QMARK_$$,0,null);$p__71438_property_empty_QMARK_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71438_property_empty_QMARK_$$,1,null);return $APP.$cljs$core$truth_$$($p__71438_property_empty_QMARK_$$)?$app$common$logic$variant_properties$generate_remove_property$$($changes__$1$jscomp$85$$,
$self__$jscomp$6052$$.$variant_id$,$pos$jscomp$121$$):$changes__$1$jscomp$85$$},$changes$jscomp$267_changes__$1$jscomp$84_it$jscomp$235_page_id$jscomp$253$$,$properties_empty_pos_variant_components$$);$data$jscomp$396_state$jscomp$842_undo_id$jscomp$69$$=Symbol();return $APP.$cljs$core$seq$$($APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$267_changes__$1$jscomp$84_it$jscomp$235_page_id$jscomp$253$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"variant-remove-property",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:rename-in-layers"],null)),$APP.$app$main$data$workspace$undo$start_undo_transaction$$($data$jscomp$396_state$jscomp$842_undo_id$jscomp$69$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$267_changes__$1$jscomp$84_it$jscomp$235_page_id$jscomp$253$$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($data$jscomp$396_state$jscomp$842_undo_id$jscomp$69$$)):
null});return new $app$main$data$workspace$variants$remove_empty_properties_71426$$($variant_id$jscomp$25$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$variants$add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($variant_id$jscomp$27$$,$p__71451$$){var $options$jscomp$575$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71451$$,0,null);typeof $app$main$data$workspace$variants$add_new_property_71456$$==="undefined"&&($app$main$data$workspace$variants$add_new_property_71456$$=function($variant_id$jscomp$28$$,$p__71451$jscomp$1$$,$vec__71452$jscomp$1$$,$options$jscomp$576$$,$meta71457$$){this.$variant_id$=
$variant_id$jscomp$28$$;this.$p__71451$=$p__71451$jscomp$1$$;this.$vec__71452$=$vec__71452$jscomp$1$$;this.options=$options$jscomp$576$$;this.$meta71457$=$meta71457$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$add_new_property_71456$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$add_new_property_71456$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4430$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_add_new_property$$},
$app$main$data$workspace$variants$add_new_property_71456$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71458$$,$meta71457__$1$$){return new $app$main$data$workspace$variants$add_new_property_71456$$(this.$variant_id$,this.$p__71451$,this.$vec__71452$,this.options,$meta71457__$1$$)},$app$main$data$workspace$variants$add_new_property_71456$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71457$},$app$main$data$workspace$variants$add_new_property_71456$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$add_new_property_71456$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$268_it$jscomp$236_page_id$jscomp$254$$,$data$jscomp$397_state$jscomp$843_undo_id$jscomp$70$$){$changes$jscomp$268_it$jscomp$236_page_id$jscomp$254$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$397_state$jscomp$843_undo_id$jscomp$70$$);$data$jscomp$397_state$jscomp$843_undo_id$jscomp$70$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$397_state$jscomp$843_undo_id$jscomp$70$$);
var $objects$jscomp$647$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$397_state$jscomp$843_undo_id$jscomp$70$$,$changes$jscomp$268_it$jscomp$236_page_id$jscomp$254$$),$APP.$cljs$cst$1631$objects$$);$changes$jscomp$268_it$jscomp$236_page_id$jscomp$254$$=$app$common$logic$variant_properties$generate_add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
$changes$jscomp$268_it$jscomp$236_page_id$jscomp$254$$),$data$jscomp$397_state$jscomp$843_undo_id$jscomp$70$$),$objects$jscomp$647$$),this.$variant_id$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.options]));$data$jscomp$397_state$jscomp$843_undo_id$jscomp$70$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($data$jscomp$397_state$jscomp$843_undo_id$jscomp$70$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$268_it$jscomp$236_page_id$jscomp$254$$),
$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($data$jscomp$397_state$jscomp$843_undo_id$jscomp$70$$))});return new $app$main$data$workspace$variants$add_new_property_71456$$($variant_id$jscomp$27$$,$p__71451$$,$p__71451$$,$options$jscomp$575$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$variants$set_variant_id$$=function($component_id$jscomp$76$$,$variant_id$jscomp$31$$){typeof $app$main$data$workspace$variants$set_variant_id_71478$$==="undefined"&&($app$main$data$workspace$variants$set_variant_id_71478$$=function($component_id$jscomp$77$$,$variant_id$jscomp$32$$,$meta71479$$){this.$component_id$=$component_id$jscomp$77$$;this.$variant_id$=$variant_id$jscomp$32$$;this.$meta71479$=$meta71479$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$variants$set_variant_id_71478$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$set_variant_id_71478$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4432$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_set_variant_id$$},$app$main$data$workspace$variants$set_variant_id_71478$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71480$$,$meta71479__$1$$){return new $app$main$data$workspace$variants$set_variant_id_71478$$(this.$component_id$,
this.$variant_id$,$meta71479__$1$$)},$app$main$data$workspace$variants$set_variant_id_71478$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71479$},$app$main$data$workspace$variants$set_variant_id_71478$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$set_variant_id_71478$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$238_page_id$jscomp$256_undo_id$jscomp$72$$,$changes$jscomp$270_data$jscomp$399_state$jscomp$845$$){var $self__$jscomp$6064$$=
this;$it$jscomp$238_page_id$jscomp$256_undo_id$jscomp$72$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$270_data$jscomp$399_state$jscomp$845$$);$changes$jscomp$270_data$jscomp$399_state$jscomp$845$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$270_data$jscomp$399_state$jscomp$845$$);$changes$jscomp$270_data$jscomp$399_state$jscomp$845$$=$APP.$app$common$files$changes_builder$update_component$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
$it$jscomp$238_page_id$jscomp$256_undo_id$jscomp$72$$),$changes$jscomp$270_data$jscomp$399_state$jscomp$845$$),$self__$jscomp$6064$$.$component_id$,function($p1__71477_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__71477_SHARP_$$,$APP.$cljs$cst$2000$variant_id$$,$self__$jscomp$6064$$.$variant_id$)});$it$jscomp$238_page_id$jscomp$256_undo_id$jscomp$72$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($it$jscomp$238_page_id$jscomp$256_undo_id$jscomp$72$$),
$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$270_data$jscomp$399_state$jscomp$845$$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($it$jscomp$238_page_id$jscomp$256_undo_id$jscomp$72$$))});return new $app$main$data$workspace$variants$set_variant_id_71478$$($component_id$jscomp$76$$,$variant_id$jscomp$31$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$variants$focus_property$$=function($variant_id$jscomp$33$$){typeof $app$main$data$workspace$variants$focus_property_71481$$==="undefined"&&($app$main$data$workspace$variants$focus_property_71481$$=function($variant_id$jscomp$34$$,$meta71482$$){this.$variant_id$=$variant_id$jscomp$34$$;this.$meta71482$=$meta71482$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$focus_property_71481$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$focus_property_71481$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4433$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_focus_property$$},$app$main$data$workspace$variants$focus_property_71481$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71483$$,$meta71482__$1$$){return new $app$main$data$workspace$variants$focus_property_71481$$(this.$variant_id$,$meta71482__$1$$)},$app$main$data$workspace$variants$focus_property_71481$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71482$},$app$main$data$workspace$variants$focus_property_71481$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$focus_property_71481$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $APP.$app$util$dom$focus_BANG_$$($APP.$app$util$dom$get_element$$(["variant-prop-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.$variant_id$),"-0"].join("")))});return new $app$main$data$workspace$variants$focus_property_71481$$($variant_id$jscomp$33$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$variants$resposition_and_resize_variant$$=function($shape_id$jscomp$121$$){typeof $app$main$data$workspace$variants$resposition_and_resize_variant_71484$$==="undefined"&&($app$main$data$workspace$variants$resposition_and_resize_variant_71484$$=function($shape_id$jscomp$122$$,$meta71485$$){this.$shape_id$=$shape_id$jscomp$122$$;this.$meta71485$=$meta71485$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$resposition_and_resize_variant_71484$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$resposition_and_resize_variant_71484$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4434$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_resposition_and_resize_variant$$},$app$main$data$workspace$variants$resposition_and_resize_variant_71484$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71486$$,$meta71485__$1$$){return new $app$main$data$workspace$variants$resposition_and_resize_variant_71484$$(this.$shape_id$,
$meta71485__$1$$)},$app$main$data$workspace$variants$resposition_and_resize_variant_71484$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71485$},$app$main$data$workspace$variants$resposition_and_resize_variant_71484$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$resposition_and_resize_variant_71484$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2496_container$jscomp$73_objects$jscomp$649_page_id$jscomp$257_width$jscomp$156$$,
$shape$jscomp$746_state$jscomp$846$$){$_$jscomp$2496_container$jscomp$73_objects$jscomp$649_page_id$jscomp$257_width$jscomp$156$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$746_state$jscomp$846$$);$_$jscomp$2496_container$jscomp$73_objects$jscomp$649_page_id$jscomp$257_width$jscomp$156$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$746_state$jscomp$846$$,$_$jscomp$2496_container$jscomp$73_objects$jscomp$649_page_id$jscomp$257_width$jscomp$156$$);
$shape$jscomp$746_state$jscomp$846$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2496_container$jscomp$73_objects$jscomp$649_page_id$jscomp$257_width$jscomp$156$$,this.$shape_id$);$_$jscomp$2496_container$jscomp$73_objects$jscomp$649_page_id$jscomp$257_width$jscomp$156$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2496_container$jscomp$73_objects$jscomp$649_page_id$jscomp$257_width$jscomp$156$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$746_state$jscomp$846$$));
$_$jscomp$2496_container$jscomp$73_objects$jscomp$649_page_id$jscomp$257_width$jscomp$156$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2496_container$jscomp$73_objects$jscomp$649_page_id$jscomp$257_width$jscomp$156$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$746_state$jscomp$846$$)+20;var $x$jscomp$1213$$=$_$jscomp$2496_container$jscomp$73_objects$jscomp$649_page_id$jscomp$257_width$jscomp$156$$-($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$746_state$jscomp$846$$)+
30);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$transforms$update_dimensions$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$746_state$jscomp$846$$)],null),$APP.$cljs$cst$290$width$$,$_$jscomp$2496_container$jscomp$73_objects$jscomp$649_page_id$jscomp$257_width$jscomp$156$$),$app$main$data$workspace$transforms$update_position$cljs$0core$0IFn$0_invoke$0arity$03$$(this.$shape_id$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1510$x$$,$x$jscomp$1213$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3880$absolute_QMARK_$$,!1],null)))});return new $app$main$data$workspace$variants$resposition_and_resize_variant_71484$$($shape_id$jscomp$121$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$variants$transform_in_variant$cljs$0core$0IFn$0_invoke$0arity$01$$=function($main_instance_id$jscomp$7$$){return $app$main$data$workspace$variants$transform_in_variant$cljs$0core$0IFn$0_invoke$0arity$07$$($main_instance_id$jscomp$7$$,null,null,$APP.$cljs$core$PersistentVector$EMPTY$$,!1,!0,!0)};
$app$main$data$workspace$variants$transform_in_variant$cljs$0core$0IFn$0_invoke$0arity$07$$=function($main_instance_id$jscomp$8$$,$variant_id$jscomp$35$$,$delta$jscomp$50$$,$prefix$jscomp$61$$,$add_wrapper_QMARK_$$,$duplicate_QMARK_$$,$flex_QMARK_$jscomp$1$$){typeof $app$main$data$workspace$variants$transform_in_variant_71498$$==="undefined"&&($app$main$data$workspace$variants$transform_in_variant_71498$$=function($main_instance_id$jscomp$9$$,$variant_id$jscomp$36$$,$delta$jscomp$51$$,$prefix$jscomp$62$$,
$add_wrapper_QMARK_$jscomp$1$$,$duplicate_QMARK_$jscomp$1$$,$flex_QMARK_$jscomp$2$$,$meta71499$$){this.$main_instance_id$=$main_instance_id$jscomp$9$$;this.$variant_id$=$variant_id$jscomp$36$$;this.$delta$=$delta$jscomp$51$$;this.prefix=$prefix$jscomp$62$$;this.$add_wrapper_QMARK_$=$add_wrapper_QMARK_$jscomp$1$$;this.$duplicate_QMARK_$=$duplicate_QMARK_$jscomp$1$$;this.$flex_QMARK_$=$flex_QMARK_$jscomp$2$$;this.$meta71499$=$meta71499$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$variants$transform_in_variant_71498$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$transform_in_variant_71498$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4436$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_transform_in_variant$$},$app$main$data$workspace$variants$transform_in_variant_71498$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71500$$,$meta71499__$1$$){return new $app$main$data$workspace$variants$transform_in_variant_71498$$(this.$main_instance_id$,
this.$variant_id$,this.$delta$,this.prefix,this.$add_wrapper_QMARK_$,this.$duplicate_QMARK_$,this.$flex_QMARK_$,$meta71499__$1$$)},$app$main$data$workspace$variants$transform_in_variant_71498$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71499$},$app$main$data$workspace$variants$transform_in_variant_71498$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$transform_in_variant_71498$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2498_variant_vec$$,$main$jscomp$3_state$jscomp$848$$){var $self__$jscomp$6080$$=this,$variant_id__$1$$=function(){var $or__5025__auto__$jscomp$844$$=$self__$jscomp$6080$$.$variant_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$844$$)?$or__5025__auto__$jscomp$844$$:$APP.$app$common$uuid$next$$()}();$_$jscomp$2498_variant_vec$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$variant_id__$1$$],null);var $file_id$jscomp$253_name__$1$jscomp$11_objects$jscomp$651$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($main$jscomp$3_state$jscomp$848$$),$num_props_page_id$jscomp$259$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($main$jscomp$3_state$jscomp$848$$);$file_id$jscomp$253_name__$1$jscomp$11_objects$jscomp$651$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($main$jscomp$3_state$jscomp$848$$,$file_id$jscomp$253_name__$1$jscomp$11_objects$jscomp$651$$,$num_props_page_id$jscomp$259$$);
$main$jscomp$3_state$jscomp$848$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$253_name__$1$jscomp$11_objects$jscomp$651$$,$self__$jscomp$6080$$.$main_instance_id$);var $parent$jscomp$281$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$253_name__$1$jscomp$11_objects$jscomp$651$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($main$jscomp$3_state$jscomp$848$$)),$component_id$jscomp$79$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($main$jscomp$3_state$jscomp$848$$),
$name$jscomp$349$$=$APP.$cljs$core$truth_$$($self__$jscomp$6080$$.$add_wrapper_QMARK_$)?["Component/",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($main$jscomp$3_state$jscomp$848$$))].join(""):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($main$jscomp$3_state$jscomp$848$$),$cpath$jscomp$3$$=function(){var $G__71501$$=$APP.$app$common$path_names$split_path$$($name$jscomp$349$$);return $APP.$cljs$core$seq$$($self__$jscomp$6080$$.prefix)?
$APP.$cljs$core$vec$$($APP.$cljs$core$cons$$($APP.$app$common$path_names$join_path$$($self__$jscomp$6080$$.prefix),$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$count$$($self__$jscomp$6080$$.prefix),$G__71501$$))):$G__71501$$}();$file_id$jscomp$253_name__$1$jscomp$11_objects$jscomp$651$$=$APP.$cljs$core$first$$($cpath$jscomp$3$$);$num_props_page_id$jscomp$259$$=function(){var $y__5111__auto__$jscomp$123$$=$APP.$cljs$core$count$$($cpath$jscomp$3$$)-1;return 1>$y__5111__auto__$jscomp$123$$?
1:$y__5111__auto__$jscomp$123$$}();var $base_props$jscomp$1_stroke_props$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2004$is_variant_container$$,!0,$APP.$cljs$cst$725$name$$,$file_id$jscomp$253_name__$1$jscomp$11_objects$jscomp$651$$,$APP.$cljs$cst$1646$r1$$,20,$APP.$cljs$cst$1647$r2$$,20,$APP.$cljs$cst$1648$r3$$,20,$APP.$cljs$cst$1649$r4$$,20,$APP.$cljs$cst$1711$layout_item_absolute$$,!0],null),$delta__$1$jscomp$2_flex_props$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,
[$APP.$cljs$cst$1708$layout_item_h_sizing$$,$APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1093$p1$$,30,$APP.$cljs$cst$1091$p2$$,30,$APP.$cljs$cst$1687$p3$$,30,$APP.$cljs$cst$1688$p4$$,30],null),$APP.$cljs$cst$1680$layout_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1681$row_gap$$,0,$APP.$cljs$cst$1682$column_gap$$,20],null)],
null),$cont_props$$=$APP.$cljs$core$truth_$$($self__$jscomp$6080$$.$flex_QMARK_$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($base_props$jscomp$1_stroke_props$$,$delta__$1$jscomp$2_flex_props$$):$base_props$jscomp$1_stroke_props$$,$main_props$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,$file_id$jscomp$253_name__$1$jscomp$11_objects$jscomp$651$$,$APP.$cljs$cst$2000$variant_id$$,$variant_id__$1$$],null);$base_props$jscomp$1_stroke_props$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$1868$stroke_alignment$$,$APP.$cljs$cst$2041$inner$$,$APP.$cljs$cst$1866$stroke_style$$,$APP.$cljs$cst$2037$solid$$,$APP.$cljs$cst$1739$stroke_color$$,"#bb97d8",$APP.$cljs$cst$1740$stroke_opacity$$,1,$APP.$cljs$cst$1655$stroke_width$$,2],null);$delta__$1$jscomp$2_flex_props$$=function(){var $or__5025__auto__$jscomp$845$$=$self__$jscomp$6080$$.$delta$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$845$$)?$or__5025__auto__$jscomp$845$$:$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$281$$)?
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0):$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-30,-30)}();var $undo_id$jscomp$74$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$74$$),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$253_name__$1$jscomp$11_objects$jscomp$651$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($main$jscomp$3_state$jscomp$848$$))?
$APP.$app$main$data$workspace$libraries$rename_component$$($component_id$jscomp$79$$,$file_id$jscomp$253_name__$1$jscomp$11_objects$jscomp$651$$):null,$app$main$data$workspace$shapes$create_artboard_from_shapes$cljs$0core$0IFn$0_invoke$0arity$07$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6080$$.$main_instance_id$],null),$variant_id__$1$$,null,null,null,$delta__$1$jscomp$2_flex_props$$,$self__$jscomp$6080$$.$flex_QMARK_$),$APP.$app$main$data$workspace$colors$remove_all_fills$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2498_variant_vec$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,"#000000",$APP.$cljs$cst$1734$opacity$$,1],null)),$APP.$cljs$core$truth_$$($self__$jscomp$6080$$.$flex_QMARK_$)?$app$main$data$workspace$shape_layout$create_layout_from_id$$($variant_id__$1$$,$APP.$cljs$cst$1660$flex$$):null,$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2498_variant_vec$$,function($p1__71492_SHARP_$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71492_SHARP_$$,
$cont_props$$]))}),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6080$$.$main_instance_id$],null),function($p1__71493_SHARP_$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71493_SHARP_$$,$main_props$$]))}),$APP.$app$main$data$workspace$colors$add_stroke$$($_$jscomp$2498_variant_vec$$,
$base_props$jscomp$1_stroke_props$$),$app$main$data$workspace$variants$set_variant_id$$($component_id$jscomp$79$$,$variant_id__$1$$)),$APP.$beicon$v2$core$from$$($cljs$core$repeatedly$cljs$0core$0IFn$0_invoke$0arity$02$$($num_props_page_id$jscomp$259$$,function(){return $APP.$app$main$data$workspace$variants$add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($variant_id__$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3517$fill_values_QMARK_$$,
!0],null)]))})),$APP.$cljs$core$count$$($cpath$jscomp$3$$)>1?$APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71494_SHARP_$$){return $APP.$app$main$data$workspace$variants$update_property_value$$($component_id$jscomp$79$$,$p1__71494_SHARP_$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cpath$jscomp$3$$,$p1__71494_SHARP_$$+1))},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($num_props_page_id$jscomp$259$$))):null,(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$truth_$$($self__$jscomp$6080$$.$duplicate_QMARK_$)?
$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6080$$.$main_instance_id$):null,$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2498_variant_vec$$,function($p1__71495_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__71495_SHARP_$$,$APP.$cljs$cst$1711$layout_item_absolute$$)}),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$74$$),$APP.$cljs$core$truth_$$($self__$jscomp$6080$$.$flex_QMARK_$)?
$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$variant_id__$1$$],null)],null)):null))});return new $app$main$data$workspace$variants$transform_in_variant_71498$$($main_instance_id$jscomp$8$$,$variant_id$jscomp$35$$,$delta$jscomp$50$$,$prefix$jscomp$61$$,$add_wrapper_QMARK_$$,
$duplicate_QMARK_$$,$flex_QMARK_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$variants$add_component_or_variant$$=function(){typeof $app$main$data$workspace$variants$add_component_or_variant_71502$$==="undefined"&&($app$main$data$workspace$variants$add_component_or_variant_71502$$=function($meta71503$$){this.$meta71503$=$meta71503$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$add_component_or_variant_71502$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$variants$add_component_or_variant_71502$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4437$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_add_component_or_variant$$},$app$main$data$workspace$variants$add_component_or_variant_71502$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71504$$,$meta71503__$1$$){return new $app$main$data$workspace$variants$add_component_or_variant_71502$$($meta71503__$1$$)},$app$main$data$workspace$variants$add_component_or_variant_71502$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71503$},$app$main$data$workspace$variants$add_component_or_variant_71502$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$add_component_or_variant_71502$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2499_first_shape$jscomp$5_objects$jscomp$652$$,$selected_ids$jscomp$3_state$jscomp$849$$){$_$jscomp$2499_first_shape$jscomp$5_objects$jscomp$652$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($selected_ids$jscomp$3_state$jscomp$849$$);
$selected_ids$jscomp$3_state$jscomp$849$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($selected_ids$jscomp$3_state$jscomp$849$$);var $add_new_variant_QMARK_$jscomp$2_selected_shapes$jscomp$5$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($_$jscomp$2499_first_shape$jscomp$5_objects$jscomp$652$$),$selected_ids$jscomp$3_state$jscomp$849$$),$single_QMARK_$jscomp$3_transform_in_variant_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$APP.$cljs$core$count$$($selected_ids$jscomp$3_state$jscomp$849$$));$_$jscomp$2499_first_shape$jscomp$5_objects$jscomp$652$$=$APP.$cljs$core$first$$($add_new_variant_QMARK_$jscomp$2_selected_shapes$jscomp$5$$);$single_QMARK_$jscomp$3_transform_in_variant_QMARK_$$=$single_QMARK_$jscomp$3_transform_in_variant_QMARK_$$&&!$APP.$app$common$types$component$is_variant_QMARK_$$($_$jscomp$2499_first_shape$jscomp$5_objects$jscomp$652$$)&&$APP.$app$common$types$component$main_instance_QMARK_$$($_$jscomp$2499_first_shape$jscomp$5_objects$jscomp$652$$);
$add_new_variant_QMARK_$jscomp$2_selected_shapes$jscomp$5$$=$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$component$is_variant_QMARK_$$,$add_new_variant_QMARK_$jscomp$2_selected_shapes$jscomp$5$$);var $undo_id$jscomp$75$$=Symbol();return $single_QMARK_$jscomp$3_transform_in_variant_QMARK_$$?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"transform-in-variant",
$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:shortcut"],null)),$APP.$app$main$data$workspace$variants$transform_in_variant$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2499_first_shape$jscomp$5_objects$jscomp$652$$))):$add_new_variant_QMARK_$jscomp$2_selected_shapes$jscomp$5$$?$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-new-variant",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:shortcut-create-component"],null)),$APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$75$$)),$APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$variants$add_new_variant$$,$selected_ids$jscomp$3_state$jscomp$849$$)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$75$$))):
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$libraries$add_component$cljs$0core$0IFn$0_invoke$0arity$02$$(null,null))});return new $app$main$data$workspace$variants$add_component_or_variant_71502$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$variants$duplicate_or_add_variant$$=function(){typeof $app$main$data$workspace$variants$duplicate_or_add_variant_71508$$==="undefined"&&($app$main$data$workspace$variants$duplicate_or_add_variant_71508$$=function($meta71509$$){this.$meta71509$=$meta71509$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$duplicate_or_add_variant_71508$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$variants$duplicate_or_add_variant_71508$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4438$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_duplicate_or_add_variant$$},$app$main$data$workspace$variants$duplicate_or_add_variant_71508$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71510$$,$meta71509__$1$$){return new $app$main$data$workspace$variants$duplicate_or_add_variant_71508$$($meta71509__$1$$)},$app$main$data$workspace$variants$duplicate_or_add_variant_71508$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71509$},$app$main$data$workspace$variants$duplicate_or_add_variant_71508$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$duplicate_or_add_variant_71508$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2500_add_new_variant_QMARK_$jscomp$3_objects$jscomp$653_selected_shapes$jscomp$6$$,$selected_ids$jscomp$4_state$jscomp$850$$){$_$jscomp$2500_add_new_variant_QMARK_$jscomp$3_objects$jscomp$653_selected_shapes$jscomp$6$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($selected_ids$jscomp$4_state$jscomp$850$$);$selected_ids$jscomp$4_state$jscomp$850$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($selected_ids$jscomp$4_state$jscomp$850$$);$_$jscomp$2500_add_new_variant_QMARK_$jscomp$3_objects$jscomp$653_selected_shapes$jscomp$6$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($_$jscomp$2500_add_new_variant_QMARK_$jscomp$3_objects$jscomp$653_selected_shapes$jscomp$6$$),
$selected_ids$jscomp$4_state$jscomp$850$$);$_$jscomp$2500_add_new_variant_QMARK_$jscomp$3_objects$jscomp$653_selected_shapes$jscomp$6$$=$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$component$is_variant_QMARK_$$,$_$jscomp$2500_add_new_variant_QMARK_$jscomp$3_objects$jscomp$653_selected_shapes$jscomp$6$$);var $undo_id$jscomp$76$$=Symbol();return $_$jscomp$2500_add_new_variant_QMARK_$jscomp$3_objects$jscomp$653_selected_shapes$jscomp$6$$?$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-new-variant",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:shortcut-duplicate"],null)),$APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$76$$),$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($selected_ids$jscomp$4_state$jscomp$850$$),!1)),$APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71507_SHARP_$$){return $APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$2$($p1__71507_SHARP_$$,
!0)},$APP.$cljs$core$rest$$($selected_ids$jscomp$4_state$jscomp$850$$))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$76$$))):(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$selection$duplicate_selected$cljs$0core$0IFn$0_invoke$0arity$02$$(!0,!1))});return new $app$main$data$workspace$variants$duplicate_or_add_variant_71508$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$variants$rename_variant$$=function($variant_id$jscomp$37$$,$name$jscomp$350$$){typeof $app$main$data$workspace$variants$rename_variant_71513$$==="undefined"&&($app$main$data$workspace$variants$rename_variant_71513$$=function($variant_id$jscomp$38$$,$name$jscomp$351$$,$meta71514$$){this.$variant_id$=$variant_id$jscomp$38$$;this.name=$name$jscomp$351$$;this.$meta71514$=$meta71514$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$variants$rename_variant_71513$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$rename_variant_71513$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4439$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_rename_variant$$},$app$main$data$workspace$variants$rename_variant_71513$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71515$$,$meta71514__$1$$){return new $app$main$data$workspace$variants$rename_variant_71513$$(this.$variant_id$,
this.name,$meta71514__$1$$)},$app$main$data$workspace$variants$rename_variant_71513$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71514$},$app$main$data$workspace$variants$rename_variant_71513$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$rename_variant_71513$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2501_objects$jscomp$654_page_id$jscomp$260_undo_id$jscomp$77$$,$data$jscomp$401_state$jscomp$851_variant_components$jscomp$1$$){$_$jscomp$2501_objects$jscomp$654_page_id$jscomp$260_undo_id$jscomp$77$$=
$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$401_state$jscomp$851_variant_components$jscomp$1$$);$data$jscomp$401_state$jscomp$851_variant_components$jscomp$1$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$401_state$jscomp$851_variant_components$jscomp$1$$);$_$jscomp$2501_objects$jscomp$654_page_id$jscomp$260_undo_id$jscomp$77$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$401_state$jscomp$851_variant_components$jscomp$1$$,
$_$jscomp$2501_objects$jscomp$654_page_id$jscomp$260_undo_id$jscomp$77$$),$APP.$cljs$cst$1631$objects$$);$data$jscomp$401_state$jscomp$851_variant_components$jscomp$1$$=$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$401_state$jscomp$851_variant_components$jscomp$1$$,$_$jscomp$2501_objects$jscomp$654_page_id$jscomp$260_undo_id$jscomp$77$$,this.$variant_id$);var $clean_name$jscomp$1$$=$APP.$app$common$path_names$join_path$$($APP.$app$common$path_names$split_path$$(this.name));
$_$jscomp$2501_objects$jscomp$654_page_id$jscomp$260_undo_id$jscomp$77$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($_$jscomp$2501_objects$jscomp$654_page_id$jscomp$260_undo_id$jscomp$77$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$variant_id$],null),function($p1__71511_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__71511_SHARP_$$,
$APP.$cljs$cst$725$name$$,$clean_name$jscomp$1$$)})),$APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71512_SHARP_$$){return $app$main$data$workspace$libraries$rename_component_and_main_instance$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__71512_SHARP_$$),$clean_name$jscomp$1$$)},$data$jscomp$401_state$jscomp$851_variant_components$jscomp$1$$)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($_$jscomp$2501_objects$jscomp$654_page_id$jscomp$260_undo_id$jscomp$77$$)))});
return new $app$main$data$workspace$variants$rename_variant_71513$$($variant_id$jscomp$37$$,$name$jscomp$350$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$=function($component_id$jscomp$80$$,$name$jscomp$352$$){typeof $app$main$data$workspace$variants$rename_comp_or_variant_and_main_71516$$==="undefined"&&($app$main$data$workspace$variants$rename_comp_or_variant_and_main_71516$$=function($component_id$jscomp$81$$,$name$jscomp$353$$,$meta71517$$){this.$component_id$=$component_id$jscomp$81$$;this.name=$name$jscomp$353$$;this.$meta71517$=$meta71517$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$rename_comp_or_variant_and_main_71516$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$rename_comp_or_variant_and_main_71516$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4440$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_rename_comp_or_variant_and_main$$},$app$main$data$workspace$variants$rename_comp_or_variant_and_main_71516$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71518$$,$meta71517__$1$$){return new $app$main$data$workspace$variants$rename_comp_or_variant_and_main_71516$$(this.$component_id$,this.name,$meta71517__$1$$)},$app$main$data$workspace$variants$rename_comp_or_variant_and_main_71516$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71517$},$app$main$data$workspace$variants$rename_comp_or_variant_and_main_71516$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$rename_comp_or_variant_and_main_71516$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2502_component$jscomp$90_data$jscomp$402$$,$state$jscomp$852$$){$_$jscomp$2502_component$jscomp$90_data$jscomp$402$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$852$$);$_$jscomp$2502_component$jscomp$90_data$jscomp$402$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2502_component$jscomp$90_data$jscomp$402$$,this.$component_id$);return $APP.$app$common$types$component$is_variant_QMARK_$$($_$jscomp$2502_component$jscomp$90_data$jscomp$402$$)?
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$variants$rename_variant$$($APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2502_component$jscomp$90_data$jscomp$402$$),this.name)):(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$libraries$rename_component_and_main_instance$$(this.$component_id$,this.name))});return new $app$main$data$workspace$variants$rename_comp_or_variant_and_main_71516$$($component_id$jscomp$80$$,$name$jscomp$352$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$variants$bounding_rect$$=function($frames$jscomp$16_max_y$jscomp$1_y2s$$){var $min_x$jscomp$1_xs$jscomp$33$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$frames$jscomp$16_max_y$jscomp$1_y2s$$),$min_y$jscomp$1_ys$jscomp$8$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1511$y$$,$frames$jscomp$16_max_y$jscomp$1_y2s$$),$max_x$jscomp$1_x2s$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71519_SHARP_$$){return $APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__71519_SHARP_$$)+
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($p1__71519_SHARP_$$)},$frames$jscomp$16_max_y$jscomp$1_y2s$$);$frames$jscomp$16_max_y$jscomp$1_y2s$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71520_SHARP_$$){return $APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__71520_SHARP_$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($p1__71520_SHARP_$$)},$frames$jscomp$16_max_y$jscomp$1_y2s$$);$min_x$jscomp$1_xs$jscomp$33$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$min$$,
$min_x$jscomp$1_xs$jscomp$33$$);$min_y$jscomp$1_ys$jscomp$8$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$min$$,$min_y$jscomp$1_ys$jscomp$8$$);$max_x$jscomp$1_x2s$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$max$$,$max_x$jscomp$1_x2s$$);$frames$jscomp$16_max_y$jscomp$1_y2s$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$max$$,$frames$jscomp$16_max_y$jscomp$1_y2s$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1510$x$$,$min_x$jscomp$1_xs$jscomp$33$$,$APP.$cljs$cst$1511$y$$,$min_y$jscomp$1_ys$jscomp$8$$,$APP.$cljs$cst$290$width$$,$max_x$jscomp$1_x2s$$-$min_x$jscomp$1_xs$jscomp$33$$,$APP.$cljs$cst$1522$height$$,$frames$jscomp$16_max_y$jscomp$1_y2s$$-$min_y$jscomp$1_ys$jscomp$8$$],null)};
$app$main$data$workspace$variants$common_prefix$$=function($paths$jscomp$1$$){return $APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__71521_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_EQ_$$,$p1__71521_SHARP_$$)},$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$map$$,$APP.$cljs$core$vector$$,$paths$jscomp$1$$))))};
$APP.$app$main$data$workspace$variants$combine_as_variants$$=function($ids$jscomp$246$$,$p__71526$$){var $map__71527__$1$$=$APP.$cljs$core$__destructure_map$$($p__71526$$),$page_id$jscomp$261$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71527__$1$$,$APP.$cljs$cst$2043$page_id$$),$trigger$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71527__$1$$,$APP.$cljs$cst$4424$trigger$$),$variant_id$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71527__$1$$,
$APP.$cljs$cst$2000$variant_id$$);typeof $app$main$data$workspace$variants$combine_as_variants_71528$$==="undefined"&&($app$main$data$workspace$variants$combine_as_variants_71528$$=function($ids$jscomp$247$$,$p__71526$jscomp$1$$,$map__71527$jscomp$1$$,$page_id$jscomp$262$$,$trigger$jscomp$3$$,$variant_id$jscomp$40$$,$meta71529$$){this.ids=$ids$jscomp$247$$;this.$p__71526$=$p__71526$jscomp$1$$;this.$map__71527$=$map__71527$jscomp$1$$;this.$page_id$=$page_id$jscomp$262$$;this.$trigger$=$trigger$jscomp$3$$;
this.$variant_id$=$variant_id$jscomp$40$$;this.$meta71529$=$meta71529$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$combine_as_variants_71528$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$combine_as_variants_71528$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4441$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_combine_as_variants$$},
$app$main$data$workspace$variants$combine_as_variants_71528$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71530$$,$meta71529__$1$$){return new $app$main$data$workspace$variants$combine_as_variants_71528$$(this.ids,this.$p__71526$,this.$map__71527$,this.$page_id$,this.$trigger$,this.$variant_id$,$meta71529__$1$$)},$app$main$data$workspace$variants$combine_as_variants_71528$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71529$},$app$main$data$workspace$variants$combine_as_variants_71528$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$combine_as_variants_71528$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$240$$,$state$jscomp$853$$,$stream$jscomp$92$$){function $redirect_to_page$jscomp$1$$($page_id__$1$jscomp$13$$){return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$mapcat$$(function(){return $combine$$($page_id__$1$jscomp$13$$)},$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3943$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_initialize_page$$),
$stream$jscomp$92$$)))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2043$page_id$$,$page_id__$1$jscomp$13$$]))))}function $combine$$($current_page__$1$$){var $objects$jscomp$655$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$853$$,$current_page__$1$$),$ids__$1$jscomp$20$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$737_shape$jscomp$748$$){$id$jscomp$737_shape$jscomp$748$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$655$$,$id$jscomp$737_shape$jscomp$748$$);return!$APP.$app$common$types$component$main_instance_QMARK_$$($id$jscomp$737_shape$jscomp$748$$)||$APP.$app$common$types$component$is_variant_QMARK_$$($id$jscomp$737_shape$jscomp$748$$)},$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$655$$,$self__$jscomp$6100$$.ids));if($APP.$cljs$core$count$$($ids__$1$jscomp$20$$)>1){var $delta$jscomp$52_first_shape$jscomp$6_shapes$jscomp$116$$=
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71522_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$655$$,$p1__71522_SHARP_$$)},$ids__$1$jscomp$20$$),$rect$jscomp$43$$=$app$main$data$workspace$variants$bounding_rect$$($delta$jscomp$52_first_shape$jscomp$6_shapes$jscomp$116$$),$prefix$jscomp$63$$=$app$main$data$workspace$variants$common_prefix$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71523_SHARP_$$){return $APP.$app$common$path_names$split_path$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__71523_SHARP_$$))},
$delta$jscomp$52_first_shape$jscomp$6_shapes$jscomp$116$$)),$add_wrapper_QMARK_$jscomp$2$$=$APP.$cljs$core$empty_QMARK_$$($prefix$jscomp$63$$);$delta$jscomp$52_first_shape$jscomp$6_shapes$jscomp$116$$=$APP.$cljs$core$first$$($delta$jscomp$52_first_shape$jscomp$6_shapes$jscomp$116$$);$delta$jscomp$52_first_shape$jscomp$6_shapes$jscomp$116$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$43$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$52_first_shape$jscomp$6_shapes$jscomp$116$$)-
30,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$43$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$52_first_shape$jscomp$6_shapes$jscomp$116$$)-30);var $common_parent$$=$APP.$cljs$core$last$$($app$main$data$workspace$variants$common_prefix$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71524_SHARP_$$){return $APP.$cljs$core$reverse$$($APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$655$$,$p1__71524_SHARP_$$))},
$ids__$1$jscomp$20$$))),$index$jscomp$364$$=$APP.$cljs$core$count$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$655$$,$common_parent$$)))+1,$variant_id__$1$jscomp$1$$=function(){var $or__5025__auto__$jscomp$846$$=$self__$jscomp$6100$$.$variant_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$846$$)?$or__5025__auto__$jscomp$846$$:$APP.$app$common$uuid$next$$()}(),$undo_id$jscomp$78$$=Symbol();return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$525$$=
$self__$jscomp$6100$$.$page_id$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$525$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_page__$1$$,$self__$jscomp$6100$$.$page_id$):$and__5023__auto__$jscomp$525$$}())?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2043$page_id$$,$self__$jscomp$6100$$.$page_id$]))):$APP.$beicon$v2$core$empty$$(),
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$78$$),$app$main$data$workspace$variants$transform_in_variant$cljs$0core$0IFn$0_invoke$0arity$07$$($APP.$cljs$core$first$$($ids__$1$jscomp$20$$),$variant_id__$1$jscomp$1$$,$delta$jscomp$52_first_shape$jscomp$6_shapes$jscomp$116$$,$prefix$jscomp$63$$,$add_wrapper_QMARK_$jscomp$2$$,!1,!1),$APP.$app$main$data$workspace$shapes$relocate_shapes$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$reverse$$($APP.$cljs$core$rest$$($ids__$1$jscomp$20$$))),$variant_id__$1$jscomp$1$$,0),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids__$1$jscomp$20$$,function($p1__71525_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__71525_SHARP_$$,$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$257$left$$),$APP.$cljs$cst$1871$constraints_v$$,
$APP.$cljs$cst$1562$top$$),$APP.$cljs$cst$1645$fixed_scroll$$,!1)}),$APP.$app$main$data$workspace$shapes$relocate_shapes$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$variant_id__$1$jscomp$1$$]),$common_parent$$,$index$jscomp$364$$),$app$main$data$workspace$transforms$update_dimensions$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$variant_id__$1$jscomp$1$$],null),$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$43$$)+
60),$app$main$data$workspace$transforms$update_dimensions$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$variant_id__$1$jscomp$1$$],null),$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$43$$)+60),$APP.$app$main$data$event$event$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"combine-as-variants",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$self__$jscomp$6100$$.$trigger$,$cljs$cst$4442$number_of_combined$$,$APP.$cljs$core$count$$($ids__$1$jscomp$20$$)],null),$APP.$cljs$core$meta$$($it__$1$jscomp$116$$)])))),$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$78$$))))}return null}
var $self__$jscomp$6100$$=this,$it__$1$jscomp$116$$=this,$current_page$jscomp$2$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$853$$);return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$526$$=$self__$jscomp$6100$$.$page_id$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$526$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$6100$$.$page_id$,$current_page$jscomp$2$$):$and__5023__auto__$jscomp$526$$}())?
$redirect_to_page$jscomp$1$$($self__$jscomp$6100$$.$page_id$):$combine$$($current_page$jscomp$2$$)});return new $app$main$data$workspace$variants$combine_as_variants_71528$$($ids$jscomp$246$$,$p__71526$$,$map__71527__$1$$,$page_id$jscomp$261$$,$trigger$jscomp$2$$,$variant_id$jscomp$39$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$variants$variant_switch$$=function($shape$jscomp$749$$,$p__71539$$){var $map__71540__$1$$=$APP.$cljs$core$__destructure_map$$($p__71539$$),$pos$jscomp$122$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71540__$1$$,$APP.$cljs$cst$1406$pos$$),$val$jscomp$185$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71540__$1$$,$APP.$cljs$cst$108$val$$);typeof $app$main$data$workspace$variants$variant_switch_71541$$==="undefined"&&($app$main$data$workspace$variants$variant_switch_71541$$=
function($shape$jscomp$750$$,$p__71539$jscomp$1$$,$map__71540$jscomp$1$$,$params$jscomp$287$$,$pos$jscomp$123$$,$val$jscomp$186$$,$meta71542$$){this.shape=$shape$jscomp$750$$;this.$p__71539$=$p__71539$jscomp$1$$;this.$map__71540$=$map__71540$jscomp$1$$;this.params=$params$jscomp$287$$;this.pos=$pos$jscomp$123$$;this.$val$=$val$jscomp$186$$;this.$meta71542$=$meta71542$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$variant_switch_71541$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$variant_switch_71541$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4444$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_variant_switch$$},$app$main$data$workspace$variants$variant_switch_71541$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71543$$,$meta71542__$1$$){return new $app$main$data$workspace$variants$variant_switch_71541$$(this.shape,this.$p__71539$,this.$map__71540$,
this.params,this.pos,this.$val$,$meta71542__$1$$)},$app$main$data$workspace$variants$variant_switch_71541$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71542$},$app$main$data$workspace$variants$variant_switch_71541$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$variant_switch_71541$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$,
$comps_nesting_loop_QMARK_$jscomp$1_current_page_objects_shape_parents_state$jscomp$855$$){var $self__$jscomp$6108$$=this;$component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$=$APP.$app$main$data$helpers$lookup_libraries$$($comps_nesting_loop_QMARK_$jscomp$1_current_page_objects_shape_parents_state$jscomp$855$$);var $component_id$jscomp$82$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6108$$.shape),
$component$jscomp$91_nearest_comp_valid_comps$$=$app$common$types$file$get_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6108$$.shape),$component_id$jscomp$82$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!1]));if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$6108$$.$val$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$91_nearest_comp_valid_comps$$,$APP.$cljs$cst$2001$variant_properties$$),$self__$jscomp$6108$$.pos),$APP.$cljs$cst$260$value$$))){$comps_nesting_loop_QMARK_$jscomp$1_current_page_objects_shape_parents_state$jscomp$855$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($comps_nesting_loop_QMARK_$jscomp$1_current_page_objects_shape_parents_state$jscomp$855$$);
var $variant_comps_variant_id$jscomp$41$$=$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$91_nearest_comp_valid_comps$$),$component_file_data$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6108$$.shape)),
$APP.$cljs$cst$142$data$$);$component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($component_file_data$$,$APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$91_nearest_comp_valid_comps$$)),$APP.$cljs$cst$1631$objects$$);$variant_comps_variant_id$jscomp$41$$=$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($component_file_data$$,
$component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$,$variant_comps_variant_id$jscomp$41$$);var $target_props$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$91_nearest_comp_valid_comps$$),$self__$jscomp$6108$$.pos,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$260$value$$,$self__$jscomp$6108$$.$val$);$component$jscomp$91_nearest_comp_valid_comps$$=
$APP.$cljs$core$reverse$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71537_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__71537_SHARP_$$,$APP.$cljs$cst$2001$variant_properties$$),$self__$jscomp$6108$$.pos),$APP.$cljs$cst$260$value$$),$self__$jscomp$6108$$.$val$)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71536_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__71536_SHARP_$$),
$component_id$jscomp$82$$)},$variant_comps_variant_id$jscomp$41$$)));$component$jscomp$91_nearest_comp_valid_comps$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$min_key$$,function($p1__71538_SHARP_$$){return $app$common$types$variant$distance$$($target_props$$,$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($p1__71538_SHARP_$$))},$component$jscomp$91_nearest_comp_valid_comps$$);$comps_nesting_loop_QMARK_$jscomp$1_current_page_objects_shape_parents_state$jscomp$855$$=
$app$common$files$helpers$get_parents_with_self$$($comps_nesting_loop_QMARK_$jscomp$1_current_page_objects_shape_parents_state$jscomp$855$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6108$$.shape));$component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$=$APP.$app$common$files$helpers$get_children_with_self$$($component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$,
$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$91_nearest_comp_valid_comps$$));$comps_nesting_loop_QMARK_$jscomp$1_current_page_objects_shape_parents_state$jscomp$855$$=$APP.$cljs$core$seq_QMARK_$$($app$common$files$helpers$components_nesting_loop_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$,$comps_nesting_loop_QMARK_$jscomp$1_current_page_objects_shape_parents_state$jscomp$855$$));
$component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$=$APP.$cljs$core$meta$$($self__$jscomp$6108$$.params);$component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$=$APP.$cljs$core$__destructure_map$$($component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$);$component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);if($APP.$cljs$core$truth_$$($component$jscomp$91_nearest_comp_valid_comps$$))return $comps_nesting_loop_QMARK_$jscomp$1_current_page_objects_shape_parents_state$jscomp$855$$?($component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$.$cljs$core$IFn$_invoke$arity$0$?
$component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$.$cljs$core$IFn$_invoke$arity$0$():$component_page_objects_it$jscomp$241_libraries$jscomp$95_map__71546_map__71546__$1_nearest_comp_children_on_error$jscomp$35$$(),$APP.$beicon$v2$core$empty$$()):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$libraries$component_swap$$($self__$jscomp$6108$$.shape,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6108$$.shape),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$91_nearest_comp_valid_comps$$),!0),$APP.$app$main$data$event$event$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"variant-switch",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:design-tab"],null),$APP.$cljs$core$meta$$(this)]))))}return null});
return new $app$main$data$workspace$variants$variant_switch_71541$$($shape$jscomp$749$$,$p__71539$$,$map__71540__$1$$,$map__71540__$1$$,$pos$jscomp$122$$,$val$jscomp$185$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$variants$variants_switch$$=function($p__71547$$){var $map__71548__$1$$=$APP.$cljs$core$__destructure_map$$($p__71547$$),$shapes$jscomp$117$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71548__$1$$,$APP.$cljs$cst$1614$shapes$$);typeof $app$main$data$workspace$variants$variants_switch_71549$$==="undefined"&&($app$main$data$workspace$variants$variants_switch_71549$$=function($p__71547$jscomp$1$$,$map__71548$jscomp$1$$,$params$jscomp$289$$,$shapes$jscomp$118$$,
$meta71550$$){this.$p__71547$=$p__71547$jscomp$1$$;this.$map__71548$=$map__71548$jscomp$1$$;this.params=$params$jscomp$289$$;this.shapes=$shapes$jscomp$118$$;this.$meta71550$=$meta71550$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$variants_switch_71549$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$variants_switch_71549$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4445$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_variants_switch$$},$app$main$data$workspace$variants$variants_switch_71549$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71551$$,$meta71550__$1$$){return new $app$main$data$workspace$variants$variants_switch_71549$$(this.$p__71547$,this.$map__71548$,this.params,this.shapes,$meta71550__$1$$)},$app$main$data$workspace$variants$variants_switch_71549$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71550$},
$app$main$data$workspace$variants$variants_switch_71549$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$variants_switch_71549$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6112$$=this,$it__$1$jscomp$118$$=this,$ids$jscomp$248$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$app$common$data$xf_COLON_map_id$$,$self__$jscomp$6112$$.shapes),
$undo_id$jscomp$79$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$79$$)),$APP.$beicon$v2$core$map$$(function($data$jscomp$403$$){return $APP.$cljs$core$with_meta$$($app$main$data$workspace$variants$variant_switch$$($data$jscomp$403$$,$self__$jscomp$6112$$.params),$APP.$cljs$core$meta$$($it__$1$jscomp$118$$))},$APP.$beicon$v2$core$from$$($self__$jscomp$6112$$.shapes)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$79$$),
$APP.$app$main$data$workspace$selection$select_shapes$$($ids$jscomp$248$$)))});return new $app$main$data$workspace$variants$variants_switch_71549$$($p__71547$$,$map__71548__$1$$,$map__71548__$1$$,$shapes$jscomp$117$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$viewport$calculate_centered_viewbox$$=function($local$jscomp$20$$,$ny$jscomp$3_position$jscomp$158$$){var $nh$jscomp$1_vbox$jscomp$27$$=$APP.$cljs$cst$1925$vbox$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$20$$),$nw$jscomp$1_nx$jscomp$3$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($nh$jscomp$1_vbox$jscomp$27$$)/2;$nh$jscomp$1_vbox$jscomp$27$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($nh$jscomp$1_vbox$jscomp$27$$)/2;$nw$jscomp$1_nx$jscomp$3$$=
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($ny$jscomp$3_position$jscomp$158$$)-$nw$jscomp$1_nx$jscomp$3$$;$ny$jscomp$3_position$jscomp$158$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($ny$jscomp$3_position$jscomp$158$$)-$nh$jscomp$1_vbox$jscomp$27$$;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($local$jscomp$20$$,$APP.$cljs$cst$1925$vbox$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1510$x$$,$nw$jscomp$1_nx$jscomp$3$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$ny$jscomp$3_position$jscomp$158$$]))};
$app$main$data$workspace$viewport$update_viewport_position_center$$=function($position$jscomp$159$$){typeof $app$main$data$workspace$viewport$update_viewport_position_center_71187$$==="undefined"&&($app$main$data$workspace$viewport$update_viewport_position_center_71187$$=function($position$jscomp$160$$,$meta71188$$){this.position=$position$jscomp$160$$;this.$meta71188$=$meta71188$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$viewport$update_viewport_position_center_71187$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$update_viewport_position_center_71187$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4448$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_update_viewport_position_center$$},$app$main$data$workspace$viewport$update_viewport_position_center_71187$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71189$$,$meta71188__$1$$){return new $app$main$data$workspace$viewport$update_viewport_position_center_71187$$(this.position,
$meta71188__$1$$)},$app$main$data$workspace$viewport$update_viewport_position_center_71187$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71188$},$app$main$data$workspace$viewport$update_viewport_position_center_71187$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$update_viewport_position_center_71187$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2510$$,$state$jscomp$861$$){return $APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$861$$)?
$state$jscomp$861$$:$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$861$$,$APP.$cljs$cst$1920$workspace_local$$,$app$main$data$workspace$viewport$calculate_centered_viewbox$$,this.position)},$app$main$data$workspace$viewport$update_viewport_position_center_71187$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$update_viewport_position_center_71187$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2511$$,
$state$jscomp$862$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$862$$)});return new $app$main$data$workspace$viewport$update_viewport_position_center_71187$$($position$jscomp$159$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$viewport$update_viewport_position$$=function($p__71196$$){var $map__71197__$1$$=$APP.$cljs$core$__destructure_map$$($p__71196$$),$x$jscomp$1214$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__71197__$1$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$identity$$),$y$jscomp$446$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__71197__$1$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$identity$$);typeof $app$main$data$workspace$viewport$update_viewport_position_71198$$===
"undefined"&&($app$main$data$workspace$viewport$update_viewport_position_71198$$=function($p__71196$jscomp$1$$,$map__71197$jscomp$1$$,$x$jscomp$1215$$,$y$jscomp$447$$,$meta71199$$){this.$p__71196$=$p__71196$jscomp$1$$;this.$map__71197$=$map__71197$jscomp$1$$;this.x=$x$jscomp$1215$$;this.y=$y$jscomp$447$$;this.$meta71199$=$meta71199$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$viewport$update_viewport_position_71198$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$update_viewport_position_71198$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4449$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_update_viewport_position$$},$app$main$data$workspace$viewport$update_viewport_position_71198$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71200$$,$meta71199__$1$$){return new $app$main$data$workspace$viewport$update_viewport_position_71198$$(this.$p__71196$,
this.$map__71197$,this.x,this.y,$meta71199__$1$$)},$app$main$data$workspace$viewport$update_viewport_position_71198$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71199$},$app$main$data$workspace$viewport$update_viewport_position_71198$$.prototype.$app$main$data$event$PerformanceEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$update_viewport_position_71198$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$update_viewport_position_71198$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2512$$,$state$jscomp$863$$){var $self__$jscomp$6130$$=this;return $APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$863$$)?$state$jscomp$863$$:$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$863$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1925$vbox$$],null),function($vbox$jscomp$28$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($vbox$jscomp$28$$,
$APP.$cljs$cst$1510$x$$,$self__$jscomp$6130$$.x),$APP.$cljs$cst$1511$y$$,$self__$jscomp$6130$$.y)})},$app$main$data$workspace$viewport$update_viewport_position_71198$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$update_viewport_position_71198$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2513$$,$state$jscomp$864$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$864$$)});
return new $app$main$data$workspace$viewport$update_viewport_position_71198$$($p__71196$$,$map__71197__$1$$,$x$jscomp$1214$$,$y$jscomp$446$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$datauri__GT_blob_uri$$=function($uri$jscomp$98$$){return $APP.$beicon$v2$core$map$$(function($blob$jscomp$37$$){return $APP.$app$util$webapi$create_uri$$($blob$jscomp$37$$)},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1581$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1579$uri$$,$uri$jscomp$98$$,$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$1591$blob$$,$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$],null))))};
$app$main$data$workspace$get_file_object_thumbnails$$=function($file_id$jscomp$254$$){return $APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$mapcat$$(function($thumbnails$jscomp$12$$){return $APP.$beicon$v2$core$mapcat$$(function($p__71572_v$jscomp$598$$){var $k$jscomp$652$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71572_v$jscomp$598$$,0,null);$p__71572_v$jscomp$598$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71572_v$jscomp$598$$,
1,null);return $APP.$cuerdas$core$starts_with_QMARK_$$($p__71572_v$jscomp$598$$,"data:")?$APP.$beicon$v2$core$map$$(function($uri$jscomp$99$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$652$$,$uri$jscomp$99$$],null)},$app$main$data$workspace$datauri__GT_blob_uri$$($p__71572_v$jscomp$598$$)):(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$652$$,
$p__71572_v$jscomp$598$$],null))},$APP.$beicon$v2$core$from$$($thumbnails$jscomp$12$$))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3946$get_file_object_thumbnails$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$254$$],null))))};
$app$main$data$workspace$resolve_file$$=function($file$jscomp$74$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"resolve file"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$74$$))],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$227$features$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$cst$227$features$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$74$$))],null)],null)}),
null,"app.main.data.workspace",$APP.$cljs$cst$1161$info$$,!1);return $APP.$beicon$v2$core$map$$(function($data$jscomp$404$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($file$jscomp$74$$,$APP.$cljs$cst$142$data$$,$APP.$app$common$data$removem$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$transit$pointer_QMARK_$$,$APP.$cljs$core$val$$),$data$jscomp$404$$))},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$142$data$$,$app$main$features$pointer_map$resolve_file$$($file$jscomp$74$$)))};
$app$main$data$workspace$check_libraries_synchronization$$=function($file_id$jscomp$255$$,$libraries$jscomp$96$$){typeof $app$main$data$workspace$check_libraries_synchronization_71599$$==="undefined"&&($app$main$data$workspace$check_libraries_synchronization_71599$$=function($file_id$jscomp$256$$,$libraries$jscomp$97$$,$meta71600$$){this.$file_id$=$file_id$jscomp$256$$;this.libraries=$libraries$jscomp$97$$;this.$meta71600$=$meta71600$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$check_libraries_synchronization_71599$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$check_libraries_synchronization_71599$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4457$app_DOT_main_DOT_data_DOT_workspace_SLASH_check_libraries_synchronization$$},$app$main$data$workspace$check_libraries_synchronization_71599$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71601$$,$meta71600__$1$$){return new $app$main$data$workspace$check_libraries_synchronization_71599$$(this.$file_id$,
this.libraries,$meta71600__$1$$)},$app$main$data$workspace$check_libraries_synchronization_71599$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71600$},$app$main$data$workspace$check_libraries_synchronization_71599$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$check_libraries_synchronization_71599$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2522_file$jscomp$75_needs_check_QMARK_$$,$state$jscomp$872$$){$_$jscomp$2522_file$jscomp$75_needs_check_QMARK_$$=
$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$872$$,this.$file_id$);var $ignore_until$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2522_file$jscomp$75_needs_check_QMARK_$$,$cljs$cst$2585$ignore_sync_until$$);$_$jscomp$2522_file$jscomp$75_needs_check_QMARK_$$=$APP.$cljs$core$some$$(function($p1__71598_SHARP_$$){return $APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($p1__71598_SHARP_$$)>$cljs$cst$3963$synced_at$$.$cljs$core$IFn$_invoke$arity$1$($p1__71598_SHARP_$$)&&
($APP.$cljs$core$not$$($ignore_until$jscomp$2$$)||$APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($p1__71598_SHARP_$$)>$ignore_until$jscomp$2$$)},this.libraries);return $APP.$cljs$core$truth_$$($_$jscomp$2522_file$jscomp$75_needs_check_QMARK_$$)?$APP.$beicon$v2$core$delay$$(1E3,(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$libraries$notify_sync_file$$())):null});return new $app$main$data$workspace$check_libraries_synchronization_71599$$($file_id$jscomp$255$$,$libraries$jscomp$96$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$library_resolved$$=function($library$jscomp$29$$){typeof $app$main$data$workspace$library_resolved_71606$$==="undefined"&&($app$main$data$workspace$library_resolved_71606$$=function($library$jscomp$30$$,$meta71607$$){this.library=$library$jscomp$30$$;this.$meta71607$=$meta71607$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$library_resolved_71606$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$library_resolved_71606$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4458$app_DOT_main_DOT_data_DOT_workspace_SLASH_library_resolved$$},$app$main$data$workspace$library_resolved_71606$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71608$$,$meta71607__$1$$){return new $app$main$data$workspace$library_resolved_71606$$(this.library,$meta71607__$1$$)},$app$main$data$workspace$library_resolved_71606$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71607$},$app$main$data$workspace$library_resolved_71606$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$library_resolved_71606$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2523$$,$state$jscomp$873$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$873$$,$APP.$cljs$cst$1916$files$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.library),
this.library)});return new $app$main$data$workspace$library_resolved_71606$$($library$jscomp$29$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$fetch_libraries$$=function($file_id$jscomp$257$$,$features__$1$jscomp$20$$){typeof $app$main$data$workspace$fetch_libries_71610$$==="undefined"&&($app$main$data$workspace$fetch_libries_71610$$=function($file_id$jscomp$258$$,$features$jscomp$5$$,$meta71611$$){this.$file_id$=$file_id$jscomp$258$$;this.features=$features$jscomp$5$$;this.$meta71611$=$meta71611$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$fetch_libries_71610$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$fetch_libries_71610$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4459$app_DOT_main_DOT_data_DOT_workspace_SLASH_fetch_libries$$},$app$main$data$workspace$fetch_libries_71610$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71612$$,$meta71611__$1$$){return new $app$main$data$workspace$fetch_libries_71610$$(this.$file_id$,this.features,$meta71611__$1$$)},$app$main$data$workspace$fetch_libries_71610$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71611$},$app$main$data$workspace$fetch_libries_71610$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$fetch_libries_71610$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2524_stopper_s$jscomp$4$$,$___$1$jscomp$1721$$,$stream$jscomp$94$$){var $self__$jscomp$6166$$=this;$_$jscomp$2524_stopper_s$jscomp$4$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4324$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize_workspace$$),
$stream$jscomp$94$$);return $APP.$beicon$v2$core$take_until$$($_$jscomp$2524_stopper_s$jscomp$4$$,$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$mapcat$$(function($libraries$jscomp$98$$){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$libraries$libraries_fetched$$($self__$jscomp$6166$$.$file_id$,$libraries$jscomp$98$$)),$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$($app$main$data$workspace$library_resolved$$,$APP.$beicon$v2$core$mapcat$$($app$main$data$workspace$resolve_file$$,
$APP.$beicon$v2$core$merge_map$$(function($map__71614__$1_p__71613$$){$map__71614__$1_p__71613$$=$APP.$cljs$core$__destructure_map$$($map__71614__$1_p__71613$$);var $id$jscomp$738$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71614__$1_p__71613$$,$APP.$cljs$cst$266$id$$),$synced_at$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71614__$1_p__71613$$,$cljs$cst$3963$synced_at$$);return $APP.$beicon$v2$core$map$$(function($p1__71609_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__71609_SHARP_$$,
$cljs$cst$3963$synced_at$$,$synced_at$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2180$library_of$$,$self__$jscomp$6166$$.$file_id$]))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2274$get_file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$id$jscomp$738$$,$APP.$cljs$cst$227$features$$,$self__$jscomp$6166$$.features],null)))},$APP.$beicon$v2$core$from$$($libraries$jscomp$98$$)))),$APP.$beicon$v2$core$map$$($app$main$data$workspace$libraries$library_thumbnails_fetched$$,
$APP.$beicon$v2$core$mapcat$$(function($file_id__$1$jscomp$4$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3946$get_file_object_thumbnails$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$file_id__$1$jscomp$4$$,$APP.$cljs$cst$78$tag$$,"component"],null))},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$266$id$$,$APP.$beicon$v2$core$from$$($libraries$jscomp$98$$))))),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$check_libraries_synchronization$$($self__$jscomp$6166$$.$file_id$,
$libraries$jscomp$98$$)))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3991$get_file_libraries$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$6166$$.$file_id$],null))),(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2326$app_DOT_main_DOT_data_DOT_workspace_SLASH_all_libraries_resolved$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,
$self__$jscomp$6166$$.$file_id$],null)))))});return new $app$main$data$workspace$fetch_libries_71610$$($file_id$jscomp$257$$,$features__$1$jscomp$20$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$workspace_initialized$$=function($file_id$jscomp$261$$){typeof $app$main$data$workspace$workspace_initialized_71620$$==="undefined"&&($app$main$data$workspace$workspace_initialized_71620$$=function($file_id$jscomp$262$$,$meta71621$$){this.$file_id$=$file_id$jscomp$262$$;this.$meta71621$=$meta71621$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$workspace_initialized_71620$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$workspace_initialized_71620$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4281$app_DOT_main_DOT_data_DOT_workspace_SLASH_workspace_initialized$$},$app$main$data$workspace$workspace_initialized_71620$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71622$$,$meta71621__$1$$){return new $app$main$data$workspace$workspace_initialized_71620$$(this.$file_id$,$meta71621__$1$$)},$app$main$data$workspace$workspace_initialized_71620$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71621$},$app$main$data$workspace$workspace_initialized_71620$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$workspace_initialized_71620$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2526$$,$state$jscomp$875$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$875$$,$APP.$cljs$cst$3563$workspace_undo$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),
$cljs$cst$4461$workspace_ready$$,this.$file_id$)},$app$main$data$workspace$workspace_initialized_71620$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$workspace_initialized_71620$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$plugins$check_open_plugin$$(),$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_local_library$$(this.$file_id$)),
$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1236$mcp$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$mcp$init$$()):null)});return new $app$main$data$workspace$workspace_initialized_71620$$($file_id$jscomp$261$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$bundle_fetched$$=function($p__71623$$){var $map__71624__$1$$=$APP.$cljs$core$__destructure_map$$($p__71623$$),$file$jscomp$76$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71624__$1$$,$APP.$cljs$cst$208$file$$),$file_id$jscomp$263$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71624__$1$$,$APP.$cljs$cst$1644$file_id$$),$thumbnails$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71624__$1$$,$APP.$cljs$cst$2229$thumbnails$$);
typeof $app$main$data$workspace$bundle_fetched_71625$$==="undefined"&&($app$main$data$workspace$bundle_fetched_71625$$=function($p__71623$jscomp$1$$,$map__71624$jscomp$1$$,$bundle$jscomp$1$$,$file$jscomp$77$$,$file_id$jscomp$264$$,$thumbnails$jscomp$14$$,$meta71626$$){this.$p__71623$=$p__71623$jscomp$1$$;this.$map__71624$=$map__71624$jscomp$1$$;this.$bundle$=$bundle$jscomp$1$$;this.file=$file$jscomp$77$$;this.$file_id$=$file_id$jscomp$264$$;this.$thumbnails$=$thumbnails$jscomp$14$$;this.$meta71626$=
$meta71626$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$bundle_fetched_71625$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$bundle_fetched_71625$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4462$app_DOT_main_DOT_data_DOT_workspace_SLASH_bundle_fetched$$},$app$main$data$workspace$bundle_fetched_71625$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71627$$,$meta71626__$1$$){return new $app$main$data$workspace$bundle_fetched_71625$$(this.$p__71623$,this.$map__71624$,this.$bundle$,this.file,this.$file_id$,this.$thumbnails$,$meta71626__$1$$)},$app$main$data$workspace$bundle_fetched_71625$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71626$},$app$main$data$workspace$bundle_fetched_71625$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.$bundle$},$app$main$data$workspace$bundle_fetched_71625$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$bundle_fetched_71625$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2529$$,$state$jscomp$876$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$876$$,$APP.$cljs$cst$2229$thumbnails$$,this.$thumbnails$),$APP.$cljs$cst$1916$files$$,$APP.$cljs$core$assoc$$,this.$file_id$,this.file)});return new $app$main$data$workspace$bundle_fetched_71625$$($p__71623$$,
$map__71624__$1$$,$map__71624__$1$$,$file$jscomp$76$$,$file_id$jscomp$263$$,$thumbnails$jscomp$13$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$zoom_to_frame$$=function(){typeof $app$main$data$workspace$zoom_to_frame_71628$$==="undefined"&&($app$main$data$workspace$zoom_to_frame_71628$$=function($meta71629$$){this.$meta71629$=$meta71629$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$zoom_to_frame_71628$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom_to_frame_71628$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4463$app_DOT_main_DOT_data_DOT_workspace_SLASH_zoom_to_frame$$},$app$main$data$workspace$zoom_to_frame_71628$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71630$$,$meta71629__$1$$){return new $app$main$data$workspace$zoom_to_frame_71628$$($meta71629__$1$$)},$app$main$data$workspace$zoom_to_frame_71628$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71629$},$app$main$data$workspace$zoom_to_frame_71628$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom_to_frame_71628$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2530_board_id_board_id__$1_frames_id_params$jscomp$290$$,$state$jscomp$877$$){$_$jscomp$2530_board_id_board_id__$1_frames_id_params$jscomp$290$$=$APP.$app$main$router$get_params$$($state$jscomp$877$$);$_$jscomp$2530_board_id_board_id__$1_frames_id_params$jscomp$290$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2530_board_id_board_id__$1_frames_id_params$jscomp$290$$,
$cljs$cst$3594$board_id$$);$_$jscomp$2530_board_id_board_id__$1_frames_id_params$jscomp$290$$=$APP.$cljs$core$vector_QMARK_$$($_$jscomp$2530_board_id_board_id__$1_frames_id_params$jscomp$290$$)?$_$jscomp$2530_board_id_board_id__$1_frames_id_params$jscomp$290$$:typeof $_$jscomp$2530_board_id_board_id__$1_frames_id_params$jscomp$290$$==="string"?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$_$jscomp$2530_board_id_board_id__$1_frames_id_params$jscomp$290$$],
null):null;$_$jscomp$2530_board_id_board_id__$1_frames_id_params$jscomp$290$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$common$uuid$uuid$$,$_$jscomp$2530_board_id_board_id__$1_frames_id_params$jscomp$290$$));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$select_shapes$$($_$jscomp$2530_board_id_board_id__$1_frames_id_params$jscomp$290$$),
$APP.$app$main$data$workspace$zoom$zoom_to_selected_shape$$)});return new $app$main$data$workspace$zoom_to_frame_71628$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$fetch_bundle$$=function($file_id$jscomp$265$$,$features__$1$jscomp$21$$){typeof $app$main$data$workspace$fetch_bundle_71631$$==="undefined"&&($app$main$data$workspace$fetch_bundle_71631$$=function($file_id$jscomp$266$$,$features$jscomp$6$$,$meta71632$$){this.$file_id$=$file_id$jscomp$266$$;this.features=$features$jscomp$6$$;this.$meta71632$=$meta71632$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$fetch_bundle_71631$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$fetch_bundle_71631$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4464$app_DOT_main_DOT_data_DOT_workspace_SLASH_fetch_bundle$$},$app$main$data$workspace$fetch_bundle_71631$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71633$$,$meta71632__$1$$){return new $app$main$data$workspace$fetch_bundle_71631$$(this.$file_id$,this.features,$meta71632__$1$$)},$app$main$data$workspace$fetch_bundle_71631$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71632$},$app$main$data$workspace$fetch_bundle_71631$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$fetch_bundle_71631$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2531_stopper_s$jscomp$5$$,$___$1$jscomp$1728$$,$stream$jscomp$95$$){var $self__$jscomp$6188$$=this;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"fetch bundle"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,""+($self__$jscomp$6188$$.$file_id$??"")],null)],null)}),null,"app.main.data.workspace",$APP.$cljs$cst$1160$debug$$,!1);$_$jscomp$2531_stopper_s$jscomp$5$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4324$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize_workspace$$),
$stream$jscomp$95$$);return $APP.$beicon$v2$core$take_until$$($_$jscomp$2531_stopper_s$jscomp$5$$,$APP.$beicon$v2$core$map$$($app$main$data$workspace$bundle_fetched$$,$APP.$beicon$v2$core$mapcat$$(function($p__71634$$){var $file$jscomp$78$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71634$$,0,null),$thumbnails$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71634$$,1,null);return $APP.$beicon$v2$core$map$$(function($file__$1$jscomp$1$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace",
$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"file resolved"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$6188$$.$file_id$],
null)],null)}),null,"app.main.data.workspace",$APP.$cljs$cst$144$trace$$,!1);return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$208$file$$,$file__$1$jscomp$1$$,$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$6188$$.$file_id$,$APP.$cljs$cst$227$features$$,$self__$jscomp$6188$$.features,$APP.$cljs$cst$2229$thumbnails$$,$thumbnails$jscomp$15$$],null)},$app$main$data$workspace$resolve_file$$($file$jscomp$78$$))},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$zip$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2274$get_file$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$self__$jscomp$6188$$.$file_id$,$APP.$cljs$cst$227$features$$,$self__$jscomp$6188$$.features],null)),$app$main$data$workspace$get_file_object_thumbnails$$($self__$jscomp$6188$$.$file_id$))))))});return new $app$main$data$workspace$fetch_bundle_71631$$($file_id$jscomp$265$$,$features__$1$jscomp$21$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$initialize_file$$=function($team_id$jscomp$82$$,$file_id$jscomp$267$$){typeof $app$main$data$workspace$initialize_file_71639$$==="undefined"&&($app$main$data$workspace$initialize_file_71639$$=function($team_id$jscomp$83$$,$file_id$jscomp$268$$,$meta71640$$){this.$team_id$=$team_id$jscomp$83$$;this.$file_id$=$file_id$jscomp$268$$;this.$meta71640$=$meta71640$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$initialize_file_71639$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$initialize_file_71639$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4465$app_DOT_main_DOT_data_DOT_workspace_SLASH_initialize_file$$},$app$main$data$workspace$initialize_file_71639$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71641$$,$meta71640__$1$$){return new $app$main$data$workspace$initialize_file_71639$$(this.$team_id$,this.$file_id$,$meta71640__$1$$)},$app$main$data$workspace$initialize_file_71639$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71640$},$app$main$data$workspace$initialize_file_71639$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$initialize_file_71639$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2532_features__$1$jscomp$22$$,$state$jscomp$878$$){var $self__$jscomp$6192$$=this;$_$jscomp$2532_features__$1$jscomp$22$$=$APP.$app$main$features$get_enabled_features$$($state$jscomp$878$$,$self__$jscomp$6192$$.$team_id$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"initialize-file"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1927$team_id$$,""+($self__$jscomp$6192$$.$team_id$??
"")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,""+($self__$jscomp$6192$$.$file_id$??"")],null)],null)}),null,"app.main.data.workspace",$APP.$cljs$cst$1160$debug$$,!1);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$fetch_bundle$$($self__$jscomp$6192$$.$file_id$,$_$jscomp$2532_features__$1$jscomp$22$$))});return new $app$main$data$workspace$initialize_file_71639$$($team_id$jscomp$82$$,$file_id$jscomp$267$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$initialize_workspace$$=function($team_id$jscomp$84$$,$file_id$jscomp$269$$){typeof $app$main$data$workspace$initialize_workspace_71650$$==="undefined"&&($app$main$data$workspace$initialize_workspace_71650$$=function($team_id$jscomp$85$$,$file_id$jscomp$270$$,$meta71651$$){this.$team_id$=$team_id$jscomp$85$$;this.$file_id$=$file_id$jscomp$270$$;this.$meta71651$=$meta71651$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},
$app$main$data$workspace$initialize_workspace_71650$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$initialize_workspace_71650$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4466$app_DOT_main_DOT_data_DOT_workspace_SLASH_initialize_workspace$$},$app$main$data$workspace$initialize_workspace_71650$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71652$$,$meta71651__$1$$){return new $app$main$data$workspace$initialize_workspace_71650$$(this.$team_id$,
this.$file_id$,$meta71651__$1$$)},$app$main$data$workspace$initialize_workspace_71650$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71651$},$app$main$data$workspace$initialize_workspace_71650$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$initialize_workspace_71650$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2533$$,$state$jscomp$879$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$879$$,
$APP.$cljs$cst$2213$recent_colors$$,$APP.$cljs$cst$2213$recent_colors$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$user$$)),$APP.$cljs$cst$2214$recent_fonts$$,$APP.$cljs$cst$2214$recent_fonts$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$user$$)),$APP.$cljs$cst$1917$current_file_id$$,this.$file_id$),$APP.$cljs$cst$2216$workspace_presence$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$initialize_workspace_71650$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$initialize_workspace_71650$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2534$$,$state$jscomp$880$$,$stream$jscomp$96$$){function $render_wasm_ready_QMARK_$$(){return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")&&$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($app$render_wasm$wasm$context_lost_QMARK_$$))}
var $self__$jscomp$6197$$=this,$stoper_s$jscomp$3$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4324$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize_workspace$$),$stream$jscomp$96$$),$rparams$$=$APP.$app$main$router$get_params$$($state$jscomp$880$$),$features__$1$jscomp$23$$=$APP.$app$main$features$get_enabled_features$$($state$jscomp$880$$,$self__$jscomp$6197$$.$team_id$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"initialize-workspace"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1927$team_id$$,""+($self__$jscomp$6197$$.$team_id$??
"")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,""+($self__$jscomp$6197$$.$file_id$??"")],null)],null)}),null,"app.main.data.workspace",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$take_until$$($stoper_s$jscomp$3$$,$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$merge$$($APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
"render-wasm/v1")?$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){var $event$jscomp$107$$=$app$util$globals$event$$("penpot:wasm:loaded");return $app$util$globals$dispatch_BANG_$$($event$jscomp$107$$)},$APP.$beicon$v2$core$filter$$($APP.$cljs$core$true_QMARK_$$,$APP.$beicon$v2$core$from$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$module$$))))):$APP.$beicon$v2$core$empty$$(),$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3494$app_DOT_main_DOT_data_DOT_fonts_SLASH_fonts_loaded$$),
$stream$jscomp$96$$))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$hide$$(),$APP.$app$main$data$comments$retrieve_comment_threads$$($self__$jscomp$6197$$.$file_id$),$app$main$data$comments$fetch_profiles$$(),$APP.$app$main$data$fonts$fetch_fonts$$($self__$jscomp$6197$$.$team_id$)),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1236$mcp$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$profile$fetch_access_tokens$$()):null),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$initialize_file$$($self__$jscomp$6197$$.$team_id$,
$self__$jscomp$6197$$.$file_id$))),$APP.$beicon$v2$core$mapcat$$(function($file$jscomp$79_map__71656__$1_p__71655$$){$file$jscomp$79_map__71656__$1_p__71655$$=$APP.$cljs$core$__destructure_map$$($file$jscomp$79_map__71656__$1_p__71655$$);$file$jscomp$79_map__71656__$1_p__71655$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$79_map__71656__$1_p__71655$$,$APP.$cljs$cst$208$file$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace",$APP.$cljs$cst$1160$debug$$)&&
$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"bundle fetched"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1927$team_id$$,""+($self__$jscomp$6197$$.$team_id$??"")],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,""+($self__$jscomp$6197$$.$file_id$??"")],null)],null)}),null,"app.main.data.workspace",$APP.$cljs$cst$1160$debug$$,!1);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$project$initialize_project$$($APP.$cljs$cst$2181$project_id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$79_map__71656__$1_p__71655$$)),$app$main$data$workspace$notifications$initialize$$($self__$jscomp$6197$$.$team_id$,$self__$jscomp$6197$$.$file_id$),
$app$main$data$workspace$shape_layout$initialize_shape_layout$$(),$app$main$data$workspace$fetch_libraries$$($self__$jscomp$6197$$.$file_id$,$features__$1$jscomp$23$$),$APP.$cljs$core$with_meta$$($app$main$data$workspace$workspace_initialized$$($self__$jscomp$6197$$.$file_id$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1927$team_id$$,$self__$jscomp$6197$$.$team_id$,$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$6197$$.$file_id$],null)))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,
$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4462$app_DOT_main_DOT_data_DOT_workspace_SLASH_bundle_fetched$$),$stream$jscomp$96$$)))),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1192$perf_logs$$)?$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $app$util$perf$setup$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4281$app_DOT_main_DOT_data_DOT_workspace_SLASH_workspace_initialized$$),
$stream$jscomp$96$$))):null,$APP.$beicon$v2$core$map$$($APP.$app$main$data$workspace$common$set_workspace_visited$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3163$app_DOT_main_DOT_data_DOT_persistence_SLASH_persistence_notification$$),$stream$jscomp$96$$))),function(){var $temp__5825__auto__$jscomp$223$$=function(){var $G__71659__$1$$=$rparams$$==null?null:$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($rparams$$);
return $G__71659__$1$$==null?null:$APP.$app$common$uuid$parse$$($G__71659__$1$$)}();return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$223$$)?$APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$workspace$libraries$go_to_local_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$,$temp__5825__auto__$jscomp$223$$,$cljs$cst$3940$update_layout_QMARK_$$,$APP.$cljs$cst$3938$update_layout$$.$cljs$core$IFn$_invoke$arity$1$($rparams$$)]))},
$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4281$app_DOT_main_DOT_data_DOT_workspace_SLASH_workspace_initialized$$),$stream$jscomp$96$$)))):null}(),$APP.$cljs$core$truth_$$($cljs$cst$3594$board_id$$.$cljs$core$IFn$_invoke$arity$1$($rparams$$))?$APP.$beicon$v2$core$map$$($app$main$data$workspace$zoom_to_frame$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4447$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_initialize_viewport$$),
$stream$jscomp$96$$))):null,function(){var $temp__5825__auto__$jscomp$224$$=function(){var $G__71660__$1$$=$rparams$$==null?null:$cljs$cst$4283$comment_id$$.$cljs$core$IFn$_invoke$arity$1$($rparams$$);return $G__71660__$1$$==null?null:$APP.$app$common$uuid$parse$$($G__71660__$1$$)}();return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$224$$)?$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$comments$navigate_to_comment_id$$($temp__5825__auto__$jscomp$224$$)},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,
$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4281$app_DOT_main_DOT_data_DOT_workspace_SLASH_workspace_initialized$$),$stream$jscomp$96$$)))):null}(),function(){var $local_commits_s$jscomp$1$$=$APP.$beicon$v2$core$filter$$($APP.$cljs$core$complement$$($APP.$cljs$core$empty_QMARK_$$),$APP.$beicon$v2$core$filter$$(function($p1__71646_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2883$local$$,$APP.$cljs$cst$193$source$$.$cljs$core$IFn$_invoke$arity$1$($p1__71646_SHARP_$$))&&
!$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$3142$tags$$.$cljs$core$IFn$_invoke$arity$1$($p1__71646_SHARP_$$),$APP.$cljs$cst$1891$position_data$$)},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($render_wasm_ready_QMARK_$$,$APP.$beicon$v2$core$filter$$($APP.$app$main$data$changes$commit_QMARK_$$,$stream$jscomp$96$$))))),$notifier_s$jscomp$3$$=$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$debounce$$(1E3,$local_commits_s$jscomp$1$$),$APP.$beicon$v2$core$filter$$($app$main$data$persistence$force_persist_QMARK_$$,
$stream$jscomp$96$$)),$objects_s$$=$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$refs$workspace_page_objects$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!0],null)),$current_page_id_s$$=$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$refs$current_page_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!0],null));return $APP.$beicon$v2$core$take_until$$($stoper_s$jscomp$3$$,
$APP.$beicon$v2$core$map$$(function($changes$jscomp$273_p__71665$$){var $text_position_data$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$273_p__71665$$,0,null),$page_id$jscomp$266$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$273_p__71665$$,1,null);$changes$jscomp$273_p__71665$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__71672_position_data$jscomp$15$$){var $id$jscomp$739$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71672_position_data$jscomp$15$$,
0,null);$p__71672_position_data$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71672_position_data$jscomp$15$$,1,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2612$mod_obj$$,$APP.$cljs$cst$266$id$$,$id$jscomp$739$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$266$$,$APP.$cljs$cst$2613$operations$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$1891$position_data$$,$APP.$cljs$cst$108$val$$,$p__71672_position_data$jscomp$15$$,$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2557$ignore_geometry$$,!0],null)],null)],null)},$text_position_data$$);return $APP.$app$common$data$not_empty_QMARK_$$($changes$jscomp$273_p__71665$$)?$APP.$app$main$data$changes$commit_changes$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3133$redo_changes$$,
$changes$jscomp$273_p__71665$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!1,$APP.$cljs$cst$3142$tags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1891$position_data$$,null],null),null)],null)):null},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($current_page_id_s$$,$APP.$beicon$v2$core$map$$(function($p__71676$$){var $commits$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71676$$,0,null),$objects$jscomp$657$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71676$$,1,null);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71649_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__71649_SHARP_$$),$APP.$app$render_wasm$api$calculate_position_data$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$657$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__71649_SHARP_$$)))],null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71648_SHARP_$$){return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$657$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__71648_SHARP_$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71647_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2612$mod_obj$$,null,$APP.$cljs$cst$2610$add_obj$$,null],null),null),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__71647_SHARP_$$))},$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$commits$jscomp$1$$])))))},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($objects_s$$,$APP.$beicon$v2$core$buffer_until$$($notifier_s$jscomp$3$$,
$local_commits_s$jscomp$1$$))))))}(),$APP.$beicon$v2$core$mapcat$$(function($p__71684_save_undo_QMARK_$jscomp$12$$){var $map__71685__$1_selected_before$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($p__71684_save_undo_QMARK_$jscomp$12$$);$p__71684_save_undo_QMARK_$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71685__$1_selected_before$jscomp$3$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$);var $undo_changes$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71685__$1_selected_before$jscomp$3$$,
$APP.$cljs$cst$3137$undo_changes$$),$redo_changes$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71685__$1_selected_before$jscomp$3$$,$APP.$cljs$cst$3133$redo_changes$$),$undo_group$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71685__$1_selected_before$jscomp$3$$,$APP.$cljs$cst$3138$undo_group$$),$tags$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71685__$1_selected_before$jscomp$3$$,$APP.$cljs$cst$3142$tags$$),$stack_undo_QMARK_$jscomp$9$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71685__$1_selected_before$jscomp$3$$,$APP.$cljs$cst$3141$stack_undo_QMARK_$$);$map__71685__$1_selected_before$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71685__$1_selected_before$jscomp$3$$,$cljs$cst$3144$selected_before$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($p__71684_save_undo_QMARK_$jscomp$12$$)?$APP.$cljs$core$seq$$($undo_changes$jscomp$9$$):$p__71684_save_undo_QMARK_$jscomp$12$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$undo$append_undo$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$3137$undo_changes$$,$undo_changes$jscomp$9$$,$APP.$cljs$cst$3133$redo_changes$$,$redo_changes$jscomp$13$$,$APP.$cljs$cst$3138$undo_group$$,$undo_group$jscomp$40$$,$APP.$cljs$cst$3142$tags$$,$tags$jscomp$11$$,$cljs$cst$3144$selected_before$$,$map__71685__$1_selected_before$jscomp$3$$],null),$stack_undo_QMARK_$jscomp$9$$)):$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$app$main$data$changes$commit_QMARK_$$,$stream$jscomp$96$$))))),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$mcp$notify_other_tabs_disconnect$$()))},$app$main$data$workspace$initialize_workspace_71650$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$initialize_workspace_71650$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $APP.$app$util$globals$global$$.name="workspace-"+(this.$file_id$??"")});return new $app$main$data$workspace$initialize_workspace_71650$$($team_id$jscomp$84$$,
$file_id$jscomp$269$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$reload_current_file$$=function(){typeof $app$main$data$workspace$reload_current_file_71695$$==="undefined"&&($app$main$data$workspace$reload_current_file_71695$$=function($meta71696$$){this.$meta71696$=$meta71696$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$reload_current_file_71695$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$reload_current_file_71695$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3370$app_DOT_main_DOT_data_DOT_workspace_SLASH_reload_current_file$$},$app$main$data$workspace$reload_current_file_71695$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71697$$,$meta71696__$1$$){return new $app$main$data$workspace$reload_current_file_71695$$($meta71696__$1$$)},$app$main$data$workspace$reload_current_file_71695$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71696$},$app$main$data$workspace$reload_current_file_71695$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$reload_current_file_71695$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2538_file_id$jscomp$273$$,$state$jscomp$883_team_id$jscomp$86$$){$_$jscomp$2538_file_id$jscomp$273$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$883_team_id$jscomp$86$$);$state$jscomp$883_team_id$jscomp$86$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$883_team_id$jscomp$86$$);
return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$initialize_workspace$$($state$jscomp$883_team_id$jscomp$86$$,$_$jscomp$2538_file_id$jscomp$273$$))});return new $app$main$data$workspace$reload_current_file_71695$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$update_shape$$=function($id$jscomp$742$$,$attrs$jscomp$153_attrs__$1$jscomp$24$$){$attrs$jscomp$153_attrs__$1$jscomp$24$$=$app$common$types$shape$check_shape_generic_attrs$$($attrs$jscomp$153_attrs__$1$jscomp$24$$);typeof $app$main$data$workspace$update_shape_71731$$==="undefined"&&($app$main$data$workspace$update_shape_71731$$=function($id$jscomp$743$$,$attrs$jscomp$154$$,$meta71732$$){this.id=$id$jscomp$743$$;this.$attrs$=$attrs$jscomp$154$$;this.$meta71732$=$meta71732$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$update_shape_71731$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_shape_71731$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4474$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_shape$$},$app$main$data$workspace$update_shape_71731$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71733$$,
$meta71732__$1$$){return new $app$main$data$workspace$update_shape_71731$$(this.id,this.$attrs$,$meta71732__$1$$)},$app$main$data$workspace$update_shape_71731$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71732$},$app$main$data$workspace$update_shape_71731$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_shape_71731$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6227$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6227$$.id],null),function($p1__71730_SHARP_$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71730_SHARP_$$,$self__$jscomp$6227$$.$attrs$]))}))});return new $app$main$data$workspace$update_shape_71731$$($id$jscomp$742$$,$attrs$jscomp$153_attrs__$1$jscomp$24$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$start_rename_shape$$=function($id$jscomp$744$$){typeof $app$main$data$workspace$start_rename_shape_71734$$==="undefined"&&($app$main$data$workspace$start_rename_shape_71734$$=function($id$jscomp$745$$,$meta71735$$){this.id=$id$jscomp$745$$;this.$meta71735$=$meta71735$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$start_rename_shape_71734$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$start_rename_shape_71734$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4475$app_DOT_main_DOT_data_DOT_workspace_SLASH_start_rename_shape$$},$app$main$data$workspace$start_rename_shape_71734$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71736$$,$meta71735__$1$$){return new $app$main$data$workspace$start_rename_shape_71734$$(this.id,$meta71735__$1$$)},$app$main$data$workspace$start_rename_shape_71734$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71735$},$app$main$data$workspace$start_rename_shape_71734$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$start_rename_shape_71734$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2548$$,$state$jscomp$888$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$888$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,
$APP.$cljs$cst$4423$shape_for_rename$$],null),this.id)});return new $app$main$data$workspace$start_rename_shape_71734$$($id$jscomp$744$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$end_rename_shape$cljs$0core$0IFn$0_invoke$0arity$02$$=function($shape_id$jscomp$126$$,$name$jscomp$357$$){typeof $app$main$data$workspace$end_rename_shape_71742$$==="undefined"&&($app$main$data$workspace$end_rename_shape_71742$$=function($shape_id$jscomp$127$$,$name$jscomp$358$$,$meta71743$$){this.$shape_id$=$shape_id$jscomp$127$$;this.name=$name$jscomp$358$$;this.$meta71743$=$meta71743$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$end_rename_shape_71742$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$end_rename_shape_71742$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4476$app_DOT_main_DOT_data_DOT_workspace_SLASH_end_rename_shape$$},$app$main$data$workspace$end_rename_shape_71742$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71744$$,$meta71743__$1$$){return new $app$main$data$workspace$end_rename_shape_71742$$(this.$shape_id$,
this.name,$meta71743__$1$$)},$app$main$data$workspace$end_rename_shape_71742$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71743$},$app$main$data$workspace$end_rename_shape_71742$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$end_rename_shape_71742$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2549$$,$state$jscomp$889$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$889$$,
$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4423$shape_for_rename$$)},$app$main$data$workspace$end_rename_shape_71742$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$end_rename_shape_71742$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2550_temp__5825__auto__$jscomp$225$$,$shape$jscomp$752_state$jscomp$890$$){$_$jscomp$2550_temp__5825__auto__$jscomp$225$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$(this.$shape_id$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$752_state$jscomp$890$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$4423$shape_for_rename$$));if($APP.$cljs$core$truth_$$($_$jscomp$2550_temp__5825__auto__$jscomp$225$$)){$shape$jscomp$752_state$jscomp$890$$=$APP.$app$main$data$helpers$lookup_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$752_state$jscomp$890$$,$_$jscomp$2550_temp__5825__auto__$jscomp$225$$);
var $name__$1$jscomp$13_valid_QMARK_$jscomp$8$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(this.name),$clean_name$jscomp$2$$=$APP.$app$common$path_names$join_path$$($APP.$app$common$path_names$split_path$$($name__$1$jscomp$13_valid_QMARK_$jscomp$8$$));$name__$1$jscomp$13_valid_QMARK_$jscomp$8$$=!$APP.$cuerdas$core$ends_with_QMARK_$$($name__$1$jscomp$13_valid_QMARK_$jscomp$8$$,"/")&&typeof $clean_name$jscomp$2$$==="string"&&!$APP.$cuerdas$core$blank_QMARK_$$($clean_name$jscomp$2$$);
var $component_id$jscomp$84$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$752_state$jscomp$890$$),$undo_id$jscomp$80$$=Symbol();return $name__$1$jscomp$13_valid_QMARK_$jscomp$8$$?$APP.$cljs$core$truth_$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$752_state$jscomp$890$$))?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$variants$rename_variant$$($_$jscomp$2550_temp__5825__auto__$jscomp$225$$,$clean_name$jscomp$2$$)):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$80$$),
$app$main$data$workspace$update_shape$$($_$jscomp$2550_temp__5825__auto__$jscomp$225$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$clean_name$jscomp$2$$],null)),$component_id$jscomp$84$$!=null&&$APP.$app$common$types$component$main_instance_QMARK_$$($shape$jscomp$752_state$jscomp$890$$)?$APP.$app$main$data$workspace$libraries$rename_component$$($component_id$jscomp$84$$,$clean_name$jscomp$2$$):null,$APP.$app$main$data$workspace$highlight$dehighlight_shape$$($_$jscomp$2550_temp__5825__auto__$jscomp$225$$),
$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$80$$)):null}return null});return new $app$main$data$workspace$end_rename_shape_71742$$($shape_id$jscomp$126$$,$name$jscomp$357$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$rename_shape_or_variant$cljs$0core$0IFn$0_invoke$0arity$04$$=function($file_id$jscomp$275$$,$page_id$jscomp$267$$,$id$jscomp$747$$,$name$jscomp$360$$){typeof $app$main$data$workspace$rename_shape_or_variant_71747$$==="undefined"&&($app$main$data$workspace$rename_shape_or_variant_71747$$=function($file_id$jscomp$276$$,$page_id$jscomp$268$$,$id$jscomp$748$$,$name$jscomp$361$$,$meta71748$$){this.$file_id$=$file_id$jscomp$276$$;this.$page_id$=$page_id$jscomp$268$$;this.id=
$id$jscomp$748$$;this.name=$name$jscomp$361$$;this.$meta71748$=$meta71748$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$rename_shape_or_variant_71747$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$rename_shape_or_variant_71747$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4477$app_DOT_main_DOT_data_DOT_workspace_SLASH_rename_shape_or_variant$$},
$app$main$data$workspace$rename_shape_or_variant_71747$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71749$$,$meta71748__$1$$){return new $app$main$data$workspace$rename_shape_or_variant_71747$$(this.$file_id$,this.$page_id$,this.id,this.name,$meta71748__$1$$)},$app$main$data$workspace$rename_shape_or_variant_71747$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71748$},$app$main$data$workspace$rename_shape_or_variant_71747$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$rename_shape_or_variant_71747$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2551_component$jscomp$92_file_data$jscomp$74_variant_properties$jscomp$3$$,$state$jscomp$891_variant_id$jscomp$42$$){var $file_id__$1$jscomp$6_is_variant_QMARK_$jscomp$1_variant_name$jscomp$2$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$(this.$file_id$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$891_variant_id$jscomp$42$$)),
$component_id$jscomp$85_page_id__$1$jscomp$15$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$(this.$page_id$,$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$891_variant_id$jscomp$42$$));$_$jscomp$2551_component$jscomp$92_file_data$jscomp$74_variant_properties$jscomp$3$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$891_variant_id$jscomp$42$$,$file_id__$1$jscomp$6_is_variant_QMARK_$jscomp$1_variant_name$jscomp$2$$);
var $shape$jscomp$753$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$891_variant_id$jscomp$42$$,$file_id__$1$jscomp$6_is_variant_QMARK_$jscomp$1_variant_name$jscomp$2$$,$component_id$jscomp$85_page_id__$1$jscomp$15$$),this.id);$state$jscomp$891_variant_id$jscomp$42$$=($file_id__$1$jscomp$6_is_variant_QMARK_$jscomp$1_variant_name$jscomp$2$$=$APP.$app$common$types$component$is_variant_QMARK_$$($shape$jscomp$753$$))?
$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$753$$):null;$file_id__$1$jscomp$6_is_variant_QMARK_$jscomp$1_variant_name$jscomp$2$$=$file_id__$1$jscomp$6_is_variant_QMARK_$jscomp$1_variant_name$jscomp$2$$?$APP.$cljs$cst$2002$variant_name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$753$$):null;$component_id$jscomp$85_page_id__$1$jscomp$15$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$753$$);$_$jscomp$2551_component$jscomp$92_file_data$jscomp$74_variant_properties$jscomp$3$$=
$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2551_component$jscomp$92_file_data$jscomp$74_variant_properties$jscomp$3$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$753$$));$_$jscomp$2551_component$jscomp$92_file_data$jscomp$74_variant_properties$jscomp$3$$=$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2551_component$jscomp$92_file_data$jscomp$74_variant_properties$jscomp$3$$);
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($file_id__$1$jscomp$6_is_variant_QMARK_$jscomp$1_variant_name$jscomp$2$$)?$app$common$types$variant$valid_properties_formula_QMARK_$$(this.name):$file_id__$1$jscomp$6_is_variant_QMARK_$jscomp$1_variant_name$jscomp$2$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$variants$update_properties_names_and_values$$($component_id$jscomp$85_page_id__$1$jscomp$15$$,$state$jscomp$891_variant_id$jscomp$42$$,$_$jscomp$2551_component$jscomp$92_file_data$jscomp$74_variant_properties$jscomp$3$$,
$app$common$types$variant$properties_formula__GT_map$$(this.name)),$app$main$data$workspace$variants$remove_empty_properties$$($state$jscomp$891_variant_id$jscomp$42$$),$APP.$app$main$data$workspace$variants$update_error$cljs$0core$0IFn$0_invoke$0arity$02$$($component_id$jscomp$85_page_id__$1$jscomp$15$$,null)):$APP.$cljs$core$truth_$$($file_id__$1$jscomp$6_is_variant_QMARK_$jscomp$1_variant_name$jscomp$2$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$variants$update_properties_names_and_values$$($component_id$jscomp$85_page_id__$1$jscomp$15$$,
$state$jscomp$891_variant_id$jscomp$42$$,$_$jscomp$2551_component$jscomp$92_file_data$jscomp$74_variant_properties$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),$app$main$data$workspace$variants$remove_empty_properties$$($state$jscomp$891_variant_id$jscomp$42$$),$APP.$app$main$data$workspace$variants$update_error$cljs$0core$0IFn$0_invoke$0arity$02$$($component_id$jscomp$85_page_id__$1$jscomp$15$$,this.name)):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$end_rename_shape$cljs$0core$0IFn$0_invoke$0arity$02$$(this.id,
this.name))});return new $app$main$data$workspace$rename_shape_or_variant_71747$$($file_id$jscomp$275$$,$page_id$jscomp$267$$,$id$jscomp$747$$,$name$jscomp$360$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$delete_selected$$=function(){typeof $app$main$data$workspace$delete_selected_71754$$==="undefined"&&($app$main$data$workspace$delete_selected_71754$$=function($meta71755$$){this.$meta71755$=$meta71755$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$delete_selected_71754$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$delete_selected_71754$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4479$app_DOT_main_DOT_data_DOT_workspace_SLASH_delete_selected$$},$app$main$data$workspace$delete_selected_71754$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71756$$,$meta71755__$1$$){return new $app$main$data$workspace$delete_selected_71754$$($meta71755__$1$$)},$app$main$data$workspace$delete_selected_71754$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71755$},$app$main$data$workspace$delete_selected_71754$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$delete_selected_71754$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2553_selected$jscomp$97$$,$hover_guides_state$jscomp$893$$){$_$jscomp$2553_selected$jscomp$97$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($hover_guides_state$jscomp$893$$);$hover_guides_state$jscomp$893$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($hover_guides_state$jscomp$893$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4289$workspace_guides$$,$APP.$cljs$cst$2204$hover$$],null));return $APP.$app$common$data$not_empty_QMARK_$$($_$jscomp$2553_selected$jscomp$97$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$01$$($_$jscomp$2553_selected$jscomp$97$$),$APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$00$$()):$APP.$app$common$data$not_empty_QMARK_$$($hover_guides_state$jscomp$893$$)?
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$guides$remove_guides$$($hover_guides_state$jscomp$893$$)):null});return new $app$main$data$workspace$delete_selected_71754$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$start_rename_selected$$=function(){typeof $app$main$data$workspace$start_rename_selected_71775$$==="undefined"&&($app$main$data$workspace$start_rename_selected_71775$$=function($meta71776$$){this.$meta71776$=$meta71776$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$start_rename_selected_71775$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$start_rename_selected_71775$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4480$app_DOT_main_DOT_data_DOT_workspace_SLASH_start_rename_selected$$},$app$main$data$workspace$start_rename_selected_71775$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71777$$,$meta71776__$1$$){return new $app$main$data$workspace$start_rename_selected_71775$$($meta71776__$1$$)},$app$main$data$workspace$start_rename_selected_71775$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71776$},$app$main$data$workspace$start_rename_selected_71775$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$start_rename_selected_71775$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2554_selected$jscomp$98$$,$id$jscomp$749_state$jscomp$894$$){$_$jscomp$2554_selected$jscomp$98$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($id$jscomp$749_state$jscomp$894$$);$id$jscomp$749_state$jscomp$894$$=$APP.$cljs$core$first$$($_$jscomp$2554_selected$jscomp$98$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($_$jscomp$2554_selected$jscomp$98$$),
1)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1615$layout$$,$APP.$cljs$cst$3727$layers$$])),$APP.$app$main$data$workspace$start_rename_shape$$($id$jscomp$749_state$jscomp$894$$)):null});return new $app$main$data$workspace$start_rename_selected_71775$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$vertical_order_selected$$=function($loc$jscomp$6$$){typeof $app$main$data$workspace$vertical_order_selected_71778$$==="undefined"&&($app$main$data$workspace$vertical_order_selected_71778$$=function($loc$jscomp$7$$,$meta71779$$){this.$loc$=$loc$jscomp$7$$;this.$meta71779$=$meta71779$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$vertical_order_selected_71778$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$vertical_order_selected_71778$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4481$app_DOT_main_DOT_data_DOT_workspace_SLASH_vertical_order_selected$$},$app$main$data$workspace$vertical_order_selected_71778$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71780$$,$meta71779__$1$$){return new $app$main$data$workspace$vertical_order_selected_71778$$(this.$loc$,$meta71779__$1$$)},$app$main$data$workspace$vertical_order_selected_71778$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71779$},$app$main$data$workspace$vertical_order_selected_71778$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$vertical_order_selected_71778$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$274_it$jscomp$244_page_id$jscomp$269$$,$state$jscomp$895_undo_id$jscomp$81$$){var $self__$jscomp$6256$$=this;$changes$jscomp$274_it$jscomp$244_page_id$jscomp$269$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$895_undo_id$jscomp$81$$);
var $objects$jscomp$658$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$895_undo_id$jscomp$81$$,$changes$jscomp$274_it$jscomp$244_page_id$jscomp$269$$),$selected_ids$jscomp$5$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$895_undo_id$jscomp$81$$),$selected_shapes$jscomp$7$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$658$$),$selected_ids$jscomp$5$$);
$state$jscomp$895_undo_id$jscomp$81$$=Symbol();$changes$jscomp$274_it$jscomp$244_page_id$jscomp$269$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes$jscomp$275$$,$shape$jscomp$754$$){var $parent$jscomp$282$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$658$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$754$$)),$sibling_ids$jscomp$2$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$282$$),
$current_index$jscomp$3$$=$APP.$app$common$data$index_of$$($sibling_ids$jscomp$2$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$754$$)),$index_in_selection$$=$APP.$app$common$data$index_of$$($selected_ids$jscomp$5$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$754$$)),$new_index$jscomp$3$$=function(){var $G__71781_G__71781__$1_x__5113__auto__$jscomp$65_y__5111__auto__$jscomp$124$$=$self__$jscomp$6256$$.$loc$;$G__71781_G__71781__$1_x__5113__auto__$jscomp$65_y__5111__auto__$jscomp$124$$=
$G__71781_G__71781__$1_x__5113__auto__$jscomp$65_y__5111__auto__$jscomp$124$$ instanceof $APP.$cljs$core$Keyword$$?$G__71781_G__71781__$1_x__5113__auto__$jscomp$65_y__5111__auto__$jscomp$124$$.$fqn$:null;switch($G__71781_G__71781__$1_x__5113__auto__$jscomp$65_y__5111__auto__$jscomp$124$$){case "top":return $APP.$cljs$core$count$$($sibling_ids$jscomp$2$$);case "down":return $G__71781_G__71781__$1_x__5113__auto__$jscomp$65_y__5111__auto__$jscomp$124$$=$current_index$jscomp$3$$-1,0>$G__71781_G__71781__$1_x__5113__auto__$jscomp$65_y__5111__auto__$jscomp$124$$?
0:$G__71781_G__71781__$1_x__5113__auto__$jscomp$65_y__5111__auto__$jscomp$124$$;case "up":$G__71781_G__71781__$1_x__5113__auto__$jscomp$65_y__5111__auto__$jscomp$124$$=$APP.$cljs$core$count$$($sibling_ids$jscomp$2$$);var $y__5114__auto__$jscomp$65$$=$current_index$jscomp$3$$+1+1;return $G__71781_G__71781__$1_x__5113__auto__$jscomp$65_y__5111__auto__$jscomp$124$$<$y__5114__auto__$jscomp$65$$?$G__71781_G__71781__$1_x__5113__auto__$jscomp$65_y__5111__auto__$jscomp$124$$:$y__5114__auto__$jscomp$65$$;
case "bottom":return $index_in_selection$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__71781_G__71781__$1_x__5113__auto__$jscomp$65_y__5111__auto__$jscomp$124$$)].join(""));}}();return $APP.$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$275$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$282$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape$jscomp$754$$],null),$new_index$jscomp$3$$)},$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$changes$jscomp$274_it$jscomp$244_page_id$jscomp$269$$),$objects$jscomp$658$$),$selected_shapes$jscomp$7$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($state$jscomp$895_undo_id$jscomp$81$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$274_it$jscomp$244_page_id$jscomp$269$$),
$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$selected_ids$jscomp$5$$],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($state$jscomp$895_undo_id$jscomp$81$$))});return new $app$main$data$workspace$vertical_order_selected_71778$$($loc$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$relocate_selected_shapes$$=function($parent_id$jscomp$97$$,$to_index$jscomp$13$$){typeof $app$main$data$workspace$relocate_selected_shapes_71791$$==="undefined"&&($app$main$data$workspace$relocate_selected_shapes_71791$$=function($parent_id$jscomp$98$$,$to_index$jscomp$14$$,$meta71792$$){this.$parent_id$=$parent_id$jscomp$98$$;this.$to_index$=$to_index$jscomp$14$$;this.$meta71792$=$meta71792$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$relocate_selected_shapes_71791$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$relocate_selected_shapes_71791$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4484$app_DOT_main_DOT_data_DOT_workspace_SLASH_relocate_selected_shapes$$},$app$main$data$workspace$relocate_selected_shapes_71791$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71793$$,$meta71792__$1$$){return new $app$main$data$workspace$relocate_selected_shapes_71791$$(this.$parent_id$,
this.$to_index$,$meta71792__$1$$)},$app$main$data$workspace$relocate_selected_shapes_71791$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71792$},$app$main$data$workspace$relocate_selected_shapes_71791$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$relocate_selected_shapes_71791$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2558_selected$jscomp$99$$,$state$jscomp$898$$){$_$jscomp$2558_selected$jscomp$99$$=
$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$898$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$relocate_shapes$$($_$jscomp$2558_selected$jscomp$99$$,this.$parent_id$,this.$to_index$))});return new $app$main$data$workspace$relocate_selected_shapes_71791$$($parent_id$jscomp$97$$,$to_index$jscomp$13$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$start_editing_selected$$=function(){typeof $app$main$data$workspace$start_editing_selected_71798$$==="undefined"&&($app$main$data$workspace$start_editing_selected_71798$$=function($meta71799$$){this.$meta71799$=$meta71799$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$start_editing_selected_71798$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$start_editing_selected_71798$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4485$app_DOT_main_DOT_data_DOT_workspace_SLASH_start_editing_selected$$},$app$main$data$workspace$start_editing_selected_71798$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71800$$,$meta71799__$1$$){return new $app$main$data$workspace$start_editing_selected_71798$$($meta71799__$1$$)},$app$main$data$workspace$start_editing_selected_71798$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71799$},$app$main$data$workspace$start_editing_selected_71798$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$start_editing_selected_71798$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2559_id$jscomp$752_selected$jscomp$100$$,$expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$){$_$jscomp$2559_id$jscomp$752_selected$jscomp$100$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$);
var $objects$jscomp$661$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$);$expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$=$APP.$cljs$core$count$$($_$jscomp$2559_id$jscomp$752_selected$jscomp$100$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,
$expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$):$APP.$cljs$core$_EQ_$$(0,$expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$)))return $APP.$beicon$v2$core$empty$$();if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$):$APP.$cljs$core$_EQ_$$(1,
$expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$))){$expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$661$$,$APP.$cljs$core$first$$($_$jscomp$2559_id$jscomp$752_selected$jscomp$100$$));$expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$=$APP.$cljs$core$__destructure_map$$($expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$);
$_$jscomp$2559_id$jscomp$752_selected$jscomp$100$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$,$APP.$cljs$cst$266$id$$);var $G__71807$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$,$APP.$cljs$cst$139$type$$);switch($G__71807$$ instanceof $APP.$cljs$core$Keyword$$?$G__71807$$.$fqn$:null){case "text":return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$edition$start_edition_mode$$($_$jscomp$2559_id$jscomp$752_selected$jscomp$100$$));
case "group":case "bool":case "frame":return $expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$,$APP.$cljs$cst$1614$shapes$$)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$select_shapes$$($expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$));
case "svg-raw":return null;default:return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$edition$start_edition_mode$$($_$jscomp$2559_id$jscomp$752_selected$jscomp$100$$),$app$main$data$workspace$path$edition$start_path_edit$$($_$jscomp$2559_id$jscomp$752_selected$jscomp$100$$))}}else return $expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$315$$,$shape_id$jscomp$128$$){var $children$jscomp$254$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$661$$,$shape_id$jscomp$128$$),$APP.$cljs$cst$1614$shapes$$);return $APP.$cljs$core$empty_QMARK_$$($children$jscomp$254$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$315$$,$shape_id$jscomp$128$$):$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$315$$,$children$jscomp$254$$)},$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),
$_$jscomp$2559_id$jscomp$752_selected$jscomp$100$$),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$select_shapes$$($expr__71804_map__71806_map__71806__$1_shapes_ids$jscomp$2_shapes_to_select_state$jscomp$899$$))});return new $app$main$data$workspace$start_editing_selected_71798$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$select_parent_layer$$=function(){typeof $app$main$data$workspace$select_parent_layer_71817$$==="undefined"&&($app$main$data$workspace$select_parent_layer_71817$$=function($meta71818$$){this.$meta71818$=$meta71818$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$select_parent_layer_71817$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$select_parent_layer_71817$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4486$app_DOT_main_DOT_data_DOT_workspace_SLASH_select_parent_layer$$},$app$main$data$workspace$select_parent_layer_71817$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71819$$,$meta71818__$1$$){return new $app$main$data$workspace$select_parent_layer_71817$$($meta71818__$1$$)},$app$main$data$workspace$select_parent_layer_71817$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71818$},$app$main$data$workspace$select_parent_layer_71817$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$select_parent_layer_71817$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2560_selected$jscomp$101$$,$shapes_to_select$jscomp$1_state$jscomp$900$$){$_$jscomp$2560_selected$jscomp$101$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($shapes_to_select$jscomp$1_state$jscomp$900$$);var $objects$jscomp$662$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($shapes_to_select$jscomp$1_state$jscomp$900$$);
$shapes_to_select$jscomp$1_state$jscomp$900$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$316$$,$shape_id$jscomp$129$$){var $parent_id$jscomp$99$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$662$$,$shape_id$jscomp$129$$),$APP.$cljs$cst$1619$parent_id$$);return $parent_id$jscomp$99$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parent_id$jscomp$99$$,$APP.$app$common$uuid$zero$$)?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$316$$,$parent_id$jscomp$99$$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$316$$,$shape_id$jscomp$129$$)},$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$_$jscomp$2560_selected$jscomp$101$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$select_shapes$$($shapes_to_select$jscomp$1_state$jscomp$900$$))});return new $app$main$data$workspace$select_parent_layer_71817$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$can_align_QMARK_$$=function($selected$jscomp$102$$,$objects$jscomp$663$$){return $APP.$cljs$core$empty_QMARK_$$($selected$jscomp$102$$)?!1:$APP.$cljs$core$count$$($selected$jscomp$102$$)>1?!0:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$663$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected$jscomp$102$$)))))};
$app$main$data$workspace$align_objects_list$$=function($objects$jscomp$665$$,$selected$jscomp$103_selected_objs$jscomp$2$$,$axis$jscomp$30$$){$selected$jscomp$103_selected_objs$jscomp$2$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71825_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$665$$,$p1__71825_SHARP_$$)},$selected$jscomp$103_selected_objs$jscomp$2$$);var $rect$jscomp$44$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($selected$jscomp$103_selected_objs$jscomp$2$$);
return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71826_SHARP_$$){var $delta$jscomp$inline_7238_wrapper_rect$jscomp$inline_7236$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__71826_SHARP_$$],null)),$align_pos$jscomp$inline_7237$$=$app$common$geom$align$calc_align_pos$$.$cljs$core$IFn$_invoke$arity$3$?$app$common$geom$align$calc_align_pos$$.$cljs$core$IFn$_invoke$arity$3$($delta$jscomp$inline_7238_wrapper_rect$jscomp$inline_7236$$,
$rect$jscomp$44$$,$axis$jscomp$30$$):$app$common$geom$align$calc_align_pos$$($delta$jscomp$inline_7238_wrapper_rect$jscomp$inline_7236$$,$rect$jscomp$44$$,$axis$jscomp$30$$);$delta$jscomp$inline_7238_wrapper_rect$jscomp$inline_7236$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($align_pos$jscomp$inline_7237$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$inline_7238_wrapper_rect$jscomp$inline_7236$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($align_pos$jscomp$inline_7237$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$inline_7238_wrapper_rect$jscomp$inline_7236$$));return $app$common$geom$shapes$transforms$move$$($p1__71826_SHARP_$$,$delta$jscomp$inline_7238_wrapper_rect$jscomp$inline_7236$$)},$selected$jscomp$103_selected_objs$jscomp$2$$)};
$APP.$app$main$data$workspace$align_objects$cljs$0core$0IFn$0_invoke$0arity$02$$=function($axis$jscomp$32$$,$selected$jscomp$104$$){typeof $app$main$data$workspace$align_objects_71829$$==="undefined"&&($app$main$data$workspace$align_objects_71829$$=function($axis$jscomp$33$$,$selected$jscomp$105$$,$meta71830$$){this.axis=$axis$jscomp$33$$;this.selected=$selected$jscomp$105$$;this.$meta71830$=$meta71830$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$align_objects_71829$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$align_objects_71829$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4488$app_DOT_main_DOT_data_DOT_workspace_SLASH_align_objects$$},$app$main$data$workspace$align_objects_71829$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71831$$,$meta71830__$1$$){return new $app$main$data$workspace$align_objects_71829$$(this.axis,
this.selected,$meta71830__$1$$)},$app$main$data$workspace$align_objects_71829$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71830$},$app$main$data$workspace$align_objects_71829$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$align_objects_71829$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2562_objects$jscomp$666$$,$selected__$1$jscomp$10_state$jscomp$902$$){$_$jscomp$2562_objects$jscomp$666$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$10_state$jscomp$902$$);var $JSCompiler_temp$jscomp$10899_axis$jscomp$inline_12862_moved$jscomp$4_or__5025__auto__$jscomp$inline_7240$$=this.selected;$selected__$1$jscomp$10_state$jscomp$902$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10899_axis$jscomp$inline_12862_moved$jscomp$4_or__5025__auto__$jscomp$inline_7240$$)?$JSCompiler_temp$jscomp$10899_axis$jscomp$inline_12862_moved$jscomp$4_or__5025__auto__$jscomp$inline_7240$$:
$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($selected__$1$jscomp$10_state$jscomp$902$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($selected__$1$jscomp$10_state$jscomp$902$$))){var $object_id$jscomp$inline_12861_parent$jscomp$inline_12865_parent_id$jscomp$inline_12864$$=$APP.$cljs$core$first$$($selected__$1$jscomp$10_state$jscomp$902$$);$JSCompiler_temp$jscomp$10899_axis$jscomp$inline_12862_moved$jscomp$4_or__5025__auto__$jscomp$inline_7240$$=
this.axis;var $object$jscomp$inline_12863_undo_id$jscomp$84$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2562_objects$jscomp$666$$,$object_id$jscomp$inline_12861_parent$jscomp$inline_12865_parent_id$jscomp$inline_12864$$);$object_id$jscomp$inline_12861_parent$jscomp$inline_12865_parent_id$jscomp$inline_12864$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2562_objects$jscomp$666$$,$object_id$jscomp$inline_12861_parent$jscomp$inline_12865_parent_id$jscomp$inline_12864$$));
$object_id$jscomp$inline_12861_parent$jscomp$inline_12865_parent_id$jscomp$inline_12864$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2562_objects$jscomp$666$$,$object_id$jscomp$inline_12861_parent$jscomp$inline_12865_parent_id$jscomp$inline_12864$$);$JSCompiler_temp$jscomp$10899_axis$jscomp$inline_12862_moved$jscomp$4_or__5025__auto__$jscomp$inline_7240$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$geom$align$align_to_parent$$($object$jscomp$inline_12863_undo_id$jscomp$84$$,
$object_id$jscomp$inline_12861_parent$jscomp$inline_12865_parent_id$jscomp$inline_12864$$,$JSCompiler_temp$jscomp$10899_axis$jscomp$inline_12862_moved$jscomp$4_or__5025__auto__$jscomp$inline_7240$$)],null)}else $JSCompiler_temp$jscomp$10899_axis$jscomp$inline_12862_moved$jscomp$4_or__5025__auto__$jscomp$inline_7240$$=$app$main$data$workspace$align_objects_list$$($_$jscomp$2562_objects$jscomp$666$$,$selected__$1$jscomp$10_state$jscomp$902$$,this.axis);$object$jscomp$inline_12863_undo_id$jscomp$84$$=
Symbol();return $APP.$app$main$data$workspace$can_align_QMARK_$$($selected__$1$jscomp$10_state$jscomp$902$$,$_$jscomp$2562_objects$jscomp$666$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($object$jscomp$inline_12863_undo_id$jscomp$84$$),$app$main$data$workspace$transforms$position_shapes$$($JSCompiler_temp$jscomp$10899_axis$jscomp$inline_12862_moved$jscomp$4_or__5025__auto__$jscomp$inline_7240$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$selected__$1$jscomp$10_state$jscomp$902$$],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($object$jscomp$inline_12863_undo_id$jscomp$84$$)):null});return new $app$main$data$workspace$align_objects_71829$$($axis$jscomp$32$$,$selected$jscomp$104$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$can_distribute_QMARK_$$=function($selected$jscomp$106$$){return $APP.$cljs$core$empty_QMARK_$$($selected$jscomp$106$$)?!1:$APP.$cljs$core$count$$($selected$jscomp$106$$)<3?!1:!0};
$APP.$app$main$data$workspace$distribute_objects$cljs$0core$0IFn$0_invoke$0arity$02$$=function($axis$jscomp$35$$,$ids$jscomp$249$$){typeof $app$main$data$workspace$distribute_objects_71839$$==="undefined"&&($app$main$data$workspace$distribute_objects_71839$$=function($axis$jscomp$36$$,$ids$jscomp$250$$,$meta71840$$){this.axis=$axis$jscomp$36$$;this.ids=$ids$jscomp$250$$;this.$meta71840$=$meta71840$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$distribute_objects_71839$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$distribute_objects_71839$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4489$app_DOT_main_DOT_data_DOT_workspace_SLASH_distribute_objects$$},$app$main$data$workspace$distribute_objects_71839$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71841$$,$meta71840__$1$$){return new $app$main$data$workspace$distribute_objects_71839$$(this.axis,this.ids,$meta71840__$1$$)},$app$main$data$workspace$distribute_objects_71839$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71840$},$app$main$data$workspace$distribute_objects_71839$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$distribute_objects_71839$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2563_page_id$jscomp$274_selected$jscomp$107$$,$state$jscomp$903$$){var $self__$jscomp$6288$$=this;$_$jscomp$2563_page_id$jscomp$274_selected$jscomp$107$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$903$$);
var $objects$jscomp$667$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$903$$,$_$jscomp$2563_page_id$jscomp$274_selected$jscomp$107$$);$_$jscomp$2563_page_id$jscomp$274_selected$jscomp$107$$=function(){var $or__5025__auto__$jscomp$856$$=$self__$jscomp$6288$$.ids;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$856$$)?$or__5025__auto__$jscomp$856$$:$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$903$$)}();
var $moved$jscomp$5$$=$app$common$geom$align$distribute_space$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71836_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$667$$,$p1__71836_SHARP_$$)},$_$jscomp$2563_page_id$jscomp$274_selected$jscomp$107$$),$self__$jscomp$6288$$.axis),$undo_id$jscomp$85$$=Symbol();return $APP.$app$main$data$workspace$can_distribute_QMARK_$$($_$jscomp$2563_page_id$jscomp$274_selected$jscomp$107$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$85$$),
$app$main$data$workspace$transforms$position_shapes$$($moved$jscomp$5$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,$_$jscomp$2563_page_id$jscomp$274_selected$jscomp$107$$],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$85$$)):null});return new $app$main$data$workspace$distribute_objects_71839$$($axis$jscomp$35$$,$ids$jscomp$249$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$toggle_proportion_lock$$=function(){typeof $app$main$data$workspace$toggle_proportion_lock_71866$$==="undefined"&&($app$main$data$workspace$toggle_proportion_lock_71866$$=function($meta71867$$){this.$meta71867$=$meta71867$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$toggle_proportion_lock_71866$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$toggle_proportion_lock_71866$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4491$app_DOT_main_DOT_data_DOT_workspace_SLASH_toggle_proportion_lock$$},$app$main$data$workspace$toggle_proportion_lock_71866$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71868$$,$meta71867__$1$$){return new $app$main$data$workspace$toggle_proportion_lock_71866$$($meta71867__$1$$)},$app$main$data$workspace$toggle_proportion_lock_71866$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71867$},$app$main$data$workspace$toggle_proportion_lock_71866$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$toggle_proportion_lock_71866$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2565_multi$jscomp$3_page_id$jscomp$275_selected_obj$jscomp$1$$,$selected$jscomp$108_state$jscomp$904$$){$_$jscomp$2565_multi$jscomp$3_page_id$jscomp$275_selected_obj$jscomp$1$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$108_state$jscomp$904$$);var $objects$jscomp$668$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$108_state$jscomp$904$$,
$_$jscomp$2565_multi$jscomp$3_page_id$jscomp$275_selected_obj$jscomp$1$$);$selected$jscomp$108_state$jscomp$904$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($selected$jscomp$108_state$jscomp$904$$);$_$jscomp$2565_multi$jscomp$3_page_id$jscomp$275_selected_obj$jscomp$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71863_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$668$$,$p1__71863_SHARP_$$)},$selected$jscomp$108_state$jscomp$904$$);
$_$jscomp$2565_multi$jscomp$3_page_id$jscomp$275_selected_obj$jscomp$1$$=$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2565_multi$jscomp$3_page_id$jscomp$275_selected_obj$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1808$proportion_lock$$],null));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$APP.$cljs$cst$1808$proportion_lock$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2565_multi$jscomp$3_page_id$jscomp$275_selected_obj$jscomp$1$$))?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($selected$jscomp$108_state$jscomp$904$$,function($p1__71864_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__71864_SHARP_$$,$APP.$cljs$cst$1808$proportion_lock$$,!0)})):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($selected$jscomp$108_state$jscomp$904$$,function($p1__71865_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__71865_SHARP_$$,
$APP.$cljs$cst$1808$proportion_lock$$,$APP.$cljs$core$not$$)}))});return new $app$main$data$workspace$toggle_proportion_lock_71866$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$show_context_menu$$=function($p__71960$$){var $map__71961__$1$$=$APP.$cljs$core$__destructure_map$$($p__71960$$),$position$jscomp$161$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71961__$1$$,$APP.$cljs$cst$1676$position$$);typeof $app$main$data$workspace$show_context_menu_71962$$==="undefined"&&($app$main$data$workspace$show_context_menu_71962$$=function($p__71960$jscomp$1$$,$map__71961$jscomp$1$$,$params$jscomp$295$$,$position$jscomp$162$$,$meta71963$$){this.$p__71960$=
$p__71960$jscomp$1$$;this.$map__71961$=$map__71961$jscomp$1$$;this.params=$params$jscomp$295$$;this.position=$position$jscomp$162$$;this.$meta71963$=$meta71963$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$show_context_menu_71962$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_context_menu_71962$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4504$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_context_menu$$},
$app$main$data$workspace$show_context_menu_71962$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71964$$,$meta71963__$1$$){return new $app$main$data$workspace$show_context_menu_71962$$(this.$p__71960$,this.$map__71961$,this.params,this.position,$meta71963__$1$$)},$app$main$data$workspace$show_context_menu_71962$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71963$},$app$main$data$workspace$show_context_menu_71962$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$show_context_menu_71962$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2576$$,$state$jscomp$915$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$915$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2205$context_menu$$],null),this.params)});return new $app$main$data$workspace$show_context_menu_71962$$($p__71960$$,$map__71961__$1$$,$map__71961__$1$$,
$position$jscomp$161$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$toggle_distances_display$$=function($value$jscomp$613$$){typeof $app$main$data$workspace$toggle_distances_display_72029$$==="undefined"&&($app$main$data$workspace$toggle_distances_display_72029$$=function($value$jscomp$614$$,$meta72030$$){this.value=$value$jscomp$614$$;this.$meta72030$=$meta72030$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$toggle_distances_display_72029$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$toggle_distances_display_72029$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4515$app_DOT_main_DOT_data_DOT_workspace_SLASH_toggle_distances_display$$},$app$main$data$workspace$toggle_distances_display_72029$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72031$$,$meta72030__$1$$){return new $app$main$data$workspace$toggle_distances_display_72029$$(this.value,$meta72030__$1$$)},$app$main$data$workspace$toggle_distances_display_72029$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72030$},$app$main$data$workspace$toggle_distances_display_72029$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$toggle_distances_display_72029$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2583$$,$state$jscomp$919$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$919$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2188$workspace_global$$,
$APP.$cljs$cst$4493$show_distances_QMARK_$$],null),this.value)});return new $app$main$data$workspace$toggle_distances_display_72029$$($value$jscomp$613$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$change_canvas_color$cljs$0core$0IFn$0_invoke$0arity$02$$=function($page_id$jscomp$276$$,$color$jscomp$107$$){typeof $app$main$data$workspace$change_canvas_color_72051$$==="undefined"&&($app$main$data$workspace$change_canvas_color_72051$$=function($page_id$jscomp$277$$,$color$jscomp$108$$,$meta72052$$){this.$page_id$=$page_id$jscomp$277$$;this.color=$color$jscomp$108$$;this.$meta72052$=$meta72052$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$change_canvas_color_72051$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$change_canvas_color_72051$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4516$app_DOT_main_DOT_data_DOT_workspace_SLASH_change_canvas_color$$},$app$main$data$workspace$change_canvas_color_72051$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72053$$,$meta72052__$1$$){return new $app$main$data$workspace$change_canvas_color_72051$$(this.$page_id$,
this.color,$meta72052__$1$$)},$app$main$data$workspace$change_canvas_color_72051$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72052$},$app$main$data$workspace$change_canvas_color_72051$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$change_canvas_color_72051$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$248_or__5025__auto__$jscomp$inline_7248_page_id__$1$jscomp$18$$,$changes$jscomp$279_page$jscomp$105_state$jscomp$920$$){$it$jscomp$248_or__5025__auto__$jscomp$inline_7248_page_id__$1$jscomp$18$$=
this.$page_id$;$it$jscomp$248_or__5025__auto__$jscomp$inline_7248_page_id__$1$jscomp$18$$=$APP.$cljs$core$truth_$$($it$jscomp$248_or__5025__auto__$jscomp$inline_7248_page_id__$1$jscomp$18$$)?$it$jscomp$248_or__5025__auto__$jscomp$inline_7248_page_id__$1$jscomp$18$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$279_page$jscomp$105_state$jscomp$920$$);$changes$jscomp$279_page$jscomp$105_state$jscomp$920$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$279_page$jscomp$105_state$jscomp$920$$,
$it$jscomp$248_or__5025__auto__$jscomp$inline_7248_page_id__$1$jscomp$18$$);$changes$jscomp$279_page$jscomp$105_state$jscomp$920$$=$APP.$app$common$files$changes_builder$mod_page$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$279_page$jscomp$105_state$jscomp$920$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2058$background$$,
$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$(this.color)],null));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$279_page$jscomp$105_state$jscomp$920$$))});return new $app$main$data$workspace$change_canvas_color_72051$$($page_id$jscomp$276$$,$color$jscomp$107$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$find_orphan_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$=function($state$jscomp$926$$,$page_id$jscomp$280$$){var $objects$jscomp$671$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$926$$,$page_id$jscomp$280$$);return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($item$jscomp$92$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_key$$($item$jscomp$92$$),$APP.$app$common$uuid$zero$$)&&
!$APP.$cljs$core$contains_QMARK_$$($objects$jscomp$671$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_val$$($item$jscomp$92$$)))},$objects$jscomp$671$$)};
$app$main$data$workspace$fix_orphan_shapes$$=function(){typeof $app$main$data$workspace$fix_orphan_shapes_72083$$==="undefined"&&($app$main$data$workspace$fix_orphan_shapes_72083$$=function($meta72084$$){this.$meta72084$=$meta72084$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$fix_orphan_shapes_72083$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$fix_orphan_shapes_72083$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4521$app_DOT_main_DOT_data_DOT_workspace_SLASH_fix_orphan_shapes$$},$app$main$data$workspace$fix_orphan_shapes_72083$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72085$$,$meta72084__$1$$){return new $app$main$data$workspace$fix_orphan_shapes_72083$$($meta72084__$1$$)},$app$main$data$workspace$fix_orphan_shapes_72083$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72084$},$app$main$data$workspace$fix_orphan_shapes_72083$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$fix_orphan_shapes_72083$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2589_orphans$$,$state$jscomp$927$$){$_$jscomp$2589_orphans$$=$APP.$cljs$core$set$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keys$$($app$main$data$workspace$find_orphan_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$927$$,$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$927$$)))));
return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$shapes$relocate_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($_$jscomp$2589_orphans$$,$APP.$app$common$uuid$zero$$,0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([!0])))});return new $app$main$data$workspace$fix_orphan_shapes_72083$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$find_components_norefs$$=function(){typeof $app$main$data$workspace$find_components_norefs_72124$$==="undefined"&&($app$main$data$workspace$find_components_norefs_72124$$=function($meta72125$$){this.$meta72125$=$meta72125$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$find_components_norefs_72124$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$find_components_norefs_72124$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4531$app_DOT_main_DOT_data_DOT_workspace_SLASH_find_components_norefs$$},$app$main$data$workspace$find_components_norefs_72124$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72126$$,$meta72125__$1$$){return new $app$main$data$workspace$find_components_norefs_72124$$($meta72125__$1$$)},$app$main$data$workspace$find_components_norefs_72124$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72125$},$app$main$data$workspace$find_components_norefs_72124$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$find_components_norefs_72124$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2598_copies_no_ref$$,$childs_no_ref_copies$jscomp$1_state$jscomp$935$$){var $objects$jscomp$672$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($childs_no_ref_copies$jscomp$1_state$jscomp$935$$);$childs_no_ref_copies$jscomp$1_state$jscomp$935$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__72121_SHARP_$$){return $APP.$app$common$types$component$instance_head_QMARK_$$($p1__72121_SHARP_$$)&&
!$APP.$app$common$types$component$main_instance_QMARK_$$($p1__72121_SHARP_$$)},$APP.$cljs$core$vals$$($objects$jscomp$672$$));$_$jscomp$2598_copies_no_ref$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__72122_SHARP_$$){return $APP.$cljs$core$not$$($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($p1__72122_SHARP_$$))},$childs_no_ref_copies$jscomp$1_state$jscomp$935$$);$childs_no_ref_copies$jscomp$1_state$jscomp$935$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc_map$$,
$id$jscomp$763_item$jscomp$93$$){$id$jscomp$763_item$jscomp$93$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$763_item$jscomp$93$$);var $childs$jscomp$14$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__72123_SHARP_$$){return $APP.$cljs$core$not$$($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($p1__72123_SHARP_$$))},$app$common$files$helpers$get_children$$($objects$jscomp$672$$,$id$jscomp$763_item$jscomp$93$$));return $APP.$cljs$core$seq$$($childs$jscomp$14$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc_map$$,$id$jscomp$763_item$jscomp$93$$,$childs$jscomp$14$$):$acc_map$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$childs_no_ref_copies$jscomp$1_state$jscomp$935$$);console.log("Copies no ref",$APP.$cljs$core$count$$($_$jscomp$2598_copies_no_ref$$),$APP.$cljs$core$clj__GT_js$$($_$jscomp$2598_copies_no_ref$$));return console.log("Childs no ref",$APP.$cljs$core$count$$($childs_no_ref_copies$jscomp$1_state$jscomp$935$$),$APP.$cljs$core$clj__GT_js$$($childs_no_ref_copies$jscomp$1_state$jscomp$935$$))});
return new $app$main$data$workspace$find_components_norefs_72124$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$=function($mode$jscomp$36$$,$options$jscomp$579$$){var $force_QMARK_$jscomp$5$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$cst$3734$force_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$579$$));typeof $app$main$data$workspace$open_layers_search_72132$$==="undefined"&&($app$main$data$workspace$open_layers_search_72132$$=function($mode$jscomp$37$$,$options$jscomp$580$$,$force_QMARK_$jscomp$6$$,$meta72133$$){this.mode=
$mode$jscomp$37$$;this.options=$options$jscomp$580$$;this.$force_QMARK_$=$force_QMARK_$jscomp$6$$;this.$meta72133$=$meta72133$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$open_layers_search_72132$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$open_layers_search_72132$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4536$app_DOT_main_DOT_data_DOT_workspace_SLASH_open_layers_search$$},
$app$main$data$workspace$open_layers_search_72132$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72134$$,$meta72133__$1$$){return new $app$main$data$workspace$open_layers_search_72132$$(this.mode,this.options,this.$force_QMARK_$,$meta72133__$1$$)},$app$main$data$workspace$open_layers_search_72132$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72133$},$app$main$data$workspace$open_layers_search_72132$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$open_layers_search_72132$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2600_mode$jscomp$inline_12867_target$jscomp$134$$,$state$jscomp$937$$){$_$jscomp$2600_mode$jscomp$inline_12867_target$jscomp$134$$=this.mode;$_$jscomp$2600_mode$jscomp$inline_12867_target$jscomp$134$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$4533$open_QMARK_$$,!0,$APP.$cljs$cst$320$mode$$,$_$jscomp$2600_mode$jscomp$inline_12867_target$jscomp$134$$,$APP.$cljs$cst$571$scope$$,
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2600_mode$jscomp$inline_12867_target$jscomp$134$$,$APP.$cljs$cst$4534$find_and_replace$$)?$APP.$cljs$cst$3083$canvas$$:$APP.$cljs$cst$3727$layers$$,$APP.$cljs$cst$4535$find_replace_mode_QMARK_$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2600_mode$jscomp$inline_12867_target$jscomp$134$$,$APP.$cljs$cst$4534$find_and_replace$$)],null);var $JSCompiler_temp$jscomp$10900_current$jscomp$50$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$937$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4537$layers_search$$],null)),$and__5023__auto__$jscomp$inline_12871_and__5023__auto__$jscomp$inline_7250$$=$APP.$cljs$core$not$$(this.$force_QMARK_$);$and__5023__auto__$jscomp$inline_12871_and__5023__auto__$jscomp$inline_7250$$?($and__5023__auto__$jscomp$inline_12871_and__5023__auto__$jscomp$inline_7250$$=$APP.$cljs$cst$4533$open_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10900_current$jscomp$50$$,
!1),$JSCompiler_temp$jscomp$10900_current$jscomp$50$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_12871_and__5023__auto__$jscomp$inline_7250$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$571$scope$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10900_current$jscomp$50$$),$APP.$cljs$cst$571$scope$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2600_mode$jscomp$inline_12867_target$jscomp$134$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4535$find_replace_mode_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10900_current$jscomp$50$$),
$APP.$cljs$cst$4535$find_replace_mode_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2600_mode$jscomp$inline_12867_target$jscomp$134$$)):$and__5023__auto__$jscomp$inline_12871_and__5023__auto__$jscomp$inline_7250$$):$JSCompiler_temp$jscomp$10900_current$jscomp$50$$=$and__5023__auto__$jscomp$inline_12871_and__5023__auto__$jscomp$inline_7250$$;return $APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10900_current$jscomp$50$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$937$$,
$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4537$layers_search$$):$APP.$cljs$core$assoc_in$$($state$jscomp$937$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4537$layers_search$$],null),$_$jscomp$2600_mode$jscomp$inline_12867_target$jscomp$134$$)});return new $app$main$data$workspace$open_layers_search_72132$$($mode$jscomp$36$$,$options$jscomp$579$$,$force_QMARK_$jscomp$5$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$highlight_shape$$=function($param72218$$){return $APP.$app$main$data$workspace$highlight$highlight_shape$$($param72218$$)};$app$main$data$workspace$dehighlight_shape$$=function($param72219$$){return $APP.$app$main$data$workspace$highlight$dehighlight_shape$$($param72219$$)};
$APP.$app$main$data$workspace$update_shape_flags$$=function($param72223$$,$param72224$$){return $app$main$data$workspace$shapes$update_shape_flags$$($param72223$$,$param72224$$)};
$app$main$ui$ds$product$loader$get_tips$$=function(){return new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.01.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.01.message")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.02.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.02.message")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.03.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.03.message")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.04.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.04.message")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.05.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.05.message")],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.06.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.06.message")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.07.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.07.message")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.08.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.08.message")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.09.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.09.message")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.10.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("loader.tips.10.message")],null)],null)};
$app$main$ui$ds$product$loader$loader_icon_STAR_$$=function($props_71382$$){var $height$jscomp$144$$=void 0,$width$jscomp$161$$=void 0,$title$jscomp$14$$=void 0,$props$jscomp$209$$=void 0;({width:$width$jscomp$161$$,height:$height$jscomp$144$$,title:$title$jscomp$14$$,...$props$jscomp$209$$}=$props_71382$$);return(0,$APP.$rumext$v2$create_element$$)("svg",{...$props$jscomp$209$$,viewBox:"0 0 677.34762 182.15429",role:"status",width:$width$jscomp$161$$,height:$height$jscomp$144$$,className:"main_ui_ds_product_loader__loader"},
(0,$APP.$rumext$v2$jsx$$)("title",{children:$title$jscomp$14$$}),(0,$APP.$rumext$v2$jsxs$$)("g",{children:[(0,$APP.$rumext$v2$jsx$$)("path",{d:"M128.273 0l-3.9 2.77L0 91.078l128.273 91.076 549.075-.006V.008L128.273 0zm20.852 30l498.223.006V152.15l-498.223.007V30zm-25 9.74v102.678l-49.033-34.813-.578-32.64 49.61-35.225z"}),(0,$APP.$rumext$v2$jsx$$)("path",{d:"M134.482 157.147v25l518.57.008.002-25-518.572-.008z",className:"main_ui_ds_product_loader__loader-line"})]}))};
$APP.$app$main$ui$ds$product$loader$loader_STAR_$$=function($height__$1$jscomp$2_props_71389$$){var $file_loading$$=void 0,$height$jscomp$145$$=void 0,$children$jscomp$255$$=void 0,$width$jscomp$162$$=void 0,$title$jscomp$15$$=void 0,$class$__$1_overlay$$=void 0,$class$$jscomp$6_title__$1$$=void 0;({className:$class$$jscomp$6_title__$1$$,width:$width$jscomp$162$$,height:$height$jscomp$145$$,title:$title$jscomp$15$$,overlay:$class$__$1_overlay$$,children:$children$jscomp$255$$,fileLoading:$file_loading$$}=
$height__$1$jscomp$2_props_71389$$);var $width__$1$jscomp$3$$=function(){var $or__5025__auto__$jscomp$861_or__5025__auto____$1$jscomp$98$$=$width$jscomp$162$$;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$861_or__5025__auto____$1$jscomp$98$$))return $or__5025__auto__$jscomp$861_or__5025__auto____$1$jscomp$98$$;$or__5025__auto__$jscomp$861_or__5025__auto____$1$jscomp$98$$=$height$jscomp$145$$!=null?$APP.$app$common$math$ceil$$(100/27*$height$jscomp$145$$):null;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$861_or__5025__auto____$1$jscomp$98$$)?
$or__5025__auto__$jscomp$861_or__5025__auto____$1$jscomp$98$$:100}();$height__$1$jscomp$2_props_71389$$=function(){var $or__5025__auto__$jscomp$862_or__5025__auto____$1$jscomp$99$$=$height$jscomp$145$$;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$862_or__5025__auto____$1$jscomp$99$$))return $or__5025__auto__$jscomp$862_or__5025__auto____$1$jscomp$99$$;$or__5025__auto__$jscomp$862_or__5025__auto____$1$jscomp$99$$=$width__$1$jscomp$3$$!=null?$APP.$app$common$math$ceil$$($width__$1$jscomp$3$$*
.27):null;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$862_or__5025__auto____$1$jscomp$99$$)?$or__5025__auto__$jscomp$862_or__5025__auto____$1$jscomp$99$$:27}();$class$__$1_overlay$$=""+($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$6_title__$1$$,"")??"")+" main_ui_ds_product_loader__wrapper "+(($APP.$cljs$core$truth_$$($class$__$1_overlay$$)?"main_ui_ds_product_loader__wrapper-overlay":"")+" "+($APP.$cljs$core$truth_$$($file_loading$$)?"main_ui_ds_product_loader__file-loading":
""));$class$$jscomp$6_title__$1$$=function(){var $or__5025__auto__$jscomp$863$$=$title$jscomp$15$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$863$$)?$or__5025__auto__$jscomp$863$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading")}();var $tips$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$ds$product$loader$get_tips$$),$tip_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$tip$$=$APP.$cljs$core$_deref$$($tip_STAR_$$);
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_loading$$),$APP.$rumext$v2$adapt$$($tips$$)],function(){if($APP.$cljs$core$truth_$$($file_loading$$)){var $sub$jscomp$19$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$cljs$core$reset_BANG_$$($tip_STAR_$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($tips$$,$cljs$core$rand_int$$($APP.$cljs$core$count$$($tips$$))))},(0,$APP.$beicon$v2$core$timer$$)(1E3,
4E3));return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$dispose_BANG_$$,$sub$jscomp$19$$)}return null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:$class$__$1_overlay$$,children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_product_loader__loader-content",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$loader$loader_icon_STAR_$$,{title:$class$$jscomp$6_title__$1$$,width:$width__$1$jscomp$3$$,height:$height__$1$jscomp$2_props_71389$$}),
$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$533$$=$file_loading$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$533$$)?$tip$$:$and__5023__auto__$jscomp$533$$}())?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_product_loader__tips-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_product_loader__tip-title",children:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tip$$,$APP.$cljs$cst$939$title$$)}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_ds_product_loader__tip-message",children:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tip$$,$APP.$cljs$cst$141$message$$)})]}):null]}),$children$jscomp$255$$]})};
$app$main$ui$hooks$resize$update_persistent_state$$=function($data$jscomp$406$$,$file_id$jscomp$296$$,$key$jscomp$388$$,$size$jscomp$130$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($data$jscomp$406$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4541$app_DOT_main_DOT_ui_DOT_hooks_DOT_resize_SLASH_state$$,$file_id$jscomp$296$$],null),$APP.$cljs$core$assoc$$,$key$jscomp$388$$,$size$jscomp$130$$)};
$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$=function($key$jscomp$390$$,$initial$jscomp$26$$,$min_val$jscomp$1$$,$max_val$jscomp$2$$,$axis$jscomp$38$$,$negate_QMARK_$jscomp$2$$,$resize_type$jscomp$3$$,$on_change_size$$){var $file_id$jscomp$297$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$),$current_size_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $saved$jscomp$inline_7261$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$storage$user$$,
$cljs$cst$4541$app_DOT_main_DOT_ui_DOT_hooks_DOT_resize_SLASH_state$$),$file_id$jscomp$297$$),$key$jscomp$390$$);return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($saved$jscomp$inline_7261$$,$initial$jscomp$26$$)}),$current_size$$=$APP.$cljs$core$_deref$$($current_size_STAR_$$),$parent_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$dragging_ref$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$start_size_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$start_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$window_height_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return window.innerHeight}),$window_height$$=$APP.$cljs$core$_deref$$($window_height_STAR_$$),$max_val__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max_val$jscomp$2$$),$APP.$rumext$v2$adapt$$($window_height$$)],function(){var $parsed_max_val$$=typeof $max_val$jscomp$2$$==="string"?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($max_val$jscomp$2$$):
null;return $APP.$cljs$core$truth_$$($parsed_max_val$$)?$window_height$$*$parsed_max_val$$:$max_val$jscomp$2$$}),$set_size$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$297$$),$APP.$rumext$v2$adapt$$($key$jscomp$390$$),$APP.$rumext$v2$adapt$$($min_val$jscomp$1$$),$APP.$rumext$v2$adapt$$($max_val__$1$$),$APP.$rumext$v2$adapt$$($window_height$$)],function($new_size$jscomp$4_new_size__$1$$){$new_size$jscomp$4_new_size__$1$$=$APP.$app$common$math$clamp$$($new_size$jscomp$4_new_size__$1$$,
$min_val$jscomp$1$$,$max_val__$1$$);$APP.$cljs$core$reset_BANG_$$($current_size_STAR_$$,$new_size$jscomp$4_new_size__$1$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$util$storage$user$$,$app$main$ui$hooks$resize$update_persistent_state$$,$file_id$jscomp$297$$,$key$jscomp$390$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$new_size$jscomp$4_new_size__$1$$]))}),$on_pointer_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_size$$)],
function($event$jscomp$108$$){$APP.$app$util$dom$capture_pointer$$($event$jscomp$108$$);$APP.$rumext$v2$set_ref_val_BANG_$$($start_size_ref$$,$current_size$$);$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$$,!0);$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$108$$));return $APP.$app$main$ui$hooks$resize$last_resize_type$$=$resize_type$jscomp$3$$}),$on_lost_pointer_capture$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$109$$){$APP.$app$util$dom$release_pointer$$($event$jscomp$109$$);
$APP.$rumext$v2$set_ref_val_BANG_$$($start_size_ref$$,null);$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$$,!1);$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$$,null);return $APP.$app$main$ui$hooks$resize$last_resize_type$$=null}),$on_pointer_move$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($min_val$jscomp$1$$),$APP.$rumext$v2$adapt$$($max_val__$1$$),$APP.$rumext$v2$adapt$$($negate_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$297$$),$APP.$rumext$v2$adapt$$($key$jscomp$390$$)],
function($event$jscomp$110_new_size$jscomp$5$$){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dragging_ref$$))){var $start$jscomp$229$$=$APP.$rumext$v2$ref_val$$($start_ref$$),$pos$jscomp$124$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$110_new_size$jscomp$5$$),$delta$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $G__71400$$=$APP.$app$common$geom$point$subtract$$($pos$jscomp$124$$,$start$jscomp$229$$);return $APP.$cljs$core$truth_$$($negate_QMARK_$jscomp$2$$)?
$APP.$app$common$geom$point$negate$$($G__71400$$):$G__71400$$}(),$axis$jscomp$38$$),$start_size$$=$APP.$rumext$v2$ref_val$$($start_size_ref$$);$event$jscomp$110_new_size$jscomp$5$$=function(){var $x__5110__auto__$jscomp$inline_7263_x__5113__auto__$jscomp$66$$=$start_size$$+$delta$jscomp$54$$;$x__5110__auto__$jscomp$inline_7263_x__5113__auto__$jscomp$66$$=$x__5110__auto__$jscomp$inline_7263_x__5113__auto__$jscomp$66$$>$min_val$jscomp$1$$?$x__5110__auto__$jscomp$inline_7263_x__5113__auto__$jscomp$66$$:
$min_val$jscomp$1$$;return $x__5110__auto__$jscomp$inline_7263_x__5113__auto__$jscomp$66$$<$max_val__$1$$?$x__5110__auto__$jscomp$inline_7263_x__5113__auto__$jscomp$66$$:$max_val__$1$$}();return $set_size$$.$cljs$core$IFn$_invoke$arity$1$?$set_size$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$110_new_size$jscomp$5$$):$set_size$$($event$jscomp$110_new_size$jscomp$5$$)}return null}),$on_resize_window$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($window_height_STAR_$$,
window.innerHeight)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_size$$),$APP.$rumext$v2$adapt$$($current_size$$)],function(){return $APP.$cljs$core$truth_$$($on_change_size$$)?$on_change_size$$.$cljs$core$IFn$_invoke$arity$1$?$on_change_size$$.$cljs$core$IFn$_invoke$arity$1$($current_size$$):$on_change_size$$($current_size$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){$APP.$app$util$globals$window$$.addEventListener("resize",
$on_resize_window$$);return function(){return $APP.$app$util$globals$window$$.removeEventListener("resize",$on_resize_window$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($window_height$$)],function(){var $new_size$jscomp$6$$=$APP.$app$common$math$clamp$$($current_size$$,$min_val$jscomp$1$$,$max_val__$1$$);return $set_size$$.$cljs$core$IFn$_invoke$arity$1$?$set_size$$.$cljs$core$IFn$_invoke$arity$1$($new_size$jscomp$6$$):$set_size$$($new_size$jscomp$6$$)});
return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$4542$on_pointer_down$$,$on_pointer_down$$,$APP.$cljs$cst$4543$on_lost_pointer_capture$$,$on_lost_pointer_capture$$,$APP.$cljs$cst$4544$on_pointer_move$$,$on_pointer_move$$,$APP.$cljs$cst$4545$parent_ref$$,$parent_ref$jscomp$1$$,$APP.$cljs$cst$4546$set_size$$,$set_size$$,$APP.$cljs$cst$874$size$$,$current_size$$],null)};
$app$main$ui$modal$on_pop_state$$=function($event$jscomp$112$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$112$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$112$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$());return history.forward()};
$APP.$app$main$ui$modal$modal_container_STAR_$$=function(){var $container$jscomp$74$$=$APP.$app$main$ui$hooks$use_portal_container$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4550$modal$$),$temp__5825__auto__$jscomp$228$$=$APP.$rumext$v2$deref$$($app$main$ui$modal$ref_COLON_modal$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$228$$)?(0,$APP.$rumext$v2$portal$$)((0,$APP.$rumext$v2$jsx$$)($app$main$ui$modal$modal_wrapper_STAR_$$,{data:$temp__5825__auto__$jscomp$228$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto__$jscomp$228$$)??
"")),$container$jscomp$74$$):null};
$APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$=function($props_71506_size_px$$){var $icon_id$$=void 0,$offset$jscomp$182_size$jscomp$131$$=void 0,$class$$jscomp$7$$=void 0,$props$jscomp$212$$=void 0;({iconId:$icon_id$$,size:$offset$jscomp$182_size$jscomp$131$$,className:$class$$jscomp$7$$,...$props$jscomp$212$$}=$props_71506_size_px$$);$props_71506_size_px$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$182_size$jscomp$131$$,"l")?32:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$182_size$jscomp$131$$,
"s")?12:16;$offset$jscomp$182_size$jscomp$131$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$182_size$jscomp$131$$,"s")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$182_size$jscomp$131$$,"m")?(16-$props_71506_size_px$$)/2:0;return(0,$APP.$rumext$v2$create_element$$)("svg",{...$props$jscomp$212$$,className:($class$$jscomp$7$$??"")+" main_ui_ds_foundations_assets_icon__icon",width:16>$props_71506_size_px$$?16:$props_71506_size_px$$,height:16>$props_71506_size_px$$?
16:$props_71506_size_px$$},(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-"+($icon_id$$??""),x:$offset$jscomp$182_size$jscomp$131$$,y:$offset$jscomp$182_size$jscomp$131$$,width:$props_71506_size_px$$,height:$props_71506_size_px$$}))};
$APP.$app$main$ui$components$radio_buttons$radio_button$$=function($icon_class_props_71531$$){var $disabled$jscomp$2$$=$icon_class_props_71531$$.disabled,$value$jscomp$615_value__$1$jscomp$19$$=$icon_class_props_71531$$.value,$type$jscomp$545_type__$1$jscomp$7$$=$icon_class_props_71531$$.type,$icon$jscomp$2$$=$icon_class_props_71531$$.icon,$title$jscomp$16$$=$icon_class_props_71531$$.title,$id$jscomp$764$$=$icon_class_props_71531$$.id;$icon_class_props_71531$$=$icon_class_props_71531$$["icon-class"];
var $checked_QMARK_$jscomp$1_context$jscomp$29$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$components$radio_buttons$context$$),$allow_empty_on_change$jscomp$9$$=$checked_QMARK_$jscomp$1_context$jscomp$29$$["allow-empty"];$type$jscomp$545_type__$1$jscomp$7$$=$type$jscomp$545_type__$1$jscomp$7$$?$type$jscomp$545_type__$1$jscomp$7$$:$allow_empty_on_change$jscomp$9$$?"checkbox":"radio";$allow_empty_on_change$jscomp$9$$=$checked_QMARK_$jscomp$1_context$jscomp$29$$["on-change"];var $name$jscomp$362$$=
$checked_QMARK_$jscomp$1_context$jscomp$29$$.name,$encode_fn$$=$checked_QMARK_$jscomp$1_context$jscomp$29$$["encode-fn"];$checked_QMARK_$jscomp$1_context$jscomp$29$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($checked_QMARK_$jscomp$1_context$jscomp$29$$.selected,$value$jscomp$615_value__$1$jscomp$19$$);$value$jscomp$615_value__$1$jscomp$19$$=$encode_fn$$.$cljs$core$IFn$_invoke$arity$1$?$encode_fn$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$615_value__$1$jscomp$19$$):$encode_fn$$($value$jscomp$615_value__$1$jscomp$19$$);
return(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:$id$jscomp$764$$,"data-testid":$id$jscomp$764$$,title:$title$jscomp$16$$,className:"main_ui_components_radio_buttons__radio-icon "+($checked_QMARK_$jscomp$1_context$jscomp$29$$?"main_ui_components_radio_buttons__checked":"")+" "+($APP.$cljs$core$truth_$$($disabled$jscomp$2$$)?"main_ui_components_radio_buttons__disabled":""),children:[$icon$jscomp$2$$!=null?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon$jscomp$2$$,
className:$icon_class_props_71531$$,"aria-hidden":!0}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_radio_buttons__title-name",children:$value$jscomp$615_value__$1$jscomp$19$$}),(0,$APP.$rumext$v2$jsx$$)("input",{id:$id$jscomp$764$$,onChange:$allow_empty_on_change$jscomp$9$$,type:$type$jscomp$545_type__$1$jscomp$7$$,name:$name$jscomp$362$$,disabled:$disabled$jscomp$2$$,value:$value$jscomp$615_value__$1$jscomp$19$$,defaultChecked:$checked_QMARK_$jscomp$1_context$jscomp$29$$})]})};
$APP.$app$main$ui$components$radio_buttons$radio_buttons$$=function($props_71535$$){var $wide$$=$props_71535$$.wide,$on_change$jscomp$10$$=$props_71535$$["on-change"],$children$jscomp$256$$=$props_71535$$.children,$selected$jscomp$111$$=$props_71535$$.selected,$decode_fn$jscomp$4_width$jscomp$163$$=$props_71535$$["decode-fn"],$name$jscomp$363$$=$props_71535$$.name,$allow_empty$jscomp$1$$=$props_71535$$["allow-empty"],$class$$jscomp$8$$=$props_71535$$.class,$encode_fn__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_71535$$["encode-fn"],
$APP.$cljs$core$identity$$),$decode_fn__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($decode_fn$jscomp$4_width$jscomp$163$$,$APP.$cljs$core$identity$$),$nitems$jscomp$1$$=$APP.$cljs$core$array_QMARK_$$($children$jscomp$256$$)?$APP.$cljs$core$count$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$identity$$,$children$jscomp$256$$)):1;$decode_fn$jscomp$4_width$jscomp$163$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($nitems$jscomp$1$$)],
function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($wide$$,!0)?"unset":$APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$(4*($nitems$jscomp$1$$-1)+32*$nitems$jscomp$1$$)});var $on_change_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$111$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$10$$)],function($event$jscomp$117$$){var $input$jscomp$66$$=$APP.$app$util$dom$get_target$$($event$jscomp$117$$),
$G__71544_71552_value$jscomp$616_value__$1$jscomp$20$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$117$$);$G__71544_71552_value$jscomp$616_value__$1$jscomp$20$$=$APP.$cljs$core$not$$($allow_empty$jscomp$1$$)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__71544_71552_value$jscomp$616_value__$1$jscomp$20$$,$selected$jscomp$111$$)?$G__71544_71552_value$jscomp$616_value__$1$jscomp$20$$:null;$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$10$$)&&($G__71544_71552_value$jscomp$616_value__$1$jscomp$20$$=
$decode_fn__$1$$.$cljs$core$IFn$_invoke$arity$1$?$decode_fn__$1$$.$cljs$core$IFn$_invoke$arity$1$($G__71544_71552_value$jscomp$616_value__$1$jscomp$20$$):$decode_fn__$1$$($G__71544_71552_value$jscomp$616_value__$1$jscomp$20$$),$on_change$jscomp$10$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$10$$.$cljs$core$IFn$_invoke$arity$2$($G__71544_71552_value$jscomp$616_value__$1$jscomp$20$$,$event$jscomp$117$$):$on_change$jscomp$10$$($G__71544_71552_value$jscomp$616_value__$1$jscomp$20$$,$event$jscomp$117$$));
return $APP.$app$util$dom$blur_BANG_$$($input$jscomp$66$$)});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($app$main$ui$components$radio_buttons$context$$),{value:{...$props_71535$$,"on-change":$on_change_SINGLEQUOTE_$$,"encode-fn":$encode_fn__$1$$,"decode-fn":$decode_fn__$1$$},children:(0,$APP.$rumext$v2$jsx$$)("div",{style:{width:$decode_fn$jscomp$4_width$jscomp$163$$},className:""+($class$$jscomp$8$$??"")+" main_ui_components_radio_buttons__radio-btn-wrapper",children:$children$jscomp$256$$},
""+($name$jscomp$363$$??"")+"-"+($selected$jscomp$111$$??""))})};
$app$main$ui$components$dropdown$dropdown_content_STAR_$$=function($props_71564$$){function $on_keyup$$($event$jscomp$119$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$119$$))?$on_close$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$$():null}function $on_click$jscomp$1$$($event$jscomp$118_parent$jscomp$285$$){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($listening_ref$$))){var $target$jscomp$136$$=$APP.$app$util$dom$get_target$$($event$jscomp$118_parent$jscomp$285$$);
if($APP.$app$config$check_platform_QMARK_$$()&&$event$jscomp$118_parent$jscomp$285$$.ctrlKey||!$APP.$cljs$core$not$$($target$jscomp$136$$.data_no_close))return null;if($APP.$cljs$core$truth_$$($container$jscomp$75$$)){$event$jscomp$118_parent$jscomp$285$$=$APP.$rumext$v2$ref_val$$($container$jscomp$75$$);var $or__5025__auto__$jscomp$inline_7270$$=$APP.$cljs$core$not$$($event$jscomp$118_parent$jscomp$285$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_7270$$?$or__5025__auto__$jscomp$inline_7270$$:
$event$jscomp$118_parent$jscomp$285$$.contains($target$jscomp$136$$))?null:$on_close$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$$()}return $on_close$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$$()}return null}var $children$jscomp$257$$=$props_71564$$.children,$on_close$$=$props_71564$$.onClose,$container$jscomp$75$$=$props_71564$$.container,$listening_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $keys$jscomp$54$$=
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"click",$on_click$jscomp$1$$),$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"contextmenu",$on_click$jscomp$1$$),$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"keyup",$on_keyup$$)],null);$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($listening_ref$$,
!0)});return function(){return $APP.$cljs$core$run_BANG_$$($APP.$goog$events$unlistenByKey$$,$keys$jscomp$54$$)}});return $children$jscomp$257$$};
$APP.$app$main$ui$components$dropdown$dropdown$$=function($props_71571$$){var $children$jscomp$258$$=$props_71571$$.children,$on_close$jscomp$1$$=$props_71571$$["on-close"],$container$jscomp$76$$=$props_71571$$.container;return $props_71571$$.show?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$dropdown$dropdown_content_STAR_$$,{onClose:$on_close$jscomp$1$$,container:$container$jscomp$76$$,children:$children$jscomp$258$$}):null};
$app$main$ui$components$select$as_key_value$$=function($item$jscomp$94$$){return $APP.$cljs$core$map_QMARK_$$($item$jscomp$94$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$94$$),$APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$94$$),$APP.$cljs$cst$1721$icon$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$94$$)],null):new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$item$jscomp$94$$,$item$jscomp$94$$,$item$jscomp$94$$],null)};$app$main$ui$components$select$rotate_index_forward$$=function($index$jscomp$369_index__$2$jscomp$2$$,$length$jscomp$49$$){$index$jscomp$369_index__$2$jscomp$2$$=($index$jscomp$369_index__$2$jscomp$2$$<0?0:$index$jscomp$369_index__$2$jscomp$2$$)+1;return $index$jscomp$369_index__$2$jscomp$2$$>$length$jscomp$49$$-1?0:$index$jscomp$369_index__$2$jscomp$2$$};
$app$main$ui$components$select$rotate_index_backward$$=function($index$jscomp$370_index__$2$jscomp$3$$,$length$jscomp$50$$){$index$jscomp$370_index__$2$jscomp$3$$=($index$jscomp$370_index__$2$jscomp$3$$<0?0:$index$jscomp$370_index__$2$jscomp$3$$)-1;return $index$jscomp$370_index__$2$jscomp$3$$<0?$length$jscomp$50$$-1:$index$jscomp$370_index__$2$jscomp$3$$};
$APP.$app$main$ui$components$select$select$$=function($dropdown_class_map__71794_props_71787$$){$dropdown_class_map__71794_props_71787$$=$APP.$rumext$v2$util$wrap_props$$($dropdown_class_map__71794_props_71787$$);var $class$$jscomp$9_map__71794__$1$$=$APP.$cljs$core$__destructure_map$$($dropdown_class_map__71794_props_71787$$),$options$jscomp$583$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$9_map__71794__$1$$,$APP.$cljs$cst$873$options$$),$on_change$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$9_map__71794__$1$$,
$APP.$cljs$cst$4157$on_change$$),$disabled$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$9_map__71794__$1$$,$APP.$cljs$cst$2948$disabled$$),$on_pointer_enter_option$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$9_map__71794__$1$$,$cljs$cst$4557$on_pointer_enter_option$$),$on_pointer_leave_option$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$9_map__71794__$1$$,$cljs$cst$4558$on_pointer_leave_option$$),$default_value$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$9_map__71794__$1$$,$cljs$cst$4559$default_value$$);$dropdown_class_map__71794_props_71787$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$9_map__71794__$1$$,$cljs$cst$4560$dropdown_class$$);var $is_open_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$9_map__71794__$1$$,$APP.$cljs$cst$4561$is_open_QMARK_$$),$data_direction$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$9_map__71794__$1$$,
$cljs$cst$4562$data_direction$$);$class$$jscomp$9_map__71794__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$9_map__71794__$1$$,$APP.$cljs$cst$1291$class$$);var $current_label_label_index$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$583$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$components$select$as_key_value$$),
$options$jscomp$583$$)}),$state_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$4561$is_open_QMARK_$$,$APP.$cljs$core$truth_$$($is_open_QMARK_$$)?$is_open_QMARK_$$:!1,$APP.$cljs$cst$4563$current_value$$,$default_value$jscomp$3$$],null)}),$dropdown_direction_state$jscomp$940$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$3$$),$current_id$jscomp$8$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dropdown_direction_state$jscomp$940$$,$APP.$cljs$cst$266$id$$),$current_value$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dropdown_direction_state$jscomp$940$$,$APP.$cljs$cst$4563$current_value$$);$current_label_label_index$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_label_label_index$$,$current_value$jscomp$1$$);var $is_open_QMARK___$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dropdown_direction_state$jscomp$940$$,
$APP.$cljs$cst$4561$is_open_QMARK_$$),$node_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$dropdown_direction_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("down");$dropdown_direction_state$jscomp$940$$=$APP.$cljs$core$_deref$$($dropdown_direction_STAR_$$);var $dropdown_direction_change_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)(0),$handle_key_up$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disabled$jscomp$3$$),$APP.$rumext$v2$adapt$$($options$jscomp$583$$),
$APP.$rumext$v2$adapt$$($current_value$jscomp$1$$)],function($e$jscomp$327$$){if($APP.$cljs$core$truth_$$($disabled$jscomp$3$$))return null;var $options__$1$jscomp$74_value$jscomp$617$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2948$disabled$$),$options$jscomp$583$$),$length$jscomp$52$$=$APP.$cljs$core$count$$($options__$1$jscomp$74_value$jscomp$617$$),$index$jscomp$373_index__$1$jscomp$13$$=
$APP.$app$common$data$index_of_pred$$($options__$1$jscomp$74_value$jscomp$617$$,function($p1__71782_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__71782_SHARP_$$),$current_value$jscomp$1$$)});$index$jscomp$373_index__$1$jscomp$13$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$373_index__$1$jscomp$13$$,0);return $APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$866$$=
(0,$APP.$app$util$keyboard$left_arrow_QMARK_$$)($e$jscomp$327$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$866$$)?$or__5025__auto__$jscomp$866$$:(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($e$jscomp$327$$)}())?($options__$1$jscomp$74_value$jscomp$617$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($options__$1$jscomp$74_value$jscomp$617$$,$app$main$ui$components$select$rotate_index_backward$$($index$jscomp$373_index__$1$jscomp$13$$,
$length$jscomp$52$$))),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$3$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4563$current_value$$,$options__$1$jscomp$74_value$jscomp$617$$),$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$11$$)?$on_change$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$($options__$1$jscomp$74_value$jscomp$617$$):$on_change$jscomp$11$$($options__$1$jscomp$74_value$jscomp$617$$):null):$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$867$$=
(0,$APP.$app$util$keyboard$right_arrow_QMARK_$$)($e$jscomp$327$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$867$$)?$or__5025__auto__$jscomp$867$$:(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($e$jscomp$327$$)}())?($options__$1$jscomp$74_value$jscomp$617$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($options__$1$jscomp$74_value$jscomp$617$$,$app$main$ui$components$select$rotate_index_forward$$($index$jscomp$373_index__$1$jscomp$13$$,
$APP.$cljs$core$count$$($options__$1$jscomp$74_value$jscomp$617$$)))),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$3$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4563$current_value$$,$options__$1$jscomp$74_value$jscomp$617$$),$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$11$$)?$on_change$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$($options__$1$jscomp$74_value$jscomp$617$$):$on_change$jscomp$11$$($options__$1$jscomp$74_value$jscomp$617$$):
null):$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$868$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($e$jscomp$327$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$868$$)?$or__5025__auto__$jscomp$868$$:(0,$APP.$app$util$keyboard$space_QMARK_$$)($e$jscomp$327$$)}())?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$3$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4561$is_open_QMARK_$$,!1):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$tab_QMARK_$$)($e$jscomp$327$$))?
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$3$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4561$is_open_QMARK_$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4563$current_value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($options__$1$jscomp$74_value$jscomp$617$$))])):null}),$open_dropdown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disabled$jscomp$3$$)],
function(){return $APP.$cljs$core$truth_$$($disabled$jscomp$3$$)?null:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$3$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4561$is_open_QMARK_$$,!0)}),$close_dropdown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$3$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4561$is_open_QMARK_$$,!1)}),$select_item$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$11$$)],
function($event$jscomp$120_value$jscomp$618$$){$event$jscomp$120_value$jscomp$618$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$120_value$jscomp$618$$),"value"));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$3$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4563$current_value$$,$event$jscomp$120_value$jscomp$618$$);return $APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$11$$)?$on_change$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$120_value$jscomp$618$$):$on_change$jscomp$11$$($event$jscomp$120_value$jscomp$618$$):null}),$highlight_item$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_pointer_enter_option$$)],function($event$jscomp$121_value$jscomp$619$$){return $APP.$cljs$core$fn_QMARK_$$($on_pointer_enter_option$$)?($event$jscomp$121_value$jscomp$619$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$121_value$jscomp$619$$),
"value")),$on_pointer_enter_option$$.$cljs$core$IFn$_invoke$arity$1$?$on_pointer_enter_option$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$121_value$jscomp$619$$):$on_pointer_enter_option$$($event$jscomp$121_value$jscomp$619$$)):null}),$unhighlight_item$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_pointer_leave_option$$)],function($event$jscomp$122_value$jscomp$620$$){return $APP.$cljs$core$fn_QMARK_$$($on_pointer_leave_option$$)?($event$jscomp$122_value$jscomp$620$$=
$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$122_value$jscomp$620$$),"value")),$on_pointer_leave_option$$.$cljs$core$IFn$_invoke$arity$1$?$on_pointer_leave_option$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$122_value$jscomp$620$$):$on_pointer_leave_option$$($event$jscomp$122_value$jscomp$620$$)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($default_value$jscomp$3$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$3$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4563$current_value$$,$default_value$jscomp$3$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_QMARK___$1$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!1,$is_open_QMARK___$1$$)?($APP.$cljs$core$reset_BANG_$$($dropdown_direction_STAR_$$,"down"),$APP.$rumext$v2$set_ref_val_BANG_$$($dropdown_direction_change_STAR_$$,
0)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_QMARK___$1$$)],function(){var $dropdown_element_is_outside_QMARK_$$=$APP.$rumext$v2$ref_val$$($node_ref$jscomp$1$$),$and__5023__auto__$jscomp$inline_7272$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_7272$$?$dropdown_element_is_outside_QMARK_$$:$and__5023__auto__$jscomp$inline_7272$$)?
($dropdown_element_is_outside_QMARK_$$=$APP.$app$util$dom$is_element_outside_QMARK_$$($dropdown_element_is_outside_QMARK_$$),$APP.$cljs$core$reset_BANG_$$($dropdown_direction_STAR_$$,$dropdown_element_is_outside_QMARK_$$?"up":"down"),$APP.$rumext$v2$set_ref_val_BANG_$$($dropdown_direction_change_STAR_$$,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$$)+1)):null});var $current_icon_selected_option$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71786_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__71786_SHARP_$$),
$default_value$jscomp$3$$)},$options$jscomp$583$$));$current_icon_selected_option$$=$APP.$cljs$cst$1721$icon$$.$cljs$core$IFn$_invoke$arity$1$($current_icon_selected_option$$);var $current_icon_ref$$=$APP.$cljs$core$truth_$$($current_icon_selected_option$$)?$APP.$app$main$ui$icons$default$0$$[$APP.$cuerdas$core$capital$$($cuerdas$core$camel$$($APP.$app$common$data$name$$($current_icon_selected_option$$)))]:null;return(0,$APP.$rumext$v2$jsxs$$)("div",{id:""+($current_id$jscomp$8$$??""),onClick:$open_dropdown$$,
onKeyUp:$handle_key_up$$,tabIndex:"0",role:"combobox",className:"main_ui_components_select__custom-select "+($APP.$cljs$core$truth_$$($disabled$jscomp$3$$)?"main_ui_components_select__disabled":"")+" "+($current_icon_ref$$!=null?"main_ui_components_select__icon":"")+" "+($class$$jscomp$9_map__71794__$1$$??""),children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($current_icon_selected_option$$)?$current_icon_ref$$:$current_icon_selected_option$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_select__current-icon",
children:$current_icon_ref$$}):null,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_select__current-label",children:$current_label_label_index$$}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_select__dropdown-button",children:$APP.$app$main$ui$icons$arrow$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$is_open_QMARK___$1$$,"on-close":$close_dropdown$$,children:(0,$APP.$rumext$v2$jsx$$)("ul",{ref:$node_ref$jscomp$1$$,"data-direction":$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($data_direction$$,
$dropdown_direction_state$jscomp$940$$),className:""+($dropdown_class_map__71794_props_71787$$??"")+" main_ui_components_select__custom-select-dropdown",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$33$$,$JSCompiler_temp_const$jscomp$10903_p__71810$$){var $JSCompiler_temp$jscomp$10905_index$jscomp$374$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$10903_p__71810$$,0,null),$item$jscomp$95$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$10903_p__71810$$,
1,null);$JSCompiler_temp_const$jscomp$10903_p__71810$$=$out_arr__44124__auto__$jscomp$33$$.push;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1472$separator$$,$item$jscomp$95$$))$JSCompiler_temp$jscomp$10905_index$jscomp$374$$=(0,$APP.$rumext$v2$jsx$$)("li",{id:""+($current_id$jscomp$8$$??"")+"-"+($JSCompiler_temp$jscomp$10905_index$jscomp$374$$??""),tabIndex:"-1",role:"option",className:"main_ui_components_select__separator"},""+($current_id$jscomp$8$$??"")+"-"+($JSCompiler_temp$jscomp$10905_index$jscomp$374$$??
""));else{var $icon$jscomp$inline_12888_vec__71814$jscomp$inline_12885$$=$app$main$ui$components$select$as_key_value$$($item$jscomp$95$$),$value$jscomp$inline_12886$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($icon$jscomp$inline_12888_vec__71814$jscomp$inline_12885$$,0,null),$label$jscomp$inline_12887$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($icon$jscomp$inline_12888_vec__71814$jscomp$inline_12885$$,1,null);$icon$jscomp$inline_12888_vec__71814$jscomp$inline_12885$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($icon$jscomp$inline_12888_vec__71814$jscomp$inline_12885$$,2,null);var $icon_ref$jscomp$inline_12889$$=$APP.$cljs$core$truth_$$($icon$jscomp$inline_12888_vec__71814$jscomp$inline_12885$$)?$APP.$app$main$ui$icons$default$0$$[$APP.$cuerdas$core$capital$$($cuerdas$core$camel$$($APP.$app$common$data$name$$($icon$jscomp$inline_12888_vec__71814$jscomp$inline_12885$$)))]:null;$JSCompiler_temp$jscomp$10905_index$jscomp$374$$=(0,$APP.$rumext$v2$jsxs$$)("li",
{role:"option",tabIndex:"-1",className:"main_ui_components_select__checked-element "+($APP.$cljs$core$truth_$$($APP.$cljs$cst$2948$disabled$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$95$$))?"main_ui_components_select__disabled":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$inline_12886$$,$current_value$jscomp$1$$)?"main_ui_components_select__is-selected":""),children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($icon$jscomp$inline_12888_vec__71814$jscomp$inline_12885$$)?
$icon_ref$jscomp$inline_12889$$:$icon$jscomp$inline_12888_vec__71814$jscomp$inline_12885$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_select__icon",children:$icon_ref$jscomp$inline_12889$$}):null,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_select__label",children:$label$jscomp$inline_12887$$}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_select__check-icon",children:$APP.$app$main$ui$icons$tick$$})],onKeyUp:$select_item$$,id:""+($current_id$jscomp$8$$??
"")+"-"+($JSCompiler_temp$jscomp$10905_index$jscomp$374$$??""),"data-value":$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$inline_12886$$])),onClick:$select_item$$,onPointerLeave:$unhighlight_item$$,onPointerEnter:$highlight_item$$},""+($current_id$jscomp$8$$??"")+"-"+($JSCompiler_temp$jscomp$10905_index$jscomp$374$$??""))}$JSCompiler_temp_const$jscomp$10903_p__71810$$.call($out_arr__44124__auto__$jscomp$33$$,
$JSCompiler_temp$jscomp$10905_index$jscomp$374$$);return $out_arr__44124__auto__$jscomp$33$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($options$jscomp$583$$))})})]})};
$app$main$ui$ds$layout$tab_switcher$tab_STAR_$$=function($aria_label_props_71635$$){var $selected$jscomp$112$$,$ref$jscomp$31$$,$icon$jscomp$4$$,$label$jscomp$15$$,$id$jscomp$765$$,$props$jscomp$214$$;({selected:$selected$jscomp$112$$,icon:$icon$jscomp$4$$,label:$label$jscomp$15$$,"aria-label":$aria_label_props_71635$$,id:$id$jscomp$765$$,ref:$ref$jscomp$31$$,...$props$jscomp$214$$}=$aria_label_props_71635$$);var $or__5025__auto__$jscomp$inline_7274$$=$label$jscomp$15$$;return(0,$APP.$rumext$v2$jsx$$)("li",
{children:(0,$APP.$rumext$v2$create_element$$)("button",{...$props$jscomp$214$$,className:"main_ui_ds_layout_tab_switcher__tab "+($APP.$cljs$core$truth_$$($selected$jscomp$112$$)?"main_ui_ds_layout_tab_switcher__selected":""),role:"tab","aria-selected":$selected$jscomp$112$$,title:$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_7274$$)?$or__5025__auto__$jscomp$inline_7274$$:$aria_label_props_71635$$,tabIndex:$APP.$cljs$core$truth_$$($selected$jscomp$112$$)?null:-1,ref:$ref$jscomp$31$$,"data-id":$id$jscomp$765$$,
id:$id$jscomp$765$$},$icon$jscomp$4$$!=null?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon$jscomp$4$$,"aria-hidden":$APP.$cljs$core$truth_$$($label$jscomp$15$$)?!0:null,"aria-label":$APP.$cljs$core$not$$($label$jscomp$15$$)?$aria_label_props_71635$$:null}):null,typeof $label$jscomp$15$$==="string"?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_layout_tab_switcher__tab-text "+($APP.$cljs$core$truth_$$($icon$jscomp$4$$)?"main_ui_ds_layout_tab_switcher__tab-text-and-icon":
""),children:$label$jscomp$15$$}):null)})};
$APP.$app$main$ui$ds$layout$tab_switcher$tab_switcher_STAR_$$=function($props_71645_scrollable_panel__$1$$){var $on_change$jscomp$12$$=void 0,$action_button_position$$=void 0,$children$jscomp$259$$=void 0,$selected$jscomp$114$$=void 0,$action_button$jscomp$1$$=void 0,$on_click$jscomp$3_tabs$jscomp$1$$=void 0,$on_ref_scrollable_panel$$=void 0,$class$$jscomp$11$$=void 0,$props$jscomp$216$$=void 0;({tabs:$on_click$jscomp$3_tabs$jscomp$1$$,className:$class$$jscomp$11$$,onChange:$on_change$jscomp$12$$,
selected:$selected$jscomp$114$$,actionButtonPosition:$action_button_position$$,actionButton:$action_button$jscomp$1$$,children:$children$jscomp$259$$,scrollablePanel:$on_ref_scrollable_panel$$,...$props$jscomp$216$$}=$props_71645_scrollable_panel__$1$$);var $nodes_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);$props_71645_scrollable_panel__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($on_ref_scrollable_panel$$,!1);var $tabs__$1$$=$APP.$cljs$core$array_QMARK_$$($on_click$jscomp$3_tabs$jscomp$1$$)?
$APP.$rumext$v2$util$bean$$($on_click$jscomp$3_tabs$jscomp$1$$):$on_click$jscomp$3_tabs$jscomp$1$$;$on_click$jscomp$3_tabs$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$12$$)],function($event$jscomp$123_id$jscomp$767$$){$event$jscomp$123_id$jscomp$767$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$123_id$jscomp$767$$),"id");return $APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$12$$)?$on_change$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$123_id$jscomp$767$$):$on_change$jscomp$12$$($event$jscomp$123_id$jscomp$767$$):null});$on_ref_scrollable_panel$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$337$$){var $state__$1$jscomp$50_state__$2$jscomp$5$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$$),{}),$id$jscomp$768$$=$APP.$app$util$dom$get_data$$($node$jscomp$337$$,"id");$state__$1$jscomp$50_state__$2$jscomp$5$$=
$APP.$app$util$object$set_BANG_$$($state__$1$jscomp$50_state__$2$jscomp$5$$,$id$jscomp$768$$,$node$jscomp$337$$);$APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$$,$state__$1$jscomp$50_state__$2$jscomp$5$$);return function(){var $state__$4_state__$5$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$$),{}),$id__$1$jscomp$9$$=$APP.$app$util$dom$get_data$$($node$jscomp$337$$,"id");$state__$4_state__$5$$=$APP.$app$util$object$unset_BANG_$$($state__$4_state__$5$$,
$id__$1$jscomp$9$$);return $APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$$,$state__$4_state__$5$$)}});var $on_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$114$$),$APP.$rumext$v2$adapt$$($tabs__$1$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$12$$)],function($event$jscomp$124_id$jscomp$769$$){function $sel_QMARK_$$($p1__71644_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$114$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__71644_SHARP_$$,
$APP.$cljs$cst$266$id$$))}var $len$jscomp$73$$=$APP.$cljs$core$count$$($tabs__$1$$);$event$jscomp$124_id$jscomp$769$$=$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$home_QMARK_$$)($event$jscomp$124_id$jscomp$769$$))?function(){var $tab$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($tabs__$1$$,0);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tab$jscomp$3$$,$APP.$cljs$cst$266$id$$)}():$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$left_arrow_QMARK_$$)($event$jscomp$124_id$jscomp$769$$))?
function(){var $index$jscomp$375_tab$jscomp$4$$=$APP.$app$common$data$index_of_pred$$($tabs__$1$$,$sel_QMARK_$$);$index$jscomp$375_tab$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($tabs__$1$$,$APP.$cljs$core$mod$$($index$jscomp$375_tab$jscomp$4$$-1,$len$jscomp$73$$));return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$375_tab$jscomp$4$$,$APP.$cljs$cst$266$id$$)}():$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$right_arrow_QMARK_$$)($event$jscomp$124_id$jscomp$769$$))?
function(){var $index$jscomp$376_tab$jscomp$5$$=$APP.$app$common$data$index_of_pred$$($tabs__$1$$,$sel_QMARK_$$);$index$jscomp$376_tab$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($tabs__$1$$,$APP.$cljs$core$mod$$($index$jscomp$376_tab$jscomp$5$$+1,$len$jscomp$73$$));return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$376_tab$jscomp$5$$,$APP.$cljs$cst$266$id$$)}():null;return $event$jscomp$124_id$jscomp$769$$!=null?($on_change$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$124_id$jscomp$769$$):$on_change$jscomp$12$$($event$jscomp$124_id$jscomp$769$$),$APP.$app$util$dom$focus_BANG_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($nodes_ref$$),$event$jscomp$124_id$jscomp$769$$))):null});return(0,$APP.$rumext$v2$create_element$$)("div",{...$props$jscomp$216$$,className:($class$$jscomp$11$$??"")+" main_ui_ds_layout_tab_switcher__tabs"},(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_ds_layout_tab_switcher__padding-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$layout$tab_switcher$tab_nav_STAR_$$,{buttonPosition:$action_button_position$$,actionButton:$action_button$jscomp$1$$,tabs:$tabs__$1$$,ref:$on_ref_scrollable_panel$$,selected:$selected$jscomp$114$$,onKeyDown:$on_key_down$$,onClick:$on_click$jscomp$3_tabs$jscomp$1$$})}),(0,$APP.$rumext$v2$jsx$$)("section",{tabIndex:0,role:"tabpanel","aria-labelledby":$selected$jscomp$114$$,className:"main_ui_ds_layout_tab_switcher__tab-panel "+
($APP.$cljs$core$truth_$$($props_71645_scrollable_panel__$1$$)?"main_ui_ds_layout_tab_switcher__scrollable-panel":""),children:$children$jscomp$259$$}))};
$app$common$files$tokens$token_value_empty_fn$$=function($map__71654__$1_p__71653_value$jscomp$622$$){$map__71654__$1_p__71653_value$jscomp$622$$=$APP.$cljs$core$__destructure_map$$($map__71654__$1_p__71653_value$jscomp$622$$);$map__71654__$1_p__71653_value$jscomp$622$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71654__$1_p__71653_value$jscomp$622$$,$APP.$cljs$cst$260$value$$);return $APP.$cuerdas$core$empty_QMARK_$$($map__71654__$1_p__71653_value$jscomp$622$$)||$APP.$cuerdas$core$blank_QMARK_$$($map__71654__$1_p__71653_value$jscomp$622$$)?
(0,$APP.$app$common$i18n$tr$$)("errors.tokens.empty-input"):null};
$APP.$app$common$files$tokens$make_token_value_schema$$=function($token_type$jscomp$3$$){return new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$531$multi$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$532$dispatch$$,$APP.$cljs$core$constantly$$($token_type$jscomp$3$$),$APP.$cljs$cst$939$title$$,"Token Value"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1734$opacity$$,
$app$common$files$tokens$schema_COLON_token_value_opacity$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1758$font_family$$,$app$common$files$tokens$schema_COLON_token_value_font_family$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1760$font_size$$,$app$common$files$tokens$schema_COLON_token_value_numeric$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1761$font_weight$$,$app$common$files$tokens$schema_COLON_token_value_font_weight$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1981$typography$$,$app$common$files$tokens$schema_COLON_token_value_typography$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1654$shadow$$,$app$common$files$tokens$schema_COLON_token_value_shadow$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$379$malli_DOT_core_SLASH_default$$,$APP.$app$common$files$tokens$schema_COLON_token_value_generic$$],null)],null)};
$APP.$app$common$files$tokens$make_token_name_schema$$=function($tokens_tree$jscomp$1$$){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,255,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71661_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__71661_SHARP_$$)),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$common$i18n$tr$$)("workspace.tokens.token-name-length-validation-error"))].join("")}],null)],null),$APP.$app$common$schema$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$token$schema_COLON_token_name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71662_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__71662_SHARP_$$)),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$common$i18n$tr$$)("workspace.tokens.token-name-validation-error"))].join("")}])),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71663_SHARP_$$){return $APP.$app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.token-name-duplication-validation-error",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__71663_SHARP_$$)]))}],null),function($p1__71664_SHARP_$$){return $tokens_tree$jscomp$1$$!=null&&!$APP.$app$common$types$tokens_lib$token_name_path_exists_QMARK_$$($p1__71664_SHARP_$$,$tokens_tree$jscomp$1$$)}],null)],null)};
$APP.$app$common$files$tokens$make_token_schema$$=function($tokens_tree$jscomp$3$$,$token_type$jscomp$4$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$app$common$schema$merge$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$types$token$schema_COLON_token_attrs$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$app$common$files$tokens$make_token_name_schema$$($tokens_tree$jscomp$3$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$APP.$app$common$files$tokens$make_token_value_schema$$($token_type$jscomp$4$$)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$936$description$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$files$tokens$schema_COLON_token_description$$],null)],null)])),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3388$error_SLASH_field$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return(0,$APP.$app$common$i18n$tr$$)("errors.tokens.self-reference")}],
null),function($name$jscomp$365_p__71686$$){var $map__71687__$1_value$jscomp$625$$=$APP.$cljs$core$__destructure_map$$($name$jscomp$365_p__71686$$);$name$jscomp$365_p__71686$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71687__$1_value$jscomp$625$$,$APP.$cljs$cst$725$name$$);$map__71687__$1_value$jscomp$625$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71687__$1_value$jscomp$625$$,$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($name$jscomp$365_p__71686$$)?
$map__71687__$1_value$jscomp$625$$:$name$jscomp$365_p__71686$$)?!$APP.$app$common$types$token$token_value_self_reference_QMARK_$$($name$jscomp$365_p__71686$$,$map__71687__$1_value$jscomp$625$$):null}],null)],null)};
$APP.$app$common$files$tokens$make_token_set_name_schema$$=function($tokens_lib$jscomp$10$$,$set_id$jscomp$23$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,255,$APP.$cljs$cst$884$error_SLASH_fn$$,
function($p1__71693_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__71693_SHARP_$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$common$i18n$tr$$)("workspace.tokens.token-name-length-validation-error"))].join("")}],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return(0,$APP.$app$common$i18n$tr$$)("errors.token-set-already-exists")}],null),function($name$jscomp$367_set$jscomp$14$$){var $or__5025__auto__$jscomp$870$$=$tokens_lib$jscomp$10$$==null;if($or__5025__auto__$jscomp$870$$)return $or__5025__auto__$jscomp$870$$;$name$jscomp$367_set$jscomp$14$$=$APP.$app$common$types$tokens_lib$get_set_by_name$$($tokens_lib$jscomp$10$$,$name$jscomp$367_set$jscomp$14$$);return $name$jscomp$367_set$jscomp$14$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$tokens_lib$get_id$$($name$jscomp$367_set$jscomp$14$$),
$set_id$jscomp$23$$)}],null)],null)};
$APP.$app$common$files$tokens$make_token_theme_group_schema$$=function($tokens_lib$jscomp$12$$,$name$jscomp$368$$,$theme_id$jscomp$3$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$338$min$$,0,$APP.$cljs$cst$339$max$$,255,$APP.$cljs$cst$884$error_SLASH_fn$$,
function($p1__71698_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__71698_SHARP_$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$common$i18n$tr$$)("workspace.tokens.token-name-length-validation-error"))].join("")}],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return(0,$APP.$app$common$i18n$tr$$)("errors.token-theme-already-exists")}],null),function($group$jscomp$40_theme$jscomp$10$$){var $or__5025__auto__$jscomp$871$$=$tokens_lib$jscomp$12$$==null;if($or__5025__auto__$jscomp$871$$)return $or__5025__auto__$jscomp$871$$;$group$jscomp$40_theme$jscomp$10$$=$app$common$types$tokens_lib$get_theme_by_name$$($tokens_lib$jscomp$12$$,$group$jscomp$40_theme$jscomp$10$$,$name$jscomp$368$$);return $group$jscomp$40_theme$jscomp$10$$==
null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$40_theme$jscomp$10$$),$theme_id$jscomp$3$$)}],null)],null)};
$APP.$app$common$files$tokens$make_token_theme_name_schema$$=function($tokens_lib$jscomp$13$$,$group$jscomp$41$$,$theme_id$jscomp$4$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,255,$APP.$cljs$cst$884$error_SLASH_fn$$,
function($p1__71699_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__71699_SHARP_$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$common$i18n$tr$$)("workspace.tokens.token-name-length-validation-error"))].join("")}],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71700_SHARP_$$){return $APP.$app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.token-theme-already-exists",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$41$$),"/",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__71700_SHARP_$$))].join("")]))}],null),function($name$jscomp$369_theme$jscomp$11$$){var $or__5025__auto__$jscomp$872$$=
$tokens_lib$jscomp$13$$==null;if($or__5025__auto__$jscomp$872$$)return $or__5025__auto__$jscomp$872$$;$name$jscomp$369_theme$jscomp$11$$=$app$common$types$tokens_lib$get_theme_by_name$$($tokens_lib$jscomp$13$$,$group$jscomp$41$$,$name$jscomp$369_theme$jscomp$11$$);return $name$jscomp$369_theme$jscomp$11$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$369_theme$jscomp$11$$),$theme_id$jscomp$4$$)}],null)],null)};
$APP.$app$common$files$tokens$parse_token_value$$=function($temp__5825__auto____$1$jscomp$12_value$jscomp$627_value__$1$jscomp$22$$){if(typeof $temp__5825__auto____$1$jscomp$12_value$jscomp$627_value__$1$jscomp$22$$==="number")return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$temp__5825__auto____$1$jscomp$12_value$jscomp$627_value__$1$jscomp$22$$],null);if(typeof $temp__5825__auto____$1$jscomp$12_value$jscomp$627_value__$1$jscomp$22$$==="string"){var $temp__5825__auto__$jscomp$229_unit$jscomp$5$$=
$APP.$cljs$core$re_find$$($app$common$files$tokens$parseable_token_value_regexp$$,$temp__5825__auto____$1$jscomp$12_value$jscomp$627_value__$1$jscomp$22$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$229_unit$jscomp$5$$))return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($temp__5825__auto__$jscomp$229_unit$jscomp$5$$,0,null),$temp__5825__auto____$1$jscomp$12_value$jscomp$627_value__$1$jscomp$22$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($temp__5825__auto__$jscomp$229_unit$jscomp$5$$,
1,null),$temp__5825__auto__$jscomp$229_unit$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($temp__5825__auto__$jscomp$229_unit$jscomp$5$$,2,null),$temp__5825__auto____$1$jscomp$12_value$jscomp$627_value__$1$jscomp$22$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto____$1$jscomp$12_value$jscomp$627_value__$1$jscomp$22$$),$APP.$cljs$core$truth_$$($temp__5825__auto____$1$jscomp$12_value$jscomp$627_value__$1$jscomp$22$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,$temp__5825__auto____$1$jscomp$12_value$jscomp$627_value__$1$jscomp$22$$,$APP.$cljs$cst$4574$unit$$,$temp__5825__auto__$jscomp$229_unit$jscomp$5$$],null):null}return null};
$APP.$app$common$files$tokens$attributes_map$$=function($attributes$jscomp$17$$,$token$jscomp$68$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($attr$jscomp$55$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$attr$jscomp$55$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$68$$)],null)}),$attributes$jscomp$17$$)};
$app$common$files$tokens$remove_attributes_for_token$$=function($attributes$jscomp$18$$,$token_name$jscomp$9$$,$applied_tokens$jscomp$3$$){var $attr_QMARK_$$=$APP.$cljs$core$set$$($attributes$jscomp$18$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p__71715_v$jscomp$600$$){var $and__5023__auto__$jscomp$541_k$jscomp$653$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71715_v$jscomp$600$$,
0,null);$p__71715_v$jscomp$600$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71715_v$jscomp$600$$,1,null);$and__5023__auto__$jscomp$541_k$jscomp$653$$=$attr_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$attr_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$541_k$jscomp$653$$):$attr_QMARK_$$($and__5023__auto__$jscomp$541_k$jscomp$653$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$541_k$jscomp$653$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__71715_v$jscomp$600$$,
$token_name$jscomp$9$$):$and__5023__auto__$jscomp$541_k$jscomp$653$$},$applied_tokens$jscomp$3$$))};
$APP.$app$common$files$tokens$token_attribute_applied_QMARK_$$=function($token$jscomp$69$$,$shape$jscomp$760_temp__5825__auto__$jscomp$230$$,$token_attribute$$){$shape$jscomp$760_temp__5825__auto__$jscomp$230$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$760_temp__5825__auto__$jscomp$230$$,$APP.$cljs$cst$1873$applied_tokens$$),$token_attribute$$);return $APP.$cljs$core$truth_$$($shape$jscomp$760_temp__5825__auto__$jscomp$230$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$69$$),$shape$jscomp$760_temp__5825__auto__$jscomp$230$$):null};$app$common$files$tokens$token_applied_QMARK_$$=function($token$jscomp$70$$,$shape$jscomp$761$$,$token_attributes$$){return $APP.$cljs$core$some$$(function($p1__71720_SHARP_$$){return $APP.$app$common$files$tokens$token_attribute_applied_QMARK_$$($token$jscomp$70$$,$shape$jscomp$761$$,$p1__71720_SHARP_$$)},$token_attributes$$)};
$APP.$app$common$files$tokens$shapes_token_applied_QMARK_$$=function($token$jscomp$71$$,$shapes$jscomp$120$$,$token_attributes$jscomp$1$$){return $APP.$cljs$core$some$$(function($p1__71722_SHARP_$$){return $app$common$files$tokens$token_applied_QMARK_$$($token$jscomp$71$$,$p1__71722_SHARP_$$,$token_attributes$jscomp$1$$)},$shapes$jscomp$120$$)};
$APP.$app$main$data$tinycolor$valid_color$$=function($color_str_tc$jscomp$2$$){$color_str_tc$jscomp$2$$=(0,$APP.$shadow$js$shim$module$0tinycolor2$0default$$)($color_str_tc$jscomp$2$$);var $JSCompiler_inline_result$jscomp$1299_and__5023__auto__$jscomp$inline_7281_and__5023__auto____$1$jscomp$inline_7282$$=$color_str_tc$jscomp$2$$.isValid();$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1299_and__5023__auto__$jscomp$inline_7281_and__5023__auto____$1$jscomp$inline_7282$$)&&($JSCompiler_inline_result$jscomp$1299_and__5023__auto__$jscomp$inline_7281_and__5023__auto____$1$jscomp$inline_7282$$=
$color_str_tc$jscomp$2$$.getFormat(),$JSCompiler_inline_result$jscomp$1299_and__5023__auto__$jscomp$inline_7281_and__5023__auto____$1$jscomp$inline_7282$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1299_and__5023__auto__$jscomp$inline_7281_and__5023__auto____$1$jscomp$inline_7282$$)?$APP.$cuerdas$core$starts_with_QMARK_$$($color_str_tc$jscomp$2$$.getFormat(),"hex")?$APP.$cuerdas$core$starts_with_QMARK_$$($color_str_tc$jscomp$2$$.getOriginalInput(),"#"):!0:$JSCompiler_inline_result$jscomp$1299_and__5023__auto__$jscomp$inline_7281_and__5023__auto____$1$jscomp$inline_7282$$);
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1299_and__5023__auto__$jscomp$inline_7281_and__5023__auto____$1$jscomp$inline_7282$$)?$color_str_tc$jscomp$2$$:null};$APP.$app$main$data$tinycolor$__GT_hex_string$$=function($tc$jscomp$5$$){return $tc$jscomp$5$$.toHexString()};$APP.$app$main$data$tinycolor$alpha$$=function($tc$jscomp$7$$){return $tc$jscomp$7$$.getAlpha()};
$APP.$app$main$data$workspace$tokens$errors$get_error_code$$=function($error_key$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($app$main$data$workspace$tokens$errors$error_codes$$,$error_key$$,$APP.$cljs$cst$4601$error_SLASH_unknown$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$errors$error_codes$$))};
$APP.$app$main$data$workspace$tokens$errors$error_with_value$$=function($error_key$jscomp$1$$,$error_value$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$data$workspace$tokens$errors$get_error_code$$($error_key$jscomp$1$$),$APP.$cljs$cst$4603$error_SLASH_value$$,$error_value$$)};$APP.$app$main$data$tokenscript$color_symbol_QMARK_$$=function($v$jscomp$608$$){return $v$jscomp$608$$ instanceof $APP.$shadow$js$shim$module$0$0penpot$0tokenscript$$.ColorSymbol};
$app$main$data$tokenscript$structured_token__GT_penpot_map$$=function($entries$jscomp$20_token_symbol$$){if($entries$jscomp$20_token_symbol$$.value instanceof Array)return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$,$entries$jscomp$20_token_symbol$$.value);$entries$jscomp$20_token_symbol$$=$cljs$core$es6_iterator_seq$$($entries$jscomp$20_token_symbol$$.value.entries());return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__71832_v$jscomp$615$$){var $k$jscomp$654$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71832_v$jscomp$615$$,0,null);$p__71832_v$jscomp$615$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71832_v$jscomp$615$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$654$$),$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$.$cljs$core$IFn$_invoke$arity$1$($p__71832_v$jscomp$615$$):$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($p__71832_v$jscomp$615$$)],null)},$entries$jscomp$20_token_symbol$$))};
$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$=function($v$jscomp$616$$){return $v$jscomp$616$$==null?null:$v$jscomp$616$$ instanceof $APP.$shadow$js$shim$module$0$0penpot$0tokenscript$$.TokenSymbol?$app$main$data$tokenscript$structured_token__GT_penpot_map$$($v$jscomp$616$$):$v$jscomp$616$$ instanceof $APP.$shadow$js$shim$module$0$0penpot$0tokenscript$$.ListSymbol?$app$main$data$tokenscript$structured_token__GT_penpot_map$$($v$jscomp$616$$):$APP.$app$main$data$tokenscript$color_symbol_QMARK_$$($v$jscomp$616$$)?
$v$jscomp$616$$.to("hex").value:$v$jscomp$616$$ instanceof $APP.$shadow$js$shim$module$0$0penpot$0tokenscript$$.NumberWithUnitSymbol&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$616$$.unit,"rem")?$v$jscomp$616$$.value*16:$v$jscomp$616$$ instanceof $APP.$shadow$js$shim$module$0$0penpot$0tokenscript$$.NumberWithUnitSymbol&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$616$$.unit,"%")?$v$jscomp$616$$.value/100:$v$jscomp$616$$.value};
$app$main$data$tokenscript$create_token_builder$$=function($tokens$jscomp$21$$){var $output$jscomp$11$$=$APP.$cljs$core$volatile_BANG_$$($tokens$jscomp$21$$);return{onResolve:function($token_name$jscomp$10$$,$resolved_symbol$$){return $output$jscomp$11$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$APP.$cljs$core$assoc_in$$($output$jscomp$11$$.$cljs$core$IDeref$_deref$arity$1$(null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$token_name$jscomp$10$$,
$APP.$cljs$cst$4605$resolved_value$$],null),$resolved_symbol$$))},onError:function($token_name$jscomp$11$$){var $default_error_value$jscomp$628$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tokens$jscomp$21$$,$token_name$jscomp$11$$);$default_error_value$jscomp$628$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4581$error_DOT_style_dictionary_SLASH_invalid_token_value$$,
$default_error_value$jscomp$628$$)],null);return $output$jscomp$11$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$APP.$cljs$core$assoc_in$$($output$jscomp$11$$.$cljs$core$IDeref$_deref$arity$1$(null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$token_name$jscomp$11$$,$APP.$cljs$cst$570$errors$$],null),$default_error_value$jscomp$628$$))},getResult:function(){return $APP.$cljs$core$_deref$$($output$jscomp$11$$)}}};
$APP.$app$main$data$tokenscript$clj__GT_token__GT_tokenscript_token$$=function($p__71842_type$jscomp$547$$){var $map__71843__$1_value$jscomp$629$$=$APP.$cljs$core$__destructure_map$$($p__71842_type$jscomp$547$$);$p__71842_type$jscomp$547$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71843__$1_value$jscomp$629$$,$APP.$cljs$cst$139$type$$);$map__71843__$1_value$jscomp$629$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71843__$1_value$jscomp$629$$,$APP.$cljs$cst$260$value$$);
return{$type:$APP.$cljs$core$name$$($p__71842_type$jscomp$547$$),$value:$APP.$cljs$core$clj__GT_js$$($map__71843__$1_value$jscomp$629$$)}};
$APP.$app$main$data$tokenscript$process_tokens$$=function($tokens$jscomp$23$$){for(var $token_map$jscomp$inline_7285$$=new Map,$G__71888$jscomp$inline_7296_seq__71844_71872$jscomp$inline_7286_seq__71844_71886__$1$jscomp$inline_7294_temp__5825__auto___71884$jscomp$inline_7293$$=$APP.$cljs$core$seq$$($tokens$jscomp$23$$),$G__71889$jscomp$inline_7297_chunk__71845_71873$jscomp$inline_7287_k_71893$jscomp$inline_7300$$=null,$G__71890$jscomp$inline_7298_c__5548__auto___71887$jscomp$inline_7295_count__71846_71874$jscomp$inline_7288_token_71894$jscomp$inline_7301_vec__71860_71892$jscomp$inline_7299$$=
0,$i__71847_71875$jscomp$inline_7289$$=0;;)if($i__71847_71875$jscomp$inline_7289$$<$G__71890$jscomp$inline_7298_c__5548__auto___71887$jscomp$inline_7295_count__71846_71874$jscomp$inline_7288_token_71894$jscomp$inline_7301_vec__71860_71892$jscomp$inline_7299$$){var $token_71878$jscomp$inline_7292_vec__71854_71876$jscomp$inline_7290$$=$G__71889$jscomp$inline_7297_chunk__71845_71873$jscomp$inline_7287_k_71893$jscomp$inline_7300$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__71847_71875$jscomp$inline_7289$$),
$k_71877$jscomp$inline_7291$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($token_71878$jscomp$inline_7292_vec__71854_71876$jscomp$inline_7290$$,0,null);$token_71878$jscomp$inline_7292_vec__71854_71876$jscomp$inline_7290$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($token_71878$jscomp$inline_7292_vec__71854_71876$jscomp$inline_7290$$,1,null);$token_map$jscomp$inline_7285$$.set($k_71877$jscomp$inline_7291$$,$APP.$app$main$data$tokenscript$clj__GT_token__GT_tokenscript_token$$($token_71878$jscomp$inline_7292_vec__71854_71876$jscomp$inline_7290$$));
$i__71847_71875$jscomp$inline_7289$$+=1}else if($G__71888$jscomp$inline_7296_seq__71844_71872$jscomp$inline_7286_seq__71844_71886__$1$jscomp$inline_7294_temp__5825__auto___71884$jscomp$inline_7293$$=$APP.$cljs$core$seq$$($G__71888$jscomp$inline_7296_seq__71844_71872$jscomp$inline_7286_seq__71844_71886__$1$jscomp$inline_7294_temp__5825__auto___71884$jscomp$inline_7293$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__71888$jscomp$inline_7296_seq__71844_71872$jscomp$inline_7286_seq__71844_71886__$1$jscomp$inline_7294_temp__5825__auto___71884$jscomp$inline_7293$$)?
($G__71890$jscomp$inline_7298_c__5548__auto___71887$jscomp$inline_7295_count__71846_71874$jscomp$inline_7288_token_71894$jscomp$inline_7301_vec__71860_71892$jscomp$inline_7299$$=$APP.$cljs$core$_chunked_first$$($G__71888$jscomp$inline_7296_seq__71844_71872$jscomp$inline_7286_seq__71844_71886__$1$jscomp$inline_7294_temp__5825__auto___71884$jscomp$inline_7293$$),$G__71888$jscomp$inline_7296_seq__71844_71872$jscomp$inline_7286_seq__71844_71886__$1$jscomp$inline_7294_temp__5825__auto___71884$jscomp$inline_7293$$=
$APP.$cljs$core$_chunked_rest$$($G__71888$jscomp$inline_7296_seq__71844_71872$jscomp$inline_7286_seq__71844_71886__$1$jscomp$inline_7294_temp__5825__auto___71884$jscomp$inline_7293$$),$G__71889$jscomp$inline_7297_chunk__71845_71873$jscomp$inline_7287_k_71893$jscomp$inline_7300$$=$G__71890$jscomp$inline_7298_c__5548__auto___71887$jscomp$inline_7295_count__71846_71874$jscomp$inline_7288_token_71894$jscomp$inline_7301_vec__71860_71892$jscomp$inline_7299$$,$G__71890$jscomp$inline_7298_c__5548__auto___71887$jscomp$inline_7295_count__71846_71874$jscomp$inline_7288_token_71894$jscomp$inline_7301_vec__71860_71892$jscomp$inline_7299$$=
$APP.$cljs$core$count$$($G__71890$jscomp$inline_7298_c__5548__auto___71887$jscomp$inline_7295_count__71846_71874$jscomp$inline_7288_token_71894$jscomp$inline_7301_vec__71860_71892$jscomp$inline_7299$$)):($G__71890$jscomp$inline_7298_c__5548__auto___71887$jscomp$inline_7295_count__71846_71874$jscomp$inline_7288_token_71894$jscomp$inline_7301_vec__71860_71892$jscomp$inline_7299$$=$APP.$cljs$core$first$$($G__71888$jscomp$inline_7296_seq__71844_71872$jscomp$inline_7286_seq__71844_71886__$1$jscomp$inline_7294_temp__5825__auto___71884$jscomp$inline_7293$$),
$G__71889$jscomp$inline_7297_chunk__71845_71873$jscomp$inline_7287_k_71893$jscomp$inline_7300$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__71890$jscomp$inline_7298_c__5548__auto___71887$jscomp$inline_7295_count__71846_71874$jscomp$inline_7288_token_71894$jscomp$inline_7301_vec__71860_71892$jscomp$inline_7299$$,0,null),$G__71890$jscomp$inline_7298_c__5548__auto___71887$jscomp$inline_7295_count__71846_71874$jscomp$inline_7288_token_71894$jscomp$inline_7301_vec__71860_71892$jscomp$inline_7299$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__71890$jscomp$inline_7298_c__5548__auto___71887$jscomp$inline_7295_count__71846_71874$jscomp$inline_7288_token_71894$jscomp$inline_7301_vec__71860_71892$jscomp$inline_7299$$,1,null),$token_map$jscomp$inline_7285$$.set($G__71889$jscomp$inline_7297_chunk__71845_71873$jscomp$inline_7287_k_71893$jscomp$inline_7300$$,$APP.$app$main$data$tokenscript$clj__GT_token__GT_tokenscript_token$$($G__71890$jscomp$inline_7298_c__5548__auto___71887$jscomp$inline_7295_count__71846_71874$jscomp$inline_7288_token_71894$jscomp$inline_7301_vec__71860_71892$jscomp$inline_7299$$)),
$G__71888$jscomp$inline_7296_seq__71844_71872$jscomp$inline_7286_seq__71844_71886__$1$jscomp$inline_7294_temp__5825__auto___71884$jscomp$inline_7293$$=$APP.$cljs$core$next$$($G__71888$jscomp$inline_7296_seq__71844_71872$jscomp$inline_7286_seq__71844_71886__$1$jscomp$inline_7294_temp__5825__auto___71884$jscomp$inline_7293$$),$G__71889$jscomp$inline_7297_chunk__71845_71873$jscomp$inline_7287_k_71893$jscomp$inline_7300$$=null,$G__71890$jscomp$inline_7298_c__5548__auto___71887$jscomp$inline_7295_count__71846_71874$jscomp$inline_7288_token_71894$jscomp$inline_7301_vec__71860_71892$jscomp$inline_7299$$=
0),$i__71847_71875$jscomp$inline_7289$$=0;else break;return $APP.$shadow$js$shim$module$0$0penpot$0tokenscript$$.processTokens($token_map$jscomp$inline_7285$$,{config:$app$main$data$tokenscript$config$$,builder:$app$main$data$tokenscript$create_token_builder$$($tokens$jscomp$23$$)})};
$APP.$app$main$data$tokenscript$resolve_tokens$$=function($result$jscomp$320_tokens$jscomp$25$$){var $tpoint$jscomp$1$$=$app$common$time$tpoint_ms$$();$result$jscomp$320_tokens$jscomp$25$$=$APP.$app$main$data$tokenscript$process_tokens$$($result$jscomp$320_tokens$jscomp$25$$);var $elapsed$jscomp$1$$=$tpoint$jscomp$1$$();$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.tokenscript",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"tokenscript/resolve-tokens"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2278$elapsed$$,$elapsed$jscomp$1$$],null)],null)}),null,"app.main.data.tokenscript",$APP.$cljs$cst$1160$debug$$,!1);return $result$jscomp$320_tokens$jscomp$25$$.output};
$app$main$data$workspace$tokens$warnings$warning_with_value$$=function($warning_key$jscomp$1$$,$warning_value$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($app$main$data$workspace$tokens$warnings$warning_codes$$,$warning_key$jscomp$1$$,$cljs$cst$4610$warning_SLASH_unknown$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$warnings$warning_codes$$)),$cljs$cst$4612$warning_SLASH_value$$,$warning_value$$)};
$app$main$data$style_dictionary$parse_sd_token_color_value$$=function($value$jscomp$632$$){var $missing_references$$=$APP.$cljs$core$seq$$($APP.$app$common$types$token$find_token_value_references$$($value$jscomp$632$$)),$temp__5823__auto__$jscomp$192$$=$APP.$app$main$data$tinycolor$valid_color$$($value$jscomp$632$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$192$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$value$jscomp$632$$,$APP.$cljs$cst$4574$unit$$,
$temp__5823__auto__$jscomp$192$$.getFormat()],null):$missing_references$$?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$missing_references$$)],null),$cljs$cst$4619$references$$,$missing_references$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4583$error_DOT_token_SLASH_invalid_color$$,$value$jscomp$632$$)],null)],null)};
$app$main$data$style_dictionary$with_units$$=function($s$jscomp$554$$){var $and__5023__auto__$jscomp$545$$=typeof $s$jscomp$554$$==="string";return $and__5023__auto__$jscomp$545$$?$APP.$cljs$core$re_matches$$(/^-?\d+(\.\d+)?(px|rem)$/,$s$jscomp$554$$):$and__5023__auto__$jscomp$545$$};
$app$main$data$style_dictionary$parse_sd_token_number_value$$=function($value$jscomp$633$$){var $number_QMARK_$$=function(){var $JSCompiler_temp$jscomp$1300_and__5023__auto__$jscomp$inline_7306_or__5025__auto__$jscomp$874$$=typeof $value$jscomp$633$$==="number";$JSCompiler_temp$jscomp$1300_and__5023__auto__$jscomp$inline_7306_or__5025__auto__$jscomp$874$$||($JSCompiler_temp$jscomp$1300_and__5023__auto__$jscomp$inline_7306_or__5025__auto__$jscomp$874$$=($JSCompiler_temp$jscomp$1300_and__5023__auto__$jscomp$inline_7306_or__5025__auto__$jscomp$874$$=
typeof $value$jscomp$633$$==="string")?$APP.$cljs$core$re_matches$$(/^-?\d+(\.\d+)?$/,$value$jscomp$633$$):$JSCompiler_temp$jscomp$1300_and__5023__auto__$jscomp$inline_7306_or__5025__auto__$jscomp$874$$);return $JSCompiler_temp$jscomp$1300_and__5023__auto__$jscomp$inline_7306_or__5025__auto__$jscomp$874$$}(),$parsed_value$jscomp$1$$=$APP.$app$common$files$tokens$parse_token_value$$($value$jscomp$633$$),$out_of_bounds$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($parsed_value$jscomp$1$$)>=
2147483647||$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($parsed_value$jscomp$1$$)<=-2147483648;if($APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($parsed_value$jscomp$1$$)){var $and__5023__auto____$1$jscomp$95$$=!$out_of_bounds$$;return $and__5023__auto____$1$jscomp$95$$?$number_QMARK_$$:$and__5023__auto____$1$jscomp$95$$}return $parsed_value$jscomp$1$$}()))return $parsed_value$jscomp$1$$;if($out_of_bounds$$)return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4585$error_DOT_token_SLASH_number_too_large$$,$value$jscomp$633$$)],null)],null);if($APP.$cljs$core$seq$$($APP.$app$common$types$token$find_token_value_references$$($value$jscomp$633$$))){var $references$jscomp$3$$=$APP.$cljs$core$seq$$($APP.$app$common$types$token$find_token_value_references$$($value$jscomp$633$$));return new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$references$jscomp$3$$)],null),$cljs$cst$4619$references$$,$references$jscomp$3$$],null)}return $APP.$cljs$core$truth_$$($app$main$data$style_dictionary$with_units$$($value$jscomp$633$$))?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4584$error_DOT_style_dictionary_SLASH_value_with_units$$,$value$jscomp$633$$)],null)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4581$error_DOT_style_dictionary_SLASH_invalid_token_value$$,
$value$jscomp$633$$)],null)],null)};
$app$main$data$style_dictionary$parse_sd_token_general_value$$=function($value$jscomp$634$$){var $parsed_value$jscomp$2_temp__5823__auto__$jscomp$193$$=$APP.$app$common$files$tokens$parse_token_value$$($value$jscomp$634$$),$out_of_bounds$jscomp$1$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($parsed_value$jscomp$2_temp__5823__auto__$jscomp$193$$)>=2147483647||$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($parsed_value$jscomp$2_temp__5823__auto__$jscomp$193$$)<=-2147483648;
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($parsed_value$jscomp$2_temp__5823__auto__$jscomp$193$$)?!$out_of_bounds$jscomp$1$$:$parsed_value$jscomp$2_temp__5823__auto__$jscomp$193$$)?$parsed_value$jscomp$2_temp__5823__auto__$jscomp$193$$:$out_of_bounds$jscomp$1$$?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4585$error_DOT_token_SLASH_number_too_large$$,
$value$jscomp$634$$)],null)],null):($parsed_value$jscomp$2_temp__5823__auto__$jscomp$193$$=$APP.$cljs$core$seq$$($APP.$app$common$types$token$find_token_value_references$$($value$jscomp$634$$)))?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,
$parsed_value$jscomp$2_temp__5823__auto__$jscomp$193$$)],null),$cljs$cst$4619$references$$,$parsed_value$jscomp$2_temp__5823__auto__$jscomp$193$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4581$error_DOT_style_dictionary_SLASH_invalid_token_value$$,$value$jscomp$634$$)],null)],null)};
$app$main$data$style_dictionary$parse_sd_token_typography_line_height$$=function($line_height_value$jscomp$1$$,$font_size_value$jscomp$1$$,$font_size_errors_or__5025__auto__$jscomp$875_or__5025__auto____$1$jscomp$100$$){var $missing_references$jscomp$1$$=$APP.$cljs$core$seq$$($APP.$app$common$types$token$find_token_value_references$$($line_height_value$jscomp$1$$));$font_size_errors_or__5025__auto__$jscomp$875_or__5025__auto____$1$jscomp$100$$=$missing_references$jscomp$1$$?new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$missing_references$jscomp$1$$)],null),$cljs$cst$4619$references$$,$missing_references$jscomp$1$$],null):$APP.$cljs$core$not$$($font_size_value$jscomp$1$$)||$APP.$cljs$core$seq$$($font_size_errors_or__5025__auto__$jscomp$875_or__5025__auto____$1$jscomp$100$$)?
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4588$error_DOT_style_dictionary_SLASH_composite_line_height_needs_font_size$$,$font_size_value$jscomp$1$$)],null),$cljs$cst$4620$font_size_value$$,$font_size_value$jscomp$1$$],null):null;if($APP.$cljs$core$truth_$$($font_size_errors_or__5025__auto__$jscomp$875_or__5025__auto____$1$jscomp$100$$))return $font_size_errors_or__5025__auto__$jscomp$875_or__5025__auto____$1$jscomp$100$$;
$font_size_errors_or__5025__auto__$jscomp$875_or__5025__auto____$1$jscomp$100$$=function(){try{var $temp__5825__auto__$jscomp$231$$=$APP.$app$common$files$tokens$parse_token_value$$($line_height_value$jscomp$1$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$231$$)){var $map__71926__$1$$=$APP.$cljs$core$__destructure_map$$($temp__5825__auto__$jscomp$231$$),$unit$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71926__$1$$,$APP.$cljs$cst$4574$unit$$),$value$jscomp$641$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71926__$1$$,$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("%",$unit$jscomp$6$$)?$value$jscomp$641$$/100:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("px",$unit$jscomp$6$$)?$value$jscomp$641$$/$font_size_value$jscomp$1$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$unit$jscomp$6$$)?$value$jscomp$641$$:null}return null}catch($e71925$$){return null}}();return $APP.$cljs$core$truth_$$($font_size_errors_or__5025__auto__$jscomp$875_or__5025__auto____$1$jscomp$100$$)?
$font_size_errors_or__5025__auto__$jscomp$875_or__5025__auto____$1$jscomp$100$$:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4581$error_DOT_style_dictionary_SLASH_invalid_token_value$$,$line_height_value$jscomp$1$$)],null)],null)};
$app$main$data$style_dictionary$parse_atomic_typography_value$$=function($normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$,$token_value$jscomp$4_value__$1$jscomp$inline_7309$$){switch($normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$ instanceof
$APP.$cljs$core$Keyword$$?$normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$.$fqn$:null){case "font-size":return $app$main$data$style_dictionary$parse_sd_token_general_value$$($token_value$jscomp$4_value__$1$jscomp$inline_7309$$);case "font-family":$token_value$jscomp$4_value__$1$jscomp$inline_7309$$=$APP.$cljs$core$flatten$$($APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($token_value$jscomp$4_value__$1$jscomp$inline_7309$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!1])));$normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$=typeof $token_value$jscomp$4_value__$1$jscomp$inline_7309$$==="string"||$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$string_QMARK_$$,$token_value$jscomp$4_value__$1$jscomp$inline_7309$$);
var $missing_references$jscomp$inline_7311_references$jscomp$inline_7315_references$jscomp$inline_7327_valid_QMARK_$jscomp$inline_7322$$=$APP.$cljs$core$seq$$($APP.$cljs$core$some$$($APP.$app$common$types$token$find_token_value_references$$,$token_value$jscomp$4_value__$1$jscomp$inline_7309$$));return $normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$?
$missing_references$jscomp$inline_7311_references$jscomp$inline_7315_references$jscomp$inline_7327_valid_QMARK_$jscomp$inline_7322$$?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$missing_references$jscomp$inline_7311_references$jscomp$inline_7315_references$jscomp$inline_7327_valid_QMARK_$jscomp$inline_7322$$)],
null),$cljs$cst$4619$references$$,$missing_references$jscomp$inline_7311_references$jscomp$inline_7315_references$jscomp$inline_7327_valid_QMARK_$jscomp$inline_7322$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$token_value$jscomp$4_value__$1$jscomp$inline_7309$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4578$error_DOT_style_dictionary_SLASH_invalid_token_value_font_family$$,
$token_value$jscomp$4_value__$1$jscomp$inline_7309$$)],null)],null);case "font-weight":return $normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$=$app$common$types$token$valid_font_weight_variant$$($token_value$jscomp$4_value__$1$jscomp$inline_7309$$),$missing_references$jscomp$inline_7311_references$jscomp$inline_7315_references$jscomp$inline_7327_valid_QMARK_$jscomp$inline_7322$$=
$APP.$cljs$core$seq$$($APP.$app$common$types$token$find_token_value_references$$($token_value$jscomp$4_value__$1$jscomp$inline_7309$$)),$APP.$cljs$core$truth_$$($normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$token_value$jscomp$4_value__$1$jscomp$inline_7309$$],null):
$missing_references$jscomp$inline_7311_references$jscomp$inline_7315_references$jscomp$inline_7327_valid_QMARK_$jscomp$inline_7322$$?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$missing_references$jscomp$inline_7311_references$jscomp$inline_7315_references$jscomp$inline_7327_valid_QMARK_$jscomp$inline_7322$$)],
null),$cljs$cst$4619$references$$,$missing_references$jscomp$inline_7311_references$jscomp$inline_7315_references$jscomp$inline_7327_valid_QMARK_$jscomp$inline_7322$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4576$error_DOT_style_dictionary_SLASH_invalid_token_value_font_weight$$,$token_value$jscomp$4_value__$1$jscomp$inline_7309$$)],
null)],null);case "letter-spacing":return $normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$=$app$main$data$style_dictionary$parse_sd_token_general_value$$($token_value$jscomp$4_value__$1$jscomp$inline_7309$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4574$unit$$.$cljs$core$IFn$_invoke$arity$1$($normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$),
"%")?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4580$error_DOT_style_dictionary_SLASH_value_with_percent$$,$token_value$jscomp$4_value__$1$jscomp$inline_7309$$)],null)],null):$normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$;
case "text-case":$normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$=$APP.$cuerdas$core$lower$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($token_value$jscomp$4_value__$1$jscomp$inline_7309$$));$missing_references$jscomp$inline_7311_references$jscomp$inline_7315_references$jscomp$inline_7327_valid_QMARK_$jscomp$inline_7322$$=$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,["none",null,"lowercase",null,"capitalize",null,"uppercase",null],null),null),$normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$);var $references$jscomp$inline_7323$$=$APP.$cljs$core$seq$$($APP.$app$common$types$token$find_token_value_references$$($token_value$jscomp$4_value__$1$jscomp$inline_7309$$));
return $missing_references$jscomp$inline_7311_references$jscomp$inline_7315_references$jscomp$inline_7327_valid_QMARK_$jscomp$inline_7322$$?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$],null):$references$jscomp$inline_7323$$?new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$references$jscomp$inline_7323$$)],null),$cljs$cst$4619$references$$,$references$jscomp$inline_7323$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4597$error_DOT_style_dictionary_SLASH_invalid_token_value_text_case$$,$token_value$jscomp$4_value__$1$jscomp$inline_7309$$)],null)],null);case "text-decoration":return $normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$=$app$common$types$token$valid_text_decoration$$($token_value$jscomp$4_value__$1$jscomp$inline_7309$$),
$missing_references$jscomp$inline_7311_references$jscomp$inline_7315_references$jscomp$inline_7327_valid_QMARK_$jscomp$inline_7322$$=$APP.$cljs$core$seq$$($APP.$app$common$types$token$find_token_value_references$$($token_value$jscomp$4_value__$1$jscomp$inline_7309$$)),$APP.$cljs$core$truth_$$($normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$)?
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$normalized_value$jscomp$inline_7321_parsed_value$jscomp$inline_7318_token_type$jscomp$5_valid_font_family$jscomp$inline_7310_valid_font_weight$jscomp$inline_7314_valid_text_decoration$jscomp$inline_7326$$],null):$missing_references$jscomp$inline_7311_references$jscomp$inline_7315_references$jscomp$inline_7327_valid_QMARK_$jscomp$inline_7322$$?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$missing_references$jscomp$inline_7311_references$jscomp$inline_7315_references$jscomp$inline_7327_valid_QMARK_$jscomp$inline_7322$$)],null),$cljs$cst$4619$references$$,$missing_references$jscomp$inline_7311_references$jscomp$inline_7315_references$jscomp$inline_7327_valid_QMARK_$jscomp$inline_7322$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4598$error_DOT_style_dictionary_SLASH_invalid_token_value_text_decoration$$,$token_value$jscomp$4_value__$1$jscomp$inline_7309$$)],null)],null);default:return null}};
$app$main$data$style_dictionary$parse_composite_typography_value$$=function($line_height$jscomp$16_value$jscomp$643_without_line_height$$){var $missing_references$jscomp$3$$=typeof $line_height$jscomp$16_value$jscomp$643_without_line_height$$==="string"?$APP.$cljs$core$seq$$($APP.$app$common$types$token$find_token_value_references$$($line_height$jscomp$16_value$jscomp$643_without_line_height$$)):null;if($APP.$cljs$core$truth_$$($missing_references$jscomp$3$$))return new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$missing_references$jscomp$3$$)],null),$cljs$cst$4619$references$$,$missing_references$jscomp$3$$],null);if(typeof $line_height$jscomp$16_value$jscomp$643_without_line_height$$==="string")return new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4599$error_DOT_style_dictionary_SLASH_invalid_token_value_typography$$,$line_height$jscomp$16_value$jscomp$643_without_line_height$$)],null)],null);var $converted$$=$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($line_height$jscomp$16_value$jscomp$643_without_line_height$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,
!0]));if($APP.$cljs$core$map_QMARK_$$($converted$$)){var $add_keyed_errors$$=function($typography_map$$,$k$jscomp$655$$,$errors$jscomp$20$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($typography_map$$,$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$concat$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71932_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__71932_SHARP_$$,$APP.$cljs$cst$4621$typography_key$$,$k$jscomp$655$$)},$errors$jscomp$20$$))};
$line_height$jscomp$16_value$jscomp$643_without_line_height$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($converted$$,$APP.$cljs$cst$1765$line_height$$);var $valid_typography$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$135$$,$p__71936_v$jscomp$617$$){var $k$jscomp$656$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71936_v$jscomp$617$$,0,null);$p__71936_v$jscomp$617$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71936_v$jscomp$617$$,
1,null);var $errors$jscomp$21_map__71940$$=$app$main$data$style_dictionary$parse_atomic_typography_value$$($k$jscomp$656$$,$p__71936_v$jscomp$617$$),$map__71940__$1_value__$1$jscomp$24$$=$APP.$cljs$core$__destructure_map$$($errors$jscomp$21_map__71940$$);$errors$jscomp$21_map__71940$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71940__$1_value__$1$jscomp$24$$,$APP.$cljs$cst$570$errors$$);$map__71940__$1_value__$1$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71940__$1_value__$1$jscomp$24$$,
$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$seq$$($errors$jscomp$21_map__71940$$)?$add_keyed_errors$$($acc$jscomp$135$$,$k$jscomp$656$$,$errors$jscomp$21_map__71940$$):$APP.$cljs$core$assoc_in$$($acc$jscomp$135$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$k$jscomp$656$$],null),$APP.$cljs$core$truth_$$($map__71940__$1_value__$1$jscomp$24$$)?$map__71940__$1_value__$1$jscomp$24$$:$p__71936_v$jscomp$617$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$260$value$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null),$line_height$jscomp$16_value$jscomp$643_without_line_height$$);$line_height$jscomp$16_value$jscomp$643_without_line_height$$=function(){var $temp__5825__auto__$jscomp$232$$=$APP.$cljs$cst$1765$line_height$$.$cljs$core$IFn$_invoke$arity$1$($converted$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$232$$)?$app$main$data$style_dictionary$parse_sd_token_typography_line_height$$($temp__5825__auto__$jscomp$232$$,
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($valid_typography$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1760$font_size$$],null)),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($valid_typography$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$1760$font_size$$],null))):null}();return $APP.$cljs$core$truth_$$($APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($line_height$jscomp$16_value$jscomp$643_without_line_height$$))?
$add_keyed_errors$$($valid_typography$$,$APP.$cljs$cst$1765$line_height$$,$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($line_height$jscomp$16_value$jscomp$643_without_line_height$$)):$APP.$cljs$core$truth_$$($line_height$jscomp$16_value$jscomp$643_without_line_height$$)?$APP.$cljs$core$assoc_in$$($valid_typography$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1765$line_height$$],null),$line_height$jscomp$16_value$jscomp$643_without_line_height$$):
$valid_typography$$}return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4599$error_DOT_style_dictionary_SLASH_invalid_token_value_typography$$,$line_height$jscomp$16_value$jscomp$643_without_line_height$$)],null)],null)};
$app$main$data$style_dictionary$parse_sd_token_shadow_inset$$=function($value$jscomp$644$$){var $references$jscomp$9$$=$APP.$cljs$core$seq$$($APP.$app$common$types$token$find_token_value_references$$($value$jscomp$644$$));return $APP.$cljs$core$boolean_QMARK_$$($value$jscomp$644$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$value$jscomp$644$$],null):$references$jscomp$9$$?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$references$jscomp$9$$)],null),$cljs$cst$4619$references$$,$references$jscomp$9$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4592$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_type$$,
$value$jscomp$644$$)],null)],null)};
$app$main$data$style_dictionary$parse_sd_token_shadow_blur$$=function($value$jscomp$645$$){var $parsed$jscomp$2$$=$app$main$data$style_dictionary$parse_sd_token_general_value$$($value$jscomp$645$$);var $and__5023__auto__$jscomp$inline_7329_valid_QMARK_$jscomp$10$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($parsed$jscomp$2$$);$and__5023__auto__$jscomp$inline_7329_valid_QMARK_$jscomp$10$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_7329_valid_QMARK_$jscomp$10$$)?$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($parsed$jscomp$2$$)>=
0:$and__5023__auto__$jscomp$inline_7329_valid_QMARK_$jscomp$10$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_7329_valid_QMARK_$jscomp$10$$)?$parsed$jscomp$2$$:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4594$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_blur$$,$value$jscomp$645$$)],
null)],null)};
$app$main$data$style_dictionary$parse_sd_token_shadow_spread$$=function($value$jscomp$646$$){var $parsed$jscomp$3$$=$app$main$data$style_dictionary$parse_sd_token_general_value$$($value$jscomp$646$$),$valid_QMARK_$jscomp$11$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($parsed$jscomp$3$$);return $APP.$cljs$core$truth_$$($valid_QMARK_$jscomp$11$$)?$parsed$jscomp$3$$:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4582$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_spread$$,$value$jscomp$646$$)],null)],null)};
$app$main$data$style_dictionary$parse_single_shadow$$=function($shadow_map_shadow_map__$1$$,$shadow_index$$){function $add_keyed_errors$jscomp$1$$($shadow_result$$,$k$jscomp$657$$,$errors$jscomp$22$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shadow_result$$,$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$concat$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71948_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__71948_SHARP_$$,
$APP.$cljs$cst$4622$shadow_key$$,$k$jscomp$657$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4623$shadow_index$$,$shadow_index$$]))},$errors$jscomp$22$$))}$shadow_map_shadow_map__$1$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1650$offset_x$$,null,$APP.$cljs$cst$1651$offset_y$$,null,$APP.$cljs$cst$1653$blur$$,null,$APP.$cljs$cst$1652$spread$$,
null,$APP.$cljs$cst$1298$color$$,null,$APP.$cljs$cst$2133$inset$$,!1],null),$shadow_map_shadow_map__$1$$]));var $parsers$jscomp$5$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1650$offset_x$$,$app$main$data$style_dictionary$parse_sd_token_general_value$$,$APP.$cljs$cst$1651$offset_y$$,$app$main$data$style_dictionary$parse_sd_token_general_value$$,$APP.$cljs$cst$1653$blur$$,$app$main$data$style_dictionary$parse_sd_token_shadow_blur$$,$APP.$cljs$cst$1652$spread$$,$app$main$data$style_dictionary$parse_sd_token_shadow_spread$$,
$APP.$cljs$cst$1298$color$$,$app$main$data$style_dictionary$parse_sd_token_color_value$$,$APP.$cljs$cst$2133$inset$$,$app$main$data$style_dictionary$parse_sd_token_shadow_inset$$],null);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$136$$,$p__71953_v$jscomp$618$$){var $k$jscomp$658$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71953_v$jscomp$618$$,0,null);$p__71953_v$jscomp$618$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71953_v$jscomp$618$$,
1,null);var $errors$jscomp$23_map__71957_temp__5823__auto__$jscomp$194$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($parsers$jscomp$5$$,$k$jscomp$658$$);if($APP.$cljs$core$truth_$$($errors$jscomp$23_map__71957_temp__5823__auto__$jscomp$194$$)){$errors$jscomp$23_map__71957_temp__5823__auto__$jscomp$194$$=$errors$jscomp$23_map__71957_temp__5823__auto__$jscomp$194$$.$cljs$core$IFn$_invoke$arity$1$?$errors$jscomp$23_map__71957_temp__5823__auto__$jscomp$194$$.$cljs$core$IFn$_invoke$arity$1$($p__71953_v$jscomp$618$$):
$errors$jscomp$23_map__71957_temp__5823__auto__$jscomp$194$$($p__71953_v$jscomp$618$$);var $map__71957__$1_value$jscomp$647$$=$APP.$cljs$core$__destructure_map$$($errors$jscomp$23_map__71957_temp__5823__auto__$jscomp$194$$);$errors$jscomp$23_map__71957_temp__5823__auto__$jscomp$194$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71957__$1_value$jscomp$647$$,$APP.$cljs$cst$570$errors$$);$map__71957__$1_value$jscomp$647$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71957__$1_value$jscomp$647$$,
$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$seq$$($errors$jscomp$23_map__71957_temp__5823__auto__$jscomp$194$$)?$add_keyed_errors$jscomp$1$$($acc$jscomp$136$$,$k$jscomp$658$$,$errors$jscomp$23_map__71957_temp__5823__auto__$jscomp$194$$):$APP.$cljs$core$assoc_in$$($acc$jscomp$136$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$k$jscomp$658$$],null),$APP.$cljs$core$truth_$$($map__71957__$1_value$jscomp$647$$)?$map__71957__$1_value$jscomp$647$$:
$p__71953_v$jscomp$618$$)}return $acc$jscomp$136$$},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null),$shadow_map_shadow_map__$1$$)};
$app$main$data$style_dictionary$parse_sd_token_shadow_value$$=function($all_errors_converted$jscomp$1_value$jscomp$648$$){var $all_values_missing_references$jscomp$4_parsed_shadows$$=typeof $all_errors_converted$jscomp$1_value$jscomp$648$$==="string"?$APP.$cljs$core$seq$$($APP.$app$common$types$token$find_token_value_references$$($all_errors_converted$jscomp$1_value$jscomp$648$$)):null;if($APP.$cljs$core$truth_$$($all_values_missing_references$jscomp$4_parsed_shadows$$))return new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$all_values_missing_references$jscomp$4_parsed_shadows$$)],null),$cljs$cst$4619$references$$,$all_values_missing_references$jscomp$4_parsed_shadows$$],null);if(typeof $all_errors_converted$jscomp$1_value$jscomp$648$$==="string")return new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4577$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow$$,$all_errors_converted$jscomp$1_value$jscomp$648$$)],null)],null);if($all_errors_converted$jscomp$1_value$jscomp$648$$==null)return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($APP.$cljs$cst$4579$error_DOT_token_SLASH_empty_input$$)],null)],null);if($APP.$cljs$core$not$$(Array.isArray($all_errors_converted$jscomp$1_value$jscomp$648$$)))return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4581$error_DOT_style_dictionary_SLASH_invalid_token_value$$,
$all_errors_converted$jscomp$1_value$jscomp$648$$)],null)],null);$all_errors_converted$jscomp$1_value$jscomp$648$$=$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($all_errors_converted$jscomp$1_value$jscomp$648$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!0]));$all_values_missing_references$jscomp$4_parsed_shadows$$=$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($idx$jscomp$98$$,$shadow_map$jscomp$1$$){return $app$main$data$style_dictionary$parse_single_shadow$$($shadow_map$jscomp$1$$,
$idx$jscomp$98$$)},$all_errors_converted$jscomp$1_value$jscomp$648$$);$all_errors_converted$jscomp$1_value$jscomp$648$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$570$errors$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$all_values_missing_references$jscomp$4_parsed_shadows$$]));$all_values_missing_references$jscomp$4_parsed_shadows$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$260$value$$,
$all_values_missing_references$jscomp$4_parsed_shadows$$));return $APP.$cljs$core$seq$$($all_errors_converted$jscomp$1_value$jscomp$648$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$570$errors$$,$all_errors_converted$jscomp$1_value$jscomp$648$$,$APP.$cljs$cst$260$value$$,$all_values_missing_references$jscomp$4_parsed_shadows$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$all_values_missing_references$jscomp$4_parsed_shadows$$],null)};
$app$main$data$style_dictionary$process_sd_tokens$$=function($sd_tokens$$,$get_origin_token$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$137$$,$output_token_parsed_token_value_sd_token$$){var $origin_token$$=$get_origin_token$$.$cljs$core$IFn$_invoke$arity$1$?$get_origin_token$$.$cljs$core$IFn$_invoke$arity$1$($output_token_parsed_token_value_sd_token$$):$get_origin_token$$($output_token_parsed_token_value_sd_token$$),$value$jscomp$649$$=$output_token_parsed_token_value_sd_token$$.value;
$output_token_parsed_token_value_sd_token$$=function(){var $G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$=$app$main$data$style_dictionary$parse_atomic_typography_value$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($origin_token$$),$value$jscomp$649$$);if($APP.$cljs$core$truth_$$($G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$))return $G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$;
$G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($origin_token$$);switch($G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$ instanceof $APP.$cljs$core$Keyword$$?$G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$.$fqn$:
null){case "typography":return $app$main$data$style_dictionary$parse_composite_typography_value$$($value$jscomp$649$$);case "shadow":return $app$main$data$style_dictionary$parse_sd_token_shadow_value$$($value$jscomp$649$$);case "color":return $app$main$data$style_dictionary$parse_sd_token_color_value$$($value$jscomp$649$$);case "opacity":$G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$=$APP.$cljs$core$seq$$($APP.$app$common$types$token$find_token_value_references$$($value$jscomp$649$$));
var $parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$=$APP.$app$common$files$tokens$parse_token_value$$($value$jscomp$649$$),$out_of_scope$jscomp$inline_12894_out_of_scope$jscomp$inline_12900$$=!(0<=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$)&&$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$)<=1),$references$jscomp$inline_12895$$=
$APP.$cljs$core$seq$$($APP.$app$common$types$token$find_token_value_references$$($value$jscomp$649$$));return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$)?!$out_of_scope$jscomp$inline_12894_out_of_scope$jscomp$inline_12900$$:$parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$)?$parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$:$references$jscomp$inline_12895$$?new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$references$jscomp$inline_12895$$)],null),$cljs$cst$4619$references$$,$references$jscomp$inline_12895$$],null):$APP.$cljs$core$not$$($G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$)&&
$out_of_scope$jscomp$inline_12894_out_of_scope$jscomp$inline_12900$$?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4590$error_DOT_style_dictionary_SLASH_invalid_token_value_opacity$$,$value$jscomp$649$$)],null)],null):$APP.$cljs$core$truth_$$($G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$?
$out_of_scope$jscomp$inline_12894_out_of_scope$jscomp$inline_12900$$?$parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$:$out_of_scope$jscomp$inline_12894_out_of_scope$jscomp$inline_12900$$:$G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$,$cljs$cst$4617$warnings$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$main$data$workspace$tokens$warnings$warning_with_value$$($cljs$cst$4606$warning_DOT_style_dictionary_SLASH_invalid_referenced_token_value_opacity$$,$value$jscomp$649$$)],null)):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4581$error_DOT_style_dictionary_SLASH_invalid_token_value$$,
$value$jscomp$649$$)],null)],null);case "stroke-width":return $G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$=$APP.$cljs$core$seq$$($APP.$app$common$types$token$find_token_value_references$$($value$jscomp$649$$)),$parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$=$APP.$app$common$files$tokens$parse_token_value$$($value$jscomp$649$$),$out_of_scope$jscomp$inline_12894_out_of_scope$jscomp$inline_12900$$=
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$)<0,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$)?!$out_of_scope$jscomp$inline_12894_out_of_scope$jscomp$inline_12900$$:$parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$)?$parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$:$G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$?
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$)],null),$cljs$cst$4619$references$$,$G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$],
null):$APP.$cljs$core$not$$($G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$)&&$out_of_scope$jscomp$inline_12894_out_of_scope$jscomp$inline_12900$$?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($cljs$cst$4596$error_DOT_style_dictionary_SLASH_invalid_token_value_stroke_width$$,
$value$jscomp$649$$)],null)],null):$APP.$cljs$core$truth_$$($G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$?$out_of_scope$jscomp$inline_12894_out_of_scope$jscomp$inline_12900$$?$parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$:$out_of_scope$jscomp$inline_12894_out_of_scope$jscomp$inline_12900$$:$G__71959_missing_references_QMARK_$jscomp$inline_12892_missing_references_QMARK_$jscomp$inline_12898_or__5025__auto__$jscomp$878$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parsed_value$jscomp$inline_12893_parsed_value$jscomp$inline_12899$$,$cljs$cst$4617$warnings$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$main$data$workspace$tokens$warnings$warning_with_value$$($cljs$cst$4609$warning_DOT_style_dictionary_SLASH_invalid_referenced_token_value_stroke_width$$,$value$jscomp$649$$)],null)):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4581$error_DOT_style_dictionary_SLASH_invalid_token_value$$,$value$jscomp$649$$)],null)],null);case "number":return $app$main$data$style_dictionary$parse_sd_token_number_value$$($value$jscomp$649$$);default:return $app$main$data$style_dictionary$parse_sd_token_general_value$$($value$jscomp$649$$)}}();$output_token_parsed_token_value_sd_token$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($output_token_parsed_token_value_sd_token$$))?$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$origin_token$$,$output_token_parsed_token_value_sd_token$$])):$APP.$cljs$core$truth_$$($cljs$cst$4617$warnings$$.$cljs$core$IFn$_invoke$arity$1$($output_token_parsed_token_value_sd_token$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($origin_token$$,
$APP.$cljs$cst$4605$resolved_value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($output_token_parsed_token_value_sd_token$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$4617$warnings$$,$cljs$cst$4617$warnings$$.$cljs$core$IFn$_invoke$arity$1$($output_token_parsed_token_value_sd_token$$),$APP.$cljs$cst$4574$unit$$,$APP.$cljs$cst$4574$unit$$.$cljs$core$IFn$_invoke$arity$1$($output_token_parsed_token_value_sd_token$$)])):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($origin_token$$,
$APP.$cljs$cst$4605$resolved_value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($output_token_parsed_token_value_sd_token$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4574$unit$$,$APP.$cljs$cst$4574$unit$$.$cljs$core$IFn$_invoke$arity$1$($output_token_parsed_token_value_sd_token$$)]));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$137$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($output_token_parsed_token_value_sd_token$$),
$output_token_parsed_token_value_sd_token$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$sd_tokens$$)};
$app$main$data$style_dictionary$add_tokens$$=function($JSCompiler_temp$jscomp$1306__$jscomp$2607$$,$tokens$jscomp$27$$){if($JSCompiler_temp$jscomp$1306__$jscomp$2607$$!=null&&$JSCompiler_temp$jscomp$1306__$jscomp$2607$$.$app$main$data$style_dictionary$IStyleDictionary$add_tokens$arity$2$!=null)$JSCompiler_temp$jscomp$1306__$jscomp$2607$$=$JSCompiler_temp$jscomp$1306__$jscomp$2607$$.$app$main$data$style_dictionary$IStyleDictionary$add_tokens$arity$2$($JSCompiler_temp$jscomp$1306__$jscomp$2607$$,$tokens$jscomp$27$$);
else{var $m__5372__auto__$jscomp$inline_7334_m__5374__auto__$jscomp$inline_7333$$=$app$main$data$style_dictionary$add_tokens$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1306__$jscomp$2607$$==null?null:$JSCompiler_temp$jscomp$1306__$jscomp$2607$$)];if($m__5372__auto__$jscomp$inline_7334_m__5374__auto__$jscomp$inline_7333$$!=null)$JSCompiler_temp$jscomp$1306__$jscomp$2607$$=$m__5372__auto__$jscomp$inline_7334_m__5374__auto__$jscomp$inline_7333$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_7334_m__5374__auto__$jscomp$inline_7333$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1306__$jscomp$2607$$,
$tokens$jscomp$27$$):$m__5372__auto__$jscomp$inline_7334_m__5374__auto__$jscomp$inline_7333$$($JSCompiler_temp$jscomp$1306__$jscomp$2607$$,$tokens$jscomp$27$$);else if($m__5372__auto__$jscomp$inline_7334_m__5374__auto__$jscomp$inline_7333$$=$app$main$data$style_dictionary$add_tokens$$._,$m__5372__auto__$jscomp$inline_7334_m__5374__auto__$jscomp$inline_7333$$!=null)$JSCompiler_temp$jscomp$1306__$jscomp$2607$$=$m__5372__auto__$jscomp$inline_7334_m__5374__auto__$jscomp$inline_7333$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_7334_m__5374__auto__$jscomp$inline_7333$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1306__$jscomp$2607$$,$tokens$jscomp$27$$):$m__5372__auto__$jscomp$inline_7334_m__5374__auto__$jscomp$inline_7333$$($JSCompiler_temp$jscomp$1306__$jscomp$2607$$,$tokens$jscomp$27$$);else throw $APP.$cljs$core$missing_protocol$$("IStyleDictionary.add-tokens",$JSCompiler_temp$jscomp$1306__$jscomp$2607$$);}return $JSCompiler_temp$jscomp$1306__$jscomp$2607$$};
$app$main$data$style_dictionary$build_dictionary$$=function($JSCompiler_temp$jscomp$1307__$jscomp$2613$$){if($JSCompiler_temp$jscomp$1307__$jscomp$2613$$!=null&&$JSCompiler_temp$jscomp$1307__$jscomp$2613$$.$app$main$data$style_dictionary$IStyleDictionary$build_dictionary$arity$1$!=null)$JSCompiler_temp$jscomp$1307__$jscomp$2613$$=$JSCompiler_temp$jscomp$1307__$jscomp$2613$$.$app$main$data$style_dictionary$IStyleDictionary$build_dictionary$arity$1$($JSCompiler_temp$jscomp$1307__$jscomp$2613$$);else{var $m__5372__auto__$jscomp$inline_7338_m__5374__auto__$jscomp$inline_7337$$=
$app$main$data$style_dictionary$build_dictionary$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1307__$jscomp$2613$$==null?null:$JSCompiler_temp$jscomp$1307__$jscomp$2613$$)];if($m__5372__auto__$jscomp$inline_7338_m__5374__auto__$jscomp$inline_7337$$!=null)$JSCompiler_temp$jscomp$1307__$jscomp$2613$$=$m__5372__auto__$jscomp$inline_7338_m__5374__auto__$jscomp$inline_7337$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_7338_m__5374__auto__$jscomp$inline_7337$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1307__$jscomp$2613$$):
$m__5372__auto__$jscomp$inline_7338_m__5374__auto__$jscomp$inline_7337$$($JSCompiler_temp$jscomp$1307__$jscomp$2613$$);else if($m__5372__auto__$jscomp$inline_7338_m__5374__auto__$jscomp$inline_7337$$=$app$main$data$style_dictionary$build_dictionary$$._,$m__5372__auto__$jscomp$inline_7338_m__5374__auto__$jscomp$inline_7337$$!=null)$JSCompiler_temp$jscomp$1307__$jscomp$2613$$=$m__5372__auto__$jscomp$inline_7338_m__5374__auto__$jscomp$inline_7337$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_7338_m__5374__auto__$jscomp$inline_7337$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1307__$jscomp$2613$$):
$m__5372__auto__$jscomp$inline_7338_m__5374__auto__$jscomp$inline_7337$$($JSCompiler_temp$jscomp$1307__$jscomp$2613$$);else throw $APP.$cljs$core$missing_protocol$$("IStyleDictionary.build-dictionary",$JSCompiler_temp$jscomp$1307__$jscomp$2613$$);}return $JSCompiler_temp$jscomp$1307__$jscomp$2613$$};$APP.$app$main$data$style_dictionary$StyleDictionary$$=function($config$jscomp$15$$){this.config=$config$jscomp$15$$};
$app$main$data$style_dictionary$resolve_tokens_tree$cljs$0core$0IFn$0_invoke$0arity$02$$=function($tokens_tree$jscomp$5$$,$get_token$$){return $APP.$app$main$data$style_dictionary$resolve_tokens_tree$cljs$0core$0IFn$0_invoke$0arity$03$$($tokens_tree$jscomp$5$$,$get_token$$,new $APP.$app$main$data$style_dictionary$StyleDictionary$$($APP.$app$main$data$style_dictionary$default_config$$))};
$APP.$app$main$data$style_dictionary$resolve_tokens_tree$cljs$0core$0IFn$0_invoke$0arity$03$$=function($tokens_tree$jscomp$6$$,$get_token$jscomp$1$$,$style_dictionary$$){return $APP.$beicon$v2$core$map$$(function($p1__71978_SHARP_$$){return $app$main$data$style_dictionary$process_sd_tokens$$($p1__71978_SHARP_$$,$get_token$jscomp$1$$)},$app$main$data$style_dictionary$build_dictionary$$($app$main$data$style_dictionary$add_tokens$$($style_dictionary$$,$tokens_tree$jscomp$6$$)))};
$app$main$data$style_dictionary$merge_name_collisions$$=function($dropped_tokens$jscomp$29$$,$resolved$jscomp$1$$){$dropped_tokens$jscomp$29$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__71986_token$jscomp$78$$){var $k$jscomp$659$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71986_token$jscomp$78$$,0,null);$p__71986_token$jscomp$78$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71986_token$jscomp$78$$,
1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$659$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p__71986_token$jscomp$78$$,$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4593$error_DOT_token_SLASH_name_collision$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p__71986_token$jscomp$78$$))],
null))],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p__71990$$){var $k$jscomp$660$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71990$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71990$$,1,null);return $APP.$cljs$core$contains_QMARK_$$($resolved$jscomp$1$$,$k$jscomp$660$$)},$dropped_tokens$jscomp$29$$)));return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$resolved$jscomp$1$$,
$dropped_tokens$jscomp$29$$]))};
$app$main$data$style_dictionary$resolve_tokens$$=function($tokens$jscomp$30$$){var $tokens_tree$jscomp$7$$=$APP.$app$common$types$tokens_lib$tokens_tree$$($tokens$jscomp$30$$);return $APP.$beicon$v2$core$map$$(function($p1__71995_SHARP_$$){return $app$main$data$style_dictionary$merge_name_collisions$$($tokens$jscomp$30$$,$p1__71995_SHARP_$$)},$app$main$data$style_dictionary$resolve_tokens_tree$cljs$0core$0IFn$0_invoke$0arity$02$$($tokens_tree$jscomp$7$$,function($p1__71994_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tokens$jscomp$30$$,$p1__71994_SHARP_$$.original.name)}))};
$APP.$app$main$data$style_dictionary$resolve_tokens_interactive$$=function($tokens$jscomp$31$$){var $map__72000_map__72000__$1$$=$app$common$types$tokens_lib$backtrace_tokens_tree$$($tokens$jscomp$31$$);$map__72000_map__72000__$1$$=$APP.$cljs$core$__destructure_map$$($map__72000_map__72000__$1$$);var $tokens_tree$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72000_map__72000__$1$$,$cljs$cst$2104$tokens_tree$$),$ids$jscomp$255$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72000_map__72000__$1$$,
$APP.$cljs$cst$1723$ids$$);return $APP.$beicon$v2$core$map$$(function($p1__71998_SHARP_$$){return $app$main$data$style_dictionary$merge_name_collisions$$($tokens$jscomp$31$$,$p1__71998_SHARP_$$)},$app$main$data$style_dictionary$resolve_tokens_tree$cljs$0core$0IFn$0_invoke$0arity$02$$($tokens_tree$jscomp$8$$,function($p1__71997_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$255$$,$APP.$cljs$core$uuid$$($p1__71997_SHARP_$$.original.id.uuid))}))};
$APP.$app$main$data$style_dictionary$use_resolved_tokens_STAR_$$=function($var_args$jscomp$1347$$){for(var $args__5755__auto__$jscomp$236$$=[],$len__5749__auto___72095$$=arguments.length,$i__5750__auto___72096$$=0;;)if($i__5750__auto___72096$$<$len__5749__auto___72095$$)$args__5755__auto__$jscomp$236$$.push(arguments[$i__5750__auto___72096$$]),$i__5750__auto___72096$$+=1;else break;return $app$main$data$style_dictionary$use_resolved_tokens_STAR_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
1<$args__5755__auto__$jscomp$236$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$236$$.slice(1),0,null):null)};
$app$main$data$style_dictionary$use_resolved_tokens_STAR_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($tokens$jscomp$34$$,$map__72021__$1_p__72020$$){$map__72021__$1_p__72020$$=$APP.$cljs$core$__destructure_map$$($map__72021__$1_p__72020$$);var $interactive_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72021__$1_p__72020$$,$cljs$cst$4626$interactive_QMARK_$$),$state_STAR_$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($tokens$jscomp$34$$);
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens$jscomp$34$$),$APP.$rumext$v2$adapt$$($interactive_QMARK_$jscomp$1$$)],function(){if($APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$))return null;if($APP.$cljs$core$seq$$($tokens$jscomp$34$$)){var $tpoint$jscomp$2$$=$app$common$time$tpoint_ms$$(),$tokens_s$$=$APP.$cljs$core$truth_$$($interactive_QMARK_$jscomp$1$$)?$APP.$app$main$data$style_dictionary$resolve_tokens_interactive$$($tokens$jscomp$34$$):
$app$main$data$style_dictionary$resolve_tokens$$($tokens$jscomp$34$$);return $APP.$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($tokens_s$$,function($resolved_tokens$jscomp$1$$){var $elapsed$jscomp$2$$=$tpoint$jscomp$2$$();$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.style-dictionary",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"use-resolved-tokens*"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2278$elapsed$$,$elapsed$jscomp$2$$],null)],null)}),null,"app.main.data.style-dictionary",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$reset_BANG_$$($state_STAR_$jscomp$4$$,$resolved_tokens$jscomp$1$$)})}return $APP.$cljs$core$reset_BANG_$$($state_STAR_$jscomp$4$$,
$tokens$jscomp$34$$)});return $APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?$APP.$app$main$data$tokenscript$resolve_tokens$$($tokens$jscomp$34$$):$APP.$cljs$core$_deref$$($state_STAR_$jscomp$4$$)};
$APP.$app$main$data$workspace$tokens$application$value__GT_color$$=function($color$jscomp$112_hex$jscomp$8$$){var $opacity$jscomp$38_temp__5825__auto__$jscomp$234$$=$APP.$app$main$data$tinycolor$valid_color$$($color$jscomp$112_hex$jscomp$8$$);return $APP.$cljs$core$truth_$$($opacity$jscomp$38_temp__5825__auto__$jscomp$234$$)?($color$jscomp$112_hex$jscomp$8$$=$APP.$app$main$data$tinycolor$__GT_hex_string$$($opacity$jscomp$38_temp__5825__auto__$jscomp$234$$),$opacity$jscomp$38_temp__5825__auto__$jscomp$234$$=
$APP.$app$main$data$tinycolor$alpha$$($opacity$jscomp$38_temp__5825__auto__$jscomp$234$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,$color$jscomp$112_hex$jscomp$8$$,$APP.$cljs$cst$1734$opacity$$,$opacity$jscomp$38_temp__5825__auto__$jscomp$234$$],null)):null};
$app$main$data$workspace$tokens$application$value__GT_shadow$$=function($value$jscomp$667$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($offset_x$jscomp$9_p__72307$$){var $inset_map__72308__$1$$=$APP.$cljs$core$__destructure_map$$($offset_x$jscomp$9_p__72307$$);$offset_x$jscomp$9_p__72307$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($inset_map__72308__$1$$,$APP.$cljs$cst$1650$offset_x$$);var $offset_y$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($inset_map__72308__$1$$,
$APP.$cljs$cst$1651$offset_y$$),$blur$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($inset_map__72308__$1$$,$APP.$cljs$cst$1653$blur$$),$spread$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($inset_map__72308__$1$$,$APP.$cljs$cst$1652$spread$$),$color$jscomp$115$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($inset_map__72308__$1$$,$APP.$cljs$cst$1298$color$$);$inset_map__72308__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($inset_map__72308__$1$$,
$APP.$cljs$cst$2133$inset$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$266$id$$,$cljs$core$random_uuid$$(),$APP.$cljs$cst$1620$hidden$$,!1,$APP.$cljs$cst$1650$offset_x$$,$offset_x$jscomp$9_p__72307$$,$APP.$cljs$cst$1651$offset_y$$,$offset_y$jscomp$9$$,$APP.$cljs$cst$1653$blur$$,$blur$jscomp$11$$,$APP.$cljs$cst$1298$color$$,$APP.$app$main$data$workspace$tokens$application$value__GT_color$$($color$jscomp$115$$),$APP.$cljs$cst$1652$spread$$,$spread$jscomp$7$$,$APP.$cljs$cst$1904$style$$,
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!0,$inset_map__72308__$1$$)?$cljs$cst$1907$inner_shadow$$:$APP.$cljs$cst$1905$drop_shadow$$],null)},$value$jscomp$667$$)};
$app$main$data$workspace$tokens$application$shape_ids_with_layout$$=function($state$jscomp$943$$,$page_id$jscomp$294$$,$shape_ids$jscomp$38$$){return $cljs$core$eduction$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$shape$layout$any_layout_QMARK_$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$app$main$data$helpers$lookup_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($state$jscomp$943$$,
$page_id$jscomp$294$$,$shape_ids$jscomp$38$$)]))};
$app$main$data$workspace$tokens$application$shape_ids_with_layout_parent$$=function($state$jscomp$944$$,$page_id$jscomp$295$$,$shape_ids$jscomp$39$$){var $objects$jscomp$673$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$944$$);return $cljs$core$eduction$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__72318_SHARP_$$){return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$673$$,$p1__72318_SHARP_$$)}),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$app$main$data$helpers$lookup_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($state$jscomp$944$$,$page_id$jscomp$295$$,$shape_ids$jscomp$39$$)]))};
$APP.$app$main$data$workspace$tokens$application$update_layout_gap$$=function($value$jscomp$683$$,$shape_ids$jscomp$49$$,$attributes$jscomp$37$$,$page_id$jscomp$302$$){typeof $app$main$data$workspace$tokens$application$update_layout_gap_72344$$==="undefined"&&($app$main$data$workspace$tokens$application$update_layout_gap_72344$$=function($value$jscomp$684$$,$shape_ids$jscomp$50$$,$attributes$jscomp$38$$,$page_id$jscomp$303$$,$meta72345$$){this.value=$value$jscomp$684$$;this.$shape_ids$=$shape_ids$jscomp$50$$;
this.attributes=$attributes$jscomp$38$$;this.$page_id$=$page_id$jscomp$303$$;this.$meta72345$=$meta72345$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$update_layout_gap_72344$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_layout_gap_72344$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4634$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_layout_gap$$},
$app$main$data$workspace$tokens$application$update_layout_gap_72344$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72346$$,$meta72345__$1$$){return new $app$main$data$workspace$tokens$application$update_layout_gap_72344$$(this.value,this.$shape_ids$,this.attributes,this.$page_id$,$meta72345__$1$$)},$app$main$data$workspace$tokens$application$update_layout_gap_72344$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72345$},$app$main$data$workspace$tokens$application$update_layout_gap_72344$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_layout_gap_72344$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_inline_result$jscomp$1310__$jscomp$2625_layout_gap$jscomp$inline_12904_or__5025__auto__$jscomp$inline_7344_value$jscomp$inline_12903$$,$ids_with_layout$jscomp$1_state$jscomp$948$$){return typeof this.value==="number"?($JSCompiler_inline_result$jscomp$1310__$jscomp$2625_layout_gap$jscomp$inline_12904_or__5025__auto__$jscomp$inline_7344_value$jscomp$inline_12903$$=
this.$page_id$,$JSCompiler_inline_result$jscomp$1310__$jscomp$2625_layout_gap$jscomp$inline_12904_or__5025__auto__$jscomp$inline_7344_value$jscomp$inline_12903$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1310__$jscomp$2625_layout_gap$jscomp$inline_12904_or__5025__auto__$jscomp$inline_7344_value$jscomp$inline_12903$$)?$JSCompiler_inline_result$jscomp$1310__$jscomp$2625_layout_gap$jscomp$inline_12904_or__5025__auto__$jscomp$inline_7344_value$jscomp$inline_12903$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($ids_with_layout$jscomp$1_state$jscomp$948$$),
$ids_with_layout$jscomp$1_state$jscomp$948$$=$app$main$data$workspace$tokens$application$shape_ids_with_layout$$($ids_with_layout$jscomp$1_state$jscomp$948$$,$JSCompiler_inline_result$jscomp$1310__$jscomp$2625_layout_gap$jscomp$inline_12904_or__5025__auto__$jscomp$inline_7344_value$jscomp$inline_12903$$,this.$shape_ids$),$JSCompiler_inline_result$jscomp$1310__$jscomp$2625_layout_gap$jscomp$inline_12904_or__5025__auto__$jscomp$inline_7344_value$jscomp$inline_12903$$=this.value,$JSCompiler_inline_result$jscomp$1310__$jscomp$2625_layout_gap$jscomp$inline_12904_or__5025__auto__$jscomp$inline_7344_value$jscomp$inline_12903$$=
$APP.$cljs$core$zipmap$$($APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$(this.attributes,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1682$column_gap$$,null,$APP.$cljs$cst$1681$row_gap$$,null],null),null)),$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$($JSCompiler_inline_result$jscomp$1310__$jscomp$2625_layout_gap$jscomp$inline_12904_or__5025__auto__$jscomp$inline_7344_value$jscomp$inline_12903$$)),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$03$$($ids_with_layout$jscomp$1_state$jscomp$948$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1680$layout_gap$$,$JSCompiler_inline_result$jscomp$1310__$jscomp$2625_layout_gap$jscomp$inline_12904_or__5025__auto__$jscomp$inline_7344_value$jscomp$inline_12903$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,this.$page_id$],null)))):null});return new $app$main$data$workspace$tokens$application$update_layout_gap_72344$$($value$jscomp$683$$,$shape_ids$jscomp$49$$,
$attributes$jscomp$37$$,$page_id$jscomp$302$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$application$generate_text_shape_update$$=function($txt_attrs$$,$shape_ids$jscomp$54$$,$page_id$jscomp$306$$){var $affects_layout_QMARK_$$=$APP.$cljs$core$some$$(function($p1__72353_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($txt_attrs$$,$p1__72353_SHARP_$$)},new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1766$letter_spacing$$,
$APP.$cljs$cst$1765$line_height$$],null));typeof $app$main$data$workspace$tokens$application$generate_text_shape_update_72356$$==="undefined"&&($app$main$data$workspace$tokens$application$generate_text_shape_update_72356$$=function($txt_attrs$jscomp$1$$,$shape_ids$jscomp$55$$,$page_id$jscomp$307$$,$update_node_QMARK_$jscomp$3$$,$update_fn$jscomp$39$$,$affects_layout_QMARK_$jscomp$1$$,$meta72357$$){this.$txt_attrs$=$txt_attrs$jscomp$1$$;this.$shape_ids$=$shape_ids$jscomp$55$$;this.$page_id$=$page_id$jscomp$307$$;
this.$update_node_QMARK_$=$update_node_QMARK_$jscomp$3$$;this.$update_fn$=$update_fn$jscomp$39$$;this.$affects_layout_QMARK_$=$affects_layout_QMARK_$jscomp$1$$;this.$meta72357$=$meta72357$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$generate_text_shape_update_72356$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$generate_text_shape_update_72356$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4636$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_generate_text_shape_update$$},$app$main$data$workspace$tokens$application$generate_text_shape_update_72356$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72358$$,$meta72357__$1$$){return new $app$main$data$workspace$tokens$application$generate_text_shape_update_72356$$(this.$txt_attrs$,this.$shape_ids$,this.$page_id$,this.$update_node_QMARK_$,this.$update_fn$,this.$affects_layout_QMARK_$,
$meta72357__$1$$)},$app$main$data$workspace$tokens$application$generate_text_shape_update_72356$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72357$},$app$main$data$workspace$tokens$application$generate_text_shape_update_72356$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$generate_text_shape_update_72356$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($G__72359__$jscomp$2628$$,$state$jscomp$949$$){var $self__$jscomp$6478$$=
this;$G__72359__$jscomp$2628$$=(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$6478$$.$shape_ids$,function($p1__72354_SHARP_$$){return $app$common$types$text$update_text_content$$($p1__72354_SHARP_$$,$self__$jscomp$6478$$.$update_node_QMARK_$,$self__$jscomp$6478$$.$update_fn$,null)},new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,$self__$jscomp$6478$$.$page_id$],
null)));return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$553$$=$self__$jscomp$6478$$.$affects_layout_QMARK_$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$553$$)?$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$949$$,"render-wasm/v1"):$and__5023__auto__$jscomp$553$$}())?$APP.$beicon$v2$core$merge$$($G__72359__$jscomp$2628$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_all$$($self__$jscomp$6478$$.$shape_ids$))):
$G__72359__$jscomp$2628$$});return new $app$main$data$workspace$tokens$application$generate_text_shape_update_72356$$($txt_attrs$$,$shape_ids$jscomp$54$$,$page_id$jscomp$306$$,function($node$jscomp$341$$){return $APP.$app$common$types$text$is_text_node_QMARK_$$($node$jscomp$341$$)||$APP.$app$common$types$text$is_paragraph_node_QMARK_$$($node$jscomp$341$$)},function($node$jscomp$342$$){return $app$common$types$typography$remove_typography_from_node$$($APP.$app$common$data$txt_merge$$($node$jscomp$342$$,
$txt_attrs$$))},$affects_layout_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$application$warn_font_variant_not_found_BANG_$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.font-variant-not-found"),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$2343$warning$$,$APP.$cljs$cst$2353$timeout$$,
7E3],null)))};
$app$main$data$workspace$tokens$application$update_closest_font_variant_id_by_weight$$=function($txt_attrs$jscomp$2$$,$target_variant$$,$call_on_mismatch_QMARK__font$jscomp$41_font_id$jscomp$33$$,$on_mismatch$$){$call_on_mismatch_QMARK__font$jscomp$41_font_id$jscomp$33$$=$APP.$app$main$fonts$get_font_data$$($call_on_mismatch_QMARK__font$jscomp$41_font_id$jscomp$33$$);var $variant$jscomp$16$$=$APP.$cljs$core$truth_$$($call_on_mismatch_QMARK__font$jscomp$41_font_id$jscomp$33$$)?$app$main$fonts$find_closest_variant$$($call_on_mismatch_QMARK__font$jscomp$41_font_id$jscomp$33$$,$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($target_variant$$),
$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($target_variant$$)):null;$call_on_mismatch_QMARK__font$jscomp$41_font_id$jscomp$33$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$554$$=$APP.$cljs$core$fn_QMARK_$$($on_mismatch$$);return $and__5023__auto__$jscomp$554$$?$variant$jscomp$16$$:$and__5023__auto__$jscomp$554$$}())?function(){var $or__5025__auto__$jscomp$883$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($target_variant$$),
$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$16$$));return $or__5025__auto__$jscomp$883$$?$or__5025__auto__$jscomp$883$$:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($target_variant$$))?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($target_variant$$),$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$16$$)):null}():null;
$APP.$cljs$core$truth_$$($call_on_mismatch_QMARK__font$jscomp$41_font_id$jscomp$33$$)&&($on_mismatch$$.$cljs$core$IFn$_invoke$arity$0$?$on_mismatch$$.$cljs$core$IFn$_invoke$arity$0$():$on_mismatch$$());return $APP.$cljs$core$truth_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$16$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($txt_attrs$jscomp$2$$,$APP.$cljs$cst$1759$font_variant_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$16$$)):
$txt_attrs$jscomp$2$$};
$app$main$data$workspace$tokens$application$generate_font_family_text_shape_update$$=function($txt_attrs$jscomp$3$$,$shape_ids$jscomp$60$$,$page_id$jscomp$310$$,$on_mismatch$jscomp$1$$){var $not_found_font$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($txt_attrs$jscomp$3$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$uuid$zero$$));typeof $app$main$data$workspace$tokens$application$generate_font_family_text_shape_update_72369$$==="undefined"&&
($app$main$data$workspace$tokens$application$generate_font_family_text_shape_update_72369$$=function($txt_attrs$jscomp$4$$,$shape_ids$jscomp$61$$,$page_id$jscomp$311$$,$on_mismatch$jscomp$2$$,$not_found_font$jscomp$1$$,$update_node_QMARK_$jscomp$5$$,$update_fn$jscomp$41$$,$meta72370$$){this.$txt_attrs$=$txt_attrs$jscomp$4$$;this.$shape_ids$=$shape_ids$jscomp$61$$;this.$page_id$=$page_id$jscomp$311$$;this.$on_mismatch$=$on_mismatch$jscomp$2$$;this.$not_found_font$=$not_found_font$jscomp$1$$;this.$update_node_QMARK_$=
$update_node_QMARK_$jscomp$5$$;this.$update_fn$=$update_fn$jscomp$41$$;this.$meta72370$=$meta72370$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$generate_font_family_text_shape_update_72369$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$generate_font_family_text_shape_update_72369$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4637$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_generate_font_family_text_shape_update$$},
$app$main$data$workspace$tokens$application$generate_font_family_text_shape_update_72369$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72371$$,$meta72370__$1$$){return new $app$main$data$workspace$tokens$application$generate_font_family_text_shape_update_72369$$(this.$txt_attrs$,this.$shape_ids$,this.$page_id$,this.$on_mismatch$,this.$not_found_font$,this.$update_node_QMARK_$,this.$update_fn$,$meta72370__$1$$)},$app$main$data$workspace$tokens$application$generate_font_family_text_shape_update_72369$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72370$},$app$main$data$workspace$tokens$application$generate_font_family_text_shape_update_72369$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$generate_font_family_text_shape_update_72369$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($G__72372__$jscomp$2629$$,$state$jscomp$950$$){var $self__$jscomp$6482$$=this;$G__72372__$jscomp$2629$$=(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$6482$$.$shape_ids$,
function($shape$jscomp$766$$){return $app$common$types$text$update_text_content$$($shape$jscomp$766$$,$self__$jscomp$6482$$.$update_node_QMARK_$,function($p1__72367_SHARP_$$){var $G__72374$$=$app$common$types$shape$token$font_weight_applied_QMARK_$$($shape$jscomp$766$$);return $self__$jscomp$6482$$.$update_fn$.$cljs$core$IFn$_invoke$arity$2$?$self__$jscomp$6482$$.$update_fn$.$cljs$core$IFn$_invoke$arity$2$($p1__72367_SHARP_$$,$G__72374$$):$self__$jscomp$6482$$.$update_fn$($p1__72367_SHARP_$$,$G__72374$$)},
null)},new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,$self__$jscomp$6482$$.$page_id$],null)));return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$950$$,"render-wasm/v1")?$APP.$beicon$v2$core$merge$$($G__72372__$jscomp$2629$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_all$$($self__$jscomp$6482$$.$shape_ids$))):$G__72372__$jscomp$2629$$});return new $app$main$data$workspace$tokens$application$generate_font_family_text_shape_update_72369$$($txt_attrs$jscomp$3$$,
$shape_ids$jscomp$60$$,$page_id$jscomp$310$$,$on_mismatch$jscomp$1$$,$not_found_font$$,function($node$jscomp$343$$){return $APP.$app$common$types$text$is_text_node_QMARK_$$($node$jscomp$343$$)||$APP.$app$common$types$text$is_paragraph_node_QMARK_$$($node$jscomp$343$$)},function($node$jscomp$344$$,$find_closest_weight_QMARK__txt_attrs__$1$$){var $font_id$jscomp$34$$=$not_found_font$$?$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$344$$):$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($txt_attrs$jscomp$3$$);
$find_closest_weight_QMARK__txt_attrs__$1$$=$APP.$cljs$core$truth_$$($find_closest_weight_QMARK__txt_attrs__$1$$)?$app$main$data$workspace$tokens$application$update_closest_font_variant_id_by_weight$$($txt_attrs$jscomp$3$$,$node$jscomp$344$$,$font_id$jscomp$34$$,$on_mismatch$jscomp$1$$):$txt_attrs$jscomp$3$$;return $app$common$types$typography$remove_typography_from_node$$($APP.$app$common$data$txt_merge$$($node$jscomp$344$$,$find_closest_weight_QMARK__txt_attrs__$1$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$application$create_font_family_text_attrs$$=function($font_family$jscomp$8_value$jscomp$692$$){$font_family$jscomp$8_value$jscomp$692$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($font_family$jscomp$8_value$jscomp$692$$),/["']/);var $font$jscomp$42$$=$font_family$jscomp$8_value$jscomp$692$$==null?null:$APP.$app$main$fonts$find_font_family$$($font_family$jscomp$8_value$jscomp$692$$);return $APP.$cljs$core$truth_$$($font$jscomp$42$$)?
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$42$$),$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$2675$family$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$42$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$uuid$zero$$),$APP.$cljs$cst$1758$font_family$$,$font_family$jscomp$8_value$jscomp$692$$],
null)};
$app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update$$=function($font_variant$jscomp$2$$,$shape_ids$jscomp$74$$,$page_id$jscomp$318$$,$on_mismatch$jscomp$3$$){var $font_variant__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($font_variant$jscomp$2$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($font_variant$jscomp$2$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1762$font_style$$,$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($font_variant$jscomp$2$$)]));
typeof $app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update_72414$$==="undefined"&&($app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update_72414$$=function($font_variant$jscomp$3$$,$shape_ids$jscomp$75$$,$page_id$jscomp$319$$,$on_mismatch$jscomp$4$$,$update_node_QMARK_$jscomp$7$$,$update_fn$jscomp$43$$,$meta72415$$){this.$font_variant$=$font_variant$jscomp$3$$;this.$shape_ids$=$shape_ids$jscomp$75$$;this.$page_id$=$page_id$jscomp$319$$;this.$on_mismatch$=
$on_mismatch$jscomp$4$$;this.$update_node_QMARK_$=$update_node_QMARK_$jscomp$7$$;this.$update_fn$=$update_fn$jscomp$43$$;this.$meta72415$=$meta72415$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update_72414$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update_72414$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4639$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_generate_font_weight_text_shape_update$$},$app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update_72414$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72416$$,$meta72415__$1$$){return new $app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update_72414$$(this.$font_variant$,this.$shape_ids$,this.$page_id$,this.$on_mismatch$,this.$update_node_QMARK_$,
this.$update_fn$,$meta72415__$1$$)},$app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update_72414$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72415$},$app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update_72414$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update_72414$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($G__72417__$jscomp$2631$$,$state$jscomp$951$$){var $self__$jscomp$6486$$=this;$G__72417__$jscomp$2631$$=(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$6486$$.$shape_ids$,function($p1__72406_SHARP_$$){return $app$common$types$text$update_text_content$$($p1__72406_SHARP_$$,$self__$jscomp$6486$$.$update_node_QMARK_$,$self__$jscomp$6486$$.$update_fn$,null)},new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2556$ignore_touched$$,
!0,$APP.$cljs$cst$2043$page_id$$,$self__$jscomp$6486$$.$page_id$],null)));return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$951$$,"render-wasm/v1")?$APP.$beicon$v2$core$merge$$($G__72417__$jscomp$2631$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_all$$($self__$jscomp$6486$$.$shape_ids$))):$G__72417__$jscomp$2631$$});return new $app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update_72414$$($font_variant__$1$$,
$shape_ids$jscomp$74$$,$page_id$jscomp$318$$,$on_mismatch$jscomp$3$$,function($node$jscomp$345$$){return $APP.$app$common$types$text$is_text_node_QMARK_$$($node$jscomp$345$$)||$APP.$app$common$types$text$is_paragraph_node_QMARK_$$($node$jscomp$345$$)},function($node$jscomp$346$$){var $txt_attrs$jscomp$5$$=$app$main$data$workspace$tokens$application$update_closest_font_variant_id_by_weight$$($font_variant__$1$$,$font_variant__$1$$,$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$346$$),
$on_mismatch$jscomp$3$$);return $app$common$types$typography$remove_typography_from_node$$($APP.$app$common$data$txt_merge$$($node$jscomp$346$$,$txt_attrs$jscomp$5$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$application$apply_functions_map$$=function($vs$jscomp$7$$,$args$jscomp$250$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($f$jscomp$835_p__72434$$){var $k$jscomp$661_temp__5825__auto__$jscomp$241$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$835_p__72434$$,0,null);$f$jscomp$835_p__72434$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$835_p__72434$$,1,null);$k$jscomp$661_temp__5825__auto__$jscomp$241$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($vs$jscomp$7$$,$k$jscomp$661_temp__5825__auto__$jscomp$241$$);return $APP.$cljs$core$truth_$$($k$jscomp$661_temp__5825__auto__$jscomp$241$$)?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($f$jscomp$835_p__72434$$,$k$jscomp$661_temp__5825__auto__$jscomp$241$$,$args$jscomp$250$$):null},new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1760$font_size$$,$app$main$data$workspace$tokens$application$update_font_size$$,$APP.$cljs$cst$1758$font_family$$,
$app$main$data$workspace$tokens$application$update_font_family$$,$APP.$cljs$cst$1761$font_weight$$,$app$main$data$workspace$tokens$application$update_font_weight$$,$APP.$cljs$cst$1766$letter_spacing$$,$app$main$data$workspace$tokens$application$update_letter_spacing$$,$APP.$cljs$cst$1979$text_case$$,$app$main$data$workspace$tokens$application$update_text_case$$,$APP.$cljs$cst$1768$text_decoration$$,$app$main$data$workspace$tokens$application$update_text_decoration$$,$APP.$cljs$cst$1765$line_height$$,
$APP.$app$main$data$workspace$tokens$application$update_line_height$$],null))};
$app$main$data$workspace$tokens$application$update_shape_dimensions$cljs$0core$0IFn$0_invoke$0arity$04$$=function($value$jscomp$712$$,$shape_ids$jscomp$83$$,$attributes$jscomp$56$$,$page_id$jscomp$323$$){typeof $app$main$data$workspace$tokens$application$update_shape_dimensions_72447$$==="undefined"&&($app$main$data$workspace$tokens$application$update_shape_dimensions_72447$$=function($value$jscomp$713$$,$shape_ids$jscomp$84$$,$attributes$jscomp$57$$,$page_id$jscomp$324$$,$meta72448$$){this.value=
$value$jscomp$713$$;this.$shape_ids$=$shape_ids$jscomp$84$$;this.attributes=$attributes$jscomp$57$$;this.$page_id$=$page_id$jscomp$324$$;this.$meta72448$=$meta72448$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$update_shape_dimensions_72447$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_shape_dimensions_72447$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4640$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_shape_dimensions$$},$app$main$data$workspace$tokens$application$update_shape_dimensions_72447$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72449$$,$meta72448__$1$$){return new $app$main$data$workspace$tokens$application$update_shape_dimensions_72447$$(this.value,this.$shape_ids$,this.attributes,this.$page_id$,$meta72448__$1$$)},$app$main$data$workspace$tokens$application$update_shape_dimensions_72447$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72448$},$app$main$data$workspace$tokens$application$update_shape_dimensions_72447$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_shape_dimensions_72447$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return typeof this.value==="number"?(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$truth_$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$(this.attributes))?$app$main$data$workspace$transforms$update_dimensions$cljs$0core$0IFn$0_invoke$0arity$04$$(this.$shape_ids$,
$APP.$cljs$cst$290$width$$,this.value,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,this.$page_id$,$cljs$cst$3864$no_wasm_QMARK_$$,!0],null)):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$(this.attributes))?$app$main$data$workspace$transforms$update_dimensions$cljs$0core$0IFn$0_invoke$0arity$04$$(this.$shape_ids$,$APP.$cljs$cst$1522$height$$,this.value,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,this.$page_id$,$cljs$cst$3864$no_wasm_QMARK_$$,!0],null)):null):null});return new $app$main$data$workspace$tokens$application$update_shape_dimensions_72447$$($value$jscomp$712$$,$shape_ids$jscomp$83$$,$attributes$jscomp$56$$,$page_id$jscomp$323$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$application$attributes__GT_actions$$=function($G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$){$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$=$APP.$cljs$core$__destructure_map$$($G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$);var $value$jscomp$714$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$,$APP.$cljs$cst$260$value$$),$shape_ids$jscomp$85$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$,$APP.$cljs$cst$4641$shape_ids$$),$attributes$jscomp$58$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$,
$APP.$cljs$cst$1993$attributes$$),$page_id$jscomp$325$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$,$APP.$cljs$cst$2043$page_id$$);$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$=$APP.$cljs$core$PersistentVector$EMPTY$$;$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$=
$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1522$height$$,null],null),null)))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$,function(){return $app$main$data$workspace$tokens$application$update_shape_dimensions$cljs$0core$0IFn$0_invoke$0arity$04$$($value$jscomp$714$$,
$shape_ids$jscomp$85$$,$APP.$cljs$core$set$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1522$height$$,null],null),null))),$page_id$jscomp$325$$)}):$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$;$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$=
$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1510$x$$,null],null),null)))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$,function(){return $APP.$app$main$data$workspace$tokens$application$update_shape_position$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$714$$,
$shape_ids$jscomp$85$$,$APP.$cljs$core$set$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1510$x$$,null],null),null))),$page_id$jscomp$325$$)}):$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$;$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$=
$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1091$p2$$,null,$APP.$cljs$cst$1688$p4$$,null,$APP.$cljs$cst$1687$p3$$,null,$APP.$cljs$cst$1093$p1$$,null],null),null)))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$,function(){return $APP.$app$main$data$workspace$tokens$application$update_layout_padding$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$714$$,
$shape_ids$jscomp$85$$,$APP.$cljs$core$set$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1091$p2$$,null,$APP.$cljs$cst$1688$p4$$,null,$APP.$cljs$cst$1687$p3$$,null,$APP.$cljs$cst$1093$p1$$,null],null),null))),$page_id$jscomp$325$$)}):$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$;
$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1702$m3$$,null,$APP.$cljs$cst$1703$m4$$,null,$APP.$cljs$cst$1701$m2$$,null,$APP.$cljs$cst$1700$m1$$,null],null),null)))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$,
function(){return $APP.$app$main$data$workspace$tokens$application$update_layout_item_margin$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$714$$,$shape_ids$jscomp$85$$,$APP.$cljs$core$set$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1702$m3$$,null,$APP.$cljs$cst$1703$m4$$,null,$APP.$cljs$cst$1701$m2$$,null,$APP.$cljs$cst$1700$m1$$,null],null),null))),
$page_id$jscomp$325$$)}):$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$;$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1682$column_gap$$,null,$APP.$cljs$cst$1681$row_gap$$,
null],null),null)))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$,function(){return $APP.$app$main$data$workspace$tokens$application$update_layout_gap$$($value$jscomp$714$$,$shape_ids$jscomp$85$$,$APP.$cljs$core$set$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1682$column_gap$$,null,$APP.$cljs$cst$1681$row_gap$$,null],null),null))),$page_id$jscomp$325$$)}):$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$;$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1647$r2$$,null,$APP.$cljs$cst$1648$r3$$,null,$APP.$cljs$cst$1646$r1$$,null,$APP.$cljs$cst$1649$r4$$,null],null),null)))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$,function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1647$r2$$,null,$APP.$cljs$cst$1648$r3$$,null,$APP.$cljs$cst$1646$r1$$,null,$APP.$cljs$cst$1649$r4$$,null],null),null))?$APP.$app$main$data$workspace$tokens$application$update_shape_radius$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$714$$,$shape_ids$jscomp$85$$,$attributes$jscomp$58$$,$page_id$jscomp$325$$):$APP.$app$main$data$workspace$tokens$application$update_shape_radius_for_corners$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$714$$,$shape_ids$jscomp$85$$,$APP.$cljs$core$set$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($attributes$jscomp$58$$,
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1647$r2$$,null,$APP.$cljs$cst$1648$r3$$,null,$APP.$cljs$cst$1646$r1$$,null,$APP.$cljs$cst$1649$r4$$,null],null),null))),$page_id$jscomp$325$$)}):$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$;$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$=
$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1655$stroke_width$$,null],null),null)))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$,function(){return $APP.$app$main$data$workspace$tokens$application$update_stroke_width$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$714$$,
$shape_ids$jscomp$85$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1655$stroke_width$$,null],null),null),$page_id$jscomp$325$$)}):$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1986$max_height$$,
null,$APP.$cljs$cst$281$max_width$$,null,$APP.$cljs$cst$1706$layout_item_max_w$$,null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null],null),null)))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$,function(){return $APP.$app$main$data$workspace$tokens$application$update_layout_sizing_limits$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$714$$,
$shape_ids$jscomp$85$$,$APP.$cljs$core$set$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($attributes$jscomp$58$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1986$max_height$$,null,$APP.$cljs$cst$281$max_width$$,null,$APP.$cljs$cst$1706$layout_item_max_w$$,null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null],null),null))),$page_id$jscomp$325$$)}):
$G__72457_G__72457__$1_G__72457__$2_G__72457__$3_G__72457__$4_G__72457__$5_G__72457__$6_G__72457__$7_map__72455__$1_p__72453$$};
$APP.$app$main$data$workspace$tokens$application$apply_token$$=function($p__72544$$){var $map__72545__$1$$=$APP.$cljs$core$__destructure_map$$($p__72544$$),$attributes$jscomp$68$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72545__$1$$,$APP.$cljs$cst$1993$attributes$$),$attributes_to_remove$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72545__$1$$,$APP.$cljs$cst$4645$attributes_to_remove$$),$token$jscomp$79$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72545__$1$$,
$APP.$cljs$cst$1136$token$$),$shape_ids$jscomp$95$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72545__$1$$,$APP.$cljs$cst$4641$shape_ids$$),$on_update_shape$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72545__$1$$,$APP.$cljs$cst$4646$on_update_shape$$);typeof $app$main$data$workspace$tokens$application$apply_token_72546$$==="undefined"&&($app$main$data$workspace$tokens$application$apply_token_72546$$=function($p__72544$jscomp$1$$,$map__72545$jscomp$1$$,$attributes$jscomp$69$$,
$attributes_to_remove$jscomp$1$$,$token$jscomp$80$$,$shape_ids$jscomp$96$$,$on_update_shape$jscomp$1$$,$meta72547$$){this.$p__72544$=$p__72544$jscomp$1$$;this.$map__72545$=$map__72545$jscomp$1$$;this.attributes=$attributes$jscomp$69$$;this.$attributes_to_remove$=$attributes_to_remove$jscomp$1$$;this.token=$token$jscomp$80$$;this.$shape_ids$=$shape_ids$jscomp$96$$;this.$on_update_shape$=$on_update_shape$jscomp$1$$;this.$meta72547$=$meta72547$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$tokens$application$apply_token_72546$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_token_72546$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4647$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_token$$},$app$main$data$workspace$tokens$application$apply_token_72546$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72548$$,$meta72547__$1$$){return new $app$main$data$workspace$tokens$application$apply_token_72546$$(this.$p__72544$,
this.$map__72545$,this.attributes,this.$attributes_to_remove$,this.token,this.$shape_ids$,this.$on_update_shape$,$meta72547__$1$$)},$app$main$data$workspace$tokens$application$apply_token_72546$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72547$},$app$main$data$workspace$tokens$application$apply_token_72546$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_token_72546$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($edition$jscomp$3_it$jscomp$251_temp__5825__auto__$jscomp$242_text_editing_QMARK_$$,$state$jscomp$955$$){var $self__$jscomp$6506$$=this,$it__$1$jscomp$127$$=this;$edition$jscomp$3_it$jscomp$251_temp__5825__auto__$jscomp$242_text_editing_QMARK_$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$955$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2199$edition$$],null));
var $objects$jscomp$674$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$955$$);$edition$jscomp$3_it$jscomp$251_temp__5825__auto__$jscomp$242_text_editing_QMARK_$$=$edition$jscomp$3_it$jscomp$251_temp__5825__auto__$jscomp$242_text_editing_QMARK_$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$674$$,
$edition$jscomp$3_it$jscomp$251_temp__5825__auto__$jscomp$242_text_editing_QMARK_$$)));if($self__$jscomp$6506$$.token==null||$edition$jscomp$3_it$jscomp$251_temp__5825__auto__$jscomp$242_text_editing_QMARK_$$)return $edition$jscomp$3_it$jscomp$251_temp__5825__auto__$jscomp$242_text_editing_QMARK_$$?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.error-text-edition"),
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$2343$warning$$,$APP.$cljs$cst$2353$timeout$$,3E3],null))):null;var $attributes_to_remove__$1$$=$APP.$cljs$core$truth_$$(function(){var $G__72555$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6506$$.token);return $app$common$types$token$typography_token_keys$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$typography_token_keys$$.$cljs$core$IFn$_invoke$arity$1$($G__72555$$):
$app$common$types$token$typography_token_keys$$($G__72555$$)}())?$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$6506$$.$attributes_to_remove$,$app$common$types$token$typography_keys$$):$APP.$cljs$core$truth_$$(function(){var $G__72557$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6506$$.token);return $app$common$types$token$typography_keys$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$typography_keys$$.$cljs$core$IFn$_invoke$arity$1$($G__72557$$):
$app$common$types$token$typography_keys$$($G__72557$$)}())?$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$6506$$.$attributes_to_remove$,$app$common$types$token$typography_token_keys$$):$self__$jscomp$6506$$.$attributes_to_remove$;$edition$jscomp$3_it$jscomp$251_temp__5825__auto__$jscomp$242_text_editing_QMARK_$$=function(){var $G__72558_G__72558__$1$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$955$$);$G__72558_G__72558__$1$$=
$G__72558_G__72558__$1$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__72558_G__72558__$1$$,$APP.$cljs$cst$2139$tokens_lib$$);return $G__72558_G__72558__$1$$==null?null:$APP.$app$common$types$tokens_lib$get_tokens_in_active_sets$$($G__72558_G__72558__$1$$)}();return $APP.$cljs$core$truth_$$($edition$jscomp$3_it$jscomp$251_temp__5825__auto__$jscomp$242_text_editing_QMARK_$$)?$APP.$beicon$v2$core$mapcat$$(function($resolved_tokens$jscomp$2_resolved_value_type$jscomp$548$$){var $undo_id$jscomp$86$$=
Symbol(),$objects__$1$jscomp$31$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$955$$),$any_variant_QMARK__selected_shapes$jscomp$8_shapes$jscomp$122$$=$APP.$cljs$core$select_keys$$($objects__$1$jscomp$31$$,$self__$jscomp$6506$$.$shape_ids$);$any_variant_QMARK__selected_shapes$jscomp$8_shapes$jscomp$122$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($G__72563_and__5023__auto__$jscomp$555_is_layout$jscomp$inline_12908_p__72559_shape$jscomp$767$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__72563_and__5023__auto__$jscomp$555_is_layout$jscomp$inline_12908_p__72559_shape$jscomp$767$$,
0,null);$G__72563_and__5023__auto__$jscomp$555_is_layout$jscomp$inline_12908_p__72559_shape$jscomp$767$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__72563_and__5023__auto__$jscomp$555_is_layout$jscomp$inline_12908_p__72559_shape$jscomp$767$$,1,null);var $G__72564_and__5023__auto__$jscomp$inline_7347_attributes$jscomp$inline_12906_or__5025__auto__$jscomp$884$$=($G__72564_and__5023__auto__$jscomp$inline_7347_attributes$jscomp$inline_12906_or__5025__auto__$jscomp$884$$=$APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects__$1$jscomp$31$$,
$G__72563_and__5023__auto__$jscomp$555_is_layout$jscomp$inline_12908_p__72559_shape$jscomp$767$$))?$APP.$cljs$core$some$$($APP.$app$common$types$token$spacing_margin_keys$$,$self__$jscomp$6506$$.attributes):$G__72564_and__5023__auto__$jscomp$inline_7347_attributes$jscomp$inline_12906_or__5025__auto__$jscomp$884$$;if($APP.$cljs$core$truth_$$($G__72564_and__5023__auto__$jscomp$inline_7347_attributes$jscomp$inline_12906_or__5025__auto__$jscomp$884$$))return $G__72564_and__5023__auto__$jscomp$inline_7347_attributes$jscomp$inline_12906_or__5025__auto__$jscomp$884$$;
$G__72564_and__5023__auto__$jscomp$inline_7347_attributes$jscomp$inline_12906_or__5025__auto__$jscomp$884$$=$self__$jscomp$6506$$.attributes;var $token_type$jscomp$inline_12907$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__72563_and__5023__auto__$jscomp$555_is_layout$jscomp$inline_12908_p__72559_shape$jscomp$767$$);$G__72563_and__5023__auto__$jscomp$555_is_layout$jscomp$inline_12908_p__72559_shape$jscomp$767$$=$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($G__72563_and__5023__auto__$jscomp$555_is_layout$jscomp$inline_12908_p__72559_shape$jscomp$767$$);
return($G__72563_and__5023__auto__$jscomp$555_is_layout$jscomp$inline_12908_p__72559_shape$jscomp$767$$=$APP.$app$common$data$not_empty_QMARK_$$($APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($G__72564_and__5023__auto__$jscomp$inline_7347_attributes$jscomp$inline_12906_or__5025__auto__$jscomp$884$$,$APP.$app$common$types$token$shape_type__GT_attributes$$($token_type$jscomp$inline_12907$$,$G__72563_and__5023__auto__$jscomp$555_is_layout$jscomp$inline_12908_p__72559_shape$jscomp$767$$))))?
($G__72563_and__5023__auto__$jscomp$555_is_layout$jscomp$inline_12908_p__72559_shape$jscomp$767$$=$self__$jscomp$6506$$.attributes,$G__72564_and__5023__auto__$jscomp$inline_7347_attributes$jscomp$inline_12906_or__5025__auto__$jscomp$884$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6506$$.token),$app$main$data$workspace$tokens$application$all_attrs_appliable_for_token_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$data$workspace$tokens$application$all_attrs_appliable_for_token_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($G__72563_and__5023__auto__$jscomp$555_is_layout$jscomp$inline_12908_p__72559_shape$jscomp$767$$,
$G__72564_and__5023__auto__$jscomp$inline_7347_attributes$jscomp$inline_12906_or__5025__auto__$jscomp$884$$):$app$main$data$workspace$tokens$application$all_attrs_appliable_for_token_QMARK_$$($G__72563_and__5023__auto__$jscomp$555_is_layout$jscomp$inline_12908_p__72559_shape$jscomp$767$$,$G__72564_and__5023__auto__$jscomp$inline_7347_attributes$jscomp$inline_12906_or__5025__auto__$jscomp$884$$)):$G__72563_and__5023__auto__$jscomp$555_is_layout$jscomp$inline_12908_p__72559_shape$jscomp$767$$},$any_variant_QMARK__selected_shapes$jscomp$8_shapes$jscomp$122$$);
var $shape_ids__$1$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keys$$($any_variant_QMARK__selected_shapes$jscomp$8_shapes$jscomp$122$$),$APP.$cljs$core$PersistentVector$EMPTY$$);$any_variant_QMARK__selected_shapes$jscomp$8_shapes$jscomp$122$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$APP.$cljs$core$vals$$($any_variant_QMARK__selected_shapes$jscomp$8_shapes$jscomp$122$$)));$resolved_tokens$jscomp$2_resolved_value_type$jscomp$548$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$2_resolved_value_type$jscomp$548$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6506$$.token),$APP.$cljs$cst$4605$resolved_value$$],null));var $resolved_value__$1$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($resolved_tokens$jscomp$2_resolved_value_type$jscomp$548$$):
$resolved_tokens$jscomp$2_resolved_value_type$jscomp$548$$,$tokenized_attributes$$=$APP.$app$common$files$tokens$attributes_map$$($self__$jscomp$6506$$.attributes,$self__$jscomp$6506$$.token);$resolved_tokens$jscomp$2_resolved_value_type$jscomp$548$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6506$$.token);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"apply-tokens",$APP.$cljs$cst$139$type$$,$resolved_tokens$jscomp$2_resolved_value_type$jscomp$548$$,$cljs$cst$4648$applied_to$$,$self__$jscomp$6506$$.attributes,$cljs$cst$4649$applied_to_variant$$,$any_variant_QMARK__selected_shapes$jscomp$8_shapes$jscomp$122$$],null),$APP.$cljs$core$meta$$($it__$1$jscomp$127$$)])))),$APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$86$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_ids__$1$jscomp$1$$,
function($G__72566__$1_shape$jscomp$768$$){$G__72566__$1_shape$jscomp$768$$=$APP.$cljs$core$truth_$$($attributes_to_remove__$1$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__72566__$1_shape$jscomp$768$$,$APP.$cljs$cst$1873$applied_tokens$$,function($p1__72543_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$dissoc$$,$p1__72543_SHARP_$$),$attributes_to_remove__$1$$)}):$G__72566__$1_shape$jscomp$768$$;
return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__72566__$1_shape$jscomp$768$$,$APP.$cljs$cst$1873$applied_tokens$$,$APP.$cljs$core$merge$$,$tokenized_attributes$$)})),$APP.$cljs$core$truth_$$($self__$jscomp$6506$$.$on_update_shape$)?function(){var $res$jscomp$44$$=$self__$jscomp$6506$$.$on_update_shape$.$cljs$core$IFn$_invoke$arity$3$?$self__$jscomp$6506$$.$on_update_shape$.$cljs$core$IFn$_invoke$arity$3$($resolved_value__$1$$,$shape_ids__$1$jscomp$1$$,$self__$jscomp$6506$$.attributes):
$self__$jscomp$6506$$.$on_update_shape$($resolved_value__$1$$,$shape_ids__$1$jscomp$1$$,$self__$jscomp$6506$$.attributes);return $res$jscomp$44$$ instanceof $beicon$v2$core$Observable$$?$res$jscomp$44$$:(0,$APP.$beicon$v2$core$of$$)($res$jscomp$44$$)}():null,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$86$$)))},$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$tokenscript$resolve_tokens$$($edition$jscomp$3_it$jscomp$251_temp__5825__auto__$jscomp$242_text_editing_QMARK_$$)):
$app$main$data$style_dictionary$resolve_tokens$$($edition$jscomp$3_it$jscomp$251_temp__5825__auto__$jscomp$242_text_editing_QMARK_$$)):null});return new $app$main$data$workspace$tokens$application$apply_token_72546$$($p__72544$$,$map__72545__$1$$,$attributes$jscomp$68$$,$attributes_to_remove$$,$token$jscomp$79$$,$shape_ids$jscomp$95$$,$on_update_shape$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$application$apply_spacing_token_separated$$=function($p__72571$$){var $map__72572__$1$$=$APP.$cljs$core$__destructure_map$$($p__72571$$),$token$jscomp$81$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72572__$1$$,$APP.$cljs$cst$1136$token$$),$shapes$jscomp$123$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72572__$1$$,$APP.$cljs$cst$1614$shapes$$),$attr$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72572__$1$$,
$APP.$cljs$cst$2599$attr$$);typeof $app$main$data$workspace$tokens$application$apply_spacing_token_separated_72574$$==="undefined"&&($app$main$data$workspace$tokens$application$apply_spacing_token_separated_72574$$=function($p__72571$jscomp$1$$,$map__72572$jscomp$1$$,$token$jscomp$82$$,$shapes$jscomp$124$$,$attr$jscomp$58$$,$meta72575$$){this.$p__72571$=$p__72571$jscomp$1$$;this.$map__72572$=$map__72572$jscomp$1$$;this.token=$token$jscomp$82$$;this.shapes=$shapes$jscomp$124$$;this.attr=$attr$jscomp$58$$;
this.$meta72575$=$meta72575$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$apply_spacing_token_separated_72574$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_spacing_token_separated_72574$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4650$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_spacing_token_separated$$},
$app$main$data$workspace$tokens$application$apply_spacing_token_separated_72574$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72576$$,$meta72575__$1$$){return new $app$main$data$workspace$tokens$application$apply_spacing_token_separated_72574$$(this.$p__72571$,this.$map__72572$,this.token,this.shapes,this.attr,$meta72575__$1$$)},$app$main$data$workspace$tokens$application$apply_spacing_token_separated_72574$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72575$},
$app$main$data$workspace$tokens$application$apply_spacing_token_separated_72574$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_spacing_token_separated_72574$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$252_map__72582_map__72582__$1_on_update_shape$jscomp$2$$,$map__72583_other$jscomp$200_state$jscomp$956$$){var $self__$jscomp$6510$$=this,$objects$jscomp$675$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($map__72583_other$jscomp$200_state$jscomp$956$$);
$it$jscomp$252_map__72582_map__72582__$1_on_update_shape$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6510$$.token));$it$jscomp$252_map__72582_map__72582__$1_on_update_shape$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($it$jscomp$252_map__72582_map__72582__$1_on_update_shape$jscomp$2$$);var $attributes$jscomp$70$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$252_map__72582_map__72582__$1_on_update_shape$jscomp$2$$,
$APP.$cljs$cst$1993$attributes$$);$it$jscomp$252_map__72582_map__72582__$1_on_update_shape$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$252_map__72582_map__72582__$1_on_update_shape$jscomp$2$$,$APP.$cljs$cst$4646$on_update_shape$$);$map__72583_other$jscomp$200_state$jscomp$956$$=$APP.$cljs$core$group_by$$(function($p1__72569_SHARP_$$){return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$675$$,$p1__72569_SHARP_$$)?$cljs$cst$4651$frame_children$$:
$cljs$cst$1349$other$$},$self__$jscomp$6510$$.shapes);var $frame_children_map__72583__$1$$=$APP.$cljs$core$__destructure_map$$($map__72583_other$jscomp$200_state$jscomp$956$$);$map__72583_other$jscomp$200_state$jscomp$956$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_children_map__72583__$1$$,$cljs$cst$1349$other$$);$frame_children_map__72583__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_children_map__72583__$1$$,$cljs$cst$4651$frame_children$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$with_meta$$($APP.$app$main$data$workspace$tokens$application$apply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1993$attributes$$,function(){var $or__5025__auto__$jscomp$885$$=$self__$jscomp$6510$$.attr;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$885$$)?$or__5025__auto__$jscomp$885$$:$attributes$jscomp$70$$}(),$APP.$cljs$cst$1136$token$$,$self__$jscomp$6510$$.token,$APP.$cljs$cst$4641$shape_ids$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$map__72583_other$jscomp$200_state$jscomp$956$$),$APP.$cljs$cst$4646$on_update_shape$$,$it$jscomp$252_map__72582_map__72582__$1_on_update_shape$jscomp$2$$],
null)),$APP.$cljs$core$meta$$(this)),$APP.$cljs$core$with_meta$$($APP.$app$main$data$workspace$tokens$application$apply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1993$attributes$$,$APP.$app$common$types$token$spacing_margin_keys$$,$APP.$cljs$cst$1136$token$$,$self__$jscomp$6510$$.token,$APP.$cljs$cst$4641$shape_ids$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$frame_children_map__72583__$1$$),$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_layout_item_margin$$],
null)),$APP.$cljs$core$meta$$(this)))});return new $app$main$data$workspace$tokens$application$apply_spacing_token_separated_72574$$($p__72571$$,$map__72572__$1$$,$token$jscomp$81$$,$shapes$jscomp$123$$,$attr$jscomp$57$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$application$unapply_token$$=function($p__72587$$){var $map__72588__$1$$=$APP.$cljs$core$__destructure_map$$($p__72587$$),$attributes$jscomp$71$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72588__$1$$,$APP.$cljs$cst$1993$attributes$$),$token_name$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72588__$1$$,$APP.$cljs$cst$4186$token_name$$),$shape_ids$jscomp$97$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72588__$1$$,
$APP.$cljs$cst$4641$shape_ids$$);typeof $app$main$data$workspace$tokens$application$unapply_token_72589$$==="undefined"&&($app$main$data$workspace$tokens$application$unapply_token_72589$$=function($p__72587$jscomp$1$$,$map__72588$jscomp$1$$,$_props$jscomp$2$$,$attributes$jscomp$72$$,$token_name$jscomp$13$$,$shape_ids$jscomp$98$$,$meta72590$$){this.$p__72587$=$p__72587$jscomp$1$$;this.$map__72588$=$map__72588$jscomp$1$$;this.$_props$=$_props$jscomp$2$$;this.attributes=$attributes$jscomp$72$$;this.$token_name$=
$token_name$jscomp$13$$;this.$shape_ids$=$shape_ids$jscomp$98$$;this.$meta72590$=$meta72590$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$unapply_token_72589$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$unapply_token_72589$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4652$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_unapply_token$$},
$app$main$data$workspace$tokens$application$unapply_token_72589$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72591$$,$meta72590__$1$$){return new $app$main$data$workspace$tokens$application$unapply_token_72589$$(this.$p__72587$,this.$map__72588$,this.$_props$,this.attributes,this.$token_name$,this.$shape_ids$,$meta72590__$1$$)},$app$main$data$workspace$tokens$application$unapply_token_72589$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72590$},$app$main$data$workspace$tokens$application$unapply_token_72589$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$unapply_token_72589$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6514$$=this;return(0,$APP.$beicon$v2$core$of$$)(function(){function $remove_token$$($p1__72586_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__72586_SHARP_$$)?$app$common$files$tokens$remove_attributes_for_token$$($self__$jscomp$6514$$.attributes,$self__$jscomp$6514$$.$token_name$,$p1__72586_SHARP_$$):null}return $APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$6514$$.$shape_ids$,
function($shape$jscomp$769$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$769$$,$APP.$cljs$cst$1873$applied_tokens$$,$remove_token$$)})}())});return new $app$main$data$workspace$tokens$application$unapply_token_72589$$($p__72587$$,$map__72588__$1$$,$map__72588__$1$$,$attributes$jscomp$71$$,$token_name$jscomp$12$$,$shape_ids$jscomp$97$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$application$toggle_token$$=function($p__72593$$){var $map__72594__$1$$=$APP.$cljs$core$__destructure_map$$($p__72593$$),$token$jscomp$83$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72594__$1$$,$APP.$cljs$cst$1136$token$$),$attrs$jscomp$163$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72594__$1$$,$APP.$cljs$cst$2645$attrs$$),$shape_ids$jscomp$99$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72594__$1$$,$APP.$cljs$cst$4641$shape_ids$$),
$expand_with_children$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72594__$1$$,$APP.$cljs$cst$4653$expand_with_children$$);typeof $app$main$data$workspace$tokens$application$on_toggle_token_72598$$==="undefined"&&($app$main$data$workspace$tokens$application$on_toggle_token_72598$$=function($p__72593$jscomp$1$$,$map__72594$jscomp$1$$,$token$jscomp$84$$,$attrs$jscomp$164$$,$shape_ids$jscomp$100$$,$expand_with_children$jscomp$1$$,$meta72599$$){this.$p__72593$=$p__72593$jscomp$1$$;this.$map__72594$=
$map__72594$jscomp$1$$;this.token=$token$jscomp$84$$;this.$attrs$=$attrs$jscomp$164$$;this.$shape_ids$=$shape_ids$jscomp$100$$;this.$expand_with_children$=$expand_with_children$jscomp$1$$;this.$meta72599$=$meta72599$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$on_toggle_token_72598$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$on_toggle_token_72598$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4654$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_on_toggle_token$$},$app$main$data$workspace$tokens$application$on_toggle_token_72598$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72600$$,$meta72599__$1$$){return new $app$main$data$workspace$tokens$application$on_toggle_token_72598$$(this.$p__72593$,this.$map__72594$,this.token,this.$attrs$,this.$shape_ids$,this.$expand_with_children$,$meta72599__$1$$)},$app$main$data$workspace$tokens$application$on_toggle_token_72598$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72599$},$app$main$data$workspace$tokens$application$on_toggle_token_72598$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$on_toggle_token_72598$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$253_shapes$jscomp$125_shapes__$1$jscomp$14$$,$map__72601_map__72601__$1_on_update_shape__$1_state$jscomp$957$$){var $self__$jscomp$6518$$=this,$objects$jscomp$676$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($map__72601_map__72601__$1_on_update_shape__$1_state$jscomp$957$$);
$it$jscomp$253_shapes$jscomp$125_shapes__$1$jscomp$14$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$676$$)),$self__$jscomp$6518$$.$shape_ids$);$it$jscomp$253_shapes$jscomp$125_shapes__$1$jscomp$14$$=$APP.$cljs$core$truth_$$($self__$jscomp$6518$$.$expand_with_children$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($shape$jscomp$770$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$770$$),$APP.$cljs$cst$1608$group$$)?$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$676$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$770$$)):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape$jscomp$770$$],null)}),$it$jscomp$253_shapes$jscomp$125_shapes__$1$jscomp$14$$):$it$jscomp$253_shapes$jscomp$125_shapes__$1$jscomp$14$$;$map__72601_map__72601__$1_on_update_shape__$1_state$jscomp$957$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6518$$.token));$map__72601_map__72601__$1_on_update_shape__$1_state$jscomp$957$$=$APP.$cljs$core$__destructure_map$$($map__72601_map__72601__$1_on_update_shape__$1_state$jscomp$957$$);
var $attributes$jscomp$73$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72601_map__72601__$1_on_update_shape__$1_state$jscomp$957$$,$APP.$cljs$cst$1993$attributes$$),$all_attributes$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72601_map__72601__$1_on_update_shape__$1_state$jscomp$957$$,$APP.$cljs$cst$4655$all_attributes$$),$on_update_shape$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72601_map__72601__$1_on_update_shape__$1_state$jscomp$957$$,
$APP.$cljs$cst$4646$on_update_shape$$);$map__72601_map__72601__$1_on_update_shape__$1_state$jscomp$957$$=$APP.$cljs$core$seq$$($self__$jscomp$6518$$.$attrs$)?function(){var $or__5025__auto__$jscomp$886$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$attr__GT_shape_update$$,$APP.$cljs$core$first$$($self__$jscomp$6518$$.$attrs$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$886$$)?$or__5025__auto__$jscomp$886$$:$on_update_shape$jscomp$3$$}():
$on_update_shape$jscomp$3$$;var $unapply_tokens_QMARK_$$=$APP.$app$common$files$tokens$shapes_token_applied_QMARK_$$($self__$jscomp$6518$$.token,$it$jscomp$253_shapes$jscomp$125_shapes__$1$jscomp$14$$,function(){var $or__5025__auto__$jscomp$887$$=$self__$jscomp$6518$$.$attrs$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$887$$)?$or__5025__auto__$jscomp$887$$:$APP.$cljs$core$truth_$$($all_attributes$$)?$all_attributes$$:$attributes$jscomp$73$$}()),$shape_ids__$1$jscomp$2$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$it$jscomp$253_shapes$jscomp$125_shapes__$1$jscomp$14$$);return $APP.$cljs$core$truth_$$($unapply_tokens_QMARK_$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1993$attributes$$,function(){var $or__5025__auto__$jscomp$888$$=$self__$jscomp$6518$$.$attrs$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$888$$)?$or__5025__auto__$jscomp$888$$:$APP.$cljs$core$truth_$$($all_attributes$$)?
$all_attributes$$:$attributes$jscomp$73$$}(),$APP.$cljs$cst$4186$token_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6518$$.token),$APP.$cljs$cst$4641$shape_ids$$,$shape_ids__$1$jscomp$2$$],null))):(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6518$$.token),$APP.$cljs$cst$1983$spacing$$)&&$self__$jscomp$6518$$.$attrs$==null?$APP.$cljs$core$with_meta$$($APP.$app$main$data$workspace$tokens$application$apply_spacing_token_separated$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1136$token$$,$self__$jscomp$6518$$.token,$APP.$cljs$cst$2599$attr$$,$self__$jscomp$6518$$.$attrs$,$APP.$cljs$cst$1614$shapes$$,$it$jscomp$253_shapes$jscomp$125_shapes__$1$jscomp$14$$],null)),$APP.$cljs$core$meta$$(this)):$APP.$cljs$core$with_meta$$($APP.$app$main$data$workspace$tokens$application$apply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1993$attributes$$,$APP.$cljs$core$empty_QMARK_$$($self__$jscomp$6518$$.$attrs$)?$attributes$jscomp$73$$:$self__$jscomp$6518$$.$attrs$,
$APP.$cljs$cst$1136$token$$,$self__$jscomp$6518$$.token,$APP.$cljs$cst$4641$shape_ids$$,$shape_ids__$1$jscomp$2$$,$APP.$cljs$cst$4646$on_update_shape$$,$map__72601_map__72601__$1_on_update_shape__$1_state$jscomp$957$$],null)),$APP.$cljs$core$meta$$(this)))});return new $app$main$data$workspace$tokens$application$on_toggle_token_72598$$($p__72593$$,$map__72594__$1$$,$token$jscomp$83$$,$attrs$jscomp$163$$,$shape_ids$jscomp$99$$,$expand_with_children$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$application$all_attrs_appliable_for_token_QMARK_$$=function($attributes$jscomp$75$$,$JSCompiler_inline_result$jscomp$1313_props$jscomp$inline_7354_token_type$jscomp$7$$){$JSCompiler_inline_result$jscomp$1313_props$jscomp$inline_7354_token_type$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,$JSCompiler_inline_result$jscomp$1313_props$jscomp$inline_7354_token_type$jscomp$7$$);var $or__5025__auto__$jscomp$inline_7355$$=
$APP.$cljs$cst$4655$all_attributes$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1313_props$jscomp$inline_7354_token_type$jscomp$7$$);$JSCompiler_inline_result$jscomp$1313_props$jscomp$inline_7354_token_type$jscomp$7$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_7355$$)?$or__5025__auto__$jscomp$inline_7355$$:$APP.$cljs$cst$1993$attributes$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1313_props$jscomp$inline_7354_token_type$jscomp$7$$);return $APP.$clojure$set$subset_QMARK_$$($attributes$jscomp$75$$,
$JSCompiler_inline_result$jscomp$1313_props$jscomp$inline_7354_token_type$jscomp$7$$)};
$APP.$app$common$logic$tokens$generate_update_active_sets$$=function($changes$jscomp$282$$,$hidden_theme_tokens_lib$jscomp$15$$,$hidden_theme_SINGLEQUOTE__update_theme_fn$$){var $G__71883$jscomp$inline_12910_active_token_set_names$$=$APP.$app$common$types$tokens_lib$get_active_themes_set_names$$($hidden_theme_tokens_lib$jscomp$15$$);$hidden_theme_tokens_lib$jscomp$15$$=$app$common$types$tokens_lib$get_hidden_theme$$($hidden_theme_tokens_lib$jscomp$15$$);$G__71883$jscomp$inline_12910_active_token_set_names$$=
$hidden_theme_tokens_lib$jscomp$15$$==null?null:$app$common$types$tokens_lib$set_sets$$($hidden_theme_tokens_lib$jscomp$15$$,$G__71883$jscomp$inline_12910_active_token_set_names$$);$hidden_theme_SINGLEQUOTE__update_theme_fn$$=$hidden_theme_SINGLEQUOTE__update_theme_fn$$.$cljs$core$IFn$_invoke$arity$1$?$hidden_theme_SINGLEQUOTE__update_theme_fn$$.$cljs$core$IFn$_invoke$arity$1$($G__71883$jscomp$inline_12910_active_token_set_names$$):$hidden_theme_SINGLEQUOTE__update_theme_fn$$($G__71883$jscomp$inline_12910_active_token_set_names$$);
return $app$common$files$changes_builder$set_token_theme$$($app$common$files$changes_builder$set_active_token_themes$$($changes$jscomp$282$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$app$common$types$tokens_lib$get_theme_path$$($hidden_theme_SINGLEQUOTE__update_theme_fn$$)])),$APP.$app$common$types$tokens_lib$get_id$$($hidden_theme_tokens_lib$jscomp$15$$),$hidden_theme_SINGLEQUOTE__update_theme_fn$$)};
$app$common$logic$tokens$generate_toggle_token_set$$=function($changes$jscomp$284$$,$tokens_lib$jscomp$17$$,$set_name$jscomp$28$$){return $APP.$app$common$logic$tokens$generate_update_active_sets$$($changes$jscomp$284$$,$tokens_lib$jscomp$17$$,function($p1__71904_SHARP_$$){return $APP.$app$common$types$tokens_lib$toggle_set$$($p1__71904_SHARP_$$,$set_name$jscomp$28$$)})};
$APP.$app$common$logic$tokens$generate_update_active_token_theme$$=function($changes$jscomp$285$$,$G__71905__$1$jscomp$inline_7357_active_token_themes_active_token_themes_SINGLEQUOTE__tokens_lib$jscomp$18$$,$update_fn$jscomp$45$$){$G__71905__$1$jscomp$inline_7357_active_token_themes_active_token_themes_SINGLEQUOTE__tokens_lib$jscomp$18$$=$G__71905__$1$jscomp$inline_7357_active_token_themes_active_token_themes_SINGLEQUOTE__tokens_lib$jscomp$18$$==null?null:$update_fn$jscomp$45$$.$cljs$core$IFn$_invoke$arity$1$?
$update_fn$jscomp$45$$.$cljs$core$IFn$_invoke$arity$1$($G__71905__$1$jscomp$inline_7357_active_token_themes_active_token_themes_SINGLEQUOTE__tokens_lib$jscomp$18$$):$update_fn$jscomp$45$$($G__71905__$1$jscomp$inline_7357_active_token_themes_active_token_themes_SINGLEQUOTE__tokens_lib$jscomp$18$$);$G__71905__$1$jscomp$inline_7357_active_token_themes_active_token_themes_SINGLEQUOTE__tokens_lib$jscomp$18$$=$G__71905__$1$jscomp$inline_7357_active_token_themes_active_token_themes_SINGLEQUOTE__tokens_lib$jscomp$18$$==
null?null:$app$common$types$tokens_lib$get_active_theme_paths$$($G__71905__$1$jscomp$inline_7357_active_token_themes_active_token_themes_SINGLEQUOTE__tokens_lib$jscomp$18$$);$G__71905__$1$jscomp$inline_7357_active_token_themes_active_token_themes_SINGLEQUOTE__tokens_lib$jscomp$18$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__71905__$1$jscomp$inline_7357_active_token_themes_active_token_themes_SINGLEQUOTE__tokens_lib$jscomp$18$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$app$common$types$tokens_lib$hidden_theme_path$$]))?
$G__71905__$1$jscomp$inline_7357_active_token_themes_active_token_themes_SINGLEQUOTE__tokens_lib$jscomp$18$$:$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($G__71905__$1$jscomp$inline_7357_active_token_themes_active_token_themes_SINGLEQUOTE__tokens_lib$jscomp$18$$,$app$common$types$tokens_lib$hidden_theme_path$$);return $app$common$files$changes_builder$set_active_token_themes$$($changes$jscomp$285$$,$G__71905__$1$jscomp$inline_7357_active_token_themes_active_token_themes_SINGLEQUOTE__tokens_lib$jscomp$18$$)};
$app$common$logic$tokens$generate_toggle_token_theme$$=function($changes$jscomp$287$$,$tokens_lib$jscomp$20$$,$id$jscomp$772$$){return $APP.$app$common$logic$tokens$generate_update_active_token_theme$$($changes$jscomp$287$$,$tokens_lib$jscomp$20$$,function($p1__71911_SHARP_$$){return $app$common$types$tokens_lib$toggle_theme_active$$($p1__71911_SHARP_$$,$id$jscomp$772$$)})};
$clojure$data$atom_diff$$=function($a$jscomp$399$$,$b$jscomp$320$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$399$$,$b$jscomp$320$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,null,$a$jscomp$399$$],null):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$a$jscomp$399$$,$b$jscomp$320$$,null],null)};
$clojure$data$vectorize$$=function($m$jscomp$218$$){return $APP.$cljs$core$seq$$($m$jscomp$218$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$321$$,$p__72025_v$jscomp$620$$){var $k$jscomp$663$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72025_v$jscomp$620$$,0,null);$p__72025_v$jscomp$620$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72025_v$jscomp$620$$,1,null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$321$$,
$k$jscomp$663$$,$p__72025_v$jscomp$620$$)},$APP.$cljs$core$vec$$($APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$max$$,$APP.$cljs$core$keys$$($m$jscomp$218$$)),null)),$m$jscomp$218$$):null};
$clojure$data$diff_associative_key$$=function($a$jscomp$400_in_a$$,$b$jscomp$321_in_b$$,$k$jscomp$664$$){var $same_va$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$400_in_a$$,$k$jscomp$664$$),$vb$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$321_in_b$$,$k$jscomp$664$$),$ab$jscomp$2_vec__72032$$=$clojure$data$diff$$($same_va$$,$vb$$),$a_STAR_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ab$jscomp$2_vec__72032$$,0,null),$b_STAR_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ab$jscomp$2_vec__72032$$,
1,null);$ab$jscomp$2_vec__72032$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ab$jscomp$2_vec__72032$$,2,null);$a$jscomp$400_in_a$$=$APP.$cljs$core$contains_QMARK_$$($a$jscomp$400_in_a$$,$k$jscomp$664$$);$b$jscomp$321_in_b$$=$APP.$cljs$core$contains_QMARK_$$($b$jscomp$321_in_b$$,$k$jscomp$664$$);$same_va$$=$a$jscomp$400_in_a$$&&$b$jscomp$321_in_b$$&&($ab$jscomp$2_vec__72032$$!=null||$same_va$$==null&&$vb$$==null);return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[!$a$jscomp$400_in_a$$||$a_STAR_$$==null&&$same_va$$?null:$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$k$jscomp$664$$,$a_STAR_$$]),!$b$jscomp$321_in_b$$||$b_STAR_$$==null&&$same_va$$?null:$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$k$jscomp$664$$,$b_STAR_$$]),$same_va$$?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$k$jscomp$664$$,$ab$jscomp$2_vec__72032$$]):null],null)};
$clojure$data$diff_sequential$$=function($a$jscomp$403_x__5110__auto__$jscomp$inline_7359$$,$b$jscomp$324_y__5111__auto__$jscomp$inline_7360$$){var $JSCompiler_temp_const$jscomp$1318$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$,$JSCompiler_temp_const$jscomp$1316$$=$clojure$data$diff_associative$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1315$$=$APP.$cljs$core$vector_QMARK_$$($a$jscomp$403_x__5110__auto__$jscomp$inline_7359$$)?$a$jscomp$403_x__5110__auto__$jscomp$inline_7359$$:
$APP.$cljs$core$vec$$($a$jscomp$403_x__5110__auto__$jscomp$inline_7359$$),$JSCompiler_temp_const$jscomp$1314$$=$APP.$cljs$core$vector_QMARK_$$($b$jscomp$324_y__5111__auto__$jscomp$inline_7360$$)?$b$jscomp$324_y__5111__auto__$jscomp$inline_7360$$:$APP.$cljs$core$vec$$($b$jscomp$324_y__5111__auto__$jscomp$inline_7360$$);$a$jscomp$403_x__5110__auto__$jscomp$inline_7359$$=$APP.$cljs$core$count$$($a$jscomp$403_x__5110__auto__$jscomp$inline_7359$$);$b$jscomp$324_y__5111__auto__$jscomp$inline_7360$$=$APP.$cljs$core$count$$($b$jscomp$324_y__5111__auto__$jscomp$inline_7360$$);
return $APP.$cljs$core$vec$$($JSCompiler_temp_const$jscomp$1318$$.call($APP.$cljs$core$map$$,$clojure$data$vectorize$$,$JSCompiler_temp_const$jscomp$1316$$.call($clojure$data$diff_associative$$,$JSCompiler_temp_const$jscomp$1315$$,$JSCompiler_temp_const$jscomp$1314$$,$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($a$jscomp$403_x__5110__auto__$jscomp$inline_7359$$>$b$jscomp$324_y__5111__auto__$jscomp$inline_7360$$?$a$jscomp$403_x__5110__auto__$jscomp$inline_7359$$:$b$jscomp$324_y__5111__auto__$jscomp$inline_7360$$))))};
$clojure$data$diff_set$$=function($a$jscomp$404$$,$b$jscomp$325$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$not_empty$$($APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$404$$,$b$jscomp$325$$)),$APP.$cljs$core$not_empty$$($APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$325$$,$a$jscomp$404$$)),$APP.$cljs$core$not_empty$$($APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$404$$,
$b$jscomp$325$$))],null)};
$clojure$data$equality_partition$$=function($JSCompiler_temp$jscomp$1321_x$jscomp$1218$$){if($JSCompiler_temp$jscomp$1321_x$jscomp$1218$$!=null&&$JSCompiler_temp$jscomp$1321_x$jscomp$1218$$.$clojure$data$EqualityPartition$equality_partition$arity$1$!=null)$JSCompiler_temp$jscomp$1321_x$jscomp$1218$$=$JSCompiler_temp$jscomp$1321_x$jscomp$1218$$.$clojure$data$EqualityPartition$equality_partition$arity$1$($JSCompiler_temp$jscomp$1321_x$jscomp$1218$$);else{var $m__5372__auto__$jscomp$inline_7364_m__5374__auto__$jscomp$inline_7363$$=$clojure$data$equality_partition$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1321_x$jscomp$1218$$==
null?null:$JSCompiler_temp$jscomp$1321_x$jscomp$1218$$)];if($m__5372__auto__$jscomp$inline_7364_m__5374__auto__$jscomp$inline_7363$$!=null)$JSCompiler_temp$jscomp$1321_x$jscomp$1218$$=$m__5372__auto__$jscomp$inline_7364_m__5374__auto__$jscomp$inline_7363$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_7364_m__5374__auto__$jscomp$inline_7363$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1321_x$jscomp$1218$$):$m__5372__auto__$jscomp$inline_7364_m__5374__auto__$jscomp$inline_7363$$($JSCompiler_temp$jscomp$1321_x$jscomp$1218$$);
else if($m__5372__auto__$jscomp$inline_7364_m__5374__auto__$jscomp$inline_7363$$=$clojure$data$equality_partition$$._,$m__5372__auto__$jscomp$inline_7364_m__5374__auto__$jscomp$inline_7363$$!=null)$JSCompiler_temp$jscomp$1321_x$jscomp$1218$$=$m__5372__auto__$jscomp$inline_7364_m__5374__auto__$jscomp$inline_7363$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_7364_m__5374__auto__$jscomp$inline_7363$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1321_x$jscomp$1218$$):$m__5372__auto__$jscomp$inline_7364_m__5374__auto__$jscomp$inline_7363$$($JSCompiler_temp$jscomp$1321_x$jscomp$1218$$);
else throw $APP.$cljs$core$missing_protocol$$("EqualityPartition.equality-partition",$JSCompiler_temp$jscomp$1321_x$jscomp$1218$$);}return $JSCompiler_temp$jscomp$1321_x$jscomp$1218$$};
$clojure$data$diff_similar$$=function($JSCompiler_temp$jscomp$1322_a$jscomp$406$$,$b$jscomp$327$$){if($JSCompiler_temp$jscomp$1322_a$jscomp$406$$!=null&&$JSCompiler_temp$jscomp$1322_a$jscomp$406$$.$clojure$data$Diff$diff_similar$arity$2$!=null)$JSCompiler_temp$jscomp$1322_a$jscomp$406$$=$JSCompiler_temp$jscomp$1322_a$jscomp$406$$.$clojure$data$Diff$diff_similar$arity$2$($JSCompiler_temp$jscomp$1322_a$jscomp$406$$,$b$jscomp$327$$);else{var $m__5372__auto__$jscomp$inline_7369_m__5374__auto__$jscomp$inline_7368$$=
$clojure$data$diff_similar$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1322_a$jscomp$406$$==null?null:$JSCompiler_temp$jscomp$1322_a$jscomp$406$$)];if($m__5372__auto__$jscomp$inline_7369_m__5374__auto__$jscomp$inline_7368$$!=null)$JSCompiler_temp$jscomp$1322_a$jscomp$406$$=$m__5372__auto__$jscomp$inline_7369_m__5374__auto__$jscomp$inline_7368$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_7369_m__5374__auto__$jscomp$inline_7368$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1322_a$jscomp$406$$,
$b$jscomp$327$$):$m__5372__auto__$jscomp$inline_7369_m__5374__auto__$jscomp$inline_7368$$($JSCompiler_temp$jscomp$1322_a$jscomp$406$$,$b$jscomp$327$$);else if($m__5372__auto__$jscomp$inline_7369_m__5374__auto__$jscomp$inline_7368$$=$clojure$data$diff_similar$$._,$m__5372__auto__$jscomp$inline_7369_m__5374__auto__$jscomp$inline_7368$$!=null)$JSCompiler_temp$jscomp$1322_a$jscomp$406$$=$m__5372__auto__$jscomp$inline_7369_m__5374__auto__$jscomp$inline_7368$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_7369_m__5374__auto__$jscomp$inline_7368$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1322_a$jscomp$406$$,
$b$jscomp$327$$):$m__5372__auto__$jscomp$inline_7369_m__5374__auto__$jscomp$inline_7368$$($JSCompiler_temp$jscomp$1322_a$jscomp$406$$,$b$jscomp$327$$);else throw $APP.$cljs$core$missing_protocol$$("Diff.diff-similar",$JSCompiler_temp$jscomp$1322_a$jscomp$406$$);}return $JSCompiler_temp$jscomp$1322_a$jscomp$406$$};
$clojure$data$diff$$=function($a$jscomp$414$$,$b$jscomp$335$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$414$$,$b$jscomp$335$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,null,$a$jscomp$414$$],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($clojure$data$equality_partition$$($a$jscomp$414$$),$clojure$data$equality_partition$$($b$jscomp$335$$))?$clojure$data$diff_similar$$($a$jscomp$414$$,$b$jscomp$335$$):
$clojure$data$atom_diff$$($a$jscomp$414$$,$b$jscomp$335$$)};
$app$main$data$workspace$tokens$propagation$invert_collect_key_vals$$=function($xs$jscomp$34$$,$resolved_tokens$jscomp$3$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$140$$,$p__72660_v$jscomp$621$$){var $k$jscomp$666$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72660_v$jscomp$621$$,0,null);$p__72660_v$jscomp$621$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72660_v$jscomp$621$$,1,null);var $resolved_token_resolved_value$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$3$$,$p__72660_v$jscomp$621$$);$resolved_token_resolved_value$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_token_resolved_value$jscomp$1$$,$APP.$cljs$cst$4605$resolved_value$$);return $APP.$cljs$core$not$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$3$$,$p__72660_v$jscomp$621$$))?$acc$jscomp$140$$:$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($acc$jscomp$140$$,
$resolved_token_resolved_value$jscomp$1$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$k$jscomp$666$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$xs$jscomp$34$$)};
$app$main$data$workspace$tokens$propagation$split_attribute_groups$$=function($attrs_values_map$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($G__72671_G__72678__$1_G__72678__$2_acc$jscomp$141$$,$p__72664_v$jscomp$622$$){var $a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72664_v$jscomp$622$$,0,null);$p__72664_v$jscomp$622$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72664_v$jscomp$622$$,
1,null);if($APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1522$height$$,null],null),null)))){var $b$jscomp$338_position$jscomp$168_rst$jscomp$3_vec__72668$$=$clojure$data$diff$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,null,
$APP.$cljs$cst$1522$height$$,null],null),null),$a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$338_position$jscomp$168_rst$jscomp$3_vec__72668$$,0,null);$a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$338_position$jscomp$168_rst$jscomp$3_vec__72668$$,1,null);$b$jscomp$338_position$jscomp$168_rst$jscomp$3_vec__72668$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$338_position$jscomp$168_rst$jscomp$3_vec__72668$$,
2,null);$G__72671_G__72678__$1_G__72678__$2_acc$jscomp$141$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__72671_G__72678__$1_G__72678__$2_acc$jscomp$141$$,$b$jscomp$338_position$jscomp$168_rst$jscomp$3_vec__72668$$,$p__72664_v$jscomp$622$$);return $APP.$cljs$core$truth_$$($a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__72671_G__72678__$1_G__72678__$2_acc$jscomp$141$$,$a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$,
$p__72664_v$jscomp$622$$):$G__72671_G__72678__$1_G__72678__$2_acc$jscomp$141$$}if($APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$,$app$common$types$token$spacing_keys$$))){$a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$=$clojure$data$diff$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1682$column_gap$$,null,$APP.$cljs$cst$1681$row_gap$$,null],null),null),$a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$);
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$,0,null);$b$jscomp$338_position$jscomp$168_rst$jscomp$3_vec__72668$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$,1,null);$a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$,2,null);var $padding$jscomp$9_vec__72675$$=
$clojure$data$diff$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1091$p2$$,null,$APP.$cljs$cst$1688$p4$$,null,$APP.$cljs$cst$1687$p3$$,null,$APP.$cljs$cst$1093$p1$$,null],null),null),$b$jscomp$338_position$jscomp$168_rst$jscomp$3_vec__72668$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($padding$jscomp$9_vec__72675$$,0,null);$b$jscomp$338_position$jscomp$168_rst$jscomp$3_vec__72668$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($padding$jscomp$9_vec__72675$$,
1,null);$padding$jscomp$9_vec__72675$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($padding$jscomp$9_vec__72675$$,2,null);$G__72671_G__72678__$1_G__72678__$2_acc$jscomp$141$$=$APP.$cljs$core$seq$$($a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__72671_G__72678__$1_G__72678__$2_acc$jscomp$141$$,$a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$,$p__72664_v$jscomp$622$$):$G__72671_G__72678__$1_G__72678__$2_acc$jscomp$141$$;
$G__72671_G__72678__$1_G__72678__$2_acc$jscomp$141$$=$APP.$cljs$core$seq$$($b$jscomp$338_position$jscomp$168_rst$jscomp$3_vec__72668$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__72671_G__72678__$1_G__72678__$2_acc$jscomp$141$$,$b$jscomp$338_position$jscomp$168_rst$jscomp$3_vec__72668$$,$p__72664_v$jscomp$622$$):$G__72671_G__72678__$1_G__72678__$2_acc$jscomp$141$$;return $APP.$cljs$core$seq$$($padding$jscomp$9_vec__72675$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__72671_G__72678__$1_G__72678__$2_acc$jscomp$141$$,
$padding$jscomp$9_vec__72675$$,$p__72664_v$jscomp$622$$):$G__72671_G__72678__$1_G__72678__$2_acc$jscomp$141$$}return $APP.$cljs$core$truth_$$($a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__72671_G__72678__$1_G__72678__$2_acc$jscomp$141$$,$a$jscomp$417_attrs$jscomp$167_gap$jscomp$4_vec__72672$$,$p__72664_v$jscomp$622$$):null},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$attrs_values_map$$)};
$app$main$data$workspace$tokens$propagation$shape_ids_by_values$$=function($attrs_values_map$jscomp$1$$,$object_id$jscomp$27$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($attrs$jscomp$168_p__72684$$){var $value$jscomp$724$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attrs$jscomp$168_p__72684$$,0,null);$attrs$jscomp$168_p__72684$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attrs$jscomp$168_p__72684$$,
1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$attrs$jscomp$168_p__72684$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$value$jscomp$724$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$object_id$jscomp$27$$])])],null)},$attrs_values_map$jscomp$1$$))};
$app$main$data$workspace$tokens$propagation$collect_shapes_update_info$$=function($resolved_tokens$jscomp$4$$,$objects$jscomp$678$$){for(var $G__72736_items$jscomp$50$$=$APP.$cljs$core$seq$$($objects$jscomp$678$$),$G__72737_frame_ids$jscomp$5$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$,$G__72738_text_ids$jscomp$5$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$G__72739_tokens$jscomp$36$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;;){var $shape_id$jscomp$131_temp__5823__auto__$jscomp$197$$=$APP.$cljs$core$first$$($G__72736_items$jscomp$50$$);
if($APP.$cljs$core$truth_$$($shape_id$jscomp$131_temp__5823__auto__$jscomp$197$$)){var $map__72695_shape$jscomp$773_vec__72692$$=$shape_id$jscomp$131_temp__5823__auto__$jscomp$197$$;$shape_id$jscomp$131_temp__5823__auto__$jscomp$197$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__72695_shape$jscomp$773_vec__72692$$,0,null);$map__72695_shape$jscomp$773_vec__72692$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__72695_shape$jscomp$773_vec__72692$$,1,null);var $applied_tokens$jscomp$4_applied_tokens__$1_map__72695__$1$$=
$APP.$cljs$core$__destructure_map$$($map__72695_shape$jscomp$773_vec__72692$$);$map__72695_shape$jscomp$773_vec__72692$$=$applied_tokens$jscomp$4_applied_tokens__$1_map__72695__$1$$;$applied_tokens$jscomp$4_applied_tokens__$1_map__72695__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$4_applied_tokens__$1_map__72695__$1$$,$APP.$cljs$cst$1873$applied_tokens$$);$applied_tokens$jscomp$4_applied_tokens__$1_map__72695__$1$$=$app$main$data$workspace$tokens$propagation$split_attribute_groups$$($app$main$data$workspace$tokens$propagation$shape_ids_by_values$$($app$main$data$workspace$tokens$propagation$invert_collect_key_vals$$($applied_tokens$jscomp$4_applied_tokens__$1_map__72695__$1$$,
$resolved_tokens$jscomp$4$$),$shape_id$jscomp$131_temp__5823__auto__$jscomp$197$$));var $parent_frame_id$jscomp$3$$=$APP.$app$common$files$helpers$get_shape_id_root_frame$$($objects$jscomp$678$$,$shape_id$jscomp$131_temp__5823__auto__$jscomp$197$$);$G__72736_items$jscomp$50$$=$APP.$cljs$core$rest$$($G__72736_items$jscomp$50$$);$G__72737_frame_ids$jscomp$5$$=$APP.$cljs$core$truth_$$($parent_frame_id$jscomp$3$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__72737_frame_ids$jscomp$5$$,$parent_frame_id$jscomp$3$$):
$G__72737_frame_ids$jscomp$5$$;$G__72738_text_ids$jscomp$5$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__72695_shape$jscomp$773_vec__72692$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__72738_text_ids$jscomp$5$$,$shape_id$jscomp$131_temp__5823__auto__$jscomp$197$$):$G__72738_text_ids$jscomp$5$$;$G__72739_tokens$jscomp$36$$=$app$main$data$workspace$tokens$propagation$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$($G__72739_tokens$jscomp$36$$,
$applied_tokens$jscomp$4_applied_tokens__$1_map__72695__$1$$)}else return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__72739_tokens$jscomp$36$$,$G__72737_frame_ids$jscomp$5$$,$G__72738_text_ids$jscomp$5$$],null)}};
$app$main$data$workspace$tokens$propagation$actionize_shapes_update_info$$=function($page_id$jscomp$332$$,$shapes_update_info$$){return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p__72698_update_infos$$){var $attrs$jscomp$169$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72698_update_infos$$,0,null);$p__72698_update_infos$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72698_update_infos$$,1,null);var $action$jscomp$1$$=$APP.$cljs$core$some$$($app$main$data$workspace$tokens$propagation$attribute_actions_map$$,
$attrs$jscomp$169$$);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__72702_shape_ids$jscomp$104$$){var $v$jscomp$623$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72702_shape_ids$jscomp$104$$,0,null);$p__72702_shape_ids$jscomp$104$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72702_shape_ids$jscomp$104$$,1,null);return $action$jscomp$1$$.$cljs$core$IFn$_invoke$arity$4$?$action$jscomp$1$$.$cljs$core$IFn$_invoke$arity$4$($v$jscomp$623$$,$p__72702_shape_ids$jscomp$104$$,
$attrs$jscomp$169$$,$page_id$jscomp$332$$):$action$jscomp$1$$($v$jscomp$623$$,$p__72702_shape_ids$jscomp$104$$,$attrs$jscomp$169$$,$page_id$jscomp$332$$)},$p__72698_update_infos$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shapes_update_info$$]))};
$app$main$data$workspace$tokens$propagation$propagate_tokens$$=function($state$jscomp$959$$,$resolved_tokens$jscomp$5$$){var $file_id$jscomp$298$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$959$$,$APP.$cljs$cst$1917$current_file_id$$),$current_page_id$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$959$$,$APP.$cljs$cst$1918$current_page_id$$),$fdata$jscomp$20$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$959$$,
$file_id$jscomp$298$$),$tpoint$jscomp$3$$=$app$common$time$tpoint_ms$$();$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.tokens.propagation",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$109$status$$,"START"],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"propagate-tokens"],null)],null)}),null,"app.main.data.workspace.tokens.propagation",$APP.$cljs$cst$1161$info$$,!1);return $APP.$beicon$v2$core$finalize$$(function(){var $elapsed$jscomp$3$$=$tpoint$jscomp$3$$();$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.tokens.propagation",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$109$status$$,"END"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"propagate-tokens"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2278$elapsed$$,$elapsed$jscomp$3$$],null)],null)}),null,"app.main.data.workspace.tokens.propagation",
$APP.$cljs$cst$1161$info$$,!1);return null},$APP.$beicon$v2$core$mapcat$$(function($page_id$jscomp$333$$){var $frame_ids$jscomp$6_page$jscomp$107$$=$APP.$app$main$data$helpers$get_page$$($fdata$jscomp$20$$,$page_id$jscomp$333$$),$text_ids$jscomp$6_vec__72710$$=$app$main$data$workspace$tokens$propagation$collect_shapes_update_info$$($resolved_tokens$jscomp$5$$,$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($frame_ids$jscomp$6_page$jscomp$107$$)),$actions$jscomp$3_attrs$jscomp$170_map__72713_observable$jscomp$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_ids$jscomp$6_vec__72710$$,0,null);$frame_ids$jscomp$6_page$jscomp$107$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_ids$jscomp$6_vec__72710$$,1,null);$text_ids$jscomp$6_vec__72710$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_ids$jscomp$6_vec__72710$$,2,null);$actions$jscomp$3_attrs$jscomp$170_map__72713_observable$jscomp$2$$=$app$main$data$workspace$tokens$propagation$actionize_shapes_update_info$$($page_id$jscomp$333$$,
$actions$jscomp$3_attrs$jscomp$170_map__72713_observable$jscomp$2$$);$actions$jscomp$3_attrs$jscomp$170_map__72713_observable$jscomp$2$$=$APP.$cljs$core$group_by$$(function($p1__72706_SHARP_$$){return $p1__72706_SHARP_$$ instanceof $beicon$v2$core$Observable$$?$cljs$cst$4682$observable$$:$APP.$cljs$cst$2023$normal$$},$actions$jscomp$3_attrs$jscomp$170_map__72713_observable$jscomp$2$$);var $map__72713__$1_normal$$=$APP.$cljs$core$__destructure_map$$($actions$jscomp$3_attrs$jscomp$170_map__72713_observable$jscomp$2$$);
$actions$jscomp$3_attrs$jscomp$170_map__72713_observable$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72713__$1_normal$$,$cljs$cst$4682$observable$$);$map__72713__$1_normal$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72713__$1_normal$$,$APP.$cljs$cst$2023$normal$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.tokens.propagation",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$109$status$$,"PROGRESS"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"propagate-tokens"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$333$$)],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2278$elapsed$$,$tpoint$jscomp$3$$()],null)],null)}),null,"app.main.data.workspace.tokens.propagation",$APP.$cljs$cst$1161$info$$,!0);return $APP.$beicon$v2$core$merge$$($APP.$cljs$core$seq$$($actions$jscomp$3_attrs$jscomp$170_map__72713_observable$jscomp$2$$)?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$beicon$v2$core$merge$$,$actions$jscomp$3_attrs$jscomp$170_map__72713_observable$jscomp$2$$):
null,$APP.$cljs$core$seq$$($map__72713__$1_normal$$)?$beicon$v2$core$concat_all$$((0,$APP.$beicon$v2$core$of$$)($map__72713__$1_normal$$)):null,$APP.$beicon$v2$core$mapcat$$(function($frame_id$jscomp$109$$){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$thumbnails$clear_thumbnail$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$298$$,$page_id$jscomp$333$$,$frame_id$jscomp$109$$,"frame"),$app$main$data$workspace$thumbnails$clear_thumbnail$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$298$$,
$page_id$jscomp$333$$,$frame_id$jscomp$109$$,"component"))},$APP.$beicon$v2$core$from$$($frame_ids$jscomp$6_page$jscomp$107$$)),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$333$$,$current_page_id$jscomp$1$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($text_ids$jscomp$6_vec__72710$$,function($shape$jscomp$774$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$774$$,
$APP.$cljs$cst$1891$position_data$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$333$$,$APP.$cljs$cst$2556$ignore_touched$$,!0],null))):null)},$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($current_page_id$jscomp$1$$),$APP.$beicon$v2$core$filter$$(function($id$jscomp$777$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$777$$,$current_page_id$jscomp$1$$)},$APP.$beicon$v2$core$from$$($APP.$cljs$cst$2228$pages$$.$cljs$core$IFn$_invoke$arity$1$($fdata$jscomp$20$$))))))};
$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$=function(){typeof $app$main$data$workspace$tokens$propagation$propagate_workspace_tokens_72716$$==="undefined"&&($app$main$data$workspace$tokens$propagation$propagate_workspace_tokens_72716$$=function($meta72717$$){this.$meta72717$=$meta72717$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens_72716$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens_72716$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4683$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_propagation_SLASH_propagate_workspace_tokens$$},$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens_72716$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72718$$,$meta72717__$1$$){return new $app$main$data$workspace$tokens$propagation$propagate_workspace_tokens_72716$$($meta72717__$1$$)},
$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens_72716$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72717$},$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens_72716$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens_72716$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2644_temp__5825__auto__$jscomp$243$$,$state$jscomp$960$$){$_$jscomp$2644_temp__5825__auto__$jscomp$243$$=
$APP.$app$common$types$tokens_lib$get_tokens_in_active_sets$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$960$$),$APP.$cljs$cst$2139$tokens_lib$$));return $APP.$cljs$core$truth_$$($_$jscomp$2644_temp__5825__auto__$jscomp$243$$)?$APP.$beicon$v2$core$mapcat$$(function($sd_tokens$jscomp$1$$){var $undo_id$jscomp$88$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$undo$start_undo_transaction$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($undo_id$jscomp$88$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2353$timeout$$,!1]))),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$shapes$update_shapes_buffer_start$$()),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__72715_SHARP_$$){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$shapes$update_shapes_buffer_stop$$()),$APP.$beicon$v2$core$throw$0$$($p1__72715_SHARP_$$))},$app$main$data$workspace$tokens$propagation$propagate_tokens$$($state$jscomp$960$$,
$sd_tokens$jscomp$1$$)),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$shapes$update_shapes_buffer_stop$$()),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$88$$)))},$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4627$tokenscript$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$common$data$update_vals$$($APP.$app$main$data$tokenscript$resolve_tokens$$($_$jscomp$2644_temp__5825__auto__$jscomp$243$$),function($p1__72714_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__72714_SHARP_$$,
$APP.$cljs$cst$4605$resolved_value$$,$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$)})):$app$main$data$style_dictionary$resolve_tokens$$($_$jscomp$2644_temp__5825__auto__$jscomp$243$$)):null});return new $app$main$data$workspace$tokens$propagation$propagate_workspace_tokens_72716$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$=function($state$jscomp$961$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$961$$),$APP.$cljs$cst$2139$tokens_lib$$)};
$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$01$$=function($state$jscomp$962$$){var $temp__5825__auto__$jscomp$244$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$962$$,$APP.$cljs$cst$2137$workspace_tokens$$),$APP.$cljs$cst$2138$selected_token_set_id$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$244$$)?$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$962$$,
$temp__5825__auto__$jscomp$244$$):null};$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$02$$=function($G__72728_state$jscomp$963$$,$id$jscomp$778$$){$G__72728_state$jscomp$963$$=$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($G__72728_state$jscomp$963$$);return $G__72728_state$jscomp$963$$==null?null:$APP.$app$common$types$tokens_lib$get_set$$($G__72728_state$jscomp$963$$,$id$jscomp$778$$)};
$APP.$app$main$data$workspace$tokens$library_edit$make_unfolded_token_types_state$$=function($file_id$jscomp$301$$,$set_id$jscomp$27$$,$types$jscomp$6$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$301$$,$APP.$cljs$cst$2643$set_id$$,$set_id$jscomp$27$$,$APP.$cljs$cst$925$types$$,$APP.$cljs$core$set$$($APP.$cljs$core$truth_$$($types$jscomp$6$$)?$types$jscomp$6$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$)],null)};
$APP.$app$main$data$workspace$tokens$library_edit$remove_path$$=function($path$jscomp$246$$,$paths$jscomp$3$$){return $APP.$cljs$core$vec$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__72777_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__72777_SHARP_$$,$path$jscomp$246$$)},$paths$jscomp$3$$))};
$APP.$app$main$data$workspace$tokens$library_edit$toggle_token_path$$=function($path$jscomp$248$$){typeof $app$main$data$workspace$tokens$library_edit$toggle_token_path_72785$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$toggle_token_path_72785$$=function($path$jscomp$249$$,$meta72786$$){this.path=$path$jscomp$249$$;this.$meta72786$=$meta72786$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$toggle_token_path_72785$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_token_path_72785$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4694$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_path$$},$app$main$data$workspace$tokens$library_edit$toggle_token_path_72785$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72787$$,$meta72786__$1$$){return new $app$main$data$workspace$tokens$library_edit$toggle_token_path_72785$$(this.path,
$meta72786__$1$$)},$app$main$data$workspace$tokens$library_edit$toggle_token_path_72785$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72786$},$app$main$data$workspace$tokens$library_edit$toggle_token_path_72785$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_token_path_72785$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2652$$,$state$jscomp$971$$){var $self__$jscomp$6562$$=
this;return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$971$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$4693$folded_token_paths$$],null),function($paths$jscomp$5_paths__$1$$){$paths$jscomp$5_paths__$1$$=$APP.$cljs$core$truth_$$($paths$jscomp$5_paths__$1$$)?$paths$jscomp$5_paths__$1$$:$APP.$cljs$core$PersistentVector$EMPTY$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__72784_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__72784_SHARP_$$,
$self__$jscomp$6562$$.path)},$paths$jscomp$5_paths__$1$$))?$APP.$app$main$data$workspace$tokens$library_edit$remove_path$$($self__$jscomp$6562$$.path,$paths$jscomp$5_paths__$1$$):$APP.$cljs$core$vec$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($paths$jscomp$5_paths__$1$$,$self__$jscomp$6562$$.path))})});return new $app$main$data$workspace$tokens$library_edit$toggle_token_path_72785$$($path$jscomp$248$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$library_edit$create_token_theme$$=function($token_theme$jscomp$4$$){typeof $app$main$data$workspace$tokens$library_edit$create_token_theme_72791$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$create_token_theme_72791$$=function($token_theme$jscomp$5$$,$new_token_theme$jscomp$1$$,$meta72792$$){this.$token_theme$=$token_theme$jscomp$5$$;this.$new_token_theme$=$new_token_theme$jscomp$1$$;this.$meta72792$=$meta72792$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$create_token_theme_72791$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$create_token_theme_72791$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4696$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_create_token_theme$$},$app$main$data$workspace$tokens$library_edit$create_token_theme_72791$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72793$$,$meta72792__$1$$){return new $app$main$data$workspace$tokens$library_edit$create_token_theme_72791$$(this.$token_theme$,this.$new_token_theme$,$meta72792__$1$$)},$app$main$data$workspace$tokens$library_edit$create_token_theme_72791$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72792$},$app$main$data$workspace$tokens$library_edit$create_token_theme_72791$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$create_token_theme_72791$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$292_data$jscomp$408_it$jscomp$254$$,$state$jscomp$973_tokens_lib$jscomp$27$$){$changes$jscomp$292_data$jscomp$408_it$jscomp$254$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$973_tokens_lib$jscomp$27$$);$state$jscomp$973_tokens_lib$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$292_data$jscomp$408_it$jscomp$254$$,$APP.$cljs$cst$2139$tokens_lib$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($state$jscomp$973_tokens_lib$jscomp$27$$)?
$APP.$app$common$types$tokens_lib$get_theme$$($state$jscomp$973_tokens_lib$jscomp$27$$,$APP.$app$common$types$tokens_lib$get_id$$(this.$token_theme$)):$state$jscomp$973_tokens_lib$jscomp$27$$))return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.token-theme-already-exists"),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,
$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2353$timeout$$,9E3],null)));$changes$jscomp$292_data$jscomp$408_it$jscomp$254$$=$app$common$files$changes_builder$set_token_theme$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$292_data$jscomp$408_it$jscomp$254$$),$APP.$app$common$types$tokens_lib$get_id$$(this.$new_token_theme$),this.$new_token_theme$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$292_data$jscomp$408_it$jscomp$254$$))});
return new $app$main$data$workspace$tokens$library_edit$create_token_theme_72791$$($token_theme$jscomp$4$$,$token_theme$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$library_edit$update_token_theme$$=function($id$jscomp$781$$,$token_theme$jscomp$6$$){typeof $app$main$data$workspace$tokens$library_edit$update_token_theme_72794$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$update_token_theme_72794$$=function($id$jscomp$782$$,$token_theme$jscomp$7$$,$meta72795$$){this.id=$id$jscomp$782$$;this.$token_theme$=$token_theme$jscomp$7$$;this.$meta72795$=$meta72795$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$update_token_theme_72794$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$update_token_theme_72794$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4697$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_update_token_theme$$},$app$main$data$workspace$tokens$library_edit$update_token_theme_72794$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72796$$,$meta72795__$1$$){return new $app$main$data$workspace$tokens$library_edit$update_token_theme_72794$$(this.id,this.$token_theme$,$meta72795__$1$$)},$app$main$data$workspace$tokens$library_edit$update_token_theme_72794$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72795$},$app$main$data$workspace$tokens$library_edit$update_token_theme_72794$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$update_token_theme_72794$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$293_data$jscomp$409_it$jscomp$255$$,$JSCompiler_inline_result$jscomp$1323_state$jscomp$974_tokens_lib$jscomp$28$$){$changes$jscomp$293_data$jscomp$409_it$jscomp$255$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1323_state$jscomp$974_tokens_lib$jscomp$28$$);$JSCompiler_inline_result$jscomp$1323_state$jscomp$974_tokens_lib$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$293_data$jscomp$409_it$jscomp$255$$,
$APP.$cljs$cst$2139$tokens_lib$$);var $and__5023__auto__$jscomp$inline_7371$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.id,$APP.$app$common$types$tokens_lib$get_id$$(this.$token_theme$));$JSCompiler_inline_result$jscomp$1323_state$jscomp$974_tokens_lib$jscomp$28$$=$and__5023__auto__$jscomp$inline_7371$$?$APP.$app$common$types$tokens_lib$get_theme$$($JSCompiler_inline_result$jscomp$1323_state$jscomp$974_tokens_lib$jscomp$28$$,$APP.$app$common$types$tokens_lib$get_id$$(this.$token_theme$)):
$and__5023__auto__$jscomp$inline_7371$$;if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1323_state$jscomp$974_tokens_lib$jscomp$28$$))return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.token-theme-already-exists"),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,
$APP.$cljs$cst$2353$timeout$$,9E3],null)));$changes$jscomp$293_data$jscomp$409_it$jscomp$255$$=$app$common$files$changes_builder$set_token_theme$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$293_data$jscomp$409_it$jscomp$255$$),$APP.$app$common$types$tokens_lib$get_id$$(this.$token_theme$),this.$token_theme$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$293_data$jscomp$409_it$jscomp$255$$))});
return new $app$main$data$workspace$tokens$library_edit$update_token_theme_72794$$($id$jscomp$781$$,$token_theme$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active$$=function($id$jscomp$785$$){typeof $app$main$data$workspace$tokens$library_edit$toggle_token_theme_active_72802$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$toggle_token_theme_active_72802$$=function($id$jscomp$786$$,$meta72803$$){this.id=$id$jscomp$786$$;this.$meta72803$=$meta72803$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active_72802$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active_72802$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4699$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_theme_active$$},$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active_72802$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72804$$,$meta72803__$1$$){return new $app$main$data$workspace$tokens$library_edit$toggle_token_theme_active_72802$$(this.id,
$meta72803__$1$$)},$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active_72802$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72803$},$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active_72802$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active_72802$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($data$jscomp$411_it$jscomp$256$$,
$changes$jscomp$295_state$jscomp$976_tokens_lib$jscomp$30$$){$data$jscomp$411_it$jscomp$256$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$295_state$jscomp$976_tokens_lib$jscomp$30$$);$changes$jscomp$295_state$jscomp$976_tokens_lib$jscomp$30$$=$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($changes$jscomp$295_state$jscomp$976_tokens_lib$jscomp$30$$);$changes$jscomp$295_state$jscomp$976_tokens_lib$jscomp$30$$=$app$common$logic$tokens$generate_toggle_token_theme$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$data$jscomp$411_it$jscomp$256$$),$changes$jscomp$295_state$jscomp$976_tokens_lib$jscomp$30$$,this.id);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$295_state$jscomp$976_tokens_lib$jscomp$30$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())});return new $app$main$data$workspace$tokens$library_edit$toggle_token_theme_active_72802$$($id$jscomp$785$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$library_edit$delete_token_theme$$=function($id$jscomp$787$$){typeof $app$main$data$workspace$tokens$library_edit$delete_token_theme_72805$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$delete_token_theme_72805$$=function($id$jscomp$788$$,$meta72806$$){this.id=$id$jscomp$788$$;this.$meta72806$=$meta72806$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$delete_token_theme_72805$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$delete_token_theme_72805$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4700$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_delete_token_theme$$},$app$main$data$workspace$tokens$library_edit$delete_token_theme_72805$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72807$$,$meta72806__$1$$){return new $app$main$data$workspace$tokens$library_edit$delete_token_theme_72805$$(this.id,
$meta72806__$1$$)},$app$main$data$workspace$tokens$library_edit$delete_token_theme_72805$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72806$},$app$main$data$workspace$tokens$library_edit$delete_token_theme_72805$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$delete_token_theme_72805$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$296_data$jscomp$412_it$jscomp$257$$,$state$jscomp$977$$){$changes$jscomp$296_data$jscomp$412_it$jscomp$257$$=
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$977$$);$changes$jscomp$296_data$jscomp$412_it$jscomp$257$$=$app$common$files$changes_builder$set_token_theme$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$296_data$jscomp$412_it$jscomp$257$$),this.id,null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$296_data$jscomp$412_it$jscomp$257$$),
$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())});return new $app$main$data$workspace$tokens$library_edit$delete_token_theme_72805$$($id$jscomp$787$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$library_edit$create_token_set$$=function($token_set$jscomp$8$$){typeof $app$main$data$workspace$tokens$library_edit$create_token_set_72812$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$create_token_set_72812$$=function($token_set$jscomp$9$$,$meta72813$$){this.$token_set$=$token_set$jscomp$9$$;this.$meta72813$=$meta72813$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$create_token_set_72812$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$create_token_set_72812$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4701$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_create_token_set$$},$app$main$data$workspace$tokens$library_edit$create_token_set_72812$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72814$$,$meta72813__$1$$){return new $app$main$data$workspace$tokens$library_edit$create_token_set_72812$$(this.$token_set$,
$meta72813__$1$$)},$app$main$data$workspace$tokens$library_edit$create_token_set_72812$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72813$},$app$main$data$workspace$tokens$library_edit$create_token_set_72812$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$create_token_set_72812$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$297_data$jscomp$413_it$jscomp$258$$,$G__72826$jscomp$inline_7373_JSCompiler_inline_result$jscomp$1324_state$jscomp$978$$){$changes$jscomp$297_data$jscomp$413_it$jscomp$258$$=
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($G__72826$jscomp$inline_7373_JSCompiler_inline_result$jscomp$1324_state$jscomp$978$$);$changes$jscomp$297_data$jscomp$413_it$jscomp$258$$=$APP.$app$common$files$changes_builder$set_token_set$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$297_data$jscomp$413_it$jscomp$258$$),$APP.$app$common$types$tokens_lib$get_id$$(this.$token_set$),
this.$token_set$);$G__72826$jscomp$inline_7373_JSCompiler_inline_result$jscomp$1324_state$jscomp$978$$=$APP.$app$common$types$tokens_lib$get_id$$(this.$token_set$);$G__72826$jscomp$inline_7373_JSCompiler_inline_result$jscomp$1324_state$jscomp$978$$=$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$.$cljs$core$IFn$_invoke$arity$1$($G__72826$jscomp$inline_7373_JSCompiler_inline_result$jscomp$1324_state$jscomp$978$$):
$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$($G__72826$jscomp$inline_7373_JSCompiler_inline_result$jscomp$1324_state$jscomp$978$$);return(0,$APP.$beicon$v2$core$of$$)($G__72826$jscomp$inline_7373_JSCompiler_inline_result$jscomp$1324_state$jscomp$978$$,$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$297_data$jscomp$413_it$jscomp$258$$))});return new $app$main$data$workspace$tokens$library_edit$create_token_set_72812$$($token_set$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$library_edit$rename_token_set$$=function($token_set$jscomp$10$$,$new_name$jscomp$29$$){typeof $app$main$data$workspace$tokens$library_edit$update_token_set_72827$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$update_token_set_72827$$=function($token_set$jscomp$11$$,$new_name$jscomp$30$$,$meta72828$$){this.$token_set$=$token_set$jscomp$11$$;this.$new_name$=$new_name$jscomp$30$$;this.$meta72828$=$meta72828$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$update_token_set_72827$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$update_token_set_72827$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4702$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_update_token_set$$},$app$main$data$workspace$tokens$library_edit$update_token_set_72827$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72829$$,$meta72828__$1$$){return new $app$main$data$workspace$tokens$library_edit$update_token_set_72827$$(this.$token_set$,this.$new_name$,$meta72828__$1$$)},$app$main$data$workspace$tokens$library_edit$update_token_set_72827$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72828$},$app$main$data$workspace$tokens$library_edit$update_token_set_72827$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$update_token_set_72827$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$298_changes$jscomp$inline_12912_data$jscomp$414_it$jscomp$259$$,$G__72834$jscomp$inline_7375_JSCompiler_inline_result$jscomp$1325_id$jscomp$inline_12913_state$jscomp$979$$){$changes$jscomp$298_changes$jscomp$inline_12912_data$jscomp$414_it$jscomp$259$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($G__72834$jscomp$inline_7375_JSCompiler_inline_result$jscomp$1325_id$jscomp$inline_12913_state$jscomp$979$$);$changes$jscomp$298_changes$jscomp$inline_12912_data$jscomp$414_it$jscomp$259$$=
$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$298_changes$jscomp$inline_12912_data$jscomp$414_it$jscomp$259$$);$G__72834$jscomp$inline_7375_JSCompiler_inline_result$jscomp$1325_id$jscomp$inline_12913_state$jscomp$979$$=$APP.$app$common$types$tokens_lib$get_id$$(this.$token_set$);var $new_name$jscomp$inline_12914$$=this.$new_name$,$G__54319$jscomp$inline_12917_library_data$jscomp$inline_12915_prev_token_set$jscomp$inline_12916$$=
$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$298_changes$jscomp$inline_12912_data$jscomp$414_it$jscomp$259$$));$G__54319$jscomp$inline_12917_library_data$jscomp$inline_12915_prev_token_set$jscomp$inline_12916$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__54319$jscomp$inline_12917_library_data$jscomp$inline_12915_prev_token_set$jscomp$inline_12916$$,$APP.$cljs$cst$2139$tokens_lib$$);
$G__54319$jscomp$inline_12917_library_data$jscomp$inline_12915_prev_token_set$jscomp$inline_12916$$=$G__54319$jscomp$inline_12917_library_data$jscomp$inline_12915_prev_token_set$jscomp$inline_12916$$==null?null:$APP.$app$common$types$tokens_lib$get_set$$($G__54319$jscomp$inline_12917_library_data$jscomp$inline_12915_prev_token_set$jscomp$inline_12916$$,$G__72834$jscomp$inline_7375_JSCompiler_inline_result$jscomp$1325_id$jscomp$inline_12913_state$jscomp$979$$);$changes$jscomp$298_changes$jscomp$inline_12912_data$jscomp$414_it$jscomp$259$$=
$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$298_changes$jscomp$inline_12912_data$jscomp$414_it$jscomp$259$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$2646$set_token_set$$,$APP.$cljs$cst$266$id$$,$G__72834$jscomp$inline_7375_JSCompiler_inline_result$jscomp$1325_id$jscomp$inline_12913_state$jscomp$979$$,
$APP.$cljs$cst$2645$attrs$$,$APP.$clojure$datafy$datafy$$($APP.$app$common$types$tokens_lib$rename$$($G__54319$jscomp$inline_12917_library_data$jscomp$inline_12915_prev_token_set$jscomp$inline_12916$$,$new_name$jscomp$inline_12914$$))],null)),$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$2646$set_token_set$$,$APP.$cljs$cst$266$id$$,$G__72834$jscomp$inline_7375_JSCompiler_inline_result$jscomp$1325_id$jscomp$inline_12913_state$jscomp$979$$,
$APP.$cljs$cst$2645$attrs$$,$APP.$clojure$datafy$datafy$$($G__54319$jscomp$inline_12917_library_data$jscomp$inline_12915_prev_token_set$jscomp$inline_12916$$)],null)));$G__72834$jscomp$inline_7375_JSCompiler_inline_result$jscomp$1325_id$jscomp$inline_12913_state$jscomp$979$$=$APP.$app$common$types$tokens_lib$get_id$$(this.$token_set$);$G__72834$jscomp$inline_7375_JSCompiler_inline_result$jscomp$1325_id$jscomp$inline_12913_state$jscomp$979$$=$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$.$cljs$core$IFn$_invoke$arity$1$($G__72834$jscomp$inline_7375_JSCompiler_inline_result$jscomp$1325_id$jscomp$inline_12913_state$jscomp$979$$):$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$($G__72834$jscomp$inline_7375_JSCompiler_inline_result$jscomp$1325_id$jscomp$inline_12913_state$jscomp$979$$);return(0,$APP.$beicon$v2$core$of$$)($G__72834$jscomp$inline_7375_JSCompiler_inline_result$jscomp$1325_id$jscomp$inline_12913_state$jscomp$979$$,
$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$298_changes$jscomp$inline_12912_data$jscomp$414_it$jscomp$259$$))});return new $app$main$data$workspace$tokens$library_edit$update_token_set_72827$$($token_set$jscomp$10$$,$new_name$jscomp$29$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$library_edit$duplicate_token_set$$=function($id$jscomp$789$$){typeof $app$main$data$workspace$tokens$library_edit$duplicate_token_set_72849$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$duplicate_token_set_72849$$=function($id$jscomp$790$$,$meta72850$$){this.id=$id$jscomp$790$$;this.$meta72850$=$meta72850$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$duplicate_token_set_72849$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$duplicate_token_set_72849$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4704$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_duplicate_token_set$$},$app$main$data$workspace$tokens$library_edit$duplicate_token_set_72849$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72851$$,$meta72850__$1$$){return new $app$main$data$workspace$tokens$library_edit$duplicate_token_set_72849$$(this.id,
$meta72850__$1$$)},$app$main$data$workspace$tokens$library_edit$duplicate_token_set_72849$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72850$},$app$main$data$workspace$tokens$library_edit$duplicate_token_set_72849$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$duplicate_token_set_72849$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$300_data$jscomp$415_it$jscomp$261$$,
$G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$){$changes$jscomp$300_data$jscomp$415_it$jscomp$261$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$);$G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$300_data$jscomp$415_it$jscomp$261$$,$APP.$cljs$cst$2139$tokens_lib$$);var $map__50032__$1$jscomp$inline_12922_suffix$jscomp$25_suffix$jscomp$inline_12923$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.duplicate-suffix"),$copy_name$jscomp$inline_12927_set_id$jscomp$inline_12919$$=this.id;$map__50032__$1$jscomp$inline_12922_suffix$jscomp$25_suffix$jscomp$inline_12923$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1371$suffix$$,$map__50032__$1$jscomp$inline_12922_suffix$jscomp$25_suffix$jscomp$inline_12923$$],null)]));$map__50032__$1$jscomp$inline_12922_suffix$jscomp$25_suffix$jscomp$inline_12923$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50032__$1$jscomp$inline_12922_suffix$jscomp$25_suffix$jscomp$inline_12923$$,$APP.$cljs$cst$1371$suffix$$);var $sets$jscomp$inline_12924_unames$jscomp$inline_12925$$=$APP.$app$common$types$tokens_lib$get_sets$$($G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$);
$sets$jscomp$inline_12924_unames$jscomp$inline_12925$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$tokens_lib$get_name$$,$sets$jscomp$inline_12924_unames$jscomp$inline_12925$$);$G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$=$APP.$app$common$types$tokens_lib$get_set$$($G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$,
$copy_name$jscomp$inline_12927_set_id$jscomp$inline_12919$$);$copy_name$jscomp$inline_12927_set_id$jscomp$inline_12919$$=$APP.$cljs$core$truth_$$($G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$)?$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$tokens_lib$get_name$$($G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$),
$sets$jscomp$inline_12924_unames$jscomp$inline_12925$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1371$suffix$$,$map__50032__$1$jscomp$inline_12922_suffix$jscomp$25_suffix$jscomp$inline_12923$$])):null;$G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$=$APP.$cljs$core$truth_$$($G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$)?
$APP.$app$common$types$tokens_lib$reid$$($APP.$app$common$types$tokens_lib$rename$$($G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$,$copy_name$jscomp$inline_12927_set_id$jscomp$inline_12919$$)):null;return $APP.$cljs$core$truth_$$($G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$)?
($changes$jscomp$300_data$jscomp$415_it$jscomp$261$$=$APP.$app$common$files$changes_builder$set_token_set$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$300_data$jscomp$415_it$jscomp$261$$),$APP.$app$common$types$tokens_lib$get_id$$($G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$),
$G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$),$G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$=$APP.$app$common$types$tokens_lib$get_id$$($G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$),
$G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$=$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$.$cljs$core$IFn$_invoke$arity$1$($G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$):
$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$($G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$),(0,$APP.$beicon$v2$core$of$$)($G__72855$jscomp$inline_7377_JSCompiler_inline_result$jscomp$1326_set$jscomp$inline_12926_state$jscomp$980_temp__5825__auto__$jscomp$245_tokens_lib$jscomp$31$$,$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$300_data$jscomp$415_it$jscomp$261$$))):
null});return new $app$main$data$workspace$tokens$library_edit$duplicate_token_set_72849$$($id$jscomp$789$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$library_edit$toggle_token_set$$=function($name$jscomp$373$$){typeof $app$main$data$workspace$tokens$library_edit$toggle_token_set_72862$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$toggle_token_set_72862$$=function($name$jscomp$374$$,$meta72863$$){this.name=$name$jscomp$374$$;this.$meta72863$=$meta72863$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$toggle_token_set_72862$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_token_set_72862$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4706$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_set$$},$app$main$data$workspace$tokens$library_edit$toggle_token_set_72862$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72864$$,$meta72863__$1$$){return new $app$main$data$workspace$tokens$library_edit$toggle_token_set_72862$$(this.name,
$meta72863__$1$$)},$app$main$data$workspace$tokens$library_edit$toggle_token_set_72862$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72863$},$app$main$data$workspace$tokens$library_edit$toggle_token_set_72862$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_token_set_72862$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2664_data$jscomp$417$$,$changes$jscomp$302_state$jscomp$982_tlib$jscomp$1$$){$_$jscomp$2664_data$jscomp$417$$=
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$302_state$jscomp$982_tlib$jscomp$1$$);$changes$jscomp$302_state$jscomp$982_tlib$jscomp$1$$=$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($changes$jscomp$302_state$jscomp$982_tlib$jscomp$1$$);$changes$jscomp$302_state$jscomp$982_tlib$jscomp$1$$=$app$common$logic$tokens$generate_toggle_token_set$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$_$jscomp$2664_data$jscomp$417$$),$changes$jscomp$302_state$jscomp$982_tlib$jscomp$1$$,this.name);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$302_state$jscomp$982_tlib$jscomp$1$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())});return new $app$main$data$workspace$tokens$library_edit$toggle_token_set_72862$$($name$jscomp$373$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$library_edit$delete_token_set$$=function($id$jscomp$791$$){typeof $app$main$data$workspace$tokens$library_edit$delete_token_set_72880$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$delete_token_set_72880$$=function($id$jscomp$792$$,$meta72881$$){this.id=$id$jscomp$792$$;this.$meta72881$=$meta72881$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$delete_token_set_72880$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$delete_token_set_72880$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4709$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_delete_token_set$$},$app$main$data$workspace$tokens$library_edit$delete_token_set_72880$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72882$$,$meta72881__$1$$){return new $app$main$data$workspace$tokens$library_edit$delete_token_set_72880$$(this.id,
$meta72881__$1$$)},$app$main$data$workspace$tokens$library_edit$delete_token_set_72880$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72881$},$app$main$data$workspace$tokens$library_edit$delete_token_set_72880$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$delete_token_set_72880$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$305_data$jscomp$420_it$jscomp$263$$,$state$jscomp$985$$){$changes$jscomp$305_data$jscomp$420_it$jscomp$263$$=
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$985$$);$changes$jscomp$305_data$jscomp$420_it$jscomp$263$$=$APP.$app$common$files$changes_builder$set_token_set$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$305_data$jscomp$420_it$jscomp$263$$),this.id,null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$305_data$jscomp$420_it$jscomp$263$$),
$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())});return new $app$main$data$workspace$tokens$library_edit$delete_token_set_72880$$($id$jscomp$791$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$create_token_with_set$$=function($token$jscomp$91$$){typeof $app$main$data$workspace$tokens$library_edit$create_token_and_set_72921$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$create_token_and_set_72921$$=function($token$jscomp$92$$,$meta72922$$){this.token=$token$jscomp$92$$;this.$meta72922$=$meta72922$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$create_token_and_set_72921$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$create_token_and_set_72921$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4714$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_create_token_and_set$$},$app$main$data$workspace$tokens$library_edit$create_token_and_set_72921$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72923$$,$meta72922__$1$$){return new $app$main$data$workspace$tokens$library_edit$create_token_and_set_72921$$(this.token,
$meta72922__$1$$)},$app$main$data$workspace$tokens$library_edit$create_token_and_set_72921$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72922$},$app$main$data$workspace$tokens$library_edit$create_token_and_set_72921$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$create_token_and_set_72921$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($G__72927$jscomp$inline_7379_JSCompiler_inline_result$jscomp$1328__$jscomp$2672_token_set$jscomp$13$$,
$JSCompiler_temp_const$jscomp$1327_changes$jscomp$309_data$jscomp$422_state$jscomp$989$$){$JSCompiler_temp_const$jscomp$1327_changes$jscomp$309_data$jscomp$422_state$jscomp$989$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$1327_changes$jscomp$309_data$jscomp$422_state$jscomp$989$$);$G__72927$jscomp$inline_7379_JSCompiler_inline_result$jscomp$1328__$jscomp$2672_token_set$jscomp$13$$=$APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,
"Global"]));var $hidden_theme$jscomp$1$$=$app$common$types$tokens_lib$make_hidden_theme$$(),$hidden_theme_with_set$$=$hidden_theme$jscomp$1$$.$app$common$types$tokens_lib$ITokenTheme$enable_set$arity$2$(null,"Global");$JSCompiler_temp_const$jscomp$1327_changes$jscomp$309_data$jscomp$422_state$jscomp$989$$=$app$common$files$changes_builder$set_active_token_themes$$($app$common$files$changes_builder$set_token_theme$$($APP.$app$common$files$changes_builder$set_token$$($APP.$app$common$files$changes_builder$set_token_set$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$JSCompiler_temp_const$jscomp$1327_changes$jscomp$309_data$jscomp$422_state$jscomp$989$$),$G__72927$jscomp$inline_7379_JSCompiler_inline_result$jscomp$1328__$jscomp$2672_token_set$jscomp$13$$.id,$G__72927$jscomp$inline_7379_JSCompiler_inline_result$jscomp$1328__$jscomp$2672_token_set$jscomp$13$$),$G__72927$jscomp$inline_7379_JSCompiler_inline_result$jscomp$1328__$jscomp$2672_token_set$jscomp$13$$.id,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.token),this.token),$hidden_theme$jscomp$1$$.id,
$hidden_theme_with_set$$),$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$app$common$types$tokens_lib$hidden_theme_path$$]));$JSCompiler_temp_const$jscomp$1327_changes$jscomp$309_data$jscomp$422_state$jscomp$989$$=$APP.$app$main$data$changes$commit_changes$$($JSCompiler_temp_const$jscomp$1327_changes$jscomp$309_data$jscomp$422_state$jscomp$989$$);$G__72927$jscomp$inline_7379_JSCompiler_inline_result$jscomp$1328__$jscomp$2672_token_set$jscomp$13$$=$G__72927$jscomp$inline_7379_JSCompiler_inline_result$jscomp$1328__$jscomp$2672_token_set$jscomp$13$$.id;
$G__72927$jscomp$inline_7379_JSCompiler_inline_result$jscomp$1328__$jscomp$2672_token_set$jscomp$13$$=$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$.$cljs$core$IFn$_invoke$arity$1$($G__72927$jscomp$inline_7379_JSCompiler_inline_result$jscomp$1328__$jscomp$2672_token_set$jscomp$13$$):$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$($G__72927$jscomp$inline_7379_JSCompiler_inline_result$jscomp$1328__$jscomp$2672_token_set$jscomp$13$$);
return(0,$APP.$beicon$v2$core$of$$)($JSCompiler_temp_const$jscomp$1327_changes$jscomp$309_data$jscomp$422_state$jscomp$989$$,$G__72927$jscomp$inline_7379_JSCompiler_inline_result$jscomp$1328__$jscomp$2672_token_set$jscomp$13$$)});return new $app$main$data$workspace$tokens$library_edit$create_token_and_set_72921$$($token$jscomp$91$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$library_edit$create_token$cljs$0core$0IFn$0_invoke$0arity$02$$=function($set_id$jscomp$33$$,$token$jscomp$94$$){typeof $app$main$data$workspace$tokens$library_edit$create_token_72935$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$create_token_72935$$=function($set_id$jscomp$34$$,$token$jscomp$95$$,$meta72936$$){this.$set_id$=$set_id$jscomp$34$$;this.token=$token$jscomp$95$$;this.$meta72936$=$meta72936$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$create_token_72935$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$create_token_72935$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4715$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_create_token$$},$app$main$data$workspace$tokens$library_edit$create_token_72935$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72937$$,$meta72936__$1$$){return new $app$main$data$workspace$tokens$library_edit$create_token_72935$$(this.$set_id$,this.token,$meta72936__$1$$)},$app$main$data$workspace$tokens$library_edit$create_token_72935$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72936$},$app$main$data$workspace$tokens$library_edit$create_token_72935$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$create_token_72935$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$310_it$jscomp$267_temp__5823__auto__$jscomp$198$$,$state$jscomp$990_token_type$jscomp$10$$){$changes$jscomp$310_it$jscomp$267_temp__5823__auto__$jscomp$198$$=$APP.$cljs$core$truth_$$(this.$set_id$)?$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$990_token_type$jscomp$10$$,this.$set_id$):$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$990_token_type$jscomp$10$$);
if($APP.$cljs$core$truth_$$($changes$jscomp$310_it$jscomp$267_temp__5823__auto__$jscomp$198$$)){var $data$jscomp$423$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$990_token_type$jscomp$10$$);$state$jscomp$990_token_type$jscomp$10$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$(this.token);$changes$jscomp$310_it$jscomp$267_temp__5823__auto__$jscomp$198$$=$APP.$app$common$files$changes_builder$set_token$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$data$jscomp$423$$),$APP.$app$common$types$tokens_lib$get_id$$($changes$jscomp$310_it$jscomp$267_temp__5823__auto__$jscomp$198$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.token),this.token);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$310_it$jscomp$267_temp__5823__auto__$jscomp$198$$),$APP.$app$main$data$event$event$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-token",$APP.$cljs$cst$139$type$$,$state$jscomp$990_token_type$jscomp$10$$],null),$APP.$cljs$core$meta$$(this)]))))}return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$tokens$library_edit$create_token_with_set$$(this.token))});return new $app$main$data$workspace$tokens$library_edit$create_token_72935$$($set_id$jscomp$33$$,$token$jscomp$94$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$03$$=function($set_id$jscomp$37$$,$id$jscomp$794$$,$params$jscomp$311$$){typeof $app$main$data$workspace$tokens$library_edit$update_token_72952$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$update_token_72952$$=function($set_id$jscomp$38$$,$id$jscomp$795$$,$params$jscomp$312$$,$meta72953$$){this.$set_id$=$set_id$jscomp$38$$;this.id=$id$jscomp$795$$;this.params=$params$jscomp$312$$;this.$meta72953$=
$meta72953$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$update_token_72952$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$update_token_72952$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4717$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_update_token$$},$app$main$data$workspace$tokens$library_edit$update_token_72952$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72954$$,$meta72953__$1$$){return new $app$main$data$workspace$tokens$library_edit$update_token_72952$$(this.$set_id$,this.id,this.params,$meta72953__$1$$)},$app$main$data$workspace$tokens$library_edit$update_token_72952$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72953$},$app$main$data$workspace$tokens$library_edit$update_token_72952$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$update_token_72952$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$313_it$jscomp$269_token_set$jscomp$16$$,$state$jscomp$992_token$jscomp$97$$){$changes$jscomp$313_it$jscomp$269_token_set$jscomp$16$$=$APP.$cljs$core$truth_$$(this.$set_id$)?$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$992_token$jscomp$97$$,this.$set_id$):$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$992_token$jscomp$97$$);var $data$jscomp$425$$=
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$992_token$jscomp$97$$);$state$jscomp$992_token$jscomp$97$$=$APP.$app$common$types$tokens_lib$get_token$$($APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($state$jscomp$992_token$jscomp$97$$),$APP.$app$common$types$tokens_lib$get_id$$($changes$jscomp$313_it$jscomp$269_token_set$jscomp$16$$),this.id);var $token_SINGLEQUOTE_$jscomp$2$$=$APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$state$jscomp$992_token$jscomp$97$$,this.params])))])),$token_type$jscomp$11$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$992_token$jscomp$97$$);$changes$jscomp$313_it$jscomp$269_token_set$jscomp$16$$=$APP.$app$common$files$changes_builder$set_token$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$data$jscomp$425$$),$APP.$app$common$types$tokens_lib$get_id$$($changes$jscomp$313_it$jscomp$269_token_set$jscomp$16$$),this.id,$token_SINGLEQUOTE_$jscomp$2$$);$APP.$app$main$data$workspace$tokens$library_edit$toggle_token_path$$([$APP.$cljs$core$name$$($token_type$jscomp$11$$),".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$992_token$jscomp$97$$))].join(""));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$313_it$jscomp$269_token_set$jscomp$16$$),
$APP.$app$main$data$event$event$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"edit-token",$APP.$cljs$cst$139$type$$,$token_type$jscomp$11$$],null),$APP.$cljs$core$meta$$(this)]))))});return new $app$main$data$workspace$tokens$library_edit$update_token_72952$$($set_id$jscomp$37$$,$id$jscomp$794$$,$params$jscomp$311$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$library_edit$delete_token$$=function($set_id$jscomp$41$$,$token_id$jscomp$19$$){typeof $app$main$data$workspace$tokens$library_edit$delete_token_72984$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$delete_token_72984$$=function($set_id$jscomp$42$$,$token_id$jscomp$20$$,$meta72985$$){this.$set_id$=$set_id$jscomp$42$$;this.$token_id$=$token_id$jscomp$20$$;this.$meta72985$=$meta72985$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$tokens$library_edit$delete_token_72984$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$delete_token_72984$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4719$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_delete_token$$},$app$main$data$workspace$tokens$library_edit$delete_token_72984$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72986$$,
$meta72985__$1$$){return new $app$main$data$workspace$tokens$library_edit$delete_token_72984$$(this.$set_id$,this.$token_id$,$meta72985__$1$$)},$app$main$data$workspace$tokens$library_edit$delete_token_72984$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72985$},$app$main$data$workspace$tokens$library_edit$delete_token_72984$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$delete_token_72984$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$316_data$jscomp$427_it$jscomp$271$$,$state$jscomp$994_token$jscomp$99_token_type$jscomp$12$$){$changes$jscomp$316_data$jscomp$427_it$jscomp$271$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$994_token$jscomp$99_token_type$jscomp$12$$);var $token_set$jscomp$18$$=$APP.$cljs$core$truth_$$(this.$set_id$)?$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$994_token$jscomp$99_token_type$jscomp$12$$,
this.$set_id$):$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$994_token$jscomp$99_token_type$jscomp$12$$);$state$jscomp$994_token$jscomp$99_token_type$jscomp$12$$=$APP.$app$common$types$tokens_lib$get_token$$($APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($state$jscomp$994_token$jscomp$99_token_type$jscomp$12$$),$APP.$app$common$types$tokens_lib$get_id$$($token_set$jscomp$18$$),this.$token_id$);$state$jscomp$994_token$jscomp$99_token_type$jscomp$12$$=
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$994_token$jscomp$99_token_type$jscomp$12$$);$changes$jscomp$316_data$jscomp$427_it$jscomp$271$$=$APP.$app$common$files$changes_builder$set_token$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$316_data$jscomp$427_it$jscomp$271$$),this.$set_id$,this.$token_id$,null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$316_data$jscomp$427_it$jscomp$271$$),
$APP.$app$main$data$event$event$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-token",$APP.$cljs$cst$139$type$$,$state$jscomp$994_token$jscomp$99_token_type$jscomp$12$$],null),$APP.$cljs$core$meta$$(this)]))))});return new $app$main$data$workspace$tokens$library_edit$delete_token_72984$$($set_id$jscomp$41$$,
$token_id$jscomp$19$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$=function($id$jscomp$796$$){typeof $app$main$data$workspace$tokens$library_edit$set_selected_token_set_id_73046$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$set_selected_token_set_id_73046$$=function($id$jscomp$797$$,$meta73047$$){this.id=$id$jscomp$797$$;this.$meta73047$=$meta73047$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id_73046$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id_73046$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4727$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_set_selected_token_set_id$$},$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id_73046$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73048$$,$meta73047__$1$$){return new $app$main$data$workspace$tokens$library_edit$set_selected_token_set_id_73046$$(this.id,
$meta73047__$1$$)},$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id_73046$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73047$},$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id_73046$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id_73046$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2683_file_id$jscomp$307$$,
$state$jscomp$1000$$){$_$jscomp$2683_file_id$jscomp$307$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1000$$);var $stored$jscomp$2$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$user$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4685$app_DOT_main_DOT_ui_DOT_workspace_DOT_tokens_SLASH_unfolded_token_types$$,$_$jscomp$2683_file_id$jscomp$307$$,this.id],null),$APP.$cljs$core$PersistentHashSet$EMPTY$$);
return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1000$$,$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2138$selected_token_set_id$$,this.id),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2137$workspace_tokens$$,$APP.$cljs$cst$4686$unfolded_token_types$$],null),$APP.$app$main$data$workspace$tokens$library_edit$make_unfolded_token_types_state$$($_$jscomp$2683_file_id$jscomp$307$$,
this.id,$stored$jscomp$2$$))});return new $app$main$data$workspace$tokens$library_edit$set_selected_token_set_id_73046$$($id$jscomp$796$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$ds$tooltip$tooltip$has_descendant_tooltip_QMARK_$$=function($trigger_el$jscomp$2$$){var $all_tooltips$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$_deref$$($app$main$ui$ds$tooltip$tooltip$tooltip_registry$$),$APP.$cljs$core$_deref$$($app$main$ui$ds$tooltip$tooltip$pending_tooltips$$)]));return $APP.$cljs$core$some$$(function($entry_el_p__72135$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($entry_el_p__72135$$,
0,null);$entry_el_p__72135$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($entry_el_p__72135$$,1,null);return $entry_el_p__72135$$!=null?$APP.$app$util$dom$child_QMARK_$$($entry_el_p__72135$$,$trigger_el$jscomp$2$$):null},$all_tooltips$$)};
$app$main$ui$ds$tooltip$tooltip$clear_schedule$$=function($ref$jscomp$33$$){var $temp__5825__auto__$jscomp$248$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$33$$);$APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$248$$)&&($APP.$beicon$v2$core$_dispose$$($temp__5825__auto__$jscomp$248$$),$APP.$rumext$v2$set_ref_val_BANG_$$($ref$jscomp$33$$,null))};
$app$main$ui$ds$tooltip$tooltip$add_schedule$$=function($ref$jscomp$34$$,$delay$jscomp$7$$,$f$jscomp$837$$){return $APP.$rumext$v2$set_ref_val_BANG_$$($ref$jscomp$34$$,$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$($delay$jscomp$7$$,$f$jscomp$837$$))};
$app$main$ui$ds$tooltip$tooltip$calculate_placement_bounding_rect$$=function($placement$$,$tooltip_brect_tooltip_width$$,$origin_brect_trigger_top$$,$offset$jscomp$183_offset__$1$jscomp$20$$){var $map__72142__$1_trigger_height$$=$APP.$cljs$core$__destructure_map$$($origin_brect_trigger_top$$);$origin_brect_trigger_top$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72142__$1_trigger_height$$,$APP.$cljs$cst$1562$top$$);var $trigger_left$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72142__$1_trigger_height$$,
$APP.$cljs$cst$257$left$$),$trigger_right$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72142__$1_trigger_height$$,$APP.$cljs$cst$258$right$$),$trigger_bottom$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72142__$1_trigger_height$$,$APP.$cljs$cst$1563$bottom$$),$trigger_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72142__$1_trigger_height$$,$APP.$cljs$cst$290$width$$);$map__72142__$1_trigger_height$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72142__$1_trigger_height$$,
$APP.$cljs$cst$1522$height$$);var $map__72143__$1_tooltip_height$$=$APP.$cljs$core$__destructure_map$$($tooltip_brect_tooltip_width$$);$tooltip_brect_tooltip_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72143__$1_tooltip_height$$,$APP.$cljs$cst$290$width$$);$map__72143__$1_tooltip_height$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72143__$1_tooltip_height$$,$APP.$cljs$cst$1522$height$$);$offset$jscomp$183_offset__$1$jscomp$20$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$183_offset__$1$jscomp$20$$,
2);switch($placement$$){case "bottom":return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1562$top$$,$trigger_bottom$$+$offset$jscomp$183_offset__$1$jscomp$20$$,$APP.$cljs$cst$257$left$$,$trigger_left$$+$trigger_width$$/2-$tooltip_brect_tooltip_width$$/2,$APP.$cljs$cst$258$right$$,$trigger_left$$+$trigger_width$$/2+$tooltip_brect_tooltip_width$$/2,$APP.$cljs$cst$1563$bottom$$,$trigger_bottom$$-$offset$jscomp$183_offset__$1$jscomp$20$$+$map__72143__$1_tooltip_height$$,$APP.$cljs$cst$290$width$$,
$tooltip_brect_tooltip_width$$,$APP.$cljs$cst$1522$height$$,$map__72143__$1_tooltip_height$$],null);case "left":return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1562$top$$,$origin_brect_trigger_top$$+$map__72142__$1_trigger_height$$/2-$map__72143__$1_tooltip_height$$/2,$APP.$cljs$cst$257$left$$,$trigger_left$$-$tooltip_brect_tooltip_width$$,$APP.$cljs$cst$258$right$$,$trigger_left$$-$tooltip_brect_tooltip_width$$+$tooltip_brect_tooltip_width$$,$APP.$cljs$cst$1563$bottom$$,$origin_brect_trigger_top$$+
$map__72142__$1_trigger_height$$/2-$map__72143__$1_tooltip_height$$/2+$map__72143__$1_tooltip_height$$,$APP.$cljs$cst$290$width$$,$tooltip_brect_tooltip_width$$,$APP.$cljs$cst$1522$height$$,$map__72143__$1_tooltip_height$$],null);case "right":return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1562$top$$,$origin_brect_trigger_top$$+$map__72142__$1_trigger_height$$/2-$map__72143__$1_tooltip_height$$/2,$APP.$cljs$cst$257$left$$,$trigger_right$$+$offset$jscomp$183_offset__$1$jscomp$20$$,
$APP.$cljs$cst$258$right$$,$trigger_right$$+$offset$jscomp$183_offset__$1$jscomp$20$$+$tooltip_brect_tooltip_width$$,$APP.$cljs$cst$1563$bottom$$,$origin_brect_trigger_top$$+$map__72142__$1_trigger_height$$/2-$map__72143__$1_tooltip_height$$/2+$map__72143__$1_tooltip_height$$,$APP.$cljs$cst$290$width$$,$tooltip_brect_tooltip_width$$,$APP.$cljs$cst$1522$height$$,$map__72143__$1_tooltip_height$$],null);case "bottom-right":return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1562$top$$,
$trigger_bottom$$+$offset$jscomp$183_offset__$1$jscomp$20$$,$APP.$cljs$cst$257$left$$,$trigger_right$$-32,$APP.$cljs$cst$258$right$$,$trigger_right$$-32+$tooltip_brect_tooltip_width$$,$APP.$cljs$cst$1563$bottom$$,$trigger_bottom$$-$offset$jscomp$183_offset__$1$jscomp$20$$+$map__72143__$1_tooltip_height$$,$APP.$cljs$cst$290$width$$,$tooltip_brect_tooltip_width$$,$APP.$cljs$cst$1522$height$$,$map__72143__$1_tooltip_height$$],null);case "bottom-left":return new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$1562$top$$,$trigger_bottom$$+$offset$jscomp$183_offset__$1$jscomp$20$$,$APP.$cljs$cst$257$left$$,$trigger_left$$-$tooltip_brect_tooltip_width$$+32,$APP.$cljs$cst$258$right$$,$trigger_left$$+32,$APP.$cljs$cst$1563$bottom$$,$trigger_bottom$$-$offset$jscomp$183_offset__$1$jscomp$20$$+$map__72143__$1_tooltip_height$$,$APP.$cljs$cst$290$width$$,$tooltip_brect_tooltip_width$$,$APP.$cljs$cst$1522$height$$,$map__72143__$1_tooltip_height$$],null);case "top-right":return new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$1562$top$$,$origin_brect_trigger_top$$-$offset$jscomp$183_offset__$1$jscomp$20$$-$map__72143__$1_tooltip_height$$,$APP.$cljs$cst$257$left$$,$trigger_right$$-32,$APP.$cljs$cst$258$right$$,$trigger_right$$-32+$tooltip_brect_tooltip_width$$,$APP.$cljs$cst$1563$bottom$$,$origin_brect_trigger_top$$-$offset$jscomp$183_offset__$1$jscomp$20$$,$APP.$cljs$cst$290$width$$,$tooltip_brect_tooltip_width$$,$APP.$cljs$cst$1522$height$$,$map__72143__$1_tooltip_height$$],null);case "top-left":return new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$1562$top$$,$origin_brect_trigger_top$$-$offset$jscomp$183_offset__$1$jscomp$20$$-$map__72143__$1_tooltip_height$$,$APP.$cljs$cst$257$left$$,$trigger_left$$-$tooltip_brect_tooltip_width$$+32,$APP.$cljs$cst$258$right$$,$trigger_left$$+32,$APP.$cljs$cst$1563$bottom$$,$origin_brect_trigger_top$$-$offset$jscomp$183_offset__$1$jscomp$20$$,$APP.$cljs$cst$290$width$$,$tooltip_brect_tooltip_width$$,$APP.$cljs$cst$1522$height$$,$map__72143__$1_tooltip_height$$],null);default:return new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$1562$top$$,$origin_brect_trigger_top$$-$offset$jscomp$183_offset__$1$jscomp$20$$-$map__72143__$1_tooltip_height$$,$APP.$cljs$cst$257$left$$,$trigger_left$$+$trigger_width$$/2-$tooltip_brect_tooltip_width$$/2,$APP.$cljs$cst$258$right$$,$trigger_left$$+$trigger_width$$/2-$tooltip_brect_tooltip_width$$/2+$tooltip_brect_tooltip_width$$,$APP.$cljs$cst$1563$bottom$$,$origin_brect_trigger_top$$-$offset$jscomp$183_offset__$1$jscomp$20$$,$APP.$cljs$cst$290$width$$,$tooltip_brect_tooltip_width$$,
$APP.$cljs$cst$1522$height$$,$map__72143__$1_tooltip_height$$],null)}};
$app$main$ui$ds$tooltip$tooltip$get_fallback_order$$=function($placement$jscomp$1$$){switch($placement$jscomp$1$$){case "top":return new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"top right bottom left top-right bottom-right bottom-left top-left".split(" "),null);case "bottom":return new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"bottom left top right bottom-right bottom-left top-left top-right".split(" "),null);
case "left":return new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"left top right bottom top-left top-right bottom-right bottom-left".split(" "),null);case "right":return new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"right bottom left top bottom-left top-left top-right bottom-right".split(" "),null);case "top-right":return new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
"top-right right bottom left top bottom-right bottom-left top-left".split(" "),null);case "bottom-right":return new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"bottom-right bottom left top right bottom-left top-left top-right".split(" "),null);case "bottom-left":return new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"bottom-left left top right bottom top-left top-right bottom-right".split(" "),null);case "top-left":return new $APP.$cljs$core$PersistentVector$$(null,
8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"top-left top right bottom left bottom-left top-right bottom-right".split(" "),null);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($placement$jscomp$1$$)].join(""));}};
$APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$=function($container$jscomp$77_props_72171$$){var $aria_label$jscomp$2_props__$1$jscomp$37$$=void 0,$placement$jscomp$3$$=void 0,$delay$jscomp$8_tooltip_class$$=void 0,$children$jscomp$260$$=void 0,$offset$jscomp$185$$=void 0,$content$jscomp$226_content__$1$jscomp$39$$=void 0,$trigger_ref$$=void 0,$id$jscomp$798_id__$1$jscomp$10$$=void 0,$class$$jscomp$12$$=void 0,$props$jscomp$219$$=void 0;({"aria-label":$aria_label$jscomp$2_props__$1$jscomp$37$$,
placement:$placement$jscomp$3$$,delay:$delay$jscomp$8_tooltip_class$$,children:$children$jscomp$260$$,offset:$offset$jscomp$185$$,content:$content$jscomp$226_content__$1$jscomp$39$$,triggerRef:$trigger_ref$$,id:$id$jscomp$798_id__$1$jscomp$10$$,className:$class$$jscomp$12$$,...$props$jscomp$219$$}=$container$jscomp$77_props_72171$$);var $internal_id_on_show_focus$$=(0,$APP.$rumext$v2$use_id$$)(),$internal_trigger_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$trigger_ref__$1$$=function(){var $or__5025__auto__$jscomp$900$$=
$trigger_ref$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$900$$)?$or__5025__auto__$jscomp$900$$:$internal_trigger_ref$$}(),$tooltip_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);$container$jscomp$77_props_72171$$=$APP.$app$main$ui$hooks$use_portal_container$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2946$tooltip$$);$id$jscomp$798_id__$1$jscomp$10$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$798_id__$1$jscomp$10$$,$internal_id_on_show_focus$$);var $tooltip_id$jscomp$4$$=
(0,$APP.$rumext$v2$use_id$$)(),$placement_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($placement$jscomp$3$$,"top")}),$placement__$1$jscomp$1$$=$APP.$cljs$core$_deref$$($placement_STAR_$$),$delay__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($delay$jscomp$8_tooltip_class$$,700),$schedule_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$visible_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$visible$$=$APP.$cljs$core$_deref$$($visible_STAR_$$),$on_show$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tooltip_id$jscomp$4$$),$APP.$rumext$v2$adapt$$($delay__$1$$)],function(){if($APP.$cljs$core$truth_$$(document.hidden))return null;var $trigger_el$jscomp$3$$=$APP.$rumext$v2$ref_val$$($trigger_ref__$1$$);$app$main$ui$ds$tooltip$tooltip$clear_schedule$$($schedule_ref$$);if($APP.$cljs$core$truth_$$($app$main$ui$ds$tooltip$tooltip$has_descendant_tooltip_QMARK_$$($trigger_el$jscomp$3$$)))return null;
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$main$ui$ds$tooltip$tooltip$pending_tooltips$$,$APP.$cljs$core$assoc$$,$tooltip_id$jscomp$4$$,$trigger_el$jscomp$3$$);return $app$main$ui$ds$tooltip$tooltip$add_schedule$$($schedule_ref$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($delay__$1$$,300),function(){var $temp__5825__auto___72237_temp__5825__auto___72239__$1$$=$APP.$cljs$core$_deref$$($app$main$ui$ds$tooltip$tooltip$active_tooltip$$);$APP.$cljs$core$truth_$$($temp__5825__auto___72237_temp__5825__auto___72239__$1$$)&&
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto___72237_temp__5825__auto___72239__$1$$),$tooltip_id$jscomp$4$$)&&($temp__5825__auto___72237_temp__5825__auto___72239__$1$$=$APP.$app$util$dom$get_element$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto___72237_temp__5825__auto___72239__$1$$)),$APP.$cljs$core$truth_$$($temp__5825__auto___72237_temp__5825__auto___72239__$1$$)&&$APP.$app$util$dom$set_css_property_BANG_$$($temp__5825__auto___72237_temp__5825__auto___72239__$1$$,
"display","none"),$APP.$cljs$core$reset_BANG_$$($app$main$ui$ds$tooltip$tooltip$active_tooltip$$,null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$main$ui$ds$tooltip$tooltip$tooltip_registry$$,$APP.$cljs$core$assoc$$,$tooltip_id$jscomp$4$$,$trigger_el$jscomp$3$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$main$ui$ds$tooltip$tooltip$pending_tooltips$$,$APP.$cljs$core$dissoc$$,$tooltip_id$jscomp$4$$);$APP.$cljs$core$reset_BANG_$$($app$main$ui$ds$tooltip$tooltip$active_tooltip$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$tooltip_id$jscomp$4$$,$APP.$cljs$cst$4424$trigger$$,$trigger_el$jscomp$3$$],null));return $APP.$cljs$core$reset_BANG_$$($visible_STAR_$$,!0)})});$internal_id_on_show_focus$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_show$$)],function($event$jscomp$125$$){return($event$jscomp$125$$!=null?$event$jscomp$125$$.relatedTarget:null)!=null?$on_show$$.$cljs$core$IFn$_invoke$arity$1$?$on_show$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$125$$):
$on_show$$($event$jscomp$125$$):null});var $on_hide$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tooltip_id$jscomp$4$$)],function(){$app$main$ui$ds$tooltip$tooltip$clear_schedule$$($schedule_ref$$);$APP.$cljs$core$reset_BANG_$$($visible_STAR_$$,!1);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$main$ui$ds$tooltip$tooltip$tooltip_registry$$,$APP.$cljs$core$dissoc$$,$tooltip_id$jscomp$4$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$main$ui$ds$tooltip$tooltip$pending_tooltips$$,
$APP.$cljs$core$dissoc$$,$tooltip_id$jscomp$4$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($app$main$ui$ds$tooltip$tooltip$active_tooltip$$)),$tooltip_id$jscomp$4$$)?$APP.$cljs$core$reset_BANG_$$($app$main$ui$ds$tooltip$tooltip$active_tooltip$$,null):null}),$handle_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_hide$$)],function($event$jscomp$126$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$126$$))?
$on_hide$$.$cljs$core$IFn$_invoke$arity$0$?$on_hide$$.$cljs$core$IFn$_invoke$arity$0$():$on_hide$$():null});$delay$jscomp$8_tooltip_class$$="main_ui_ds_tooltip_tooltip__tooltip-content-wrapper "+($placement__$1$jscomp$1$$==="top"?"main_ui_ds_tooltip_tooltip__tooltip-top":"")+" "+($placement__$1$jscomp$1$$==="bottom"?"main_ui_ds_tooltip_tooltip__tooltip-bottom":"")+" "+($placement__$1$jscomp$1$$==="left"?"main_ui_ds_tooltip_tooltip__tooltip-left":"")+" "+($placement__$1$jscomp$1$$==="right"?"main_ui_ds_tooltip_tooltip__tooltip-right":
"")+" "+($placement__$1$jscomp$1$$==="top-right"?"main_ui_ds_tooltip_tooltip__tooltip-top-right":"")+" "+($placement__$1$jscomp$1$$==="bottom-right"?"main_ui_ds_tooltip_tooltip__tooltip-bottom-right":"")+" "+($placement__$1$jscomp$1$$==="bottom-left"?"main_ui_ds_tooltip_tooltip__tooltip-bottom-left":"")+" "+($placement__$1$jscomp$1$$==="top-left"?"main_ui_ds_tooltip_tooltip__tooltip-top-left":"");$content$jscomp$226_content__$1$jscomp$39$$=$APP.$cljs$core$fn_QMARK_$$($content$jscomp$226_content__$1$jscomp$39$$)?
$content$jscomp$226_content__$1$jscomp$39$$.$cljs$core$IFn$_invoke$arity$0$?$content$jscomp$226_content__$1$jscomp$39$$.$cljs$core$IFn$_invoke$arity$0$():$content$jscomp$226_content__$1$jscomp$39$$():$content$jscomp$226_content__$1$jscomp$39$$;$aria_label$jscomp$2_props__$1$jscomp$37$$={...$props$jscomp$219$$,"aria-label":typeof $content$jscomp$226_content__$1$jscomp$39$$==="string"?$content$jscomp$226_content__$1$jscomp$39$$:$aria_label$jscomp$2_props__$1$jscomp$37$$,className:($class$$jscomp$12$$??
"")+" main_ui_ds_tooltip_tooltip__tooltip-trigger",id:$id$jscomp$798_id__$1$jscomp$10$$,onMouseLeave:$on_hide$$,onFocus:$internal_id_on_show_focus$$,onBlur:$on_hide$$,onMouseEnter:$on_show$$,ref:$internal_trigger_ref$$,onKeyDown:$handle_key_down$$};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($visible$$),$APP.$rumext$v2$adapt$$($placement__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($offset$jscomp$185$$)],function(){if($APP.$cljs$core$truth_$$($visible$$)){var $trigger_el$jscomp$4$$=
$APP.$rumext$v2$ref_val$$($trigger_ref__$1$$),$tooltip_el$$=$APP.$rumext$v2$ref_val$$($tooltip_ref$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($trigger_el$jscomp$4$$)?$tooltip_el$$:$trigger_el$jscomp$4$$)?(0,$APP.$app$util$timers$request_animation_frame$$)(function(){var $new_placement_origin_brect$jscomp$2$$=$APP.$app$util$dom$get_bounding_rect$$($trigger_el$jscomp$4$$),$placement_rect_temp__5825__auto__$jscomp$250_tooltip_brect$jscomp$2$$=$APP.$app$util$dom$get_bounding_rect$$($tooltip_el$$);
a:{for(var $offset$jscomp$inline_7392$$=$offset$jscomp$185$$,$window_size$jscomp$inline_7393$$=$APP.$app$util$dom$get_window_size$$(),$placements$jscomp$inline_7394$$=$APP.$cljs$core$seq$$($app$main$ui$ds$tooltip$tooltip$get_fallback_order$$($placement__$1$jscomp$1$$));;){var $placement__$1$jscomp$inline_7396_temp__5825__auto__$jscomp$inline_7395$$=$APP.$cljs$core$first$$($placements$jscomp$inline_7394$$);if($APP.$cljs$core$truth_$$($placement__$1$jscomp$inline_7396_temp__5825__auto__$jscomp$inline_7395$$)){var $placement_brect$jscomp$inline_7397$$=
$app$main$ui$ds$tooltip$tooltip$calculate_placement_bounding_rect$$($placement__$1$jscomp$inline_7396_temp__5825__auto__$jscomp$inline_7395$$,$placement_rect_temp__5825__auto__$jscomp$250_tooltip_brect$jscomp$2$$,$new_placement_origin_brect$jscomp$2$$,$offset$jscomp$inline_7392$$);if($app$util$dom$is_bounding_rect_outside_QMARK_$$($placement_brect$jscomp$inline_7397$$,$window_size$jscomp$inline_7393$$)){$placements$jscomp$inline_7394$$=$APP.$cljs$core$rest$$($placements$jscomp$inline_7394$$);continue}else{$placement_rect_temp__5825__auto__$jscomp$250_tooltip_brect$jscomp$2$$=
[$placement__$1$jscomp$inline_7396_temp__5825__auto__$jscomp$inline_7395$$,$placement_brect$jscomp$inline_7397$$];break a}}else{$placement_rect_temp__5825__auto__$jscomp$250_tooltip_brect$jscomp$2$$=null;break a}break}$placement_rect_temp__5825__auto__$jscomp$250_tooltip_brect$jscomp$2$$=void 0}return $APP.$cljs$core$truth_$$($placement_rect_temp__5825__auto__$jscomp$250_tooltip_brect$jscomp$2$$)?($new_placement_origin_brect$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($placement_rect_temp__5825__auto__$jscomp$250_tooltip_brect$jscomp$2$$,
0,null),$placement_rect_temp__5825__auto__$jscomp$250_tooltip_brect$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($placement_rect_temp__5825__auto__$jscomp$250_tooltip_brect$jscomp$2$$,1,null),$APP.$app$util$dom$set_css_property_BANG_$$($tooltip_el$$,"inset-block-start",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1562$top$$.$cljs$core$IFn$_invoke$arity$1$($placement_rect_temp__5825__auto__$jscomp$250_tooltip_brect$jscomp$2$$)),"px"].join("")),$APP.$app$util$dom$set_css_property_BANG_$$($tooltip_el$$,
"inset-inline-start",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($placement_rect_temp__5825__auto__$jscomp$250_tooltip_brect$jscomp$2$$)),"px"].join("")),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_placement_origin_brect$jscomp$2$$,$placement__$1$jscomp$1$$)?$APP.$cljs$core$reset_BANG_$$($placement_STAR_$$,$new_placement_origin_brect$jscomp$2$$):null):null}):null}return null});return(0,$APP.$rumext$v2$create_element$$)("div",
$aria_label$jscomp$2_props__$1$jscomp$37$$,$children$jscomp$260$$,$APP.$cljs$core$truth_$$($visible$$)?(0,$APP.$rumext$v2$portal$$)((0,$APP.$rumext$v2$jsx$$)("div",{role:"tooltip",id:$tooltip_id$jscomp$4$$,ref:$tooltip_ref$$,className:"main_ui_ds_tooltip_tooltip__tooltip",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:$delay$jscomp$8_tooltip_class$$,children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_tooltip_tooltip__tooltip-content",children:$content$jscomp$226_content__$1$jscomp$39$$}),
(0,$APP.$rumext$v2$jsx$$)("div",{id:"tooltip-arrow",className:"main_ui_ds_tooltip_tooltip__tooltip-arrow"})]})}),$container$jscomp$77_props_72171$$):null)};
$app$main$ui$ds$controls$utilities$hint_message$hint_message_STAR_$$=function($props_72200_type__$1$jscomp$9$$){var $message$jscomp$102$$=void 0,$type$jscomp$562$$=void 0,$id$jscomp$799$$=void 0,$class$$jscomp$14$$=void 0;({id:$id$jscomp$799$$,className:$class$$jscomp$14$$,message:$message$jscomp$102$$,type:$type$jscomp$562$$}=$props_72200_type__$1$jscomp$9$$);$props_72200_type__$1$jscomp$9$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$562$$,$APP.$cljs$cst$275$hint$$);
return(0,$APP.$rumext$v2$jsx$$)("div",{className:""+($class$$jscomp$14$$??"")+" main_ui_ds_controls_utilities_hint_message__hint-message "+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_72200_type__$1$jscomp$9$$,"hint")?"main_ui_ds_controls_utilities_hint_message__type-hint":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_72200_type__$1$jscomp$9$$,"warning")?"main_ui_ds_controls_utilities_hint_message__type-warning":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_72200_type__$1$jscomp$9$$,
"error")?"main_ui_ds_controls_utilities_hint_message__type-error":"")),"aria-live":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_72200_type__$1$jscomp$9$$,"warning")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_72200_type__$1$jscomp$9$$,"error")?"polite":null,children:$message$jscomp$102$$!=null?(0,$APP.$rumext$v2$jsx$$)("span",{id:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$799$$),"-hint"].join(""),className:"main_ui_ds_controls_utilities_hint_message__hint-message-text",
children:$message$jscomp$102$$}):null})};
$APP.$app$main$ui$ds$controls$utilities$label$label_STAR_$$=function($children$jscomp$262_props_72252$$){var $for$$$,$class$$jscomp$16$$,$props$jscomp$223$$;({className:$class$$jscomp$16$$,htmlFor:$for$$$,isOptional:$is_optional_is_optional__$1_or__5025__auto__$jscomp$inline_7399$$,children:$children$jscomp$262_props_72252$$,...$props$jscomp$223$$}=$children$jscomp$262_props_72252$$);var $is_optional_is_optional__$1_or__5025__auto__$jscomp$inline_7399$$=$APP.$cljs$core$truth_$$($is_optional_is_optional__$1_or__5025__auto__$jscomp$inline_7399$$)?$is_optional_is_optional__$1_or__5025__auto__$jscomp$inline_7399$$:
!1;return(0,$APP.$rumext$v2$create_element$$)("label",{...$props$jscomp$223$$,className:""+($class$$jscomp$16$$??"")+" main_ui_ds_controls_utilities_label__label",htmlFor:$for$$$},(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$children$jscomp$262_props_72252$$!=null?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_controls_utilities_label__label-text",children:$children$jscomp$262_props_72252$$}):null,$APP.$cljs$core$truth_$$($is_optional_is_optional__$1_or__5025__auto__$jscomp$inline_7399$$)?
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_controls_utilities_label__label-optional",children:"(Optional)"}):null]}))};
$app$main$ui$ds$utilities$swatch$color_title$$=function($color$jscomp$116_color_item$$){var $map__72302_name$jscomp$375$$=$APP.$cljs$core$meta$$($color$jscomp$116_color_item$$),$map__72302__$1_path$jscomp$254_path_and_name$$=$APP.$cljs$core$__destructure_map$$($map__72302_name$jscomp$375$$);$map__72302_name$jscomp$375$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72302__$1_path$jscomp$254_path_and_name$$,$APP.$cljs$cst$725$name$$);$map__72302__$1_path$jscomp$254_path_and_name$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72302__$1_path$jscomp$254_path_and_name$$,
$APP.$cljs$cst$296$path$$);$map__72302__$1_path$jscomp$254_path_and_name$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__72302__$1_path$jscomp$254_path_and_name$$)?!$APP.$cuerdas$core$empty_QMARK_$$($map__72302__$1_path$jscomp$254_path_and_name$$):$map__72302__$1_path$jscomp$254_path_and_name$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__72302__$1_path$jscomp$254_path_and_name$$)," / ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__72302_name$jscomp$375$$)].join(""):
$map__72302_name$jscomp$375$$;var $gradient$jscomp$22$$=$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$116_color_item$$),$image$jscomp$26$$=$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$116_color_item$$);$color$jscomp$116_color_item$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$116_color_item$$);return $map__72302_name$jscomp$375$$!=null?$color$jscomp$116_color_item$$!=null?""+($map__72302__$1_path$jscomp$254_path_and_name$$??
"")+" ("+($color$jscomp$116_color_item$$??"")+")":$gradient$jscomp$22$$!=null?""+($map__72302__$1_path$jscomp$254_path_and_name$$??"")+" ("+($APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$22$$))??"")+")":$image$jscomp$26$$!=null?""+($map__72302__$1_path$jscomp$254_path_and_name$$??"")+" ("+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.image")??"")+")":$map__72302__$1_path$jscomp$254_path_and_name$$:$color$jscomp$116_color_item$$!=
null?$color$jscomp$116_color_item$$:$gradient$jscomp$22$$!=null?$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$22$$)):$image$jscomp$26$$!=null?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.image"):null};
$APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$=function($element_type_props_72306$$){var $tooltip_content$$=void 0,$background$jscomp$11_button_type_read_only_QMARK_$jscomp$3$$=void 0,$children$jscomp$263_has_errors$$=void 0,$on_click$jscomp$4$$=void 0,$size$jscomp$132$$=void 0,$active$jscomp$1$$=void 0,$class$$jscomp$18_class$__$1$jscomp$1$$=void 0,$show_tooltip_show_tooltip__$1$$=void 0,$props$jscomp$225$$=void 0;({background:$background$jscomp$11_button_type_read_only_QMARK_$jscomp$3$$,className:$class$$jscomp$18_class$__$1$jscomp$1$$,
size:$size$jscomp$132$$,active:$active$jscomp$1$$,hasErrors:$children$jscomp$263_has_errors$$,tooltipContent:$tooltip_content$$,onClick:$on_click$jscomp$4$$,showTooltip:$show_tooltip_show_tooltip__$1$$,...$props$jscomp$225$$}=$element_type_props_72306$$);var $background__$1$$=$APP.$cljs$core$object_QMARK_$$($background$jscomp$11_button_type_read_only_QMARK_$jscomp$3$$)?$APP.$app$common$json$__GT_clj$$($background$jscomp$11_button_type_read_only_QMARK_$jscomp$3$$):$background$jscomp$11_button_type_read_only_QMARK_$jscomp$3$$;
$background$jscomp$11_button_type_read_only_QMARK_$jscomp$3$$=$on_click$jscomp$4$$==null;var $element_id$jscomp$2_id_QMARK_$$=$APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($background__$1$$)!=null;$element_type_props_72306$$=$background$jscomp$11_button_type_read_only_QMARK_$jscomp$3$$?"div":"button";$background$jscomp$11_button_type_read_only_QMARK_$jscomp$3$$=$background$jscomp$11_button_type_read_only_QMARK_$jscomp$3$$?null:"button";$show_tooltip_show_tooltip__$1$$=$show_tooltip_show_tooltip__$1$$!=
null?$show_tooltip_show_tooltip__$1$$:!0;var $size__$1$jscomp$6$$=function(){var $or__5025__auto__$jscomp$906$$=$size$jscomp$132$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$906$$)?$or__5025__auto__$jscomp$906$$:"small"}(),$active__$1$$=function(){var $or__5025__auto__$jscomp$907$$=$active$jscomp$1$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$907$$)?$or__5025__auto__$jscomp$907$$:!1}(),$gradient_type$jscomp$1$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($background__$1$$)),
$gradient_data_gradient_stops$$=$APP.$cljs$cst$1733$stops$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($background__$1$$));$gradient_data_gradient_stops$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$gradient_type$jscomp$1$$,$APP.$cljs$cst$1733$stops$$,$gradient_data_gradient_stops$$],null);var $image$jscomp$27$$=$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($background__$1$$),$format$jscomp$35$$=$element_id$jscomp$2_id_QMARK_$$?
"rounded":"square";$element_id$jscomp$2_id_QMARK_$$=(0,$APP.$rumext$v2$use_id$$)();var $has_opacity_QMARK_$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($background__$1$$)!=null&&$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($background__$1$$)<1,$element_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$on_click__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($background__$1$$),$APP.$rumext$v2$adapt$$($on_click$jscomp$4$$)],function($event$jscomp$127$$){return $APP.$cljs$core$fn_QMARK_$$($on_click$jscomp$4$$)?
$on_click$jscomp$4$$($background__$1$$,$event$jscomp$127$$):null});$class$$jscomp$18_class$__$1$jscomp$1$$=""+($class$$jscomp$18_class$__$1$jscomp$1$$??"")+" main_ui_ds_utilities_swatch__swatch "+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($size__$1$jscomp$6$$,"small")?"main_ui_ds_utilities_swatch__small":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($size__$1$jscomp$6$$,"medium")?"main_ui_ds_utilities_swatch__medium":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($size__$1$jscomp$6$$,
"large")?"main_ui_ds_utilities_swatch__large":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($format$jscomp$35$$,"square")?"main_ui_ds_utilities_swatch__square":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active__$1$$,!0)?"main_ui_ds_utilities_swatch__active":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($element_type_props_72306$$,"button")?"main_ui_ds_utilities_swatch__interactive":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($format$jscomp$35$$,
"rounded")?"main_ui_ds_utilities_swatch__rounded":""));$children$jscomp$263_has_errors$$=(0,$APP.$rumext$v2$create_element$$)($element_type_props_72306$$,{...$props$jscomp$225$$,className:$class$$jscomp$18_class$__$1$jscomp$1$$,onClick:$on_click__$1$$,type:$background$jscomp$11_button_type_read_only_QMARK_$jscomp$3$$,"aria-labelledby":$element_id$jscomp$2_id_QMARK_$$,ref:$element_ref$$},$gradient_type$jscomp$1$$!=null?(0,$APP.$rumext$v2$jsx$$)("div",{style:{backgroundImage:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$util$color$gradient__GT_css$$($gradient_data_gradient_stops$$)),
", repeating-conic-gradient(lightgray 0% 25%, white 0% 50%)"].join("")},className:"main_ui_ds_utilities_swatch__swatch-gradient"}):$image$jscomp$27$$!=null?function(){var $uri$jscomp$100$$=$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($image$jscomp$27$$);return(0,$APP.$rumext$v2$jsx$$)("div",{style:{backgroundImage:"url("+($uri$jscomp$100$$??"")+")"},className:"main_ui_ds_utilities_swatch__swatch-image"})}():$APP.$cljs$core$truth_$$($children$jscomp$263_has_errors$$)?(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_ds_utilities_swatch__swatch-error"}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_utilities_swatch__swatch-opacity",children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{background:$app$util$color$color__GT_background$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($background__$1$$,$APP.$cljs$cst$1734$opacity$$,1))},className:"main_ui_ds_utilities_swatch__swatch-solid-side"}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{"--solid-color-overlay":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$util$color$color__GT_background$$($background__$1$$))},
className:"main_ui_ds_utilities_swatch__swatch-opacity-side "+($has_opacity_QMARK_$$?"main_ui_ds_utilities_swatch__swatch-opacity-side-transparency":"")+" "+($has_opacity_QMARK_$$?"":"main_ui_ds_utilities_swatch__swatch-opacity-side-solid-color")})]}));return $APP.$cljs$core$truth_$$($show_tooltip_show_tooltip__$1$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$APP.$cljs$core$truth_$$($tooltip_content$$)?$tooltip_content$$:$app$main$ui$ds$utilities$swatch$color_title$$($background__$1$$),
triggerRef:$element_ref$$,id:$element_id$jscomp$2_id_QMARK_$$,children:$children$jscomp$263_has_errors$$}):$children$jscomp$263_has_errors$$};
$goog$string$format$$=function($formatString$jscomp$1$$,$var_args$jscomp$1384$$){const $args$jscomp$251$$=Array.prototype.slice.call(arguments),$template$jscomp$7$$=$args$jscomp$251$$.shift();if(typeof $template$jscomp$7$$=="undefined")throw Error("[goog.string.format] Template required");return $template$jscomp$7$$.replace(/%([0\- \+]*)(\d+)?(\.(\d+))?([%sfdiu])/g,function($match$jscomp$55$$,$flags$jscomp$35$$,$width$jscomp$164$$,$dotp$$,$precision$jscomp$21$$,$type$jscomp$565$$,$offset$jscomp$186$$,
$wholeString$$){if($type$jscomp$565$$=="%")return"%";const $value$jscomp$726$$=$args$jscomp$251$$.shift();if(typeof $value$jscomp$726$$=="undefined")throw Error("[goog.string.format] Not enough arguments");arguments[0]=$value$jscomp$726$$;return $goog$string$format$$.$demuxes_$[$type$jscomp$565$$].apply(null,arguments)})};
$app$main$ui$components$color_bullet$color_title$$=function($color$jscomp$118_color_item$jscomp$1$$){var $map__72326_name$jscomp$376$$=$APP.$cljs$core$meta$$($color$jscomp$118_color_item$jscomp$1$$),$map__72326__$1_path$jscomp$255_path_and_name$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($map__72326_name$jscomp$376$$);$map__72326_name$jscomp$376$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72326__$1_path$jscomp$255_path_and_name$jscomp$1$$,$APP.$cljs$cst$725$name$$);$map__72326__$1_path$jscomp$255_path_and_name$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72326__$1_path$jscomp$255_path_and_name$jscomp$1$$,$APP.$cljs$cst$296$path$$);$map__72326__$1_path$jscomp$255_path_and_name$jscomp$1$$=$APP.$cljs$core$truth_$$($map__72326__$1_path$jscomp$255_path_and_name$jscomp$1$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__72326__$1_path$jscomp$255_path_and_name$jscomp$1$$)," / ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__72326_name$jscomp$376$$)].join(""):$map__72326_name$jscomp$376$$;
var $gradient$jscomp$23$$=$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$118_color_item$jscomp$1$$),$image$jscomp$28$$=$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$118_color_item$jscomp$1$$),$color_str$jscomp$2_opacity$jscomp$40$$=$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$118_color_item$jscomp$1$$);$color$jscomp$118_color_item$jscomp$1$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$118_color_item$jscomp$1$$);
$color_str$jscomp$2_opacity$jscomp$40$$=$APP.$cljs$core$truth_$$($color$jscomp$118_color_item$jscomp$1$$)?typeof $color_str$jscomp$2_opacity$jscomp$40$$==="number"&&$color_str$jscomp$2_opacity$jscomp$40$$<1?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$118_color_item$jscomp$1$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($color_str$jscomp$2_opacity$jscomp$40$$*100)),"%"].join(""):$color$jscomp$118_color_item$jscomp$1$$:
null;return $map__72326_name$jscomp$376$$!=null?$color$jscomp$118_color_item$jscomp$1$$!=null?""+($map__72326__$1_path$jscomp$255_path_and_name$jscomp$1$$??"")+" ("+($color_str$jscomp$2_opacity$jscomp$40$$??"")+")":$gradient$jscomp$23$$!=null?""+($map__72326__$1_path$jscomp$255_path_and_name$jscomp$1$$??"")+" ("+($APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$23$$))??"")+")":$image$jscomp$28$$!=null?""+($map__72326__$1_path$jscomp$255_path_and_name$jscomp$1$$??
"")+" ("+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.image")??"")+")":$map__72326__$1_path$jscomp$255_path_and_name$jscomp$1$$:$color$jscomp$118_color_item$jscomp$1$$!=null?$color_str$jscomp$2_opacity$jscomp$40$$:$gradient$jscomp$23$$!=null?$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$23$$)):$image$jscomp$28$$!=null?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.image"):null};
$APP.$app$main$ui$components$color_bullet$color_name$$=function($map__72337_map__72337__$1_name$jscomp$377_props_72335$$){var $color$jscomp$120_color__$1$jscomp$16$$=$map__72337_map__72337__$1_name$jscomp$377_props_72335$$.color,$JSCompiler_temp$jscomp$10908_on_click$jscomp$6$$=$map__72337_map__72337__$1_name$jscomp$377_props_72335$$["on-click"],$JSCompiler_temp_const$jscomp$10909_size$jscomp$133$$=$map__72337_map__72337__$1_name$jscomp$377_props_72335$$.size,$on_double_click$$=$map__72337_map__72337__$1_name$jscomp$377_props_72335$$["on-double-click"],
$JSCompiler_inline_result$jscomp$10910_origin$jscomp$41_title$jscomp$inline_12929$$=$map__72337_map__72337__$1_name$jscomp$377_props_72335$$.origin;$map__72337_map__72337__$1_name$jscomp$377_props_72335$$=$APP.$cljs$core$meta$$($color$jscomp$120_color__$1$jscomp$16$$);$map__72337_map__72337__$1_name$jscomp$377_props_72335$$=$APP.$cljs$core$__destructure_map$$($map__72337_map__72337__$1_name$jscomp$377_props_72335$$);$map__72337_map__72337__$1_name$jscomp$377_props_72335$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72337_map__72337__$1_name$jscomp$377_props_72335$$,
$APP.$cljs$cst$725$name$$);var $gradient$jscomp$25_map__72339__$1$$=$APP.$cljs$core$__destructure_map$$(typeof $color$jscomp$120_color__$1$jscomp$16$$==="string"?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,$color$jscomp$120_color__$1$jscomp$16$$,$APP.$cljs$cst$1734$opacity$$,1],null):$color$jscomp$120_color__$1$jscomp$16$$);$color$jscomp$120_color__$1$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient$jscomp$25_map__72339__$1$$,$APP.$cljs$cst$1298$color$$);
$gradient$jscomp$25_map__72339__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient$jscomp$25_map__72339__$1$$,$APP.$cljs$cst$1724$gradient$$);$APP.$cljs$core$not$$($JSCompiler_temp_const$jscomp$10909_size$jscomp$133$$)||$JSCompiler_temp_const$jscomp$10909_size$jscomp$133$$>64?($JSCompiler_temp_const$jscomp$10909_size$jscomp$133$$=($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10910_origin$jscomp$41_title$jscomp$inline_12929$$,$APP.$cljs$cst$4751$palette$$)&&
$JSCompiler_temp_const$jscomp$10909_size$jscomp$133$$<72?"main_ui_components_color_bullet__color-text":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10910_origin$jscomp$41_title$jscomp$inline_12929$$,$APP.$cljs$cst$4751$palette$$)&&$JSCompiler_temp_const$jscomp$10909_size$jscomp$133$$>=64&&$JSCompiler_temp_const$jscomp$10909_size$jscomp$133$$<72?"main_ui_components_color_bullet__small-text":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10910_origin$jscomp$41_title$jscomp$inline_12929$$,
$APP.$cljs$cst$4751$palette$$)&&$JSCompiler_temp_const$jscomp$10909_size$jscomp$133$$>=72?"main_ui_components_color_bullet__big-text":"")+" "+($gradient$jscomp$25_map__72339__$1$$!=null?"main_ui_components_color_bullet__gradient":"")+" "+($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10910_origin$jscomp$41_title$jscomp$inline_12929$$,$APP.$cljs$cst$4751$palette$$)?"main_ui_components_color_bullet__color-row-name":""),$JSCompiler_inline_result$jscomp$10910_origin$jscomp$41_title$jscomp$inline_12929$$=
$APP.$cljs$core$truth_$$($map__72337_map__72337__$1_name$jscomp$377_props_72335$$)?$map__72337_map__72337__$1_name$jscomp$377_props_72335$$:$APP.$cljs$core$truth_$$($color$jscomp$120_color__$1$jscomp$16$$)?$color$jscomp$120_color__$1$jscomp$16$$:$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$25_map__72339__$1$$)),$JSCompiler_inline_result$jscomp$10910_origin$jscomp$41_title$jscomp$inline_12929$$=$APP.$cuerdas$core$replace$$($JSCompiler_inline_result$jscomp$10910_origin$jscomp$41_title$jscomp$inline_12929$$,
".",".​"),$JSCompiler_temp$jscomp$10908_on_click$jscomp$6$$=(0,$APP.$rumext$v2$jsx$$)("span",{title:$map__72337_map__72337__$1_name$jscomp$377_props_72335$$,onClick:$JSCompiler_temp$jscomp$10908_on_click$jscomp$6$$,onDoubleClick:$on_double_click$$,className:$JSCompiler_temp_const$jscomp$10909_size$jscomp$133$$,children:$JSCompiler_inline_result$jscomp$10910_origin$jscomp$41_title$jscomp$inline_12929$$})):$JSCompiler_temp$jscomp$10908_on_click$jscomp$6$$=null;return $JSCompiler_temp$jscomp$10908_on_click$jscomp$6$$};
$app$main$data$exports$assets$toggle_detail_visibililty$$=function(){typeof $app$main$data$exports$assets$toggle_detail_visibililty_72381$$==="undefined"&&($app$main$data$exports$assets$toggle_detail_visibililty_72381$$=function($meta72382$$){this.$meta72382$=$meta72382$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$exports$assets$toggle_detail_visibililty_72381$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$exports$assets$toggle_detail_visibililty_72381$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4752$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_toggle_detail_visibililty$$},$app$main$data$exports$assets$toggle_detail_visibililty_72381$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72383$$,$meta72382__$1$$){return new $app$main$data$exports$assets$toggle_detail_visibililty_72381$$($meta72382__$1$$)},$app$main$data$exports$assets$toggle_detail_visibililty_72381$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72382$},$app$main$data$exports$assets$toggle_detail_visibililty_72381$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$toggle_detail_visibililty_72381$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2690$$,$state$jscomp$1005$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1005$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2177$export$$,$cljs$cst$4753$detail_visible$$],null),$APP.$cljs$core$not$$)});return new $app$main$data$exports$assets$toggle_detail_visibililty_72381$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$exports$assets$clear_export_state$$=function($id$jscomp$803$$){typeof $app$main$data$exports$assets$clear_export_state_72393$$==="undefined"&&($app$main$data$exports$assets$clear_export_state_72393$$=function($id$jscomp$804$$,$meta72394$$){this.id=$id$jscomp$804$$;this.$meta72394$=$meta72394$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$exports$assets$clear_export_state_72393$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$exports$assets$clear_export_state_72393$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4756$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_clear_export_state$$},$app$main$data$exports$assets$clear_export_state_72393$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72395$$,$meta72394__$1$$){return new $app$main$data$exports$assets$clear_export_state_72393$$(this.id,$meta72394__$1$$)},$app$main$data$exports$assets$clear_export_state_72393$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72394$},$app$main$data$exports$assets$clear_export_state_72393$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$clear_export_state_72393$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2692_existing_id$$,$state$jscomp$1007$$){$_$jscomp$2692_existing_id$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2177$export$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1007$$));
return $_$jscomp$2692_existing_id$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.id,$_$jscomp$2692_existing_id$$)?$state$jscomp$1007$$:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1007$$,$APP.$cljs$cst$2177$export$$)});return new $app$main$data$exports$assets$clear_export_state_72393$$($id$jscomp$803$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$exports$assets$show_workspace_export_dialog$$=function($p__72401$$){var $map__72402__$1$$=$APP.$cljs$core$__destructure_map$$($p__72401$$),$selected$jscomp$116$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72402__$1$$,$APP.$cljs$cst$1921$selected$$),$origin$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72402__$1$$,$APP.$cljs$cst$1786$origin$$);typeof $app$main$data$exports$assets$show_workspace_export_dialog_72403$$==="undefined"&&($app$main$data$exports$assets$show_workspace_export_dialog_72403$$=
function($p__72401$jscomp$1$$,$map__72402$jscomp$1$$,$selected$jscomp$117$$,$origin$jscomp$43$$,$meta72404$$){this.$p__72401$=$p__72401$jscomp$1$$;this.$map__72402$=$map__72402$jscomp$1$$;this.selected=$selected$jscomp$117$$;this.origin=$origin$jscomp$43$$;this.$meta72404$=$meta72404$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$exports$assets$show_workspace_export_dialog_72403$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$exports$assets$show_workspace_export_dialog_72403$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4757$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_show_workspace_export_dialog$$},$app$main$data$exports$assets$show_workspace_export_dialog_72403$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72405$$,$meta72404__$1$$){return new $app$main$data$exports$assets$show_workspace_export_dialog_72403$$(this.$p__72401$,this.$map__72402$,this.selected,
this.origin,$meta72404__$1$$)},$app$main$data$exports$assets$show_workspace_export_dialog_72403$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72404$},$app$main$data$exports$assets$show_workspace_export_dialog_72403$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$show_workspace_export_dialog_72403$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2693$$,$state$jscomp$1008$$){var $self__$jscomp$6718$$=
this,$___$2$jscomp$620$$=this,$file_id$jscomp$308$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1008$$),$page_id$jscomp$334$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1008$$),$selected__$1$jscomp$11$$=function(){var $or__5025__auto__$jscomp$910$$=$self__$jscomp$6718$$.selected;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$910$$)?$or__5025__auto__$jscomp$910$$:$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$03$$($state$jscomp$1008$$,
$page_id$jscomp$334$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)}(),$shapes$jscomp$127$$=$APP.$cljs$core$seq$$($selected__$1$jscomp$11$$)?$app$main$data$helpers$lookup_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$1008$$,$selected__$1$jscomp$11$$):$APP.$cljs$core$reverse$$($app$main$data$helpers$filter_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$1008$$,function($p1__72399_SHARP_$$){return $APP.$cljs$core$count$$($APP.$cljs$cst$1870$exports$$.$cljs$core$IFn$_invoke$arity$1$($p1__72399_SHARP_$$))>
0})),$page$jscomp$108$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1008$$),$page_name$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$108$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4125$export_shapes$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1870$exports$$,$APP.$cljs$core$vec$$(function(){return function $app$main$data$exports$assets$show_workspace_export_dialog_$_iter__72408$$($s__72409$$){return new $APP.$cljs$core$LazySeq$$(null,
function(){for(var $s__72409__$1$$=$s__72409$$;;){var $fs__5500__auto__$jscomp$4_temp__5825__auto__$jscomp$251$$=$APP.$cljs$core$seq$$($s__72409__$1$$);if($fs__5500__auto__$jscomp$4_temp__5825__auto__$jscomp$251$$){var $xs__6385__auto__$jscomp$12$$=$fs__5500__auto__$jscomp$4_temp__5825__auto__$jscomp$251$$,$shape$jscomp$775$$=$APP.$cljs$core$first$$($xs__6385__auto__$jscomp$12$$);if($fs__5500__auto__$jscomp$4_temp__5825__auto__$jscomp$251$$=$APP.$cljs$core$seq$$(function($s__72409__$1$jscomp$1$$,
$shape$jscomp$776$$,$xs__6385__auto__$jscomp$13$$,$temp__5825__auto__$jscomp$252$$,$file_id$jscomp$309$$,$page_id$jscomp$335$$,$selected__$1$jscomp$12$$,$shapes$jscomp$128$$,$page$jscomp$109$$,$page_name$jscomp$1$$,$___$2$jscomp$621$$,$map__72402$jscomp$2$$,$map__72402__$1$jscomp$1$$,$selected$jscomp$118$$,$origin$jscomp$44$$){return function $app$main$data$exports$assets$show_workspace_export_dialog_$_iter__72408_$_iter__72410$$($s__72411$$){return new $APP.$cljs$core$LazySeq$$(null,function($s__72409__$1$jscomp$2$$,
$shape$jscomp$777$$,$xs__6385__auto__$jscomp$14$$,$temp__5825__auto__$jscomp$253$$,$file_id$jscomp$310$$,$page_id$jscomp$336$$){return function(){for(;;){var $s__72411__$2_temp__5825__auto____$1$jscomp$14$$=$APP.$cljs$core$seq$$($s__72411$$);if($s__72411__$2_temp__5825__auto____$1$jscomp$14$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__72411__$2_temp__5825__auto____$1$jscomp$14$$)){var $JSCompiler_inline_result$jscomp$1330_c__5501__auto__$jscomp$32$$=$APP.$cljs$core$_chunked_first$$($s__72411__$2_temp__5825__auto____$1$jscomp$14$$),
$size__5502__auto__$jscomp$32$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1330_c__5501__auto__$jscomp$32$$),$b__72413_export$$jscomp$1$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$32$$);a:{for(var $i__72412$jscomp$inline_7404$$=0;;)if($i__72412$jscomp$inline_7404$$<$size__5502__auto__$jscomp$32$$){var $export$$jscomp$inline_7405_x$jscomp$inline_12932$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1330_c__5501__auto__$jscomp$32$$,$i__72412$jscomp$inline_7404$$),
$b$jscomp$inline_12931$$=$b__72413_export$$jscomp$1$$;$export$$jscomp$inline_7405_x$jscomp$inline_12932$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($export$$jscomp$inline_7405_x$jscomp$inline_12932$$,$APP.$cljs$cst$3109$enabled$$,
!0),$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$336$$),$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$310$$),$APP.$cljs$cst$2272$object_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$777$$)),$APP.$cljs$cst$1811$shape$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$777$$,$APP.$cljs$cst$1870$exports$$)),$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$777$$));$b$jscomp$inline_12931$$.add($export$$jscomp$inline_7405_x$jscomp$inline_12932$$);
$i__72412$jscomp$inline_7404$$+=1}else{$JSCompiler_inline_result$jscomp$1330_c__5501__auto__$jscomp$32$$=!0;break a}$JSCompiler_inline_result$jscomp$1330_c__5501__auto__$jscomp$32$$=void 0}return $JSCompiler_inline_result$jscomp$1330_c__5501__auto__$jscomp$32$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__72413_export$$jscomp$1$$),$app$main$data$exports$assets$show_workspace_export_dialog_$_iter__72408_$_iter__72410$$($APP.$cljs$core$_chunked_rest$$($s__72411__$2_temp__5825__auto____$1$jscomp$14$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__72413_export$$jscomp$1$$),null)}$b__72413_export$$jscomp$1$$=$APP.$cljs$core$first$$($s__72411__$2_temp__5825__auto____$1$jscomp$14$$);return $APP.$cljs$core$cons$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($b__72413_export$$jscomp$1$$,
$APP.$cljs$cst$3109$enabled$$,!0),$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$336$$),$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$310$$),$APP.$cljs$cst$2272$object_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$777$$)),$APP.$cljs$cst$1811$shape$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$777$$,$APP.$cljs$cst$1870$exports$$)),$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$777$$)),$app$main$data$exports$assets$show_workspace_export_dialog_$_iter__72408_$_iter__72410$$($APP.$cljs$core$rest$$($s__72411__$2_temp__5825__auto____$1$jscomp$14$$)))}return null}}}($s__72409__$1$jscomp$1$$,
$shape$jscomp$776$$,$xs__6385__auto__$jscomp$13$$,$temp__5825__auto__$jscomp$252$$,$file_id$jscomp$309$$,$page_id$jscomp$335$$,$selected__$1$jscomp$12$$,$shapes$jscomp$128$$,$page$jscomp$109$$,$page_name$jscomp$1$$,$___$2$jscomp$621$$,$map__72402$jscomp$2$$,$map__72402__$1$jscomp$1$$,$selected$jscomp$118$$,$origin$jscomp$44$$),null,null)}}($s__72409__$1$$,$shape$jscomp$775$$,$xs__6385__auto__$jscomp$12$$,$fs__5500__auto__$jscomp$4_temp__5825__auto__$jscomp$251$$,$file_id$jscomp$308$$,$page_id$jscomp$334$$,
$selected__$1$jscomp$11$$,$shapes$jscomp$127$$,$page$jscomp$108$$,$page_name$$,$___$2$jscomp$620$$,$p__72401$$,$map__72402__$1$$,$selected$jscomp$116$$,$origin$jscomp$42$$)($APP.$cljs$cst$1870$exports$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$775$$))))return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($fs__5500__auto__$jscomp$4_temp__5825__auto__$jscomp$251$$,$app$main$data$exports$assets$show_workspace_export_dialog_$_iter__72408$$($APP.$cljs$core$rest$$($s__72409__$1$$)));$s__72409__$1$$=
$APP.$cljs$core$rest$$($s__72409__$1$$)}else return null}},null,null)}($shapes$jscomp$127$$)}()),$APP.$cljs$cst$1786$origin$$,$self__$jscomp$6718$$.origin,$APP.$cljs$cst$725$name$$,$page_name$$],null)))});return new $app$main$data$exports$assets$show_workspace_export_dialog_72403$$($p__72401$$,$map__72402__$1$$,$selected$jscomp$116$$,$origin$jscomp$42$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$exports$assets$show_viewer_export_dialog$$=function($p__72421$$){var $map__72422__$1$$=$APP.$cljs$core$__destructure_map$$($p__72421$$),$shapes$jscomp$130$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72422__$1$$,$APP.$cljs$cst$1614$shapes$$),$page_id$jscomp$337$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72422__$1$$,$APP.$cljs$cst$2043$page_id$$),$file_id$jscomp$311$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72422__$1$$,$APP.$cljs$cst$1644$file_id$$),
$share_id$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72422__$1$$,$APP.$cljs$cst$3237$share_id$$),$exports__$1$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72422__$1$$,$APP.$cljs$cst$1870$exports$$),$name$jscomp$378$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72422__$1$$,$APP.$cljs$cst$725$name$$);typeof $app$main$data$exports$assets$show_viewer_export_dialog_72423$$==="undefined"&&($app$main$data$exports$assets$show_viewer_export_dialog_72423$$=
function($p__72421$jscomp$1$$,$map__72422$jscomp$1$$,$shapes$jscomp$131$$,$page_id$jscomp$338$$,$file_id$jscomp$312$$,$share_id$jscomp$13$$,$exports$jscomp$8$$,$name$jscomp$379$$,$meta72424$$){this.$p__72421$=$p__72421$jscomp$1$$;this.$map__72422$=$map__72422$jscomp$1$$;this.shapes=$shapes$jscomp$131$$;this.$page_id$=$page_id$jscomp$338$$;this.$file_id$=$file_id$jscomp$312$$;this.$share_id$=$share_id$jscomp$13$$;this.exports=$exports$jscomp$8$$;this.name=$name$jscomp$379$$;this.$meta72424$=$meta72424$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$exports$assets$show_viewer_export_dialog_72423$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$show_viewer_export_dialog_72423$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4758$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_show_viewer_export_dialog$$},$app$main$data$exports$assets$show_viewer_export_dialog_72423$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72425$$,$meta72424__$1$$){return new $app$main$data$exports$assets$show_viewer_export_dialog_72423$$(this.$p__72421$,this.$map__72422$,this.shapes,this.$page_id$,this.$file_id$,this.$share_id$,this.exports,this.name,$meta72424__$1$$)},$app$main$data$exports$assets$show_viewer_export_dialog_72423$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72424$},$app$main$data$exports$assets$show_viewer_export_dialog_72423$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$exports$assets$show_viewer_export_dialog_72423$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6722$$=this,$___$3$jscomp$202$$=this,$exports__$1$jscomp$3$$=function(){return function $app$main$data$exports$assets$show_viewer_export_dialog_$_iter__72428$$($s__72429$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__72429__$1$$=$s__72429$$;;){var $fs__5500__auto__$jscomp$5_temp__5825__auto__$jscomp$254$$=$APP.$cljs$core$seq$$($s__72429__$1$$);
if($fs__5500__auto__$jscomp$5_temp__5825__auto__$jscomp$254$$){var $xs__6385__auto__$jscomp$15$$=$fs__5500__auto__$jscomp$5_temp__5825__auto__$jscomp$254$$,$shape$jscomp$778$$=$APP.$cljs$core$first$$($xs__6385__auto__$jscomp$15$$);if($fs__5500__auto__$jscomp$5_temp__5825__auto__$jscomp$254$$=$APP.$cljs$core$seq$$(function($s__72429__$1$jscomp$1$$,$shape$jscomp$779$$,$xs__6385__auto__$jscomp$16$$,$temp__5825__auto__$jscomp$255$$,$___$3$jscomp$203$$,$map__72422$jscomp$2$$,$map__72422__$1$jscomp$1$$,
$shapes$jscomp$132$$,$page_id$jscomp$339$$,$file_id$jscomp$313$$,$share_id$jscomp$14$$,$exports__$1$jscomp$4$$,$name$jscomp$380$$){return function $app$main$data$exports$assets$show_viewer_export_dialog_$_iter__72428_$_iter__72430$$($s__72431$$){return new $APP.$cljs$core$LazySeq$$(null,function($s__72429__$1$jscomp$2$$,$shape$jscomp$780$$){return function(){for(;;){var $s__72431__$2_temp__5825__auto____$1$jscomp$15$$=$APP.$cljs$core$seq$$($s__72431$$);if($s__72431__$2_temp__5825__auto____$1$jscomp$15$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__72431__$2_temp__5825__auto____$1$jscomp$15$$)){var $c__5501__auto__$jscomp$33$$=
$APP.$cljs$core$_chunked_first$$($s__72431__$2_temp__5825__auto____$1$jscomp$15$$),$size__5502__auto__$jscomp$33$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$33$$),$b__72433$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$33$$);return function(){for(var $i__72432$$=0;;)if($i__72432$$<$size__5502__auto__$jscomp$33$$){var $G__72438$jscomp$inline_7407_JSCompiler_inline_result$jscomp$1332_export$$jscomp$4$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$33$$,$i__72432$$),$JSCompiler_temp_const$jscomp$1331$$=
$b__72433$$;$G__72438$jscomp$inline_7407_JSCompiler_inline_result$jscomp$1332_export$$jscomp$4$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__72438$jscomp$inline_7407_JSCompiler_inline_result$jscomp$1332_export$$jscomp$4$$,
$APP.$cljs$cst$3109$enabled$$,!0),$APP.$cljs$cst$2043$page_id$$,$self__$jscomp$6722$$.$page_id$),$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$6722$$.$file_id$),$APP.$cljs$cst$2272$object_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$780$$)),$APP.$cljs$cst$1811$shape$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$780$$,$APP.$cljs$cst$1870$exports$$)),$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$780$$));
$G__72438$jscomp$inline_7407_JSCompiler_inline_result$jscomp$1332_export$$jscomp$4$$=$APP.$cljs$core$truth_$$($self__$jscomp$6722$$.$share_id$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__72438$jscomp$inline_7407_JSCompiler_inline_result$jscomp$1332_export$$jscomp$4$$,$APP.$cljs$cst$3237$share_id$$,$self__$jscomp$6722$$.$share_id$):$G__72438$jscomp$inline_7407_JSCompiler_inline_result$jscomp$1332_export$$jscomp$4$$;$JSCompiler_temp_const$jscomp$1331$$.add($G__72438$jscomp$inline_7407_JSCompiler_inline_result$jscomp$1332_export$$jscomp$4$$);
$i__72432$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__72433$$),$app$main$data$exports$assets$show_viewer_export_dialog_$_iter__72428_$_iter__72430$$($APP.$cljs$core$_chunked_rest$$($s__72431__$2_temp__5825__auto____$1$jscomp$15$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__72433$$),null)}var $export$$jscomp$3$$=$APP.$cljs$core$first$$($s__72431__$2_temp__5825__auto____$1$jscomp$15$$);return $APP.$cljs$core$cons$$(function(){var $G__72441$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($export$$jscomp$3$$,
$APP.$cljs$cst$3109$enabled$$,!0),$APP.$cljs$cst$2043$page_id$$,$self__$jscomp$6722$$.$page_id$),$APP.$cljs$cst$1644$file_id$$,$self__$jscomp$6722$$.$file_id$),$APP.$cljs$cst$2272$object_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$780$$)),$APP.$cljs$cst$1811$shape$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$780$$,$APP.$cljs$cst$1870$exports$$)),$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$780$$));
return $APP.$cljs$core$truth_$$($self__$jscomp$6722$$.$share_id$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__72441$$,$APP.$cljs$cst$3237$share_id$$,$self__$jscomp$6722$$.$share_id$):$G__72441$$}(),$app$main$data$exports$assets$show_viewer_export_dialog_$_iter__72428_$_iter__72430$$($APP.$cljs$core$rest$$($s__72431__$2_temp__5825__auto____$1$jscomp$15$$)))}return null}}}($s__72429__$1$jscomp$1$$,$shape$jscomp$779$$,$xs__6385__auto__$jscomp$16$$,$temp__5825__auto__$jscomp$255$$,$___$3$jscomp$203$$,
$map__72422$jscomp$2$$,$map__72422__$1$jscomp$1$$,$shapes$jscomp$132$$,$page_id$jscomp$339$$,$file_id$jscomp$313$$,$share_id$jscomp$14$$,$exports__$1$jscomp$4$$,$name$jscomp$380$$),null,null)}}($s__72429__$1$$,$shape$jscomp$778$$,$xs__6385__auto__$jscomp$15$$,$fs__5500__auto__$jscomp$5_temp__5825__auto__$jscomp$254$$,$___$3$jscomp$202$$,$p__72421$$,$map__72422__$1$$,$shapes$jscomp$130$$,$page_id$jscomp$337$$,$file_id$jscomp$311$$,$share_id$jscomp$12$$,$exports__$1$jscomp$3$$,$name$jscomp$378$$)($self__$jscomp$6722$$.exports)))return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($fs__5500__auto__$jscomp$5_temp__5825__auto__$jscomp$254$$,
$app$main$data$exports$assets$show_viewer_export_dialog_$_iter__72428$$($APP.$cljs$core$rest$$($s__72429__$1$$)));$s__72429__$1$$=$APP.$cljs$core$rest$$($s__72429__$1$$)}else return null}},null,null)}($self__$jscomp$6722$$.shapes)}();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4125$export_shapes$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1870$exports$$,$APP.$cljs$core$vec$$($exports__$1$jscomp$3$$),$APP.$cljs$cst$1786$origin$$,
"viewer",$APP.$cljs$cst$725$name$$,$self__$jscomp$6722$$.name],null)))});return new $app$main$data$exports$assets$show_viewer_export_dialog_72423$$($p__72421$$,$map__72422__$1$$,$shapes$jscomp$130$$,$page_id$jscomp$337$$,$file_id$jscomp$311$$,$share_id$jscomp$12$$,$exports__$1$jscomp$2$$,$name$jscomp$378$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$exports$assets$initialize_export_status$$=function($exports$jscomp$9$$,$cmd$jscomp$5$$,$resource$jscomp$1$$){typeof $app$main$data$exports$assets$initialize_export_status_72450$$==="undefined"&&($app$main$data$exports$assets$initialize_export_status_72450$$=function($exports$jscomp$10$$,$cmd$jscomp$6$$,$resource$jscomp$2$$,$meta72451$$){this.exports=$exports$jscomp$10$$;this.cmd=$cmd$jscomp$6$$;this.$resource$=$resource$jscomp$2$$;this.$meta72451$=$meta72451$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$exports$assets$initialize_export_status_72450$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$initialize_export_status_72450$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4761$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_initialize_export_status$$},$app$main$data$exports$assets$initialize_export_status_72450$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72452$$,$meta72451__$1$$){return new $app$main$data$exports$assets$initialize_export_status_72450$$(this.exports,this.cmd,this.$resource$,$meta72451__$1$$)},$app$main$data$exports$assets$initialize_export_status_72450$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72451$},$app$main$data$exports$assets$initialize_export_status_72450$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$initialize_export_status_72450$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2696$$,$state$jscomp$1010$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1010$$,$APP.$cljs$cst$2177$export$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$4755$widget_visible$$,$APP.$cljs$cst$4762$in_progress$$,$cljs$cst$4753$detail_visible$$,$cljs$cst$4763$resource_id$$,$APP.$cljs$cst$1870$exports$$,$APP.$cljs$cst$2503$last_update$$,$cljs$cst$4764$healthy_QMARK_$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$3115$cmd$$,$APP.$cljs$cst$2244$progress$$],
[!0,!0,!0,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.$resource$),this.exports,$APP.$app$common$time$now$$(),!0,!1,this.cmd,0]))});return new $app$main$data$exports$assets$initialize_export_status_72450$$($exports$jscomp$9$$,$cmd$jscomp$5$$,$resource$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$exports$assets$update_export_status$$=function($p__72456$$){var $map__72458__$1$$=$APP.$cljs$core$__destructure_map$$($p__72456$$),$done$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72458__$1$$,$APP.$cljs$cst$4765$done$$),$status$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72458__$1$$,$APP.$cljs$cst$109$status$$),$resource_uri$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72458__$1$$,$cljs$cst$4766$resource_uri$$),
$filename$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72458__$1$$,$APP.$cljs$cst$4767$filename$$),$mtype$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72458__$1$$,$APP.$cljs$cst$1726$mtype$$);typeof $app$main$data$exports$assets$update_export_status_72459$$==="undefined"&&($app$main$data$exports$assets$update_export_status_72459$$=function($p__72456$jscomp$1$$,$map__72458$jscomp$1$$,$data$jscomp$430$$,$done$jscomp$3$$,$status$jscomp$18$$,$resource_uri$jscomp$1$$,
$filename$jscomp$9$$,$mtype$jscomp$21$$,$meta72460$$){this.$p__72456$=$p__72456$jscomp$1$$;this.$map__72458$=$map__72458$jscomp$1$$;this.data=$data$jscomp$430$$;this.done=$done$jscomp$3$$;this.status=$status$jscomp$18$$;this.$resource_uri$=$resource_uri$jscomp$1$$;this.filename=$filename$jscomp$9$$;this.$mtype$=$mtype$jscomp$21$$;this.$meta72460$=$meta72460$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$exports$assets$update_export_status_72459$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$update_export_status_72459$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4768$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_update_export_status$$},$app$main$data$exports$assets$update_export_status_72459$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72461$$,$meta72460__$1$$){return new $app$main$data$exports$assets$update_export_status_72459$$(this.$p__72456$,this.$map__72458$,this.data,
this.done,this.status,this.$resource_uri$,this.filename,this.$mtype$,$meta72460__$1$$)},$app$main$data$exports$assets$update_export_status_72459$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72460$},$app$main$data$exports$assets$update_export_status_72459$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$update_export_status_72459$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2697_healthy_QMARK_$jscomp$1$$,
$G__72462__$1_G__72462__$2_state$jscomp$1011$$){$_$jscomp$2697_healthy_QMARK_$jscomp$1$$=$APP.$app$common$time$diff_ms$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($G__72462__$1_G__72462__$2_state$jscomp$1011$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2177$export$$,$APP.$cljs$cst$2503$last_update$$],null)))<6E3;$G__72462__$1_G__72462__$2_state$jscomp$1011$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.status,
"running")?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($G__72462__$1_G__72462__$2_state$jscomp$1011$$,$APP.$cljs$cst$2177$export$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2244$progress$$,this.done,$APP.$cljs$cst$2503$last_update$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$time$now$$(),$cljs$cst$4764$healthy_QMARK_$$,$_$jscomp$2697_healthy_QMARK_$jscomp$1$$])):$G__72462__$1_G__72462__$2_state$jscomp$1011$$;$G__72462__$1_G__72462__$2_state$jscomp$1011$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.status,"error")?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($G__72462__$1_G__72462__$2_state$jscomp$1011$$,$APP.$cljs$cst$2177$export$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4762$in_progress$$,!1,$APP.$cljs$cst$849$error$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$145$cause$$.$cljs$core$IFn$_invoke$arity$1$(this.data),$APP.$cljs$cst$2503$last_update$$,$APP.$app$common$time$now$$(),$cljs$cst$4764$healthy_QMARK_$$,
$_$jscomp$2697_healthy_QMARK_$jscomp$1$$])):$G__72462__$1_G__72462__$2_state$jscomp$1011$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.status,"ended")?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($G__72462__$1_G__72462__$2_state$jscomp$1011$$,$APP.$cljs$cst$2177$export$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4762$in_progress$$,!1,$APP.$cljs$cst$2503$last_update$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$time$now$$(),
$cljs$cst$4764$healthy_QMARK_$$,$_$jscomp$2697_healthy_QMARK_$jscomp$1$$])):$G__72462__$1_G__72462__$2_state$jscomp$1011$$},$app$main$data$exports$assets$update_export_status_72459$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$update_export_status_72459$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.status,"ended")?$APP.$app$util$dom$trigger_download_uri$$(this.filename,
this.$mtype$,this.$resource_uri$):null});return new $app$main$data$exports$assets$update_export_status_72459$$($p__72456$$,$map__72458__$1$$,$map__72458__$1$$,$done$jscomp$2$$,$status$jscomp$17$$,$resource_uri$$,$filename$jscomp$8$$,$mtype$jscomp$20$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$exports$assets$request_simple_export$$=function($p__72470$$){var $map__72471__$1$$=$APP.$cljs$core$__destructure_map$$($p__72470$$),$export$$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72471__$1$$,$APP.$cljs$cst$2177$export$$);if($APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4124$wasm_export$$)&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1534$png$$,
null,$APP.$cljs$cst$1536$webp$$,null,$APP.$cljs$cst$1535$jpeg$$,null],null),null),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($export$$jscomp$5$$)))return typeof $app$main$data$exports$assets$request_simple_export_wasm_72472$$==="undefined"&&($app$main$data$exports$assets$request_simple_export_wasm_72472$$=function($p__72470$jscomp$1$$,$map__72471$jscomp$1$$,$export$$jscomp$6$$,$meta72473$$){this.$p__72470$=$p__72470$jscomp$1$$;this.$map__72471$=$map__72471$jscomp$1$$;this.$export$$=
$export$$jscomp$6$$;this.$meta72473$=$meta72473$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$exports$assets$request_simple_export_wasm_72472$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$request_simple_export_wasm_72472$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4769$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_request_simple_export_wasm$$},
$app$main$data$exports$assets$request_simple_export_wasm_72472$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72474$$,$meta72473__$1$$){return new $app$main$data$exports$assets$request_simple_export_wasm_72472$$(this.$p__72470$,this.$map__72471$,this.$export$$,$meta72473__$1$$)},$app$main$data$exports$assets$request_simple_export_wasm_72472$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72473$},$app$main$data$exports$assets$request_simple_export_wasm_72472$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$request_simple_export_wasm_72472$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){var $map__66801__$1$jscomp$inline_12938_url$jscomp$inline_12942$$=$APP.$cljs$core$__destructure_map$$(this.$export$$),$mtype$jscomp$inline_12943_type$jscomp$inline_12939$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66801__$1$jscomp$inline_12938_url$jscomp$inline_12942$$,$APP.$cljs$cst$139$type$$),$filename$jscomp$inline_12944_suffix$jscomp$inline_12940$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66801__$1$jscomp$inline_12938_url$jscomp$inline_12942$$,$APP.$cljs$cst$1371$suffix$$),$name$jscomp$inline_12941$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66801__$1$jscomp$inline_12938_url$jscomp$inline_12942$$,$APP.$cljs$cst$725$name$$);$map__66801__$1$jscomp$inline_12938_url$jscomp$inline_12942$$=$APP.$app$main$data$exports$wasm$export_image_uri$$($map__66801__$1$jscomp$inline_12938_url$jscomp$inline_12942$$);$mtype$jscomp$inline_12943_type$jscomp$inline_12939$$=
$app$common$media$format__GT_mtype$$($mtype$jscomp$inline_12943_type$jscomp$inline_12939$$);$filename$jscomp$inline_12944_suffix$jscomp$inline_12940$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$inline_12941$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($filename$jscomp$inline_12944_suffix$jscomp$inline_12940$$)?$filename$jscomp$inline_12944_suffix$jscomp$inline_12940$$:"")].join("");$APP.$app$util$dom$trigger_download_uri$$($filename$jscomp$inline_12944_suffix$jscomp$inline_12940$$,
$mtype$jscomp$inline_12943_type$jscomp$inline_12939$$,$map__66801__$1$jscomp$inline_12938_url$jscomp$inline_12942$$);$APP.$app$util$webapi$revoke_uri$$($map__66801__$1$jscomp$inline_12938_url$jscomp$inline_12942$$);return null}),new $app$main$data$exports$assets$request_simple_export_wasm_72472$$($p__72470$$,$map__72471__$1$$,$export$$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);typeof $app$main$data$exports$assets$request_simple_export_72480$$==="undefined"&&($app$main$data$exports$assets$request_simple_export_72480$$=
function($p__72470$jscomp$2$$,$map__72471$jscomp$2$$,$export$$jscomp$7$$,$meta72481$$){this.$p__72470$=$p__72470$jscomp$2$$;this.$map__72471$=$map__72471$jscomp$2$$;this.$export$$=$export$$jscomp$7$$;this.$meta72481$=$meta72481$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$exports$assets$request_simple_export_72480$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$request_simple_export_72480$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4770$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_request_simple_export$$},$app$main$data$exports$assets$request_simple_export_72480$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72482$$,$meta72481__$1$$){return new $app$main$data$exports$assets$request_simple_export_72480$$(this.$p__72470$,this.$map__72471$,this.$export$$,$meta72481__$1$$)},$app$main$data$exports$assets$request_simple_export_72480$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72481$},
$app$main$data$exports$assets$request_simple_export_72480$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$request_simple_export_72480$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2700$$,$state$jscomp$1012$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$1012$$,$APP.$cljs$cst$2177$export$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4762$in_progress$$,!0,$APP.$cljs$cst$266$id$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$uuid$zero$$]))},$app$main$data$exports$assets$request_simple_export_72480$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$request_simple_export_72480$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2701_profile_id$jscomp$14$$,$params$jscomp$319_state$jscomp$1013$$){$_$jscomp$2701_profile_id$jscomp$14$$=$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$319_state$jscomp$1013$$);
$params$jscomp$319_state$jscomp$1013$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1870$exports$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$export$$],null),$APP.$cljs$cst$2313$profile_id$$,$_$jscomp$2701_profile_id$jscomp$14$$,$APP.$cljs$cst$3115$cmd$$,$APP.$cljs$cst$4125$export_shapes$$,$APP.$cljs$cst$2281$wait$$,!0,$APP.$cljs$cst$4771$is_wasm$$,$APP.$app$main$features$active_feature_QMARK_$$($params$jscomp$319_state$jscomp$1013$$,
"render-wasm/v1")&&$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4124$wasm_export$$)],null);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2534$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$),$APP.$beicon$v2$core$timeout$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$beicon$v2$core$empty$$(),$APP.$beicon$v2$core$first$$($APP.$beicon$v2$core$filter$$(function($p1__72469_SHARP_$$){return $p1__72469_SHARP_$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3151$saved$$,
$p1__72469_SHARP_$$)},$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$refs$persistence_state$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!0],null))))),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$89$$){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$exports$assets$clear_export_state$$($APP.$app$common$uuid$zero$$)),$APP.$beicon$v2$core$throw$0$$($cause$jscomp$89$$))},
$APP.$beicon$v2$core$map$$(function($filename$jscomp$10_p__72498$$){var $map__72499__$1_uri$jscomp$102$$=$APP.$cljs$core$__destructure_map$$($filename$jscomp$10_p__72498$$);$filename$jscomp$10_p__72498$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72499__$1_uri$jscomp$102$$,$APP.$cljs$cst$4767$filename$$);var $mtype$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72499__$1_uri$jscomp$102$$,$APP.$cljs$cst$1726$mtype$$);$map__72499__$1_uri$jscomp$102$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72499__$1_uri$jscomp$102$$,
$APP.$cljs$cst$1579$uri$$);$APP.$app$util$dom$trigger_download_uri$$($filename$jscomp$10_p__72498$$,$mtype$jscomp$22$$,$map__72499__$1_uri$jscomp$102$$);return $app$main$data$exports$assets$clear_export_state$$($APP.$app$common$uuid$zero$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2177$export$$,$params$jscomp$319_state$jscomp$1013$$))))});return new $app$main$data$exports$assets$request_simple_export_72480$$($p__72470$$,$map__72471__$1$$,$export$$jscomp$5$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$exports$assets$request_multiple_export$$=function($p__72507$$){var $map__72508__$1$$=$APP.$cljs$core$__destructure_map$$($p__72507$$),$exports__$1$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72508__$1$$,$APP.$cljs$cst$1870$exports$$),$cmd$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__72508__$1$$,$APP.$cljs$cst$3115$cmd$$,$APP.$cljs$cst$4125$export_shapes$$),$name$jscomp$382$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72508__$1$$,$APP.$cljs$cst$725$name$$);
typeof $app$main$data$exports$assets$request_multiple_export_72510$$==="undefined"&&($app$main$data$exports$assets$request_multiple_export_72510$$=function($p__72507$jscomp$1$$,$map__72508$jscomp$1$$,$params$jscomp$321$$,$exports$jscomp$11$$,$cmd$jscomp$8$$,$name$jscomp$383$$,$meta72511$$){this.$p__72507$=$p__72507$jscomp$1$$;this.$map__72508$=$map__72508$jscomp$1$$;this.params=$params$jscomp$321$$;this.exports=$exports$jscomp$11$$;this.cmd=$cmd$jscomp$8$$;this.name=$name$jscomp$383$$;this.$meta72511$=
$meta72511$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$exports$assets$request_multiple_export_72510$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$request_multiple_export_72510$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4772$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_request_multiple_export$$},$app$main$data$exports$assets$request_multiple_export_72510$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72512$$,$meta72511__$1$$){return new $app$main$data$exports$assets$request_multiple_export_72510$$(this.$p__72507$,this.$map__72508$,this.params,this.exports,this.cmd,this.name,$meta72511__$1$$)},$app$main$data$exports$assets$request_multiple_export_72510$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72511$},$app$main$data$exports$assets$request_multiple_export_72510$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$request_multiple_export_72510$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2702_params__$1$jscomp$41$$,$state$jscomp$1014$$){var $self__$jscomp$6748$$=this,$resource_id$$=$APP.$cljs$core$volatile_BANG_$$(null),$profile_id$jscomp$15$$=$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1014$$),$progress_stream_ws_conn$$=$cljs$cst$3337$ws_conn$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1014$$);$_$jscomp$2702_params__$1$jscomp$41$$=function(){var $G__72519$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1870$exports$$,
$self__$jscomp$6748$$.exports,$APP.$cljs$cst$3115$cmd$$,$self__$jscomp$6748$$.cmd,$APP.$cljs$cst$2313$profile_id$$,$profile_id$jscomp$15$$,$cljs$cst$4773$force_multiple$$,!0,$APP.$cljs$cst$4771$is_wasm$$,$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$1014$$,"render-wasm/v1")&&$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4124$wasm_export$$)],null);return $self__$jscomp$6748$$.name!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__72519$$,
$APP.$cljs$cst$725$name$$,$self__$jscomp$6748$$.name):$G__72519$$}();$progress_stream_ws_conn$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$filter$$(function($p1__72503_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($resource_id$$),$cljs$cst$4763$resource_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__72503_SHARP_$$))},$APP.$beicon$v2$core$filter$$(function($p1__72502_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$4774$export_update$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__72502_SHARP_$$))},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$3113$payload$$,$APP.$beicon$v2$core$filter$$($app$util$websocket$message_event_QMARK_$$,$app$util$websocket$_stream$$($progress_stream_ws_conn$$))))));var $stopper$jscomp$38$$=$APP.$beicon$v2$core$filter$$(function($p1__72504_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("ended",$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($p1__72504_SHARP_$$))||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("error",$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($p1__72504_SHARP_$$))},$progress_stream_ws_conn$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$main$store$ongoing_tasks$$,$APP.$cljs$core$conj$$,$APP.$cljs$cst$2177$export$$);return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2534$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$),$APP.$beicon$v2$core$map$$(function($map__72521__$1_p__72520$$){$map__72521__$1_p__72520$$=
$APP.$cljs$core$__destructure_map$$($map__72521__$1_p__72520$$);var $id$jscomp$805$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72521__$1_p__72520$$,$APP.$cljs$cst$266$id$$);$APP.$cljs$core$_vreset_BANG_$$($resource_id$$,$id$jscomp$805$$);return $app$main$data$exports$assets$initialize_export_status$$($self__$jscomp$6748$$.exports,$self__$jscomp$6748$$.cmd,$map__72521__$1_p__72520$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2177$export$$,$_$jscomp$2702_params__$1$jscomp$41$$)),
$APP.$beicon$v2$core$finalize$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$main$store$ongoing_tasks$$,$APP.$cljs$core$disj$$,$APP.$cljs$cst$2177$export$$)},$APP.$beicon$v2$core$take_until$$($APP.$beicon$v2$core$delay$$(500,$stopper$jscomp$38$$),$APP.$beicon$v2$core$map$$($app$main$data$exports$assets$update_export_status$$,$progress_stream_ws_conn$$))),$APP.$beicon$v2$core$take_until$$($APP.$beicon$v2$core$delay$$(6E3,$stopper$jscomp$38$$),$APP.$beicon$v2$core$map$$(function(){return $app$main$data$exports$assets$clear_export_state$$($APP.$cljs$core$_deref$$($resource_id$$))},
$APP.$beicon$v2$core$delay$$(5E3,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__72505_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("ended",$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($p1__72505_SHARP_$$))},$progress_stream_ws_conn$$))))))});return new $app$main$data$exports$assets$request_multiple_export_72510$$($p__72507$$,$map__72508__$1$$,$map__72508__$1$$,$exports__$1$jscomp$7$$,$cmd$jscomp$7$$,$name$jscomp$382$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$exports$assets$request_export$$=function($map__72525__$1_p__72524$$){$map__72525__$1_p__72524$$=$APP.$cljs$core$__destructure_map$$($map__72525__$1_p__72524$$);var $exports__$1$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72525__$1_p__72524$$,$APP.$cljs$cst$1870$exports$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($exports__$1$jscomp$8$$))?$APP.$app$main$data$exports$assets$request_simple_export$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__72525__$1_p__72524$$,
$APP.$cljs$cst$2177$export$$,$APP.$cljs$core$first$$($exports__$1$jscomp$8$$))):$app$main$data$exports$assets$request_multiple_export$$($map__72525__$1_p__72524$$)};
$app$main$data$exports$assets$retry_last_export$$=function(){typeof $app$main$data$exports$assets$retry_last_export_72529$$==="undefined"&&($app$main$data$exports$assets$retry_last_export_72529$$=function($meta72530$$){this.$meta72530$=$meta72530$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$exports$assets$retry_last_export_72529$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$retry_last_export_72529$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4775$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_retry_last_export$$},$app$main$data$exports$assets$retry_last_export_72529$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72531$$,$meta72530__$1$$){return new $app$main$data$exports$assets$retry_last_export_72529$$($meta72530__$1$$)},$app$main$data$exports$assets$retry_last_export_72529$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72530$},$app$main$data$exports$assets$retry_last_export_72529$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$retry_last_export_72529$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2703_params$jscomp$323$$,$state$jscomp$1015$$){$_$jscomp$2703_params$jscomp$323$$=$APP.$cljs$core$select_keys$$($APP.$cljs$cst$2177$export$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1015$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1870$exports$$,$APP.$cljs$cst$3115$cmd$$],
null));return $APP.$cljs$core$seq$$($_$jscomp$2703_params$jscomp$323$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$exports$assets$request_multiple_export$$($_$jscomp$2703_params$jscomp$323$$)):null});return new $app$main$data$exports$assets$retry_last_export_72529$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$exports$assets$export_shapes_event$$=function($exports$jscomp$12$$,$origin$jscomp$46$$){var $types$jscomp$12$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($counts$jscomp$3$$,$map__72533__$1_p__72532_type$jscomp$569$$){$map__72533__$1_p__72532_type$jscomp$569$$=$APP.$cljs$core$__destructure_map$$($map__72533__$1_p__72532_type$jscomp$569$$);$map__72533__$1_p__72532_type$jscomp$569$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72533__$1_p__72532_type$jscomp$569$$,
$APP.$cljs$cst$139$type$$);var $JSCompiler_inline_result$jscomp$1333_fexpr__72534$jscomp$inline_7409$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1534$png$$,null,$cljs$cst$1934$pdf$$,null,$APP.$cljs$cst$1536$webp$$,null,$APP.$cljs$cst$1538$svg$$,null,$APP.$cljs$cst$1535$jpeg$$,null],null),null);$JSCompiler_inline_result$jscomp$1333_fexpr__72534$jscomp$inline_7409$$=$JSCompiler_inline_result$jscomp$1333_fexpr__72534$jscomp$inline_7409$$.$cljs$core$IFn$_invoke$arity$1$?
$JSCompiler_inline_result$jscomp$1333_fexpr__72534$jscomp$inline_7409$$.$cljs$core$IFn$_invoke$arity$1$($map__72533__$1_p__72532_type$jscomp$569$$):$JSCompiler_inline_result$jscomp$1333_fexpr__72534$jscomp$inline_7409$$($map__72533__$1_p__72532_type$jscomp$569$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1333_fexpr__72534$jscomp$inline_7409$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($counts$jscomp$3$$,$map__72533__$1_p__72532_type$jscomp$569$$,$APP.$cljs$core$inc$$):
$counts$jscomp$3$$},new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1534$png$$,0,$APP.$cljs$cst$1535$jpeg$$,0,$APP.$cljs$cst$1536$webp$$,0,$cljs$cst$1934$pdf$$,0,$APP.$cljs$cst$1538$svg$$,0],null),$exports$jscomp$12$$);return $APP.$app$main$data$event$event$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$types$jscomp$12$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"export-shapes",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$origin$jscomp$46$$,$cljs$cst$4776$num_shapes$$,$APP.$cljs$core$count$$($exports$jscomp$12$$)],null)])))};
$app$main$ui$shapes$text$html_text$render_text$$=function($props_72468_text$jscomp$62$$){var $class$$jscomp$19_node$jscomp$349$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_72468_text$jscomp$62$$,"node"),$parent$jscomp$286_style$jscomp$49$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_72468_text$jscomp$62$$,"parent"),$shape$jscomp$781$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_72468_text$jscomp$62$$,"shape"),$code_QMARK_$jscomp$1$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_72468_text$jscomp$62$$,"code?");$props_72468_text$jscomp$62$$=$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($class$$jscomp$19_node$jscomp$349$$);$parent$jscomp$286_style$jscomp$49$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_72468_text$jscomp$62$$,"")?$APP.$app$main$ui$shapes$text$styles$generate_text_styles$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$781$$,$parent$jscomp$286_style$jscomp$49$$,
null):$APP.$app$main$ui$shapes$text$styles$generate_text_styles$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$781$$,$class$$jscomp$19_node$jscomp$349$$,null);$class$$jscomp$19_node$jscomp$349$$=$APP.$cljs$core$truth_$$($code_QMARK_$jscomp$1$$)?$cljs$cst$3999$$id$$.$cljs$core$IFn$_invoke$arity$1$($class$$jscomp$19_node$jscomp$349$$):null;return(0,$APP.$rumext$v2$jsx$$)("span",{className:"text-node "+($class$$jscomp$19_node$jscomp$349$$??""),style:$parent$jscomp$286_style$jscomp$49$$,children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_72468_text$jscomp$62$$,
"")?" ":$props_72468_text$jscomp$62$$})};
$app$main$ui$shapes$text$html_text$render_root$$=function($props_72475_style$jscomp$50$$){var $class$$jscomp$20_node$jscomp$350$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_72475_style$jscomp$50$$,"node"),$children$jscomp$264$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_72475_style$jscomp$50$$,"children"),$code_QMARK_$jscomp$2$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_72475_style$jscomp$50$$,"code?");$props_72475_style$jscomp$50$$=
$app$main$ui$shapes$text$styles$generate_root_styles$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_72475_style$jscomp$50$$,"shape"),$class$$jscomp$20_node$jscomp$350$$,$code_QMARK_$jscomp$2$$);$class$$jscomp$20_node$jscomp$350$$=$APP.$cljs$core$truth_$$($code_QMARK_$jscomp$2$$)?$cljs$cst$3999$$id$$.$cljs$core$IFn$_invoke$arity$1$($class$$jscomp$20_node$jscomp$350$$):null;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"root rich-text "+
($class$$jscomp$20_node$jscomp$350$$??""),style:$props_72475_style$jscomp$50$$,xmlns:"http://www.w3.org/1999/xhtml",children:$children$jscomp$264$$})};
$app$main$ui$shapes$text$html_text$render_paragraph_set$$=function($code_QMARK_$jscomp$3_props_72479$$){var $class$$jscomp$21_node$jscomp$351$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($code_QMARK_$jscomp$3_props_72479$$,"node"),$children$jscomp$265$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($code_QMARK_$jscomp$3_props_72479$$,"children"),$shape$jscomp$783_style$jscomp$51$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($code_QMARK_$jscomp$3_props_72479$$,
"shape");$code_QMARK_$jscomp$3_props_72479$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($code_QMARK_$jscomp$3_props_72479$$,"code?");$shape$jscomp$783_style$jscomp$51$$=$APP.$cljs$core$truth_$$($code_QMARK_$jscomp$3_props_72479$$)?null:$app$main$ui$shapes$text$styles$generate_paragraph_set_styles$$($shape$jscomp$783_style$jscomp$51$$);$class$$jscomp$21_node$jscomp$351$$=$APP.$cljs$core$truth_$$($code_QMARK_$jscomp$3_props_72479$$)?$cljs$cst$3999$$id$$.$cljs$core$IFn$_invoke$arity$1$($class$$jscomp$21_node$jscomp$351$$):
null;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"paragraph-set "+($class$$jscomp$21_node$jscomp$351$$??""),style:$shape$jscomp$783_style$jscomp$51$$,children:$children$jscomp$265$$})};
$app$main$ui$shapes$text$html_text$render_paragraph$$=function($props_72483_style$jscomp$52$$){var $dir$jscomp$5_node$jscomp$352$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_72483_style$jscomp$52$$,"node"),$children$jscomp$266$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_72483_style$jscomp$52$$,"children"),$class$$jscomp$22_code_QMARK_$jscomp$4$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_72483_style$jscomp$52$$,"code?");
$props_72483_style$jscomp$52$$=$APP.$cljs$core$truth_$$($class$$jscomp$22_code_QMARK_$jscomp$4$$)?null:$APP.$app$main$ui$shapes$text$styles$generate_paragraph_styles$$($dir$jscomp$5_node$jscomp$352$$);$class$$jscomp$22_code_QMARK_$jscomp$4$$=$APP.$cljs$core$truth_$$($class$$jscomp$22_code_QMARK_$jscomp$4$$)?$cljs$cst$3999$$id$$.$cljs$core$IFn$_invoke$arity$1$($dir$jscomp$5_node$jscomp$352$$):null;$dir$jscomp$5_node$jscomp$352$$=$APP.$cljs$cst$1764$text_direction$$.$cljs$core$IFn$_invoke$arity$2$($dir$jscomp$5_node$jscomp$352$$,
"auto");return(0,$APP.$rumext$v2$jsx$$)("p",{className:"paragraph "+($class$$jscomp$22_code_QMARK_$jscomp$4$$??""),style:$props_72483_style$jscomp$52$$,dir:$dir$jscomp$5_node$jscomp$352$$,children:$children$jscomp$266$$})};
$app$util$code_gen$markup_html$generate_html$cljs$0core$0IFn$0_invoke$0arity$03$$=function($objects$jscomp$680$$,$shape$jscomp$787$$,$level$jscomp$53$$){if($shape$jscomp$787$$!=null&&$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$787$$)!=null){var $indent$jscomp$2$$=$cuerdas$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$("  ",$level$jscomp$53$$),$shape_html_shape_html__$1$$=$app$util$code_gen$common$svg_markup_QMARK_$$($shape$jscomp$787$$)?function(){var $svg_markup$$=
$app$util$code_gen$markup_svg$generate_single_svg$$($objects$jscomp$680$$,$shape$jscomp$787$$);return""+($indent$jscomp$2$$??"")+'\x3cdiv class\x3d"shape '+(($APP.$app$common$data$name$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$787$$))??"")+" "+($app$util$code_gen$common$shape__GT_selector$$($shape$jscomp$787$$)??""))+'"\x3e\n'+($svg_markup$$??"")+"\n"+($indent$jscomp$2$$??"")+"\x3c/div\x3e"}():$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$787$$)?
function(){var $text_shape_html_text_shape_html__$1$$=$shadow$js$shim$module$0react_dom$0server$$.renderToStaticMarkup($rumext$v2$element$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$ui$shapes$text$html_text$text_shape$$,{shape:$shape$jscomp$787$$,"code?":!0}));$text_shape_html_text_shape_html__$1$$=$APP.$cuerdas$core$replace$$($text_shape_html_text_shape_html__$1$$,/style\s*=\s*["'][^"']*["']/,"");return""+($indent$jscomp$2$$??"")+'\x3cdiv class\x3d"shape '+(($APP.$app$common$data$name$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$787$$))??
"")+" "+($app$util$code_gen$common$shape__GT_selector$$($shape$jscomp$787$$)??""))+'"\x3e\n'+($text_shape_html_text_shape_html__$1$$??"")+"\n"+($indent$jscomp$2$$??"")+"\x3c/div\x3e"}():$app$common$files$helpers$image_shape_QMARK_$$($shape$jscomp$787$$)?function(){var $data$jscomp$431_image_url$jscomp$2_or__5025__auto__$jscomp$inline_7413$$=$cljs$cst$1633$metadata$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$787$$);$data$jscomp$431_image_url$jscomp$2_or__5025__auto__$jscomp$inline_7413$$=$APP.$cljs$core$truth_$$($data$jscomp$431_image_url$jscomp$2_or__5025__auto__$jscomp$inline_7413$$)?
$data$jscomp$431_image_url$jscomp$2_or__5025__auto__$jscomp$inline_7413$$:$APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$787$$);$data$jscomp$431_image_url$jscomp$2_or__5025__auto__$jscomp$inline_7413$$=$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$431_image_url$jscomp$2_or__5025__auto__$jscomp$inline_7413$$);return""+($indent$jscomp$2$$??"")+'\x3cimg src\x3d"'+($data$jscomp$431_image_url$jscomp$2_or__5025__auto__$jscomp$inline_7413$$??
"")+'" class\x3d"shape '+(($APP.$app$common$data$name$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$787$$))??"")+" "+($app$util$code_gen$common$shape__GT_selector$$($shape$jscomp$787$$)??""))+'"\x3e\n'+($indent$jscomp$2$$??"")+"\x3c/img\x3e"}():$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$787$$))?""+($indent$jscomp$2$$??"")+'\x3cdiv class\x3d"shape '+(($APP.$app$common$data$name$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$787$$))??
"")+" "+($app$util$code_gen$common$shape__GT_selector$$($shape$jscomp$787$$)??""))+'"\x3e\n'+($indent$jscomp$2$$??"")+"\x3c/div\x3e":function(){var $children$jscomp$268_children__$1$jscomp$35$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__72535_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$680$$,$p1__72535_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$787$$));$children$jscomp$268_children__$1$jscomp$35$$=
$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$787$$)?$APP.$cljs$core$reverse$$($children$jscomp$268_children__$1$jscomp$35$$):$children$jscomp$268_children__$1$jscomp$35$$;return""+($indent$jscomp$2$$??"")+'\x3cdiv class\x3d"'+(($APP.$app$common$data$name$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$787$$))??"")+" "+($app$util$code_gen$common$shape__GT_selector$$($shape$jscomp$787$$)??""))+'"\x3e\n'+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__72536_SHARP_$$){return $app$util$code_gen$markup_html$generate_html$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$680$$,$p1__72536_SHARP_$$,$level$jscomp$53$$+1)},$children$jscomp$268_children__$1$jscomp$35$$))??"")+"\n"+($indent$jscomp$2$$??"")+"\x3c/div\x3e"}();$shape_html_shape_html__$1$$=$app$util$code_gen$common$has_wrapper_QMARK_$$($objects$jscomp$680$$,$shape$jscomp$787$$)?'\x3cdiv class\x3d"'+(($app$util$code_gen$common$shape__GT_selector$$($shape$jscomp$787$$)??
"")+'-wrapper"\x3e')+($shape_html_shape_html__$1$$??"")+"\x3c/div\x3e":$shape_html_shape_html__$1$$;return""+($indent$jscomp$2$$??"")+"\x3c!-- "+(($APP.$app$common$data$name$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$787$$))??"")+": "+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$787$$)??""))+" --\x3e\n"+($shape_html_shape_html__$1$$??"")}return null};
$app$util$code_gen$markup_html$generate_markup$$=function($objects$jscomp$681$$,$shapes$jscomp$134$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__72552_SHARP_$$){return $app$util$code_gen$markup_html$generate_html$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$681$$,$p1__72552_SHARP_$$,0)},$shapes$jscomp$134$$))};
$APP.$app$util$code_gen$generate_formatted_markup_code$$=function($markup_objects$jscomp$683$$,$type$jscomp$572$$,$shapes$jscomp$136$$){a:switch($type$jscomp$572$$){case "html":var $generate_markup$jscomp$inline_12949$$=$app$util$code_gen$markup_html$generate_markup$$;break a;case "svg":$generate_markup$jscomp$inline_12949$$=$APP.$app$util$code_gen$markup_svg$generate_markup$$;break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$572$$)].join(""));
}$markup_objects$jscomp$683$$=$generate_markup$jscomp$inline_12949$$.$cljs$core$IFn$_invoke$arity$2$?$generate_markup$jscomp$inline_12949$$.$cljs$core$IFn$_invoke$arity$2$($markup_objects$jscomp$683$$,$shapes$jscomp$136$$):$generate_markup$jscomp$inline_12949$$($markup_objects$jscomp$683$$,$shapes$jscomp$136$$);return $APP.$app$util$code_beautify$format_code$$($markup_objects$jscomp$683$$,$type$jscomp$572$$)};
$app$main$data$preview$shapes__GT_fonts$$=function($shapes$jscomp$137$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$clojure$set$union$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($app$main$fonts$get_content_fonts$$,$APP.$cljs$cst$1637$content$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$text_shape_QMARK_$$,$shapes$jscomp$137$$)))};
$app$main$data$preview$update_preview$$=function($preview$jscomp$2$$,$shape_id$jscomp$132$$){typeof $app$main$data$preview$update_preview_72595$$==="undefined"&&($app$main$data$preview$update_preview_72595$$=function($preview$jscomp$3$$,$shape_id$jscomp$133$$,$meta72596$$){this.$preview$=$preview$jscomp$3$$;this.$shape_id$=$shape_id$jscomp$133$$;this.$meta72596$=$meta72596$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$preview$update_preview_72595$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$preview$update_preview_72595$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4777$app_DOT_main_DOT_data_DOT_preview_SLASH_update_preview$$},$app$main$data$preview$update_preview_72595$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72597$$,$meta72596__$1$$){return new $app$main$data$preview$update_preview_72595$$(this.$preview$,this.$shape_id$,$meta72596__$1$$)},$app$main$data$preview$update_preview_72595$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72596$},$app$main$data$preview$update_preview_72595$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$preview$update_preview_72595$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2704_fonts$jscomp$25$$,$state$jscomp$1016$$){var $self__$jscomp$6756$$=this,$objects$jscomp$686$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1016$$),$shape$jscomp$788$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$686$$,
$self__$jscomp$6756$$.$shape_id$),$all_children$jscomp$3$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$data$getf$$($objects$jscomp$686$$),$APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$686$$,$APP.$app$common$files$helpers$selected_with_children$$($objects$jscomp$686$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6756$$.$shape_id$],null))));$_$jscomp$2704_fonts$jscomp$25$$=
$app$main$data$preview$shapes__GT_fonts$$($all_children$jscomp$3$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($fontfaces_css_style_code$$){$fontfaces_css_style_code$$=""+($fontfaces_css_style_code$$??"")+"\n"+($APP.$app$util$code_beautify$format_code$$($APP.$app$util$code_gen$generate_style_code$$.$cljs$core$IFn$_invoke$arity$4$($objects$jscomp$686$$,"css",new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$788$$],
null),$all_children$jscomp$3$$),"css")??"");var $markup_code$$=$APP.$app$util$code_gen$generate_formatted_markup_code$$($objects$jscomp$686$$,"html",new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$788$$],null));return $app$main$data$preview$update_preview_window$$($self__$jscomp$6756$$.$preview$,$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("\x3c!DOCTYPE html\x3e\n\x3chtml\x3e\n  \x3chead\x3e\n    \x3cstyle\x3e\n    %s\n    \x3c/style\x3e\n  \x3c/head\x3e\n  \x3cbody\x3e\n  %s\n  \x3c/body\x3e\n\x3c/html\x3e",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$fontfaces_css_style_code$$,$markup_code$$])),$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$788$$)),$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$788$$)))},$APP.$beicon$v2$core$map$$(function($p1__72592_SHARP_$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",
$p1__72592_SHARP_$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$merge_map$$($APP.$app$main$fonts$fetch_font_css$$,$APP.$beicon$v2$core$from$$($_$jscomp$2704_fonts$jscomp$25$$)))))});return new $app$main$data$preview$update_preview_72595$$($preview$jscomp$2$$,$shape_id$jscomp$132$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$preview$open_preview_selected$$=function(){typeof $app$main$data$preview$open_preview_selected_72602$$==="undefined"&&($app$main$data$preview$open_preview_selected_72602$$=function($meta72603$$){this.$meta72603$=$meta72603$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$preview$open_preview_selected_72602$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$preview$open_preview_selected_72602$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4778$app_DOT_main_DOT_data_DOT_preview_SLASH_open_preview_selected$$},$app$main$data$preview$open_preview_selected_72602$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72604$$,$meta72603__$1$$){return new $app$main$data$preview$open_preview_selected_72602$$($meta72603__$1$$)},$app$main$data$preview$open_preview_selected_72602$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72603$},$app$main$data$preview$open_preview_selected_72602$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$preview$open_preview_selected_72602$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2705$$,$state$jscomp$1017$$){var $shape_id$jscomp$134$$=$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$1017$$)),$closed_preview$$=$APP.$beicon$v2$core$subject$$(),$preview$jscomp$4$$=window.open("/#/frame-preview");$preview$jscomp$4$$!=null&&$preview$jscomp$4$$.addEventListener("beforeunload",
function(){return $closed_preview$$.next(!0)});return $APP.$beicon$v2$core$map$$(function(){return $app$main$data$preview$update_preview$$($preview$jscomp$4$$,$shape_id$jscomp$134$$)},$APP.$beicon$v2$core$debounce$$(1E3,$APP.$beicon$v2$core$take_until$$($closed_preview$$,$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$refs$all_children_objects$$($shape_id$jscomp$134$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!0],
null)))))});return new $app$main$data$preview$open_preview_selected_72602$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$text$shortcuts$is_bold_QMARK_$$=function($variant_id$jscomp$43$$){return $APP.$cljs$core$some$$(function($p1__72581_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($variant_id$jscomp$43$$,$p1__72581_SHARP_$$)},new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["bold","black","700"],null))};
$app$main$data$workspace$text$shortcuts$is_italic_QMARK_$$=function($variant_id$jscomp$44$$){return $APP.$cljs$core$some$$(function($p1__72584_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($variant_id$jscomp$44$$,$p1__72584_SHARP_$$)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["italic","cursive"],null))};
$app$main$data$workspace$text$shortcuts$generate_variant_props$$=function($font$jscomp$43_font_id$jscomp$35_new_variant__$1_text_values$$,$variant_id$jscomp$45$$){function $first_intersection$$($list1$$,$list2$$){return $APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($list1$$),$list2$$))}var $current_variant$$=$APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$43_font_id$jscomp$35_new_variant__$1_text_values$$),
$bold_options$$=$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($current_variant$$,"black"))?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["black","bold","700"],null):$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($current_variant$$,"700"))?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["700","black","bold"],null):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["bold","black","700"],null),$current_variant_no_italic_fonts$jscomp$26$$=$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($current_variant$$,"italic"))?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($current_variant$$,0,$APP.$cljs$core$count$$($current_variant$$)-6):$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($current_variant$$,"cursive"))?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($current_variant$$,0,$APP.$cljs$core$count$$($current_variant$$)-
7):null,$regular_options$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$current_variant_no_italic_fonts$jscomp$26$$,"regular","normal","400"],null),$italic_options$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$not$$($APP.$cuerdas$core$includes_QMARK_$$($current_variant$$,"bold"))&&$APP.$cljs$core$not$$($APP.$cuerdas$core$includes_QMARK_$$($current_variant$$,"black"))&&$APP.$cljs$core$not$$($APP.$cuerdas$core$includes_QMARK_$$($current_variant$$,
"700"))?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($current_variant$$),"italic"].join(""):null,"italic","cursive"],null),$bold_italic_options$$=$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($current_variant$$,"black"))?new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"blackitalic blackcursive bolditalic 700italic boldcursive 700cursive".split(" "),null):$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($current_variant$$,
"700"))?new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"700italic 700cursive bolditalic blackitalic boldcursive blackcursive".split(" "),null):new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"bolditalic 700italic blackitalic boldcursive 700cursive blackcursive".split(" "),null);$font$jscomp$43_font_id$jscomp$35_new_variant__$1_text_values$$=$APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$43_font_id$jscomp$35_new_variant__$1_text_values$$);
$current_variant_no_italic_fonts$jscomp$26$$=$APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$);$font$jscomp$43_font_id$jscomp$35_new_variant__$1_text_values$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_variant_no_italic_fonts$jscomp$26$$,$font$jscomp$43_font_id$jscomp$35_new_variant__$1_text_values$$);var $variants$jscomp$8$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$cst$2676$variants$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$43_font_id$jscomp$35_new_variant__$1_text_values$$)),
$new_variant$$=function(){var $JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$=$app$main$data$workspace$text$shortcuts$is_bold_QMARK_$$($current_variant$$),$italic_QMARK_$jscomp$2$$=$app$main$data$workspace$text$shortcuts$is_italic_QMARK_$$($current_variant$$),$add_bold_QMARK_$$=$APP.$cljs$core$not$$($JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$)&&
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant_id$jscomp$45$$,"add-bold")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant_id$jscomp$45$$,"toggle-bold")),$remove_bold_QMARK_$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant_id$jscomp$45$$,
"remove-bold")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant_id$jscomp$45$$,"toggle-bold"):$JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$,$add_italic_QMARK_$$=$APP.$cljs$core$not$$($italic_QMARK_$jscomp$2$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant_id$jscomp$45$$,"add-italic")||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant_id$jscomp$45$$,"toggle-italic")),$remove_italic_QMARK_$$=$APP.$cljs$core$truth_$$($italic_QMARK_$jscomp$2$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant_id$jscomp$45$$,"remove-italic")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant_id$jscomp$45$$,"toggle-italic"):$italic_QMARK_$jscomp$2$$;$APP.$cljs$core$truth_$$($add_bold_QMARK_$$?$italic_QMARK_$jscomp$2$$:$add_bold_QMARK_$$)?($JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$=
$first_intersection$$($variants$jscomp$8$$,$bold_italic_options$$),$JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$)?
$JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$:$first_intersection$$($variants$jscomp$8$$,$bold_options$$)):$add_bold_QMARK_$$&&$APP.$cljs$core$not$$($italic_QMARK_$jscomp$2$$)?$JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$=
$first_intersection$$($variants$jscomp$8$$,$bold_options$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($remove_bold_QMARK_$$)?$italic_QMARK_$jscomp$2$$:$remove_bold_QMARK_$$)?$JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$=$first_intersection$$($variants$jscomp$8$$,$italic_options$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($remove_bold_QMARK_$$)?
$APP.$cljs$core$not$$($italic_QMARK_$jscomp$2$$):$remove_bold_QMARK_$$)?$JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$=$first_intersection$$($variants$jscomp$8$$,$regular_options$$):$APP.$cljs$core$truth_$$($add_italic_QMARK_$$?$JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$:
$add_italic_QMARK_$$)?($JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$=$first_intersection$$($variants$jscomp$8$$,$bold_italic_options$$),$JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$=
$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$)?$JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$:$first_intersection$$($variants$jscomp$8$$,
$italic_options$$)):$JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$=$add_italic_QMARK_$$&&$APP.$cljs$core$not$$($JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$)?
$first_intersection$$($variants$jscomp$8$$,$italic_options$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($remove_italic_QMARK_$$)?$JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$:$remove_italic_QMARK_$$)?$first_intersection$$($variants$jscomp$8$$,$bold_options$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($remove_italic_QMARK_$$)?
$APP.$cljs$core$not$$($JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$):$remove_italic_QMARK_$$)?$first_intersection$$($variants$jscomp$8$$,$regular_options$$):null;return $JSCompiler_temp$jscomp$10911_JSCompiler_temp$jscomp$10912_JSCompiler_temp$jscomp$10913_JSCompiler_temp$jscomp$10914_JSCompiler_temp$jscomp$10915_bold_QMARK__or__5025__auto__$jscomp$inline_12952_or__5025__auto__$jscomp$inline_12954$$}();
$font$jscomp$43_font_id$jscomp$35_new_variant__$1_text_values$$=$APP.$cljs$core$truth_$$($new_variant$$)?$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__72585_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__72585_SHARP_$$),$new_variant$$)},$APP.$cljs$cst$2676$variants$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$43_font_id$jscomp$35_new_variant__$1_text_values$$))):
null;return $APP.$cljs$core$truth_$$($font$jscomp$43_font_id$jscomp$35_new_variant__$1_text_values$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1759$font_variant_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$43_font_id$jscomp$35_new_variant__$1_text_values$$),$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1996$weight$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$43_font_id$jscomp$35_new_variant__$1_text_values$$),$APP.$cljs$cst$1762$font_style$$,
$APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$43_font_id$jscomp$35_new_variant__$1_text_values$$)],null):null};
$app$main$data$workspace$text$shortcuts$calculate_text_values$$=function($shape$jscomp$789$$){var $editor_state$jscomp$8_state_map$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor-wasm/v1")?$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_wasm_editor_styles$$):$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2")?$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_v2_editor_state$$):
$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_editor_state$$),$editor_styles$jscomp$3$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor-wasm/v1")?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($editor_state$jscomp$8_state_map$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$789$$)):null;$editor_state$jscomp$8_state_map$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
"text-editor/v2")?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($editor_state$jscomp$8_state_map$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$789$$));var $editor_instance$jscomp$3$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2")?$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_editor$$):null;return $APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$texts$current_root_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1811$shape$$,$shape$jscomp$789$$,$APP.$cljs$cst$2645$attrs$$,$APP.$app$common$types$text$text_valign_attrs$$],null)),$APP.$app$main$data$workspace$texts$current_paragraph_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$4009$editor_styles$$,$editor_styles$jscomp$3$$,$APP.$cljs$cst$4011$editor_state$$,$editor_state$jscomp$8_state_map$$,$APP.$cljs$cst$4010$editor_instance$$,$editor_instance$jscomp$3$$,$APP.$cljs$cst$1811$shape$$,$shape$jscomp$789$$,$APP.$cljs$cst$2645$attrs$$,
$APP.$app$common$types$text$paragraph_attrs$$],null)),$APP.$app$main$data$workspace$texts$current_text_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$4009$editor_styles$$,$editor_styles$jscomp$3$$,$APP.$cljs$cst$4011$editor_state$$,$editor_state$jscomp$8_state_map$$,$APP.$cljs$cst$4010$editor_instance$$,$editor_instance$jscomp$3$$,$APP.$cljs$cst$1811$shape$$,$shape$jscomp$789$$,$APP.$cljs$cst$2645$attrs$$,$APP.$app$common$types$text$text_node_attrs$$],null))]))};
$app$main$data$workspace$text$shortcuts$blend_props$$=function($all_underline_QMARK__shapes$jscomp$138$$,$props$jscomp$233$$){var $all_italic_QMARK__text_values$jscomp$2$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$text$shortcuts$calculate_text_values$$,$all_underline_QMARK__shapes$jscomp$138$$);$all_underline_QMARK__shapes$jscomp$138$$=$APP.$cljs$core$every_QMARK_$$(function($p1__72606_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($p1__72606_SHARP_$$),
"underline")},$all_italic_QMARK__text_values$jscomp$2$$);var $all_line_through_QMARK_$$=$APP.$cljs$core$every_QMARK_$$(function($p1__72607_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($p1__72607_SHARP_$$),"line-through")},$all_italic_QMARK__text_values$jscomp$2$$),$all_bold_QMARK_$$=$APP.$cljs$core$every_QMARK_$$(function($p1__72608_SHARP_$$){return $app$main$data$workspace$text$shortcuts$is_bold_QMARK_$$($APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__72608_SHARP_$$))},
$all_italic_QMARK__text_values$jscomp$2$$);$all_italic_QMARK__text_values$jscomp$2$$=$APP.$cljs$core$every_QMARK_$$(function($p1__72609_SHARP_$$){return $app$main$data$workspace$text$shortcuts$is_italic_QMARK_$$($APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__72609_SHARP_$$))},$all_italic_QMARK__text_values$jscomp$2$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$233$$),
"toggle-underline")?$all_underline_QMARK__shapes$jscomp$138$$?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1768$text_decoration$$,"none"],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1768$text_decoration$$,"underline"],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$233$$),"toggle-line-through")?$all_line_through_QMARK_$$?new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1768$text_decoration$$,"none"],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1768$text_decoration$$,"line-through"],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$233$$),"toggle-bold")?$all_bold_QMARK_$$?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1759$font_variant_id$$,"remove-bold"],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1759$font_variant_id$$,
"add-bold"],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$233$$),"toggle-italic")?$all_italic_QMARK__text_values$jscomp$2$$?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1759$font_variant_id$$,"remove-italic"],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1759$font_variant_id$$,"add-italic"],null):$props$jscomp$233$$};
$app$main$data$workspace$text$shortcuts$update_attrs_when_no_readonly$$=function($props$jscomp$234$$){var $undo_id$jscomp$89$$=Symbol(),$can_edit_QMARK_$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$refs$permissions$$)),$read_only_QMARK_$jscomp$5$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_read_only_QMARK_$$),$text_shapes$jscomp$1$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$text_shape_QMARK_$$,
$APP.$cljs$core$_deref$$($app$main$data$workspace$text$shortcuts$selected_shapes_with_children$$))),$props__$1$jscomp$45$$=$APP.$cljs$core$count$$($text_shapes$jscomp$1$$)>1?$app$main$data$workspace$text$shortcuts$blend_props$$($text_shapes$jscomp$1$$,$props$jscomp$234$$):$props$jscomp$234$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_edit_QMARK_$$)?$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$5$$)&&$text_shapes$jscomp$1$$!=null:$can_edit_QMARK_$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$89$$)),
$APP.$cljs$core$run_BANG_$$(function($p1__72620_SHARP_$$){var $props__$1$jscomp$inline_12960_text_values$jscomp$inline_12958$$=$app$main$data$workspace$text$shortcuts$calculate_text_values$$($p1__72620_SHARP_$$),$font_size$jscomp$inline_12959$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($props__$1$jscomp$inline_12960_text_values$jscomp$inline_12958$$));$props__$1$jscomp$inline_12960_text_values$jscomp$inline_12958$$=
$APP.$cljs$core$truth_$$($cljs$cst$4779$font_size_inc$$.$cljs$core$IFn$_invoke$arity$1$($props__$1$jscomp$45$$))?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($font_size$jscomp$inline_12959$$+1)],null):$APP.$cljs$core$truth_$$($cljs$cst$4780$font_size_dec$$.$cljs$core$IFn$_invoke$arity$1$($props__$1$jscomp$45$$))?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($font_size$jscomp$inline_12959$$-
1)],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($props__$1$jscomp$45$$),"toggle-underline")?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($props__$1$jscomp$inline_12960_text_values$jscomp$inline_12958$$),"underline")?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1768$text_decoration$$,"none"],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1768$text_decoration$$,"underline"],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($props__$1$jscomp$45$$),"toggle-line-through")?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($props__$1$jscomp$inline_12960_text_values$jscomp$inline_12958$$),"line-through")?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1768$text_decoration$$,
"none"],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1768$text_decoration$$,"line-through"],null):$APP.$cljs$core$truth_$$($APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($props__$1$jscomp$45$$))?$app$main$data$workspace$text$shortcuts$generate_variant_props$$($props__$1$jscomp$inline_12960_text_values$jscomp$inline_12958$$,$APP.$cljs$cst$1759$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($props__$1$jscomp$45$$)):$props__$1$jscomp$45$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($p1__72620_SHARP_$$)?
$props__$1$jscomp$inline_12960_text_values$jscomp$inline_12958$$:$p1__72620_SHARP_$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__72620_SHARP_$$),$props__$1$jscomp$inline_12960_text_values$jscomp$inline_12958$$)):null},$text_shapes$jscomp$1$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$89$$))):
null};$app$main$data$workspace$shortcuts$toggle_layout_flag$$=function($flag$jscomp$12$$){return $APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($flag$jscomp$12$$),$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-shortcuts")};
$app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($events$jscomp$4$$){var $can_edit_QMARK_$jscomp$1$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$refs$permissions$$)),$read_only_QMARK_$jscomp$6$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_read_only_QMARK_$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$6$$):
$can_edit_QMARK_$jscomp$1$$)?$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$events$jscomp$4$$):null};
$app$main$ui$components$context_menu_a11y$generate_ids_group$$=function($ids$jscomp$256_options$jscomp$585$$,$has_parents_QMARK__ids__$1$jscomp$21$$){$ids$jscomp$256_options$jscomp$585$$=$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$components$context_menu_a11y$xf_COLON_options$$,$ids$jscomp$256_options$jscomp$585$$);$has_parents_QMARK__ids__$1$jscomp$21$$=$APP.$cljs$core$truth_$$($has_parents_QMARK__ids__$1$jscomp$21$$)?$APP.$cljs$core$cons$$("go-back-sub-option",$ids$jscomp$256_options$jscomp$585$$):
$ids$jscomp$256_options$jscomp$585$$;return $APP.$cljs$core$vec$$($has_parents_QMARK__ids__$1$jscomp$21$$)};
$app$main$ui$components$context_menu_a11y$context_menu_inner_STAR_$$=function($props_72611_props__$1$jscomp$46$$){function $on_key_down$jscomp$1$$($options_original$$,$parent_original$$){return function($event$jscomp$131$$){var $ids__$1$jscomp$22_next_id_72642$$=$app$main$ui$components$context_menu_a11y$generate_ids_group$$($options_original$$,$parent_original$$),$first_id_len$jscomp$74$$=$APP.$app$util$dom$get_element$$($APP.$cljs$core$first$$($ids__$1$jscomp$22_next_id_72642$$)),$actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$=
$APP.$goog$dom$getElement$$($first_id_len$jscomp$74$$);$first_id_len$jscomp$74$$=$APP.$cljs$core$count$$($ids__$1$jscomp$22_next_id_72642$$);var $parent_id$jscomp$101$$=$APP.$app$util$dom$get_attribute$$($APP.$app$util$dom$get_target$$($event$jscomp$131$$),"id"),$option$jscomp$4$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__72605_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parent_id$jscomp$101$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__72605_SHARP_$$))},
$options_original$$),$sub_options$$=$APP.$cljs$core$not_empty$$($APP.$cljs$cst$873$options$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$4$$)),$handler$jscomp$43$$=$APP.$cljs$cst$2402$handler$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$4$$),$is_back_option_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("go-back-sub-option",$parent_id$jscomp$101$$);$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$home_QMARK_$$)($event$jscomp$131$$))&&$APP.$cljs$core$truth_$$($actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$)&&
$APP.$app$util$dom$focus_BANG_$$($actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$);$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$131$$))&&($is_back_option_QMARK_$$?$on_submenu_exit$$.$cljs$core$IFn$_invoke$arity$1$?$on_submenu_exit$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$131$$):$on_submenu_exit$$($event$jscomp$131$$):$APP.$cljs$core$truth_$$($sub_options$$)?($APP.$app$util$dom$stop_propagation$$($event$jscomp$131$$),
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$5$$,$APP.$cljs$core$update$$,$cljs$cst$4898$levels$$,$APP.$cljs$core$conj$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1365$parent$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$4$$),$APP.$cljs$cst$873$options$$,$sub_options$$],null)]))):($APP.$app$util$dom$stop_propagation$$($event$jscomp$131$$),$handler$jscomp$43$$.$cljs$core$IFn$_invoke$arity$1$?
$handler$jscomp$43$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$131$$):$handler$jscomp$43$$($event$jscomp$131$$)));$APP.$cljs$core$truth_$$($is_back_option_QMARK_$$?(0,$APP.$app$util$keyboard$left_arrow_QMARK_$$)($event$jscomp$131$$):$is_back_option_QMARK_$$)&&($on_submenu_exit$$.$cljs$core$IFn$_invoke$arity$1$?$on_submenu_exit$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$131$$):$on_submenu_exit$$($event$jscomp$131$$));$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($sub_options$$)?(0,$APP.$app$util$keyboard$right_arrow_QMARK_$$)($event$jscomp$131$$):
$sub_options$$)&&($APP.$app$util$dom$stop_propagation$$($event$jscomp$131$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$5$$,$APP.$cljs$core$update$$,$cljs$cst$4898$levels$$,$APP.$cljs$core$conj$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1365$parent$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$4$$),$APP.$cljs$cst$873$options$$,$sub_options$$],
null)])));$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$131$$))&&($actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$=$APP.$app$util$dom$get_attribute$$($APP.$app$util$globals$document$$.activeElement,"id"),$actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$=$APP.$app$common$data$index_of$$($ids__$1$jscomp$22_next_id_72642$$,$actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$),
$actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$)?$APP.$cljs$core$last$$($ids__$1$jscomp$22_next_id_72642$$):$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($ids__$1$jscomp$22_next_id_72642$$,$actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$-
1),$APP.$app$util$dom$focus_BANG_$$($APP.$goog$dom$getElement$$($actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$)));$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$131$$))&&($actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$=$APP.$app$util$dom$get_attribute$$($APP.$app$util$globals$document$$.activeElement,"id"),$actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$=
$APP.$app$common$data$index_of$$($ids__$1$jscomp$22_next_id_72642$$,$actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$),$ids__$1$jscomp$22_next_id_72642$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($first_id_len$jscomp$74$$-1,$actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$)?$APP.$cljs$core$first$$($ids__$1$jscomp$22_next_id_72642$$):$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($ids__$1$jscomp$22_next_id_72642$$,
1+$actual_id_72636_actual_id_72640_actual_index_72637_actual_index_72641_first_element_previous_id_72638$$),$APP.$app$util$dom$focus_BANG_$$($APP.$goog$dom$getElement$$($ids__$1$jscomp$22_next_id_72642$$)));return $APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$914$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$131$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$914$$)?$or__5025__auto__$jscomp$914$$:(0,$APP.$app$util$keyboard$tab_QMARK_$$)($event$jscomp$131$$)}())?
($on_close$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_close$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$131$$):$on_close$jscomp$2$$($event$jscomp$131$$),$APP.$app$util$dom$focus_BANG_$$($APP.$goog$dom$getElement$$($origin$jscomp$47$$))):null}}function $enter_submenu$$($name$jscomp$384$$,$options__$1$jscomp$75$$){return function($event$jscomp$129$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$129$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$5$$,
$APP.$cljs$core$update$$,$cljs$cst$4898$levels$$,$APP.$cljs$core$conj$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1365$parent$$,$name$jscomp$384$$,$APP.$cljs$cst$873$options$$,$options__$1$jscomp$75$$],null)]))}}var $options$jscomp$586$$=$props_72611_props__$1$jscomp$46$$.options,$fixed$$=$props_72611_props__$1$jscomp$46$$.fixed,$selectable$$=$props_72611_props__$1$jscomp$46$$.selectable,$left$jscomp$27_route$jscomp$6_state$jscomp$1019$$=
$props_72611_props__$1$jscomp$46$$.left,$min_width$jscomp$3$$=$props_72611_props__$1$jscomp$46$$.minWidth,$selected$jscomp$121$$=$props_72611_props__$1$jscomp$46$$.selected,$on_close$jscomp$2$$=$props_72611_props__$1$jscomp$46$$.onClose,$top$jscomp$8$$=$props_72611_props__$1$jscomp$46$$.top,$origin$jscomp$47$$=$props_72611_props__$1$jscomp$46$$.origin,$width__$1$jscomp$4$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_72611_props__$1$jscomp$46$$.width,"initial"),$min_width__$1$jscomp$1$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($min_width$jscomp$3$$,!1),$left__$1$jscomp$2$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($left$jscomp$27_route$jscomp$6_state$jscomp$1019$$,0),$top__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($top$jscomp$8$$,0);$left$jscomp$27_route$jscomp$6_state$jscomp$1019$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$route$$);var $in_dashboard_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4897$dashboard_projects$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($left$jscomp$27_route$jscomp$6_state$jscomp$1019$$))),$state_STAR_$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1651$offset_y$$,0,$APP.$cljs$cst$1650$offset_x$$,0,$cljs$cst$4898$levels$$,null],null)});$left$jscomp$27_route$jscomp$6_state$jscomp$1019$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$5$$);
var $offset_x$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($left$jscomp$27_route$jscomp$6_state$jscomp$1019$$,$APP.$cljs$cst$1650$offset_x$$),$offset_y$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($left$jscomp$27_route$jscomp$6_state$jscomp$1019$$,$APP.$cljs$cst$1651$offset_y$$),$levels$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($left$jscomp$27_route$jscomp$6_state$jscomp$1019$$,$cljs$cst$4898$levels$$),$internal_id$jscomp$1$$=(0,$APP.$rumext$v2$use_id$$)(),
$on_local_close$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_close$jscomp$2$$)],function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$5$$,$APP.$cljs$core$assoc$$,$cljs$cst$4898$levels$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1365$parent$$,null,$APP.$cljs$cst$873$options$$,$options$jscomp$586$$],null)],
null));return $APP.$cljs$core$fn_QMARK_$$($on_close$jscomp$2$$)?$on_close$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$2$$():null});$props_72611_props__$1$jscomp$46$$={...$props_72611_props__$1$jscomp$46$$,onClose:$on_local_close$$};var $ids$jscomp$257$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($levels$jscomp$3$$)],function(){var $last_level$$=$APP.$cljs$core$last$$($levels$jscomp$3$$);
return $app$main$ui$components$context_menu_a11y$generate_ids_group$$($APP.$cljs$cst$873$options$$.$cljs$core$IFn$_invoke$arity$1$($last_level$$),$APP.$cljs$cst$1365$parent$$.$cljs$core$IFn$_invoke$arity$1$($last_level$$))}),$check_menu_offscreen$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($top__$1$$),$APP.$rumext$v2$adapt$$($left__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($offset_x$jscomp$10$$),$APP.$rumext$v2$adapt$$($offset_y$jscomp$10$$)],function($node$jscomp$354_node_height_target_offset_y$$){if($node$jscomp$354_node_height_target_offset_y$$!=
null){var $bounding_rect_node_width_target_offset_x$$=$APP.$app$util$dom$get_bounding_rect$$($node$jscomp$354_node_height_target_offset_y$$),$window_size$jscomp$2_window_width$$=$APP.$app$util$dom$get_window_size$$();$node$jscomp$354_node_height_target_offset_y$$=$bounding_rect_node_width_target_offset_x$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounding_rect_node_width_target_offset_x$$,$APP.$cljs$cst$1522$height$$);$bounding_rect_node_width_target_offset_x$$=$bounding_rect_node_width_target_offset_x$$?.width??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounding_rect_node_width_target_offset_x$$,$APP.$cljs$cst$290$width$$);var $window_height$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($window_size$jscomp$2_window_width$$,$APP.$cljs$cst$1522$height$$);$window_size$jscomp$2_window_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($window_size$jscomp$2_window_width$$,$APP.$cljs$cst$290$width$$);$node$jscomp$354_node_height_target_offset_y$$=$top__$1$$+$node$jscomp$354_node_height_target_offset_y$$>
$window_height$jscomp$1$$?-$node$jscomp$354_node_height_target_offset_y$$:0;$bounding_rect_node_width_target_offset_x$$=$left__$1$jscomp$2$$+$bounding_rect_node_width_target_offset_x$$>$window_size$jscomp$2_window_width$$?-$bounding_rect_node_width_target_offset_x$$:0;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$354_node_height_target_offset_y$$,$offset_y$jscomp$10$$)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($bounding_rect_node_width_target_offset_x$$,
$offset_x$jscomp$10$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$5$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1651$offset_y$$,$node$jscomp$354_node_height_target_offset_y$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1650$offset_x$$,$bounding_rect_node_width_target_offset_x$$])):null}return null}),$on_submenu_exit$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$130$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$130$$);
return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$5$$,$APP.$cljs$core$update$$,$cljs$cst$4898$levels$$,$APP.$cljs$core$pop$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$586$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$5$$,$APP.$cljs$core$assoc$$,$cljs$cst$4898$levels$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1365$parent$$,null,$APP.$cljs$cst$873$options$$,$options$jscomp$586$$],null)],null))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($internal_id$jscomp$1$$)],function(){return $app$util$globals$dispatch_BANG_$$($app$util$globals$event$$("penpot:context-menu:open",{id:$internal_id$jscomp$1$$}))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($internal_id$jscomp$1$$),
$APP.$rumext$v2$adapt$$($on_local_close$$)],function(){function $on_event$jscomp$1$$($event$jscomp$132$$){var $temp__5825__auto__$jscomp$257$$=$event$jscomp$132$$.detail;return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$257$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($internal_id$jscomp$1$$,$temp__5825__auto__$jscomp$257$$.id)?$on_local_close$$.$cljs$core$IFn$_invoke$arity$1$?$on_local_close$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$132$$):$on_local_close$$($event$jscomp$132$$):
null:null}$APP.$app$util$globals$document$$.addEventListener("penpot:context-menu:open",$on_event$jscomp$1$$);return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$util$globals$unlisten$$,"penpot:context-menu:open",$on_event$jscomp$1$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$257$$)],function(){return $APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$focus_BANG_$$($APP.$app$util$dom$get_element$$($APP.$cljs$core$first$$($ids$jscomp$257$$)))})});
return $levels$jscomp$3$$!=null?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$components$dropdown$dropdown_content_STAR_$$,$props_72611_props__$1$jscomp$46$$,function(){var $level$jscomp$54_parent$jscomp$289$$=$APP.$cljs$core$peek$$($levels$jscomp$3$$),$options__$1$jscomp$76$$=$APP.$cljs$cst$873$options$$.$cljs$core$IFn$_invoke$arity$1$($level$jscomp$54_parent$jscomp$289$$);$level$jscomp$54_parent$jscomp$289$$=$APP.$cljs$cst$1365$parent$$.$cljs$core$IFn$_invoke$arity$1$($level$jscomp$54_parent$jscomp$289$$);
return(0,$APP.$rumext$v2$jsx$$)("div",{style:{top:$top__$1$$+$offset_y$jscomp$10$$,left:$left__$1$jscomp$2$$+$offset_x$jscomp$10$$},onKeyDown:$on_key_down$jscomp$1$$($options__$1$jscomp$76$$,$level$jscomp$54_parent$jscomp$289$$),className:($APP.$cljs$core$truth_$$($selectable$$)?"main_ui_components_context_menu_a11y__is-selectable":"")+" main_ui_components_context_menu_a11y__context-menu main_ui_components_context_menu_a11y__is-open "+($APP.$cljs$core$truth_$$($fixed$$)?"main_ui_components_context_menu_a11y__fixed":
""),children:(0,$APP.$rumext$v2$jsxs$$)("ul",{style:{width:$width__$1$jscomp$4$$},role:"menu",ref:$check_menu_offscreen$$,className:($APP.$cljs$core$truth_$$($min_width__$1$jscomp$1$$)?"main_ui_components_context_menu_a11y__min-width":"")+" main_ui_components_context_menu_a11y__context-menu-items",children:[$APP.$cljs$core$truth_$$($level$jscomp$54_parent$jscomp$289$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("li",{id:"go-back-sub-option",role:"menuitem",
tabIndex:"0",onKeyDown:$APP.$app$util$dom$prevent_default$$,className:"main_ui_components_context_menu_a11y__context-menu-item",children:(0,$APP.$rumext$v2$jsxs$$)("button",{"data-no-close":!0,onClick:$on_submenu_exit$$,className:"main_ui_components_context_menu_a11y__context-menu-action main_ui_components_context_menu_a11y__submenu-back",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_context_menu_a11y__submenu-icon-back",children:$APP.$app$main$ui$icons$arrow$$}),$level$jscomp$54_parent$jscomp$289$$]})}),
(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_components_context_menu_a11y__separator"})]}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$36$$,$p__72625$$){var $index$jscomp$378$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72625$$,0,null),$option$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72625$$,1,null);$out_arr__44124__auto__$jscomp$36$$.push(function(){var $name$jscomp$385$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$5$$),
$id$jscomp$807$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$5$$),$sub_options$jscomp$1$$=$APP.$cljs$cst$873$options$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$5$$),$handler$jscomp$44$$=$APP.$cljs$cst$2402$handler$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$5$$),$title$jscomp$18$$=$APP.$cljs$cst$939$title$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$5$$),$disabled$jscomp$4$$=$APP.$cljs$cst$2948$disabled$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$5$$);
return $APP.$cljs$core$truth_$$($name$jscomp$385$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$385$$,$APP.$cljs$cst$1472$separator$$)?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_components_context_menu_a11y__separator"},"context-item-"+($index$jscomp$378$$??"")):(0,$APP.$rumext$v2$jsx$$)("li",{id:$id$jscomp$807$$,tabIndex:"0",role:"menuitem",onKeyDown:$APP.$app$util$dom$prevent_default$$,className:($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($selected$jscomp$121$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$385$$,$selected$jscomp$121$$):$selected$jscomp$121$$)?"main_ui_components_context_menu_a11y__is-selected":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($selected$jscomp$121$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$807$$,$selected$jscomp$121$$):$selected$jscomp$121$$)?"main_ui_components_context_menu_a11y__selected":"")+" main_ui_components_context_menu_a11y__context-menu-item",children:$APP.$cljs$core$not$$($sub_options$jscomp$1$$)?
(0,$APP.$rumext$v2$jsxs$$)("a",{title:$title$jscomp$18$$,onClick:function($p1__72610_SHARP_$$){$APP.$app$util$dom$stop_propagation$$($p1__72610_SHARP_$$);if($APP.$cljs$core$truth_$$($disabled$jscomp$4$$))return null;$on_close$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_close$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($p1__72610_SHARP_$$):$on_close$jscomp$2$$($p1__72610_SHARP_$$);return $handler$jscomp$44$$.$cljs$core$IFn$_invoke$arity$1$?$handler$jscomp$44$$.$cljs$core$IFn$_invoke$arity$1$($p1__72610_SHARP_$$):
$handler$jscomp$44$$($p1__72610_SHARP_$$)},"data-testid":$id$jscomp$807$$,className:"main_ui_components_context_menu_a11y__context-menu-action "+($APP.$cljs$core$truth_$$($disabled$jscomp$4$$)?"main_ui_components_context_menu_a11y__context-menu-action-disabled":""),children:[$in_dashboard_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$385$$,"Default")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.default-team-name"):$name$jscomp$385$$,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($selected$jscomp$121$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$807$$,$selected$jscomp$121$$):$selected$jscomp$121$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_context_menu_a11y__selected-icon",children:$APP.$app$main$ui$icons$tick$$}):null]}):(0,$APP.$rumext$v2$jsxs$$)("a",{"data-no-close":!0,onClick:$enter_submenu$$($name$jscomp$385$$,$sub_options$jscomp$1$$),"data-testid":$id$jscomp$807$$,className:"main_ui_components_context_menu_a11y__context-menu-action main_ui_components_context_menu_a11y__submenu",
children:[$name$jscomp$385$$,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_context_menu_a11y__submenu-icon",children:$APP.$app$main$ui$icons$arrow$$})]})},$id$jscomp$807$$):null}());return $out_arr__44124__auto__$jscomp$36$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($options__$1$jscomp$76$$))]})})}()):null};
$APP.$app$main$ui$components$context_menu_a11y$context_menu_STAR_$$=function($props_72631$$){return $props_72631$$.show?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$components$context_menu_a11y$context_menu_inner_STAR_$$,$props_72631$$):null};
$APP.$app$main$ui$components$title_bar$title_bar_STAR_$$=function($props_72679$$){var $on_collapsed$$=$props_72679$$.onCollapsed,$title_class$$=$props_72679$$.titleClass,$children$jscomp$269$$=$props_72679$$.children,$add_icon_gap$$=$props_72679$$.addIconGap,$on_btn_click$$=$props_72679$$.onBtnClick,$collapsed$$=$props_72679$$.collapsed,$btn_title$$=$props_72679$$.btnTitle,$btn_icon$$=$props_72679$$.btnIcon,$title$jscomp$19$$=$props_72679$$.title;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_components_title_bar__title-bar "+
($props_72679$$.className??""),children:[$props_72679$$.collapsable?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_components_title_bar__title-wrapper "+($title_class$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_collapsed$$,className:"main_ui_components_title_bar__icon-text-btn",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$APP.$cljs$core$truth_$$($collapsed$$)?"arrow-right":"arrow-down",size:"s",className:"main_ui_components_title_bar__icon"}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_components_title_bar__title",children:$title$jscomp$19$$})]})}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_components_title_bar__title-only "+($APP.$cljs$core$truth_$$($add_icon_gap$$)?"main_ui_components_title_bar__title-only-icon-gap":"")+" "+($title_class$$??""),children:$title$jscomp$19$$}),$children$jscomp$269$$,$on_btn_click$$!=null?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",
"aria-label":$btn_title$$,onClick:$on_btn_click$$,icon:$btn_icon$$}):null]})};$app$main$ui$components$title_bar$inspect_title_bar_STAR_$$=function($props_72680$$){return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_components_title_bar__title-bar "+($props_72680$$.className??""),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:($props_72680$$.titleClass??"")+" main_ui_components_title_bar__title-only main_ui_components_title_bar__inspect-title",children:$props_72680$$.title})})};
$app$util$shape_icon$get_bool_icon$$=function($G__72770_shape$jscomp$791$$){$G__72770_shape$jscomp$791$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__72770_shape$jscomp$791$$,$APP.$cljs$cst$1888$bool_type$$);switch($G__72770_shape$jscomp$791$$ instanceof $APP.$cljs$core$Keyword$$?$G__72770_shape$jscomp$791$$.$fqn$:null){case "difference":return"boolean-difference";case "exclude":return"boolean-exclude";case "intersection":return"boolean-intersection";case "union":return"boolean-union";
default:return null}};
$APP.$app$util$shape_icon$get_shape_icon$$=function($shape$jscomp$793$$){if($APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$793$$))return $APP.$app$common$types$component$main_instance_QMARK_$$($shape$jscomp$793$$)?$APP.$app$common$types$component$is_variant_QMARK_$$($shape$jscomp$793$$)?"variant":"component":"component-copy";var $G__72771$$=$shape$jscomp$793$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$793$$,$APP.$cljs$cst$139$type$$);switch($G__72771$$ instanceof
$APP.$cljs$core$Keyword$$?$G__72771$$.$fqn$:null){case "frame":return $APP.$cljs$core$truth_$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$793$$))?"component":$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$793$$)&&$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$793$$)?"flex-horizontal":$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$793$$)&&
$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$793$$)?"flex-vertical":$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$793$$)?"flex-grid":"board";case "image":return"img";case "line":return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$has_images_QMARK_$$($shape$jscomp$793$$))?"img":"rectangle";case "circle":return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$has_images_QMARK_$$($shape$jscomp$793$$))?
"img":"elipse";case "path":return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$has_images_QMARK_$$($shape$jscomp$793$$))?"img":"path";case "rect":return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$has_images_QMARK_$$($shape$jscomp$793$$))?"img":"rectangle";case "text":return"text";case "group":return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1609$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$793$$))?"mask":"group";case "bool":return $app$util$shape_icon$get_bool_icon$$($shape$jscomp$793$$);
case "svg-raw":return"img";default:return null}};
$APP.$app$main$data$dashboard$project_created$$=function($p__72930$$){var $map__72931__$1$$=$APP.$cljs$core$__destructure_map$$($p__72930$$),$id$jscomp$812$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72931__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$dashboard$project_created_72932$$==="undefined"&&($app$main$data$dashboard$project_created_72932$$=function($p__72930$jscomp$1$$,$map__72931$jscomp$1$$,$project$jscomp$5$$,$id$jscomp$813$$,$meta72933$$){this.$p__72930$=$p__72930$jscomp$1$$;
this.$map__72931$=$map__72931$jscomp$1$$;this.project=$project$jscomp$5$$;this.id=$id$jscomp$813$$;this.$meta72933$=$meta72933$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$project_created_72932$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$project_created_72932$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4935$app_DOT_main_DOT_data_DOT_dashboard_SLASH_project_created$$},
$app$main$data$dashboard$project_created_72932$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72934$$,$meta72933__$1$$){return new $app$main$data$dashboard$project_created_72932$$(this.$p__72930$,this.$map__72931$,this.project,this.id,$meta72933__$1$$)},$app$main$data$dashboard$project_created_72932$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72933$},$app$main$data$dashboard$project_created_72932$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.project},
$app$main$data$dashboard$project_created_72932$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$project_created_72932$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2726$$,$state$jscomp$1036$$){return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$1036$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1928$projects$$,this.id],null),this.project),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2185$dashboard_local$$,$APP.$cljs$cst$4936$project_for_edit$$],null),this.id)});return new $app$main$data$dashboard$project_created_72932$$($p__72930$$,$map__72931__$1$$,$map__72931__$1$$,$id$jscomp$812$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$project_duplicated$$=function($p__72945$$){var $map__72946__$1$$=$APP.$cljs$core$__destructure_map$$($p__72945$$),$id$jscomp$814$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72946__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$dashboard$project_duplicated_72947$$==="undefined"&&($app$main$data$dashboard$project_duplicated_72947$$=function($p__72945$jscomp$1$$,$map__72946$jscomp$1$$,$project$jscomp$7$$,$id$jscomp$815$$,$meta72948$$){this.$p__72945$=$p__72945$jscomp$1$$;
this.$map__72946$=$map__72946$jscomp$1$$;this.project=$project$jscomp$7$$;this.id=$id$jscomp$815$$;this.$meta72948$=$meta72948$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$project_duplicated_72947$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$project_duplicated_72947$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4939$app_DOT_main_DOT_data_DOT_dashboard_SLASH_project_duplicated$$},
$app$main$data$dashboard$project_duplicated_72947$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72949$$,$meta72948__$1$$){return new $app$main$data$dashboard$project_duplicated_72947$$(this.$p__72945$,this.$map__72946$,this.project,this.id,$meta72948__$1$$)},$app$main$data$dashboard$project_duplicated_72947$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72948$},$app$main$data$dashboard$project_duplicated_72947$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$project_duplicated_72947$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2728$$,$state$jscomp$1038$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$1038$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1928$projects$$,this.id],null),this.project)});return new $app$main$data$dashboard$project_duplicated_72947$$($p__72945$$,$map__72946__$1$$,$map__72946__$1$$,$id$jscomp$814$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$duplicate_project$$=function($p__72955$$){var $map__72956__$1$$=$APP.$cljs$core$__destructure_map$$($p__72955$$),$id$jscomp$816$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72956__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$387$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72956__$1$$,$APP.$cljs$cst$725$name$$);typeof $app$main$data$dashboard$duplicate_project_72957$$==="undefined"&&($app$main$data$dashboard$duplicate_project_72957$$=function($p__72955$jscomp$1$$,
$map__72956$jscomp$1$$,$params$jscomp$328$$,$id$jscomp$817$$,$name$jscomp$388$$,$meta72958$$){this.$p__72955$=$p__72955$jscomp$1$$;this.$map__72956$=$map__72956$jscomp$1$$;this.params=$params$jscomp$328$$;this.id=$id$jscomp$817$$;this.name=$name$jscomp$388$$;this.$meta72958$=$meta72958$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$duplicate_project_72957$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$duplicate_project_72957$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4940$app_DOT_main_DOT_data_DOT_dashboard_SLASH_duplicate_project$$},$app$main$data$dashboard$duplicate_project_72957$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72959$$,$meta72958__$1$$){return new $app$main$data$dashboard$duplicate_project_72957$$(this.$p__72955$,this.$map__72956$,this.params,this.id,this.name,$meta72958__$1$$)},$app$main$data$dashboard$duplicate_project_72957$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72958$},$app$main$data$dashboard$duplicate_project_72957$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$duplicate_project_72957$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2181$project_id$$,this.id,$APP.$cljs$cst$725$name$$,this.name],null)},$app$main$data$dashboard$duplicate_project_72957$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$duplicate_project_72957$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2730_map__72960_on_success$jscomp$32$$,$new_name$jscomp$33_projects$jscomp$4_state$jscomp$1039_unames$jscomp$15$$){$_$jscomp$2730_map__72960_on_success$jscomp$32$$=$APP.$cljs$core$meta$$(this.params);var $map__72960__$1_on_error$jscomp$38$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$2730_map__72960_on_success$jscomp$32$$);$_$jscomp$2730_map__72960_on_success$jscomp$32$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__72960__$1_on_error$jscomp$38$$,$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);$map__72960__$1_on_error$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__72960__$1_on_error$jscomp$38$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);$new_name$jscomp$33_projects$jscomp$4_state$jscomp$1039_unames$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_name$jscomp$33_projects$jscomp$4_state$jscomp$1039_unames$jscomp$15$$,
$APP.$cljs$cst$1928$projects$$);$new_name$jscomp$33_projects$jscomp$4_state$jscomp$1039_unames$jscomp$15$$=$APP.$app$common$files$helpers$get_used_names$$($new_name$jscomp$33_projects$jscomp$4_state$jscomp$1039_unames$jscomp$15$$);$new_name$jscomp$33_projects$jscomp$4_state$jscomp$1039_unames$jscomp$15$$=$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(this.name,$new_name$jscomp$33_projects$jscomp$4_state$jscomp$1039_unames$jscomp$15$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1628$suffix_fn$$,
function($copy_count$jscomp$3$$){return" "+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.copy-suffix")??"")+(($copy_count$jscomp$3$$>1?[" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($copy_count$jscomp$3$$)].join(""):null)??"")}]));return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__72960__$1_on_error$jscomp$38$$,$APP.$beicon$v2$core$map$$($app$main$data$dashboard$project_duplicated$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2730_map__72960_on_success$jscomp$32$$,
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$4941$duplicate_project$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2181$project_id$$,this.id,$APP.$cljs$cst$725$name$$,$new_name$jscomp$33_projects$jscomp$4_state$jscomp$1039_unames$jscomp$15$$],null)))))});return new $app$main$data$dashboard$duplicate_project_72957$$($p__72955$$,$map__72956__$1$$,$map__72956__$1$$,$id$jscomp$816$$,$name$jscomp$387$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$move_project$$=function($p__72969$$){var $map__72970__$1$$=$APP.$cljs$core$__destructure_map$$($p__72969$$),$id$jscomp$818$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72970__$1$$,$APP.$cljs$cst$266$id$$),$team_id$jscomp$98$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72970__$1$$,$APP.$cljs$cst$1927$team_id$$);typeof $app$main$data$dashboard$move_project_72974$$==="undefined"&&($app$main$data$dashboard$move_project_72974$$=function($p__72969$jscomp$1$$,
$map__72970$jscomp$1$$,$params$jscomp$330$$,$id$jscomp$819$$,$team_id$jscomp$99$$,$meta72975$$){this.$p__72969$=$p__72969$jscomp$1$$;this.$map__72970$=$map__72970$jscomp$1$$;this.params=$params$jscomp$330$$;this.id=$id$jscomp$819$$;this.$team_id$=$team_id$jscomp$99$$;this.$meta72975$=$meta72975$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$move_project_72974$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$move_project_72974$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4942$app_DOT_main_DOT_data_DOT_dashboard_SLASH_move_project$$},$app$main$data$dashboard$move_project_72974$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72976$$,$meta72975__$1$$){return new $app$main$data$dashboard$move_project_72974$$(this.$p__72969$,this.$map__72970$,this.params,this.id,this.$team_id$,$meta72975__$1$$)},$app$main$data$dashboard$move_project_72974$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72975$},$app$main$data$dashboard$move_project_72974$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$move_project_72974$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$1927$team_id$$,this.$team_id$],null)},$app$main$data$dashboard$move_project_72974$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$move_project_72974$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__72977_on_success$jscomp$33$$=$APP.$cljs$core$meta$$(this.params),$map__72977__$1_on_error$jscomp$39$$=$APP.$cljs$core$__destructure_map$$($map__72977_on_success$jscomp$33$$);$map__72977_on_success$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__72977__$1_on_error$jscomp$39$$,$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);$map__72977__$1_on_error$jscomp$39$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__72977__$1_on_error$jscomp$39$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__72977__$1_on_error$jscomp$39$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__72977_on_success$jscomp$33$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$4943$move_project$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2181$project_id$$,this.id,$APP.$cljs$cst$1927$team_id$$,this.$team_id$],null))))});return new $app$main$data$dashboard$move_project_72974$$($p__72969$$,$map__72970__$1$$,$map__72970__$1$$,$id$jscomp$818$$,$team_id$jscomp$98$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$dashboard$toggle_project_pin$$=function($p__72979$$){var $map__72980__$1$$=$APP.$cljs$core$__destructure_map$$($p__72979$$),$id$jscomp$820$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72980__$1$$,$APP.$cljs$cst$266$id$$),$is_pinned$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72980__$1$$,$APP.$cljs$cst$4903$is_pinned$$);typeof $app$main$data$dashboard$toggle_project_pin_72981$$==="undefined"&&($app$main$data$dashboard$toggle_project_pin_72981$$=
function($p__72979$jscomp$1$$,$map__72980$jscomp$1$$,$project$jscomp$9$$,$id$jscomp$821$$,$is_pinned$jscomp$1$$,$meta72982$$){this.$p__72979$=$p__72979$jscomp$1$$;this.$map__72980$=$map__72980$jscomp$1$$;this.project=$project$jscomp$9$$;this.id=$id$jscomp$821$$;this.$is_pinned$=$is_pinned$jscomp$1$$;this.$meta72982$=$meta72982$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$toggle_project_pin_72981$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$toggle_project_pin_72981$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4944$app_DOT_main_DOT_data_DOT_dashboard_SLASH_toggle_project_pin$$},$app$main$data$dashboard$toggle_project_pin_72981$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72983$$,$meta72982__$1$$){return new $app$main$data$dashboard$toggle_project_pin_72981$$(this.$p__72979$,this.$map__72980$,this.project,this.id,this.$is_pinned$,
$meta72982__$1$$)},$app$main$data$dashboard$toggle_project_pin_72981$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72982$},$app$main$data$dashboard$toggle_project_pin_72981$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$toggle_project_pin_72981$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2733$$,$state$jscomp$1040$$){return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$1040$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1928$projects$$,this.id],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4903$is_pinned$$,$APP.$cljs$core$not$$(this.$is_pinned$)]))},$app$main$data$dashboard$toggle_project_pin_72981$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$toggle_project_pin_72981$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2734_params$jscomp$331_project__$1$$,$state$jscomp$1041$$){$_$jscomp$2734_params$jscomp$331_project__$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1041$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1928$projects$$,this.id],null));$_$jscomp$2734_params$jscomp$331_project__$1$$=$APP.$cljs$core$select_keys$$($_$jscomp$2734_params$jscomp$331_project__$1$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$4903$is_pinned$$,$APP.$cljs$cst$1927$team_id$$],null));return $APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$4945$update_project_pin$$,$_$jscomp$2734_params$jscomp$331_project__$1$$))});return new $app$main$data$dashboard$toggle_project_pin_72981$$($p__72979$$,$map__72980__$1$$,$map__72980__$1$$,$id$jscomp$820$$,$is_pinned$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$dashboard$rename_project$$=function($p__72987$$){var $map__72988__$1$$=$APP.$cljs$core$__destructure_map$$($p__72987$$),$id$jscomp$822$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72988__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$389$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72988__$1$$,$APP.$cljs$cst$725$name$$);typeof $app$main$data$dashboard$rename_project_72989$$==="undefined"&&($app$main$data$dashboard$rename_project_72989$$=function($p__72987$jscomp$1$$,
$map__72988$jscomp$1$$,$params$jscomp$333$$,$id$jscomp$823$$,$name$jscomp$390$$,$meta72990$$){this.$p__72987$=$p__72987$jscomp$1$$;this.$map__72988$=$map__72988$jscomp$1$$;this.params=$params$jscomp$333$$;this.id=$id$jscomp$823$$;this.name=$name$jscomp$390$$;this.$meta72990$=$meta72990$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$rename_project_72989$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$rename_project_72989$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4946$app_DOT_main_DOT_data_DOT_dashboard_SLASH_rename_project$$},$app$main$data$dashboard$rename_project_72989$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72991$$,$meta72990__$1$$){return new $app$main$data$dashboard$rename_project_72989$$(this.$p__72987$,this.$map__72988$,this.params,this.id,this.name,$meta72990__$1$$)},$app$main$data$dashboard$rename_project_72989$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72990$},$app$main$data$dashboard$rename_project_72989$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$rename_project_72989$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2735$$,$state$jscomp$1042$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$1042$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1928$projects$$,this.id],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,this.name])),$APP.$cljs$cst$2185$dashboard_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4936$project_for_edit$$)},$app$main$data$dashboard$rename_project_72989$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$rename_project_72989$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){return $APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$4947$rename_project$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$725$name$$,this.name],null)))});return new $app$main$data$dashboard$rename_project_72989$$($p__72987$$,$map__72988__$1$$,$map__72988__$1$$,$id$jscomp$822$$,$name$jscomp$389$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$delete_project$$=function($p__72996$$){var $map__72997__$1$$=$APP.$cljs$core$__destructure_map$$($p__72996$$),$id$jscomp$824$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72997__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$dashboard$delete_project_72998$$==="undefined"&&($app$main$data$dashboard$delete_project_72998$$=function($p__72996$jscomp$1$$,$map__72997$jscomp$1$$,$params$jscomp$335$$,$id$jscomp$825$$,$meta72999$$){this.$p__72996$=$p__72996$jscomp$1$$;
this.$map__72997$=$map__72997$jscomp$1$$;this.params=$params$jscomp$335$$;this.id=$id$jscomp$825$$;this.$meta72999$=$meta72999$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$delete_project_72998$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_project_72998$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4948$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_project$$},
$app$main$data$dashboard$delete_project_72998$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73000$$,$meta72999__$1$$){return new $app$main$data$dashboard$delete_project_72998$$(this.$p__72996$,this.$map__72997$,this.params,this.id,$meta72999__$1$$)},$app$main$data$dashboard$delete_project_72998$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72999$},$app$main$data$dashboard$delete_project_72998$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$delete_project_72998$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2737$$,$state$jscomp$1043$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1043$$,$APP.$cljs$cst$1928$projects$$,$APP.$cljs$core$dissoc$$,this.id)},$app$main$data$dashboard$delete_project_72998$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_project_72998$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){return $APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$4949$delete_project$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,this.id],null)))});return new $app$main$data$dashboard$delete_project_72998$$($p__72996$$,$map__72997__$1$$,$map__72997__$1$$,$id$jscomp$824$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$dashboard$file_created$$=function($p__73051$$){var $map__73052__$1$$=$APP.$cljs$core$__destructure_map$$($p__73051$$),$id$jscomp$832$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73052__$1$$,$APP.$cljs$cst$266$id$$),$project_id$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73052__$1$$,$APP.$cljs$cst$2181$project_id$$);typeof $app$main$data$dashboard$file_created_73053$$==="undefined"&&($app$main$data$dashboard$file_created_73053$$=function($p__73051$jscomp$1$$,
$map__73052$jscomp$1$$,$file$jscomp$84$$,$id$jscomp$833$$,$project_id$jscomp$23$$,$meta73054$$){this.$p__73051$=$p__73051$jscomp$1$$;this.$map__73052$=$map__73052$jscomp$1$$;this.file=$file$jscomp$84$$;this.id=$id$jscomp$833$$;this.$project_id$=$project_id$jscomp$23$$;this.$meta73054$=$meta73054$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$file_created_73053$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$file_created_73053$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4957$app_DOT_main_DOT_data_DOT_dashboard_SLASH_file_created$$},$app$main$data$dashboard$file_created_73053$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73055$$,$meta73054__$1$$){return new $app$main$data$dashboard$file_created_73053$$(this.$p__73051$,this.$map__73052$,this.file,this.id,this.$project_id$,$meta73054__$1$$)},$app$main$data$dashboard$file_created_73053$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73054$},$app$main$data$dashboard$file_created_73053$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,this.id,$cljs$cst$3425$file_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$(this.file)],null)},$app$main$data$dashboard$file_created_73053$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$file_created_73053$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2750_file__$1$jscomp$2$$,$state$jscomp$1049$$){$_$jscomp$2750_file__$1$jscomp$2$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.file,$APP.$cljs$cst$142$data$$);return $APP.$app$common$data$update_in_when$$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$1049$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,this.id],null),$_$jscomp$2750_file__$1$jscomp$2$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4914$recent_files$$,this.id],null),$_$jscomp$2750_file__$1$jscomp$2$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1928$projects$$,this.$project_id$,$APP.$cljs$cst$1080$count$$],null),$APP.$cljs$core$inc$$)});return new $app$main$data$dashboard$file_created_73053$$($p__73051$$,$map__73052__$1$$,$map__73052__$1$$,$id$jscomp$832$$,$project_id$jscomp$22$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$dashboard$move_files$$=function($p__73080$$){var $map__73081__$1$$=$APP.$cljs$core$__destructure_map$$($p__73080$$),$ids$jscomp$258$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73081__$1$$,$APP.$cljs$cst$1723$ids$$),$project_id$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73081__$1$$,$APP.$cljs$cst$2181$project_id$$);typeof $app$main$data$dashboard$move_files_73082$$==="undefined"&&($app$main$data$dashboard$move_files_73082$$=function($p__73080$jscomp$1$$,
$map__73081$jscomp$1$$,$params$jscomp$347$$,$ids$jscomp$259$$,$project_id$jscomp$27$$,$meta73083$$){this.$p__73080$=$p__73080$jscomp$1$$;this.$map__73081$=$map__73081$jscomp$1$$;this.params=$params$jscomp$347$$;this.ids=$ids$jscomp$259$$;this.$project_id$=$project_id$jscomp$27$$;this.$meta73083$=$meta73083$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$move_files_73082$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$move_files_73082$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4962$app_DOT_main_DOT_data_DOT_dashboard_SLASH_move_files$$},$app$main$data$dashboard$move_files_73082$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73084$$,$meta73083__$1$$){return new $app$main$data$dashboard$move_files_73082$$(this.$p__73080$,this.$map__73081$,this.params,this.ids,this.$project_id$,$meta73083__$1$$)},$app$main$data$dashboard$move_files_73082$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73083$},$app$main$data$dashboard$move_files_73082$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$move_files_73082$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$4963$num_files$$,$APP.$cljs$core$count$$(this.ids),$APP.$cljs$cst$2181$project_id$$,this.$project_id$],null)},$app$main$data$dashboard$move_files_73082$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$move_files_73082$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2755_origin_project$$,$state$jscomp$1052$$){function $update_project$$($project$jscomp$10$$,$delta$jscomp$55$$,$op$jscomp$19$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($project$jscomp$10$$,$APP.$cljs$cst$1080$count$$,function($p1__73079_SHARP_$$){var $G__73092$$=$APP.$cljs$core$count$$($self__$jscomp$6915$$.ids);
return $op$jscomp$19$$.$cljs$core$IFn$_invoke$arity$2$?$op$jscomp$19$$.$cljs$core$IFn$_invoke$arity$2$($p1__73079_SHARP_$$,$G__73092$$):$op$jscomp$19$$($p1__73079_SHARP_$$,$G__73092$$)}),$APP.$cljs$cst$1737$modified_at$$,$app$common$time$plus$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$4964$milliseconds$$,$delta$jscomp$55$$],null)))}var $self__$jscomp$6915$$=this;$_$jscomp$2755_origin_project$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1052$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,$APP.$cljs$core$first$$($self__$jscomp$6915$$.ids),$APP.$cljs$cst$2181$project_id$$],null));return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$1052$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1928$projects$$,$_$jscomp$2755_origin_project$$],
null),$update_project$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([0,$APP.$cljs$core$_$$])),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1928$projects$$,$self__$jscomp$6915$$.$project_id$],null),$update_project$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([10,$APP.$cljs$core$_PLUS_$$]))},$app$main$data$dashboard$move_files_73082$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$move_files_73082$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__73093_on_success$jscomp$36$$=$APP.$cljs$core$meta$$(this.params),$map__73093__$1_on_error$jscomp$42$$=$APP.$cljs$core$__destructure_map$$($map__73093_on_success$jscomp$36$$);$map__73093_on_success$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73093__$1_on_error$jscomp$42$$,$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);$map__73093__$1_on_error$jscomp$42$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73093__$1_on_error$jscomp$42$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__73093__$1_on_error$jscomp$42$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__73093_on_success$jscomp$36$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$4965$move_files$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,
[$APP.$cljs$cst$1723$ids$$,this.ids,$APP.$cljs$cst$2181$project_id$$,this.$project_id$],null))))});return new $app$main$data$dashboard$move_files_73082$$($p__73080$$,$map__73081__$1$$,$map__73081__$1$$,$ids$jscomp$258$$,$project_id$jscomp$26$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$dashboard$clone_template$$=function($p__73094$$){var $map__73095__$1$$=$APP.$cljs$core$__destructure_map$$($p__73094$$),$template_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73095__$1$$,$APP.$cljs$cst$4966$template_id$$),$project_id$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73095__$1$$,$APP.$cljs$cst$2181$project_id$$);typeof $app$main$data$dashboard$clone_template_73096$$==="undefined"&&($app$main$data$dashboard$clone_template_73096$$=
function($p__73094$jscomp$1$$,$map__73095$jscomp$1$$,$params$jscomp$349$$,$template_id$jscomp$1$$,$project_id$jscomp$29$$,$meta73097$$){this.$p__73094$=$p__73094$jscomp$1$$;this.$map__73095$=$map__73095$jscomp$1$$;this.params=$params$jscomp$349$$;this.$template_id$=$template_id$jscomp$1$$;this.$project_id$=$project_id$jscomp$29$$;this.$meta73097$=$meta73097$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$clone_template_73096$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$clone_template_73096$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4967$app_DOT_main_DOT_data_DOT_dashboard_SLASH_clone_template$$},$app$main$data$dashboard$clone_template_73096$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73098$$,$meta73097__$1$$){return new $app$main$data$dashboard$clone_template_73096$$(this.$p__73094$,this.$map__73095$,this.params,this.$template_id$,this.$project_id$,
$meta73097__$1$$)},$app$main$data$dashboard$clone_template_73096$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73097$},$app$main$data$dashboard$clone_template_73096$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$clone_template_73096$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4966$template_id$$,this.$template_id$],null)},$app$main$data$dashboard$clone_template_73096$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$clone_template_73096$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2758_map__73099_on_success$jscomp$37$$,$state$jscomp$1053$$){var $self__$jscomp$6921$$=this;$_$jscomp$2758_map__73099_on_success$jscomp$37$$=$APP.$cljs$core$meta$$($self__$jscomp$6921$$.params);var $map__73099__$1_on_error$jscomp$43$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$2758_map__73099_on_success$jscomp$37$$);$_$jscomp$2758_map__73099_on_success$jscomp$37$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73099__$1_on_error$jscomp$43$$,$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$identity$$);$map__73099__$1_on_error$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73099__$1_on_error$jscomp$43$$,$APP.$cljs$cst$1295$on_error$$,$APP.$beicon$v2$core$throw$0$$);var $project_id__$1$jscomp$3$$=function(){var $or__5025__auto__$jscomp$918$$=$self__$jscomp$6921$$.$project_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$918$$)?
$or__5025__auto__$jscomp$918$$:$APP.$cljs$cst$2174$current_project_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1053$$)}();return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__73099__$1_on_error$jscomp$43$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2758_map__73099_on_success$jscomp$37$$,$APP.$beicon$v2$core$map$$($APP.$app$util$sse$get_payload$$,$APP.$beicon$v2$core$filter$$($APP.$app$util$sse$end_of_stream_QMARK_$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($event$jscomp$133$$){var $payload$jscomp$9$$=
$APP.$app$util$sse$get_payload$$($event$jscomp$133$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$133$$.type,"progress")?$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.dashboard",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$275$hint$$,"clone-template: progress"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1366$section$$,$APP.$cljs$cst$1366$section$$.$cljs$core$IFn$_invoke$arity$1$($payload$jscomp$9$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($payload$jscomp$9$$)],null)],null)}),null,"app.main.data.dashboard",
$APP.$cljs$cst$1160$debug$$,!1):$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.dashboard",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"clone-template: end"],null)],null)}),null,"app.main.data.dashboard",$APP.$cljs$cst$1160$debug$$,
!1);return null},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2257$app_DOT_util_DOT_sse_SLASH_clone_template$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2181$project_id$$,$project_id__$1$jscomp$3$$,$APP.$cljs$cst$4966$template_id$$,$self__$jscomp$6921$$.$template_id$],null)))))))});return new $app$main$data$dashboard$clone_template_73096$$($p__73094$$,$map__73095__$1$$,$map__73095__$1$$,$template_id$$,$project_id$jscomp$28$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$create_element$$=function(){typeof $app$main$data$dashboard$create_element_73100$$==="undefined"&&($app$main$data$dashboard$create_element_73100$$=function($meta73101$$){this.$meta73101$=$meta73101$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$create_element_73100$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$create_element_73100$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4968$app_DOT_main_DOT_data_DOT_dashboard_SLASH_create_element$$},$app$main$data$dashboard$create_element_73100$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73102$$,$meta73101__$1$$){return new $app$main$data$dashboard$create_element_73100$$($meta73101__$1$$)},$app$main$data$dashboard$create_element_73100$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73101$},$app$main$data$dashboard$create_element_73100$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$create_element_73100$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2759_action$jscomp$2_in_project_QMARK__route$jscomp$7$$,$state$jscomp$1054$$){var $team_id$jscomp$100$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1054$$);$_$jscomp$2759_action$jscomp$2_in_project_QMARK__route$jscomp$7$$=$APP.$cljs$cst$2171$route$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1054$$);var $params$jscomp$350_pparams$$=
$APP.$cljs$cst$2395$path_params$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2759_action$jscomp$2_in_project_QMARK__route$jscomp$7$$),$action_name_name$jscomp$397$$=($_$jscomp$2759_action$jscomp$2_in_project_QMARK__route$jscomp$7$$=$APP.$cljs$core$contains_QMARK_$$($params$jscomp$350_pparams$$,$APP.$cljs$cst$2181$project_id$$))?function(){var $files$jscomp$20_unames$jscomp$18$$=$APP.$app$main$data$helpers$lookup_team_files$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$1054$$,$team_id$jscomp$100$$);
$files$jscomp$20_unames$jscomp$18$$=$APP.$app$common$files$helpers$get_used_names$$($files$jscomp$20_unames$jscomp$18$$);return $APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.new-file-prefix"),$files$jscomp$20_unames$jscomp$18$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1629$immediate_suffix_QMARK_$$,!0]))}():function(){var $projects$jscomp$5_unames$jscomp$19$$=
$APP.$app$main$data$helpers$lookup_team_projects$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$1054$$,$team_id$jscomp$100$$);$projects$jscomp$5_unames$jscomp$19$$=$APP.$app$common$files$helpers$get_used_names$$($projects$jscomp$5_unames$jscomp$19$$);return $APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.new-project-prefix"),$projects$jscomp$5_unames$jscomp$19$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1629$immediate_suffix_QMARK_$$,
!0]))}();$params$jscomp$350_pparams$$=$_$jscomp$2759_action$jscomp$2_in_project_QMARK__route$jscomp$7$$?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2181$project_id$$,$APP.$cljs$cst$2181$project_id$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$350_pparams$$),$APP.$cljs$cst$725$name$$,$action_name_name$jscomp$397$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,$action_name_name$jscomp$397$$,$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$100$$],
null);$action_name_name$jscomp$397$$=$_$jscomp$2759_action$jscomp$2_in_project_QMARK__route$jscomp$7$$?$APP.$cljs$cst$4959$create_file$$:$APP.$cljs$cst$4938$create_project$$;$_$jscomp$2759_action$jscomp$2_in_project_QMARK__route$jscomp$7$$=$_$jscomp$2759_action$jscomp$2_in_project_QMARK__route$jscomp$7$$?$APP.$app$main$data$dashboard$file_created$$:$APP.$app$main$data$dashboard$project_created$$;var $can_edit_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1054$$,
$APP.$cljs$cst$2173$teams$$),$team_id$jscomp$100$$),$APP.$cljs$cst$1722$permissions$$),$APP.$cljs$cst$1596$can_edit$$);return $APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$2$$)?$APP.$beicon$v2$core$map$$($_$jscomp$2759_action$jscomp$2_in_project_QMARK__route$jscomp$7$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($action_name_name$jscomp$397$$,$params$jscomp$350_pparams$$)):null});return new $app$main$data$dashboard$create_element_73100$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$ui$components$link_button$link_button$$=function($class$$jscomp$25_props_72801$$){var $value$jscomp$730$$=$class$$jscomp$25_props_72801$$.value,$on_click$jscomp$7$$=$class$$jscomp$25_props_72801$$["on-click"],$data_testid$jscomp$1$$=$class$$jscomp$25_props_72801$$["data-testid"];$class$$jscomp$25_props_72801$$=$class$$jscomp$25_props_72801$$.class;var $on_key_down$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$7$$)],
function($event$jscomp$136$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$136$$))?$APP.$cljs$core$fn_QMARK_$$($on_click$jscomp$7$$)?$on_click$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$136$$):$on_click$jscomp$7$$($event$jscomp$136$$):null:null});return(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$value$jscomp$730$$,tabIndex:"0",onClick:$on_click$jscomp$7$$,onKeyDown:$on_key_down$jscomp$2$$,
"data-testid":$data_testid$jscomp$1$$,className:$class$$jscomp$25_props_72801$$})};
$APP.$app$main$ui$components$search_bar$search_bar_STAR_$$=function($auto_focus_props_72811$$){var $on_key_down$jscomp$3$$=$auto_focus_props_72811$$.onKeyDown,$on_change$jscomp$13$$=$auto_focus_props_72811$$.onChange,$children$jscomp$270$$=$auto_focus_props_72811$$.children,$on_clear$$=$auto_focus_props_72811$$.onClear,$icon_id$jscomp$2$$=$auto_focus_props_72811$$.iconId,$placeholder$$=$auto_focus_props_72811$$.placeholder,$value$jscomp$731$$=$auto_focus_props_72811$$.value,$input_ref$jscomp$2$$=
$auto_focus_props_72811$$.inputRef,$id$jscomp$840$$=$auto_focus_props_72811$$.id,$class$$jscomp$26$$=$auto_focus_props_72811$$.className,$on_submit$$=$auto_focus_props_72811$$.onSubmit;$auto_focus_props_72811$$=$auto_focus_props_72811$$.autoFocus;var $handle_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$13$$)],function($event$jscomp$137$$){var $value__$1$jscomp$27$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$137$$);return $on_change$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$27$$,$event$jscomp$137$$):$on_change$jscomp$13$$($value__$1$jscomp$27$$,$event$jscomp$137$$)}),$handle_clear$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_clear$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$13$$)],function($event$jscomp$138$$){return $APP.$cljs$core$truth_$$($on_clear$$)?$on_clear$$.$cljs$core$IFn$_invoke$arity$1$?$on_clear$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$138$$):
$on_clear$$($event$jscomp$138$$):$on_change$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$("",$event$jscomp$138$$):$on_change$jscomp$13$$("",$event$jscomp$138$$)}),$handle_key_down$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_submit$$),$APP.$rumext$v2$adapt$$($on_key_down$jscomp$3$$)],function($event$jscomp$139$$){$APP.$cljs$core$fn_QMARK_$$($on_key_down$jscomp$3$$)&&($on_key_down$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?
$on_key_down$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$139$$):$on_key_down$jscomp$3$$($event$jscomp$139$$));var $enter_QMARK__value_72817__$1$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$139$$),$esc_QMARK_$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$139$$),$node$jscomp$355$$=$APP.$app$util$dom$get_target$$($event$jscomp$139$$);$enter_QMARK__value_72817__$1$$&&($APP.$app$util$dom$blur_BANG_$$($node$jscomp$355$$),$APP.$cljs$core$fn_QMARK_$$($on_submit$$)&&($enter_QMARK__value_72817__$1$$=
(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$139$$),$on_submit$$.$cljs$core$IFn$_invoke$arity$2$?$on_submit$$.$cljs$core$IFn$_invoke$arity$2$($enter_QMARK__value_72817__$1$$,$event$jscomp$139$$):$on_submit$$($enter_QMARK__value_72817__$1$$,$event$jscomp$139$$)));return $esc_QMARK_$$?$APP.$app$util$dom$blur_BANG_$$($node$jscomp$355$$):null});return(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_components_search_bar__search-box "+($children$jscomp$270$$!=null?"main_ui_components_search_bar__has-children":
""),children:[$children$jscomp$270$$,(0,$APP.$rumext$v2$jsxs$$)("div",{className:($class$$jscomp$26$$??"")+" main_ui_components_search_bar__search-input-wrapper",children:[$APP.$cljs$core$truth_$$($icon_id$jscomp$2$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon_id$jscomp$2$$,size:"s",className:"main_ui_components_search_bar__icon"}):null,(0,$APP.$rumext$v2$jsx$$)("input",{onChange:$handle_change$$,className:"main_ui_components_search_bar__search-input",
placeholder:$placeholder$$,id:$id$jscomp$840$$,value:$value$jscomp$731$$,autoComplete:"off",ref:$input_ref$jscomp$2$$,onKeyDown:$handle_key_down$jscomp$1$$,autoFocus:$auto_focus_props_72811$$}),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",$value$jscomp$731$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_clear$$,className:"main_ui_components_search_bar__clear-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"delete-text",
size:"s"})}):null]})]})};
$APP.$app$main$ui$ds$buttons$button$button_STAR_$$=function($element$jscomp$75_props_72866$$){var $props__$1$jscomp$47_to$jscomp$25$$=void 0,$children$jscomp$271$$=void 0,$internal_class_variant$jscomp$20_variant__$1$jscomp$3$$=void 0,$on_ref$jscomp$1$$=void 0,$type$jscomp$579$$=void 0,$icon$jscomp$8$$=void 0,$class$$jscomp$27$$=void 0,$props$jscomp$237$$=void 0;({variant:$internal_class_variant$jscomp$20_variant__$1$jscomp$3$$,icon:$icon$jscomp$8$$,children:$children$jscomp$271$$,className:$class$$jscomp$27$$,
onRef:$on_ref$jscomp$1$$,to:$props__$1$jscomp$47_to$jscomp$25$$,type:$type$jscomp$579$$,...$props$jscomp$237$$}=$element$jscomp$75_props_72866$$);$internal_class_variant$jscomp$20_variant__$1$jscomp$3$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($internal_class_variant$jscomp$20_variant__$1$jscomp$3$$,"primary");$element$jscomp$75_props_72866$$=$APP.$cljs$core$truth_$$($props__$1$jscomp$47_to$jscomp$25$$)?"a":"button";$internal_class_variant$jscomp$20_variant__$1$jscomp$3$$="main_ui_ds_buttons_button__button "+
($props__$1$jscomp$47_to$jscomp$25$$!=null?"main_ui_ds_buttons_button__button-link":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($internal_class_variant$jscomp$20_variant__$1$jscomp$3$$,"primary")?"main_ui_ds_buttons_button__button-primary":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($internal_class_variant$jscomp$20_variant__$1$jscomp$3$$,"secondary")?"main_ui_ds_buttons_button__button-secondary":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($internal_class_variant$jscomp$20_variant__$1$jscomp$3$$,
"ghost")?"main_ui_ds_buttons_button__button-ghost":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($internal_class_variant$jscomp$20_variant__$1$jscomp$3$$,"destructive")?"main_ui_ds_buttons_button__button-destructive":"");$props__$1$jscomp$47_to$jscomp$25$$={...$props$jscomp$237$$,className:($class$$jscomp$27$$??"")+" "+($internal_class_variant$jscomp$20_variant__$1$jscomp$3$$??""),href:$props__$1$jscomp$47_to$jscomp$25$$,type:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$579$$,
"button"),ref:function($node$jscomp$356$$){return $APP.$cljs$core$truth_$$($on_ref$jscomp$1$$)?$on_ref$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_ref$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$356$$):$on_ref$jscomp$1$$($node$jscomp$356$$):null}};return(0,$APP.$rumext$v2$create_element$$)($element$jscomp$75_props_72866$$,$props__$1$jscomp$47_to$jscomp$25$$,$APP.$cljs$core$truth_$$($icon$jscomp$8$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon$jscomp$8$$,
size:"m"}):null,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_buttons_button__label-wrapper",children:$children$jscomp$271$$}))};
$APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$=function($props_72871$$){var $text$jscomp$64$$=void 0,$icon$jscomp$9$$=void 0,$class$$jscomp$28$$=void 0,$props$jscomp$238$$=void 0;({className:$class$$jscomp$28$$,icon:$icon$jscomp$9$$,text:$text$jscomp$64$$,...$props$jscomp$238$$}=$props_72871$$);return(0,$APP.$rumext$v2$create_element$$)("div",{...$props$jscomp$238$$,className:($class$$jscomp$28$$??"")+" main_ui_ds_product_empty_state__group"},(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_product_empty_state__icon-wrapper",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon$jscomp$9$$,size:"l",className:"main_ui_ds_product_empty_state__icon"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_product_empty_state__text",children:$text$jscomp$64$$}))};
$APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$=function($children$jscomp$272_props_73002$$){var $typography$jscomp$25$$,$props$jscomp$239$$;({level:$level$jscomp$55_or__5025__auto__$jscomp$inline_7432_tag$jscomp$88$$,typography:$typography$jscomp$25$$,className:$class$$jscomp$29_class$__$1$jscomp$2$$,children:$children$jscomp$272_props_73002$$,...$props$jscomp$239$$}=$children$jscomp$272_props_73002$$);var $level$jscomp$55_or__5025__auto__$jscomp$inline_7432_tag$jscomp$88$$="h"+
(($APP.$cljs$core$truth_$$($level$jscomp$55_or__5025__auto__$jscomp$inline_7432_tag$jscomp$88$$)?$level$jscomp$55_or__5025__auto__$jscomp$inline_7432_tag$jscomp$88$$:"1")??"");var $class$$jscomp$29_class$__$1$jscomp$2$$=""+($class$$jscomp$29_class$__$1$jscomp$2$$??"")+" "+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$25$$,"display")?"main_ui_ds_foundations_typography_heading__display-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$25$$,
"title-large")?"main_ui_ds_foundations_typography_heading__title-large-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$25$$,"title-medium")?"main_ui_ds_foundations_typography_heading__title-medium-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$25$$,"title-small")?"main_ui_ds_foundations_typography_heading__title-small-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$25$$,
"headline-large")?"main_ui_ds_foundations_typography_heading__headline-large-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$25$$,"headline-medium")?"main_ui_ds_foundations_typography_heading__headline-medium-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$25$$,"headline-small")?"main_ui_ds_foundations_typography_heading__headline-small-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$25$$,
"body-large")?"main_ui_ds_foundations_typography_heading__body-large-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$25$$,"body-medium")?"main_ui_ds_foundations_typography_heading__body-medium-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$25$$,"body-small")?"main_ui_ds_foundations_typography_heading__body-small-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$25$$,
"code-font")?"main_ui_ds_foundations_typography_heading__code-font-typography":""));return(0,$APP.$rumext$v2$create_element$$)($level$jscomp$55_or__5025__auto__$jscomp$inline_7432_tag$jscomp$88$$,{...$props$jscomp$239$$,className:$class$$jscomp$29_class$__$1$jscomp$2$$},$children$jscomp$272_props_73002$$)};
$APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$=function($children$jscomp$273_props_73041$$){var $class$$jscomp$30_or__5025__auto__$jscomp$inline_7434$$,$props$jscomp$240$$;({as:$as_as__$1$$,typography:$class$__$1$jscomp$3_typography$jscomp$26$$,children:$children$jscomp$273_props_73041$$,className:$class$$jscomp$30_or__5025__auto__$jscomp$inline_7434$$,...$props$jscomp$240$$}=$children$jscomp$273_props_73041$$);var $as_as__$1$$=$APP.$cljs$core$empty_QMARK_$$($as_as__$1$$)||$as_as__$1$$==
null?"p":$as_as__$1$$;var $class$__$1$jscomp$3_typography$jscomp$26$$=""+(($APP.$cljs$core$truth_$$($class$$jscomp$30_or__5025__auto__$jscomp$inline_7434$$)?$class$$jscomp$30_or__5025__auto__$jscomp$inline_7434$$:"")??"")+" "+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($class$__$1$jscomp$3_typography$jscomp$26$$,"display")?"main_ui_ds_foundations_typography_text__display-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($class$__$1$jscomp$3_typography$jscomp$26$$,
"title-large")?"main_ui_ds_foundations_typography_text__title-large-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($class$__$1$jscomp$3_typography$jscomp$26$$,"title-medium")?"main_ui_ds_foundations_typography_text__title-medium-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($class$__$1$jscomp$3_typography$jscomp$26$$,"title-small")?"main_ui_ds_foundations_typography_text__title-small-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($class$__$1$jscomp$3_typography$jscomp$26$$,
"headline-large")?"main_ui_ds_foundations_typography_text__headline-large-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($class$__$1$jscomp$3_typography$jscomp$26$$,"headline-medium")?"main_ui_ds_foundations_typography_text__headline-medium-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($class$__$1$jscomp$3_typography$jscomp$26$$,"headline-small")?"main_ui_ds_foundations_typography_text__headline-small-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($class$__$1$jscomp$3_typography$jscomp$26$$,
"body-large")?"main_ui_ds_foundations_typography_text__body-large-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($class$__$1$jscomp$3_typography$jscomp$26$$,"body-medium")?"main_ui_ds_foundations_typography_text__body-medium-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($class$__$1$jscomp$3_typography$jscomp$26$$,"body-small")?"main_ui_ds_foundations_typography_text__body-small-typography":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($class$__$1$jscomp$3_typography$jscomp$26$$,
"code-font")?"main_ui_ds_foundations_typography_text__code-font-typography":""));return(0,$APP.$rumext$v2$create_element$$)($as_as__$1$$,{...$props$jscomp$240$$,className:$class$__$1$jscomp$3_typography$jscomp$26$$},$children$jscomp$273_props_73041$$)};
$app$main$ui$ds$notifications$shared$notification_pill$icons_by_level$$=function($level$jscomp$56$$){switch($level$jscomp$56$$ instanceof $APP.$cljs$core$Keyword$$?$level$jscomp$56$$.$fqn$:null){case "info":return"info";case "default":return"info";case "warning":return"msg-neutral";case "error":return"delete-text";case "success":return"status-tick";default:return"info"}};
$APP.$app$main$ui$ds$notifications$shared$notification_pill$notification_pill_STAR_$$=function($appearance_props_73057$$){var $detail$jscomp$5$$=$appearance_props_73057$$.detail,$children$jscomp$274$$=$appearance_props_73057$$.children,$class$$jscomp$31_type$jscomp$580$$=$appearance_props_73057$$.type,$level$jscomp$57$$=$appearance_props_73057$$.level,$is_html_is_html__$1$$=$appearance_props_73057$$.isHtml;$appearance_props_73057$$=$appearance_props_73057$$.appearance;$class$$jscomp$31_type$jscomp$580$$=
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($appearance_props_73057$$,$APP.$cljs$cst$4984$neutral$$)?"main_ui_ds_notifications_shared_notification_pill__appearance-neutral":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($appearance_props_73057$$,$APP.$cljs$cst$4985$ghost$$)?"main_ui_ds_notifications_shared_notification_pill__appearance-ghost":"")+" "+($APP.$cljs$core$truth_$$($detail$jscomp$5$$)?"main_ui_ds_notifications_shared_notification_pill__with-detail":"")+" "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$31_type$jscomp$580$$,$APP.$cljs$cst$2349$toast$$)?"main_ui_ds_notifications_shared_notification_pill__type-toast":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$31_type$jscomp$580$$,$APP.$cljs$cst$2312$context$$)?"main_ui_ds_notifications_shared_notification_pill__type-context":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$57$$,$APP.$cljs$cst$205$default$$)?"main_ui_ds_notifications_shared_notification_pill__level-default":
"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$57$$,$APP.$cljs$cst$2343$warning$$)?"main_ui_ds_notifications_shared_notification_pill__level-warning":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$57$$,$APP.$cljs$cst$849$error$$)?"main_ui_ds_notifications_shared_notification_pill__level-error":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$57$$,$APP.$cljs$cst$2344$success$$)?"main_ui_ds_notifications_shared_notification_pill__level-success":
"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$57$$,$APP.$cljs$cst$1161$info$$)?"main_ui_ds_notifications_shared_notification_pill__level-info":"");$is_html_is_html__$1$$=$APP.$cljs$core$truth_$$($is_html_is_html__$1$$)?$is_html_is_html__$1$$:!1;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:""+($class$$jscomp$31_type$jscomp$580$$??"")+" main_ui_ds_notifications_shared_notification_pill__notification-pill",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_notifications_shared_notification_pill__error-message",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$app$main$ui$ds$notifications$shared$notification_pill$icons_by_level$$($level$jscomp$57$$),className:"main_ui_ds_notifications_shared_notification_pill__icon"}),$APP.$cljs$core$truth_$$($is_html_is_html__$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{dangerouslySetInnerHTML:{__html:$children$jscomp$274$$},className:"main_ui_ds_notifications_shared_notification_pill__context-text"}):$children$jscomp$274$$]}),
$APP.$cljs$core$truth_$$($detail$jscomp$5$$)?(0,$APP.$rumext$v2$jsxs$$)("details",{className:"main_ui_ds_notifications_shared_notification_pill__error-detail",children:[(0,$APP.$rumext$v2$jsx$$)("summary",{className:"main_ui_ds_notifications_shared_notification_pill__error-detail-summary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.notification-pill.detail")}),(0,$APP.$rumext$v2$jsx$$)("div",{dangerouslySetInnerHTML:{__html:$detail$jscomp$5$$},className:"main_ui_ds_notifications_shared_notification_pill__error-detail-content"})]}):
null]})};
$APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$=function($children$jscomp$275_props_73078$$){var $is_html$jscomp$1_or__5025__auto__$jscomp$inline_7436$$,$props$jscomp$241$$;({className:$class$$jscomp$32_class$__$1$jscomp$4$$,type:$type$jscomp$581_type__$1$jscomp$12$$,appearance:$appearance$jscomp$1_appearance__$1$$,level:$level$jscomp$58_level__$1$jscomp$1$$,isHtml:$is_html$jscomp$1_or__5025__auto__$jscomp$inline_7436$$,children:$children$jscomp$275_props_73078$$,...$props$jscomp$241$$}=
$children$jscomp$275_props_73078$$);var $class$$jscomp$32_class$__$1$jscomp$4$$=""+($class$$jscomp$32_class$__$1$jscomp$4$$??"")+" main_ui_ds_notifications_context_notification__contextual-notification "+(($APP.$cljs$core$truth_$$($is_html$jscomp$1_or__5025__auto__$jscomp$inline_7436$$)?"main_ui_ds_notifications_context_notification__contain-html":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$58_level__$1$jscomp$1$$,$APP.$cljs$cst$205$default$$)?"main_ui_ds_notifications_context_notification__level-default":
"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$58_level__$1$jscomp$1$$,$APP.$cljs$cst$2343$warning$$)?"main_ui_ds_notifications_context_notification__level-warning":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$58_level__$1$jscomp$1$$,$APP.$cljs$cst$849$error$$)?"main_ui_ds_notifications_context_notification__level-error":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$58_level__$1$jscomp$1$$,$APP.$cljs$cst$2344$success$$)?
"main_ui_ds_notifications_context_notification__level-success":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$58_level__$1$jscomp$1$$,$APP.$cljs$cst$1161$info$$)?"main_ui_ds_notifications_context_notification__level-info":""));var $level$jscomp$58_level__$1$jscomp$1$$=typeof $level$jscomp$58_level__$1$jscomp$1$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($level$jscomp$58_level__$1$jscomp$1$$):$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$58_level__$1$jscomp$1$$,
$APP.$cljs$cst$205$default$$);var $type$jscomp$581_type__$1$jscomp$12$$=typeof $type$jscomp$581_type__$1$jscomp$12$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$581_type__$1$jscomp$12$$):$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$581_type__$1$jscomp$12$$,$APP.$cljs$cst$2312$context$$);var $appearance$jscomp$1_appearance__$1$$=typeof $appearance$jscomp$1_appearance__$1$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($appearance$jscomp$1_appearance__$1$$):
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($appearance$jscomp$1_appearance__$1$$,$APP.$cljs$cst$4984$neutral$$);return(0,$APP.$rumext$v2$create_element$$)("aside",{...$props$jscomp$241$$,className:$class$$jscomp$32_class$__$1$jscomp$4$$,role:"alert","aria-live":"polite"},$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$shared$notification_pill$notification_pill_STAR_$$,{level:$level$jscomp$58_level__$1$jscomp$1$$,type:$type$jscomp$581_type__$1$jscomp$12$$,isHtml:$APP.$cljs$core$truth_$$($is_html$jscomp$1_or__5025__auto__$jscomp$inline_7436$$)?
$is_html$jscomp$1_or__5025__auto__$jscomp$inline_7436$$:!1,appearance:$appearance$jscomp$1_appearance__$1$$,children:$children$jscomp$275_props_73078$$}))};
$app$main$ui$workspace$plugins$normalize_plugin_url$$=function($plugin_url$jscomp$2$$){return $APP.$cuerdas$core$ends_with_QMARK_$$($plugin_url$jscomp$2$$,"manifest.json")?$plugin_url$jscomp$2$$:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$uri$uri$$($plugin_url$jscomp$2$$),$APP.$cljs$cst$296$path$$,function($path$jscomp$256$$){return $APP.$cuerdas$core$ends_with_QMARK_$$($path$jscomp$256$$,"/")?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$256$$),
"manifest.json"].join(""):[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$256$$),"/manifest.json"].join("")}))};$app$main$ui$workspace$plugins$icon_url$$=function($host$jscomp$10$$,$icon$jscomp$10$$){return""+($host$jscomp$10$$??"")+($APP.$cuerdas$core$ends_with_QMARK_$$($host$jscomp$10$$,"/")||$APP.$cuerdas$core$starts_with_QMARK_$$($icon$jscomp$10$$,"/")?"":"/")+($icon$jscomp$10$$??"")};
$app$main$ui$workspace$plugins$plugin_entry$$=function($host$jscomp$11_map__73109_map__73109__$1_props_73105$$){$host$jscomp$11_map__73109_map__73109__$1_props_73105$$=$APP.$rumext$v2$util$wrap_props$$($host$jscomp$11_map__73109_map__73109__$1_props_73105$$);$host$jscomp$11_map__73109_map__73109__$1_props_73105$$=$APP.$cljs$core$__destructure_map$$($host$jscomp$11_map__73109_map__73109__$1_props_73105$$);var $index$jscomp$381$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($host$jscomp$11_map__73109_map__73109__$1_props_73105$$,
$APP.$cljs$cst$1795$index$$),$manifest$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($host$jscomp$11_map__73109_map__73109__$1_props_73105$$,$cljs$cst$4987$manifest$$),$handle_open_click_user_can_edit$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($host$jscomp$11_map__73109_map__73109__$1_props_73105$$,$cljs$cst$4988$user_can_edit$$),$on_open_plugin$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($host$jscomp$11_map__73109_map__73109__$1_props_73105$$,$cljs$cst$4989$on_open_plugin$$),
$on_remove_plugin$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($host$jscomp$11_map__73109_map__73109__$1_props_73105$$,$cljs$cst$4990$on_remove_plugin$$),$handle_delete_click_is_edition_plugin_QMARK_$jscomp$1_map__73110__$1_permissions__$1$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($manifest$jscomp$2$$),$plugin_id$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_delete_click_is_edition_plugin_QMARK_$jscomp$1_map__73110__$1_permissions__$1$jscomp$1$$,$APP.$cljs$cst$1720$plugin_id$$);
$host$jscomp$11_map__73109_map__73109__$1_props_73105$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_delete_click_is_edition_plugin_QMARK_$jscomp$1_map__73110__$1_permissions__$1$jscomp$1$$,$APP.$cljs$cst$744$host$$);var $icon$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_delete_click_is_edition_plugin_QMARK_$jscomp$1_map__73110__$1_permissions__$1$jscomp$1$$,$APP.$cljs$cst$1721$icon$$),$name$jscomp$402$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_delete_click_is_edition_plugin_QMARK_$jscomp$1_map__73110__$1_permissions__$1$jscomp$1$$,
$APP.$cljs$cst$725$name$$),$description$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_delete_click_is_edition_plugin_QMARK_$jscomp$1_map__73110__$1_permissions__$1$jscomp$1$$,$APP.$cljs$cst$936$description$$),$permissions$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_delete_click_is_edition_plugin_QMARK_$jscomp$1_map__73110__$1_permissions__$1$jscomp$1$$,$APP.$cljs$cst$1722$permissions$$),$plugins_permissions_peek$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$plugins_permissions_peek$$);
$handle_delete_click_is_edition_plugin_QMARK_$jscomp$1_map__73110__$1_permissions__$1$jscomp$1$$=function(){var $or__5025__auto__$jscomp$923$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($plugins_permissions_peek$$,$plugin_id$jscomp$13$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$923$$)?$or__5025__auto__$jscomp$923$$:$permissions$jscomp$13$$}();$handle_delete_click_is_edition_plugin_QMARK_$jscomp$1_map__73110__$1_permissions__$1$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($handle_delete_click_is_edition_plugin_QMARK_$jscomp$1_map__73110__$1_permissions__$1$jscomp$1$$,
"content:write")||$APP.$cljs$core$contains_QMARK_$$($handle_delete_click_is_edition_plugin_QMARK_$jscomp$1_map__73110__$1_permissions__$1$jscomp$1$$,"library:write");var $can_open_QMARK_$$=$APP.$cljs$core$truth_$$($handle_open_click_user_can_edit$$)?$handle_open_click_user_can_edit$$:!$handle_delete_click_is_edition_plugin_QMARK_$jscomp$1_map__73110__$1_permissions__$1$jscomp$1$$;$handle_open_click_user_can_edit$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$381$$),
$APP.$rumext$v2$adapt$$($manifest$jscomp$2$$),$APP.$rumext$v2$adapt$$($on_open_plugin$$),$APP.$rumext$v2$adapt$$($can_open_QMARK_$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_open_QMARK_$$)?$on_open_plugin$$:$can_open_QMARK_$$)?$on_open_plugin$$.$cljs$core$IFn$_invoke$arity$1$?$on_open_plugin$$.$cljs$core$IFn$_invoke$arity$1$($manifest$jscomp$2$$):$on_open_plugin$$($manifest$jscomp$2$$):null});$handle_delete_click_is_edition_plugin_QMARK_$jscomp$1_map__73110__$1_permissions__$1$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$381$$),$APP.$rumext$v2$adapt$$($on_remove_plugin$$)],function(){return $APP.$cljs$core$truth_$$($on_remove_plugin$$)?$on_remove_plugin$$.$cljs$core$IFn$_invoke$arity$1$?$on_remove_plugin$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$381$$):$on_remove_plugin$$($index$jscomp$381$$):null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__plugins-list-element",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_plugins__plugin-icon",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:$icon$jscomp$11$$!=null?$app$main$ui$workspace$plugins$icon_url$$($host$jscomp$11_map__73109_map__73109__$1_props_73105$$,$icon$jscomp$11$$):(0,$APP.$app$util$avatars$generate$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$name$jscomp$402$$],null))})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__plugin-description",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_plugins__plugin-title",children:$name$jscomp$402$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__plugin-summary",children:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($description$jscomp$16$$,"")})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:"main_ui_workspace_plugins__open-button",variant:"secondary",type:"button",onClick:$handle_open_click_user_can_edit$$,title:$APP.$cljs$core$truth_$$($can_open_QMARK_$$)?
null:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.error.need-editor"),disabled:$APP.$cljs$core$not$$($can_open_QMARK_$$),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.button-open")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.remove-plugin"),onClick:$handle_delete_click_is_edition_plugin_QMARK_$jscomp$1_map__73110__$1_permissions__$1$jscomp$1$$,
icon:"delete"})]})};
$app$main$ui$workspace$plugins$plugin_management_dialog$$=function(){var $plugins_state_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$plugins$register$plugins_list$$()}),$plugins_state$$=$APP.$cljs$core$_deref$$($plugins_state_STAR_$$),$plugin_url_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$plugin_url$jscomp$3$$=$APP.$cljs$core$_deref$$($plugin_url_STAR_$$),$input_status_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$error_manifest_QMARK__input_status$$=
$APP.$cljs$core$_deref$$($input_status_STAR_$$),$error_url_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$4991$error_url$$,$error_manifest_QMARK__input_status$$);$error_manifest_QMARK__input_status$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$4992$error_manifest$$,$error_manifest_QMARK__input_status$$);var $error_QMARK_$$=$error_url_QMARK_$$||$error_manifest_QMARK__input_status$$,$on_url_change_permissions$jscomp$14$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$permissions$$),
$user_can_edit_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($on_url_change_permissions$jscomp$14$$,$APP.$cljs$cst$1596$can_edit$$),$fetching_manifest_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$on_url_change_permissions$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($value$jscomp$735$$){$APP.$cljs$core$reset_BANG_$$($input_status_STAR_$$,null);return $APP.$cljs$core$reset_BANG_$$($plugin_url_STAR_$$,$value$jscomp$735$$)});
var $on_install$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($plugins_state$$),$APP.$rumext$v2$adapt$$($plugin_url$jscomp$3$$)],function(){$APP.$cljs$core$reset_BANG_$$($fetching_manifest_QMARK_$$,!0);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($plugin$jscomp$5$$){$APP.$cljs$core$reset_BANG_$$($fetching_manifest_QMARK_$$,!1);return $APP.$cljs$core$truth_$$($plugin$jscomp$5$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"install-plugin",$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($plugin$jscomp$5$$),$APP.$cljs$cst$1975$url$$,$plugin_url$jscomp$3$$],null))),$APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4993$plugin_permissions$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3402$plugin$$,$plugin$jscomp$5$$,$APP.$cljs$cst$2479$on_accept$$,function(){$APP.$app$plugins$register$install_plugin_BANG_$$($plugin$jscomp$5$$);
return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4894$plugin_management$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)}],null)),$APP.$cljs$core$reset_BANG_$$($input_status_STAR_$$,$APP.$cljs$cst$2344$success$$),$APP.$cljs$core$reset_BANG_$$($plugin_url_STAR_$$,"")):$APP.$cljs$core$reset_BANG_$$($input_status_STAR_$$,$cljs$cst$4992$error_manifest$$)},function($err$jscomp$43$$){console.error($err$jscomp$43$$);$APP.$cljs$core$reset_BANG_$$($fetching_manifest_QMARK_$$,
!1);return $APP.$cljs$core$reset_BANG_$$($input_status_STAR_$$,$cljs$cst$4991$error_url$$)},$APP.$app$main$data$plugins$fetch_manifest$$($app$main$ui$workspace$plugins$normalize_plugin_url$$($plugin_url$jscomp$3$$)))}),$on_open_plugin$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($manifest$jscomp$3$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"start-plugin",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:plugins",$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($manifest$jscomp$3$$),$APP.$cljs$cst$744$host$$,$APP.$cljs$cst$744$host$$.$cljs$core$IFn$_invoke$arity$1$($manifest$jscomp$3$$)],null)));$APP.$app$main$data$plugins$open_plugin_BANG_$$($manifest$jscomp$3$$,$user_can_edit_QMARK_$jscomp$2$$);return $APP.$app$main$data$modal$hide_BANG_$$()}),$on_remove_plugin$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($plugins_state$$)],function($plugin$jscomp$6_plugin_index$$){var $plugins_list$$=$APP.$app$plugins$register$plugins_list$$();$plugin$jscomp$6_plugin_index$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($plugins_list$$,$plugin$jscomp$6_plugin_index$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"remove-plugin",$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($plugin$jscomp$6_plugin_index$$),$APP.$cljs$cst$744$host$$,$APP.$cljs$cst$744$host$$.$cljs$core$IFn$_invoke$arity$1$($plugin$jscomp$6_plugin_index$$)],null)));$app$main$data$plugins$close_plugin_BANG_$$($plugin$jscomp$6_plugin_index$$);$app$plugins$register$remove_plugin_BANG_$$($plugin$jscomp$6_plugin_index$$);return $APP.$cljs$core$reset_BANG_$$($plugins_state_STAR_$$,$APP.$app$plugins$register$plugins_list$$())});
return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__modal-dialog main_ui_workspace_plugins__plugin-management",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_workspace_plugins__close-btn",children:$app$main$ui$workspace$plugins$close_icon$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__modal-title",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.title")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__top-bar",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{onChange:$on_url_change_permissions$jscomp$14$$,onSubmit:$on_install$$,value:$plugin_url$jscomp$3$$,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.search-placeholder"),
className:$error_QMARK_$$?"main_ui_workspace_plugins__input-error":""}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$_deref$$($fetching_manifest_QMARK_$$),onClick:$on_install$$,className:"main_ui_workspace_plugins__primary-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.install")})]}),$error_url_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__info "+($error_QMARK_$$?"main_ui_workspace_plugins__error":""),
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.error.url")}):null,$error_manifest_QMARK__input_status$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__info "+($error_QMARK_$$?"main_ui_workspace_plugins__error":""),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.error.manifest")}):null,$APP.$cljs$core$empty_QMARK_$$($plugins_state$$)?null:$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{className:"main_ui_workspace_plugins__discover",
onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"open-plugins-list"],null)))},content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.plugins.discover",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$config$plugins_list_uri$$]))}),(0,$APP.$rumext$v2$jsx$$)("hr",
{}),$APP.$cljs$core$empty_QMARK_$$($plugins_state$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__plugins-empty",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__plugins-empty-logo",children:$APP.$app$main$ui$icons$puzzle$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__plugins-empty-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.empty-plugins")}),(0,$APP.$rumext$v2$jsxs$$)("a",
{href:$app$config$plugins_list_uri$$,target:"_blank",onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"open-plugins-list"],null)))},className:"main_ui_workspace_plugins__plugins-link",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.plugin-list-link"),$app$main$ui$icons$external_link$$]})]}):
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!1,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.installed-plugins")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__plugins-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$37$$,$manifest$jscomp$4_p__73139$$){var $idx$jscomp$99$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($manifest$jscomp$4_p__73139$$,0,null);$manifest$jscomp$4_p__73139$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($manifest$jscomp$4_p__73139$$,1,null);$out_arr__44124__auto__$jscomp$37$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$plugins$plugin_entry$$,{index:$idx$jscomp$99$$,manifest:$manifest$jscomp$4_p__73139$$,"user-can-edit":$user_can_edit_QMARK_$jscomp$2$$,"on-open-plugin":$on_open_plugin$jscomp$1$$,"on-remove-plugin":$on_remove_plugin$jscomp$1$$},
"plugin-"+($idx$jscomp$99$$??"")));return $out_arr__44124__auto__$jscomp$37$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($plugins_state$$))})]})]})]})})};
$app$main$ui$workspace$plugins$plugins_permission_list_STAR_$$=function($permissions$jscomp$15_props_73143$$){$permissions$jscomp$15_props_73143$$=$permissions$jscomp$15_props_73143$$.permissions;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__permissions-list",children:[$APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$15_props_73143$$,"content:write")?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__permissions-list-entry",children:[$app$main$ui$icons$oauth_1$$,
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_workspace_plugins__permissions-list-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.permissions.content-write")})]}):$APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$15_props_73143$$,"content:read")?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__permissions-list-entry",children:[$app$main$ui$icons$oauth_1$$,(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_workspace_plugins__permissions-list-text",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.permissions.content-read")})]}):null,$APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$15_props_73143$$,"user:read")?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__permissions-list-entry",children:[$app$main$ui$icons$oauth_2$$,(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_workspace_plugins__permissions-list-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.permissions.user-read")})]}):
null,$APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$15_props_73143$$,"library:write")?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__permissions-list-entry",children:[$app$main$ui$icons$oauth_3$$,(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_workspace_plugins__permissions-list-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.permissions.library-write")})]}):$APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$15_props_73143$$,
"library:read")?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__permissions-list-entry",children:[$app$main$ui$icons$oauth_3$$,(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_workspace_plugins__permissions-list-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.permissions.library-read")})]}):null,$APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$15_props_73143$$,"comment:write")?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__permissions-list-entry",
children:[$app$main$ui$icons$oauth_1$$,(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_workspace_plugins__permissions-list-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.permissions.comment-write")})]}):$APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$15_props_73143$$,"comment:read")?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__permissions-list-entry",children:[$app$main$ui$icons$oauth_1$$,(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_workspace_plugins__permissions-list-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.permissions.comment-read")})]}):null,$APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$15_props_73143$$,"allow:downloads")?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__permissions-list-entry",children:[$app$main$ui$icons$oauth_1$$,(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_workspace_plugins__permissions-list-text",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.permissions.allow-download")})]}):null,$APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$15_props_73143$$,"allow:localstorage")?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__permissions-list-entry",children:[$app$main$ui$icons$oauth_1$$,(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_workspace_plugins__permissions-list-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.permissions.allow-localstorage")})]}):
null,$APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$15_props_73143$$,"clipboard:write")?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__permissions-list-entry",children:[$app$main$ui$icons$oauth_1$$,(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_workspace_plugins__permissions-list-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.permissions.clipboard-write")})]}):$APP.$cljs$core$contains_QMARK_$$($permissions$jscomp$15_props_73143$$,
"clipboard:read")?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__permissions-list-entry",children:[$app$main$ui$icons$oauth_1$$,(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_workspace_plugins__permissions-list-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.permissions.clipboard-read")})]}):null]})};
$app$main$ui$workspace$plugins$plugins_permissions_dialog$$=function($map__73152_plugin$jscomp$7_props_73150$$){$map__73152_plugin$jscomp$7_props_73150$$=$APP.$rumext$v2$util$wrap_props$$($map__73152_plugin$jscomp$7_props_73150$$);var $map__73152__$1_on_close_dialog$$=$APP.$cljs$core$__destructure_map$$($map__73152_plugin$jscomp$7_props_73150$$);$map__73152_plugin$jscomp$7_props_73150$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73152__$1_on_close_dialog$$,$APP.$cljs$cst$3402$plugin$$);
var $on_accept$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73152__$1_on_close_dialog$$,$APP.$cljs$cst$2479$on_accept$$),$on_close$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73152__$1_on_close_dialog$$,$APP.$cljs$cst$4994$on_close$$),$host$jscomp$12$$=$APP.$cljs$cst$744$host$$.$cljs$core$IFn$_invoke$arity$1$($map__73152_plugin$jscomp$7_props_73150$$),$permissions$jscomp$16$$=$APP.$cljs$core$set$$($APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($map__73152_plugin$jscomp$7_props_73150$$)),
$on_accept_dialog$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_accept$jscomp$1$$)],function($event$jscomp$140$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$140$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"allow-plugin-permissions",$APP.$cljs$cst$744$host$$,$host$jscomp$12$$,
$APP.$cljs$cst$1722$permissions$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$permissions$jscomp$16$$)],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]));return $APP.$cljs$core$truth_$$($on_accept$jscomp$1$$)?$on_accept$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$on_accept$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_accept$jscomp$1$$():null});$map__73152__$1_on_close_dialog$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_close$jscomp$3$$)],
function($event$jscomp$141$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$141$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"reject-plugin-permissions",$APP.$cljs$cst$744$host$$,$host$jscomp$12$$,$APP.$cljs$cst$1722$permissions$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$permissions$jscomp$16$$)],
null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]));return $APP.$cljs$core$truth_$$($on_close$jscomp$3$$)?$on_close$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$3$$():null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_accept_dialog$$)],function(){$APP.$app$util$globals$document$$.addEventListener("keydown",$on_accept_dialog$$);
return function(){return $APP.$app$util$globals$document$$.removeEventListener("keydown",$on_accept_dialog$$)}});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__modal-dialog main_ui_workspace_plugins__plugin-permissions",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$map__73152__$1_on_close_dialog$$,className:"main_ui_workspace_plugins__close-btn",children:$app$main$ui$workspace$plugins$close_icon$$}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.plugins.permissions.title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cuerdas$core$upper$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($map__73152_plugin$jscomp$7_props_73150$$))]))}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$plugins$plugins_permission_list_STAR_$$,
{permissions:$permissions$jscomp$16$$}),$APP.$cljs$core$contains_QMARK_$$($app$config$plugins_whitelist$$,$host$jscomp$12$$)?null:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__permissions-disclaimer",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.permissions.disclaimer")})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__action-buttons",
children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-cancel"),onClick:$map__73152__$1_on_close_dialog$$,className:"main_ui_workspace_plugins__cancel-button main_ui_workspace_plugins__button-expand"}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-allow"),onClick:$on_accept_dialog$$,className:"main_ui_workspace_plugins__primary-button main_ui_workspace_plugins__button-expand"})]})})]})})};
$app$main$ui$workspace$plugins$plugins_permissions_updated_dialog$$=function($map__73167_plugin$jscomp$8_props_73165$$){$map__73167_plugin$jscomp$8_props_73165$$=$APP.$rumext$v2$util$wrap_props$$($map__73167_plugin$jscomp$8_props_73165$$);var $map__73167__$1_on_close_dialog$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($map__73167_plugin$jscomp$8_props_73165$$);$map__73167_plugin$jscomp$8_props_73165$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73167__$1_on_close_dialog$jscomp$1$$,
$APP.$cljs$cst$3402$plugin$$);var $on_accept$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73167__$1_on_close_dialog$jscomp$1$$,$APP.$cljs$cst$2479$on_accept$$),$on_close$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73167__$1_on_close_dialog$jscomp$1$$,$APP.$cljs$cst$4994$on_close$$),$host$jscomp$13$$=$APP.$cljs$cst$744$host$$.$cljs$core$IFn$_invoke$arity$1$($map__73167_plugin$jscomp$8_props_73165$$),$permissions$jscomp$17$$=$APP.$cljs$core$set$$($APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($map__73167_plugin$jscomp$8_props_73165$$)),
$on_accept_dialog$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_accept$jscomp$2$$)],function($event$jscomp$142$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$142$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"allow-plugin-permissions",$APP.$cljs$cst$744$host$$,$host$jscomp$13$$,
$APP.$cljs$cst$1722$permissions$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$permissions$jscomp$17$$)],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]));return $APP.$cljs$core$truth_$$($on_accept$jscomp$2$$)?$on_accept$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_accept$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_accept$jscomp$2$$():null});$map__73167__$1_on_close_dialog$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_close$jscomp$4$$)],
function($event$jscomp$143$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$143$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"reject-plugin-permissions",$APP.$cljs$cst$744$host$$,$host$jscomp$13$$,$APP.$cljs$cst$1722$permissions$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$permissions$jscomp$17$$)],
null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]));return $APP.$cljs$core$truth_$$($on_close$jscomp$4$$)?$on_close$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$4$$():null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_accept_dialog$jscomp$1$$)],function(){$APP.$app$util$globals$document$$.addEventListener("keydown",$on_accept_dialog$jscomp$1$$);
return function(){return $APP.$app$util$globals$document$$.removeEventListener("keydown",$on_accept_dialog$jscomp$1$$)}});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__modal-dialog main_ui_workspace_plugins__plugin-permissions",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$map__73167__$1_on_close_dialog$jscomp$1$$,className:"main_ui_workspace_plugins__close-btn",
children:$app$main$ui$workspace$plugins$close_icon$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.plugins.permissions-update.title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cuerdas$core$upper$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($map__73167_plugin$jscomp$8_props_73165$$))]))}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__modal-content",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__modal-paragraph",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.permissions-update.warning")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$plugins$plugins_permission_list_STAR_$$,{permissions:$permissions$jscomp$17$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__action-buttons",
children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-cancel"),onClick:$map__73167__$1_on_close_dialog$jscomp$1$$,className:"main_ui_workspace_plugins__cancel-button main_ui_workspace_plugins__button-expand"}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-allow"),onClick:$on_accept_dialog$jscomp$1$$,className:"main_ui_workspace_plugins__primary-button main_ui_workspace_plugins__button-expand"})]})})]})})};
$app$main$ui$workspace$plugins$plugins_try_out_dialog$$=function($map__73180_plugin$jscomp$9_props_73175$$){$map__73180_plugin$jscomp$9_props_73175$$=$APP.$rumext$v2$util$wrap_props$$($map__73180_plugin$jscomp$9_props_73175$$);var $icon$jscomp$12_map__73180__$1$$=$APP.$cljs$core$__destructure_map$$($map__73180_plugin$jscomp$9_props_73175$$);$map__73180_plugin$jscomp$9_props_73175$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($icon$jscomp$12_map__73180__$1$$,$APP.$cljs$cst$3402$plugin$$);
var $on_accept$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($icon$jscomp$12_map__73180__$1$$,$APP.$cljs$cst$2479$on_accept$$),$on_close$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($icon$jscomp$12_map__73180__$1$$,$APP.$cljs$cst$4994$on_close$$),$map__73181__$1_name$jscomp$403$$=$APP.$cljs$core$__destructure_map$$($map__73180_plugin$jscomp$9_props_73175$$);$icon$jscomp$12_map__73180__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73181__$1_name$jscomp$403$$,
$APP.$cljs$cst$1721$icon$$);var $host$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73181__$1_name$jscomp$403$$,$APP.$cljs$cst$744$host$$);$map__73181__$1_name$jscomp$403$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73181__$1_name$jscomp$403$$,$APP.$cljs$cst$725$name$$);var $on_accept_dialog$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_accept$jscomp$3$$)],function($event$jscomp$144$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$144$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"try-out-accept"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]));return $APP.$cljs$core$truth_$$($on_accept$jscomp$3$$)?$on_accept$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_accept$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():
$on_accept$jscomp$3$$():null}),$on_close_dialog$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_close$jscomp$5$$)],function($event$jscomp$145$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$145$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"try-out-cancel"],null)),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]));return $APP.$cljs$core$truth_$$($on_close$jscomp$5$$)?$on_close$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$5$$():null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_accept_dialog$jscomp$2$$)],function(){$APP.$app$util$globals$document$$.addEventListener("keydown",$on_accept_dialog$jscomp$2$$);
return function(){return $APP.$app$util$globals$document$$.removeEventListener("keydown",$on_accept_dialog$jscomp$2$$)}});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__modal-dialog main_ui_workspace_plugins__plugin-try-out",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_close_dialog$jscomp$2$$,className:"main_ui_workspace_plugins__close-btn",children:$app$main$ui$workspace$plugins$close_icon$$}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__modal-title",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__plugin-icon",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:$icon$jscomp$12_map__73180__$1$$!=null?$app$main$ui$workspace$plugins$icon_url$$($host$jscomp$14$$,$icon$jscomp$12_map__73180__$1$$):(0,$APP.$app$util$avatars$generate$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$map__73181__$1_name$jscomp$403$$],
null))})}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.plugins.try-out.title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cuerdas$core$upper$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($map__73180_plugin$jscomp$9_props_73175$$))]))]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__modal-content",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__modal-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.try-out.message")})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_plugins__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_plugins__action-buttons",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.try-out.cancel"),onClick:$on_close_dialog$jscomp$2$$,className:"main_ui_workspace_plugins__cancel-button main_ui_workspace_plugins__button-expand"}),(0,$APP.$rumext$v2$jsx$$)("input",
{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.try-out.try"),onClick:$on_accept_dialog$jscomp$2$$,className:"main_ui_workspace_plugins__primary-button main_ui_workspace_plugins__button-expand"})]})})]})})};
$app$main$ui$comments$parse_urls$$=function($element$jscomp$76_parts$jscomp$22$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($element$jscomp$76_parts$jscomp$22$$),$APP.$cljs$cst$1588$text$$)){var $text$jscomp$65_urls$jscomp$3$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($element$jscomp$76_parts$jscomp$22$$);$element$jscomp$76_parts$jscomp$22$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($text$jscomp$65_urls$jscomp$3$$,
$app$main$ui$comments$r_url_split$$);$text$jscomp$65_urls$jscomp$3$$=$APP.$cljs$core$re_seq$$($app$main$ui$comments$r_url_split$$,$text$jscomp$65_urls$jscomp$3$$);return $app$common$data$interleave_all$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73103_SHARP_$$){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1637$content$$],[$APP.$cljs$cst$1588$text$$,$p1__73103_SHARP_$$])},$element$jscomp$76_parts$jscomp$22$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73104_SHARP_$$){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1637$content$$],[$APP.$cljs$cst$1975$url$$,$p1__73104_SHARP_$$])},$text$jscomp$65_urls$jscomp$3$$))}return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$element$jscomp$76_parts$jscomp$22$$],null)};
$app$main$ui$comments$parse_comment$$=function($comment$jscomp$11$$){return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$main$ui$comments$parse_urls$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$data$interleave_all$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73115_SHARP_$$){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1637$content$$],
[$APP.$cljs$cst$1588$text$$,$p1__73115_SHARP_$$])},$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($comment$jscomp$11$$,$app$main$ui$comments$r_mentions_split$$)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$841_p__73119$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$841_p__73119$$,0,null);var $user$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$841_p__73119$$,1,null);$id$jscomp$841_p__73119$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$841_p__73119$$,
2,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$4996$mention$$,$APP.$cljs$cst$1637$content$$,$user$jscomp$6$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$id$jscomp$841_p__73119$$],null)],null)},$APP.$cljs$core$re_seq$$($app$main$ui$comments$r_mentions$$,$comment$jscomp$11$$)))]))};
$app$main$ui$comments$parse_nodes$$=function($node$jscomp$357$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($node__$1$jscomp$73$$){var $JSCompiler_inline_result$jscomp$1342_and__5023__auto__$jscomp$inline_7438$$=($JSCompiler_inline_result$jscomp$1342_and__5023__auto__$jscomp$inline_7438$$=$node__$1$jscomp$73$$ instanceof HTMLElement)?$APP.$app$util$dom$get_data$$($node__$1$jscomp$73$$,"user-id"):$JSCompiler_inline_result$jscomp$1342_and__5023__auto__$jscomp$inline_7438$$;
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1342_and__5023__auto__$jscomp$inline_7438$$)?"@["+($node__$1$jscomp$73$$.textContent??"")+"]("+($APP.$app$util$dom$get_data$$($node__$1$jscomp$73$$,"user-id")??"")+")":$node__$1$jscomp$73$$.textContent},$node$jscomp$357$$!=null?$node$jscomp$357$$.children:null))};
$app$main$ui$comments$create_text_node$cljs$0core$0IFn$0_invoke$0arity$01$$=function($text$jscomp$66$$){return $app$util$dom$set_html_BANG_$$($APP.$app$util$dom$set_data_BANG_$$($APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("span"),"type","text"),$APP.$cljs$core$empty_QMARK_$$($text$jscomp$66$$)?"​":$app$util$dom$escape_html$$($text$jscomp$66$$))};
$app$main$ui$comments$create_mention_node$$=function($id$jscomp$842$$,$fullname$jscomp$1$$){return $APP.$app$util$object$set_BANG_$$($APP.$app$util$dom$set_data_BANG_$$($APP.$app$util$dom$set_data_BANG_$$($APP.$app$util$dom$set_data_BANG_$$($APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("span"),"type","mention"),"user-id",""+($id$jscomp$842$$??"")),"fullname",$fullname$jscomp$1$$),"textContent",$fullname$jscomp$1$$)};
$app$main$ui$comments$current_text_node_STAR_$$=function($node$jscomp$358$$,$anchor_node_span_node$$){return $APP.$cljs$core$truth_$$($node$jscomp$358$$.contains($anchor_node_span_node$$))?($anchor_node_span_node$$=$anchor_node_span_node$$ instanceof Text?$APP.$app$util$dom$get_parent$$($anchor_node_span_node$$):$anchor_node_span_node$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$358$$,$APP.$app$util$dom$get_parent$$($anchor_node_span_node$$))?$anchor_node_span_node$$:null):
null};
$app$main$ui$comments$current_text_node$$=function($node$jscomp$359_span_node$jscomp$1$$){var $offset$jscomp$190_temp__5825__auto__$jscomp$260$$=$app$util$webapi$get_selection$$();if($APP.$cljs$core$truth_$$($offset$jscomp$190_temp__5825__auto__$jscomp$260$$)){var $range$jscomp$14$$=$offset$jscomp$190_temp__5825__auto__$jscomp$260$$.getRangeAt(0);$offset$jscomp$190_temp__5825__auto__$jscomp$260$$=$APP.$cljs$core$truth_$$($range$jscomp$14$$)?$range$jscomp$14$$.startOffset:null;$node$jscomp$359_span_node$jscomp$1$$=$app$main$ui$comments$current_text_node_STAR_$$($node$jscomp$359_span_node$jscomp$1$$,
$APP.$cljs$core$truth_$$($range$jscomp$14$$)?$range$jscomp$14$$.startContainer:null);return $APP.$cljs$core$truth_$$($node$jscomp$359_span_node$jscomp$1$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$node$jscomp$359_span_node$jscomp$1$$,$offset$jscomp$190_temp__5825__auto__$jscomp$260$$],null):null}return null};
$app$main$ui$comments$absolute_offset$$=function($G__73441_node$jscomp$360_nodes$jscomp$33$$,$child$jscomp$121$$,$offset$jscomp$191$$){$G__73441_node$jscomp$360_nodes$jscomp$33$$=$APP.$cljs$core$seq$$($G__73441_node$jscomp$360_nodes$jscomp$33$$!=null?$G__73441_node$jscomp$360_nodes$jscomp$33$$.children:null);for(var $G__73442_acc$jscomp$145$$=0;;){var $head$jscomp$23_temp__5823__auto__$jscomp$201$$=$APP.$cljs$core$first$$($G__73441_node$jscomp$360_nodes$jscomp$33$$);if($APP.$cljs$core$truth_$$($head$jscomp$23_temp__5823__auto__$jscomp$201$$)){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($head$jscomp$23_temp__5823__auto__$jscomp$201$$,
$child$jscomp$121$$))return $G__73442_acc$jscomp$145$$+$offset$jscomp$191$$;$G__73441_node$jscomp$360_nodes$jscomp$33$$=$APP.$cljs$core$rest$$($G__73441_node$jscomp$360_nodes$jscomp$33$$);$G__73442_acc$jscomp$145$$+=$head$jscomp$23_temp__5823__auto__$jscomp$201$$.textContent.length}else return null}};
$app$main$ui$comments$get_prev_node$$=function($parent$jscomp$290$$,$node$jscomp$361$$){return $APP.$cljs$core$second$$($APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__73153$$){var $it$jscomp$274$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73153$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73153$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$361$$,$it$jscomp$274$$)},$APP.$app$common$data$with_prev$$($parent$jscomp$290$$!=
null?$parent$jscomp$290$$.children:null)))};
$app$main$ui$comments$blank_content_QMARK_$$=function($content$jscomp$228_content__$1$jscomp$41$$){$content$jscomp$228_content__$1$jscomp$41$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$228_content__$1$jscomp$41$$);return $APP.$cuerdas$core$blank_QMARK_$$($content$jscomp$228_content__$1$jscomp$41$$)||$APP.$cuerdas$core$empty_QMARK_$$($content$jscomp$228_content__$1$jscomp$41$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($content$jscomp$228_content__$1$jscomp$41$$),1)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($content$jscomp$228_content__$1$jscomp$41$$),"​")};
$app$main$ui$comments$comment_content_STAR_$$=function($comment_elements_props_73160$$){var $content$jscomp$229$$=$comment_elements_props_73160$$.content;$comment_elements_props_73160$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($content$jscomp$229$$)],function(){return $app$main$ui$comments$parse_comment$$($content$jscomp$229$$)});return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$38$$,$map__73171_p__73166_type$jscomp$582$$){var $idx$jscomp$100$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__73171_p__73166_type$jscomp$582$$,0,null);$map__73171_p__73166_type$jscomp$582$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__73171_p__73166_type$jscomp$582$$,1,null);var $content__$1$jscomp$42_map__73171__$1$$=$APP.$cljs$core$__destructure_map$$($map__73171_p__73166_type$jscomp$582$$);$map__73171_p__73166_type$jscomp$582$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content__$1$jscomp$42_map__73171__$1$$,$APP.$cljs$cst$139$type$$);
$content__$1$jscomp$42_map__73171__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content__$1$jscomp$42_map__73171__$1$$,$APP.$cljs$cst$1637$content$$);$out_arr__44124__auto__$jscomp$38$$.push($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__73171_p__73166_type$jscomp$582$$,$APP.$cljs$cst$1975$url$$)?(0,$APP.$rumext$v2$jsx$$)("a",{href:$content__$1$jscomp$42_map__73171__$1$$,target:"_blank",rel:"noopener noreferrer",className:"main_ui_comments__comment-link",children:$content__$1$jscomp$42_map__73171__$1$$},
$idx$jscomp$100$$):(0,$APP.$rumext$v2$jsx$$)("span",{className:($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__73171_p__73166_type$jscomp$582$$,$APP.$cljs$cst$1588$text$$)?"main_ui_comments__comment-text":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__73171_p__73166_type$jscomp$582$$,$cljs$cst$4996$mention$$)?"main_ui_comments__comment-mention":""),children:$content__$1$jscomp$42_map__73171__$1$$},$idx$jscomp$100$$));return $out_arr__44124__auto__$jscomp$38$$},
[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($comment_elements_props_73160$$))};
$app$main$ui$comments$comment_input_STAR_$$=function($init_input_props_73179$$){var $on_ctrl_enter$$=$init_input_props_73179$$.onCtrlEnter,$on_change$jscomp$14$$=$init_input_props_73179$$.onChange,$placeholder$jscomp$1$$=$init_input_props_73179$$.placeholder,$on_focus$$=$init_input_props_73179$$.onFocus,$on_esc$$=$init_input_props_73179$$.onEsc,$on_blur$$=$init_input_props_73179$$.onBlur,$autofocus$$=$init_input_props_73179$$.autofocus,$value__$1$jscomp$28$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($init_input_props_73179$$.value,
""),$prev_value$$=$APP.$app$main$ui$hooks$use_previous$$($value__$1$jscomp$28$$),$local_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$mentions_s$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$comments$mentions_context$$),$cur_mention$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$prev_selection_ref$$=(0,$APP.$rumext$v2$use_ref$$)();$init_input_props_73179$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$362$$){$APP.$rumext$v2$set_ref_val_BANG_$$($local_ref$$,
$node$jscomp$362$$);if($APP.$cljs$core$truth_$$($node$jscomp$362$$))for(var $G__73450_seq__73182_seq__73182__$1_temp__5825__auto__$jscomp$261$$=$APP.$cljs$core$seq$$($app$main$ui$comments$parse_comment$$($value__$1$jscomp$28$$)),$G__73198_73454_c__5548__auto__$jscomp$21_chunk__73183_map__73197__$1$$=null,$G__73452_count__73184$$=0,$i__73185$$=0;;)if($i__73185$$<$G__73452_count__73184$$){var $G__73451_content$jscomp$230_map__73195_map__73197$$=$G__73198_73454_c__5548__auto__$jscomp$21_chunk__73183_map__73197__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$i__73185$$),$data$jscomp$432_map__73195__$1$$=$APP.$cljs$core$__destructure_map$$($G__73451_content$jscomp$230_map__73195_map__73197$$),$G__73196_73443_type$jscomp$583$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$432_map__73195__$1$$,$APP.$cljs$cst$139$type$$);$G__73451_content$jscomp$230_map__73195_map__73197$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$432_map__73195__$1$$,$APP.$cljs$cst$1637$content$$);$data$jscomp$432_map__73195__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$432_map__73195__$1$$,
$APP.$cljs$cst$142$data$$);switch($G__73196_73443_type$jscomp$583$$ instanceof $APP.$cljs$core$Keyword$$?$G__73196_73443_type$jscomp$583$$.$fqn$:null){case "text":$APP.$app$util$dom$append_child_BANG_$$($node$jscomp$362$$,$app$main$ui$comments$create_text_node$cljs$0core$0IFn$0_invoke$0arity$01$$($G__73451_content$jscomp$230_map__73195_map__73197$$));break;case "url":$APP.$app$util$dom$append_child_BANG_$$($node$jscomp$362$$,$app$main$ui$comments$create_text_node$cljs$0core$0IFn$0_invoke$0arity$01$$($G__73451_content$jscomp$230_map__73195_map__73197$$));
break;case "mention":$APP.$app$util$dom$append_child_BANG_$$($node$jscomp$362$$,$app$main$ui$comments$create_mention_node$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$432_map__73195__$1$$),$G__73451_content$jscomp$230_map__73195_map__73197$$))}$i__73185$$+=1}else if($G__73450_seq__73182_seq__73182__$1_temp__5825__auto__$jscomp$261$$=$APP.$cljs$core$seq$$($G__73450_seq__73182_seq__73182__$1_temp__5825__auto__$jscomp$261$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($G__73450_seq__73182_seq__73182__$1_temp__5825__auto__$jscomp$261$$))$G__73198_73454_c__5548__auto__$jscomp$21_chunk__73183_map__73197__$1$$=
$APP.$cljs$core$_chunked_first$$($G__73450_seq__73182_seq__73182__$1_temp__5825__auto__$jscomp$261$$),$G__73450_seq__73182_seq__73182__$1_temp__5825__auto__$jscomp$261$$=$APP.$cljs$core$_chunked_rest$$($G__73450_seq__73182_seq__73182__$1_temp__5825__auto__$jscomp$261$$),$G__73451_content$jscomp$230_map__73195_map__73197$$=$G__73198_73454_c__5548__auto__$jscomp$21_chunk__73183_map__73197__$1$$,$G__73452_count__73184$$=$APP.$cljs$core$count$$($G__73198_73454_c__5548__auto__$jscomp$21_chunk__73183_map__73197__$1$$),
$G__73198_73454_c__5548__auto__$jscomp$21_chunk__73183_map__73197__$1$$=$G__73451_content$jscomp$230_map__73195_map__73197$$;else{$G__73451_content$jscomp$230_map__73195_map__73197$$=$APP.$cljs$core$first$$($G__73450_seq__73182_seq__73182__$1_temp__5825__auto__$jscomp$261$$);$G__73198_73454_c__5548__auto__$jscomp$21_chunk__73183_map__73197__$1$$=$APP.$cljs$core$__destructure_map$$($G__73451_content$jscomp$230_map__73195_map__73197$$);$G__73196_73443_type$jscomp$583$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__73198_73454_c__5548__auto__$jscomp$21_chunk__73183_map__73197__$1$$,
$APP.$cljs$cst$139$type$$);$G__73451_content$jscomp$230_map__73195_map__73197$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__73198_73454_c__5548__auto__$jscomp$21_chunk__73183_map__73197__$1$$,$APP.$cljs$cst$1637$content$$);$data$jscomp$432_map__73195__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__73198_73454_c__5548__auto__$jscomp$21_chunk__73183_map__73197__$1$$,$APP.$cljs$cst$142$data$$);$G__73198_73454_c__5548__auto__$jscomp$21_chunk__73183_map__73197__$1$$=$G__73196_73443_type$jscomp$583$$;
switch($G__73198_73454_c__5548__auto__$jscomp$21_chunk__73183_map__73197__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__73198_73454_c__5548__auto__$jscomp$21_chunk__73183_map__73197__$1$$.$fqn$:null){case "text":$APP.$app$util$dom$append_child_BANG_$$($node$jscomp$362$$,$app$main$ui$comments$create_text_node$cljs$0core$0IFn$0_invoke$0arity$01$$($G__73451_content$jscomp$230_map__73195_map__73197$$));break;case "url":$APP.$app$util$dom$append_child_BANG_$$($node$jscomp$362$$,$app$main$ui$comments$create_text_node$cljs$0core$0IFn$0_invoke$0arity$01$$($G__73451_content$jscomp$230_map__73195_map__73197$$));
break;case "mention":$APP.$app$util$dom$append_child_BANG_$$($node$jscomp$362$$,$app$main$ui$comments$create_mention_node$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$432_map__73195__$1$$),$G__73451_content$jscomp$230_map__73195_map__73197$$))}$G__73450_seq__73182_seq__73182__$1_temp__5825__auto__$jscomp$261$$=$APP.$cljs$core$next$$($G__73450_seq__73182_seq__73182__$1_temp__5825__auto__$jscomp$261$$);$G__73198_73454_c__5548__auto__$jscomp$21_chunk__73183_map__73197__$1$$=
null;$G__73452_count__73184$$=0}$i__73185$$=0}else return null;else return null});var $handle_input$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$14$$)],function(){for(var $new_input_node$jscomp$363$$=$APP.$rumext$v2$ref_val$$($local_ref$$),$children$jscomp$276$$=$new_input_node$jscomp$363$$!=null?$new_input_node$jscomp$363$$.children:null,$c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$=$APP.$cljs$core$seq$$($children$jscomp$276$$),
$G__73474_chunk__73200_73462_seq__73199_73471__$1$$=null,$G__73475_count__73201_73463$$=0,$G__73473_i__73202_73464$$=0;;)if($G__73473_i__73202_73464$$<$G__73475_count__73201_73463$$){var $child_node_73465$$=$G__73474_chunk__73200_73462_seq__73199_73471__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__73473_i__73202_73464$$);$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($child_node_73465$$.tagName,"SPAN")&&$child_node_73465$$.remove();$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_data$$($child_node_73465$$,
"type"),"text")&&$APP.$cljs$core$empty_QMARK_$$($APP.$app$util$dom$get_text$$($child_node_73465$$))&&$app$util$dom$set_html_BANG_$$($child_node_73465$$,"​");$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_data$$($child_node_73465$$,"type"),"mention")&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_data$$($child_node_73465$$,"fullname"),$APP.$app$util$dom$get_text$$($child_node_73465$$))&&$child_node_73465$$.remove();$G__73473_i__73202_73464$$+=
1}else if($c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$=$APP.$cljs$core$seq$$($c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$))$G__73474_chunk__73200_73462_seq__73199_73471__$1$$=$c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__73474_chunk__73200_73462_seq__73199_73471__$1$$)?($c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$=
$APP.$cljs$core$_chunked_first$$($G__73474_chunk__73200_73462_seq__73199_73471__$1$$),$G__73473_i__73202_73464$$=$APP.$cljs$core$_chunked_rest$$($G__73474_chunk__73200_73462_seq__73199_73471__$1$$),$G__73474_chunk__73200_73462_seq__73199_73471__$1$$=$c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$,$G__73475_count__73201_73463$$=$APP.$cljs$core$count$$($c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$),$c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$=
$G__73473_i__73202_73464$$):($c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$=$APP.$cljs$core$first$$($G__73474_chunk__73200_73462_seq__73199_73471__$1$$),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$.tagName,"SPAN")&&$c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$.remove(),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_data$$($c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$,
"type"),"text")&&$APP.$cljs$core$empty_QMARK_$$($APP.$app$util$dom$get_text$$($c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$))&&$app$util$dom$set_html_BANG_$$($c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$,"​"),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_data$$($c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$,"type"),"mention")&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_data$$($c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$,
"fullname"),$APP.$app$util$dom$get_text$$($c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$))&&$c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$.remove(),$c__5548__auto___73472_child_node_73477_seq__73199_73461_temp__5825__auto___73470$$=$APP.$cljs$core$next$$($G__73474_chunk__73200_73462_seq__73199_73471__$1$$),$G__73474_chunk__73200_73462_seq__73199_73471__$1$$=null,$G__73475_count__73201_73463$$=0),$G__73473_i__73202_73464$$=0;
else break;$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$children$jscomp$276$$.length)&&$APP.$app$util$dom$append_child_BANG_$$($new_input_node$jscomp$363$$,$app$main$ui$comments$create_text_node$cljs$0core$0IFn$0_invoke$0arity$01$$(""));$new_input_node$jscomp$363$$=$app$main$ui$comments$parse_nodes$$($new_input_node$jscomp$363$$);return $APP.$cljs$core$truth_$$($on_change$jscomp$14$$)?$on_change$jscomp$14$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$14$$.$cljs$core$IFn$_invoke$arity$1$($new_input_node$jscomp$363$$):
$on_change$jscomp$14$$($new_input_node$jscomp$363$$):null}),$handle_select$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $temp__5825__auto__$jscomp$262$$=$APP.$rumext$v2$ref_val$$($local_ref$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$262$$)){var $mention_offset$jscomp$192_temp__5825__auto____$1$jscomp$16_to_offset_73483$$=$app$util$webapi$get_selection$$();if($APP.$cljs$core$truth_$$($mention_offset$jscomp$192_temp__5825__auto____$1$jscomp$16_to_offset_73483$$)){var $range$jscomp$15$$=
$mention_offset$jscomp$192_temp__5825__auto____$1$jscomp$16_to_offset_73483$$.getRangeAt(0),$anchor_node$jscomp$2$$=$APP.$cljs$core$truth_$$($range$jscomp$15$$)?$range$jscomp$15$$.startContainer:null;$mention_offset$jscomp$192_temp__5825__auto____$1$jscomp$16_to_offset_73483$$=$APP.$cljs$core$truth_$$($range$jscomp$15$$)?$range$jscomp$15$$.startOffset:null;$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$591$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($temp__5825__auto__$jscomp$262$$,
$anchor_node$jscomp$2$$);return $and__5023__auto__$jscomp$591$$?$range$jscomp$15$$.collapsed:$and__5023__auto__$jscomp$591$$}())&&$app$util$webapi$set_cursor_after_BANG_$$($anchor_node$jscomp$2$$);var $temp__5825__auto____$2$jscomp$1$$=$app$main$ui$comments$current_text_node_STAR_$$($temp__5825__auto__$jscomp$262$$,$anchor_node$jscomp$2$$);if($APP.$cljs$core$truth_$$($temp__5825__auto____$2$jscomp$1$$)){var $prev_73486_prev_offset$jscomp$1_vec__73218$$=$APP.$rumext$v2$ref_val$$($prev_selection_ref$$),
$from_offset_73482_prev_span$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($prev_73486_prev_offset$jscomp$1_vec__73218$$,0,null);$prev_73486_prev_offset$jscomp$1_vec__73218$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($prev_73486_prev_offset$jscomp$1_vec__73218$$,1,null);var $next_73487_node_text_vec__73222_73484$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$dom$get_text$$($temp__5825__auto____$2$jscomp$1$$),0,$mention_offset$jscomp$192_temp__5825__auto____$1$jscomp$16_to_offset_73483$$),
$current_at_symbol$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($next_73487_node_text_vec__73222_73484$$,0,$mention_offset$jscomp$192_temp__5825__auto____$1$jscomp$16_to_offset_73483$$),"@"),$mention_text$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($next_73487_node_text_vec__73222_73484$$,$current_at_symbol$$),$at_symbol_inside_word_QMARK_$$=$current_at_symbol$$>0&&$cuerdas$core$word_QMARK_$$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($next_73487_node_text_vec__73222_73484$$,
$current_at_symbol$$-1,$current_at_symbol$$));$APP.$rumext$v2$set_ref_val_BANG_$$($prev_selection_ref$$,[$temp__5825__auto____$2$jscomp$1$$,$mention_offset$jscomp$192_temp__5825__auto____$1$jscomp$16_to_offset_73483$$]);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_data$$($temp__5825__auto____$2$jscomp$1$$,"type"),"mention")&&($from_offset_73482_prev_span$$=$app$main$ui$comments$absolute_offset$$($temp__5825__auto__$jscomp$262$$,$from_offset_73482_prev_span$$,$prev_73486_prev_offset$jscomp$1_vec__73218$$),
$mention_offset$jscomp$192_temp__5825__auto____$1$jscomp$16_to_offset_73483$$=$app$main$ui$comments$absolute_offset$$($temp__5825__auto__$jscomp$262$$,$temp__5825__auto____$2$jscomp$1$$,$mention_offset$jscomp$192_temp__5825__auto____$1$jscomp$16_to_offset_73483$$),$next_73487_node_text_vec__73222_73484$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__73225$$){var $elem$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73225$$,0,
null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73225$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73225$$,2,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($elem$jscomp$8$$,$temp__5825__auto____$2$jscomp$1$$)},$app$common$data$with_prev_next$$($app$util$dom$seq_nodes$$($temp__5825__auto__$jscomp$262$$)))),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($next_73487_node_text_vec__73222_73484$$,0,null),$prev_73486_prev_offset$jscomp$1_vec__73218$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($next_73487_node_text_vec__73222_73484$$,1,null),$next_73487_node_text_vec__73222_73484$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($next_73487_node_text_vec__73222_73484$$,2,null),$from_offset_73482_prev_span$$>$mention_offset$jscomp$192_temp__5825__auto____$1$jscomp$16_to_offset_73483$$?$app$util$webapi$set_cursor_after_BANG_$$($prev_73486_prev_offset$jscomp$1_vec__73218$$):$app$util$webapi$set_cursor_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($next_73487_node_text_vec__73222_73484$$,
1));if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$592$$=!$at_symbol_inside_word_QMARK_$$;return $and__5023__auto__$jscomp$592$$?$APP.$cljs$core$re_matches$$(/@\w*/,$mention_text$$):$and__5023__auto__$jscomp$592$$}()))return $APP.$cljs$core$reset_BANG_$$($cur_mention$$,$mention_text$$),$mentions_s$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$4997$display_mentions$$],null)),$mention_offset$jscomp$192_temp__5825__auto____$1$jscomp$16_to_offset_73483$$=
$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($mention_text$$,1),$APP.$app$common$data$not_empty_QMARK_$$($mention_offset$jscomp$192_temp__5825__auto____$1$jscomp$16_to_offset_73483$$)?$mentions_s$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$4998$filter_mentions$$,$APP.$cljs$cst$142$data$$,$mention_offset$jscomp$192_temp__5825__auto____$1$jscomp$16_to_offset_73483$$],null)):null;$APP.$cljs$core$reset_BANG_$$($cur_mention$$,null);return $mentions_s$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$4999$hide_mentions$$],null))}}}return null}),$handle_focus$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$146$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$146$$);$APP.$app$util$dom$set_css_property_BANG_$$($APP.$rumext$v2$ref_val$$($local_ref$$),"--placeholder","");return $APP.$cljs$core$truth_$$($on_focus$$)?$on_focus$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$146$$):
$on_focus$$($event$jscomp$146$$):null}),$handle_blur$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value__$1$jscomp$28$$)],function($event$jscomp$147$$){$APP.$cljs$core$empty_QMARK_$$($value__$1$jscomp$28$$)&&$APP.$app$util$dom$set_css_property_BANG_$$($APP.$rumext$v2$ref_val$$($local_ref$$),"--placeholder",'"'+($placeholder$jscomp$1$$??"")+'"');return $APP.$cljs$core$truth_$$($on_blur$$)?$on_blur$$.$cljs$core$IFn$_invoke$arity$1$?$on_blur$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$147$$):
$on_blur$$($event$jscomp$147$$):null}),$handle_insert_mention$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$14$$)],function($data$jscomp$433_mention_span$$){var $G__73243_temp__5825__auto__$jscomp$263$$=$APP.$rumext$v2$ref_val$$($local_ref$$);if($APP.$cljs$core$truth_$$($G__73243_temp__5825__auto__$jscomp$263$$)){var $offset$jscomp$193_prefix$jscomp$64_temp__5825__auto____$1$jscomp$17$$=$app$main$ui$comments$current_text_node$$($G__73243_temp__5825__auto__$jscomp$263$$);
if($APP.$cljs$core$truth_$$($offset$jscomp$193_prefix$jscomp$64_temp__5825__auto____$1$jscomp$17$$)){var $span_node$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offset$jscomp$193_prefix$jscomp$64_temp__5825__auto____$1$jscomp$17$$,0,null);$offset$jscomp$193_prefix$jscomp$64_temp__5825__auto____$1$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offset$jscomp$193_prefix$jscomp$64_temp__5825__auto____$1$jscomp$17$$,1,null);var $after_span_node_text$jscomp$1_suffix$jscomp$27$$=
$APP.$app$util$dom$get_text$$($span_node$jscomp$3$$);var $current_at_symbol$jscomp$1_or__5025__auto__$jscomp$inline_7442_sel$jscomp$5$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($after_span_node_text$jscomp$1_suffix$jscomp$27$$,0,$offset$jscomp$193_prefix$jscomp$64_temp__5825__auto____$1$jscomp$17$$),"@");$current_at_symbol$jscomp$1_or__5025__auto__$jscomp$inline_7442_sel$jscomp$5$$=$APP.$cljs$core$truth_$$($current_at_symbol$jscomp$1_or__5025__auto__$jscomp$inline_7442_sel$jscomp$5$$)?
$current_at_symbol$jscomp$1_or__5025__auto__$jscomp$inline_7442_sel$jscomp$5$$:$app$main$ui$comments$absolute_offset$$($G__73243_temp__5825__auto__$jscomp$263$$,$span_node$jscomp$3$$,$offset$jscomp$193_prefix$jscomp$64_temp__5825__auto____$1$jscomp$17$$);var $mention$jscomp$1$$=$APP.$cljs$core$re_find$$(/@\w*/,$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($after_span_node_text$jscomp$1_suffix$jscomp$27$$,$current_at_symbol$jscomp$1_or__5025__auto__$jscomp$inline_7442_sel$jscomp$5$$));$offset$jscomp$193_prefix$jscomp$64_temp__5825__auto____$1$jscomp$17$$=
$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($after_span_node_text$jscomp$1_suffix$jscomp$27$$,0,$current_at_symbol$jscomp$1_or__5025__auto__$jscomp$inline_7442_sel$jscomp$5$$);$after_span_node_text$jscomp$1_suffix$jscomp$27$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($after_span_node_text$jscomp$1_suffix$jscomp$27$$,$current_at_symbol$jscomp$1_or__5025__auto__$jscomp$inline_7442_sel$jscomp$5$$+$APP.$cljs$core$count$$($mention$jscomp$1$$));$data$jscomp$433_mention_span$$=$app$main$ui$comments$create_mention_node$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$750$user$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$433_mention_span$$)),
$APP.$cljs$cst$1360$fullname$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$750$user$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$433_mention_span$$)));$after_span_node_text$jscomp$1_suffix$jscomp$27$$=$app$main$ui$comments$create_text_node$cljs$0core$0IFn$0_invoke$0arity$01$$(" "+($after_span_node_text$jscomp$1_suffix$jscomp$27$$??""));$current_at_symbol$jscomp$1_or__5025__auto__$jscomp$inline_7442_sel$jscomp$5$$=$app$util$webapi$get_selection$$();$app$util$dom$set_html_BANG_$$($span_node$jscomp$3$$,
$APP.$cljs$core$empty_QMARK_$$($offset$jscomp$193_prefix$jscomp$64_temp__5825__auto____$1$jscomp$17$$)?"​":$app$util$dom$escape_html$$($offset$jscomp$193_prefix$jscomp$64_temp__5825__auto____$1$jscomp$17$$));$app$util$dom$insert_after_BANG_$$($G__73243_temp__5825__auto__$jscomp$263$$,$span_node$jscomp$3$$,$data$jscomp$433_mention_span$$);$app$util$dom$insert_after_BANG_$$($G__73243_temp__5825__auto__$jscomp$263$$,$data$jscomp$433_mention_span$$,$after_span_node_text$jscomp$1_suffix$jscomp$27$$);$app$util$webapi$set_cursor_after_BANG_$$($after_span_node_text$jscomp$1_suffix$jscomp$27$$);
$current_at_symbol$jscomp$1_or__5025__auto__$jscomp$inline_7442_sel$jscomp$5$$.collapseToEnd();if($APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$14$$))return $G__73243_temp__5825__auto__$jscomp$263$$=$app$main$ui$comments$parse_nodes$$($G__73243_temp__5825__auto__$jscomp$263$$),$on_change$jscomp$14$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$14$$.$cljs$core$IFn$_invoke$arity$1$($G__73243_temp__5825__auto__$jscomp$263$$):$on_change$jscomp$14$$($G__73243_temp__5825__auto__$jscomp$263$$)}}return null}),
$handle_insert_at_symbol$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $span_node$jscomp$4_temp__5825__auto__$jscomp$264_temp__5825__auto____$1$jscomp$18$$=$APP.$rumext$v2$ref_val$$($local_ref$$);if($APP.$cljs$core$truth_$$($span_node$jscomp$4_temp__5825__auto__$jscomp$264_temp__5825__auto____$1$jscomp$18$$)&&($span_node$jscomp$4_temp__5825__auto__$jscomp$264_temp__5825__auto____$1$jscomp$18$$=$app$main$ui$comments$current_text_node$$($span_node$jscomp$4_temp__5825__auto__$jscomp$264_temp__5825__auto____$1$jscomp$18$$),
$APP.$cljs$core$truth_$$($span_node$jscomp$4_temp__5825__auto__$jscomp$264_temp__5825__auto____$1$jscomp$18$$))){$span_node$jscomp$4_temp__5825__auto__$jscomp$264_temp__5825__auto____$1$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($span_node$jscomp$4_temp__5825__auto__$jscomp$264_temp__5825__auto____$1$jscomp$18$$,0,null);var $node_text$jscomp$2$$=$APP.$app$util$dom$get_text$$($span_node$jscomp$4_temp__5825__auto__$jscomp$264_temp__5825__auto____$1$jscomp$18$$),$at_symbol$$=
$app$main$ui$comments$blank_content_QMARK_$$($node_text$jscomp$2$$)?"@":" @";$app$util$dom$set_html_BANG_$$($span_node$jscomp$4_temp__5825__auto__$jscomp$264_temp__5825__auto____$1$jscomp$18$$,""+($app$util$dom$escape_html$$($node_text$jscomp$2$$)??"")+($at_symbol$$??""));return $app$util$webapi$set_cursor_after_BANG_$$($span_node$jscomp$4_temp__5825__auto__$jscomp$264_temp__5825__auto____$1$jscomp$18$$)}return null}),$handle_key_down$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_esc$$),
$APP.$rumext$v2$adapt$$($on_ctrl_enter$$),$APP.$rumext$v2$adapt$$($handle_select$$),$APP.$rumext$v2$adapt$$($handle_input$$)],function($event$jscomp$148$$){$handle_select$$.$cljs$core$IFn$_invoke$arity$1$?$handle_select$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$148$$):$handle_select$$($event$jscomp$148$$);var $prev_node_span_node__$1_temp__5825__auto__$jscomp$265$$=$APP.$rumext$v2$ref_val$$($local_ref$$);if($APP.$cljs$core$truth_$$($prev_node_span_node__$1_temp__5825__auto__$jscomp$265$$)){var $offset$jscomp$194_offset__$1$jscomp$21_temp__5825__auto____$1$jscomp$19_vec__73253$$=
$app$main$ui$comments$current_text_node$$($prev_node_span_node__$1_temp__5825__auto__$jscomp$265$$);if($APP.$cljs$core$truth_$$($offset$jscomp$194_offset__$1$jscomp$21_temp__5825__auto____$1$jscomp$19_vec__73253$$)){var $range$jscomp$16_span_node$jscomp$5_txt$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offset$jscomp$194_offset__$1$jscomp$21_temp__5825__auto____$1$jscomp$19_vec__73253$$,0,null);$offset$jscomp$194_offset__$1$jscomp$21_temp__5825__auto____$1$jscomp$19_vec__73253$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offset$jscomp$194_offset__$1$jscomp$21_temp__5825__auto____$1$jscomp$19_vec__73253$$,
1,null);if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$593$$=$APP.$cljs$core$_deref$$($cur_mention$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$593$$)?(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$148$$):$and__5023__auto__$jscomp$593$$}()))return $APP.$app$util$dom$prevent_default$$($event$jscomp$148$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$148$$),$mentions_s$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,
$cljs$cst$5000$insert_selected_mention$$],null));if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$594$$=$APP.$cljs$core$_deref$$($cur_mention$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$594$$)?(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$148$$):$and__5023__auto__$jscomp$594$$}()))return $APP.$app$util$dom$prevent_default$$($event$jscomp$148$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$148$$),$mentions_s$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$5001$insert_next_mention$$],null));if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$595$$=$APP.$cljs$core$_deref$$($cur_mention$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$595$$)?(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$148$$):$and__5023__auto__$jscomp$595$$}()))return $APP.$app$util$dom$prevent_default$$($event$jscomp$148$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$148$$),$mentions_s$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$5002$insert_prev_mention$$],null));if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$596$$=$APP.$cljs$core$_deref$$($cur_mention$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$596$$)?(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$148$$):$and__5023__auto__$jscomp$596$$}()))return $APP.$app$util$dom$prevent_default$$($event$jscomp$148$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$148$$),$mentions_s$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$4999$hide_mentions$$],null));if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$597$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$148$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$597$$)?$APP.$cljs$core$fn_QMARK_$$($on_esc$$):$and__5023__auto__$jscomp$597$$}()))return $on_esc$$.$cljs$core$IFn$_invoke$arity$1$?$on_esc$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$148$$):$on_esc$$($event$jscomp$148$$);if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$598_and__5023__auto____$1$jscomp$101$$=
$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$148$$);return $and__5023__auto__$jscomp$598_and__5023__auto____$1$jscomp$101$$?($and__5023__auto__$jscomp$598_and__5023__auto____$1$jscomp$101$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$148$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$598_and__5023__auto____$1$jscomp$101$$)?$APP.$cljs$core$fn_QMARK_$$($on_ctrl_enter$$):$and__5023__auto__$jscomp$598_and__5023__auto____$1$jscomp$101$$):$and__5023__auto__$jscomp$598_and__5023__auto____$1$jscomp$101$$}()))return $on_ctrl_enter$$.$cljs$core$IFn$_invoke$arity$1$?
$on_ctrl_enter$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$148$$):$on_ctrl_enter$$($event$jscomp$148$$);if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$148$$))){if($range$jscomp$16_span_node$jscomp$5_txt$$=$app$util$webapi$get_selection$$().getRangeAt(0),$APP.$app$util$dom$prevent_default$$($event$jscomp$148$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$148$$),$offset$jscomp$194_offset__$1$jscomp$21_temp__5825__auto____$1$jscomp$19_vec__73253$$=$app$main$ui$comments$current_text_node$$($prev_node_span_node__$1_temp__5825__auto__$jscomp$265$$),
$prev_node_span_node__$1_temp__5825__auto__$jscomp$265$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offset$jscomp$194_offset__$1$jscomp$21_temp__5825__auto____$1$jscomp$19_vec__73253$$,0,null),$offset$jscomp$194_offset__$1$jscomp$21_temp__5825__auto____$1$jscomp$19_vec__73253$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($offset$jscomp$194_offset__$1$jscomp$21_temp__5825__auto____$1$jscomp$19_vec__73253$$,1,null),$range$jscomp$16_span_node$jscomp$5_txt$$.deleteContents(),
$handle_input$$.$cljs$core$IFn$_invoke$arity$0$?$handle_input$$.$cljs$core$IFn$_invoke$arity$0$():$handle_input$$(),$APP.$cljs$core$truth_$$($prev_node_span_node__$1_temp__5825__auto__$jscomp$265$$))return $range$jscomp$16_span_node$jscomp$5_txt$$=$prev_node_span_node__$1_temp__5825__auto__$jscomp$265$$.textContent,$app$util$dom$set_html_BANG_$$($prev_node_span_node__$1_temp__5825__auto__$jscomp$265$$,""+($app$util$dom$escape_html$$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($range$jscomp$16_span_node$jscomp$5_txt$$,
0,$offset$jscomp$194_offset__$1$jscomp$21_temp__5825__auto____$1$jscomp$19_vec__73253$$))??"")+"\n​"+($app$util$dom$escape_html$$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($range$jscomp$16_span_node$jscomp$5_txt$$,$offset$jscomp$194_offset__$1$jscomp$21_temp__5825__auto____$1$jscomp$19_vec__73253$$))??"")),$app$util$webapi$set_cursor_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($prev_node_span_node__$1_temp__5825__auto__$jscomp$265$$,$offset$jscomp$194_offset__$1$jscomp$21_temp__5825__auto____$1$jscomp$19_vec__73253$$+
1),$handle_input$$.$cljs$core$IFn$_invoke$arity$0$?$handle_input$$.$cljs$core$IFn$_invoke$arity$0$():$handle_input$$()}else if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$backspace_QMARK_$$)($event$jscomp$148$$))&&($prev_node_span_node__$1_temp__5825__auto__$jscomp$265$$=$app$main$ui$comments$get_prev_node$$($prev_node_span_node__$1_temp__5825__auto__$jscomp$265$$,$range$jscomp$16_span_node$jscomp$5_txt$$),$prev_node_span_node__$1_temp__5825__auto__$jscomp$265$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("mention",
$APP.$app$util$dom$get_data$$($prev_node_span_node__$1_temp__5825__auto__$jscomp$265$$,"type"))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$194_offset__$1$jscomp$21_temp__5825__auto____$1$jscomp$19_vec__73253$$,1)))return $APP.$app$util$dom$prevent_default$$($event$jscomp$148$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$148$$),$prev_node_span_node__$1_temp__5825__auto__$jscomp$265$$.remove()}}return null});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($autofocus$$)],
function(){return $autofocus$$?$APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($local_ref$$)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_select$$)],function(){document.addEventListener("selectionchange",$handle_select$$);return function(){return document.removeEventListener("selectionchange",$handle_select$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$truth_$$($mentions_s$$)?
$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__73256_type$jscomp$584$$){var $data$jscomp$434_map__73257__$1$$=$APP.$cljs$core$__destructure_map$$($p__73256_type$jscomp$584$$);$p__73256_type$jscomp$584$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$434_map__73257__$1$$,$APP.$cljs$cst$139$type$$);$data$jscomp$434_map__73257__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$434_map__73257__$1$$,$APP.$cljs$cst$142$data$$);
switch($p__73256_type$jscomp$584$$ instanceof $APP.$cljs$core$Keyword$$?$p__73256_type$jscomp$584$$.$fqn$:null){case "insert-mention":return $handle_insert_mention$$.$cljs$core$IFn$_invoke$arity$1$?$handle_insert_mention$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$434_map__73257__$1$$):$handle_insert_mention$$($data$jscomp$434_map__73257__$1$$);case "insert-at-symbol":return $handle_insert_at_symbol$$.$cljs$core$IFn$_invoke$arity$0$?$handle_insert_at_symbol$$.$cljs$core$IFn$_invoke$arity$0$():
$handle_insert_at_symbol$$();default:return null}},$mentions_s$$):null});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$(null,function(){var $temp__5825__auto__$jscomp$266$$=$APP.$rumext$v2$ref_val$$($local_ref$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$266$$)?($temp__5825__auto__$jscomp$266$$.style.height="0",$temp__5825__auto__$jscomp$266$$.style.height=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(2+$temp__5825__auto__$jscomp$266$$.scrollHeight),
"px"].join("")):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value__$1$jscomp$28$$),$APP.$rumext$v2$adapt$$($prev_value$$)],function(){var $temp__5825__auto__$jscomp$267$$=$APP.$rumext$v2$ref_val$$($local_ref$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$267$$)){if($APP.$app$common$data$not_empty_QMARK_$$($prev_value$$)&&$APP.$cljs$core$empty_QMARK_$$($value__$1$jscomp$28$$))return $app$util$dom$set_html_BANG_$$($temp__5825__auto__$jscomp$267$$,
""),$APP.$app$util$dom$append_child_BANG_$$($temp__5825__auto__$jscomp$267$$,$app$main$ui$comments$create_text_node$cljs$0core$0IFn$0_invoke$0arity$01$$("")),$APP.$app$util$dom$set_css_property_BANG_$$($temp__5825__auto__$jscomp$267$$,"--placeholder",""),$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$267$$);var $JSCompiler_inline_result$jscomp$664_JSCompiler_temp$jscomp$662_JSCompiler_temp$jscomp$663$$;if($JSCompiler_inline_result$jscomp$664_JSCompiler_temp$jscomp$662_JSCompiler_temp$jscomp$663$$=
$temp__5825__auto__$jscomp$267$$!=null)if($JSCompiler_inline_result$jscomp$664_JSCompiler_temp$jscomp$662_JSCompiler_temp$jscomp$663$$=$APP.$cljs$core$empty_QMARK_$$($value__$1$jscomp$28$$))$JSCompiler_inline_result$jscomp$664_JSCompiler_temp$jscomp$662_JSCompiler_temp$jscomp$663$$=$APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$267$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(document.activeElement,$temp__5825__auto__$jscomp$267$$):$temp__5825__auto__$jscomp$267$$,$JSCompiler_inline_result$jscomp$664_JSCompiler_temp$jscomp$662_JSCompiler_temp$jscomp$663$$=
$APP.$cljs$core$not$$($JSCompiler_inline_result$jscomp$664_JSCompiler_temp$jscomp$662_JSCompiler_temp$jscomp$663$$);return $JSCompiler_inline_result$jscomp$664_JSCompiler_temp$jscomp$662_JSCompiler_temp$jscomp$663$$?$APP.$app$util$dom$set_css_property_BANG_$$($temp__5825__auto__$jscomp$267$$,"--placeholder",'"'+($placeholder$jscomp$1$$??"")+'"'):$temp__5825__auto__$jscomp$267$$!=null?$APP.$app$util$dom$set_css_property_BANG_$$($temp__5825__auto__$jscomp$267$$,"--placeholder",""):null}return null});
return(0,$APP.$rumext$v2$jsx$$)("div",{role:"textbox",onInput:$handle_input$$,className:"main_ui_comments__comment-input",suppressContentEditableWarning:!0,onFocus:$handle_focus$$,onBlur:$handle_blur$$,ref:$init_input_props_73179$$,onKeyDown:$handle_key_down$jscomp$2$$,contentEditable:"true"})};
$app$main$ui$comments$mentions_panel_STAR_$$=function(){var $mentions_s$jscomp$1$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$comments$mentions_context$$),$display$jscomp$1_map__73265_team$jscomp$12$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$team$$),$members$jscomp$2$$=$APP.$cljs$cst$3264$members$$.$cljs$core$IFn$_invoke$arity$1$($display$jscomp$1_map__73265_team$jscomp$12$$),$state_STAR_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1932$display$$,!1,$cljs$cst$5003$mention_filter$$,"",$APP.$cljs$cst$1921$selected$$,0],null)});$display$jscomp$1_map__73265_team$jscomp$12$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$6$$);var $map__73265__$1_selected$jscomp$122$$=$APP.$cljs$core$__destructure_map$$($display$jscomp$1_map__73265_team$jscomp$12$$);$display$jscomp$1_map__73265_team$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73265__$1_selected$jscomp$122$$,$APP.$cljs$cst$1932$display$$);
var $mention_filter$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73265__$1_selected$jscomp$122$$,$cljs$cst$5003$mention_filter$$);$map__73265__$1_selected$jscomp$122$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73265__$1_selected$jscomp$122$$,$APP.$cljs$cst$1921$selected$$);var $mentions_users$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mention_filter$$),$APP.$rumext$v2$adapt$$($members$jscomp$2$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(4,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($fullname$jscomp$2_or__5025__auto____$2$jscomp$28_p__73267$$){var $email$jscomp$10_map__73268__$1$$=$APP.$cljs$core$__destructure_map$$($fullname$jscomp$2_or__5025__auto____$2$jscomp$28_p__73267$$);$fullname$jscomp$2_or__5025__auto____$2$jscomp$28_p__73267$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($email$jscomp$10_map__73268__$1$$,$APP.$cljs$cst$1360$fullname$$);
$email$jscomp$10_map__73268__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($email$jscomp$10_map__73268__$1$$,$APP.$cljs$cst$3183$email$$);var $or__5025__auto__$jscomp$926_or__5025__auto____$1$jscomp$104$$=$APP.$cljs$core$not$$($mention_filter$$);if($or__5025__auto__$jscomp$926_or__5025__auto____$1$jscomp$104$$||($or__5025__auto__$jscomp$926_or__5025__auto____$1$jscomp$104$$=$APP.$cljs$core$empty_QMARK_$$($mention_filter$$)))return $or__5025__auto__$jscomp$926_or__5025__auto____$1$jscomp$104$$;
$fullname$jscomp$2_or__5025__auto____$2$jscomp$28_p__73267$$=$APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($fullname$jscomp$2_or__5025__auto____$2$jscomp$28_p__73267$$),$APP.$cuerdas$core$lower$$($mention_filter$$));return $APP.$cljs$core$truth_$$($fullname$jscomp$2_or__5025__auto____$2$jscomp$28_p__73267$$)?$fullname$jscomp$2_or__5025__auto____$2$jscomp$28_p__73267$$:$APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($email$jscomp$10_map__73268__$1$$),$APP.$cuerdas$core$lower$$($mention_filter$$))},
$members$jscomp$2$$)))}),$selected__$1$jscomp$14$$=$APP.$app$common$math$clamp$$($map__73265__$1_selected$jscomp$122$$,0,$APP.$cljs$core$count$$($mentions_users$$)-1),$handle_click_mention$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$149_user$jscomp$7$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$149_user$jscomp$7$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$149_user$jscomp$7$$);var $id$jscomp$843$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$149_user$jscomp$7$$),
"user-id"));$event$jscomp$149_user$jscomp$7$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73261_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73261_SHARP_$$),$id$jscomp$843$$)},$members$jscomp$2$$);return $mentions_s$jscomp$1$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$5004$insert_mention$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$750$user$$,$event$jscomp$149_user$jscomp$7$$],null)],null))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mentions_users$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$14$$)],function(){var $sub$jscomp$20$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__73269_type$jscomp$585$$){var $data$jscomp$435_map__73270__$1$$=$APP.$cljs$core$__destructure_map$$($p__73269_type$jscomp$585$$);$p__73269_type$jscomp$585$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$435_map__73270__$1$$,$APP.$cljs$cst$139$type$$);$data$jscomp$435_map__73270__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$435_map__73270__$1$$,$APP.$cljs$cst$142$data$$);switch($p__73269_type$jscomp$585$$ instanceof $APP.$cljs$core$Keyword$$?$p__73269_type$jscomp$585$$.$fqn$:null){case "display-mentions":return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$6$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$1932$display$$,!0);case "hide-mentions":return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$6$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1932$display$$,!1,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5003$mention_filter$$,""]));case "filter-mentions":return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$6$$,$APP.$cljs$core$assoc$$,$cljs$cst$5003$mention_filter$$,$data$jscomp$435_map__73270__$1$$);
case "insert-selected-mention":return $mentions_s$jscomp$1$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$5004$insert_mention$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$750$user$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mentions_users$$,$selected__$1$jscomp$14$$)],null)],null));case "insert-next-mention":return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$6$$,
$APP.$cljs$core$update$$,$APP.$cljs$cst$1921$selected$$,function($p1__73262_SHARP_$$){return $APP.$app$common$math$clamp$$($p1__73262_SHARP_$$+1,0,$APP.$cljs$core$count$$($mentions_users$$)-1)});case "insert-prev-mention":return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$6$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$1921$selected$$,function($p1__73263_SHARP_$$){return $APP.$app$common$math$clamp$$($p1__73263_SHARP_$$-1,0,$APP.$cljs$core$count$$($mentions_users$$)-
1)});default:return null}},$mentions_s$jscomp$1$$);return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$20$$)}});return $display$jscomp$1_map__73265_team$jscomp$12$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__comments-mentions-choice",children:$APP.$cljs$core$empty_QMARK_$$($mentions_users$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__comments-mentions-empty",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("comments.mentions.not-found",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$mention_filter$$]))}):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$39$$,$map__73276_map__73276__$1_p__73272$$){var $idx$jscomp$101$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__73276_map__73276__$1_p__73272$$,0,null);$map__73276_map__73276__$1_p__73272$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__73276_map__73276__$1_p__73272$$,1,null);$map__73276_map__73276__$1_p__73272$$=
$APP.$cljs$core$__destructure_map$$($map__73276_map__73276__$1_p__73272$$);var $id$jscomp$844$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73276_map__73276__$1_p__73272$$,$APP.$cljs$cst$266$id$$),$fullname$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73276_map__73276__$1_p__73272$$,$APP.$cljs$cst$1360$fullname$$),$email$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73276_map__73276__$1_p__73272$$,$APP.$cljs$cst$3183$email$$);$out_arr__44124__auto__$jscomp$39$$.push((0,$APP.$rumext$v2$jsxs$$)("div",
{onPointerDown:$handle_click_mention$$,"data-user-id":""+($id$jscomp$844$$??""),className:"main_ui_comments__comments-mentions-entry "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected__$1$jscomp$14$$,$idx$jscomp$101$$)?"main_ui_comments__is-selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:$APP.$app$config$resolve_profile_photo_url$$($map__73276_map__73276__$1_p__73272$$),className:"main_ui_comments__comments-mentions-avatar"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__comments-mentions-name",
children:$fullname$jscomp$3$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__comments-mentions-email",children:$email$jscomp$11$$})]},$id$jscomp$844$$));return $out_arr__44124__auto__$jscomp$39$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($mentions_users$$))}):null};
$app$main$ui$comments$mentions_button_STAR_$$=function(){var $mentions_s$jscomp$2$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$comments$mentions_context$$),$display_mentions_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$handle_pointer_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($display_mentions_STAR_$$))],function($event$jscomp$150$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$150$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$150$$);
return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($display_mentions_STAR_$$))?$mentions_s$jscomp$2$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$4999$hide_mentions$$],null)):$mentions_s$jscomp$2$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$5005$insert_at_symbol$$],null))}),$handle_key_down$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($display_mentions_STAR_$$))],
function($event$jscomp$151$$){var $JSCompiler_inline_result$jscomp$1343_or__5025__auto__$jscomp$inline_7446$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$151$$);$JSCompiler_inline_result$jscomp$1343_or__5025__auto__$jscomp$inline_7446$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1343_or__5025__auto__$jscomp$inline_7446$$)?$JSCompiler_inline_result$jscomp$1343_or__5025__auto__$jscomp$inline_7446$$:(0,$APP.$app$util$keyboard$space_QMARK_$$)($event$jscomp$151$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1343_or__5025__auto__$jscomp$inline_7446$$)?
$handle_pointer_down$$.$cljs$core$IFn$_invoke$arity$1$?$handle_pointer_down$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$151$$):$handle_pointer_down$$($event$jscomp$151$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $sub$jscomp$21$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($map__73280__$1_p__73279$$){$map__73280__$1_p__73279$$=$APP.$cljs$core$__destructure_map$$($map__73280__$1_p__73279$$);var $type$jscomp$586$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73280__$1_p__73279$$,
$APP.$cljs$cst$139$type$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73280__$1_p__73279$$,$APP.$cljs$cst$1102$_$$);switch($type$jscomp$586$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$586$$.$fqn$:null){case "display-mentions":return $APP.$cljs$core$reset_BANG_$$($display_mentions_STAR_$$,!0);case "hide-mentions":return $APP.$cljs$core$reset_BANG_$$($display_mentions_STAR_$$,!1);default:return null}},$mentions_s$jscomp$2$$);return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$21$$)}});
return(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.mention"),onPointerDown:$handle_pointer_down$$,onKeyDown:$handle_key_down$jscomp$3$$,iconClass:"main_ui_comments__open-mentions-button "+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($display_mentions_STAR_$$))?"main_ui_comments__is-toggled":""),icon:"at"})};
$app$main$ui$comments$comment_avatar_STAR_$$=function($children$jscomp$277_props_73282$$){var $image$jscomp$30$$,$props$jscomp$242$$;({image:$image$jscomp$30$$,variant:$or__5025__auto__$jscomp$inline_7448_variant$jscomp$21_variant__$1$jscomp$4$$,className:$class$$jscomp$33_class$__$1$jscomp$5$$,children:$children$jscomp$277_props_73282$$,...$props$jscomp$242$$}=$children$jscomp$277_props_73282$$);var $or__5025__auto__$jscomp$inline_7448_variant$jscomp$21_variant__$1$jscomp$4$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_7448_variant$jscomp$21_variant__$1$jscomp$4$$)?
$or__5025__auto__$jscomp$inline_7448_variant$jscomp$21_variant__$1$jscomp$4$$:"read";var $class$$jscomp$33_class$__$1$jscomp$5$$=""+($class$$jscomp$33_class$__$1$jscomp$5$$??"")+" main_ui_comments__avatar "+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($or__5025__auto__$jscomp$inline_7448_variant$jscomp$21_variant__$1$jscomp$4$$,"read")?"main_ui_comments__avatar-read":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($or__5025__auto__$jscomp$inline_7448_variant$jscomp$21_variant__$1$jscomp$4$$,
"unread")?"main_ui_comments__avatar-unread":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($or__5025__auto__$jscomp$inline_7448_variant$jscomp$21_variant__$1$jscomp$4$$,"solved")?"main_ui_comments__avatar-solved":""));return(0,$APP.$rumext$v2$create_element$$)("div",{...$props$jscomp$242$$,className:$class$$jscomp$33_class$__$1$jscomp$5$$},$APP.$cljs$core$truth_$$($image$jscomp$30$$)?(0,$APP.$rumext$v2$jsx$$)("img",{src:$image$jscomp$30$$,className:"main_ui_comments__avatar-image"}):
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__avatar-text",children:$children$jscomp$277_props_73282$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__avatar-mask "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($or__5025__auto__$jscomp$inline_7448_variant$jscomp$21_variant__$1$jscomp$4$$,"solved")?"main_ui_comments__avatar-darken":"")}))};
$app$main$ui$comments$comment_info_STAR_$$=function($JSCompiler_temp_const$jscomp$1344_props_73283$$){var $JSCompiler_temp_const$jscomp$1345_profile$jscomp$22$$=$JSCompiler_temp_const$jscomp$1344_props_73283$$.profile,$item$jscomp$96_total_replies$jscomp$inline_7452$$=$JSCompiler_temp_const$jscomp$1344_props_73283$$.item;$JSCompiler_temp_const$jscomp$1345_profile$jscomp$22$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__author",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_avatar_STAR_$$,
{image:$APP.$app$config$resolve_profile_photo_url$$($JSCompiler_temp_const$jscomp$1345_profile$jscomp$22$$),className:"main_ui_comments__avatar-lg",variant:$APP.$cljs$core$truth_$$($APP.$cljs$cst$3445$is_resolved$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$96_total_replies$jscomp$inline_7452$$))?"solved":$APP.$cljs$cst$3428$count_unread_comments$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$96_total_replies$jscomp$inline_7452$$)>0?"unread":"read"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__author-identity",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__author-fullname",children:$APP.$cljs$cst$1360$fullname$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$1345_profile$jscomp$22$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__author-timeago",children:$APP.$app$common$time$timeago$$($APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$96_total_replies$jscomp$inline_7452$$))})]})]});$JSCompiler_temp_const$jscomp$1344_props_73283$$=
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__item",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_content_STAR_$$,{content:$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$96_total_replies$jscomp$inline_7452$$)})});var $JSCompiler_inline_result$jscomp$1346_total_comments$jscomp$inline_7450_unread_replies$jscomp$inline_7453$$=$cljs$cst$3429$count_comments$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$96_total_replies$jscomp$inline_7452$$);
var $unread_comments$jscomp$inline_7451$$=$APP.$cljs$cst$3428$count_unread_comments$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$96_total_replies$jscomp$inline_7452$$);$item$jscomp$96_total_replies$jscomp$inline_7452$$=$JSCompiler_inline_result$jscomp$1346_total_comments$jscomp$inline_7450_unread_replies$jscomp$inline_7453$$-1;$JSCompiler_inline_result$jscomp$1346_total_comments$jscomp$inline_7450_unread_replies$jscomp$inline_7453$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($unread_comments$jscomp$inline_7451$$,
$JSCompiler_inline_result$jscomp$1346_total_comments$jscomp$inline_7450_unread_replies$jscomp$inline_7453$$)?$unread_comments$jscomp$inline_7451$$-1:$unread_comments$jscomp$inline_7451$$;$JSCompiler_inline_result$jscomp$1346_total_comments$jscomp$inline_7450_unread_replies$jscomp$inline_7453$$=(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$item$jscomp$96_total_replies$jscomp$inline_7452$$>0?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$96_total_replies$jscomp$inline_7452$$,
1)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_comments__replies-total",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$96_total_replies$jscomp$inline_7452$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.reply"))].join("")}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_comments__replies-total",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$96_total_replies$jscomp$inline_7452$$),
" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.replies"))].join("")}):null,$item$jscomp$96_total_replies$jscomp$inline_7452$$>0&&$JSCompiler_inline_result$jscomp$1346_total_comments$jscomp$inline_7450_unread_replies$jscomp$inline_7453$$>0?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1346_total_comments$jscomp$inline_7450_unread_replies$jscomp$inline_7453$$,1)?(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_comments__replies-unread",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1346_total_comments$jscomp$inline_7450_unread_replies$jscomp$inline_7453$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.reply.new"))].join("")}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_comments__replies-unread",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1346_total_comments$jscomp$inline_7450_unread_replies$jscomp$inline_7453$$),
" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.replies.new"))].join("")}):null]});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$JSCompiler_temp_const$jscomp$1345_profile$jscomp$22$$,$JSCompiler_temp_const$jscomp$1344_props_73283$$,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__replies",children:$JSCompiler_inline_result$jscomp$1346_total_comments$jscomp$inline_7450_unread_replies$jscomp$inline_7453$$})]})};
$app$main$ui$comments$comment_form_buttons_STAR_$$=function($handle_cancel_props_73288$$){var $on_cancel$$=$handle_cancel_props_73288$$.onCancel,$is_disabled$$=$handle_cancel_props_73288$$.isDisabled,$on_submit$jscomp$1$$=$handle_cancel_props_73288$$.onSubmit;$handle_cancel_props_73288$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_cancel$$)],function($event$jscomp$152$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$152$$))?
$on_cancel$$.$cljs$core$IFn$_invoke$arity$0$?$on_cancel$$.$cljs$core$IFn$_invoke$arity$0$():$on_cancel$$():null});var $handle_submit$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_submit$jscomp$1$$)],function($event$jscomp$153$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$153$$))?$on_submit$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$on_submit$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_submit$jscomp$1$$():
null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__form-buttons-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$mentions_button_STAR_$$,{}),$on_cancel$$!=null?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"ghost",type:"button",onKeyDown:$handle_cancel_props_73288$$,onClick:$on_cancel$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-cancel")}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,
{variant:"primary",type:"button",onKeyDown:$handle_submit$$,onClick:$on_submit$jscomp$1$$,disabled:$is_disabled$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.post")})]})};$app$main$ui$comments$exceeds_length_QMARK_$$=function($content$jscomp$231$$){return $APP.$cljs$core$count$$($content$jscomp$231$$)>750};
$app$main$ui$comments$comment_reply_form_STAR_$$=function($disabled_QMARK__props_73302$$){var $on_submit$jscomp$2$$=$disabled_QMARK__props_73302$$.onSubmit,$content$jscomp$232$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("");$disabled_QMARK__props_73302$$=$app$main$ui$comments$blank_content_QMARK_$$($APP.$cljs$core$_deref$$($content$jscomp$232$$))||$app$main$ui$comments$exceeds_length_QMARK_$$($APP.$cljs$core$_deref$$($content$jscomp$232$$));var $on_cancel$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2169$interrupt$$)}),
$on_change$jscomp$15$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__73300_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($content$jscomp$232$$,$p1__73300_SHARP_$$)}),$on_submit_STAR_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($content$jscomp$232$$))],function(){var $G__73310_73494$$=$APP.$cljs$core$_deref$$($content$jscomp$232$$);$on_submit$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_submit$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__73310_73494$$):
$on_submit$jscomp$2$$($G__73310_73494$$);return $APP.$cljs$core$reset_BANG_$$($content$jscomp$232$$,"")});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__form",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_input_STAR_$$,{value:$APP.$cljs$core$_deref$$($content$jscomp$232$$),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.reply.thread"),autofocus:!0,onCtrlEnter:$on_submit_STAR_$$,onChange:$on_change$jscomp$15$$}),$app$main$ui$comments$exceeds_length_QMARK_$$($APP.$cljs$core$_deref$$($content$jscomp$232$$))?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__error-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.character-limit-exceeded")}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_form_buttons_STAR_$$,{onSubmit:$on_submit_STAR_$$,onCancel:$on_cancel$jscomp$1$$,isDisabled:$disabled_QMARK__props_73302$$})]})};
$app$main$ui$comments$comment_edit_form_STAR_$$=function($disabled_QMARK_$jscomp$1_props_73313$$){var $on_cancel$jscomp$2$$=$disabled_QMARK_$jscomp$1_props_73313$$.onCancel,$on_submit$jscomp$3$$=$disabled_QMARK_$jscomp$1_props_73313$$.onSubmit,$content__$1$jscomp$43$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($disabled_QMARK_$jscomp$1_props_73313$$.content);$disabled_QMARK_$jscomp$1_props_73313$$=$app$main$ui$comments$blank_content_QMARK_$$($APP.$cljs$core$_deref$$($content__$1$jscomp$43$$))||
$app$main$ui$comments$exceeds_length_QMARK_$$($APP.$cljs$core$_deref$$($content__$1$jscomp$43$$));var $on_change$jscomp$16$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__73311_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($content__$1$jscomp$43$$,$p1__73311_SHARP_$$)}),$on_submit_STAR_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($content__$1$jscomp$43$$))],function(){var $G__73315$$=$APP.$cljs$core$_deref$$($content__$1$jscomp$43$$);
return $on_submit$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_submit$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($G__73315$$):$on_submit$jscomp$3$$($G__73315$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__form",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_input_STAR_$$,{value:$APP.$cljs$core$_deref$$($content__$1$jscomp$43$$),autofocus:!0,onCtrlEnter:$on_submit_STAR_$jscomp$1$$,onChange:$on_change$jscomp$16$$}),$app$main$ui$comments$exceeds_length_QMARK_$$($APP.$cljs$core$_deref$$($content__$1$jscomp$43$$))?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__error-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.character-limit-exceeded")}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_form_buttons_STAR_$$,{onSubmit:$on_submit_STAR_$jscomp$1$$,onCancel:$on_cancel$jscomp$2$$,isDisabled:$disabled_QMARK_$jscomp$1_props_73313$$})]})};
$app$main$ui$comments$offset_position$$=function($position$jscomp$175_y$jscomp$449$$,$base_x_viewport$jscomp$2$$,$base_y_zoom$jscomp$41$$,$bubble_margin_orientation_left_QMARK_$$){var $h$jscomp$165_viewport__$1$$=$APP.$cljs$core$truth_$$($base_x_viewport$jscomp$2$$)?$base_x_viewport$jscomp$2$$:new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1650$offset_x$$,0,$APP.$cljs$cst$1651$offset_y$$,0,$APP.$cljs$cst$290$width$$,0,$APP.$cljs$cst$1522$height$$,0],null);$base_x_viewport$jscomp$2$$=
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$175_y$jscomp$449$$)*$base_y_zoom$jscomp$41$$+$APP.$cljs$cst$1650$offset_x$$.$cljs$core$IFn$_invoke$arity$1$($h$jscomp$165_viewport__$1$$);$base_y_zoom$jscomp$41$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$175_y$jscomp$449$$)*$base_y_zoom$jscomp$41$$+$APP.$cljs$cst$1651$offset_y$$.$cljs$core$IFn$_invoke$arity$1$($h$jscomp$165_viewport__$1$$);var $x$jscomp$1227$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$175_y$jscomp$449$$);
$position$jscomp$175_y$jscomp$449$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$175_y$jscomp$449$$);var $w$jscomp$42$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($h$jscomp$165_viewport__$1$$);$h$jscomp$165_viewport__$1$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($h$jscomp$165_viewport__$1$$);$bubble_margin_orientation_left_QMARK_$$=$base_x_viewport$jscomp$2$$+284+$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bubble_margin_orientation_left_QMARK_$$)>=
$w$jscomp$42$$;return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1510$x$$,$x$jscomp$1227$$,$APP.$cljs$cst$1511$y$$,$position$jscomp$175_y$jscomp$449$$,$cljs$cst$5006$h_dir$$,$bubble_margin_orientation_left_QMARK_$$?$APP.$cljs$cst$257$left$$:$APP.$cljs$cst$258$right$$,$cljs$cst$5007$v_dir$$,$base_y_zoom$jscomp$41$$>=$h$jscomp$165_viewport__$1$$/2?$APP.$cljs$cst$1562$top$$:$APP.$cljs$cst$1563$bottom$$],null)};
$APP.$app$main$ui$comments$comment_floating_thread_draft_STAR_$$=function($profile$jscomp$23_props_73326$$){var $pos$jscomp$127_viewport$jscomp$3$$=$profile$jscomp$23_props_73326$$.viewport,$on_cancel$jscomp$3$$=$profile$jscomp$23_props_73326$$.onCancel,$pos_y_zoom$jscomp$42$$=$profile$jscomp$23_props_73326$$.zoom,$position_modifier$$=$profile$jscomp$23_props_73326$$.positionModifier,$draft$$=$profile$jscomp$23_props_73326$$.draft,$on_submit$jscomp$4$$=$profile$jscomp$23_props_73326$$.onSubmit;$profile$jscomp$23_props_73326$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);var $mentions_s$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subject$$()}),$disabled_QMARK_$jscomp$2_margin_x$jscomp$4_position$jscomp$176$$=function(){var $G__73329$$=$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($draft$$);return $position_modifier$$!=null?$APP.$app$common$geom$point$transform$$($G__73329$$,$position_modifier$$):$G__73329$$}(),$content$jscomp$234$$=
$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($draft$$),$bubble_margin$jscomp$1_pos_x$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0);$pos$jscomp$127_viewport$jscomp$3$$=$app$main$ui$comments$offset_position$$($disabled_QMARK_$jscomp$2_margin_x$jscomp$4_position$jscomp$176$$,$pos$jscomp$127_viewport$jscomp$3$$,$pos_y_zoom$jscomp$42$$,$bubble_margin$jscomp$1_pos_x$$);$disabled_QMARK_$jscomp$2_margin_x$jscomp$4_position$jscomp$176$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bubble_margin$jscomp$1_pos_x$$)*
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5006$h_dir$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$127_viewport$jscomp$3$$),$APP.$cljs$cst$257$left$$)?-1:1);var $margin_y$jscomp$4_on_esc$jscomp$1$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bubble_margin$jscomp$1_pos_x$$)*($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5007$v_dir$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$127_viewport$jscomp$3$$),$APP.$cljs$cst$1562$top$$)?-1:1);$bubble_margin$jscomp$1_pos_x$$=
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$127_viewport$jscomp$3$$)*$pos_y_zoom$jscomp$42$$+$disabled_QMARK_$jscomp$2_margin_x$jscomp$4_position$jscomp$176$$;$pos_y_zoom$jscomp$42$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$127_viewport$jscomp$3$$)*$pos_y_zoom$jscomp$42$$-$margin_y$jscomp$4_on_esc$jscomp$1$$;$disabled_QMARK_$jscomp$2_margin_x$jscomp$4_position$jscomp$176$$=$app$main$ui$comments$blank_content_QMARK_$$($content$jscomp$234$$)||$app$main$ui$comments$exceeds_length_QMARK_$$($content$jscomp$234$$);
$margin_y$jscomp$4_on_esc$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($draft$$)],function($event$jscomp$154$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$154$$);return $APP.$cljs$core$fn_QMARK_$$($on_cancel$jscomp$3$$)?$on_cancel$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_cancel$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_cancel$jscomp$3$$():$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2169$interrupt$$)});
var $on_change$jscomp$17$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($draft$$)],function($content__$1$jscomp$44$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$update_draft_thread$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1637$content$$,$content__$1$jscomp$44$$],null)))}),$on_submit_STAR_$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($draft$$)],
function(){return $on_submit$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$on_submit$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($draft$$):$on_submit$jscomp$4$$($draft$$)});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($app$main$ui$comments$mentions_context$$),{value:$mentions_s$jscomp$3$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{style:{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos_y_zoom$jscomp$42$$),"px"].join(""),left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($bubble_margin$jscomp$1_pos_x$$),
"px"].join("")},className:"main_ui_comments__floating-thread-draft-wrapper "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5006$h_dir$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$127_viewport$jscomp$3$$),$APP.$cljs$cst$257$left$$)?"main_ui_comments__left":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5007$v_dir$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$127_viewport$jscomp$3$$),$APP.$cljs$cst$1562$top$$)?"main_ui_comments__top":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",
{"data-testid":"floating-thread-bubble",style:{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos_y_zoom$jscomp$42$$),"px"].join(""),left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($bubble_margin$jscomp$1_pos_x$$),"px"].join("")},onClick:$APP.$app$util$dom$stop_propagation$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_avatar_STAR_$$,{className:"main_ui_comments__avatar-lg",image:$APP.$app$config$resolve_profile_photo_url$$($profile$jscomp$23_props_73326$$)})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{style:{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos_y_zoom$jscomp$42$$-24),"px"].join(""),left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($bubble_margin$jscomp$1_pos_x$$+28),"px"].join("")},onClick:$APP.$app$util$dom$stop_propagation$$,className:"main_ui_comments__floating-thread-draft-inner-wrapper main_ui_comments__cursor-auto",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__form",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_input_STAR_$$,
{placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.write-new-comment"),value:$APP.$cljs$core$truth_$$($content$jscomp$234$$)?$content$jscomp$234$$:"",autofocus:!0,onEsc:$margin_y$jscomp$4_on_esc$jscomp$1$$,onChange:$on_change$jscomp$17$$,onCtrlEnter:$on_submit_STAR_$jscomp$2$$}),$app$main$ui$comments$exceeds_length_QMARK_$$($content$jscomp$234$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__error-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.character-limit-exceeded")}):
null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_form_buttons_STAR_$$,{onSubmit:$on_submit_STAR_$jscomp$2$$,onCancel:$margin_y$jscomp$4_on_esc$jscomp$1$$,isDisabled:$disabled_QMARK_$jscomp$2_margin_x$jscomp$4_position$jscomp$176$$})]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$mentions_panel_STAR_$$,{})]})]})})};
$app$main$ui$comments$comment_floating_thread_header_STAR_$$=function($owner_props_73346$$){var $thread$jscomp$35$$=$owner_props_73346$$.thread,$origin$jscomp$48$$=$owner_props_73346$$.origin;$owner_props_73346$$=$APP.$app$main$data$comments$get_owner$$($thread$jscomp$35$$);var $profile$jscomp$24$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$options$jscomp$587$$=$APP.$rumext$v2$deref$$($app$main$ui$comments$ref_COLON_comments_local_options$$),$toggle_resolved$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($thread$jscomp$35$$)],
function($event$jscomp$155$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$155$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$update_comment_thread$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($thread$jscomp$35$$,$APP.$cljs$cst$3445$is_resolved$$,$APP.$cljs$core$not$$)))}),$on_toggle_options$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$156$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$156$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$toggle_comment_options$$($APP.$app$common$uuid$zero$$))}),$delete_thread$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$comments$close_thread$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$48$$,
$APP.$cljs$cst$1592$viewer$$)?$app$main$data$comments$delete_comment_thread_on_viewer$$($thread$jscomp$35$$):$APP.$app$main$data$comments$delete_comment_thread_on_workspace$cljs$0core$0IFn$0_invoke$0arity$02$$($thread$jscomp$35$$,$APP.$cljs$core$identity$$)]))}),$on_delete_thread$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$157$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$157$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$hide_comment_options$$());
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-comment-thread.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-comment-thread.message"),$APP.$cljs$cst$2476$accept_label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-comment-thread.accept"),$APP.$cljs$cst$2479$on_accept$$,$delete_thread$$],null)))}),$on_hide_options$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$587$$)],function($event$jscomp$158$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$158$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$hide_comment_options$$())});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__floating-thread-header-left",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.comment")," ",(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_comments__grayed-text",children:["#",$APP.$cljs$cst$3426$seqn$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$35$$)]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__floating-thread-header-right",children:[$thread$jscomp$35$$!=null?(0,$APP.$rumext$v2$jsx$$)("div",
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.comment.mark-as-solved"),onClick:$toggle_resolved$$,className:"main_ui_comments__checkbox-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_comments__checkbox "+($APP.$cljs$core$truth_$$($APP.$cljs$cst$3445$is_resolved$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$35$$))?"checked":""),children:$APP.$app$main$ui$icons$tick$$})}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$24$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($owner_props_73346$$))?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.options"),onClick:$on_toggle_options$$,icon:"menu"}):null]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$587$$,$APP.$app$common$uuid$zero$$),
"on-close":$on_hide_options$$,children:(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_comments__dropdown-menu",children:(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_delete_thread$$,className:"main_ui_comments__dropdown-menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete-comment-thread")})})})]})};
$app$main$ui$comments$comment_floating_thread_item_STAR_$$=function($owner$jscomp$1_props_73371$$){var $thread$jscomp$36$$=$owner$jscomp$1_props_73371$$.thread,$comment$jscomp$12$$=$owner$jscomp$1_props_73371$$.comment;$owner$jscomp$1_props_73371$$=$APP.$app$main$data$comments$get_owner$$($comment$jscomp$12$$);var $profile$jscomp$25$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$options$jscomp$588$$=$APP.$rumext$v2$deref$$($app$main$ui$comments$ref_COLON_comments_local_options$$),$edition_QMARK_$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$on_toggle_options$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$588$$)],function($event$jscomp$159$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$159$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$toggle_comment_options$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($comment$jscomp$12$$)))}),$on_hide_options$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$588$$)],function($event$jscomp$160$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$160$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$hide_comment_options$$())}),$on_edit_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$588$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$hide_comment_options$$());
return $APP.$cljs$core$reset_BANG_$$($edition_QMARK_$$,!0)}),$on_delete_comment$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($comment$jscomp$12$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$delete_comment$$($comment$jscomp$12$$))}),$on_submit$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($comment$jscomp$12$$),$APP.$rumext$v2$adapt$$($thread$jscomp$36$$)],
function($content$jscomp$235$$){$APP.$cljs$core$reset_BANG_$$($edition_QMARK_$$,!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$update_comment$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($comment$jscomp$12$$,$APP.$cljs$cst$1637$content$$,$content$jscomp$235$$)))}),$on_cancel$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($edition_QMARK_$$,!1)});return(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_comments__floating-thread-item-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__floating-thread-item",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__author",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_avatar_STAR_$$,{image:$APP.$app$config$resolve_profile_photo_url$$($owner$jscomp$1_props_73371$$)}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__author-identity",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_comments__author-fullname",children:$APP.$cljs$cst$1360$fullname$$.$cljs$core$IFn$_invoke$arity$1$($owner$jscomp$1_props_73371$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__author-timeago",children:$APP.$app$common$time$timeago$$($APP.$cljs$cst$1737$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($comment$jscomp$12$$))})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$25$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($owner$jscomp$1_props_73371$$))?
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.options"),onClick:$on_toggle_options$jscomp$1$$,icon:"menu"}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__item",children:$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($edition_QMARK_$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_edit_form_STAR_$$,{content:$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($comment$jscomp$12$$),
onSubmit:$on_submit$jscomp$5$$,onCancel:$on_cancel$jscomp$4$$}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_comments__text",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_content_STAR_$$,{content:$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($comment$jscomp$12$$)})})})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$588$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($comment$jscomp$12$$)),
"on-close":$on_hide_options$jscomp$1$$,children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_comments__dropdown-menu",children:[(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_edit_clicked$$,className:"main_ui_comments__dropdown-menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.edit")}),$APP.$cljs$core$truth_$$($thread$jscomp$36$$)?null:(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_delete_comment$$,className:"main_ui_comments__dropdown-menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete-comment")})]})})]})};
$APP.$app$main$ui$comments$group_bubbles$cljs$0core$0IFn$0_invoke$0arity$04$$=function($zoom$jscomp$45$$,$circles$jscomp$1_remaining$jscomp$1$$,$visited$jscomp$4$$,$groups$jscomp$2$$){if($APP.$cljs$core$empty_QMARK_$$($circles$jscomp$1_remaining$jscomp$1$$))return $groups$jscomp$2$$;var $current$jscomp$53$$=$APP.$cljs$core$first$$($circles$jscomp$1_remaining$jscomp$1$$);$circles$jscomp$1_remaining$jscomp$1$$=$APP.$cljs$core$rest$$($circles$jscomp$1_remaining$jscomp$1$$);var $overlapping_group$$=$APP.$cljs$core$some$$(function($group$jscomp$43$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$data$workspace$comments$overlap_bubbles_QMARK_$$,
$zoom$jscomp$45$$,$current$jscomp$53$$),$group$jscomp$43$$))?$group$jscomp$43$$:null},$groups$jscomp$2$$);return $APP.$cljs$core$truth_$$($overlapping_group$$)?$APP.$app$main$ui$comments$group_bubbles$cljs$0core$0IFn$0_invoke$0arity$04$$($zoom$jscomp$45$$,$circles$jscomp$1_remaining$jscomp$1$$,$visited$jscomp$4$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($group$jscomp$44$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($group$jscomp$44$$,$overlapping_group$$)?
$APP.$cljs$core$cons$$($current$jscomp$53$$,$group$jscomp$44$$):$group$jscomp$44$$},$groups$jscomp$2$$)):$APP.$app$main$ui$comments$group_bubbles$cljs$0core$0IFn$0_invoke$0arity$04$$($zoom$jscomp$45$$,$circles$jscomp$1_remaining$jscomp$1$$,$visited$jscomp$4$$,$APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$current$jscomp$53$$],null),$groups$jscomp$2$$))};
$app$main$ui$comments$inside_vbox_QMARK_$$=function($pos_x$jscomp$2_positions$jscomp$1_thread_group$$,$vbox$jscomp$30_wl_y2$jscomp$37$$){$vbox$jscomp$30_wl_y2$jscomp$37$$=$APP.$cljs$cst$1925$vbox$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$30_wl_y2$jscomp$37$$);$pos_x$jscomp$2_positions$jscomp$1_thread_group$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$position$$,$pos_x$jscomp$2_positions$jscomp$1_thread_group$$);var $pos_y$jscomp$2_position$jscomp$177$$=$app$common$geom$point$center_points$$($pos_x$jscomp$2_positions$jscomp$1_thread_group$$);
$pos_x$jscomp$2_positions$jscomp$1_thread_group$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($pos_y$jscomp$2_position$jscomp$177$$);$pos_y$jscomp$2_position$jscomp$177$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($pos_y$jscomp$2_position$jscomp$177$$);var $x1$jscomp$37$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$30_wl_y2$jscomp$37$$),$y1$jscomp$39$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$30_wl_y2$jscomp$37$$),$x2$jscomp$35$$=
$x1$jscomp$37$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$30_wl_y2$jscomp$37$$);$vbox$jscomp$30_wl_y2$jscomp$37$$=$y1$jscomp$39$$+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$30_wl_y2$jscomp$37$$);return $x2$jscomp$35$$>$pos_x$jscomp$2_positions$jscomp$1_thread_group$$&&$pos_x$jscomp$2_positions$jscomp$1_thread_group$$>$x1$jscomp$37$$&&$vbox$jscomp$30_wl_y2$jscomp$37$$>$pos_y$jscomp$2_position$jscomp$177$$&&$pos_y$jscomp$2_position$jscomp$177$$>
$y1$jscomp$39$$};
$app$main$ui$comments$comment_sidebar_thread_item_STAR_$$=function($owner$jscomp$3_props_73433$$){var $item$jscomp$98$$=$owner$jscomp$3_props_73433$$.item,$on_click$jscomp$10$$=$owner$jscomp$3_props_73433$$.onClick;$owner$jscomp$3_props_73433$$=$APP.$app$main$data$comments$get_owner$$($item$jscomp$98$$);var $frame$jscomp$41$$=$APP.$rumext$v2$deref$$($app$main$refs$workspace_page_object_by_id$$($APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$98$$),$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$98$$))),$on_click_STAR_$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($item$jscomp$98$$)],function($event$jscomp$167$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$167$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$167$$);return $APP.$cljs$core$fn_QMARK_$$($on_click$jscomp$10$$)?$on_click$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$98$$):$on_click$jscomp$10$$($item$jscomp$98$$):null});return(0,$APP.$rumext$v2$jsxs$$)("div",
{onClick:$on_click_STAR_$jscomp$1$$,className:"main_ui_comments__cover",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__location",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__location-text",children:[["#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3426$seqn$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$98$$))].join(""),[" - ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$3424$page_name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$98$$))].join(""),
$frame$jscomp$41$$==null||$APP.$app$common$files$helpers$root_QMARK_$$($frame$jscomp$41$$)?null:[" - ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$41$$))].join("")]})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_info_STAR_$$,{item:$item$jscomp$98$$,profile:$owner$jscomp$3_props_73433$$})]})};
$app$main$ui$comments$comment_sidebar_thread_group_STAR_$$=function($props_73434$$){var $on_thread_click$$=$props_73434$$.onThreadClick;return(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$41$$,$item$jscomp$99$$){$out_arr__44124__auto__$jscomp$41$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_sidebar_thread_item_STAR_$$,{item:$item$jscomp$99$$,onClick:$on_thread_click$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$99$$)));
return $out_arr__44124__auto__$jscomp$41$$},[],$APP.$cljs$cst$1838$items$$.$cljs$core$IFn$_invoke$arity$1$($props_73434$$.group))})};
$app$main$ui$comments$comment_dashboard_thread_item_STAR_$$=function($owner$jscomp$4_props_73436$$){var $item$jscomp$100$$=$owner$jscomp$4_props_73436$$.item,$on_click$jscomp$11$$=$owner$jscomp$4_props_73436$$.onClick;$owner$jscomp$4_props_73436$$=$APP.$app$main$data$comments$get_owner$$($item$jscomp$100$$);var $on_click_STAR_$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($item$jscomp$100$$)],function($event$jscomp$168$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$168$$);
$APP.$app$util$dom$prevent_default$$($event$jscomp$168$$);return $APP.$cljs$core$fn_QMARK_$$($on_click$jscomp$11$$)?$on_click$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$100$$):$on_click$jscomp$11$$($item$jscomp$100$$):null});return(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$on_click_STAR_$jscomp$2$$,className:"main_ui_comments__cover",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__location",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_comments__location-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"comments"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__location-text",children:[["#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3426$seqn$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$100$$))].join(""),[" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$3425$file_name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$100$$))].join(""),
[", ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$3424$page_name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$100$$))].join("")]})]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_info_STAR_$$,{item:$item$jscomp$100$$,profile:$owner$jscomp$4_props_73436$$})]})};
$app$main$ui$comments$comment_dashboard_thread_group_STAR_$$=function($props_73437$$){var $on_thread_click$jscomp$1$$=$props_73437$$.onThreadClick;return(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$42$$,$item$jscomp$101$$){$out_arr__44124__auto__$jscomp$42$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_dashboard_thread_item_STAR_$$,{item:$item$jscomp$101$$,onClick:$on_thread_click$jscomp$1$$},
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$101$$)));return $out_arr__44124__auto__$jscomp$42$$},[],$APP.$cljs$cst$1838$items$$.$cljs$core$IFn$_invoke$arity$1$($props_73437$$.group))})};
$APP.$app$main$ui$ds$product$panel_title$panel_title_STAR_$$=function($props_73149$$){var $text$jscomp$67$$=void 0,$on_close$jscomp$6$$=void 0,$class$$jscomp$34$$=void 0,$props$jscomp$243$$=void 0;({className:$class$$jscomp$34$$,text:$text$jscomp$67$$,onClose:$on_close$jscomp$6$$,...$props$jscomp$243$$}=$props_73149$$);return(0,$APP.$rumext$v2$create_element$$)("div",{...$props$jscomp$243$$,className:($class$$jscomp$34$$??"")+" main_ui_ds_product_panel_title__panel-title"},(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_ds_product_panel_title__panel-title-text",children:$text$jscomp$67$$}),$APP.$cljs$core$truth_$$($on_close$jscomp$6$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$on_close$jscomp$6$$,icon:"close"}):null)};
$app$main$ui$workspace$comments$sidebar_options$$=function($from_viewer_props_73438$$){$from_viewer_props_73438$$=$from_viewer_props_73438$$["from-viewer"];var $cmode_map__73439$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comments_local$$),$map__73439__$1_update_mode$$=$APP.$cljs$core$__destructure_map$$($cmode_map__73439$$);$cmode_map__73439$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73439__$1_update_mode$$,$APP.$cljs$cst$320$mode$$);var $cshow$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73439__$1_update_mode$$,
$cljs$cst$3471$show$$);$map__73439__$1_update_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$169_mode$jscomp$38$$){$event$jscomp$169_mode$jscomp$38$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$169_mode$jscomp$38$$),"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$update_filters$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$320$mode$$,$event$jscomp$169_mode$jscomp$38$$],null)))});var $update_show$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($cshow$$)],function(){var $mode$jscomp$39$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$111$pending$$,$cshow$$)?$APP.$cljs$cst$2124$all$$:$APP.$cljs$cst$111$pending$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$update_filters$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$3471$show$$,$mode$jscomp$39$$],null)))});return(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_comments__comment-mode-dropdown "+($APP.$cljs$core$truth_$$($from_viewer_props_73438$$)?"main_ui_workspace_comments__viewer-dropdown":""),children:[(0,$APP.$rumext$v2$jsxs$$)("li",{"data-value":"all",onClick:$map__73439__$1_update_mode$$,className:"main_ui_workspace_comments__dropdown-item "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2124$all$$,$cmode_map__73439$$)||
$cmode_map__73439$$==null?"main_ui_workspace_comments__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_comments__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.show-all-comments")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_comments__icon",children:$APP.$app$main$ui$icons$tick$$})]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-value":"yours",onClick:$map__73439__$1_update_mode$$,className:"main_ui_workspace_comments__dropdown-item "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3479$yours$$,$cmode_map__73439$$)?"main_ui_workspace_comments__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_comments__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.show-your-comments")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_comments__icon",children:$APP.$app$main$ui$icons$tick$$})]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-value":"mentions",
onClick:$map__73439__$1_update_mode$$,className:"main_ui_workspace_comments__dropdown-item "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3431$mentions$$,$cmode_map__73439$$)?"main_ui_workspace_comments__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_comments__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.show-mentions")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_comments__icon",children:$APP.$app$main$ui$icons$tick$$})]}),
(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_comments__separator"}),(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:$update_show$$,className:"main_ui_workspace_comments__dropdown-item "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$111$pending$$,$cshow$$)?"main_ui_workspace_comments__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_comments__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.hide-resolved-comments")}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_comments__icon",children:$APP.$app$main$ui$icons$tick$$})]})]})};
$APP.$app$main$ui$workspace$comments$comments_sidebar_STAR_$$=function($close_section_props_73488_threads$jscomp$9$$){var $options_QMARK__profiles$jscomp$1$$=$close_section_props_73488_threads$jscomp$9$$.profiles,$from_viewer$jscomp$1$$=$close_section_props_73488_threads$jscomp$9$$.fromViewer,$page_id$jscomp$342_page_id__$1$jscomp$21$$=$close_section_props_73488_threads$jscomp$9$$.pageId;$close_section_props_73488_threads$jscomp$9$$=$close_section_props_73488_threads$jscomp$9$$.threads;var $tgroups_threads__$1_threads_map$jscomp$1$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$threads$$),$profile$jscomp$26_toggle_mode_selector$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$profiles_SINGLEQUOTE_$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profiles$$),$profiles__$1$$=$APP.$cljs$core$truth_$$($options_QMARK__profiles$jscomp$1$$)?$options_QMARK__profiles$jscomp$1$$:$profiles_SINGLEQUOTE_$$,$local$jscomp$23$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comments_local$$),$state_STAR_$jscomp$7$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);
$options_QMARK__profiles$jscomp$1$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$7$$);$tgroups_threads__$1_threads_map$jscomp$1$$=$close_section_props_73488_threads$jscomp$9$$==null?$APP.$app$main$data$comments$apply_filters$$($local$jscomp$23$$,$profile$jscomp$26_toggle_mode_selector$$,$APP.$cljs$core$reverse$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1737$modified_at$$,$APP.$cljs$core$vals$$($tgroups_threads__$1_threads_map$jscomp$1$$)))):$close_section_props_73488_threads$jscomp$9$$;
$close_section_props_73488_threads$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($from_viewer$jscomp$1$$)],function(){return $APP.$cljs$core$truth_$$($from_viewer$jscomp$1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$update_options$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5013$show_sidebar_QMARK_$$,!1],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$edition$clear_edition_mode$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$deselect_all$$.$cljs$core$IFn$_invoke$arity$1$(!0)]))});$tgroups_threads__$1_threads_map$jscomp$1$$=$app$main$data$comments$group_threads_by_page$$($tgroups_threads__$1_threads_map$jscomp$1$$);$page_id$jscomp$342_page_id__$1$jscomp$21$$=$APP.$cljs$core$truth_$$($page_id$jscomp$342_page_id__$1$jscomp$21$$)?$page_id$jscomp$342_page_id__$1$jscomp$21$$:(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_page_id$$);
$profile$jscomp$26_toggle_mode_selector$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$170$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$170$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$7$$,$APP.$cljs$core$not$$)});var $on_thread_click$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$342_page_id__$1$jscomp$21$$),$APP.$rumext$v2$adapt$$($from_viewer$jscomp$1$$)],
function($thread$jscomp$39$$){return $APP.$cljs$core$truth_$$($from_viewer$jscomp$1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$comments$open_thread$$($thread$jscomp$39$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"viewer"],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$comments$navigate_to_comment$$($thread$jscomp$39$$))});
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_comments__comments-section "+($APP.$cljs$core$truth_$$($from_viewer$jscomp$1$$)?"main_ui_workspace_comments__from-viewer":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$panel_title$panel_title_STAR_$$,{className:"main_ui_workspace_comments__comments-title",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.comments"),onClose:$close_section_props_73488_threads$jscomp$9$$}),(0,$APP.$rumext$v2$jsxs$$)("button",
{onClick:$profile$jscomp$26_toggle_mode_selector$$,className:"main_ui_workspace_comments__mode-dropdown-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_comments__mode-label",children:function(){var $G__73490$$=$APP.$cljs$cst$320$mode$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$23$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$G__73490$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2124$all$$,$G__73490$$))return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.show-all-comments");
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3479$yours$$,$G__73490$$))return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.show-your-comments");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3431$mentions$$,$G__73490$$))return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.show-mentions");throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__73490$$)].join(""));}()}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_comments__arrow-icon",children:$APP.$app$main$ui$icons$arrow$$})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$options_QMARK__profiles$jscomp$1$$,"on-close":function(){return $APP.$cljs$core$reset_BANG_$$($state_STAR_$jscomp$7$$,!1)},children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$comments$sidebar_options$$,{local:$local$jscomp$23$$,"from-viewer":$from_viewer$jscomp$1$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_comments__comments-section-content",
children:$APP.$cljs$core$seq$$($tgroups_threads__$1_threads_map$jscomp$1$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_comments__thread-groups",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_sidebar_thread_group_STAR_$$,{group:$APP.$cljs$core$first$$($tgroups_threads__$1_threads_map$jscomp$1$$),onThreadClick:$on_thread_click$jscomp$2$$,profiles:$profiles__$1$$}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$43$$,
$tgroup$$){$out_arr__44124__auto__$jscomp$43$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_sidebar_thread_group_STAR_$$,{group:$tgroup$$,onThreadClick:$on_thread_click$jscomp$2$$,profiles:$profiles__$1$$},$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($tgroup$$)));return $out_arr__44124__auto__$jscomp$43$$},[],$APP.$cljs$core$rest$$($tgroups_threads__$1_threads_map$jscomp$1$$))]}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_comments__thread-group-placeholder",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"comments",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.no-comments-available")})})})]})};
$APP.$app$main$data$exports$files$open_export_dialog$$=function($files$jscomp$22_files__$1$jscomp$4$$){$files$jscomp$22_files__$1$jscomp$4$$=$app$main$data$exports$files$check_export_files$$($files$jscomp$22_files__$1$jscomp$4$$);typeof $app$main$data$exports$files$export_files_73210$$==="undefined"&&($app$main$data$exports$files$export_files_73210$$=function($files$jscomp$23$$,$meta73211$$){this.files=$files$jscomp$23$$;this.$meta73211$=$meta73211$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$exports$files$export_files_73210$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$files$export_files_73210$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5015$app_DOT_main_DOT_data_DOT_exports_DOT_files_SLASH_export_files$$},$app$main$data$exports$files$export_files_73210$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73212$$,$meta73211__$1$$){return new $app$main$data$exports$files$export_files_73210$$(this.files,
$meta73211__$1$$)},$app$main$data$exports$files$export_files_73210$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73211$},$app$main$data$exports$files$export_files_73210$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$files$export_files_73210$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2776$$,$state$jscomp$1065$$){var $team_id$jscomp$116$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1065$$,
$APP.$cljs$cst$1926$current_team_id$$);return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"export-binary-files",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard",$APP.$cljs$cst$954$format$$,"binfile-v3",$APP.$cljs$cst$4963$num_files$$,$APP.$cljs$core$count$$(this.files)],null))),$APP.$beicon$v2$core$map$$(function($files__$1$jscomp$5$$){return $APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5015$app_DOT_main_DOT_data_DOT_exports_DOT_files_SLASH_export_files$$,$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$116$$,$APP.$cljs$cst$1916$files$$,$files__$1$jscomp$5$$],null))},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$mapcat$$(function($file$jscomp$87$$){return $APP.$beicon$v2$core$map$$(function($p1__73209_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($file$jscomp$87$$,
$APP.$cljs$cst$2485$has_libraries$$,$p1__73209_SHARP_$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2486$has_file_libraries$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$87$$)],null)))},$APP.$beicon$v2$core$from$$(this.files)))))});return new $app$main$data$exports$files$export_files_73210$$($files$jscomp$22_files__$1$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$versions$initialize_version$$=function(){typeof $app$main$data$workspace$versions$initialize_version_73323$$==="undefined"&&($app$main$data$workspace$versions$initialize_version_73323$$=function($meta73324$$){this.$meta73324$=$meta73324$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$initialize_version_73323$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$initialize_version_73323$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5031$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_initialize_version$$},$app$main$data$workspace$versions$initialize_version_73323$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73325$$,$meta73324__$1$$){return new $app$main$data$workspace$versions$initialize_version_73323$$($meta73324__$1$$)},$app$main$data$workspace$versions$initialize_version_73323$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73324$},$app$main$data$workspace$versions$initialize_version_73323$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$initialize_version_73323$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2784_team_id$jscomp$117$$,$state$jscomp$1071$$,$stream$jscomp$100$$){var $page_id$jscomp$343$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1071$$),$file_id$jscomp$328$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1071$$);$_$jscomp$2784_team_id$jscomp$117$$=
$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1071$$);return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$workspace$pages$initialize_page$$($file_id$jscomp$328$$,$page_id$jscomp$343$$)},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4462$app_DOT_main_DOT_data_DOT_workspace_SLASH_bundle_fetched$$),$stream$jscomp$100$$))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$hide$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$5032$restore_dialog$$])),$app$main$data$workspace$initialize_file$$($_$jscomp$2784_team_id$jscomp$117$$,$file_id$jscomp$328$$)))},$app$main$data$workspace$versions$initialize_version_73323$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$initialize_version_73323$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $app$main$data$workspace$thumbnails$clear_queue_BANG_$$()});return new $app$main$data$workspace$versions$initialize_version_73323$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$versions$wait_for_persistence$$=function($file_id$jscomp$329$$,$snapshot_id$$){return $APP.$beicon$v2$core$mapcat$$(function(){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5033$restore_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$329$$,$APP.$cljs$cst$266$id$$,$snapshot_id$$],null))},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__73331_SHARP_$$){return $p1__73331_SHARP_$$==
null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3151$saved$$,$p1__73331_SHARP_$$)},$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$refs$persistence_state$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1326$emit_current_value_QMARK_$$,!0],null)))))};
$APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$=function($can_focus__$1_props_73292$$){var $can_focus$$=void 0,$props$jscomp$244$$=void 0;({canFocus:$can_focus$$,...$props$jscomp$244$$}=$can_focus__$1_props_73292$$);$can_focus__$1_props_73292$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($can_focus$$,!0);return(0,$APP.$rumext$v2$create_element$$)("li",{...$props$jscomp$244$$,role:"menuitem",tabIndex:$APP.$cljs$core$truth_$$($can_focus__$1_props_73292$$)?"0":
"-1"})};
$app$main$ui$components$dropdown_menu$internal_dropdown_menu_STAR_$$=function($class$$jscomp$35_props_73301$$){function $on_key_down$jscomp$4$$($event$jscomp$173_target$jscomp$138$$){var $temp__5825__auto__$jscomp$272$$=$APP.$rumext$v2$ref_val$$($container$jscomp$79$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$272$$)){var $entries$jscomp$21$$=$APP.$cljs$core$vec$$($APP.$app$util$dom$query_all$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5825__auto__$jscomp$272$$,"[role\x3dmenuitem]"));if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$173_target$jscomp$138$$))){var $selected$jscomp$123$$=
$APP.$app$util$globals$document$$.activeElement,$index$jscomp$382$$=$APP.$app$common$data$index_of_pred$$($entries$jscomp$21$$,function($p1__73297_SHARP_$$){return $p1__73297_SHARP_$$===$selected$jscomp$123$$});$event$jscomp$173_target$jscomp$138$$=$index$jscomp$382$$==null?$APP.$cljs$core$peek$$($entries$jscomp$21$$):function(){var $or__5025__auto__$jscomp$938$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($entries$jscomp$21$$,$index$jscomp$382$$-1);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$938$$)?
$or__5025__auto__$jscomp$938$$:$APP.$cljs$core$peek$$($entries$jscomp$21$$)}();return $APP.$app$util$dom$focus_BANG_$$($event$jscomp$173_target$jscomp$138$$)}return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$173_target$jscomp$138$$))?($selected$jscomp$123$$=$APP.$app$util$globals$document$$.activeElement,$index$jscomp$382$$=$APP.$app$common$data$index_of_pred$$($entries$jscomp$21$$,function($p1__73298_SHARP_$$){return $p1__73298_SHARP_$$===$selected$jscomp$123$$}),
$event$jscomp$173_target$jscomp$138$$=$index$jscomp$382$$==null?$APP.$cljs$core$first$$($entries$jscomp$21$$):function(){var $or__5025__auto__$jscomp$939$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($entries$jscomp$21$$,$index$jscomp$382$$+1);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$939$$)?$or__5025__auto__$jscomp$939$$:$APP.$cljs$core$first$$($entries$jscomp$21$$)}(),$APP.$app$util$dom$focus_BANG_$$($event$jscomp$173_target$jscomp$138$$)):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$173_target$jscomp$138$$))?
($selected$jscomp$123$$=$APP.$app$util$globals$document$$.activeElement,$APP.$app$util$dom$prevent_default$$($event$jscomp$173_target$jscomp$138$$),$APP.$app$util$dom$click$$($selected$jscomp$123$$)):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$tab_QMARK_$$)($event$jscomp$173_target$jscomp$138$$))?$on_close$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$7$$():null}return null}function $on_keyup$jscomp$1$$($event$jscomp$172$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$172$$))?
$on_close$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$7$$():null}var $children$jscomp$278$$=$class$$jscomp$35_props_73301$$.children,$on_close$jscomp$7$$=$class$$jscomp$35_props_73301$$.onClose,$id$jscomp$867$$=$class$$jscomp$35_props_73301$$.id;$class$$jscomp$35_props_73301$$=$class$$jscomp$35_props_73301$$.className;var $on_click$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_close$jscomp$7$$)],
function($event$jscomp$171$$){var $target$jscomp$137$$=$APP.$app$util$dom$get_target$$($event$jscomp$171$$);return $APP.$app$config$check_platform_QMARK_$$()&&$event$jscomp$171$$.ctrlKey||!$APP.$cljs$core$not$$($target$jscomp$137$$.data_no_close)||!$APP.$cljs$core$fn_QMARK_$$($on_close$jscomp$7$$)?null:$on_close$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$7$$()}),$container$jscomp$79$$=(0,$APP.$rumext$v2$use_ref$$)();$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$867$$)],
function(){return $APP.$cljs$core$truth_$$($id$jscomp$867$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5054$dropdown_SLASH_open$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$id$jscomp$867$$],null))):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_close$jscomp$7$$),$APP.$rumext$v2$adapt$$($id$jscomp$867$$)],function(){if($APP.$cljs$core$truth_$$($id$jscomp$867$$)){var $stream$jscomp$101$$=
$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__73299_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$867$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73299_SHARP_$$))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$5054$dropdown_SLASH_open$$),$APP.$app$main$store$stream$$)))),$subs$jscomp$19$$=$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$04$$($stream$jscomp$101$$,
null,null,$on_close$jscomp$7$$);return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$19$$)}}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $keys$jscomp$55$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"click",$on_click$jscomp$12$$),$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"contextmenu",$on_click$jscomp$12$$),
$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"keyup",$on_keyup$jscomp$1$$),$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"keydown",$on_key_down$jscomp$4$$)],null);return function(){for(var $c__5548__auto__$jscomp$22_seq__73319_temp__5825__auto__$jscomp$273$$=$APP.$cljs$core$seq$$($keys$jscomp$55$$),$G__73352_chunk__73320_seq__73319__$1$$=null,$G__73351_count__73321$$=0,$i__73322$$=0;;)if($i__73322$$<$G__73351_count__73321$$){var $G__73353_key$jscomp$391$$=$G__73352_chunk__73320_seq__73319__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$i__73322$$);$APP.$goog$events$unlistenByKey$$($G__73353_key$jscomp$391$$);$i__73322$$+=1}else if($c__5548__auto__$jscomp$22_seq__73319_temp__5825__auto__$jscomp$273$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$22_seq__73319_temp__5825__auto__$jscomp$273$$))$G__73352_chunk__73320_seq__73319__$1$$=$c__5548__auto__$jscomp$22_seq__73319_temp__5825__auto__$jscomp$273$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__73352_chunk__73320_seq__73319__$1$$)?($c__5548__auto__$jscomp$22_seq__73319_temp__5825__auto__$jscomp$273$$=
$APP.$cljs$core$_chunked_first$$($G__73352_chunk__73320_seq__73319__$1$$),$G__73351_count__73321$$=$APP.$cljs$core$_chunked_rest$$($G__73352_chunk__73320_seq__73319__$1$$),$G__73352_chunk__73320_seq__73319__$1$$=$c__5548__auto__$jscomp$22_seq__73319_temp__5825__auto__$jscomp$273$$,$G__73353_key$jscomp$391$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$22_seq__73319_temp__5825__auto__$jscomp$273$$),$c__5548__auto__$jscomp$22_seq__73319_temp__5825__auto__$jscomp$273$$=$G__73351_count__73321$$,$G__73351_count__73321$$=
$G__73353_key$jscomp$391$$):($G__73353_key$jscomp$391$$=$APP.$cljs$core$first$$($G__73352_chunk__73320_seq__73319__$1$$),$APP.$goog$events$unlistenByKey$$($G__73353_key$jscomp$391$$),$c__5548__auto__$jscomp$22_seq__73319_temp__5825__auto__$jscomp$273$$=$APP.$cljs$core$next$$($G__73352_chunk__73320_seq__73319__$1$$),$G__73352_chunk__73320_seq__73319__$1$$=null,$G__73351_count__73321$$=0),$i__73322$$=0;else return null}});return(0,$APP.$rumext$v2$jsx$$)("ul",{role:"menu",ref:$container$jscomp$79$$,
className:$class$$jscomp$35_props_73301$$,children:$children$jscomp$278$$})};$APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$=function($props_73330$$){return $APP.$cljs$core$truth_$$($props_73330$$.show)?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$components$dropdown_menu$internal_dropdown_menu_STAR_$$,$props_73330$$):null};
$APP.$app$main$data$nitrate$show_nitrate_popup$cljs$0core$0IFn$0_invoke$0arity$02$$=function($popup_type$jscomp$1$$,$extra_props$$){typeof $app$main$data$nitrate$show_nitrate_popup_73339$$==="undefined"&&($app$main$data$nitrate$show_nitrate_popup_73339$$=function($popup_type$jscomp$2$$,$extra_props$jscomp$1$$,$meta73340$$){this.$popup_type$=$popup_type$jscomp$2$$;this.$extra_props$=$extra_props$jscomp$1$$;this.$meta73340$=$meta73340$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$nitrate$show_nitrate_popup_73339$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$show_nitrate_popup_73339$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5057$app_DOT_main_DOT_data_DOT_nitrate_SLASH_show_nitrate_popup$$},$app$main$data$nitrate$show_nitrate_popup_73339$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73341$$,$meta73340__$1$$){return new $app$main$data$nitrate$show_nitrate_popup_73339$$(this.$popup_type$,
this.$extra_props$,$meta73340__$1$$)},$app$main$data$nitrate$show_nitrate_popup_73339$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73340$},$app$main$data$nitrate$show_nitrate_popup_73339$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$show_nitrate_popup_73339$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$7058$$=this;return $APP.$beicon$v2$core$map$$(function($connectivity$$){return $APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$7058$$.$popup_type$,
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($connectivity$$)?$connectivity$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$self__$jscomp$7058$$.$extra_props$])))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5058$app_DOT_main_DOT_data_DOT_nitrate_SLASH_get_nitrate_connectivity$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$))});return new $app$main$data$nitrate$show_nitrate_popup_73339$$($popup_type$jscomp$1$$,
$extra_props$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$nitrate$go_to_nitrate_cc_create_org$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2462$href$$,"/control-center/?action\x3dcreate-org"])))};
$APP.$app$main$data$nitrate$go_to_buy_nitrate_license$cljs$0core$0IFn$0_invoke$0arity$02$$=function($G__73372$jscomp$inline_7457_subscription$jscomp$1$$,$callback$jscomp$92_href$jscomp$14_params$jscomp$358$$){$G__73372$jscomp$inline_7457_subscription$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3201$subscription$$,$G__73372$jscomp$inline_7457_subscription$jscomp$1$$],null);$callback$jscomp$92_href$jscomp$14_params$jscomp$358$$=$APP.$cljs$core$truth_$$($callback$jscomp$92_href$jscomp$14_params$jscomp$358$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__73372$jscomp$inline_7457_subscription$jscomp$1$$,$APP.$cljs$cst$2354$callback$$,$callback$jscomp$92_href$jscomp$14_params$jscomp$358$$):$G__73372$jscomp$inline_7457_subscription$jscomp$1$$;$callback$jscomp$92_href$jscomp$14_params$jscomp$358$$="/control-center/licenses/start?"+($APP.$app$common$uri$map__GT_query_string$cljs$0core$0IFn$0_invoke$0arity$02$$($callback$jscomp$92_href$jscomp$14_params$jscomp$358$$)??"");return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2462$href$$,
$callback$jscomp$92_href$jscomp$14_params$jscomp$358$$])))};
$APP.$app$main$data$nitrate$is_valid_license_QMARK_$$=function($profile$jscomp$27$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1233$nitrate$$)&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,["trialing",null,"past_due",null,"active",null],null),null),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profile$jscomp$27$$,$APP.$cljs$cst$3201$subscription$$),
$APP.$cljs$cst$109$status$$))};
$app$main$data$nitrate$leave_org$$=function($p__73376$$){var $map__73377__$1$$=$APP.$cljs$core$__destructure_map$$($p__73376$$),$id$jscomp$868$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73377__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$404$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73377__$1$$,$APP.$cljs$cst$725$name$$),$default_team_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73377__$1$$,$APP.$cljs$cst$2496$default_team_id$$),$teams_to_delete$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73377__$1$$,$cljs$cst$5059$teams_to_delete$$),$teams_to_leave$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73377__$1$$,$cljs$cst$5060$teams_to_leave$$),$on_error$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73377__$1$$,$APP.$cljs$cst$1295$on_error$$);typeof $app$main$data$nitrate$leave_org_73378$$==="undefined"&&($app$main$data$nitrate$leave_org_73378$$=function($default_team_id$jscomp$1$$,$on_error$jscomp$54$$,
$map__73377$jscomp$1$$,$name$jscomp$405$$,$params$jscomp$360$$,$teams_to_leave$jscomp$1$$,$teams_to_delete$jscomp$1$$,$id$jscomp$869$$,$p__73376$jscomp$1$$,$meta73379$$){this.$default_team_id$=$default_team_id$jscomp$1$$;this.$on_error$=$on_error$jscomp$54$$;this.$map__73377$=$map__73377$jscomp$1$$;this.name=$name$jscomp$405$$;this.params=$params$jscomp$360$$;this.$teams_to_leave$=$teams_to_leave$jscomp$1$$;this.$teams_to_delete$=$teams_to_delete$jscomp$1$$;this.id=$id$jscomp$869$$;this.$p__73376$=
$p__73376$jscomp$1$$;this.$meta73379$=$meta73379$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$nitrate$leave_org_73378$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$leave_org_73378$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5061$app_DOT_main_DOT_data_DOT_nitrate_SLASH_leave_org$$},$app$main$data$nitrate$leave_org_73378$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_73380$$,$meta73379__$1$$){return new $app$main$data$nitrate$leave_org_73378$$(this.$default_team_id$,this.$on_error$,this.$map__73377$,this.name,this.params,this.$teams_to_leave$,this.$teams_to_delete$,this.id,this.$p__73376$,$meta73379__$1$$)},$app$main$data$nitrate$leave_org_73378$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73379$},$app$main$data$nitrate$leave_org_73378$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$leave_org_73378$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2801$$,$state$jscomp$1081$$){var $self__$jscomp$7062$$=this,$profile_team_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1081$$,$APP.$cljs$cst$1914$profile$$),$APP.$cljs$cst$2496$default_team_id$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$7062$$.$on_error$,$APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$fetch_teams$$(),
$APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,$profile_team_id$$])),$APP.$app$main$data$modal$hide$$(),$APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dasboard.leave-org.toast",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$7062$$.name])),
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$2344$success$$],null)))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5061$app_DOT_main_DOT_data_DOT_nitrate_SLASH_leave_org$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,$self__$jscomp$7062$$.id,$APP.$cljs$cst$725$name$$,$self__$jscomp$7062$$.name,$APP.$cljs$cst$2496$default_team_id$$,$self__$jscomp$7062$$.$default_team_id$,$cljs$cst$5059$teams_to_delete$$,
$self__$jscomp$7062$$.$teams_to_delete$,$cljs$cst$5060$teams_to_leave$$,$self__$jscomp$7062$$.$teams_to_leave$],null))))});return new $app$main$data$nitrate$leave_org_73378$$($default_team_id$$,$on_error$jscomp$53$$,$map__73377__$1$$,$name$jscomp$404$$,$map__73377__$1$$,$teams_to_leave$$,$teams_to_delete$$,$id$jscomp$868$$,$p__73376$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$ui$ds$product$cta$cta_STAR_$$=function($class$__$1$jscomp$6_props_73435$$){var $children$jscomp$279$$=void 0,$title$jscomp$21$$=void 0,$class$$jscomp$36$$=void 0,$props$jscomp$246$$=void 0;({className:$class$$jscomp$36$$,title:$title$jscomp$21$$,children:$children$jscomp$279$$,...$props$jscomp$246$$}=$class$__$1$jscomp$6_props_73435$$);$class$__$1$jscomp$6_props_73435$$=$APP.$app$common$data$append_class$$($class$$jscomp$36$$,"main_ui_ds_product_cta__cta");return(0,$APP.$rumext$v2$create_element$$)("div",
{...$props$jscomp$246$$,className:$class$__$1$jscomp$6_props_73435$$,"data-testid":"cta"},(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_product_cta__cta-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"headline-small",className:"main_ui_ds_product_cta__placeholder-title",children:$title$jscomp$21$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_product_cta__cta-message",children:$children$jscomp$279$$}))};
$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$=function($p__73495_type$jscomp$588$$){var $and__5023__auto____$1$jscomp$inline_7459_map__73497__$1$$=$APP.$cljs$core$__destructure_map$$($p__73495_type$jscomp$588$$);$p__73495_type$jscomp$588$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto____$1$jscomp$inline_7459_map__73497__$1$$,$APP.$cljs$cst$139$type$$);var $JSCompiler_inline_result$jscomp$1348_status$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto____$1$jscomp$inline_7459_map__73497__$1$$,
$APP.$cljs$cst$109$status$$);$APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$inline_7459_map__73497__$1$$)?($and__5023__auto____$1$jscomp$inline_7459_map__73497__$1$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto____$1$jscomp$inline_7459_map__73497__$1$$),$JSCompiler_inline_result$jscomp$1348_status$jscomp$19$$=$APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$inline_7459_map__73497__$1$$)?!$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,["unpaid",null,"canceled",null],null),null),$JSCompiler_inline_result$jscomp$1348_status$jscomp$19$$):$and__5023__auto____$1$jscomp$inline_7459_map__73497__$1$$):$JSCompiler_inline_result$jscomp$1348_status$jscomp$19$$=$and__5023__auto____$1$jscomp$inline_7459_map__73497__$1$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1348_status$jscomp$19$$)?$p__73495_type$jscomp$588$$:"professional"};
$app$main$ui$dashboard$subscription$cta_power_up_STAR_$$=function($props_73498_top_title$$){var $bottom_button$$=$props_73498_top_title$$.bottomButton,$bottom_button_href$$=$props_73498_top_title$$.bottomButtonHref,$has_dropdown$$=$props_73498_top_title$$.hasDropdown,$bottom_description$$=$props_73498_top_title$$.bottomDescription,$top_description$$=$props_73498_top_title$$.topDescription,$is_highlighted$$=$props_73498_top_title$$.isHighlighted;$props_73498_top_title$$=$props_73498_top_title$$.topTitle;
var $show_data_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_data$$=$APP.$cljs$core$_deref$$($show_data_STAR_$$),$handle_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$174$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$174$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_data_STAR_$$,$APP.$cljs$core$not$$)}),$handle_navigation$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$175$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$175$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2462$href$$,$bottom_button_href$$])))});return(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$handle_click$$,className:"main_ui_dashboard_subscription__cta-power-up "+($APP.$cljs$core$truth_$$($is_highlighted$$)?"main_ui_dashboard_subscription__highlighted":""),children:[(0,$APP.$rumext$v2$jsxs$$)("button",
{className:"main_ui_dashboard_subscription__cta-top-section "+($APP.$cljs$core$not$$($has_dropdown$$)?"main_ui_dashboard_subscription__cta-without-dropdown":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_subscription__content",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_subscription__cta-title",children:$props_73498_top_title$$}),(0,$APP.$rumext$v2$jsx$$)("span",{"data-testid":"subscription-name",className:"main_ui_dashboard_subscription__cta-text",
children:$top_description$$})]}),$APP.$cljs$core$truth_$$($has_dropdown$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($has_dropdown$$)?$show_data$$:$has_dropdown$$)?"arrow-up":"arrow-down",className:"main_ui_dashboard_subscription__icon-dropdown",size:"s"}):null]}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($has_dropdown$$)?$show_data$$:$has_dropdown$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_subscription__cta-bottom-section",
children:$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{content:$bottom_description$$,className:"main_ui_dashboard_subscription__content",tagName:"span"})}):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($bottom_description$$)?$bottom_button$$:$bottom_description$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_subscription__cta-bottom-section",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_subscription__content",children:$bottom_description$$}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",className:"main_ui_dashboard_subscription__cta-bottom-button",onClick:$handle_navigation$$,children:$bottom_button$$})]}):null]})};
$app$main$ui$dashboard$subscription$subscription_sidebar_STAR_$$=function($props_73499_subscription_type$$){var $subscription$jscomp$3_subscription_is_trial$$=$APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($props_73499_subscription_type$$.profile));$props_73499_subscription_type$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($subscription$jscomp$3_subscription_is_trial$$);$subscription$jscomp$3_subscription_is_trial$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($subscription$jscomp$3_subscription_is_trial$$),"trialing");var $subscription_href$$=""+($APP.$lambdaisland$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"#/settings/subscriptions"]))??"");switch($props_73499_subscription_type$$){case "professional":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$cta_power_up_STAR_$$,
{topTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.power-up.your-subscription"),topDescription:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.power-up.professional.top-title"),bottomDescription:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.power-up.professional.bottom-description"),bottomButton:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.power-up.professional.bottom-button"),
bottomButtonHref:$subscription_href$$,hasDropdown:!1,isHighlighted:!0});case "unlimited":return $subscription$jscomp$3_subscription_is_trial$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$cta_power_up_STAR_$$,{topTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.power-up.your-subscription"),topDescription:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.power-up.trial.top-title"),bottomDescription:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.dashboard.power-up.trial.bottom-description",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$subscription_href$$])),hasDropdown:!0,isHighlighted:!1}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$cta_power_up_STAR_$$,{topTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.power-up.your-subscription"),topDescription:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.power-up.unlimited-plan"),bottomDescription:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.dashboard.power-up.unlimited.bottom-text",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$subscription_href$$])),hasDropdown:!0,isHighlighted:!1});case "enterprise":return $subscription$jscomp$3_subscription_is_trial$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$cta_power_up_STAR_$$,{topTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.power-up.your-subscription"),topDescription:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.power-up.enterprise-trial.top-title"),
hasDropdown:!1,isHighlighted:!1}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$cta_power_up_STAR_$$,{topTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.power-up.your-subscription"),topDescription:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.power-up.enterprise-plan"),hasDropdown:!1,isHighlighted:!1});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($props_73499_subscription_type$$)].join(""));
}};
$app$main$ui$dashboard$subscription$nitrate_sidebar_STAR_$$=function($nitrate_QMARK__props_73503$$){var $profile$jscomp$29$$=$nitrate_QMARK__props_73503$$.profile,$teams$jscomp$8$$=$nitrate_QMARK__props_73503$$.teams;$nitrate_QMARK__props_73503$$=$APP.$app$main$data$nitrate$is_valid_license_QMARK_$$($profile$jscomp$29$$);var $nitrate_license$$=$APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$29$$),$subscription_type$jscomp$1$$=$nitrate_QMARK__props_73503$$?$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($nitrate_license$$):$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$29$$))),
$no_orgs_created_QMARK__orgs$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($teams$jscomp$8$$)],function(){return $APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($entries$jscomp$22_p__73507$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($entries$jscomp$22_p__73507$$,0,null);$entries$jscomp$22_p__73507$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($entries$jscomp$22_p__73507$$,
1,null);return $APP.$cljs$core$first$$($entries$jscomp$22_p__73507$$)},$APP.$cljs$core$group_by$$($APP.$cljs$cst$3256$organization_id$$,$APP.$cljs$core$vals$$($teams$jscomp$8$$)))))});$no_orgs_created_QMARK__orgs$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($no_orgs_created_QMARK__orgs$$),1);var $handle_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($nitrate_license$$),$APP.$rumext$v2$adapt$$($subscription_type$jscomp$1$$)],
function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$1$$,"unlimited")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$nitrate$show_nitrate_popup$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5065$nitrate_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5066$nitrate_license$$,$nitrate_license$$,$APP.$cljs$cst$5067$show_contact_sales_option$$,!0],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$nitrate$show_nitrate_popup$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5068$nitrate_form$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$))}),$handle_go_to_cc$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$data$nitrate$go_to_nitrate_cc_create_org$$);return $nitrate_QMARK__props_73503$$&&$no_orgs_created_QMARK__orgs$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_subscription__nitrate-banner main_ui_dashboard_subscription__highlighted",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_subscription__nitrate-content",children:(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_dashboard_subscription__nitrate-title",children:"Create your first org"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_subscription__nitrate-content",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_subscription__nitrate-info",children:"Some further information and explanation."}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",className:"main_ui_dashboard_subscription__nitrate-bottom-button",
onClick:$handle_go_to_cc$$,children:"CREATE ORGANIZATION"})]})]}):$nitrate_QMARK__props_73503$$?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_subscription__nitrate-banner main_ui_dashboard_subscription__highlighted",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_subscription__nitrate-content",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_subscription__nitrate-title",children:"Unlock Nitrate features"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_subscription__nitrate-content",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_subscription__nitrate-info",children:"Some further information and explanation."}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",className:"main_ui_dashboard_subscription__nitrate-bottom-button",onClick:$handle_click$jscomp$1$$,children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$29$$))?
"UPGRADE TO NITRATE":"Try 14 days for free"})]})]})};
$app$main$ui$dashboard$subscription$nitrate_current_plan_STAR_$$=function($nitrate_QMARK_$jscomp$1_props_73517$$){var $profile$jscomp$30_subscription$jscomp$4$$=$nitrate_QMARK_$jscomp$1_props_73517$$.profile;$nitrate_QMARK_$jscomp$1_props_73517$$=$APP.$app$main$data$nitrate$is_valid_license_QMARK_$$($profile$jscomp$30_subscription$jscomp$4$$);var $nitrate_license$jscomp$1$$=$APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$30_subscription$jscomp$4$$);$profile$jscomp$30_subscription$jscomp$4$$=
$APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$30_subscription$jscomp$4$$));var $subscription_type$jscomp$2$$=$nitrate_QMARK_$jscomp$1_props_73517$$?$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($nitrate_license$jscomp$1$$):$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($profile$jscomp$30_subscription$jscomp$4$$),$subscription_is_trial$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("trialing",
$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($nitrate_QMARK_$jscomp$1_props_73517$$?$nitrate_license$jscomp$1$$:$profile$jscomp$30_subscription$jscomp$4$$));return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_subscription__nitrate-current-plan",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_subscription__nitrate-current-plan-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.current-plan.title")}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_subscription__nitrate-current-plan-text",children:function(){switch($subscription_type$jscomp$2$$){case "professional":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.current-plan.professional");case "unlimited":return $subscription_is_trial$jscomp$1$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.current-plan.unlimited-trial"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.current-plan.unlimited");
case "nitrate":return $subscription_is_trial$jscomp$1$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.current-plan.nitrate-trial"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.current-plan.nitrate");case "enterprise":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.current-plan.enterprise");default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($subscription_type$jscomp$2$$)].join(""));
}}()})]})};
$app$main$ui$dashboard$subscription$menu_team_icon_STAR_$$=function($props_73524_subscription_type$jscomp$4$$){$props_73524_subscription_type$jscomp$4$$=$props_73524_subscription_type$jscomp$4$$.subscriptionType;a:switch($props_73524_subscription_type$jscomp$4$$){case "unlimited":var $JSCompiler_inline_result$jscomp$1349$$="character-u";break a;case "enterprise":$JSCompiler_inline_result$jscomp$1349$$="character-e";break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($props_73524_subscription_type$jscomp$4$$)].join(""));}return(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_dashboard_subscription__subscription-icon-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$JSCompiler_inline_result$jscomp$1349$$,className:"main_ui_dashboard_subscription__subscription-icon",size:"s",title:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_73524_subscription_type$jscomp$4$$,"unlimited")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.power-up.unlimited-plan"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.power-up.enterprise-plan"),"data-testid":"subscription-icon"})})};
$app$main$ui$dashboard$subscription$dashboard_cta_STAR_$$=function($cta_message_props_73530_subscription_type$jscomp$5$$){var $editors$jscomp$1_subscription$jscomp$6$$=$APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($cta_message_props_73530_subscription_type$jscomp$5$$.profile));$cta_message_props_73530_subscription_type$jscomp$5$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($editors$jscomp$1_subscription$jscomp$6$$);
var $go_to_subscription$jscomp$1$$=""+($APP.$lambdaisland$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"#/settings/subscriptions"]))??""),$cta_title_seats$$=$APP.$cljs$cst$5070$quantity$$.$cljs$core$IFn$_invoke$arity$1$($editors$jscomp$1_subscription$jscomp$6$$);$editors$jscomp$1_subscription$jscomp$6$$=$APP.$cljs$core$count$$($APP.$cljs$cst$3200$editors$$.$cljs$core$IFn$_invoke$arity$1$($editors$jscomp$1_subscription$jscomp$6$$));
$cta_title_seats$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("professional",$cta_message_props_73530_subscription_type$jscomp$5$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.dashboard.professional-dashboard-cta-title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$editors$jscomp$1_subscription$jscomp$6$$])):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("unlimited",$cta_message_props_73530_subscription_type$jscomp$5$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.dashboard.unlimited-dashboard-cta-title",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cta_title_seats$$,$editors$jscomp$1_subscription$jscomp$6$$])):null;$cta_message_props_73530_subscription_type$jscomp$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("professional",$cta_message_props_73530_subscription_type$jscomp$5$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.dashboard.professional-dashboard-cta-upgrade-owner",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$go_to_subscription$jscomp$1$$])):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("unlimited",$cta_message_props_73530_subscription_type$jscomp$5$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.dashboard.unlimited-dashboard-cta-upgrade-owner",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$go_to_subscription$jscomp$1$$])):null;return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$cta$cta_STAR_$$,{className:"main_ui_dashboard_subscription__dashboard-cta",title:$cta_title_seats$$,
children:$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{tagName:"span",className:"main_ui_dashboard_subscription__cta-message",content:$cta_message_props_73530_subscription_type$jscomp$5$$})})};
$app$main$ui$dashboard$subscription$show_subscription_dashboard_banner_QMARK_$$=function($profile$jscomp$32_subscription_type$jscomp$6$$){var $editors$jscomp$2_subscription$jscomp$7$$=$APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$32_subscription_type$jscomp$6$$));$profile$jscomp$32_subscription_type$jscomp$6$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($editors$jscomp$2_subscription$jscomp$7$$);
var $seats$jscomp$1$$=$APP.$cljs$cst$5070$quantity$$.$cljs$core$IFn$_invoke$arity$1$($editors$jscomp$2_subscription$jscomp$7$$);$editors$jscomp$2_subscription$jscomp$7$$=$APP.$cljs$core$count$$($APP.$cljs$cst$3200$editors$$.$cljs$core$IFn$_invoke$arity$1$($editors$jscomp$2_subscription$jscomp$7$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($profile$jscomp$32_subscription_type$jscomp$6$$,"professional")&&$editors$jscomp$2_subscription$jscomp$7$$>8||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($profile$jscomp$32_subscription_type$jscomp$6$$,
"unlimited")&&($seats$jscomp$1$$<25&&$editors$jscomp$2_subscription$jscomp$7$$-$seats$jscomp$1$$>=4||$seats$jscomp$1$$<25&&$editors$jscomp$2_subscription$jscomp$7$$>=25&&$editors$jscomp$2_subscription$jscomp$7$$>$seats$jscomp$1$$)};
$app$util$forms$use_rerender_fn$$=function(){var $render_fn$$=(0,$APP.$rumext$v2$useState$$)(0)[1];return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($render_fn$$)],function(){return $render_fn$$.$cljs$core$IFn$_invoke$arity$1$?$render_fn$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$inc$$):$render_fn$$($APP.$cljs$core$inc$$)})};
$app$util$forms$wrap_update_schema_fn$$=function($f$jscomp$838$$,$map__73501__$1_p__73500$$){$map__73501__$1_p__73500$$=$APP.$cljs$core$__destructure_map$$($map__73501__$1_p__73500$$);var $schema$jscomp$240$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73501__$1_p__73500$$,$APP.$cljs$cst$298$schema$$),$validators$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73501__$1_p__73500$$,$APP.$cljs$cst$5072$validators$$);return function(){function $G__73532$$($var_args$jscomp$1396$$){var $G__73533__i_args$jscomp$253$$=
null;if(arguments.length>0){$G__73533__i_args$jscomp$253$$=0;for(var $G__73533__a$$=Array(arguments.length-0);$G__73533__i_args$jscomp$253$$<$G__73533__a$$.length;)$G__73533__a$$[$G__73533__i_args$jscomp$253$$]=arguments[$G__73533__i_args$jscomp$253$$+0],++$G__73533__i_args$jscomp$253$$;$G__73533__i_args$jscomp$253$$=new $APP.$cljs$core$IndexedSeq$$($G__73533__a$$,0,null)}return $G__73532__delegate$$.call(this,$G__73533__i_args$jscomp$253$$)}function $G__73532__delegate$$($args$jscomp$252_state$jscomp$1083$$){$args$jscomp$252_state$jscomp$1083$$=
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$838$$,$args$jscomp$252_state$jscomp$1083$$);var $cleaned_val$jscomp$inline_12974$$=$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$252_state$jscomp$1083$$);var $temp__5823__auto__$jscomp$inline_12976_valid_QMARK_$jscomp$12$$=$malli$core$decoder$cljs$0core$0IFn$0_invoke$0arity$03$$($schema$jscomp$240$$);$cleaned_val$jscomp$inline_12974$$=$APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_12976_valid_QMARK_$jscomp$12$$)?
$temp__5823__auto__$jscomp$inline_12976_valid_QMARK_$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5823__auto__$jscomp$inline_12976_valid_QMARK_$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($cleaned_val$jscomp$inline_12974$$):$temp__5823__auto__$jscomp$inline_12976_valid_QMARK_$jscomp$12$$($cleaned_val$jscomp$inline_12974$$):$cleaned_val$jscomp$inline_12974$$;$temp__5823__auto__$jscomp$inline_12976_valid_QMARK_$jscomp$12$$=$APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($schema$jscomp$240$$,
$cleaned_val$jscomp$inline_12974$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_12976_valid_QMARK_$jscomp$12$$))var $JSCompiler_temp$jscomp$10837_errors$jscomp$24_errors$jscomp$inline_12983_explain$jscomp$inline_12981_value$jscomp$inline_12982$$=null;else $JSCompiler_temp$jscomp$10837_errors$jscomp$24_errors$jscomp$inline_12983_explain$jscomp$inline_12981_value$jscomp$inline_12982$$=$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$252_state$jscomp$1083$$),$JSCompiler_temp$jscomp$10837_errors$jscomp$24_errors$jscomp$inline_12983_explain$jscomp$inline_12981_value$jscomp$inline_12982$$=
$malli$core$explain$cljs$0core$0IFn$0_invoke$0arity$03$$($schema$jscomp$240$$,$JSCompiler_temp$jscomp$10837_errors$jscomp$24_errors$jscomp$inline_12983_explain$jscomp$inline_12981_value$jscomp$inline_12982$$),$JSCompiler_temp$jscomp$10837_errors$jscomp$24_errors$jscomp$inline_12983_explain$jscomp$inline_12981_value$jscomp$inline_12982$$=$app$common$schema$messages$apply_validators$$($validators$jscomp$7$$,$args$jscomp$252_state$jscomp$1083$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$schema$messages$interpret_schema_problem$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10837_errors$jscomp$24_errors$jscomp$inline_12983_explain$jscomp$inline_12981_value$jscomp$inline_12982$$))),$JSCompiler_temp$jscomp$10837_errors$jscomp$24_errors$jscomp$inline_12983_explain$jscomp$inline_12981_value$jscomp$inline_12982$$=$APP.$cljs$core$not_empty$$($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$252_state$jscomp$1083$$),
$JSCompiler_temp$jscomp$10837_errors$jscomp$24_errors$jscomp$inline_12983_explain$jscomp$inline_12981_value$jscomp$inline_12982$$]))));var $JSCompiler_inline_result$jscomp$1350_and__5023__auto____$1$jscomp$inline_7463_extra_errors$$=$APP.$cljs$core$not_empty$$($APP.$cljs$cst$5073$extra_errors$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$252_state$jscomp$1083$$));var $and__5023__auto__$jscomp$inline_7462$$=$APP.$cljs$core$not$$($JSCompiler_temp$jscomp$10837_errors$jscomp$24_errors$jscomp$inline_12983_explain$jscomp$inline_12981_value$jscomp$inline_12982$$);
$JSCompiler_inline_result$jscomp$1350_and__5023__auto____$1$jscomp$inline_7463_extra_errors$$=$and__5023__auto__$jscomp$inline_7462$$?($JSCompiler_inline_result$jscomp$1350_and__5023__auto____$1$jscomp$inline_7463_extra_errors$$=$APP.$cljs$core$not$$($JSCompiler_inline_result$jscomp$1350_and__5023__auto____$1$jscomp$inline_7463_extra_errors$$))?$temp__5823__auto__$jscomp$inline_12976_valid_QMARK_$jscomp$12$$:$JSCompiler_inline_result$jscomp$1350_and__5023__auto____$1$jscomp$inline_7463_extra_errors$$:
$and__5023__auto__$jscomp$inline_7462$$;return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($args$jscomp$252_state$jscomp$1083$$,$APP.$cljs$cst$570$errors$$,$JSCompiler_temp$jscomp$10837_errors$jscomp$24_errors$jscomp$inline_12983_explain$jscomp$inline_12981_value$jscomp$inline_12982$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5074$clean_data$$,$APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_12976_valid_QMARK_$jscomp$12$$)?$cleaned_val$jscomp$inline_12974$$:
null,$APP.$cljs$cst$5075$valid$$,$JSCompiler_inline_result$jscomp$1350_and__5023__auto____$1$jscomp$inline_7463_extra_errors$$]))}$G__73532$$.$cljs$lang$maxFixedArity$=0;$G__73532$$.$cljs$lang$applyTo$=function($arglist__73534_args$jscomp$254$$){$arglist__73534_args$jscomp$254$$=$APP.$cljs$core$seq$$($arglist__73534_args$jscomp$254$$);return $G__73532__delegate$$($arglist__73534_args$jscomp$254$$)};$G__73532$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__73532__delegate$$;return $G__73532$$}()};
$app$util$forms$make_initial_state$$=function($initial$jscomp$27_initial__$1$jscomp$1_initial_data$$,$initial_errors_initial_errors__$1_initial_errors__$2$$){$initial$jscomp$27_initial__$1$jscomp$1_initial_data$$=$APP.$cljs$core$fn_QMARK_$$($initial$jscomp$27_initial__$1$jscomp$1_initial_data$$)?$initial$jscomp$27_initial__$1$jscomp$1_initial_data$$.$cljs$core$IFn$_invoke$arity$0$?$initial$jscomp$27_initial__$1$jscomp$1_initial_data$$.$cljs$core$IFn$_invoke$arity$0$():$initial$jscomp$27_initial__$1$jscomp$1_initial_data$$():
$initial$jscomp$27_initial__$1$jscomp$1_initial_data$$;$initial$jscomp$27_initial__$1$jscomp$1_initial_data$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($initial$jscomp$27_initial__$1$jscomp$1_initial_data$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);$initial_errors_initial_errors__$1_initial_errors__$2$$=$APP.$cljs$core$fn_QMARK_$$($initial_errors_initial_errors__$1_initial_errors__$2$$)?$initial_errors_initial_errors__$1_initial_errors__$2$$.$cljs$core$IFn$_invoke$arity$0$?$initial_errors_initial_errors__$1_initial_errors__$2$$.$cljs$core$IFn$_invoke$arity$0$():
$initial_errors_initial_errors__$1_initial_errors__$2$$():$initial_errors_initial_errors__$1_initial_errors__$2$$;$initial_errors_initial_errors__$1_initial_errors__$2$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($initial_errors_initial_errors__$1_initial_errors__$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$5076$initial$$,$initial$jscomp$27_initial__$1$jscomp$1_initial_data$$,$APP.$cljs$cst$5077$initial_errors$$,
$initial_errors_initial_errors__$1_initial_errors__$2$$,$APP.$cljs$cst$142$data$$,$initial$jscomp$27_initial__$1$jscomp$1_initial_data$$,$APP.$cljs$cst$5073$extra_errors$$,$initial_errors_initial_errors__$1_initial_errors__$2$$,$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1626$touched$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null)};
$app$util$forms$t_app$0util$0forms73504$$=function($internal_state$$,$rerender_fn$$,$wrap_update_fn$$,$opts$jscomp$302$$,$meta73505$$){this.$internal_state$=$internal_state$$;this.$rerender_fn$=$rerender_fn$$;this.$wrap_update_fn$=$wrap_update_fn$$;this.$opts$=$opts$jscomp$302$$;this.$meta73505$=$meta73505$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=98304};
$APP.$app$util$forms$use_form$$=function($var_args$jscomp$1397$$){for(var $args__5755__auto__$jscomp$240$$=[],$len__5749__auto___73538$$=arguments.length,$i__5750__auto___73539$$=0;;)if($i__5750__auto___73539$$<$len__5749__auto___73538$$)$args__5755__auto__$jscomp$240$$.push(arguments[$i__5750__auto___73539$$]),$i__5750__auto___73539$$+=1;else break;return $APP.$app$util$forms$use_form$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<$args__5755__auto__$jscomp$240$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$240$$.slice(0),
0,null):null)};
$APP.$app$util$forms$use_form$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__73521_schema$jscomp$241$$){var $map__73522__$1$$=$APP.$cljs$core$__destructure_map$$($p__73521_schema$jscomp$241$$),$initial$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73522__$1$$,$APP.$cljs$cst$5076$initial$$),$initial_errors$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73522__$1$$,$APP.$cljs$cst$5077$initial_errors$$);$p__73521_schema$jscomp$241$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73522__$1$$,
$APP.$cljs$cst$298$schema$$);var $validators$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73522__$1$$,$APP.$cljs$cst$5072$validators$$),$rerender_fn$jscomp$3$$=$app$util$forms$use_rerender_fn$$(),$initial__$1$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($initial$jscomp$28$$),$APP.$rumext$v2$adapt$$($initial_errors$jscomp$1$$)],function(){return $app$util$forms$make_initial_state$$($initial$jscomp$28$$,$initial_errors$jscomp$1$$)}),
$internal_state$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)($initial__$1$jscomp$2$$),$form_mutator$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($p__73521_schema$jscomp$241$$),$APP.$rumext$v2$adapt$$($validators$jscomp$8$$)],function(){var $mutator_opts$jscomp$inline_7474$$=$APP.$cljs$core$select_keys$$($map__73522__$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$298$schema$$,$APP.$cljs$cst$5072$validators$$],
null));$mutator_opts$jscomp$inline_7474$$=new $app$util$forms$t_app$0util$0forms73504$$($internal_state$jscomp$3$$,$rerender_fn$jscomp$3$$,$app$util$forms$wrap_update_schema_fn$$,$mutator_opts$jscomp$inline_7474$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($mutator_opts$jscomp$inline_7474$$,$APP.$cljs$core$identity$$);return $mutator_opts$jscomp$inline_7474$$});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($internal_state$jscomp$3$$,
$initial__$1$jscomp$2$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($initial__$1$jscomp$2$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($form_mutator$$,$APP.$app$common$data$deep_merge$$,$initial__$1$jscomp$2$$)});return $form_mutator$$};
$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$=function($form$jscomp$156$$,$field$jscomp$3$$,$value$jscomp$738$$,$trim_QMARK_$jscomp$1$$){function $clean_errors$$($errors$jscomp$25$$){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$25$$,$field$jscomp$3$$))}return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$156$$,function($state$jscomp$1084$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$1084$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$field$jscomp$3$$],null),!0),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$field$jscomp$3$$],null),$APP.$cljs$core$truth_$$($trim_QMARK_$jscomp$1$$)?$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$738$$):$value$jscomp$738$$),$APP.$cljs$cst$570$errors$$,$clean_errors$$),$APP.$cljs$cst$5073$extra_errors$$,
$clean_errors$$),$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,"")})};
$app$util$forms$update_input_value_BANG_$$=function($form$jscomp$157$$,$field$jscomp$4$$,$value$jscomp$739$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$157$$,function($state$jscomp$1085$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc_in$$($state$jscomp$1085$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,
$field$jscomp$4$$],null),$value$jscomp$739$$),$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$dissoc$$,$field$jscomp$4$$),$APP.$cljs$cst$5073$extra_errors$$,$APP.$cljs$core$dissoc$$,"")})};
$APP.$app$main$ui$components$forms$input$$=function($children$jscomp$280_map__73547_props_73543$$){function $on_clear$jscomp$1$$($G__73548_event$jscomp$178$$){$APP.$app$util$dom$prevent_default$$($G__73548_event$jscomp$178$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($form__$1$jscomp$6$$,function($state$jscomp$1086$$){return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$1086$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$142$data$$,$input_name$$],null),""),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$input_name$$],null),!1)});$G__73548_event$jscomp$178$$=$APP.$rumext$v2$ref_val$$($input_ref$jscomp$3$$);return $G__73548_event$jscomp$178$$==null?null:$APP.$app$util$dom$focus_BANG_$$($G__73548_event$jscomp$178$$)}function $on_click$jscomp$13$$(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$6$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$input_name$$],null)))?null:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form__$1$jscomp$6$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$input_name$$],null),!0)}function $on_blur$jscomp$1$$(){return $APP.$cljs$core$reset_BANG_$$($focus_QMARK_$$,!1)}function $on_change$jscomp$18$$($event$jscomp$177_value__$1$jscomp$29$$){$event$jscomp$177_value__$1$jscomp$29$$=
$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$177_value__$1$jscomp$29$$));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form__$1$jscomp$6$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$input_name$$],null),!0);$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form__$1$jscomp$6$$,$input_name$$,$event$jscomp$177_value__$1$jscomp$29$$,
$trim$jscomp$1$$);return $on_change_value__$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_value__$1$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$name$$,$event$jscomp$177_value__$1$jscomp$29$$):$on_change_value__$1$$($APP.$cljs$core$name$$,$event$jscomp$177_value__$1$jscomp$29$$)}function $on_focus$jscomp$1$$(){return $APP.$cljs$core$reset_BANG_$$($focus_QMARK_$$,!0)}function $swap_text_password$$(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($type_SINGLEQUOTE_$$,function($input_type__$1$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("password",
$input_type__$1$$)?"text":"password"})}$children$jscomp$280_map__73547_props_73543$$=$APP.$rumext$v2$util$wrap_props$$($children$jscomp$280_map__73547_props_73543$$);var $map__73547__$1$$=$APP.$cljs$core$__destructure_map$$($children$jscomp$280_map__73547_props_73543$$),$form$jscomp$160_is_text_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73547__$1$$,$APP.$cljs$cst$179$form$$);$children$jscomp$280_map__73547_props_73543$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73547__$1$$,
$APP.$cljs$cst$342$children$$);var $help_icon_SINGLEQUOTE__placeholder$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73547__$1$$,$APP.$cljs$cst$5082$placeholder$$),$show_error$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73547__$1$$,$cljs$cst$5083$show_error$$,!0),$disabled$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73547__$1$$,$APP.$cljs$cst$2948$disabled$$),$on_change_value_on_key_press$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73547__$1$$,
$cljs$cst$5084$on_change_value$$),$show_success_QMARK__show_valid_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73547__$1$$,$cljs$cst$5085$show_success_QMARK_$$),$hint$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73547__$1$$,$APP.$cljs$cst$275$hint$$),$checked_QMARK_$jscomp$2_data_testid$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73547__$1$$,$cljs$cst$4555$data_testid$$),$label$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73547__$1$$,
$APP.$cljs$cst$2287$label$$),$trim$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73547__$1$$,$APP.$cljs$cst$3686$trim$$),$help_icon_props__$1$jscomp$56$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73547__$1$$,$APP.$cljs$cst$5086$help_icon$$),$input_type$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73547__$1$$,$APP.$cljs$cst$139$type$$,"text"),$input_name$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73547__$1$$,$APP.$cljs$cst$725$name$$),
$more_classes$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73547__$1$$,$APP.$cljs$cst$1291$class$$),$auto_focus_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73547__$1$$,$cljs$cst$5087$auto_focus_QMARK_$$,!1),$input_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(null),$data_testid__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($checked_QMARK_$jscomp$2_data_testid$jscomp$2$$,$input_name$$),$form__$1$jscomp$6$$=$APP.$cljs$core$truth_$$($form$jscomp$160_is_text_QMARK_$jscomp$2$$)?
$form$jscomp$160_is_text_QMARK_$jscomp$2$$:(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$components$forms$form_ctx$$),$type_SINGLEQUOTE_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($input_type$$),$focus_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$is_checkbox_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($type_SINGLEQUOTE_$$),"checkbox"),$is_radio_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($type_SINGLEQUOTE_$$),
"radio"),$placeholder__$1$$=($form$jscomp$160_is_text_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($type_SINGLEQUOTE_$$),"password")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($type_SINGLEQUOTE_$$),"text")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($type_SINGLEQUOTE_$$),"email"))?$APP.$cljs$core$truth_$$($help_icon_SINGLEQUOTE__placeholder$jscomp$2$$)?$help_icon_SINGLEQUOTE__placeholder$jscomp$2$$:
$label$jscomp$27$$:null,$touched_QMARK_$jscomp$2$$=function(){var $and__5023__auto__$jscomp$609$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form__$1$jscomp$6$$)),$input_name$$);return $and__5023__auto__$jscomp$609$$?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$6$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,
$input_name$$],null)):$and__5023__auto__$jscomp$609$$}(),$error$jscomp$83$$=function(){var $or__5025__auto__$jscomp$943$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$6$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$input_name$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$943$$)?$or__5025__auto__$jscomp$943$$:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$6$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,$input_name$$],null))}(),$value$jscomp$740$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form__$1$jscomp$6$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$input_name$$],null),"");$help_icon_SINGLEQUOTE__placeholder$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($input_type$$,
"password")&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($type_SINGLEQUOTE_$$),"password")?$app$main$ui$icons$shown$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($input_type$$,"password")&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($type_SINGLEQUOTE_$$),"text")?$app$main$ui$icons$hide$$:$help_icon_props__$1$jscomp$56$$;var $on_change_value__$1$$=$APP.$cljs$core$truth_$$($on_change_value_on_key_press$$)?$on_change_value_on_key_press$$:
$APP.$cljs$core$constantly$$(null);$on_change_value_on_key_press$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($input_ref$jscomp$3$$)],function($e$jscomp$329$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$329$$);return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$space_QMARK_$$)($e$jscomp$329$$))?$APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$3$$)):null});$help_icon_props__$1$jscomp$56$$=$APP.$rumext$v2$util$map__GT_props$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $G__73549_G__73550$jscomp$inline_12985$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__73547__$1$$,$APP.$cljs$cst$5086$help_icon$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$179$form$$,$APP.$cljs$cst$3686$trim$$,$APP.$cljs$cst$342$children$$,$cljs$cst$5085$show_success_QMARK_$$,$cljs$cst$5087$auto_focus_QMARK_$$,$APP.$cljs$cst$2287$label$$])),$APP.$cljs$cst$266$id$$,$APP.$cljs$core$name$$($input_name$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$550$ref$$,
$input_ref$jscomp$3$$,$APP.$cljs$cst$260$value$$,$value$jscomp$740$$,$cljs$cst$5088$auto_focus$$,$auto_focus_QMARK_$$,$APP.$cljs$cst$3386$on_click$$,$is_radio_QMARK_$$||$is_checkbox_QMARK_$$?$on_click$jscomp$13$$:null,$APP.$cljs$cst$5089$on_focus$$,$on_focus$jscomp$1$$,$APP.$cljs$cst$5090$on_blur$$,$on_blur$jscomp$1$$,$APP.$cljs$cst$5082$placeholder$$,$placeholder__$1$$,$APP.$cljs$cst$4157$on_change$$,$on_change$jscomp$18$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$core$_deref$$($type_SINGLEQUOTE_$$),
$cljs$cst$5091$tab_index$$,"0"]));$G__73549_G__73550$jscomp$inline_12985$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($value$jscomp$740$$)?$is_checkbox_QMARK_$$:$value$jscomp$740$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__73549_G__73550$jscomp$inline_12985$$,$cljs$cst$5092$default_checked$$,$value$jscomp$740$$):$G__73549_G__73550$jscomp$inline_12985$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($touched_QMARK_$jscomp$2$$)?$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$83$$):
$touched_QMARK_$jscomp$2$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__73549_G__73550$jscomp$inline_12985$$,"aria-invalid","true",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["aria-describedby","error-"+($input_name$$??"")])):$G__73549_G__73550$jscomp$inline_12985$$}());$checked_QMARK_$jscomp$2_data_testid$jscomp$2$$=$is_checkbox_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$740$$,!0);$show_success_QMARK__show_valid_QMARK_$$=
$APP.$cljs$core$truth_$$($show_success_QMARK__show_valid_QMARK_$$)?$APP.$cljs$core$truth_$$($touched_QMARK_$jscomp$2$$)?$APP.$cljs$core$not$$($error$jscomp$83$$):$touched_QMARK_$jscomp$2$$:$show_success_QMARK__show_valid_QMARK_$$;var $show_invalid_QMARK_$$=$APP.$cljs$core$truth_$$($touched_QMARK_$jscomp$2$$)?$error$jscomp$83$$:$touched_QMARK_$jscomp$2$$;return(0,$APP.$rumext$v2$jsx$$)("div",{className:""+($more_classes$$??"")+" main_ui_components_forms__input-wrapper "+(($APP.$cljs$core$truth_$$($show_success_QMARK__show_valid_QMARK_$$)?
"main_ui_components_forms__valid":"")+" "+($APP.$cljs$core$truth_$$($show_invalid_QMARK_$$)?"main_ui_components_forms__invalid":"")+" "+($is_checkbox_QMARK_$$?"main_ui_components_forms__checkbox":"")+" "+($APP.$cljs$core$truth_$$($disabled$jscomp$5$$)?"main_ui_components_forms__disabled":"")),children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$label$jscomp$27$$!=null?(0,$APP.$rumext$v2$jsxs$$)("label",{tabIndex:"-1",htmlFor:$APP.$cljs$core$name$$($input_name$$),className:($is_checkbox_QMARK_$$?
"":"main_ui_components_forms__input-with-label-form")+" "+($form$jscomp$160_is_text_QMARK_$jscomp$2$$?"main_ui_components_forms__input-label":"")+" "+($is_radio_QMARK_$$?"main_ui_components_forms__radio-label":"")+" "+($is_checkbox_QMARK_$$?"main_ui_components_forms__checkbox-label":""),children:[$label$jscomp$27$$,$is_checkbox_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("span",{tabIndex:"0",onKeyPress:$on_change_value_on_key_press$$,className:$checked_QMARK_$jscomp$2_data_testid$jscomp$2$$?"checked":"",children:$checked_QMARK_$jscomp$2_data_testid$jscomp$2$$?
$APP.$app$main$ui$icons$status_tick$$:null}):null,$is_checkbox_QMARK_$$?(0,$APP.$rumext$v2$create_element$$)("input",$help_icon_props__$1$jscomp$56$$):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_components_forms__input-and-icon",children:[(0,$APP.$rumext$v2$create_element$$)("input",$help_icon_props__$1$jscomp$56$$),$APP.$cljs$core$truth_$$($help_icon_SINGLEQUOTE__placeholder$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("span",{onClick:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("password",
$input_type$$)?$swap_text_password$$:null,className:"main_ui_components_forms__help-icon",children:$help_icon_SINGLEQUOTE__placeholder$jscomp$2$$}):null,$APP.$cljs$core$truth_$$($show_success_QMARK__show_valid_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_forms__valid-icon",children:$APP.$app$main$ui$icons$tick$$}):null,$APP.$cljs$core$truth_$$($show_invalid_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("button",{type:"button",tabIndex:"-1",onClick:$on_clear$jscomp$1$$,className:"main_ui_components_forms__invalid-icon",
children:$APP.$app$main$ui$icons$close$$}):null]})]}):$children$jscomp$280_map__73547_props_73543$$!=null?(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:$APP.$cljs$core$name$$($input_name$$),children:[(0,$APP.$rumext$v2$create_element$$)("input",$help_icon_props__$1$jscomp$56$$),$children$jscomp$280_map__73547_props_73543$$]}):null,$APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($touched_QMARK_$jscomp$2$$)){var $and__5023__auto____$1$jscomp$105$$=$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$83$$);
return $APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$105$$)?$show_error$$:$and__5023__auto____$1$jscomp$105$$}return $touched_QMARK_$jscomp$2$$}())?function(){var $message$jscomp$103$$=$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$83$$);return(0,$APP.$rumext$v2$jsx$$)("div",{id:"error-"+($input_name$$??""),"data-testid":""+($data_testid__$1$$??"")+"-error",className:"main_ui_components_forms__error",children:$message$jscomp$103$$})}():$APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($touched_QMARK_$jscomp$2$$)){var $and__5023__auto____$1$jscomp$106$$=
$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$83$$);return $APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$106$$)?$show_error$$:$and__5023__auto____$1$jscomp$106$$}return $touched_QMARK_$jscomp$2$$}())?function(){var $code$jscomp$44$$=$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$83$$);return(0,$APP.$rumext$v2$jsx$$)("div",{id:"error-"+($input_name$$??""),"data-testid":""+($data_testid__$1$$??"")+"-error",className:"main_ui_components_forms__error",
children:$APP.$cljs$core$vector_QMARK_$$($code$jscomp$44$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($code$jscomp$44$$,0),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($code$jscomp$44$$,1))])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($code$jscomp$44$$)})}():typeof $hint$jscomp$11$$==="string"?(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_components_forms__hint",children:$hint$jscomp$11$$}):null]})})};
$APP.$app$main$ui$components$forms$select$$=function($map__73554_options$jscomp$589_props_73553$$){$map__73554_options$jscomp$589_props_73553$$=$APP.$rumext$v2$util$wrap_props$$($map__73554_options$jscomp$589_props_73553$$);var $map__73554__$1_value$jscomp$742$$=$APP.$cljs$core$__destructure_map$$($map__73554_options$jscomp$589_props_73553$$);$map__73554_options$jscomp$589_props_73553$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73554__$1_value$jscomp$742$$,$APP.$cljs$cst$873$options$$);
var $disabled$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73554__$1_value$jscomp$742$$,$APP.$cljs$cst$2948$disabled$$),$form$jscomp$162$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73554__$1_value$jscomp$742$$,$APP.$cljs$cst$179$form$$),$default$$jscomp$87$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73554__$1_value$jscomp$742$$,$APP.$cljs$cst$205$default$$,""),$dropdown_class$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73554__$1_value$jscomp$742$$,
$cljs$cst$4560$dropdown_class$$),$select_class$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73554__$1_value$jscomp$742$$,$cljs$cst$5095$select_class$$),$input_name$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73554__$1_value$jscomp$742$$,$APP.$cljs$cst$725$name$$),$form__$1$jscomp$8$$=$APP.$cljs$core$truth_$$($form$jscomp$162$$)?$form$jscomp$162$$:(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$components$forms$form_ctx$$);$map__73554__$1_value$jscomp$742$$=
function(){var $or__5025__auto__$jscomp$947$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$8$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$input_name$jscomp$2$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$947$$)?$or__5025__auto__$jscomp$947$$:$default$$jscomp$87$$}();return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_components_forms__select-wrapper",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$map__73554__$1_value$jscomp$742$$,disabled:$disabled$jscomp$7$$,options:$map__73554_options$jscomp$589_props_73553$$,"class":$select_class$$,"dropdown-class":$dropdown_class$jscomp$1$$,"on-change":function($event$jscomp$180_value__$1$jscomp$31$$){$event$jscomp$180_value__$1$jscomp$31$$=typeof $event$jscomp$180_value__$1$jscomp$31$$==="string"?$event$jscomp$180_value__$1$jscomp$31$$:(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$180_value__$1$jscomp$31$$);
return $APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form__$1$jscomp$8$$,$input_name$jscomp$2$$,$event$jscomp$180_value__$1$jscomp$31$$,!1)}})})};
$APP.$app$main$ui$components$forms$radio_buttons$$=function($props_73555$$){var $form$jscomp$163$$=function(){var $or__5025__auto__$jscomp$948$$=$props_73555$$.form;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$948$$)?$or__5025__auto__$jscomp$948$$:(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$components$forms$form_ctx$$)}(),$name$jscomp$406$$=$props_73555$$.name,$image$jscomp$31$$=$props_73555$$.image,$current_value$jscomp$2$$=function(){var $or__5025__auto__$jscomp$949$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$163$$),
$APP.$cljs$cst$142$data$$),$name$jscomp$406$$,"");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$949$$)?$or__5025__auto__$jscomp$949$$:$props_73555$$.value}(),$on_change$jscomp$20$$=$props_73555$$["on-change"],$options$jscomp$590$$=$props_73555$$.options,$trim_QMARK_$jscomp$2$$=$props_73555$$.trim,$class$$jscomp$37$$=$props_73555$$["class"],$encode_fn$jscomp$2$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_73555$$["encode-fn"],$APP.$cljs$core$identity$$),$decode_fn$jscomp$5$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_73555$$["decode-fn"],$APP.$cljs$core$identity$$),$on_change_SINGLEQUOTE_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$20$$),$APP.$rumext$v2$adapt$$($form$jscomp$163$$),$APP.$rumext$v2$adapt$$($name$jscomp$406$$)],function($G__73556$jscomp$inline_7476_event$jscomp$181_value$jscomp$743$$){$G__73556$jscomp$inline_7476_event$jscomp$181_value$jscomp$743$$=$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($G__73556$jscomp$inline_7476_event$jscomp$181_value$jscomp$743$$));
$G__73556$jscomp$inline_7476_event$jscomp$181_value$jscomp$743$$=$decode_fn$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$decode_fn$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($G__73556$jscomp$inline_7476_event$jscomp$181_value$jscomp$743$$):$decode_fn$jscomp$5$$($G__73556$jscomp$inline_7476_event$jscomp$181_value$jscomp$743$$);$form$jscomp$163$$!=null&&($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$163$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$name$jscomp$406$$],null),!0),$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$163$$,$name$jscomp$406$$,$G__73556$jscomp$inline_7476_event$jscomp$181_value$jscomp$743$$,$trim_QMARK_$jscomp$2$$));return $APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$20$$)?$on_change$jscomp$20$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$20$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$406$$,
$G__73556$jscomp$inline_7476_event$jscomp$181_value$jscomp$743$$):$on_change$jscomp$20$$($name$jscomp$406$$,$G__73556$jscomp$inline_7476_event$jscomp$181_value$jscomp$743$$):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:$APP.$cljs$core$truth_$$($image$jscomp$31$$)?$class$$jscomp$37$$:""+($class$$jscomp$37$$??"")+" main_ui_components_forms__custom-radio",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$44$$,$JSCompiler_inline_result$jscomp$1359_image__$1_p__73557$$){var $JSCompiler_temp_const$jscomp$1357_map__73558__$1$$=
$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$1359_image__$1_p__73557$$);$JSCompiler_inline_result$jscomp$1359_image__$1_p__73557$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1357_map__73558__$1$$,$APP.$cljs$cst$1612$image$$);var $icon$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1357_map__73558__$1$$,$APP.$cljs$cst$1721$icon$$),$checked_QMARK_$jscomp$inline_7481_value$jscomp$744$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1357_map__73558__$1$$,
$APP.$cljs$cst$260$value$$),$label$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1357_map__73558__$1$$,$APP.$cljs$cst$2287$label$$),$area$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1357_map__73558__$1$$,$APP.$cljs$cst$1674$area$$);$JSCompiler_temp_const$jscomp$1357_map__73558__$1$$=$out_arr__44124__auto__$jscomp$44$$.push;var $image_QMARK_$jscomp$inline_7478$$=$JSCompiler_inline_result$jscomp$1359_image__$1_p__73557$$!=
null,$icon_QMARK_$jscomp$inline_7479$$=$icon$jscomp$13$$!=null,$value_SINGLEQUOTE_$jscomp$inline_7480$$=$encode_fn$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$encode_fn$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($checked_QMARK_$jscomp$inline_7481_value$jscomp$744$$):$encode_fn$jscomp$2$$($checked_QMARK_$jscomp$inline_7481_value$jscomp$744$$);$checked_QMARK_$jscomp$inline_7481_value$jscomp$744$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($checked_QMARK_$jscomp$inline_7481_value$jscomp$744$$,
$current_value$jscomp$2$$);var $key$jscomp$inline_7482$$=""+($APP.$app$common$data$name$$($name$jscomp$406$$)??"")+"-"+($APP.$app$common$data$name$$($value_SINGLEQUOTE_$jscomp$inline_7480$$)??"");$JSCompiler_inline_result$jscomp$1359_image__$1_p__73557$$=(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:$key$jscomp$inline_7482$$,style:{gridArea:$area$jscomp$5$$},className:"main_ui_components_forms__radio-label "+($checked_QMARK_$jscomp$inline_7481_value$jscomp$744$$?"checked":"")+" "+($image_QMARK_$jscomp$inline_7478$$||
$icon_QMARK_$jscomp$inline_7479$$?"main_ui_components_forms__with-image":""),children:[$image_QMARK_$jscomp$inline_7478$$?(0,$APP.$rumext$v2$jsx$$)("span",{style:{backgroundImage:"url("+($JSCompiler_inline_result$jscomp$1359_image__$1_p__73557$$??"")+")"},className:"main_ui_components_forms__image-inside"}):$icon_QMARK_$jscomp$inline_7479$$?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_forms__icon-inside",children:$icon$jscomp$13$$}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_forms__radio-icon "+
($checked_QMARK_$jscomp$inline_7481_value$jscomp$744$$?"checked":""),children:$checked_QMARK_$jscomp$inline_7481_value$jscomp$744$$?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_forms__radio-dot"}):null}),$label$jscomp$29$$,(0,$APP.$rumext$v2$jsx$$)("input",{onChange:$on_change_SINGLEQUOTE_$jscomp$1$$,type:"radio",id:$key$jscomp$inline_7482$$,name:$name$jscomp$406$$,value:$value_SINGLEQUOTE_$jscomp$inline_7480$$,checked:$checked_QMARK_$jscomp$inline_7481_value$jscomp$744$$,className:"main_ui_components_forms__radio-input"})]},
$key$jscomp$inline_7482$$);$JSCompiler_temp_const$jscomp$1357_map__73558__$1$$.call($out_arr__44124__auto__$jscomp$44$$,$JSCompiler_inline_result$jscomp$1359_image__$1_p__73557$$);return $out_arr__44124__auto__$jscomp$44$$},[],$options$jscomp$590$$)})};
$APP.$app$main$ui$components$forms$submit_button_STAR_$$=function($props_73563$$){var $form$jscomp$165_form__$1$jscomp$9_on_key_down$jscomp$5$$=$props_73563$$.form,$children$jscomp$281$$=$props_73563$$.children,$disabled$jscomp$8_disabled_QMARK_$jscomp$3$$=$props_73563$$.disabled,$name$jscomp$408_name__$1$jscomp$15$$=$props_73563$$.name,$on_click$jscomp$14$$=$props_73563$$.onClick,$label$jscomp$31$$=$props_73563$$.label,$class$$jscomp$39_class$__$1$jscomp$7$$=$props_73563$$.className;$form$jscomp$165_form__$1$jscomp$9_on_key_down$jscomp$5$$=
$APP.$cljs$core$truth_$$($form$jscomp$165_form__$1$jscomp$9_on_key_down$jscomp$5$$)?$form$jscomp$165_form__$1$jscomp$9_on_key_down$jscomp$5$$:(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$components$forms$form_ctx$$);$disabled$jscomp$8_disabled_QMARK_$jscomp$3$$=$form$jscomp$165_form__$1$jscomp$9_on_key_down$jscomp$5$$!=null&&$APP.$cljs$core$not$$($APP.$cljs$cst$5075$valid$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$165_form__$1$jscomp$9_on_key_down$jscomp$5$$)))||$disabled$jscomp$8_disabled_QMARK_$jscomp$3$$===
!0;$class$$jscomp$39_class$__$1$jscomp$7$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$39_class$__$1$jscomp$7$$,"main_ui_components_forms__button-submit");$name$jscomp$408_name__$1$jscomp$15$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$408_name__$1$jscomp$15$$,"submit");$form$jscomp$165_form__$1$jscomp$9_on_key_down$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$14$$)],
function($event$jscomp$183$$){var $JSCompiler_inline_result$jscomp$1360_and__5023__auto__$jscomp$inline_7484$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$183$$);$JSCompiler_inline_result$jscomp$1360_and__5023__auto__$jscomp$inline_7484$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1360_and__5023__auto__$jscomp$inline_7484$$)?$APP.$cljs$core$fn_QMARK_$$($on_click$jscomp$14$$):$JSCompiler_inline_result$jscomp$1360_and__5023__auto__$jscomp$inline_7484$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1360_and__5023__auto__$jscomp$inline_7484$$)?
$on_click$jscomp$14$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$14$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$183$$):$on_click$jscomp$14$$($event$jscomp$183$$):null});return(0,$APP.$rumext$v2$create_element$$)("button",{...$props_73563$$,children:void 0,disabled:$disabled$jscomp$8_disabled_QMARK_$jscomp$3$$,onKeyDown:$form$jscomp$165_form__$1$jscomp$9_on_key_down$jscomp$5$$,name:$name$jscomp$408_name__$1$jscomp$15$$,labek:void 0,className:$class$$jscomp$39_class$__$1$jscomp$7$$,type:"submit"},
$children$jscomp$281$$!=null?$children$jscomp$281$$:(0,$APP.$rumext$v2$jsx$$)("span",{children:$label$jscomp$31$$}))};
$APP.$app$main$ui$components$forms$form$$=function($on_submit_SINGLEQUOTE__props_73565$$){var $form__$1$jscomp$10$$=$on_submit_SINGLEQUOTE__props_73565$$.form,$children$jscomp$282$$=$on_submit_SINGLEQUOTE__props_73565$$.children,$class$$jscomp$40$$=$on_submit_SINGLEQUOTE__props_73565$$.class,$on_submit$jscomp$7$$=$on_submit_SINGLEQUOTE__props_73565$$["on-submit"];$on_submit_SINGLEQUOTE__props_73565$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_submit$jscomp$7$$)],
function($event$jscomp$184$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$184$$);return $APP.$cljs$core$fn_QMARK_$$($on_submit$jscomp$7$$)?$on_submit$jscomp$7$$.$cljs$core$IFn$_invoke$arity$2$?$on_submit$jscomp$7$$.$cljs$core$IFn$_invoke$arity$2$($form__$1$jscomp$10$$,$event$jscomp$184$$):$on_submit$jscomp$7$$($form__$1$jscomp$10$$,$event$jscomp$184$$):null});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$components$forms$form_ctx$$),{value:$form__$1$jscomp$10$$,
children:(0,$APP.$rumext$v2$jsx$$)("form",{onSubmit:$on_submit_SINGLEQUOTE__props_73565$$,className:$class$$jscomp$40$$,children:$children$jscomp$282$$})})};$app$main$ui$components$forms$conj_dedup$$=function($coll$jscomp$1098$$,$item$jscomp$102$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($coll$jscomp$1098$$,$item$jscomp$102$$))};
$APP.$app$main$ui$components$forms$multi_input$$=function($label$jscomp$32_map__73570_props_73569$$){$label$jscomp$32_map__73570_props_73569$$=$APP.$rumext$v2$util$wrap_props$$($label$jscomp$32_map__73570_props_73569$$);var $klass$jscomp$4_map__73570__$1$$=$APP.$cljs$core$__destructure_map$$($label$jscomp$32_map__73570_props_73569$$),$auto_focus_QMARK_$jscomp$1_form$jscomp$166$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($klass$jscomp$4_map__73570__$1$$,$APP.$cljs$cst$179$form$$);$label$jscomp$32_map__73570_props_73569$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($klass$jscomp$4_map__73570__$1$$,$APP.$cljs$cst$2287$label$$);var $class$$jscomp$41_in_klass$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($klass$jscomp$4_map__73570__$1$$,$APP.$cljs$cst$1291$class$$),$name$jscomp$409$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($klass$jscomp$4_map__73570__$1$$,$APP.$cljs$cst$725$name$$),$trim$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($klass$jscomp$4_map__73570__$1$$,
$APP.$cljs$cst$3686$trim$$),$valid_item_fn$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($klass$jscomp$4_map__73570__$1$$,$cljs$cst$5096$valid_item_fn$$),$caution_item_fn$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($klass$jscomp$4_map__73570__$1$$,$cljs$cst$5097$caution_item_fn$$),$on_submit$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($klass$jscomp$4_map__73570__$1$$,$cljs$cst$5098$on_submit$$),$form__$1$jscomp$11$$=$APP.$cljs$core$truth_$$($auto_focus_QMARK_$jscomp$1_form$jscomp$166$$)?
$auto_focus_QMARK_$jscomp$1_form$jscomp$166$$:(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$components$forms$form_ctx$$),$input_name$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($klass$jscomp$4_map__73570__$1$$,$APP.$cljs$cst$725$name$$),$touched_QMARK_$jscomp$4$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$11$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,
$input_name$jscomp$3$$],null)),$error$jscomp$85_on_focus$jscomp$3$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$11$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$input_name$jscomp$3$$],null)),$focus_QMARK_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$auto_focus_QMARK_$jscomp$1_form$jscomp$166$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($klass$jscomp$4_map__73570__$1$$,
$cljs$cst$5087$auto_focus_QMARK_$$,!1);var $items$jscomp$51$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $initial$jscomp$29$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$11$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$input_name$jscomp$3$$],null));return $APP.$cljs$core$vector_QMARK_$$($initial$jscomp$29$$)||$APP.$cljs$core$set_QMARK_$$($initial$jscomp$29$$)?
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($val$jscomp$187$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1588$text$$,$val$jscomp$187$$,$APP.$cljs$cst$5075$valid$$,$valid_item_fn$$.$cljs$core$IFn$_invoke$arity$1$?$valid_item_fn$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$187$$):$valid_item_fn$$($val$jscomp$187$$),$cljs$cst$5099$caution$$,$caution_item_fn$$.$cljs$core$IFn$_invoke$arity$1$?$caution_item_fn$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$187$$):
$caution_item_fn$$($val$jscomp$187$$)],null)},$initial$jscomp$29$$):$APP.$cljs$core$PersistentVector$EMPTY$$}),$value$jscomp$747$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$result$jscomp$323$$=$APP.$app$main$ui$hooks$use_equal_memo$$($APP.$cljs$core$_deref$$($items$jscomp$51$$)),$empty_QMARK_$$=$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$core$_deref$$($value$jscomp$747$$))&&$APP.$cljs$core$count$$($APP.$cljs$core$_deref$$($items$jscomp$51$$))===0;$klass$jscomp$4_map__73570__$1$$=
[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($klass$jscomp$4_map__73570__$1$$,$APP.$cljs$cst$1291$class$$))," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($focus_QMARK_$jscomp$2$$))?"main_ui_components_forms__focus":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($touched_QMARK_$jscomp$4$$)?$APP.$cljs$core$not$$($error$jscomp$85_on_focus$jscomp$3$$):$touched_QMARK_$jscomp$4$$)?
"main_ui_components_forms__valid":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($touched_QMARK_$jscomp$4$$)?$error$jscomp$85_on_focus$jscomp$3$$:$touched_QMARK_$jscomp$4$$)?"main_ui_components_forms__invalid":"")+" "+($empty_QMARK_$$?"main_ui_components_forms__empty":"")+" main_ui_components_forms__custom-multi-input")].join("");$class$$jscomp$41_in_klass$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($class$$jscomp$41_in_klass$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$("main_ui_components_forms__inside-input "+
($APP.$cljs$core$count$$($APP.$cljs$core$_deref$$($items$jscomp$51$$))>0?"main_ui_components_forms__no-padding":"")+" "+($APP.$cljs$core$truth_$$(function(){var $G__73572$jscomp$inline_7486_JSCompiler_inline_result$jscomp$1364_JSCompiler_temp$jscomp$1361_JSCompiler_temp$jscomp$1362_JSCompiler_temp$jscomp$1363_and__5023__auto__$jscomp$624$$=$valid_item_fn$$!=null;if($G__73572$jscomp$inline_7486_JSCompiler_inline_result$jscomp$1364_JSCompiler_temp$jscomp$1361_JSCompiler_temp$jscomp$1362_JSCompiler_temp$jscomp$1363_and__5023__auto__$jscomp$624$$)if($APP.$cljs$core$truth_$$($touched_QMARK_$jscomp$4$$)){if($G__73572$jscomp$inline_7486_JSCompiler_inline_result$jscomp$1364_JSCompiler_temp$jscomp$1361_JSCompiler_temp$jscomp$1362_JSCompiler_temp$jscomp$1363_and__5023__auto__$jscomp$624$$=
!$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$core$_deref$$($value$jscomp$747$$)))$G__73572$jscomp$inline_7486_JSCompiler_inline_result$jscomp$1364_JSCompiler_temp$jscomp$1361_JSCompiler_temp$jscomp$1362_JSCompiler_temp$jscomp$1363_and__5023__auto__$jscomp$624$$=$APP.$cljs$core$_deref$$($value$jscomp$747$$),$G__73572$jscomp$inline_7486_JSCompiler_inline_result$jscomp$1364_JSCompiler_temp$jscomp$1361_JSCompiler_temp$jscomp$1362_JSCompiler_temp$jscomp$1363_and__5023__auto__$jscomp$624$$=$valid_item_fn$$.$cljs$core$IFn$_invoke$arity$1$?
$valid_item_fn$$.$cljs$core$IFn$_invoke$arity$1$($G__73572$jscomp$inline_7486_JSCompiler_inline_result$jscomp$1364_JSCompiler_temp$jscomp$1361_JSCompiler_temp$jscomp$1362_JSCompiler_temp$jscomp$1363_and__5023__auto__$jscomp$624$$):$valid_item_fn$$($G__73572$jscomp$inline_7486_JSCompiler_inline_result$jscomp$1364_JSCompiler_temp$jscomp$1361_JSCompiler_temp$jscomp$1362_JSCompiler_temp$jscomp$1363_and__5023__auto__$jscomp$624$$),$G__73572$jscomp$inline_7486_JSCompiler_inline_result$jscomp$1364_JSCompiler_temp$jscomp$1361_JSCompiler_temp$jscomp$1362_JSCompiler_temp$jscomp$1363_and__5023__auto__$jscomp$624$$=
$APP.$cljs$core$not$$($G__73572$jscomp$inline_7486_JSCompiler_inline_result$jscomp$1364_JSCompiler_temp$jscomp$1361_JSCompiler_temp$jscomp$1362_JSCompiler_temp$jscomp$1363_and__5023__auto__$jscomp$624$$)}else $G__73572$jscomp$inline_7486_JSCompiler_inline_result$jscomp$1364_JSCompiler_temp$jscomp$1361_JSCompiler_temp$jscomp$1362_JSCompiler_temp$jscomp$1363_and__5023__auto__$jscomp$624$$=$touched_QMARK_$jscomp$4$$;return $G__73572$jscomp$inline_7486_JSCompiler_inline_result$jscomp$1364_JSCompiler_temp$jscomp$1361_JSCompiler_temp$jscomp$1362_JSCompiler_temp$jscomp$1363_and__5023__auto__$jscomp$624$$}())?
"main_ui_components_forms__invalid":""))].join("");$error$jscomp$85_on_focus$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($focus_QMARK_$jscomp$2$$,!0)});var $on_change$jscomp$22$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($content$jscomp$237_event$jscomp$185$$){$content$jscomp$237_event$jscomp$185$$=$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($content$jscomp$237_event$jscomp$185$$));
return $APP.$cljs$core$reset_BANG_$$($value$jscomp$747$$,$content$jscomp$237_event$jscomp$185$$)}),$update_form_BANG_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($form__$1$jscomp$11$$)],function($items__$1$jscomp$7_value__$1$jscomp$32$$){$items__$1$jscomp$7_value__$1$jscomp$32$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$items__$1$jscomp$7_value__$1$jscomp$32$$));
return $app$util$forms$update_input_value_BANG_$$($form__$1$jscomp$11$$,$input_name$jscomp$3$$,$items__$1$jscomp$7_value__$1$jscomp$32$$)}),$on_key_down$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($value$jscomp$747$$))],function($event$jscomp$186$$){var $val$jscomp$188$$=function(){var $G__73573$$=$APP.$cljs$core$_deref$$($value$jscomp$747$$);return $APP.$cljs$core$truth_$$($trim$jscomp$3$$)?$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($G__73573$$):
$G__73573$$}();if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$954_or__5025__auto____$1$jscomp$105$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$186$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$954_or__5025__auto____$1$jscomp$105$$))return $or__5025__auto__$jscomp$954_or__5025__auto____$1$jscomp$105$$;$or__5025__auto__$jscomp$954_or__5025__auto____$1$jscomp$105$$=$app$util$keyboard$comma_QMARK_$$($event$jscomp$186$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$954_or__5025__auto____$1$jscomp$105$$)?
$or__5025__auto__$jscomp$954_or__5025__auto____$1$jscomp$105$$:(0,$APP.$app$util$keyboard$space_QMARK_$$)($event$jscomp$186$$)}()))if($APP.$app$util$dom$prevent_default$$($event$jscomp$186$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$186$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form__$1$jscomp$11$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$input_name$jscomp$3$$],
null),!0),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$625_and__5023__auto____$1$jscomp$108$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$186$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$625_and__5023__auto____$1$jscomp$108$$)?($and__5023__auto__$jscomp$625_and__5023__auto____$1$jscomp$108$$=$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$core$_deref$$($value$jscomp$747$$)))?$APP.$cljs$core$not_empty$$($APP.$cljs$core$_deref$$($items$jscomp$51$$)):$and__5023__auto__$jscomp$625_and__5023__auto____$1$jscomp$108$$:
$and__5023__auto__$jscomp$625_and__5023__auto____$1$jscomp$108$$}())&&$APP.$cljs$core$fn_QMARK_$$($on_submit$jscomp$8$$)&&($on_submit$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$?$on_submit$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$($form__$1$jscomp$11$$,$event$jscomp$186$$):$on_submit$jscomp$8$$($form__$1$jscomp$11$$,$event$jscomp$186$$)),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$626$$=$valid_item_fn$$.$cljs$core$IFn$_invoke$arity$1$?$valid_item_fn$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$188$$):
$valid_item_fn$$($val$jscomp$188$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$626$$)?!$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$core$_deref$$($value$jscomp$747$$)):$and__5023__auto__$jscomp$626$$}())){$APP.$cljs$core$reset_BANG_$$($value$jscomp$747$$,"");$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form__$1$jscomp$11$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,
$input_name$jscomp$3$$],null),!1);for(var $c__5548__auto__$jscomp$23_seq__73574_temp__5825__auto__$jscomp$274$$=$APP.$cljs$core$seq$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($val$jscomp$188$$,/,|\s+/)),$G__73606_chunk__73575_seq__73574__$1$$=null,$G__73605_count__73576$$=0,$i__73577$$=0;;)if($i__73577$$<$G__73605_count__73576$$){var $G__73607_val__$1$jscomp$13$$=$G__73606_chunk__73575_seq__73574__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__73577$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($items$jscomp$51$$,
$app$main$ui$components$forms$conj_dedup$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1588$text$$,$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($G__73607_val__$1$jscomp$13$$),$APP.$cljs$cst$5075$valid$$,$valid_item_fn$$.$cljs$core$IFn$_invoke$arity$1$?$valid_item_fn$$.$cljs$core$IFn$_invoke$arity$1$($G__73607_val__$1$jscomp$13$$):$valid_item_fn$$($G__73607_val__$1$jscomp$13$$),$cljs$cst$5099$caution$$,$caution_item_fn$$.$cljs$core$IFn$_invoke$arity$1$?$caution_item_fn$$.$cljs$core$IFn$_invoke$arity$1$($G__73607_val__$1$jscomp$13$$):
$caution_item_fn$$($G__73607_val__$1$jscomp$13$$)],null));$i__73577$$+=1}else if($c__5548__auto__$jscomp$23_seq__73574_temp__5825__auto__$jscomp$274$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$23_seq__73574_temp__5825__auto__$jscomp$274$$))$G__73606_chunk__73575_seq__73574__$1$$=$c__5548__auto__$jscomp$23_seq__73574_temp__5825__auto__$jscomp$274$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__73606_chunk__73575_seq__73574__$1$$)?($c__5548__auto__$jscomp$23_seq__73574_temp__5825__auto__$jscomp$274$$=
$APP.$cljs$core$_chunked_first$$($G__73606_chunk__73575_seq__73574__$1$$),$G__73605_count__73576$$=$APP.$cljs$core$_chunked_rest$$($G__73606_chunk__73575_seq__73574__$1$$),$G__73606_chunk__73575_seq__73574__$1$$=$c__5548__auto__$jscomp$23_seq__73574_temp__5825__auto__$jscomp$274$$,$G__73607_val__$1$jscomp$13$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$23_seq__73574_temp__5825__auto__$jscomp$274$$),$c__5548__auto__$jscomp$23_seq__73574_temp__5825__auto__$jscomp$274$$=$G__73605_count__73576$$,
$G__73605_count__73576$$=$G__73607_val__$1$jscomp$13$$):($G__73607_val__$1$jscomp$13$$=$APP.$cljs$core$first$$($G__73606_chunk__73575_seq__73574__$1$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($items$jscomp$51$$,$app$main$ui$components$forms$conj_dedup$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1588$text$$,$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($G__73607_val__$1$jscomp$13$$),$APP.$cljs$cst$5075$valid$$,$valid_item_fn$$.$cljs$core$IFn$_invoke$arity$1$?
$valid_item_fn$$.$cljs$core$IFn$_invoke$arity$1$($G__73607_val__$1$jscomp$13$$):$valid_item_fn$$($G__73607_val__$1$jscomp$13$$),$cljs$cst$5099$caution$$,$caution_item_fn$$.$cljs$core$IFn$_invoke$arity$1$?$caution_item_fn$$.$cljs$core$IFn$_invoke$arity$1$($G__73607_val__$1$jscomp$13$$):$caution_item_fn$$($G__73607_val__$1$jscomp$13$$)],null)),$c__5548__auto__$jscomp$23_seq__73574_temp__5825__auto__$jscomp$274$$=$APP.$cljs$core$next$$($G__73606_chunk__73575_seq__73574__$1$$),$G__73606_chunk__73575_seq__73574__$1$$=
null,$G__73605_count__73576$$=0),$i__73577$$=0;else return null}else return null;else return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$627$$=(0,$APP.$app$util$keyboard$backspace_QMARK_$$)($event$jscomp$186$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$627$$)?$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$core$_deref$$($value$jscomp$747$$)):$and__5023__auto__$jscomp$627$$}())?($APP.$app$util$dom$prevent_default$$($event$jscomp$186$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$186$$),
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$51$$,function($items__$1$jscomp$8$$){return $APP.$cljs$core$empty_QMARK_$$($items__$1$jscomp$8$$)?$items__$1$jscomp$8$$:$APP.$cljs$core$pop$$($items__$1$jscomp$8$$)})):null}),$on_blur$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($focus_QMARK_$jscomp$2$$,!1);return $APP.$cljs$core$truth_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$11$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$input_name$jscomp$3$$],null)))?null:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form__$1$jscomp$11$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,$input_name$jscomp$3$$],null),!0)}),$remove_item_BANG_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($item$jscomp$103$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$51$$,
function($p1__73567_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($x$jscomp$1231$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1231$$,$item$jscomp$103$$)}),$p1__73567_SHARP_$$)})}),$manage_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($item$jscomp$104$$,$event$jscomp$187$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$187$$))?
$remove_item_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$remove_item_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$104$$):$remove_item_BANG_$$($item$jscomp$104$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($result$jscomp$323$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($value$jscomp$747$$))],function(){var $val$jscomp$189_values$jscomp$74_values__$1$jscomp$3$$=function(){var $G__73578$$=$APP.$cljs$core$_deref$$($value$jscomp$747$$);return $APP.$cljs$core$truth_$$($trim$jscomp$3$$)?
$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($G__73578$$):$G__73578$$}();$val$jscomp$189_values$jscomp$74_values__$1$jscomp$3$$=$app$main$ui$components$forms$conj_dedup$$($result$jscomp$323$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1588$text$$,$val$jscomp$189_values$jscomp$74_values__$1$jscomp$3$$,$APP.$cljs$cst$5075$valid$$,$valid_item_fn$$.$cljs$core$IFn$_invoke$arity$1$?$valid_item_fn$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$189_values$jscomp$74_values__$1$jscomp$3$$):
$valid_item_fn$$($val$jscomp$189_values$jscomp$74_values__$1$jscomp$3$$)],null));$val$jscomp$189_values$jscomp$74_values__$1$jscomp$3$$=$APP.$cljs$core$filterv$$(function($p1__73568_SHARP_$$){return $APP.$cljs$cst$5075$valid$$.$cljs$core$IFn$_invoke$arity$1$($p1__73568_SHARP_$$)},$val$jscomp$189_values$jscomp$74_values__$1$jscomp$3$$);return $update_form_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$update_form_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$189_values$jscomp$74_values__$1$jscomp$3$$):
$update_form_BANG_$$($val$jscomp$189_values$jscomp$74_values__$1$jscomp$3$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:$klass$jscomp$4_map__73570__$1$$,children:[(0,$APP.$rumext$v2$jsx$$)("input",{onChange:$on_change$jscomp$22$$,className:$class$$jscomp$41_in_klass$$,placeholder:$empty_QMARK_$$?$label$jscomp$32_map__73570_props_73569$$:null,id:$name$jscomp$409$$.$cljs$core$IFn$_invoke$arity$1$?$name$jscomp$409$$.$cljs$core$IFn$_invoke$arity$1$($input_name$jscomp$3$$):$name$jscomp$409$$($input_name$jscomp$3$$),
value:$APP.$cljs$core$_deref$$($value$jscomp$747$$),onFocus:$error$jscomp$85_on_focus$jscomp$3$$,onBlur:$on_blur$jscomp$3$$,type:"text",onKeyDown:$on_key_down$jscomp$6$$,autoFocus:$auto_focus_QMARK_$jscomp$1_form$jscomp$166$$}),(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:$name$jscomp$409$$.$cljs$core$IFn$_invoke$arity$1$?$name$jscomp$409$$.$cljs$core$IFn$_invoke$arity$1$($input_name$jscomp$3$$):$name$jscomp$409$$($input_name$jscomp$3$$),children:$label$jscomp$32_map__73570_props_73569$$}),function(){var $temp__5825__auto__$jscomp$275$$=
$APP.$cljs$core$seq$$($APP.$cljs$core$_deref$$($items$jscomp$51$$));return $temp__5825__auto__$jscomp$275$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_components_forms__selected-items",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$46$$,$item$jscomp$105$$){$out_arr__44124__auto__$jscomp$46$$.push((0,$APP.$rumext$v2$jsx$$)("div",{tabIndex:"0",onKeyDown:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($manage_key_down$$,
$item$jscomp$105$$),className:"main_ui_components_forms__selected-item",children:(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_components_forms__around "+($APP.$cljs$core$not$$($APP.$cljs$cst$5075$valid$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$105$$))?"main_ui_components_forms__invalid":"")+" "+($APP.$cljs$core$truth_$$($cljs$cst$5099$caution$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$105$$))?"main_ui_components_forms__caution":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_forms__text",
children:$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$105$$)}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $remove_item_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$remove_item_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$105$$):$remove_item_BANG_$$($item$jscomp$105$$)},className:"main_ui_components_forms__icon",children:$APP.$app$main$ui$icons$close$$})]})},$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$105$$)));return $out_arr__44124__auto__$jscomp$46$$},
[],$temp__5825__auto__$jscomp$275$$)}):null}()]})};
$APP.$app$main$ui$components$org_avatar$org_avatar_STAR_$$=function($name$jscomp$410_props_73531$$){var $size$jscomp$134$$=$name$jscomp$410_props_73531$$.size,$avatar_bg_org$$=$name$jscomp$410_props_73531$$.org;$name$jscomp$410_props_73531$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($avatar_bg_org$$);var $custom_photo$$=$cljs$cst$3326$custom_photo$$.$cljs$core$IFn$_invoke$arity$1$($avatar_bg_org$$);$avatar_bg_org$$=$cljs$cst$3325$avatar_bg_url$$.$cljs$core$IFn$_invoke$arity$1$($avatar_bg_org$$);var $initials$$=
$app$common$data$get_initials$$($name$jscomp$410_props_73531$$);return $APP.$cljs$core$truth_$$($custom_photo$$)?(0,$APP.$rumext$v2$jsx$$)("img",{src:$custom_photo$$,alt:$name$jscomp$410_props_73531$$,className:"main_ui_components_org_avatar__org-avatar main_ui_components_org_avatar__org-avatar-custom "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($size$jscomp$134$$,"xxxl")?"main_ui_components_org_avatar__org-avatar-xxxl":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($size$jscomp$134$$,
"xxl")?"main_ui_components_org_avatar__org-avatar-xxl":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($size$jscomp$134$$,"xl")?"main_ui_components_org_avatar__org-avatar-xl":"")}):(0,$APP.$rumext$v2$jsxs$$)("div",{"aria-hidden":"true",className:"main_ui_components_org_avatar__org-avatar "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($size$jscomp$134$$,"xxxl")?"main_ui_components_org_avatar__org-avatar-xxxl":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($size$jscomp$134$$,
"xxl")?"main_ui_components_org_avatar__org-avatar-xxl":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($size$jscomp$134$$,"xl")?"main_ui_components_org_avatar__org-avatar-xl":""),children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:$avatar_bg_org$$,alt:"",className:"main_ui_components_org_avatar__org-avatar-bg"}),$APP.$cljs$core$seq$$($initials$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_org_avatar__org-avatar-initials "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($size$jscomp$134$$,
"xxxl")?"main_ui_components_org_avatar__size-initials-xxxl":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($size$jscomp$134$$,"xxl")?"main_ui_components_org_avatar__size-initials-xxl":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($size$jscomp$134$$,"xl")?"main_ui_components_org_avatar__size-initials-xxl":""),children:$initials$$}):null]})};
$app$main$ui$dashboard$change_owner$leave_and_reassign_modal$$=function($map__73582_props_73581_team$jscomp$15$$){$map__73582_props_73581_team$jscomp$15$$=$APP.$rumext$v2$util$wrap_props$$($map__73582_props_73581_team$jscomp$15$$);var $map__73582__$1_members$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($map__73582_props_73581_team$jscomp$15$$),$profile$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73582__$1_members$jscomp$3$$,$APP.$cljs$cst$1914$profile$$);$map__73582_props_73581_team$jscomp$15$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73582__$1_members$jscomp$3$$,$APP.$cljs$cst$2492$team$$);var $accept$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73582__$1_members$jscomp$3$$,$APP.$cljs$cst$924$accept$$),$form$jscomp$167$$=function(){var $G__73586$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,
$app$main$ui$dashboard$change_owner$schema_COLON_leave_modal_form$$,$APP.$cljs$cst$5076$initial$$,$G__73586$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$dashboard$change_owner$schema_COLON_leave_modal_form$$,$APP.$cljs$cst$5076$initial$$,$G__73586$$)}();$map__73582__$1_members$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73582_props_73581_team$jscomp$15$$,$APP.$cljs$cst$3264$members$$);var $options$jscomp$592$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-and-reassign.select-member-to-promote")],null)],null),$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__73579_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($p1__73579_SHARP_$$),
$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$34$$))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__73580_SHARP_$$){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$2287$label$$,$APP.$cljs$cst$260$value$$],[$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__73580_SHARP_$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73580_SHARP_$$))])})),$map__73582__$1_members$jscomp$3$$);
return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_change_owner__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_change_owner__modal-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_change_owner__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_dashboard_change_owner__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-and-reassign.title")}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_dashboard_change_owner__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_change_owner__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_dashboard_change_owner__modal-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.leave-and-reassign.hint1",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($map__73582_props_73581_team$jscomp$15$$)]))}),
$APP.$cljs$core$empty_QMARK_$$($map__73582__$1_members$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_dashboard_change_owner__modal-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-and-reassign.forbidden")}):(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$form$$,{form:$form$jscomp$167$$,children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$select$$,{name:$cljs$cst$3274$member_id$$,
options:$options$jscomp$592$$})})})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_change_owner__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_change_owner__action-buttons",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel"),onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_dashboard_change_owner__cancel-button"}),(0,$APP.$rumext$v2$jsx$$)("input",
{className:"accept-button main_ui_dashboard_change_owner__accept-btn "+(($APP.$cljs$core$truth_$$($APP.$cljs$cst$5075$valid$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$167$$)))?"main_ui_dashboard_change_owner__danger":"")+" "+($APP.$cljs$core$not$$($APP.$cljs$cst$5075$valid$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$167$$)))?"disabled":"")),type:"button",disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5075$valid$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$167$$))),
value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-and-reassign.promote-and-leave"),onClick:function(){var $member_id$jscomp$4$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$167$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5074$clean_data$$,$cljs$cst$3274$member_id$$],null));return $accept$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$accept$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($member_id$jscomp$4$$):
$accept$jscomp$7$$($member_id$jscomp$4$$)}})]})})]})})};
$app$main$ui$dashboard$change_owner$team_member_select_STAR_$$=function($default_member_id_props_73589$$){var $form$jscomp$168$$=$default_member_id_props_73589$$.form,$profile$jscomp$35$$=$default_member_id_props_73589$$.profile,$field_name$$=$default_member_id_props_73589$$.fieldName,$team$jscomp$16$$=$default_member_id_props_73589$$.team;$default_member_id_props_73589$$=$default_member_id_props_73589$$.defaultMemberId;var $filtered_members_members$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$16$$,
$APP.$cljs$cst$3264$members$$);$filtered_members_members$jscomp$4$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73587_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($p1__73587_SHARP_$$),$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$35$$))},$filtered_members_members$jscomp$4$$);var $options$jscomp$593$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73588_SHARP_$$){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$2287$label$$,
$APP.$cljs$cst$260$value$$],[$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__73588_SHARP_$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73588_SHARP_$$))])},$filtered_members_members$jscomp$4$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_change_owner__team-select-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_change_owner__team-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$16$$)}),
$APP.$cljs$core$empty_QMARK_$$($filtered_members_members$jscomp$4$$)?(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_dashboard_change_owner__modal-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-and-reassign.forbidden")}):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$select$$,{name:$field_name$$,"select-class":"main_ui_dashboard_change_owner__team-member","dropdown-class":"main_ui_dashboard_change_owner__team-member",options:$options$jscomp$593$$,
form:$form$jscomp$168$$,"default":$default_member_id_props_73589$$})]})};
$app$main$ui$dashboard$change_owner$make_leave_org_modal_form_schema$$=function($teams$jscomp$9$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"LeaveOrgModalForm"],null)],null),function(){return function $app$main$ui$dashboard$change_owner$make_leave_org_modal_form_schema_$_iter__73594$$($s__73595$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__73595__$2_temp__5825__auto__$jscomp$276$$=
$APP.$cljs$core$seq$$($s__73595$$);if($s__73595__$2_temp__5825__auto__$jscomp$276$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__73595__$2_temp__5825__auto__$jscomp$276$$)){var $JSCompiler_inline_result$jscomp$1365_c__5501__auto__$jscomp$34$$=$APP.$cljs$core$_chunked_first$$($s__73595__$2_temp__5825__auto__$jscomp$276$$),$size__5502__auto__$jscomp$34$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1365_c__5501__auto__$jscomp$34$$),$b__73597_team$jscomp$17$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$34$$);
a:{for(var $i__73596$jscomp$inline_7488$$=0;;)if($i__73596$jscomp$inline_7488$$<$size__5502__auto__$jscomp$34$$){var $team$jscomp$inline_7489_x$jscomp$inline_12988$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1365_c__5501__auto__$jscomp$34$$,$i__73596$jscomp$inline_7488$$),$b$jscomp$inline_12987$$=$b__73597_team$jscomp$17$$;$team$jscomp$inline_7489_x$jscomp$inline_12988$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$(["member-id-",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$inline_7489_x$jscomp$inline_12988$$))].join("")),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null);$b$jscomp$inline_12987$$.add($team$jscomp$inline_7489_x$jscomp$inline_12988$$);$i__73596$jscomp$inline_7488$$+=1}else{$JSCompiler_inline_result$jscomp$1365_c__5501__auto__$jscomp$34$$=!0;break a}$JSCompiler_inline_result$jscomp$1365_c__5501__auto__$jscomp$34$$=void 0}return $JSCompiler_inline_result$jscomp$1365_c__5501__auto__$jscomp$34$$?
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__73597_team$jscomp$17$$),$app$main$ui$dashboard$change_owner$make_leave_org_modal_form_schema_$_iter__73594$$($APP.$cljs$core$_chunked_rest$$($s__73595__$2_temp__5825__auto__$jscomp$276$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__73597_team$jscomp$17$$),null)}$b__73597_team$jscomp$17$$=$APP.$cljs$core$first$$($s__73595__$2_temp__5825__auto__$jscomp$276$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$(["member-id-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($b__73597_team$jscomp$17$$))].join("")),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),$app$main$ui$dashboard$change_owner$make_leave_org_modal_form_schema_$_iter__73594$$($APP.$cljs$core$rest$$($s__73595__$2_temp__5825__auto__$jscomp$276$$)))}return null}},
null,null)}($teams$jscomp$9$$)}())};
$app$main$ui$dashboard$team_form$on_create_success$$=function($_form_team_id$jscomp$123$$,$response$jscomp$13$$){$_form_team_id$jscomp$123$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($response$jscomp$13$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$02$$("Team created successfully"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,$_form_team_id$jscomp$123$$]))]))};
$app$main$ui$dashboard$team_form$on_update_success$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$02$$("Team created successfully"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]))};
$app$main$ui$dashboard$team_form$on_error$$=function($form$jscomp$170_id$jscomp$870$$){$form$jscomp$170_id$jscomp$870$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$170_id$jscomp$870$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5074$clean_data$$,$APP.$cljs$cst$266$id$$],null));return $APP.$cljs$core$truth_$$($form$jscomp$170_id$jscomp$870$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$("Error on updating team.")):
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$("Error on creating team."))};
$app$main$ui$dashboard$team_form$on_submit$$=function($data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$){var $JSCompiler_temp$jscomp$1366_data$jscomp$438_mdata$jscomp$inline_12991_mdata$jscomp$inline_7494$$=$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$));if($APP.$cljs$core$truth_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1366_data$jscomp$438_mdata$jscomp$inline_12991_mdata$jscomp$inline_7494$$)))$JSCompiler_temp$jscomp$1366_data$jscomp$438_mdata$jscomp$inline_12991_mdata$jscomp$inline_7494$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$dashboard$team_form$on_update_success$$,$data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$),$APP.$cljs$cst$1295$on_error$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$dashboard$team_form$on_error$$,$data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$)],
null),$data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$=$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$)),$data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$=$APP.$cljs$core$select_keys$$($data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$725$name$$],null)),$JSCompiler_temp$jscomp$1366_data$jscomp$438_mdata$jscomp$inline_12991_mdata$jscomp$inline_7494$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$team$update_team$$($APP.$cljs$core$with_meta$$($data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$,
$JSCompiler_temp$jscomp$1366_data$jscomp$438_mdata$jscomp$inline_12991_mdata$jscomp$inline_7494$$)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]));else{$JSCompiler_temp$jscomp$1366_data$jscomp$438_mdata$jscomp$inline_12991_mdata$jscomp$inline_7494$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$dashboard$team_form$on_create_success$$,$data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$),
$APP.$cljs$cst$1295$on_error$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$dashboard$team_form$on_error$$,$data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$)],null);$data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$=$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$));
var $G__73590$jscomp$inline_12994$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$)],null);$data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$3256$organization_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__73590$jscomp$inline_12994$$,$APP.$cljs$cst$3256$organization_id$$,$APP.$cljs$cst$3256$organization_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$)):$G__73590$jscomp$inline_12994$$;$JSCompiler_temp$jscomp$1366_data$jscomp$438_mdata$jscomp$inline_12991_mdata$jscomp$inline_7494$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$team$create_team$$($APP.$cljs$core$with_meta$$($data$jscomp$inline_12992_data$jscomp$inline_7495_form$jscomp$173_params$jscomp$inline_12993_team$jscomp$inline_7496$$,
$JSCompiler_temp$jscomp$1366_data$jscomp$438_mdata$jscomp$inline_12991_mdata$jscomp$inline_7494$$)),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$APP.$cljs$cst$5106$dashboard$$],null)))}return $JSCompiler_temp$jscomp$1366_data$jscomp$438_mdata$jscomp$inline_12991_mdata$jscomp$inline_7494$$};
$app$main$ui$dashboard$team_form$team_form_modal$$=function($handle_keydown$jscomp$1_initial$jscomp$30_map__73592_map__73592__$1_props_73591$$){$handle_keydown$jscomp$1_initial$jscomp$30_map__73592_map__73592__$1_props_73591$$=$APP.$rumext$v2$util$wrap_props$$($handle_keydown$jscomp$1_initial$jscomp$30_map__73592_map__73592__$1_props_73591$$);$handle_keydown$jscomp$1_initial$jscomp$30_map__73592_map__73592__$1_props_73591$$=$APP.$cljs$core$__destructure_map$$($handle_keydown$jscomp$1_initial$jscomp$30_map__73592_map__73592__$1_props_73591$$);
var $team$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_keydown$jscomp$1_initial$jscomp$30_map__73592_map__73592__$1_props_73591$$,$APP.$cljs$cst$2492$team$$),$organization_id$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_keydown$jscomp$1_initial$jscomp$30_map__73592_map__73592__$1_props_73591$$,$APP.$cljs$cst$3256$organization_id$$);$handle_keydown$jscomp$1_initial$jscomp$30_map__73592_map__73592__$1_props_73591$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$26$$),
$APP.$rumext$v2$adapt$$($organization_id$jscomp$10$$)],function(){if($APP.$cljs$core$truth_$$($team$jscomp$26$$))return $APP.$cljs$core$select_keys$$($team$jscomp$26$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$266$id$$],null));var $G__73593$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$cljs$core$truth_$$($organization_id$jscomp$10$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__73593$$,
$APP.$cljs$cst$3256$organization_id$$,$organization_id$jscomp$10$$):$G__73593$$});var $form$jscomp$174$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$app$main$ui$dashboard$team_form$schema_COLON_team_form$$,$APP.$cljs$cst$5076$initial$$,$handle_keydown$jscomp$1_initial$jscomp$30_map__73592_map__73592__$1_props_73591$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$dashboard$team_form$schema_COLON_team_form$$,
$APP.$cljs$cst$5076$initial$$,$handle_keydown$jscomp$1_initial$jscomp$30_map__73592_map__73592__$1_props_73591$$);$handle_keydown$jscomp$1_initial$jscomp$30_map__73592_map__73592__$1_props_73591$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$330$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($e$jscomp$330$$))?($APP.$app$util$dom$prevent_default$$($e$jscomp$330$$),$APP.$app$util$dom$stop_propagation$$($e$jscomp$330$$),$app$main$ui$dashboard$team_form$on_submit$$($form$jscomp$174$$,
$e$jscomp$330$$)):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team_form__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team_form__modal-container",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,{form:$form$jscomp$174$$,"on-submit":$app$main$ui$dashboard$team_form$on_submit$$,"class":"main_ui_dashboard_team_form__team-form",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team_form__modal-header",
children:[$APP.$cljs$core$truth_$$($team$jscomp$26$$)?(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_dashboard_team_form__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename-team")}):(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_dashboard_team_form__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.create-team")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_dashboard_team_form__modal-close-btn",
children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team_form__modal-content",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{type:"text","auto-focus?":!0,"class":"main_ui_dashboard_team_form__group-name-input",form:$form$jscomp$174$$,name:$APP.$cljs$cst$725$name$$,placeholder:"E.g. Design",label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.create-team.placeholder"),"on-key-down":$handle_keydown$jscomp$1_initial$jscomp$30_map__73592_map__73592__$1_props_73591$$})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team_form__modal-footer",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team_form__action-buttons",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,{label:$APP.$cljs$core$truth_$$($team$jscomp$26$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.update-team"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.create-team"),className:"main_ui_dashboard_team_form__accept-btn"})})})]})})})};
$app$main$ui$ds$controls$shared$option$option_STAR_$$=function($props_73564_render_avatar_fn$$){var $aria_label$jscomp$5$$=void 0,$selected$jscomp$124$$=void 0,$ref$jscomp$39$$=void 0,$icon$jscomp$15$$=void 0,$on_click$jscomp$15$$=void 0,$class$$jscomp$42_focused$$=void 0,$label$jscomp$33$$=void 0,$id$jscomp$871$$=void 0,$avatar$$=void 0,$dimmed$$=void 0;({"aria-label":$aria_label$jscomp$5$$,selected:$selected$jscomp$124$$,ref:$ref$jscomp$39$$,icon:$icon$jscomp$15$$,onClick:$on_click$jscomp$15$$,
focused:$class$$jscomp$42_focused$$,label:$label$jscomp$33$$,id:$id$jscomp$871$$,avatar:$avatar$$,dimmed:$dimmed$$}=$props_73564_render_avatar_fn$$);$props_73564_render_avatar_fn$$=$APP.$cljs$core$truth_$$($avatar$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($avatar$$,$cljs$cst$5111$render_fn$$):null;$class$$jscomp$42_focused$$="main_ui_ds_controls_shared_option__option "+($icon$jscomp$15$$!=null?"main_ui_ds_controls_shared_option__option-with-icon":"")+" "+($APP.$cljs$core$fn_QMARK_$$($props_73564_render_avatar_fn$$)?
"main_ui_ds_controls_shared_option__option-with-avatar":"")+" "+($APP.$cljs$core$truth_$$($selected$jscomp$124$$)?"main_ui_ds_controls_shared_option__option-selected":"")+" "+($APP.$cljs$core$truth_$$($class$$jscomp$42_focused$$)?"main_ui_ds_controls_shared_option__option-current":"");return(0,$APP.$rumext$v2$jsxs$$)("li",{role:"option",className:$class$$jscomp$42_focused$$,children:[$icon$jscomp$15$$!=null?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon$jscomp$15$$,
size:"s",className:"main_ui_ds_controls_shared_option__option-icon","aria-hidden":$APP.$cljs$core$truth_$$($label$jscomp$33$$)?!0:null,"aria-label":$APP.$cljs$core$not$$($label$jscomp$33$$)?$aria_label$jscomp$5$$:null}):null,$APP.$cljs$core$fn_QMARK_$$($props_73564_render_avatar_fn$$)?(0,$APP.$rumext$v2$jsx$$)($props_73564_render_avatar_fn$$,{avatar:$avatar$$}):null,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_controls_shared_option__option-text "+($APP.$cljs$core$truth_$$($dimmed$$)?"main_ui_ds_controls_shared_option__option-text-dimmed":
""),children:$label$jscomp$33$$}),$selected$jscomp$124$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_ds_controls_shared_option__option-check","aria-hidden":$label$jscomp$33$$?!0:null}):null],id:$id$jscomp$871$$,"data-testid":"dropdown-option",value:$id$jscomp$871$$,"data-id":$id$jscomp$871$$,onClick:$on_click$jscomp$15$$,ref:$ref$jscomp$39$$,"aria-selected":$selected$jscomp$124$$})};
$app$main$ui$ds$controls$shared$token_option$token_option_STAR_$$=function($element_ref$jscomp$1_internal_id$jscomp$2_props_73566$$){var $selected$jscomp$125$$=void 0,$ref$jscomp$40$$=void 0,$value$jscomp$748$$=void 0,$name$jscomp$411$$=void 0,$resolved$jscomp$2$$=void 0,$on_click$jscomp$16$$=void 0,$focused$jscomp$1$$=void 0,$id$jscomp$872_id__$1$jscomp$12$$=void 0;({id:$id$jscomp$872_id__$1$jscomp$12$$,name:$name$jscomp$411$$,onClick:$on_click$jscomp$16$$,selected:$selected$jscomp$125$$,ref:$ref$jscomp$40$$,
focused:$focused$jscomp$1$$,resolved:$resolved$jscomp$2$$,value:$value$jscomp$748$$}=$element_ref$jscomp$1_internal_id$jscomp$2_props_73566$$);$element_ref$jscomp$1_internal_id$jscomp$2_props_73566$$=(0,$APP.$rumext$v2$use_id$$)();$id$jscomp$872_id__$1$jscomp$12$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$872_id__$1$jscomp$12$$,$element_ref$jscomp$1_internal_id$jscomp$2_props_73566$$);$element_ref$jscomp$1_internal_id$jscomp$2_props_73566$$=(0,$APP.$rumext$v2$use_ref$$)(null);
return(0,$APP.$rumext$v2$jsxs$$)("li",{role:"option","aria-label":$name$jscomp$411$$,className:"main_ui_ds_controls_shared_token_option__token-option main_ui_ds_controls_shared_token_option__option-with-pill "+($APP.$cljs$core$truth_$$($selected$jscomp$125$$)?"main_ui_ds_controls_shared_token_option__option-selected-token":"")+" "+($APP.$cljs$core$truth_$$($focused$jscomp$1$$)?"main_ui_ds_controls_shared_token_option__option-current":""),children:[$APP.$cljs$core$truth_$$($selected$jscomp$125$$)?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_ds_controls_shared_token_option__option-check","aria-hidden":$APP.$cljs$core$truth_$$($name$jscomp$411$$)?!0:null}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_controls_shared_token_option__icon-placeholder"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$name$jscomp$411$$,triggerRef:$element_ref$jscomp$1_internal_id$jscomp$2_props_73566$$,
id:""+($id$jscomp$872_id__$1$jscomp$12$$??"")+"-name",className:"main_ui_ds_controls_shared_token_option__option-text",children:(0,$APP.$rumext$v2$jsx$$)("span",{"aria-labelledby":""+($id$jscomp$872_id__$1$jscomp$12$$??"")+"-name",ref:$element_ref$jscomp$1_internal_id$jscomp$2_props_73566$$,className:"main_ui_ds_controls_shared_token_option__option-name",children:$name$jscomp$411$$})}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$628$$=$resolved$jscomp$2$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$628$$)?
!$APP.$cljs$core$map_QMARK_$$($resolved$jscomp$2$$):$and__5023__auto__$jscomp$628$$}())?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_controls_shared_token_option__option-pill",children:$resolved$jscomp$2$$}):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$629$$=$resolved$jscomp$2$$==null;return $and__5023__auto__$jscomp$629$$?$value$jscomp$748$$:$and__5023__auto__$jscomp$629$$}())?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_controls_shared_token_option__option-pill",
children:"--"}):null],id:$id$jscomp$872_id__$1$jscomp$12$$,"data-testid":"dropdown-option",value:$id$jscomp$872_id__$1$jscomp$12$$,"data-id":$id$jscomp$872_id__$1$jscomp$12$$,onClick:$on_click$jscomp$16$$,ref:$ref$jscomp$40$$,"aria-selected":$selected$jscomp$125$$})};
$APP.$app$main$ui$ds$controls$shared$render_option$render_option$$=function($option$jscomp$6$$,$ref$jscomp$41$$,$on_click$jscomp$17$$,$selected$jscomp$126$$,$focused$jscomp$2$$){var $id$jscomp$873$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($option$jscomp$6$$,$APP.$cljs$cst$266$id$$),$name$jscomp$412$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($option$jscomp$6$$,$APP.$cljs$cst$725$name$$),$G__73626$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($option$jscomp$6$$,
$APP.$cljs$cst$139$type$$);switch($G__73626$$ instanceof $APP.$cljs$core$Keyword$$?$G__73626$$.$fqn$:null){case "group":return(0,$APP.$rumext$v2$jsxs$$)("li",{role:"presentation",className:"main_ui_ds_controls_shared_render_option__group-option",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-down",size:"m",className:"main_ui_ds_controls_shared_render_option__option-check","aria-hidden":$APP.$cljs$core$truth_$$($name$jscomp$412$$)?!0:null}),
$APP.$app$common$data$name$$($name$jscomp$412$$)]},$app$common$weak$weak_key$$($option$jscomp$6$$));case "separator":return(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_ds_controls_shared_render_option__option-separator"},$app$common$weak$weak_key$$($option$jscomp$6$$));case "empty":return(0,$APP.$rumext$v2$jsx$$)("li",{role:"presentation",className:"main_ui_ds_controls_shared_render_option__option-empty",children:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($option$jscomp$6$$,$APP.$cljs$cst$2287$label$$)},
$app$common$weak$weak_key$$($option$jscomp$6$$));case "token":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$shared$token_option$token_option_STAR_$$,{role:"option",selected:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$873$$,$selected$jscomp$126$$),id:$id$jscomp$873$$,name:$name$jscomp$412$$,value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($option$jscomp$6$$,$APP.$cljs$cst$260$value$$),focused:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$873$$,
$focused$jscomp$2$$),onClick:$on_click$jscomp$17$$,ref:$ref$jscomp$41$$,resolved:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($option$jscomp$6$$,$APP.$cljs$cst$4605$resolved_value$$)},$app$common$weak$weak_key$$($option$jscomp$6$$));default:return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$shared$option$option_STAR_$$,{role:"option",selected:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$873$$,$selected$jscomp$126$$),"aria-label":$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($option$jscomp$6$$,
$APP.$cljs$cst$4564$aria_label$$),label:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($option$jscomp$6$$,$APP.$cljs$cst$2287$label$$),id:$id$jscomp$873$$,avatar:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($option$jscomp$6$$,$cljs$cst$5110$avatar$$),focused:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$873$$,$focused$jscomp$2$$),dimmed:$APP.$cljs$cst$5109$dimmed$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$6$$)===!0,onClick:$on_click$jscomp$17$$,ref:$ref$jscomp$41$$,
icon:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($option$jscomp$6$$,$APP.$cljs$cst$1721$icon$$)},$app$common$weak$weak_key$$($option$jscomp$6$$))}};
$APP.$app$main$ui$ds$controls$shared$options_dropdown$options_dropdown_STAR_$$=function($align__$1$jscomp$1_props_73631$$){var $options$jscomp$594$$=void 0,$align$jscomp$2$$=void 0,$selected$jscomp$127$$=void 0,$ref$jscomp$42$$=void 0,$on_click$jscomp$18$$=void 0,$empty_to_end$$=void 0,$focused$jscomp$3$$=void 0,$class$$jscomp$43_props__$1$jscomp$59$$=void 0,$options_blank_wrapper_ref$jscomp$2$$=void 0,$options__$1$jscomp$77_props$jscomp$261$$=void 0;({options:$options$jscomp$594$$,align:$align$jscomp$2$$,
selected:$selected$jscomp$127$$,ref:$ref$jscomp$42$$,onClick:$on_click$jscomp$18$$,emptyToEnd:$empty_to_end$$,focused:$focused$jscomp$3$$,className:$class$$jscomp$43_props__$1$jscomp$59$$,wrapperRef:$options_blank_wrapper_ref$jscomp$2$$,...$options__$1$jscomp$77_props$jscomp$261$$}=$align__$1$jscomp$1_props_73631$$);$align__$1$jscomp$1_props_73631$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($align$jscomp$2$$,$APP.$cljs$cst$257$left$$);$class$$jscomp$43_props__$1$jscomp$59$$={...$options__$1$jscomp$77_props$jscomp$261$$,
className:($class$$jscomp$43_props__$1$jscomp$59$$??"")+" main_ui_ds_controls_shared_options_dropdown__option-list "+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align__$1$jscomp$1_props_73631$$,$APP.$cljs$cst$257$left$$)?"main_ui_ds_controls_shared_options_dropdown__left-align":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align__$1$jscomp$1_props_73631$$,$APP.$cljs$cst$258$right$$)?"main_ui_ds_controls_shared_options_dropdown__right-align":"")),ref:$options_blank_wrapper_ref$jscomp$2$$,
tabIndex:"-1",role:"listbox"};$options_blank_wrapper_ref$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($empty_to_end$$),$APP.$rumext$v2$adapt$$($options$jscomp$594$$)],function(){return $empty_to_end$$?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$main$ui$ds$controls$shared$options_dropdown$xf_COLON_filter_blank_id$$,$options$jscomp$594$$):null});$options__$1$jscomp$77_props$jscomp$261$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($empty_to_end$$),
$APP.$rumext$v2$adapt$$($options$jscomp$594$$)],function(){return $empty_to_end$$?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$main$ui$ds$controls$shared$options_dropdown$xf_COLON_filter_non_blank_id$$,$options$jscomp$594$$):$options$jscomp$594$$});return(0,$APP.$rumext$v2$create_element$$)("ul",$class$$jscomp$43_props__$1$jscomp$59$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$48$$,$option$jscomp$7$$){$out_arr__44124__auto__$jscomp$48$$.push($APP.$app$main$ui$ds$controls$shared$render_option$render_option$$($option$jscomp$7$$,
$ref$jscomp$42$$,$on_click$jscomp$18$$,$selected$jscomp$127$$,$focused$jscomp$3$$));return $out_arr__44124__auto__$jscomp$48$$},[],$options__$1$jscomp$77_props$jscomp$261$$),$APP.$cljs$core$seq$$($options_blank_wrapper_ref$jscomp$2$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$seq$$($options__$1$jscomp$77_props$jscomp$261$$)?(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_ds_controls_shared_options_dropdown__option-separator"}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$49$$,
$option$jscomp$8$$){$out_arr__44124__auto__$jscomp$49$$.push($APP.$app$main$ui$ds$controls$shared$render_option$render_option$$($option$jscomp$8$$,$ref$jscomp$42$$,$on_click$jscomp$18$$,$selected$jscomp$127$$,$focused$jscomp$3$$));return $out_arr__44124__auto__$jscomp$49$$},[],$options_blank_wrapper_ref$jscomp$2$$)]}):null)};
$APP.$app$main$ui$ds$controls$select$get_option$$=function($options$jscomp$595_options__$1$jscomp$78$$,$id$jscomp$874$$){$options$jscomp$595_options__$1$jscomp$78$$=$APP.$cljs$core$delay_QMARK_$$($options$jscomp$595_options__$1$jscomp$78$$)?$APP.$cljs$core$_deref$$($options$jscomp$595_options__$1$jscomp$78$$):$options$jscomp$595_options__$1$jscomp$78$$;var $or__5025__auto__$jscomp$955$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73632_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$874$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__73632_SHARP_$$,$APP.$cljs$cst$266$id$$))},$options$jscomp$595_options__$1$jscomp$78$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$955$$)?$or__5025__auto__$jscomp$955$$:$APP.$cljs$core$seq$$($options$jscomp$595_options__$1$jscomp$78$$)?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($options$jscomp$595_options__$1$jscomp$78$$,0):null};
$APP.$app$main$ui$ds$controls$select$handle_focus_change$$=function($id$jscomp$875_option$jscomp$10_options$jscomp$597$$,$focused_STAR_$$,$new_index$jscomp$6$$,$node$jscomp$371_nodes$jscomp$34$$){$id$jscomp$875_option$jscomp$10_options$jscomp$597$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$875_option$jscomp$10_options$jscomp$597$$,$new_index$jscomp$6$$);$id$jscomp$875_option$jscomp$10_options$jscomp$597$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$875_option$jscomp$10_options$jscomp$597$$,
$APP.$cljs$cst$266$id$$);$node$jscomp$371_nodes$jscomp$34$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($node$jscomp$371_nodes$jscomp$34$$,$id$jscomp$875_option$jscomp$10_options$jscomp$597$$);$APP.$cljs$core$reset_BANG_$$($focused_STAR_$$,$id$jscomp$875_option$jscomp$10_options$jscomp$597$$);return $APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($node$jscomp$371_nodes$jscomp$34$$,!1)};
$app$main$ui$ds$controls$select$handle_selection$$=function($focused_STAR_$jscomp$1$$,$selected_STAR_$$,$open_STAR_$$){var $temp__5825__auto___73635$$=$APP.$cljs$core$_deref$$($focused_STAR_$jscomp$1$$);$APP.$cljs$core$truth_$$($temp__5825__auto___73635$$)&&$APP.$cljs$core$reset_BANG_$$($selected_STAR_$$,$temp__5825__auto___73635$$);$APP.$cljs$core$reset_BANG_$$($open_STAR_$$,!1);$APP.$cljs$core$reset_BANG_$$($focused_STAR_$jscomp$1$$,null)};
$APP.$app$main$ui$ds$controls$select$select_STAR_$$=function($props_73634_variant__$1$jscomp$5$$){var $is_open$jscomp$1_options$jscomp$598$$=void 0,$on_change$jscomp$23$$=void 0,$dropdown_alignment$$=void 0,$listbox_id_variant$jscomp$22$$=void 0,$disabled$jscomp$9$$=void 0,$default_selected$$=void 0,$empty_to_end$jscomp$1_empty_to_end__$1$$=void 0,$wrapper_class$$=void 0,$class$$jscomp$44_props__$1$jscomp$60$$=void 0,$label$jscomp$34_props$jscomp$262$$=void 0;({options:$is_open$jscomp$1_options$jscomp$598$$,
onChange:$on_change$jscomp$23$$,dropdownAlignment:$dropdown_alignment$$,variant:$listbox_id_variant$jscomp$22$$,disabled:$disabled$jscomp$9$$,defaultSelected:$default_selected$$,emptyToEnd:$empty_to_end$jscomp$1_empty_to_end__$1$$,wrapperClass:$wrapper_class$$,className:$class$$jscomp$44_props__$1$jscomp$60$$,...$label$jscomp$34_props$jscomp$262$$}=$props_73634_variant__$1$jscomp$5$$);var $options__$1$jscomp$79$$=$APP.$cljs$core$array_QMARK_$$($is_open$jscomp$1_options$jscomp$598$$)?$APP.$rumext$v2$util$bean$$($is_open$jscomp$1_options$jscomp$598$$):
$is_open$jscomp$1_options$jscomp$598$$;$props_73634_variant__$1$jscomp$5$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($listbox_id_variant$jscomp$22$$,"default");$empty_to_end$jscomp$1_empty_to_end__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($empty_to_end$jscomp$1_empty_to_end__$1$$,!1);var $is_open_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$is_open$jscomp$1_options$jscomp$598$$=$APP.$cljs$core$_deref$$($is_open_STAR_$$);var $selected_id_STAR_$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $option$jscomp$inline_7500$$=$APP.$app$main$ui$ds$controls$select$get_option$$($options__$1$jscomp$79$$,$default_selected$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($option$jscomp$inline_7500$$,$APP.$cljs$cst$266$id$$)}),$selected_id$jscomp$3$$=$APP.$cljs$core$_deref$$($selected_id_STAR_$$),$focused_id_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$focused_id$$=$APP.$cljs$core$_deref$$($focused_id_STAR_$$);
$listbox_id_variant$jscomp$22$$=(0,$APP.$rumext$v2$use_id$$)();var $nodes_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$options_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$select_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$empty_selected_id_QMARK_$$=$goog$string$internal$isEmptyOrWhitespace$$($goog$string$makeSafe$$($selected_id$jscomp$3$$)),$set_option_ref$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$372$$){var $state__$1$jscomp$52_state__$2$jscomp$6$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$1$$),{}),$id$jscomp$876$$=$APP.$app$util$dom$get_data$$($node$jscomp$372$$,"id");$state__$1$jscomp$52_state__$2$jscomp$6$$=$APP.$app$util$object$set_BANG_$$($state__$1$jscomp$52_state__$2$jscomp$6$$,$id$jscomp$876$$,$node$jscomp$372$$);$APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$1$$,$state__$1$jscomp$52_state__$2$jscomp$6$$);return function(){var $state__$4$jscomp$1_state__$5$jscomp$1$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$1$$),{}),$id__$1$jscomp$13$$=$APP.$app$util$dom$get_data$$($node$jscomp$372$$,"id");$state__$4$jscomp$1_state__$5$jscomp$1$$=$APP.$app$util$object$unset_BANG_$$($state__$4$jscomp$1_state__$5$jscomp$1$$,$id__$1$jscomp$13$$);return $APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$1$$,$state__$4$jscomp$1_state__$5$jscomp$1$$)}}),$on_option_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$23$$)],
function($event$jscomp$188_id$jscomp$877$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$188_id$jscomp$877$$);$event$jscomp$188_id$jscomp$877$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$188_id$jscomp$877$$),"id");$APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$$,$event$jscomp$188_id$jscomp$877$$);$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$$,null);$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$$,!1);return $APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$23$$)?
$on_change$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$188_id$jscomp$877$$):$on_change$jscomp$23$$($event$jscomp$188_id$jscomp$877$$):null}),$on_click$jscomp$19$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disabled$jscomp$9$$)],function($event$jscomp$189$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$189$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$189$$);return $APP.$cljs$core$truth_$$($disabled$jscomp$9$$)?
null:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($is_open_STAR_$$,$APP.$cljs$core$not$$)}),$on_blur$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$190$$){if($APP.$cljs$core$truth_$$($APP.$app$util$dom$is_child_QMARK_$$($APP.$rumext$v2$ref_val$$($select_ref$$),$event$jscomp$190$$!=null?$event$jscomp$190$$.relatedTarget:null)))return null;$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$$,null);return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$$,
!1)}),$icon$jscomp$16_on_button_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focused_id$$),$APP.$rumext$v2$adapt$$($disabled$jscomp$9$$)],function($event$jscomp$191$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$191$$);if($APP.$cljs$core$truth_$$($disabled$jscomp$9$$))return null;var $options__$2$$=$APP.$rumext$v2$ref_val$$($options_ref$$),$len$jscomp$75$$=$APP.$cljs$core$count$$($options__$2$$),$index$jscomp$383$$=$APP.$app$common$data$index_of_pred$$($options__$2$$,
function($p1__73633_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($focused_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__73633_SHARP_$$,$APP.$cljs$cst$266$id$$))}),$nodes$jscomp$35$$=$APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$1$$);if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$home_QMARK_$$)($event$jscomp$191$$)))return $APP.$app$main$ui$ds$controls$select$handle_focus_change$$($options__$2$$,$focused_id_STAR_$$,0,$nodes$jscomp$35$$);if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$191$$)))return $APP.$app$main$ui$ds$controls$select$handle_focus_change$$($options__$2$$,
$focused_id_STAR_$$,$APP.$cljs$core$mod$$($index$jscomp$383$$-1,$len$jscomp$75$$),$nodes$jscomp$35$$);if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$191$$)))return $APP.$app$main$ui$ds$controls$select$handle_focus_change$$($options__$2$$,$focused_id_STAR_$$,$APP.$cljs$core$mod$$($index$jscomp$383$$+1,$len$jscomp$75$$),$nodes$jscomp$35$$);if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$956$$=(0,$APP.$app$util$keyboard$space_QMARK_$$)($event$jscomp$191$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$956$$)?$or__5025__auto__$jscomp$956$$:(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$191$$)}())){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($is_open_STAR_$$)))return $APP.$app$util$dom$prevent_default$$($event$jscomp$191$$),$app$main$ui$ds$controls$select$handle_selection$$($focused_id_STAR_$$,$selected_id_STAR_$$,$is_open_STAR_$$),$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$23$$)&&$focused_id$$!=null?$on_change$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$($focused_id$$):$on_change$jscomp$23$$($focused_id$$):null}else if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$191$$)))return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$$,!1),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$$,null);return null});$class$$jscomp$44_props__$1$jscomp$60$$={...$label$jscomp$34_props$jscomp$262$$,role:"combobox","aria-expanded":$is_open$jscomp$1_options$jscomp$598$$,className:($class$$jscomp$44_props__$1$jscomp$60$$??
"")+" main_ui_ds_controls_select__select "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_73634_variant__$1$jscomp$5$$,"ghost")?"main_ui_ds_controls_select__variant-ghost":""),"aria-haspopup":"listbox",onClick:$on_click$jscomp$19$$,"aria-controls":$listbox_id_variant$jscomp$22$$,"aria-activedescendant":$focused_id$$,onKeyDown:$icon$jscomp$16_on_button_key_down$$,disabled:$disabled$jscomp$9$$};var $dimmed_QMARK__selected_option$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options__$1$jscomp$79$$),
$APP.$rumext$v2$adapt$$($selected_id$jscomp$3$$)],function(){return $APP.$app$common$data$not_empty_QMARK_$$($options__$1$jscomp$79$$)?$APP.$app$main$ui$ds$controls$select$get_option$$($options__$1$jscomp$79$$,$selected_id$jscomp$3$$):null});$label$jscomp$34_props$jscomp$262$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dimmed_QMARK__selected_option$jscomp$1$$,$APP.$cljs$cst$2287$label$$);$icon$jscomp$16_on_button_key_down$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dimmed_QMARK__selected_option$jscomp$1$$,
$APP.$cljs$cst$1721$icon$$);var $has_icon_QMARK_$$=$icon$jscomp$16_on_button_key_down$$!=null;$dimmed_QMARK__selected_option$jscomp$1$$=$APP.$cljs$cst$5109$dimmed$$.$cljs$core$IFn$_invoke$arity$1$($dimmed_QMARK__selected_option$jscomp$1$$);var $icon_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$icon_id$jscomp$4$$=(0,$APP.$rumext$v2$use_id$$)();$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options__$1$jscomp$79$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($options_ref$$,
$options__$1$jscomp$79$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$on_click$jscomp$19$$,ref:$select_ref$$,onBlur:$on_blur$jscomp$4$$,className:($wrapper_class$$??"")+" main_ui_ds_controls_select__select-wrapper",children:[(0,$APP.$rumext$v2$create_element$$)("button",$class$$jscomp$44_props__$1$jscomp$60$$,(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_ds_controls_select__select-header "+($has_icon_QMARK_$$?"main_ui_ds_controls_select__header-icon":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_73634_variant__$1$jscomp$5$$,
"icon-only")?"main_ui_ds_controls_select__header-icon-only":""),children:[$has_icon_QMARK_$$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_73634_variant__$1$jscomp$5$$,"icon-only")?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$label$jscomp$34_props$jscomp$262$$,triggerRef:$icon_ref$jscomp$1$$,id:""+($icon_id$jscomp$4$$??"")+"-name",className:"main_ui_ds_controls_select__option-text",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:$icon$jscomp$16_on_button_key_down$$,ref:$icon_ref$jscomp$1$$,"aria-labelledby":""+($icon_id$jscomp$4$$??"")+"-name"})}):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon$jscomp$16_on_button_key_down$$,size:"s","aria-hidden":!0}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_73634_variant__$1$jscomp$5$$,"icon-only")?null:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_controls_select__header-label "+($APP.$cljs$core$truth_$$($empty_selected_id_QMARK_$$?
$empty_selected_id_QMARK_$$:$dimmed_QMARK__selected_option$jscomp$1$$)?"main_ui_ds_controls_select__header-label-dimmed":""),children:$empty_selected_id_QMARK_$$?"--":$label$jscomp$34_props$jscomp$262$$})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-down",className:"main_ui_ds_controls_select__arrow",size:"s","aria-hidden":!0})),$is_open$jscomp$1_options$jscomp$598$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$shared$options_dropdown$options_dropdown_STAR_$$,
{onClick:$on_option_click$$,id:$listbox_id_variant$jscomp$22$$,options:$options__$1$jscomp$79$$,selected:$selected_id$jscomp$3$$,focused:$focused_id$$,align:$dropdown_alignment$$,emptyToEnd:$empty_to_end$jscomp$1_empty_to_end__$1$$,ref:$set_option_ref$$}):null]})};
$APP.$app$main$ui$ds$controls$combobox$combobox_STAR_$$=function($empty_to_end__$1$jscomp$1_props_73640$$){var $listbox_id$jscomp$1_options$jscomp$599$$=void 0,$on_change$jscomp$24$$=void 0,$max_length$jscomp$4$$=void 0,$select_only_set_option_ref$jscomp$1$$=void 0,$placeholder$jscomp$3$$=void 0,$disabled$jscomp$10$$=void 0,$has_error$$=void 0,$default_selected$jscomp$1$$=void 0,$empty_to_end$jscomp$2_on_option_click$jscomp$1$$=void 0,$id$jscomp$878$$=void 0,$class$$jscomp$45$$=void 0;({options:$listbox_id$jscomp$1_options$jscomp$599$$,
onChange:$on_change$jscomp$24$$,maxLength:$max_length$jscomp$4$$,selectOnly:$select_only_set_option_ref$jscomp$1$$,placeholder:$placeholder$jscomp$3$$,disabled:$disabled$jscomp$10$$,hasError:$has_error$$,defaultSelected:$default_selected$jscomp$1$$,emptyToEnd:$empty_to_end$jscomp$2_on_option_click$jscomp$1$$,id:$id$jscomp$878$$,className:$class$$jscomp$45$$}=$empty_to_end__$1$jscomp$1_props_73640$$);var $options__$1$jscomp$80$$=$APP.$cljs$core$array_QMARK_$$($listbox_id$jscomp$1_options$jscomp$599$$)?
$APP.$rumext$v2$util$bean$$($listbox_id$jscomp$1_options$jscomp$599$$):$listbox_id$jscomp$1_options$jscomp$599$$,$select_only__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($select_only_set_option_ref$jscomp$1$$,!1);$empty_to_end__$1$jscomp$1_props_73640$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($empty_to_end$jscomp$2_on_option_click$jscomp$1$$,!1);var $is_open_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$is_open$jscomp$2$$=
$APP.$cljs$core$_deref$$($is_open_STAR_$jscomp$1$$),$selected_id_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($default_selected$jscomp$1$$),$selected_id$jscomp$4$$=$APP.$cljs$core$_deref$$($selected_id_STAR_$jscomp$1$$),$filter_id_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$filter_id$jscomp$9$$=$APP.$cljs$core$_deref$$($filter_id_STAR_$$),$focused_id_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$focused_id$jscomp$1$$=$APP.$cljs$core$_deref$$($focused_id_STAR_$jscomp$1$$),$combobox_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$input_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(null),$nodes_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),$options_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null);$listbox_id$jscomp$1_options$jscomp$599$$=(0,$APP.$rumext$v2$use_id$$)();var $value_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$dropdown_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options__$1$jscomp$80$$),
$APP.$rumext$v2$adapt$$($filter_id$jscomp$9$$),$APP.$rumext$v2$adapt$$($select_only__$1$$)],function(){return $APP.$cljs$core$truth_$$($select_only__$1$$)?$APP.$cljs$core$not_empty$$($options__$1$jscomp$80$$):$APP.$cljs$core$not_empty$$($APP.$cljs$core$filterv$$(function($option$jscomp$11_option__$1$$){$option$jscomp$11_option__$1$$=$APP.$cuerdas$core$lower$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($option$jscomp$11_option__$1$$,$APP.$cljs$cst$2287$label$$));return $APP.$cuerdas$core$includes_QMARK_$$($option$jscomp$11_option__$1$$,
$APP.$cuerdas$core$lower$$($filter_id$jscomp$9$$))},$options__$1$jscomp$80$$))});$select_only_set_option_ref$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$374$$){var $state__$1$jscomp$53_state__$2$jscomp$7$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$2$$),{}),$id__$1$jscomp$14$$=$APP.$app$util$dom$get_data$$($node$jscomp$374$$,"id");$state__$1$jscomp$53_state__$2$jscomp$7$$=$APP.$app$util$object$set_BANG_$$($state__$1$jscomp$53_state__$2$jscomp$7$$,
$id__$1$jscomp$14$$,$node$jscomp$374$$);$APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$2$$,$state__$1$jscomp$53_state__$2$jscomp$7$$);return function(){var $state__$4$jscomp$2_state__$5$jscomp$2$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$2$$),{}),$id__$2$$=$APP.$app$util$dom$get_data$$($node$jscomp$374$$,"id");$state__$4$jscomp$2_state__$5$jscomp$2$$=$APP.$app$util$object$unset_BANG_$$($state__$4$jscomp$2_state__$5$jscomp$2$$,
$id__$2$$);return $APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$2$$,$state__$4$jscomp$2_state__$5$jscomp$2$$)}});$empty_to_end$jscomp$2_on_option_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$24$$)],function($event$jscomp$192_id__$1$jscomp$15$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$192_id__$1$jscomp$15$$);$event$jscomp$192_id__$1$jscomp$15$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$192_id__$1$jscomp$15$$),
"id");$APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$1$$,$event$jscomp$192_id__$1$jscomp$15$$);$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$1$$,!1);$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$1$$,null);return $APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$24$$)?$on_change$jscomp$24$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$24$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$192_id__$1$jscomp$15$$):$on_change$jscomp$24$$($event$jscomp$192_id__$1$jscomp$15$$):null});
var $on_click$jscomp$20$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disabled$jscomp$10$$)],function($event$jscomp$193$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$193$$);if($APP.$cljs$core$truth_$$($disabled$jscomp$10$$))return null;$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($is_open_STAR_$jscomp$1$$))||$APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$$,"");return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($is_open_STAR_$jscomp$1$$,
$APP.$cljs$core$not$$)}),$on_blur$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$24$$),$APP.$rumext$v2$adapt$$($options__$1$jscomp$80$$),$APP.$rumext$v2$adapt$$($selected_id$jscomp$4$$),$APP.$rumext$v2$adapt$$($select_only__$1$$)],function($event$jscomp$194_input_value_temp__5825__auto__$jscomp$280_value$jscomp$749$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$194_input_value_temp__5825__auto__$jscomp$280_value$jscomp$749$$);
if($APP.$cljs$core$truth_$$($APP.$app$util$dom$is_child_QMARK_$$($APP.$rumext$v2$ref_val$$($combobox_ref$$),$event$jscomp$194_input_value_temp__5825__auto__$jscomp$280_value$jscomp$749$$!=null?$event$jscomp$194_input_value_temp__5825__auto__$jscomp$280_value$jscomp$749$$.relatedTarget:null)))return null;$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$1$$,!1);$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$1$$,null);if($APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$24$$)&&($event$jscomp$194_input_value_temp__5825__auto__$jscomp$280_value$jscomp$749$$=
$APP.$rumext$v2$ref_val$$($input_ref$jscomp$4$$),$APP.$cljs$core$truth_$$($event$jscomp$194_input_value_temp__5825__auto__$jscomp$280_value$jscomp$749$$))){$event$jscomp$194_input_value_temp__5825__auto__$jscomp$280_value$jscomp$749$$=$APP.$app$util$dom$get_input_value$$($event$jscomp$194_input_value_temp__5825__auto__$jscomp$280_value$jscomp$749$$);var $selected_option$jscomp$3$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73637_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected_id$jscomp$4$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__73637_SHARP_$$,$APP.$cljs$cst$266$id$$))},$options__$1$jscomp$80$$);$event$jscomp$194_input_value_temp__5825__auto__$jscomp$280_value$jscomp$749$$=$APP.$cljs$core$truth_$$($select_only__$1$$)?$selected_id$jscomp$4$$:$selected_option$jscomp$3$$!=null?$selected_id$jscomp$4$$:$event$jscomp$194_input_value_temp__5825__auto__$jscomp$280_value$jscomp$749$$;return $on_change$jscomp$24$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$24$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$194_input_value_temp__5825__auto__$jscomp$280_value$jscomp$749$$):
$on_change$jscomp$24$$($event$jscomp$194_input_value_temp__5825__auto__$jscomp$280_value$jscomp$749$$)}return null}),$on_input_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disabled$jscomp$10$$)],function($event$jscomp$195$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$195$$);if($APP.$cljs$core$truth_$$($disabled$jscomp$10$$))return null;$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($is_open_STAR_$jscomp$1$$))||$APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$$,
"");return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$1$$,!0)}),$on_input_focus$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$196$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$196$$);return $APP.$cljs$core$truth_$$($disabled$jscomp$10$$)?null:$APP.$app$util$dom$select_text_BANG_$$($event$jscomp$196$$.target)}),$on_input_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open$jscomp$2$$),$APP.$rumext$v2$adapt$$($focused_id$jscomp$1$$),
$APP.$rumext$v2$adapt$$($disabled$jscomp$10$$),$APP.$rumext$v2$adapt$$($select_only__$1$$)],function($event$jscomp$197$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$197$$);if($APP.$cljs$core$truth_$$($disabled$jscomp$10$$))return null;$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($select_only__$1$$)?$APP.$cljs$core$not$$((0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$197$$))&&$APP.$cljs$core$not$$((0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$197$$))&&$APP.$cljs$core$not$$((0,$APP.$app$util$keyboard$home_QMARK_$$)($event$jscomp$197$$))&&
$APP.$cljs$core$not$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$197$$))&&$APP.$cljs$core$not$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$197$$))&&$APP.$cljs$core$not$$((0,$APP.$app$util$keyboard$tab_QMARK_$$)($event$jscomp$197$$)):$select_only__$1$$)&&$APP.$app$util$dom$prevent_default$$($event$jscomp$197$$);var $options__$2$jscomp$1$$=$APP.$rumext$v2$ref_val$$($options_ref$jscomp$1$$),$len$jscomp$76_new_index$jscomp$7$$=$APP.$cljs$core$count$$($options__$2$jscomp$1$$),
$index$jscomp$384_nodes$jscomp$36$$=$APP.$app$common$data$index_of_pred$$($options__$2$jscomp$1$$,function($p1__73638_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($focused_id$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__73638_SHARP_$$,$APP.$cljs$cst$266$id$$))}),$index__$1$jscomp$16$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$384_nodes$jscomp$36$$,-1);$index$jscomp$384_nodes$jscomp$36$$=$APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$2$$);
return $APP.$cljs$core$truth_$$($is_open$jscomp$2$$)?$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$home_QMARK_$$)($event$jscomp$197$$))?$APP.$app$main$ui$ds$controls$select$handle_focus_change$$($options__$2$jscomp$1$$,$focused_id_STAR_$jscomp$1$$,0,$index$jscomp$384_nodes$jscomp$36$$):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$197$$))?($len$jscomp$76_new_index$jscomp$7$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index__$1$jscomp$16$$,
-1)?$len$jscomp$76_new_index$jscomp$7$$-1:$APP.$cljs$core$mod$$($index__$1$jscomp$16$$-1,$len$jscomp$76_new_index$jscomp$7$$),$APP.$app$main$ui$ds$controls$select$handle_focus_change$$($options__$2$jscomp$1$$,$focused_id_STAR_$jscomp$1$$,$len$jscomp$76_new_index$jscomp$7$$,$index$jscomp$384_nodes$jscomp$36$$)):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$197$$))?($len$jscomp$76_new_index$jscomp$7$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index__$1$jscomp$16$$,
-1)?0:$APP.$cljs$core$mod$$($index__$1$jscomp$16$$+1,$len$jscomp$76_new_index$jscomp$7$$),$APP.$app$main$ui$ds$controls$select$handle_focus_change$$($options__$2$jscomp$1$$,$focused_id_STAR_$jscomp$1$$,$len$jscomp$76_new_index$jscomp$7$$,$index$jscomp$384_nodes$jscomp$36$$)):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$197$$))?($APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$1$$,$focused_id$jscomp$1$$),$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$1$$,
!1),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$1$$,null),$APP.$app$util$dom$blur_BANG_$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$4$$)),$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$24$$)&&$focused_id$jscomp$1$$!=null?$on_change$jscomp$24$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$24$$.$cljs$core$IFn$_invoke$arity$1$($focused_id$jscomp$1$$):$on_change$jscomp$24$$($focused_id$jscomp$1$$):null):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$197$$))?
($APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$1$$,!1),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$1$$,null),$APP.$app$util$dom$blur_BANG_$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$4$$))):null:$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$197$$))?$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$1$$,!0):$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$958$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$197$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$958$$)?$or__5025__auto__$jscomp$958$$:(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$197$$)}())?$APP.$app$util$dom$blur_BANG_$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$4$$)):null}),$on_input_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($select_only__$1$$)],function($event$jscomp$198_value$jscomp$750$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$198_value$jscomp$750$$);if($APP.$cljs$core$truth_$$($select_only__$1$$))return null;
$event$jscomp$198_value$jscomp$750$$=$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$198_value$jscomp$750$$));$APP.$rumext$v2$set_ref_val_BANG_$$($value_ref$$,$event$jscomp$198_value$jscomp$750$$);$APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$1$$,$event$jscomp$198_value$jscomp$750$$);$APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$$,$event$jscomp$198_value$jscomp$750$$);return $APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$1$$,null)}),$selected_option$jscomp$2$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options__$1$jscomp$80$$),$APP.$rumext$v2$adapt$$($selected_id$jscomp$4$$)],function(){return $APP.$app$common$data$not_empty_QMARK_$$($options__$1$jscomp$80$$)?$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73639_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected_id$jscomp$4$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__73639_SHARP_$$,
$APP.$cljs$cst$266$id$$))},$options__$1$jscomp$80$$):null}),$icon$jscomp$17$$=$APP.$cljs$core$truth_$$($selected_option$jscomp$2$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selected_option$jscomp$2$$,$APP.$cljs$cst$1721$icon$$):null,$avatar$jscomp$1$$=$APP.$cljs$core$truth_$$($selected_option$jscomp$2$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selected_option$jscomp$2$$,$cljs$cst$5110$avatar$$):null,$render_avatar_fn$jscomp$1$$=$APP.$cljs$core$truth_$$($avatar$jscomp$1$$)?
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($avatar$jscomp$1$$,$cljs$cst$5111$render_fn$$):null;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dropdown_options$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($options_ref$jscomp$1$$,$dropdown_options$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($default_selected$jscomp$1$$)],function(){return $APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$1$$,
$default_selected$jscomp$1$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$24$$)],function(){return function(){var $temp__5825__auto__$jscomp$281$$=$APP.$rumext$v2$ref_val$$($value_ref$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$281$$)?($APP.$rumext$v2$set_ref_val_BANG_$$($value_ref$$,null),$on_change$jscomp$24$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$24$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto__$jscomp$281$$):
$on_change$jscomp$24$$($temp__5825__auto__$jscomp$281$$)):null}});return(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$combobox_ref$$,className:"main_ui_ds_controls_combobox__wrapper "+($APP.$cljs$core$truth_$$($has_error$$)?"main_ui_ds_controls_combobox__has-error":"")+" "+($APP.$cljs$core$truth_$$($disabled$jscomp$10$$)?"main_ui_ds_controls_combobox__disabled":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{onBlur:$on_blur$jscomp$5$$,onClick:$on_click$jscomp$20$$,className:($class$$jscomp$45$$??"")+" main_ui_ds_controls_combobox__combobox",
children:[(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_ds_controls_combobox__header "+($icon$jscomp$17$$!=null?"main_ui_ds_controls_combobox__header-icon":"")+" "+($APP.$cljs$core$fn_QMARK_$$($render_avatar_fn$jscomp$1$$)?"main_ui_ds_controls_combobox__header-avatar":""),children:[$APP.$cljs$core$truth_$$($icon$jscomp$17$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon$jscomp$17$$,size:"s","aria-hidden":!0}):null,$APP.$cljs$core$fn_QMARK_$$($render_avatar_fn$jscomp$1$$)?
(0,$APP.$rumext$v2$jsx$$)($render_avatar_fn$jscomp$1$$,{avatar:$avatar$jscomp$1$$}):null,(0,$APP.$rumext$v2$jsx$$)("input",{role:"combobox",onChange:$on_input_change$$,"aria-expanded":$is_open$jscomp$2$$,className:"main_ui_ds_controls_combobox__input",placeholder:$placeholder$jscomp$3$$,"aria-autocomplete":$APP.$cljs$core$truth_$$($select_only__$1$$)?"none":"both",id:$id$jscomp$878$$,"data-testid":"combobox-input",maxLength:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($max_length$jscomp$4$$,
255),value:$APP.$cljs$core$truth_$$($select_only__$1$$)?$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($selected_option$jscomp$2$$),""):$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($selected_option$jscomp$2$$))?$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($selected_id$jscomp$4$$,""):$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($selected_option$jscomp$2$$),
""),onFocus:$on_input_focus$$,autoComplete:"off",readOnly:$select_only__$1$$,onClick:$on_input_click$$,"aria-controls":$listbox_id$jscomp$1_options$jscomp$599$$,type:"text",ref:$input_ref$jscomp$4$$,"aria-activedescendant":$focused_id$jscomp$1$$,onKeyDown:$on_input_key_down$$,disabled:$disabled$jscomp$10$$})]}),$APP.$app$common$data$not_empty_QMARK_$$($options__$1$jscomp$80$$)?(0,$APP.$rumext$v2$jsx$$)("button",{type:"button",tabIndex:"-1","aria-expanded":$is_open$jscomp$2$$,"aria-controls":$listbox_id$jscomp$1_options$jscomp$599$$,
onClick:$on_click$jscomp$20$$,className:"main_ui_ds_controls_combobox__button-toggle-list",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-down",className:"main_ui_ds_controls_combobox__arrow",size:"s","aria-hidden":!0,"data-testid":"combobox-open-button"})}):null]}),$is_open$jscomp$2$$&&$dropdown_options$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$shared$options_dropdown$options_dropdown_STAR_$$,{onClick:$empty_to_end$jscomp$2_on_option_click$jscomp$1$$,
options:$dropdown_options$$,selected:$selected_id$jscomp$4$$,focused:$focused_id$jscomp$1$$,ref:$select_only_set_option_ref$jscomp$1$$,id:$listbox_id$jscomp$1_options$jscomp$599$$,emptyToEnd:$empty_to_end__$1$jscomp$1_props_73640$$,"data-testid":"combobox-options"}):null]})};
$APP.$app$main$ui$notifications$badge$badge_notification$$=function($props_73641_size$jscomp$135$$){var $is_focus$$=$props_73641_size$jscomp$135$$["is-focus"],$content$jscomp$238$$=$props_73641_size$jscomp$135$$.content,$type$jscomp$590$$=$props_73641_size$jscomp$135$$.type;$props_73641_size$jscomp$135$$=$props_73641_size$jscomp$135$$.size;return(0,$APP.$rumext$v2$jsx$$)("aside",{className:"main_ui_notifications_badge__badge-notification "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$590$$,
$APP.$cljs$cst$2343$warning$$)?"main_ui_notifications_badge__warning":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$590$$,$APP.$cljs$cst$849$error$$)?"main_ui_notifications_badge__error":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$590$$,$APP.$cljs$cst$2344$success$$)?"main_ui_notifications_badge__success":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$590$$,$APP.$cljs$cst$1161$info$$)?"main_ui_notifications_badge__info":
"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_73641_size$jscomp$135$$,$APP.$cljs$cst$3877$small$$)?"main_ui_notifications_badge__small":"")+" "+($APP.$cljs$core$truth_$$($is_focus$$)?"main_ui_notifications_badge__focus":""),children:$content$jscomp$238$$})};
$app$main$ui$notifications$context_notification$get_icon_by_level$$=function($level$jscomp$59$$){switch($level$jscomp$59$$ instanceof $APP.$cljs$core$Keyword$$?$level$jscomp$59$$.$fqn$:null){case "warning":return $app$main$ui$notifications$context_notification$neutral_icon$$;case "error":return $app$main$ui$notifications$context_notification$error_icon$$;case "success":return $app$main$ui$notifications$context_notification$success_icon$$;case "info":return $app$main$ui$notifications$context_notification$info_icon$$;
default:return $app$main$ui$notifications$context_notification$neutral_icon$$}};
$APP.$app$main$ui$notifications$context_notification$context_notification$$=function($props_73643$$){var $links$jscomp$3$$=$props_73643$$.links,$content$jscomp$239$$=$props_73643$$.content,$level$jscomp$60$$=$props_73643$$.level,$is_html$jscomp$2$$=$props_73643$$["is-html"];return(0,$APP.$rumext$v2$jsxs$$)("aside",{className:""+($props_73643$$.class??"")+" main_ui_notifications_context_notification__context-notification "+(($APP.$cljs$core$truth_$$($is_html$jscomp$2$$)?"main_ui_notifications_context_notification__contain-html":
"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$60$$,$APP.$cljs$cst$2343$warning$$)?"main_ui_notifications_context_notification__warning":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$60$$,$APP.$cljs$cst$849$error$$)?"main_ui_notifications_context_notification__error":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$60$$,$APP.$cljs$cst$2344$success$$)?"main_ui_notifications_context_notification__success":"")+
" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$60$$,$APP.$cljs$cst$1161$info$$)?"main_ui_notifications_context_notification__info":"")),children:[$app$main$ui$notifications$context_notification$get_icon_by_level$$($level$jscomp$60$$),(0,$APP.$rumext$v2$jsx$$)("div",{dangerouslySetInnerHTML:$APP.$cljs$core$truth_$$($is_html$jscomp$2$$)?{__html:$content$jscomp$239$$}:null,className:"main_ui_notifications_context_notification__context-text",children:$APP.$cljs$core$truth_$$($is_html$jscomp$2$$)?
null:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$content$jscomp$239$$,$links$jscomp$3$$!=null?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$50$$,$link$jscomp$9_p__73644$$){var $index$jscomp$385$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($link$jscomp$9_p__73644$$,0,null);$link$jscomp$9_p__73644$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($link$jscomp$9_p__73644$$,1,null);$out_arr__44124__auto__$jscomp$50$$.push($APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$link_button$link_button$$,
{"class":"main_ui_notifications_context_notification__link","on-click":$APP.$cljs$cst$2354$callback$$.$cljs$core$IFn$_invoke$arity$1$($link$jscomp$9_p__73644$$),value:$APP.$cljs$cst$2287$label$$.$cljs$core$IFn$_invoke$arity$1$($link$jscomp$9_p__73644$$)},"link-"+($index$jscomp$385$$??"")));return $out_arr__44124__auto__$jscomp$50$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($links$jscomp$3$$)):null]})})]})};
$app$main$ui$dashboard$team$invite_members_modal$$=function($current_members_emails_members$jscomp$9_props_73659$$){function $on_error$jscomp$55$$($_form$jscomp$3_map__73671__$1$$,$cause$jscomp$91_type$jscomp$591$$){$_form$jscomp$3_map__73671__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$ex_data$$($cause$jscomp$91_type$jscomp$591$$));$cause$jscomp$91_type$jscomp$591$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_form$jscomp$3_map__73671__$1$$,$APP.$cljs$cst$139$type$$);var $code$jscomp$45$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_form$jscomp$3_map__73671__$1$$,$APP.$cljs$cst$273$code$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2252$validation$$,$cause$jscomp$91_type$jscomp$591$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5128$profile_is_muted$$,$code$jscomp$45$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.profile-is-muted")),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()])):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2252$validation$$,$cause$jscomp$91_type$jscomp$591$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5129$max_invitations_by_request$$,$code$jscomp$45$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($error_text$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.maximum-invitations-by-request-reached",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2501$threshold$$.$cljs$core$IFn$_invoke$arity$1$($_form$jscomp$3_map__73671__$1$$)]))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2561$restriction$$,$cause$jscomp$91_type$jscomp$591$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3382$max_quote_reached$$,$code$jscomp$45$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($error_text$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.max-quota-reached",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2872$target$$.$cljs$core$IFn$_invoke$arity$1$($_form$jscomp$3_map__73671__$1$$)]))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5130$member_is_muted$$,$code$jscomp$45$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5131$email_has_permanent_bounces$$,$code$jscomp$45$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5132$email_has_complaints$$,$code$jscomp$45$$)?
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($error_text$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.email-spam-or-permanent-bounces",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($_form$jscomp$3_map__73671__$1$$)]))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2561$restriction$$,$cause$jscomp$91_type$jscomp$591$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5133$email_domain_is_not_allowed$$,
$code$jscomp$45$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.email-domain-not-allowed")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()])):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.generic")),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]))}function $on_success$jscomp$47$$($_form$jscomp$2_map__73666__$1$$,$p__73665$$){$_form$jscomp$2_map__73666__$1$$=$APP.$cljs$core$__destructure_map$$($p__73665$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_form$jscomp$2_map__73666__$1$$,$APP.$cljs$cst$2328$total$$)>0&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("notifications.invitation-email-sent")));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$APP.$app$main$data$team$fetch_invitations$$()]))}var $invite_email$jscomp$1$$=$current_members_emails_members$jscomp$9_props_73659$$["invite-email"],$roles_team$jscomp$28$$=$current_members_emails_members$jscomp$9_props_73659$$.team,$origin$jscomp$51$$=
$current_members_emails_members$jscomp$9_props_73659$$.origin;$current_members_emails_members$jscomp$9_props_73659$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($roles_team$jscomp$28$$,$APP.$cljs$cst$3264$members$$);var $perms$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($roles_team$jscomp$28$$,$APP.$cljs$cst$1722$permissions$$),$team_id$jscomp$124$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($roles_team$jscomp$28$$,$APP.$cljs$cst$266$id$$);$roles_team$jscomp$28$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($perms$$)],function(){return $APP.$cljs$core$filterv$$($APP.$cljs$core$identity$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"viewer",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.viewer")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,"editor",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.editor")],null),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1597$is_admin$$.$cljs$core$IFn$_invoke$arity$1$($perms$$))?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"admin",$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.admin")],null):null],null))});var $form$jscomp$175_initial$jscomp$31$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$124$$),
$APP.$rumext$v2$adapt$$($invite_email$jscomp$1$$)],function(){return $APP.$cljs$core$truth_$$($invite_email$jscomp$1$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2490$role$$,"editor",$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$124$$,$APP.$cljs$cst$3290$emails$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$invite_email$jscomp$1$$])],null):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2490$role$$,"editor",$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$124$$],
null)});$form$jscomp$175_initial$jscomp$31$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$app$main$ui$dashboard$team$schema_COLON_invite_member_form$$,$APP.$cljs$cst$5076$initial$$,$form$jscomp$175_initial$jscomp$31$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$dashboard$team$schema_COLON_invite_member_form$$,$APP.$cljs$cst$5076$initial$$,$form$jscomp$175_initial$jscomp$31$$);
var $error_text$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$current_data_emails$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$175_initial$jscomp$31$$),$APP.$cljs$cst$5074$clean_data$$),$APP.$cljs$cst$3290$emails$$));$current_members_emails_members$jscomp$9_props_73659$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3183$email$$),$current_members_emails_members$jscomp$9_props_73659$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__modal-team-container "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$51$$,$APP.$cljs$cst$2532$workspace$$)?"main_ui_dashboard_team__modal-team-container-workspace":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$51$$,$APP.$cljs$cst$5134$hero$$)?
"main_ui_dashboard_team__hero":""),children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,{"on-submit":function($form__$1$jscomp$12$$){var $params$jscomp$366$$=$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form__$1$jscomp$12$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$with_meta$$($APP.$app$main$data$team$create_invitations$$($APP.$cljs$core$with_meta$$($params$jscomp$366$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_success$jscomp$47$$,$form__$1$jscomp$12$$),$APP.$cljs$cst$1295$on_error$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_error$jscomp$55$$,$form__$1$jscomp$12$$)],null))),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$origin$jscomp$51$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$team$fetch_invitations$$(),
$APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$(null)]))},form:$form$jscomp$175_initial$jscomp$31$$,children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.invite-team-member.title")}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2532$workspace$$,$origin$jscomp$51$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__invite-team-member-text",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.invite-team-member.text")}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",$APP.$cljs$core$_deref$$($error_text$$))?null:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$context_notification$context_notification$$,{content:$APP.$cljs$core$_deref$$($error_text$$),level:$APP.$cljs$cst$849$error$$}),$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($current_data_emails$$,$current_members_emails_members$jscomp$9_props_73659$$))?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$context_notification$context_notification$$,{content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.invite-member.repeated-invitation"),level:$APP.$cljs$cst$2343$warning$$}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__role-select",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_dashboard_team__role-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.roles")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$select$$,{name:$APP.$cljs$cst$2490$role$$,options:$roles_team$jscomp$28$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__invitation-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$multi_input$$,{type:"email","class":"main_ui_dashboard_team__email-input",name:$APP.$cljs$cst$3290$emails$$,"auto-focus?":!0,trim:!0,"valid-item-fn":$APP.$app$common$schema$parse_email$$,"caution-item-fn":$current_members_emails_members$jscomp$9_props_73659$$,
label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.invite-member.emails")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__action-buttons",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.invite-member-confirm.accept"),className:"main_ui_dashboard_team__accept-btn",disabled:$APP.$cljs$core$boolean$0$$($APP.$cljs$core$some$$($current_data_emails$$,
$current_members_emails_members$jscomp$9_props_73659$$))&&$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($current_members_emails_members$jscomp$9_props_73659$$,$current_data_emails$$))})})]})})};
$app$main$ui$dashboard$team$member_info$$=function($is_you_QMARK__props_73690$$){var $member$$=$is_you_QMARK__props_73690$$.member;$is_you_QMARK__props_73690$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($is_you_QMARK__props_73690$$.profile),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($member$$));return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:$APP.$app$config$resolve_profile_photo_url$$($member$$),
className:"main_ui_dashboard_team__member-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__member-info",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__member-name",children:[$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($member$$),$is_you_QMARK__props_73690$$?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__you",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.you")}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_team__member-email",children:$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($member$$)})]})]})};
$app$main$ui$dashboard$team$rol_info_STAR_$$=function($on_set_owner_props_73693$$){var $is_you_profile$jscomp$40$$=$on_set_owner_props_73693$$.profile,$on_set_viewer$$=$on_set_owner_props_73693$$.onSetViewer,$on_set_editor$$=$on_set_owner_props_73693$$.onSetEditor,$member$jscomp$1$$=$on_set_owner_props_73693$$.member,$on_set_admin$$=$on_set_owner_props_73693$$.onSetAdmin,$is_owner$jscomp$2_team$jscomp$29$$=$on_set_owner_props_73693$$.team;$on_set_owner_props_73693$$=$on_set_owner_props_73693$$.onSetOwner;
var $member_is_owner$$=$APP.$cljs$cst$1598$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($member$jscomp$1$$),$member_is_admin$$=function(){var $and__5023__auto__$jscomp$632$$=$APP.$cljs$cst$1597$is_admin$$.$cljs$core$IFn$_invoke$arity$1$($member$jscomp$1$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$632$$)?$APP.$cljs$core$not$$($member_is_owner$$):$and__5023__auto__$jscomp$632$$}(),$member_is_editor$$=function(){var $and__5023__auto__$jscomp$633$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($member$jscomp$1$$);
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$633$$)?$APP.$cljs$core$not$$($member_is_admin$$)&&$APP.$cljs$core$not$$($member_is_owner$$):$and__5023__auto__$jscomp$633$$}(),$member_is_viewer$$=$APP.$cljs$core$not$$($member_is_editor$$)&&$APP.$cljs$core$not$$($member_is_admin$$)&&$APP.$cljs$core$not$$($member_is_owner$$),$show_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$not_superior_permissions$jscomp$20$$=$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($is_owner$jscomp$2_team$jscomp$29$$);
$is_owner$jscomp$2_team$jscomp$29$$=$APP.$cljs$cst$1598$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($not_superior_permissions$jscomp$20$$);var $is_admin$$=$APP.$cljs$cst$1597$is_admin$$.$cljs$core$IFn$_invoke$arity$1$($not_superior_permissions$jscomp$20$$);$is_you_profile$jscomp$40$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($is_you_profile$jscomp$40$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($member$jscomp$1$$));
var $can_change_rol$$=$APP.$cljs$core$truth_$$($is_owner$jscomp$2_team$jscomp$29$$)?$is_owner$jscomp$2_team$jscomp$29$$:$is_admin$$;$not_superior_permissions$jscomp$20$$=function(){var $and__5023__auto__$jscomp$inline_7504_or__5025__auto__$jscomp$960$$=($and__5023__auto__$jscomp$inline_7504_or__5025__auto__$jscomp$960$$=$APP.$cljs$core$not$$($member_is_owner$$))?$is_admin$$:$and__5023__auto__$jscomp$inline_7504_or__5025__auto__$jscomp$960$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_7504_or__5025__auto__$jscomp$960$$)?
$and__5023__auto__$jscomp$inline_7504_or__5025__auto__$jscomp$960$$:$APP.$cljs$core$truth_$$($can_change_rol$$)?$APP.$cljs$core$truth_$$($member_is_admin$$)?$member_is_admin$$:$APP.$cljs$core$truth_$$($member_is_editor$$)?$member_is_editor$$:$member_is_viewer$$:$can_change_rol$$}();var $role$jscomp$13$$=$APP.$cljs$core$truth_$$($member_is_owner$$)?"labels.owner":$APP.$cljs$core$truth_$$($member_is_admin$$)?"labels.admin":$APP.$cljs$core$truth_$$($member_is_editor$$)?"labels.editor":"labels.viewer",
$on_show$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_QMARK_$$,!0)}),$on_hide$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_QMARK_$$,!1)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_change_rol$$)?$APP.$cljs$core$truth_$$($not_superior_permissions$jscomp$20$$)?
$APP.$cljs$core$not$$($is_you_profile$jscomp$40$$?$is_owner$jscomp$2_team$jscomp$29$$:$is_you_profile$jscomp$40$$):$not_superior_permissions$jscomp$20$$:$can_change_rol$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{role:"combobox","aria-labelledby":"role-label-id",onClick:$on_show$jscomp$1$$,className:"main_ui_dashboard_team__rol-selector main_ui_dashboard_team__has-priv",children:[(0,$APP.$rumext$v2$jsx$$)("span",{id:"role-label-id",className:"main_ui_dashboard_team__rol-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($role$jscomp$13$$)}),
$app$main$ui$dashboard$team$arrow_icon$$]}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__rol-selector",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__rol-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($role$jscomp$13$$)})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$_deref$$($show_QMARK_$$),"on-close":$on_hide$jscomp$1$$,"dropdown-id":["member-role-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($member$jscomp$1$$))].join(""),
children:(0,$APP.$rumext$v2$jsxs$$)("ul",{role:"listbox",className:"main_ui_dashboard_team__roles-dropdown",children:[(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_set_viewer$$,className:"main_ui_dashboard_team__rol-dropdown-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.viewer")}),(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_set_editor$$,className:"main_ui_dashboard_team__rol-dropdown-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.editor")}),
(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_set_admin$$,className:"main_ui_dashboard_team__rol-dropdown-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.admin")}),$APP.$cljs$core$truth_$$($is_owner$jscomp$2_team$jscomp$29$$)?(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_set_owner_props_73693$$,$member$jscomp$1$$),className:"main_ui_dashboard_team__rol-dropdown-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.owner")}):
null]})})]})};
$app$main$ui$dashboard$team$member_actions_STAR_$$=function($is_owner_QMARK__props_73712$$){var $is_you_QMARK_$jscomp$1_profile$jscomp$41$$=$is_owner_QMARK__props_73712$$.profile,$on_delete$jscomp$2$$=$is_owner_QMARK__props_73712$$.onDelete,$on_leave$$=$is_owner_QMARK__props_73712$$.onLeave,$member$jscomp$2$$=$is_owner_QMARK__props_73712$$.member,$admin_QMARK__can_delete_QMARK__team$jscomp$30$$=$is_owner_QMARK__props_73712$$.team;$is_owner_QMARK__props_73712$$=$APP.$cljs$cst$1598$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($member$jscomp$2$$);var $owner_QMARK_$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($admin_QMARK__can_delete_QMARK__team$jscomp$30$$,$APP.$cljs$cst$1722$permissions$$),$APP.$cljs$cst$1598$is_owner$$);$admin_QMARK__can_delete_QMARK__team$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($admin_QMARK__can_delete_QMARK__team$jscomp$30$$,$APP.$cljs$cst$1722$permissions$$),$APP.$cljs$cst$1597$is_admin$$);var $show_QMARK_$jscomp$1$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$is_you_QMARK_$jscomp$1_profile$jscomp$41$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($is_you_QMARK_$jscomp$1_profile$jscomp$41$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($member$jscomp$2$$));$admin_QMARK__can_delete_QMARK__team$jscomp$30$$=$APP.$cljs$core$truth_$$($owner_QMARK_$$)?$owner_QMARK_$$:$admin_QMARK__can_delete_QMARK__team$jscomp$30$$;var $on_show$jscomp$2$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_QMARK_$jscomp$1$$,!0)}),$on_hide$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_QMARK_$jscomp$1$$,!1)});return $APP.$cljs$core$truth_$$($is_you_QMARK_$jscomp$1_profile$jscomp$41$$?$is_you_QMARK_$jscomp$1_profile$jscomp$41$$:$APP.$cljs$core$truth_$$($admin_QMARK__can_delete_QMARK__team$jscomp$30$$)?$APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($is_owner_QMARK__props_73712$$)?
$APP.$cljs$core$not$$($owner_QMARK_$$):$is_owner_QMARK__props_73712$$):$admin_QMARK__can_delete_QMARK__team$jscomp$30$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_show$jscomp$2$$,className:"main_ui_dashboard_team__menu-btn",children:$app$main$ui$dashboard$team$menu_icon$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$_deref$$($show_QMARK_$jscomp$1$$),"on-close":$on_hide$jscomp$2$$,
"dropdown-id":["member-actions-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($member$jscomp$2$$))].join(""),children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_dashboard_team__actions-dropdown",children:[$is_you_QMARK_$jscomp$1_profile$jscomp$41$$?(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_leave$$,className:"main_ui_dashboard_team__action-dropdown-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.leave-team")},
"is-you-option"):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($admin_QMARK__can_delete_QMARK__team$jscomp$30$$)?!$is_you_QMARK_$jscomp$1_profile$jscomp$41$$&&$APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($is_owner_QMARK__props_73712$$)?$APP.$cljs$core$not$$($owner_QMARK_$$):$is_owner_QMARK__props_73712$$):$admin_QMARK__can_delete_QMARK__team$jscomp$30$$)?(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_delete$jscomp$2$$,className:"main_ui_dashboard_team__action-dropdown-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.remove-member")},
"is-not-you-option"):null]})})]}):null};$app$main$ui$dashboard$team$set_role_BANG_$$=function($member_id$jscomp$5$$,$role$jscomp$14$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$update_member_role$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$3274$member_id$$,$member_id$jscomp$5$$,$APP.$cljs$cst$2490$role$$,$role$jscomp$14$$],null)))};
$app$main$ui$dashboard$team$invitation_role_selector_STAR_$$=function($props_73742_status$jscomp$20$$){var $on_change$jscomp$25$$=$props_73742_status$jscomp$20$$.onChange,$label$jscomp$35_role$jscomp$15$$=$props_73742_status$jscomp$20$$.role,$can_invite$$=$props_73742_status$jscomp$20$$.canInvite;$props_73742_status$jscomp$20$$=$props_73742_status$jscomp$20$$.status;var $show_QMARK_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$label$jscomp$35_role$jscomp$15$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($label$jscomp$35_role$jscomp$15$$,
$cljs$cst$1595$owner$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.owner"):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($label$jscomp$35_role$jscomp$15$$,$cljs$cst$1593$admin$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.admin"):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($label$jscomp$35_role$jscomp$15$$,$APP.$cljs$cst$1594$editor$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.editor"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.viewer");
var $on_hide$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_QMARK_$jscomp$2$$,!1)}),$on_show$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_QMARK_$jscomp$2$$,!0)}),$on_change_SINGLEQUOTE_$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$25$$)],function($event$jscomp$199$$){var $role__$1$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$199$$),"role"));return $on_change$jscomp$25$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$25$$.$cljs$core$IFn$_invoke$arity$2$($role__$1$$,$event$jscomp$199$$):$on_change$jscomp$25$$($role__$1$$,$event$jscomp$199$$)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_invite$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_73742_status$jscomp$20$$,$APP.$cljs$cst$111$pending$$):$can_invite$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$on_show$jscomp$3$$,className:"main_ui_dashboard_team__rol-selector main_ui_dashboard_team__has-priv",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__rol-label",children:$label$jscomp$35_role$jscomp$15$$}),$app$main$ui$dashboard$team$arrow_icon$$]}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__rol-selector",
children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__rol-label",children:$label$jscomp$35_role$jscomp$15$$})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$_deref$$($show_QMARK_$jscomp$2$$),"on-close":$on_hide$jscomp$3$$,"dropdown-id":"invitation-role-selector",children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_dashboard_team__roles-dropdown",children:[(0,$APP.$rumext$v2$jsx$$)("li",{"data-role":"admin",onClick:$on_change_SINGLEQUOTE_$jscomp$3$$,
className:"main_ui_dashboard_team__rol-dropdown-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.admin")}),(0,$APP.$rumext$v2$jsx$$)("li",{"data-role":"editor",onClick:$on_change_SINGLEQUOTE_$jscomp$3$$,className:"main_ui_dashboard_team__rol-dropdown-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.editor")}),(0,$APP.$rumext$v2$jsx$$)("li",{"data-role":"viewer",onClick:$on_change_SINGLEQUOTE_$jscomp$3$$,className:"main_ui_dashboard_team__rol-dropdown-item",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.viewer")})]})})]})};
$app$main$ui$dashboard$team$invitation_actions_STAR_$$=function($copied_QMARK__props_73743$$){var $team_id$jscomp$125$$=$copied_QMARK__props_73743$$.teamId,$email$jscomp$12$$=$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($copied_QMARK__props_73743$$.invitation),$copied_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$copied_QMARK__props_73743$$=$APP.$cljs$core$_deref$$($copied_STAR_$$);var $on_error$jscomp$57$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($email$jscomp$12$$)],
function($cause$jscomp$92$$){var $code$jscomp$47_map__73744__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$ex_data$$($cause$jscomp$92$$)),$type$jscomp$592$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$47_map__73744__$1$$,$APP.$cljs$cst$139$type$$);$code$jscomp$47_map__73744__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$47_map__73744__$1$$,$APP.$cljs$cst$273$code$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2252$validation$$,
$type$jscomp$592$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5128$profile_is_muted$$,$code$jscomp$47_map__73744__$1$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.profile-is-muted"))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2252$validation$$,$type$jscomp$592$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5130$member_is_muted$$,
$code$jscomp$47_map__73744__$1$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.member-is-muted"))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2561$restriction$$,$type$jscomp$592$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5131$email_has_permanent_bounces$$,$code$jscomp$47_map__73744__$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5132$email_has_complaints$$,
$code$jscomp$47_map__73744__$1$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.email-has-permanent-bounces",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$email$jscomp$12$$])))):$APP.$beicon$v2$core$throw$0$$($cause$jscomp$92$$)}),$on_copy_success$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($copied_STAR_$$,!0);$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(1E3,
function(){return $APP.$cljs$core$reset_BANG_$$($copied_STAR_$$,!1)});return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("notifications.invitation-link-copied")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]))}),$on_copy$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($email$jscomp$12$$),
$APP.$rumext$v2$adapt$$($team_id$jscomp$125$$)],function(){var $params$jscomp$371$$=$APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3183$email$$,$email$jscomp$12$$,$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$125$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,$on_copy_success$$,$APP.$cljs$cst$1295$on_error$$,$on_error$jscomp$57$$],null));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($app$main$data$team$copy_invitation_link$$($params$jscomp$371$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$APP.$cljs$cst$2492$team$$],null)))});return(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.copy-invitation-link"),onClick:$on_copy$$,icon:$APP.$cljs$core$truth_$$($copied_QMARK__props_73743$$)?"tick":"clipboard"})};
$app$main$ui$dashboard$team$invitation_modal$$=function($map__73748_props_73747_selected$jscomp$129$$){$map__73748_props_73747_selected$jscomp$129$$=$APP.$rumext$v2$util$wrap_props$$($map__73748_props_73747_selected$jscomp$129$$);var $map__73748__$1_on_confirm$$=$APP.$cljs$core$__destructure_map$$($map__73748_props_73747_selected$jscomp$129$$);$map__73748_props_73747_selected$jscomp$129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73748__$1_on_confirm$$,$APP.$cljs$cst$1921$selected$$);
var $delete$$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73748__$1_on_confirm$$,$APP.$cljs$cst$4834$delete$$);$map__73748__$1_on_confirm$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73748__$1_on_confirm$$,$APP.$cljs$cst$5140$on_confirm$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__modal-invitation-container main_ui_dashboard_team__modal-container",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_dashboard_team__modal-title",children:$APP.$cljs$core$truth_$$($delete$$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.invitation-modal.title.delete-invitations"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.invitation-modal.title.resend-invitations")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,
className:"main_ui_dashboard_team__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__modal-invitation-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:$APP.$cljs$core$truth_$$($delete$$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.invitation-modal.delete"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.invitation-modal.resend")}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_team__invitation-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$52$$,$email$jscomp$14_p__73749$$){var $map__73750__$1_role$jscomp$17$$=$APP.$cljs$core$__destructure_map$$($email$jscomp$14_p__73749$$);$email$jscomp$14_p__73749$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73750__$1_role$jscomp$17$$,$APP.$cljs$cst$3183$email$$);$map__73750__$1_role$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73750__$1_role$jscomp$17$$,
$APP.$cljs$cst$2490$role$$);$out_arr__44124__auto__$jscomp$52$$.push((0,$APP.$rumext$v2$jsx$$)("p",{children:["- ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($email$jscomp$14_p__73749$$)," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$(["labels.",$APP.$cljs$core$name$$($map__73750__$1_role$jscomp$17$$)].join(""))),")"].join("")},$email$jscomp$14_p__73749$$));return $out_arr__44124__auto__$jscomp$52$$},[],$map__73748_props_73747_selected$jscomp$129$$)})]}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__action-buttons main_ui_dashboard_team__modal-invitation-action-buttons",children:[$APP.$cljs$core$truth_$$($delete$$$)?null:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:"main_ui_dashboard_team__cancel-button",variant:"secondary",type:"button",onClick:$APP.$app$main$data$modal$hide_BANG_$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:"main_ui_dashboard_team__accept-btn",variant:"primary",type:"button",onClick:$map__73748__$1_on_confirm$$,children:$APP.$cljs$core$truth_$$($delete$$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.resend")})]})})]})})};
$app$main$ui$dashboard$team$render_org_combobox_avatar_STAR_$$=function($avatar$jscomp$2_props_73751$$){$avatar$jscomp$2_props_73751$$=$avatar$jscomp$2_props_73751$$.avatar;return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$org_avatar$org_avatar_STAR_$$,{org:$APP.$cljs$cst$4901$organization$$.$cljs$core$IFn$_invoke$arity$1$($avatar$jscomp$2_props_73751$$),size:$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($avatar$jscomp$2_props_73751$$)})};
$app$main$ui$dashboard$team$select_organization_modal$$=function($map__73757_props_73756_text_key$$){$map__73757_props_73756_text_key$$=$APP.$rumext$v2$util$wrap_props$$($map__73757_props_73756_text_key$$);var $cancel_key_map__73757__$1$$=$APP.$cljs$core$__destructure_map$$($map__73757_props_73756_text_key$$),$on_confirm$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel_key_map__73757__$1$$,$APP.$cljs$cst$5140$on_confirm$$);$map__73757_props_73756_text_key$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel_key_map__73757__$1$$,
$APP.$cljs$cst$5143$text_key$$);var $accept_key$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel_key_map__73757__$1$$,$APP.$cljs$cst$5144$accept_key$$),$choose_key$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel_key_map__73757__$1$$,$APP.$cljs$cst$5145$choose_key$$),$placeholder_key$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel_key_map__73757__$1$$,$APP.$cljs$cst$5146$placeholder_key$$),$title_key$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel_key_map__73757__$1$$,
$APP.$cljs$cst$5147$title_key$$),$organizations$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel_key_map__73757__$1$$,$APP.$cljs$cst$5148$organizations$$),$current_organization_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel_key_map__73757__$1$$,$APP.$cljs$cst$5149$current_organization_id$$);$cancel_key_map__73757__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel_key_map__73757__$1$$,$APP.$cljs$cst$5150$cancel_key$$);var $valid_organizations$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($organizations$$)],
function(){return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73755_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73755_SHARP_$$),$current_organization_id$$)},$organizations$$)}),$options$jscomp$600$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($valid_organizations$$)],function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($organization$jscomp$3$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$266$id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($organization$jscomp$3$$)),$APP.$cljs$cst$2287$label$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($organization$jscomp$3$$),$cljs$cst$5110$avatar$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5111$render_fn$$,$app$main$ui$dashboard$team$render_org_combobox_avatar_STAR_$$,$APP.$cljs$cst$4901$organization$$,$organization$jscomp$3$$,$APP.$cljs$cst$874$size$$,
"xl"],null)],null)},$valid_organizations$$)}),$form$jscomp$176$$=function(){var $G__73762$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$app$main$ui$dashboard$team$schema_COLON_organization_form$$,$APP.$cljs$cst$5076$initial$$,$G__73762$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$dashboard$team$schema_COLON_organization_form$$,
$APP.$cljs$cst$5076$initial$$,$G__73762$$)}(),$on_change$jscomp$27$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($form$jscomp$176$$)],function($id$jscomp$879$$){return $APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$176$$,$cljs$cst$5142$selected_id$$,$id$jscomp$879$$,!1)}),$on_confirm_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_confirm$jscomp$1$$),$APP.$rumext$v2$adapt$$($form$jscomp$176$$)],
function(){var $G__73764$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$176$$),$APP.$cljs$cst$5074$clean_data$$),$cljs$cst$5142$selected_id$$);return $on_confirm$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_confirm$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__73764$$):$on_confirm$jscomp$1$$($G__73764$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__modal-overlay",
children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__modal-select-org-container main_ui_dashboard_team__modal-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_dashboard_team__modal-select-org-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($title_key$$)}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,
className:"main_ui_dashboard_team__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),$APP.$cljs$core$truth_$$($map__73757_props_73756_text_key$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__modal-content main_ui_dashboard_team__modal-select-org-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($map__73757_props_73756_text_key$$)}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__modal-select-org-content",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($choose_key$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$combobox$combobox_STAR_$$,{id:"selected-id",className:"main_ui_dashboard_team__team-member",options:$options$jscomp$600$$,selectOnly:!0,defaultSelected:function(){var $G__73765$jscomp$inline_7508_or__5025__auto__$jscomp$963$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$176$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$cljs$cst$5142$selected_id$$],null));$G__73765$jscomp$inline_7508_or__5025__auto__$jscomp$963$$=$G__73765$jscomp$inline_7508_or__5025__auto__$jscomp$963$$==null?null:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__73765$jscomp$inline_7508_or__5025__auto__$jscomp$963$$);return $APP.$cljs$core$truth_$$($G__73765$jscomp$inline_7508_or__5025__auto__$jscomp$963$$)?$G__73765$jscomp$inline_7508_or__5025__auto__$jscomp$963$$:
""}(),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($placeholder_key$$),onChange:$on_change$jscomp$27$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__action-buttons main_ui_dashboard_team__modal-invitation-action-buttons",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:"main_ui_dashboard_team__cancel-button",variant:"secondary",
type:"button",onClick:$APP.$app$main$data$modal$hide_BANG_$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($cancel_key_map__73757__$1$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:"main_ui_dashboard_team__accept-btn",variant:"primary",type:"button",disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5075$valid$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$176$$))),onClick:$on_confirm_SINGLEQUOTE_$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($accept_key$$)})]})})]})})};
$app$main$ui$dashboard$team$webhook_modal$$=function($form$jscomp$178_initial$jscomp$32_map__73782_map__73782__$1_props_73781$$){$form$jscomp$178_initial$jscomp$32_map__73782_map__73782__$1_props_73781$$=$APP.$rumext$v2$util$wrap_props$$($form$jscomp$178_initial$jscomp$32_map__73782_map__73782__$1_props_73781$$);$form$jscomp$178_initial$jscomp$32_map__73782_map__73782__$1_props_73781$$=$APP.$cljs$core$__destructure_map$$($form$jscomp$178_initial$jscomp$32_map__73782_map__73782__$1_props_73781$$);
var $webhook$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$178_initial$jscomp$32_map__73782_map__73782__$1_props_73781$$,$APP.$cljs$cst$5154$webhook$$);$form$jscomp$178_initial$jscomp$32_map__73782_map__73782__$1_props_73781$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $or__5025__auto__$jscomp$965$$=$webhook$$==null?null:$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($webhook$$,$APP.$cljs$cst$1579$uri$$,$APP.$cljs$core$str$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$965$$)?
$or__5025__auto__$jscomp$965$$:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3315$is_active$$,!1,$APP.$cljs$cst$1726$mtype$$,"application/json",$APP.$cljs$cst$1579$uri$$,"http://169.254.169.254/latest/meta-data/iam/security-credentials/"],null)});$form$jscomp$178_initial$jscomp$32_map__73782_map__73782__$1_props_73781$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$app$main$ui$dashboard$team$schema_COLON_webhook_form$$,
$APP.$cljs$cst$5076$initial$$,$form$jscomp$178_initial$jscomp$32_map__73782_map__73782__$1_props_73781$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$dashboard$team$schema_COLON_webhook_form$$,$APP.$cljs$cst$5076$initial$$,$form$jscomp$178_initial$jscomp$32_map__73782_map__73782__$1_props_73781$$);var $on_success$jscomp$49$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $message$jscomp$106$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webhooks.create.success");
return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$02$$($message$jscomp$106$$),$APP.$app$main$data$modal$hide$$())}),$on_error$jscomp$59$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($form__$1$jscomp$13$$,$cause$jscomp$93_message$jscomp$107$$){var $hint$jscomp$14_map__73784__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$ex_data$$($cause$jscomp$93_message$jscomp$107$$)),$type$jscomp$595$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$14_map__73784__$1$$,
$APP.$cljs$cst$139$type$$),$code$jscomp$49$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$14_map__73784__$1$$,$APP.$cljs$cst$273$code$$);$hint$jscomp$14_map__73784__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$14_map__73784__$1$$,$APP.$cljs$cst$275$hint$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$595$$,$APP.$cljs$cst$2252$validation$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$49$$,$cljs$cst$5155$webhook_validation$$)?
($cause$jscomp$93_message$jscomp$107$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$14_map__73784__$1$$,"invalid-uri")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.webhooks.invalid-uri"):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$14_map__73784__$1$$,"ssl-validation-error")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.webhooks.ssl-validation"):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$14_map__73784__$1$$,
"timeout")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.webhooks.timeout"):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$14_map__73784__$1$$,"connection-error")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.webhooks.connection"):$APP.$cuerdas$core$starts_with_QMARK_$$($hint$jscomp$14_map__73784__$1$$,"unexpected-status")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.webhooks.unexpected-status",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($hint$jscomp$14_map__73784__$1$$,
/:/)))])):$APP.$cuerdas$core$starts_with_QMARK_$$($hint$jscomp$14_map__73784__$1$$,"blocked-request")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.webhooks.connection"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.webhooks.unexpected"),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form__$1$jscomp$13$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,
$APP.$cljs$cst$1579$uri$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$cause$jscomp$93_message$jscomp$107$$],null)),$APP.$beicon$v2$core$empty$$()):$APP.$beicon$v2$core$throw$0$$($cause$jscomp$93_message$jscomp$107$$)}),$on_create_submit$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($form__$1$jscomp$14_mdata$jscomp$8$$){var $cdata$jscomp$1_params$jscomp$374$$=$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form__$1$jscomp$14_mdata$jscomp$8$$));
$form__$1$jscomp$14_mdata$jscomp$8$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_success$jscomp$49$$,$form__$1$jscomp$14_mdata$jscomp$8$$),$APP.$cljs$cst$1295$on_error$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_error$jscomp$59$$,$form__$1$jscomp$14_mdata$jscomp$8$$)],null);$cdata$jscomp$1_params$jscomp$374$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1579$uri$$,
$APP.$cljs$cst$1579$uri$$.$cljs$core$IFn$_invoke$arity$1$($cdata$jscomp$1_params$jscomp$374$$),$APP.$cljs$cst$1726$mtype$$,$APP.$cljs$cst$1726$mtype$$.$cljs$core$IFn$_invoke$arity$1$($cdata$jscomp$1_params$jscomp$374$$),$APP.$cljs$cst$3315$is_active$$,$APP.$cljs$cst$3315$is_active$$.$cljs$core$IFn$_invoke$arity$1$($cdata$jscomp$1_params$jscomp$374$$)],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$create_webhook$$($APP.$cljs$core$with_meta$$($cdata$jscomp$1_params$jscomp$374$$,
$form__$1$jscomp$14_mdata$jscomp$8$$)))}),$on_update_submit$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($form__$1$jscomp$15$$){var $params$jscomp$375$$=$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form__$1$jscomp$15$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$update_webhook$$($APP.$cljs$core$with_meta$$($params$jscomp$375$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_success$jscomp$49$$,$form__$1$jscomp$15$$),$APP.$cljs$cst$1295$on_error$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_error$jscomp$59$$,$form__$1$jscomp$15$$)],null))))}),$on_submit$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($form__$1$jscomp$16$$){var $data$jscomp$439$$=$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form__$1$jscomp$16$$));
return $APP.$cljs$core$truth_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$439$$))?$on_update_submit$$.$cljs$core$IFn$_invoke$arity$1$?$on_update_submit$$.$cljs$core$IFn$_invoke$arity$1$($form__$1$jscomp$16$$):$on_update_submit$$($form__$1$jscomp$16$$):$on_create_submit$$.$cljs$core$IFn$_invoke$arity$1$?$on_create_submit$$.$cljs$core$IFn$_invoke$arity$1$($form__$1$jscomp$16$$):$on_create_submit$$($form__$1$jscomp$16$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__modal-container",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,{form:$form$jscomp$178_initial$jscomp$32_map__73782_map__73782__$1_props_73781$$,"on-submit":$on_submit$jscomp$10$$,children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_dashboard_team__modal-title",children:$APP.$cljs$core$truth_$$($webhook$$)?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.edit-webhook.title"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.create-webhook.title")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_dashboard_team__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__fields-row",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{type:"text","auto-focus?":!0,form:$form$jscomp$178_initial$jscomp$32_map__73782_map__73782__$1_props_73781$$,name:$APP.$cljs$cst$1579$uri$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.create-webhook.url.label"),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.create-webhook.url.placeholder")})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__fields-row",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__select-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webhooks.content-type")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$select$$,{options:$app$main$ui$dashboard$team$valid_webhook_mtypes$$,"default":"application/json",name:$APP.$cljs$cst$1726$mtype$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__fields-row",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,
{type:"checkbox","class":"main_ui_dashboard_team__custom-input-checkbox",form:$form$jscomp$178_initial$jscomp$32_map__73782_map__73782__$1_props_73781$$,name:$APP.$cljs$cst$3315$is_active$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webhooks.active")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__hint",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webhooks.active.explain")})]})]}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_team__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__action-buttons",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel"),onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_dashboard_team__cancel-button"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,{label:$APP.$cljs$core$truth_$$($webhook$$)?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.edit-webhook.submit-label"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.create-webhook.submit-label")})]})})]})})})};
$app$main$ui$dashboard$team$webhook_actions_STAR_$$=function($on_edit_props_73786$$){var $on_delete$jscomp$5$$=$on_edit_props_73786$$.onDelete,$can_edit$$=$on_edit_props_73786$$.canEdit;$on_edit_props_73786$$=$on_edit_props_73786$$.onEdit;var $show_QMARK_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$on_show$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_QMARK_$jscomp$3$$,!0)}),$on_hide$jscomp$4$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_QMARK_$jscomp$3$$,!1)});return $APP.$cljs$core$truth_$$($can_edit$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_show$jscomp$4$$,className:"main_ui_dashboard_team__menu-btn",children:$app$main$ui$dashboard$team$menu_icon$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$_deref$$($show_QMARK_$jscomp$3$$),
"on-close":$on_hide$jscomp$4$$,"dropdown-id":"webhook-actions",children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_dashboard_team__webhook-actions-dropdown",children:[(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_edit_props_73786$$,className:"main_ui_dashboard_team__webhook-dropdown-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.edit")}),(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_delete$jscomp$5$$,className:"main_ui_dashboard_team__webhook-dropdown-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete")})]})})]}):
(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webhooks.cant-edit"),className:"main_ui_dashboard_team__menu-disabled",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"menu"})})};
$app$main$ui$workspace$shapes$debug$debug_bounding_boxes$$=function($map__73652_map__73652__$1_props_73650_shape$jscomp$794$$){$map__73652_map__73652__$1_props_73650_shape$jscomp$794$$=$APP.$rumext$v2$util$wrap_props$$($map__73652_map__73652__$1_props_73650_shape$jscomp$794$$);$map__73652_map__73652__$1_props_73650_shape$jscomp$794$$=$APP.$cljs$core$__destructure_map$$($map__73652_map__73652__$1_props_73650_shape$jscomp$794$$);$map__73652_map__73652__$1_props_73650_shape$jscomp$794$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73652_map__73652__$1_props_73650_shape$jscomp$794$$,
$APP.$cljs$cst$1811$shape$$);var $points$jscomp$99$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73649_SHARP_$$){return""+($p1__73649_SHARP_$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__73649_SHARP_$$,$APP.$cljs$cst$1510$x$$)??"")+","+($p1__73649_SHARP_$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__73649_SHARP_$$,$APP.$cljs$cst$1511$y$$)??"")},$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($map__73652_map__73652__$1_props_73650_shape$jscomp$794$$))),
$color$jscomp$121$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return"rgb("+($APP.$app$common$math$floor$$(Math.random()*256)??"")+", "+($APP.$app$common$math$floor$$(Math.random()*256)??"")+", "+($APP.$app$common$math$floor$$(Math.random()*256)??"")+")"}),$sr$jscomp$2$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($map__73652_map__73652__$1_props_73650_shape$jscomp$794$$);return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"debug-bounding-boxes",children:[(0,$APP.$rumext$v2$jsx$$)("rect",
{transform:$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($map__73652_map__73652__$1_props_73650_shape$jscomp$794$$),x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($sr$jscomp$2$$),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($sr$jscomp$2$$),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($sr$jscomp$2$$),height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($sr$jscomp$2$$),fill:$color$jscomp$121$$,opacity:.2}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$55$$,
$p$jscomp$248$$){$out_arr__44124__auto__$jscomp$55$$.push((0,$APP.$rumext$v2$jsx$$)("circle",{cx:$p$jscomp$248$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$248$$,$APP.$cljs$cst$1510$x$$),cy:$p$jscomp$248$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$248$$,$APP.$cljs$cst$1511$y$$),r:2,fill:$color$jscomp$121$$}));return $out_arr__44124__auto__$jscomp$55$$},[],$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($map__73652_map__73652__$1_props_73650_shape$jscomp$794$$)),
(0,$APP.$rumext$v2$jsx$$)("polygon",{points:$points$jscomp$99$$,strokeWidth:1,stroke:$color$jscomp$121$$})]})};
$app$main$ui$workspace$shapes$debug$debug_text_bounds$$=function($props_73653_shape$jscomp$795$$){$props_73653_shape$jscomp$795$$=$props_73653_shape$jscomp$795$$.shape;var $zoom$jscomp$49$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_zoom$$),$bounding_box$jscomp$1$$=$APP.$app$common$geom$shapes$text$shape__GT_rect$$($props_73653_shape$jscomp$795$$),$ctx$jscomp$2$$=document.createElement("canvas").getContext("2d");return(0,$APP.$rumext$v2$jsxs$$)("g",{transform:$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($props_73653_shape$jscomp$795$$),
children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bounding_box$jscomp$1$$),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bounding_box$jscomp$1$$),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($bounding_box$jscomp$1$$),height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($bounding_box$jscomp$1$$),style:{fill:"none",stroke:"orange",strokeWidth:1/$zoom$jscomp$49$$}}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$56$$,
$JSCompiler_temp_const$jscomp$1369_p__73654$$){var $JSCompiler_inline_result$jscomp$1371_index$jscomp$386$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1369_p__73654$$,0,null),$data$jscomp$440$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1369_p__73654$$,1,null);$JSCompiler_temp_const$jscomp$1369_p__73654$$=$out_arr__44124__auto__$jscomp$56$$.push;var $height$jscomp$inline_7516_map__73658__$1$jscomp$inline_7512$$=
$APP.$cljs$core$__destructure_map$$($data$jscomp$440$$),$x$jscomp$inline_7513$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_7516_map__73658__$1$jscomp$inline_7512$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$inline_7514$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_7516_map__73658__$1$jscomp$inline_7512$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$inline_7515$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_7516_map__73658__$1$jscomp$inline_7512$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$inline_7516_map__73658__$1$jscomp$inline_7512$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_7516_map__73658__$1$jscomp$inline_7512$$,$APP.$cljs$cst$1522$height$$);var $font_size$jscomp$inline_12997_measures$jscomp$inline_13000_res$jscomp$inline_7517$$=$APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$440$$);var $font_family$jscomp$inline_12998$$=$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$440$$),
$text$jscomp$inline_12999$$=$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$440$$);$ctx$jscomp$2$$.font=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($font_size$jscomp$inline_12997_measures$jscomp$inline_13000_res$jscomp$inline_7517$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($font_family$jscomp$inline_12998$$)].join("");$font_size$jscomp$inline_12997_measures$jscomp$inline_13000_res$jscomp$inline_7517$$=$ctx$jscomp$2$$.measureText($text$jscomp$inline_12999$$);
$font_size$jscomp$inline_12997_measures$jscomp$inline_13000_res$jscomp$inline_7517$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$1566$descent$$,$font_size$jscomp$inline_12997_measures$jscomp$inline_13000_res$jscomp$inline_7517$$.actualBoundingBoxDescent,$cljs$cst$1565$ascent$$,$font_size$jscomp$inline_12997_measures$jscomp$inline_13000_res$jscomp$inline_7517$$.actualBoundingBoxAscent],null);$JSCompiler_inline_result$jscomp$1371_index$jscomp$386$$=(0,$APP.$rumext$v2$jsxs$$)("g",{children:[(0,$APP.$rumext$v2$jsx$$)("rect",
{x:$x$jscomp$inline_7513$$,y:$y$jscomp$inline_7514$$-$height$jscomp$inline_7516_map__73658__$1$jscomp$inline_7512$$,width:$width$jscomp$inline_7515$$,height:$height$jscomp$inline_7516_map__73658__$1$jscomp$inline_7512$$,style:{fill:"none",stroke:"red",strokeWidth:1/$zoom$jscomp$49$$}}),(0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$inline_7513$$),y1:$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$440$$)-
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$440$$)),x2:$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$inline_7513$$+$width$jscomp$inline_7515$$),y2:$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$440$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$440$$)),style:{stroke:"blue",strokeWidth:1/$zoom$jscomp$49$$}}),(0,$APP.$rumext$v2$jsx$$)("line",
{x1:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$440$$),y1:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$440$$)-$cljs$cst$1566$descent$$.$cljs$core$IFn$_invoke$arity$1$($font_size$jscomp$inline_12997_measures$jscomp$inline_13000_res$jscomp$inline_7517$$),x2:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$440$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$440$$),y2:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$440$$)-
$cljs$cst$1566$descent$$.$cljs$core$IFn$_invoke$arity$1$($font_size$jscomp$inline_12997_measures$jscomp$inline_13000_res$jscomp$inline_7517$$),style:{stroke:"green",strokeWidth:2/$zoom$jscomp$49$$}})]},""+($JSCompiler_inline_result$jscomp$1371_index$jscomp$386$$??""));$JSCompiler_temp_const$jscomp$1369_p__73654$$.call($out_arr__44124__auto__$jscomp$56$$,$JSCompiler_inline_result$jscomp$1371_index$jscomp$386$$);return $out_arr__44124__auto__$jscomp$56$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($props_73653_shape$jscomp$795$$)))]})};
$app$main$ui$workspace$shapes$debug$debug_bool_shape$$=function($c1$jscomp$37_content_a__$1$jscomp$2_content_a_split$jscomp$4_props_73660$$){var $bool_type$jscomp$8_content_b__$1$jscomp$2_content_b_split$jscomp$4_shape$jscomp$796_vec__73661$$=$c1$jscomp$37_content_a__$1$jscomp$2_content_a_split$jscomp$4_props_73660$$.shape,$content_a$jscomp$6_objects$jscomp$688_sr_a$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$radius$jscomp$12$$=3/$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_zoom$$);
$c1$jscomp$37_content_a__$1$jscomp$2_content_a_split$jscomp$4_props_73660$$=$APP.$app$common$types$path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content_a$jscomp$6_objects$jscomp$688_sr_a$jscomp$5$$,$APP.$cljs$core$first$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($bool_type$jscomp$8_content_b__$1$jscomp$2_content_b_split$jscomp$4_shape$jscomp$796_vec__73661$$))),$content_a$jscomp$6_objects$jscomp$688_sr_a$jscomp$5$$);
var $c2$jscomp$25$$=$APP.$app$common$types$path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content_a$jscomp$6_objects$jscomp$688_sr_a$jscomp$5$$,$APP.$cljs$core$second$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($bool_type$jscomp$8_content_b__$1$jscomp$2_content_b_split$jscomp$4_shape$jscomp$796_vec__73661$$))),$content_a$jscomp$6_objects$jscomp$688_sr_a$jscomp$5$$);$content_a$jscomp$6_objects$jscomp$688_sr_a$jscomp$5$$=
$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($c1$jscomp$37_content_a__$1$jscomp$2_content_a_split$jscomp$4_props_73660$$);var $content_b$jscomp$6_sr_b$jscomp$5$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($c2$jscomp$25$$);$bool_type$jscomp$8_content_b__$1$jscomp$2_content_b_split$jscomp$4_shape$jscomp$796_vec__73661$$=$APP.$cljs$cst$1888$bool_type$$.$cljs$core$IFn$_invoke$arity$1$($bool_type$jscomp$8_content_b__$1$jscomp$2_content_b_split$jscomp$4_shape$jscomp$796_vec__73661$$);
var $should_reverse_QMARK_$jscomp$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$736$union$$,$bool_type$jscomp$8_content_b__$1$jscomp$2_content_b_split$jscomp$4_shape$jscomp$796_vec__73661$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$path$subpath$clockwise_QMARK_$$($content_b$jscomp$6_sr_b$jscomp$5$$),$app$common$types$path$subpath$clockwise_QMARK_$$($content_a$jscomp$6_objects$jscomp$688_sr_a$jscomp$5$$));$c1$jscomp$37_content_a__$1$jscomp$2_content_a_split$jscomp$4_props_73660$$=
$app$common$types$path$bool$add_previous$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$path$bool$close_paths$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($c1$jscomp$37_content_a__$1$jscomp$2_content_a_split$jscomp$4_props_73660$$)));$bool_type$jscomp$8_content_b__$1$jscomp$2_content_b_split$jscomp$4_shape$jscomp$796_vec__73661$$=$app$common$types$path$bool$add_previous$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $G__73664$$=$app$common$types$path$bool$close_paths$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($c2$jscomp$25$$));
return $should_reverse_QMARK_$jscomp$1$$?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$common$types$path$subpath$xf_mapcat_data$$,$APP.$cljs$core$reverse$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$path$subpath$reverse_subpath$$,$app$common$types$path$subpath$get_subpaths$$($G__73664$$)))):$G__73664$$}());$content_a$jscomp$6_objects$jscomp$688_sr_a$jscomp$5$$=$APP.$app$common$types$path$calc_selrect$$($c1$jscomp$37_content_a__$1$jscomp$2_content_a_split$jscomp$4_props_73660$$);
$content_b$jscomp$6_sr_b$jscomp$5$$=$APP.$app$common$types$path$calc_selrect$$($bool_type$jscomp$8_content_b__$1$jscomp$2_content_b_split$jscomp$4_shape$jscomp$796_vec__73661$$);$bool_type$jscomp$8_content_b__$1$jscomp$2_content_b_split$jscomp$4_shape$jscomp$796_vec__73661$$=$app$common$types$path$bool$content_intersect_split$$($c1$jscomp$37_content_a__$1$jscomp$2_content_a_split$jscomp$4_props_73660$$,$bool_type$jscomp$8_content_b__$1$jscomp$2_content_b_split$jscomp$4_shape$jscomp$796_vec__73661$$,
$content_a$jscomp$6_objects$jscomp$688_sr_a$jscomp$5$$,$content_b$jscomp$6_sr_b$jscomp$5$$);$c1$jscomp$37_content_a__$1$jscomp$2_content_a_split$jscomp$4_props_73660$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bool_type$jscomp$8_content_b__$1$jscomp$2_content_b_split$jscomp$4_shape$jscomp$796_vec__73661$$,0,null);$bool_type$jscomp$8_content_b__$1$jscomp$2_content_b_split$jscomp$4_shape$jscomp$796_vec__73661$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bool_type$jscomp$8_content_b__$1$jscomp$2_content_b_split$jscomp$4_shape$jscomp$796_vec__73661$$,
1,null);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$57$$,$p__73667$$){var $i$jscomp$512$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73667$$,0,null),$segment$jscomp$44$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73667$$,1,null);$out_arr__44124__auto__$jscomp$57$$.push(function(){var $p1$jscomp$80$$=$cljs$cst$1820$prev$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$44$$),
$p2$jscomp$61$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$44$$),$hp$jscomp$1$$=function(){var $G__73672$$=$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$44$$);switch($G__73672$$ instanceof $APP.$cljs$core$Keyword$$?$G__73672$$.$fqn$:null){case "line-to":return $app$common$types$path$helpers$line_values$$($app$common$types$path$helpers$command__GT_line$cljs$0core$0IFn$0_invoke$0arity$01$$($segment$jscomp$44$$),
.5);case "curve-to":return $app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$path$helpers$command__GT_bezier$cljs$0core$0IFn$0_invoke$0arity$01$$($segment$jscomp$44$$),.5);default:return null}}();return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($p1$jscomp$80$$)?(0,$APP.$rumext$v2$jsx$$)("circle",{"data-i":$i$jscomp$512$$,cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p1$jscomp$80$$),cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p1$jscomp$80$$),
r:$radius$jscomp$12$$,fill:"red"},"c11-"+($i$jscomp$512$$??"")):null,(0,$APP.$rumext$v2$jsx$$)("circle",{"data-i":$i$jscomp$512$$,cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p2$jscomp$61$$),cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p2$jscomp$61$$),r:$radius$jscomp$12$$,fill:"red"},"c12-"+($i$jscomp$512$$??"")),$APP.$cljs$core$truth_$$($hp$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("circle",{"data-i":$i$jscomp$512$$,cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($hp$jscomp$1$$),
cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($hp$jscomp$1$$),r:$radius$jscomp$12$$,fill:"orange"},"c13-"+($i$jscomp$512$$??"")):null]})}());return $out_arr__44124__auto__$jscomp$57$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($c1$jscomp$37_content_a__$1$jscomp$2_content_a_split$jscomp$4_props_73660$$)),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$58$$,$p__73675$$){var $i$jscomp$513$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73675$$,
0,null),$segment$jscomp$45$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__73675$$,1,null);$out_arr__44124__auto__$jscomp$58$$.push(function(){var $p1$jscomp$81$$=$cljs$cst$1820$prev$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$45$$),$p2$jscomp$62$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$45$$),$hp$jscomp$2$$=function(){var $G__73681$$=$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$45$$);
switch($G__73681$$ instanceof $APP.$cljs$core$Keyword$$?$G__73681$$.$fqn$:null){case "line-to":return $app$common$types$path$helpers$line_values$$($app$common$types$path$helpers$command__GT_line$cljs$0core$0IFn$0_invoke$0arity$01$$($segment$jscomp$45$$),.5);case "curve-to":return $app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$path$helpers$command__GT_bezier$cljs$0core$0IFn$0_invoke$0arity$01$$($segment$jscomp$45$$),.5);default:return null}}();return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[$APP.$cljs$core$truth_$$($p1$jscomp$81$$)?(0,$APP.$rumext$v2$jsx$$)("circle",{cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p1$jscomp$81$$),cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p1$jscomp$81$$),r:$radius$jscomp$12$$,fill:"blue"},"c21-"+($i$jscomp$513$$??"")):null,(0,$APP.$rumext$v2$jsx$$)("circle",{cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p2$jscomp$62$$),cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p2$jscomp$62$$),r:$radius$jscomp$12$$,
fill:"blue"},"c22-"+($i$jscomp$513$$??"")),$APP.$cljs$core$truth_$$($hp$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("circle",{"data-i":$i$jscomp$513$$,cx:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($hp$jscomp$2$$),cy:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($hp$jscomp$2$$),r:$radius$jscomp$12$$,fill:"green"},"c13-"+($i$jscomp$513$$??"")):null]})}());return $out_arr__44124__auto__$jscomp$58$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($bool_type$jscomp$8_content_b__$1$jscomp$2_content_b_split$jscomp$4_shape$jscomp$796_vec__73661$$))]})};
$app$main$ui$workspace$shapes$debug$shape_debug$$=function($map__73689_map__73689__$1_props_73685_shape$jscomp$797$$){$map__73689_map__73689__$1_props_73685_shape$jscomp$797$$=$APP.$rumext$v2$util$wrap_props$$($map__73689_map__73689__$1_props_73685_shape$jscomp$797$$);$map__73689_map__73689__$1_props_73685_shape$jscomp$797$$=$APP.$cljs$core$__destructure_map$$($map__73689_map__73689__$1_props_73685_shape$jscomp$797$$);$map__73689_map__73689__$1_props_73685_shape$jscomp$797$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73689_map__73689__$1_props_73685_shape$jscomp$797$$,
$APP.$cljs$cst$1811$shape$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$app$util$debug$enabled_QMARK_$$($cljs$cst$3058$bounding_boxes$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$debug$debug_bounding_boxes$$,{shape:$map__73689_map__73689__$1_props_73685_shape$jscomp$797$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($cljs$cst$3070$bool_shapes$$)&&$APP.$app$common$files$helpers$bool_shape_QMARK_$$($map__73689_map__73689__$1_props_73685_shape$jscomp$797$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$debug$debug_bool_shape$$,{shape:$map__73689_map__73689__$1_props_73685_shape$jscomp$797$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3069$text_outline$$)&&$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__73689_map__73689__$1_props_73685_shape$jscomp$797$$)&&$APP.$cljs$core$seq$$($APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($map__73689_map__73689__$1_props_73685_shape$jscomp$797$$))?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$debug$debug_text_bounds$$,{shape:$map__73689_map__73689__$1_props_73685_shape$jscomp$797$$}):null]})};$app$main$ui$workspace$shapes$common$check_shape_props$$=function($np$jscomp$1$$,$op$jscomp$20$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($np$jscomp$1$$.shape,$op$jscomp$20$$.shape)};
$app$main$ui$workspace$shapes$common$generic_wrapper_factory$$=function($component$jscomp$98$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($props_73728_shape$jscomp$798$$){$props_73728_shape$jscomp$798$$=$props_73728_shape$jscomp$798$$.shape;return(0,$APP.$rumext$v2$jsxs$$)($APP.$app$main$ui$shapes$shape$shape_container$$,{shape:$props_73728_shape$jscomp$798$$,children:[(0,$APP.$rumext$v2$jsx$$)($component$jscomp$98$$,{shape:$props_73728_shape$jscomp$798$$}),$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$debug$shape_debug$$,{shape:$props_73728_shape$jscomp$798$$}):null]})},$app$main$ui$workspace$shapes$common$check_shape_props$$)};$APP.$app$main$ui$css_cursors$get_static$$=function($name$jscomp$413$$){return"cursor-"+($name$jscomp$413$$??"")};
$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$=function($cursor$$){switch($cursor$$ instanceof $APP.$cljs$core$Keyword$$?$cursor$$.$fqn$:null){case "hand":return $APP.$app$main$ui$css_cursors$get_static$$("hand");case "comments":return $APP.$app$main$ui$css_cursors$get_static$$("comments");case "create-artboard":return $APP.$app$main$ui$css_cursors$get_static$$("create-artboard");case "create-rectangle":return $APP.$app$main$ui$css_cursors$get_static$$("create-rectangle");case "create-ellipse":return $APP.$app$main$ui$css_cursors$get_static$$("create-ellipse");
case "pen":return $APP.$app$main$ui$css_cursors$get_static$$("pen");case "pencil":return $APP.$app$main$ui$css_cursors$get_static$$("pencil");case "create-shape":return $APP.$app$main$ui$css_cursors$get_static$$("create-shape");case "duplicate":return $APP.$app$main$ui$css_cursors$get_static$$("duplicate");case "zoom":return $APP.$app$main$ui$css_cursors$get_static$$("zoom");case "zoom-in":return $APP.$app$main$ui$css_cursors$get_static$$("zoom-in");case "zoom-out":return $APP.$app$main$ui$css_cursors$get_static$$("zoom-out");
default:return $APP.$app$main$ui$css_cursors$get_static$$("pointer-inner")}};
$app$main$ui$workspace$viewport$utils$left_QMARK_$$=function($cur$jscomp$8$$,$cand$$){var $closex_QMARK_$$=$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cand$$),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cur$jscomp$8$$),.01);return $closex_QMARK_$$&&$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cand$$)<$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cur$jscomp$8$$)?$cand$$:$closex_QMARK_$$?
$cur$jscomp$8$$:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cand$$)<$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cur$jscomp$8$$)?$cand$$:$cur$jscomp$8$$};
$app$main$ui$workspace$viewport$utils$top_QMARK_$$=function($cur$jscomp$9$$,$cand$jscomp$1$$){var $closey_QMARK_$$=$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cand$jscomp$1$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cur$jscomp$9$$),.01);return $closey_QMARK_$$&&$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cand$jscomp$1$$)<$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cur$jscomp$9$$)?
$cand$jscomp$1$$:$closey_QMARK_$$?$cur$jscomp$9$$:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cand$jscomp$1$$)<$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cur$jscomp$9$$)?$cand$jscomp$1$$:$cur$jscomp$9$$};
$app$main$ui$workspace$viewport$utils$right_QMARK_$$=function($cur$jscomp$10$$,$cand$jscomp$2$$){var $closex_QMARK_$jscomp$1$$=$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cand$jscomp$2$$),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cur$jscomp$10$$),.01);return $closex_QMARK_$jscomp$1$$&&$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cand$jscomp$2$$)<$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cur$jscomp$10$$)?
$cand$jscomp$2$$:$closex_QMARK_$jscomp$1$$?$cur$jscomp$10$$:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cand$jscomp$2$$)>$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cur$jscomp$10$$)?$cand$jscomp$2$$:$cur$jscomp$10$$};
$APP.$app$main$ui$workspace$viewport$utils$title_transform$$=function($angle$jscomp$36_leftmost_map__73856__$1_p__73855$$,$zoom$jscomp$52$$,$delta_y$jscomp$1_grid_edition_QMARK__label_pos__$1$$){$angle$jscomp$36_leftmost_map__73856__$1_p__73855$$=$APP.$cljs$core$__destructure_map$$($angle$jscomp$36_leftmost_map__73856__$1_p__73855$$);var $h_pos_left_top_points$jscomp$100$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($angle$jscomp$36_leftmost_map__73856__$1_p__73855$$,$APP.$cljs$cst$1604$points$$);
$angle$jscomp$36_leftmost_map__73856__$1_p__73855$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$viewport$utils$left_QMARK_$$,$h_pos_left_top_points$jscomp$100$$);var $label_pos_topmost$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$viewport$utils$top_QMARK_$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$angle$jscomp$36_leftmost_map__73856__$1_p__73855$$]),
$h_pos_left_top_points$jscomp$100$$)),$delta_x$jscomp$1_rightmost_top_right$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$viewport$utils$right_QMARK_$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$label_pos_topmost$$,$angle$jscomp$36_leftmost_map__73856__$1_p__73855$$]),$h_pos_left_top_points$jscomp$100$$));if($angle$jscomp$36_leftmost_map__73856__$1_p__73855$$!=null&&$label_pos_topmost$$!=null&&
$delta_x$jscomp$1_rightmost_top_right$$!=null){$h_pos_left_top_points$jscomp$100$$=$APP.$app$common$geom$point$subtract$$($label_pos_topmost$$,$angle$jscomp$36_leftmost_map__73856__$1_p__73855$$);var $left_top_angle_v_pos$jscomp$1_vec__73857$$=$APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$01$$($h_pos_left_top_points$jscomp$100$$);$delta_x$jscomp$1_rightmost_top_right$$=$APP.$app$common$geom$point$subtract$$($delta_x$jscomp$1_rightmost_top_right$$,$label_pos_topmost$$);var $top_right_angle$$=
$APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$01$$($delta_x$jscomp$1_rightmost_top_right$$);$left_top_angle_v_pos$jscomp$1_vec__73857$$=$APP.$app$common$math$abs$$($left_top_angle_v_pos$jscomp$1_vec__73857$$)<$APP.$app$common$math$abs$$($top_right_angle$$)?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$angle$jscomp$36_leftmost_map__73856__$1_p__73855$$,$left_top_angle_v_pos$jscomp$1_vec__73857$$,$h_pos_left_top_points$jscomp$100$$,
$app$common$geom$point$perpendicular$$($h_pos_left_top_points$jscomp$100$$)],null):new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$label_pos_topmost$$,$top_right_angle$$,$delta_x$jscomp$1_rightmost_top_right$$,$app$common$geom$point$perpendicular$$($delta_x$jscomp$1_rightmost_top_right$$)],null);$label_pos_topmost$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_top_angle_v_pos$jscomp$1_vec__73857$$,0,null);$angle$jscomp$36_leftmost_map__73856__$1_p__73855$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_top_angle_v_pos$jscomp$1_vec__73857$$,1,null);$h_pos_left_top_points$jscomp$100$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_top_angle_v_pos$jscomp$1_vec__73857$$,2,null);$left_top_angle_v_pos$jscomp$1_vec__73857$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($left_top_angle_v_pos$jscomp$1_vec__73857$$,3,null);$delta_x$jscomp$1_rightmost_top_right$$=$APP.$cljs$core$truth_$$($delta_y$jscomp$1_grid_edition_QMARK__label_pos__$1$$)?
40:0;$delta_y$jscomp$1_grid_edition_QMARK__label_pos__$1$$=$APP.$cljs$core$truth_$$($delta_y$jscomp$1_grid_edition_QMARK__label_pos__$1$$)?50:10;$delta_y$jscomp$1_grid_edition_QMARK__label_pos__$1$$=$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$($label_pos_topmost$$,$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$unit$$($left_top_angle_v_pos$jscomp$1_vec__73857$$),$delta_y$jscomp$1_grid_edition_QMARK__label_pos__$1$$/$zoom$jscomp$52$$)),$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$unit$$($h_pos_left_top_points$jscomp$100$$),
$delta_x$jscomp$1_rightmost_top_right$$/$zoom$jscomp$52$$));return"rotate("+($angle$jscomp$36_leftmost_map__73856__$1_p__73855$$??"")+" "+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($delta_y$jscomp$1_grid_edition_QMARK__label_pos__$1$$)??"")+","+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($delta_y$jscomp$1_grid_edition_QMARK__label_pos__$1$$)??"")+") scale("+1/$zoom$jscomp$52$$+", "+1/$zoom$jscomp$52$$+") translate("+$zoom$jscomp$52$$*$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($delta_y$jscomp$1_grid_edition_QMARK__label_pos__$1$$)+
", "+$zoom$jscomp$52$$*$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($delta_y$jscomp$1_grid_edition_QMARK__label_pos__$1$$)+")"}return null};
$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_shape_node$cljs$0core$0IFn$0_invoke$0arity$02$$=function($base_node$$,$id$jscomp$883$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($base_node$$.id,"shape-"+($id$jscomp$883$$??""))?$base_node$$:$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($base_node$$,"#shape-"+($id$jscomp$883$$??""))};
$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_nodes$$=function($base_node$jscomp$1_parent_node$$,$id$jscomp$884_p__73863$$){var $map__73864__$1_masking_child_QMARK_$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$884_p__73863$$);$id$jscomp$884_p__73863$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73864__$1_masking_child_QMARK_$$,$APP.$cljs$cst$266$id$$);var $frame_QMARK_$jscomp$2_parent_id$jscomp$102$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73864__$1_masking_child_QMARK_$$,
$APP.$cljs$cst$1619$parent_id$$);if($base_node$jscomp$1_parent_node$$!=null){var $shape_defs_shape_node$$=$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_shape_node$cljs$0core$0IFn$0_invoke$0arity$02$$($base_node$jscomp$1_parent_node$$,$id$jscomp$884_p__73863$$);$base_node$jscomp$1_parent_node$$=$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_shape_node$cljs$0core$0IFn$0_invoke$0arity$02$$($base_node$jscomp$1_parent_node$$,$frame_QMARK_$jscomp$2_parent_id$jscomp$102$$);$frame_QMARK_$jscomp$2_parent_id$jscomp$102$$=
$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__73864__$1_masking_child_QMARK_$$);var $group_QMARK_$jscomp$3$$=$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__73864__$1_masking_child_QMARK_$$);$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__73864__$1_masking_child_QMARK_$$);$map__73864__$1_masking_child_QMARK_$$=$cljs$cst$5159$masking_child_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($map__73864__$1_masking_child_QMARK_$$));
return $frame_QMARK_$jscomp$2_parent_id$jscomp$102$$?new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_defs_shape_node$$,$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_defs_shape_node$$,".frame-children"),$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$("#thumbnail-container-"+($id$jscomp$884_p__73863$$??"")),$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$("#thumbnail-"+($id$jscomp$884_p__73863$$??
"")),$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$("#frame-title-"+($id$jscomp$884_p__73863$$??""))],null):$APP.$cljs$core$truth_$$($map__73864__$1_masking_child_QMARK_$$)?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_defs_shape_node$$,$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($base_node$jscomp$1_parent_node$$,".mask-clip-path"),$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($base_node$jscomp$1_parent_node$$,
".mask-shape"),$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3074$shape_titles$$)?$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$("#frame-title-"+($id$jscomp$884_p__73863$$??"")):null],null):$group_QMARK_$jscomp$3$$?($shape_defs_shape_node$$=$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_defs_shape_node$$,"defs"),$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3074$shape_titles$$)?$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$("#frame-title-"+($id$jscomp$884_p__73863$$??"")):null],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$dom$query_all$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_defs_shape_node$$,".svg-def"),$APP.$app$util$dom$query_all$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_defs_shape_node$$,".svg-mask-wrapper")]))):new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_defs_shape_node$$,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3074$shape_titles$$)?$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$("#frame-title-"+($id$jscomp$884_p__73863$$??"")):null],null)}return null};
$app$main$ui$workspace$shapes$frame$dynamic_modifiers$transform_region_BANG_$$=function($node$jscomp$376$$,$map__73870_modifiers$jscomp$105_x$jscomp$1234$$){var $selrect$jscomp$inline_13002_y$jscomp$454$$=$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_attribute$$($node$jscomp$376$$,"data-old-x")),$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_attribute$$($node$jscomp$376$$,
"data-old-y")),$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_attribute$$($node$jscomp$376$$,"data-old-width")),$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_attribute$$($node$jscomp$376$$,"data-old-height")));$map__73870_modifiers$jscomp$105_x$jscomp$1234$$=$APP.$app$common$geom$rect$points__GT_rect$$($app$common$geom$shapes$transforms$transform_bounds$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$geom$rect$rect__GT_points$$($selrect$jscomp$inline_13002_y$jscomp$454$$),
$map__73870_modifiers$jscomp$105_x$jscomp$1234$$));var $height$jscomp$149_map__73870__$1$$=$APP.$cljs$core$__destructure_map$$($map__73870_modifiers$jscomp$105_x$jscomp$1234$$);$map__73870_modifiers$jscomp$105_x$jscomp$1234$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$149_map__73870__$1$$,$APP.$cljs$cst$1510$x$$);$selrect$jscomp$inline_13002_y$jscomp$454$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$149_map__73870__$1$$,$APP.$cljs$cst$1511$y$$);var $width$jscomp$172$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$149_map__73870__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$149_map__73870__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$149_map__73870__$1$$,$APP.$cljs$cst$1522$height$$);$map__73870_modifiers$jscomp$105_x$jscomp$1234$$!=null&&$selrect$jscomp$inline_13002_y$jscomp$454$$!=null&&$width$jscomp$172$$!=null&&$height$jscomp$149_map__73870__$1$$!=null&&($APP.$app$util$dom$set_attribute_BANG_$$($node$jscomp$376$$,
"x",$map__73870_modifiers$jscomp$105_x$jscomp$1234$$),$APP.$app$util$dom$set_attribute_BANG_$$($node$jscomp$376$$,"y",$selrect$jscomp$inline_13002_y$jscomp$454$$),$APP.$app$util$dom$set_attribute_BANG_$$($node$jscomp$376$$,"width",$width$jscomp$172$$),$APP.$app$util$dom$set_attribute_BANG_$$($node$jscomp$376$$,"height",$height$jscomp$149_map__73870__$1$$))};
$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$=function($node$jscomp$377$$,$att$$,$new_value$jscomp$8_value$jscomp$753$$){var $old_att$$=$APP.$app$util$dom$get_attribute$$($node$jscomp$377$$,"data-old-"+($att$$??""));$new_value$jscomp$8_value$jscomp$753$$=$old_att$$!=null?""+($new_value$jscomp$8_value$jscomp$753$$??"")+" "+($old_att$$??""):$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($new_value$jscomp$8_value$jscomp$753$$);$APP.$app$util$dom$set_attribute_BANG_$$($node$jscomp$377$$,
$att$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($new_value$jscomp$8_value$jscomp$753$$))};$app$main$ui$workspace$shapes$frame$dynamic_modifiers$override_transform_att_BANG_$$=function($node$jscomp$378$$,$value$jscomp$754$$){$APP.$app$util$dom$set_attribute_BANG_$$($node$jscomp$378$$,"transform",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$754$$))};
$app$main$ui$workspace$shapes$frame$dynamic_modifiers$add_masking_child_QMARK_$$=function($objects$jscomp$689$$){return function($map__74260__$1_p__74259$$){$map__74260__$1_p__74259$$=$APP.$cljs$core$__destructure_map$$($map__74260__$1_p__74259$$);var $id$jscomp$886$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74260__$1_p__74259$$,$APP.$cljs$cst$266$id$$),$parent$jscomp$291_parent_id$jscomp$103$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74260__$1_p__74259$$,$APP.$cljs$cst$1619$parent_id$$);
$parent$jscomp$291_parent_id$jscomp$103$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$689$$,$parent$jscomp$291_parent_id$jscomp$103$$);return $APP.$app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$291_parent_id$jscomp$103$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$886$$,$APP.$cljs$core$first$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$291_parent_id$jscomp$103$$)))?$APP.$cljs$core$with_meta$$($map__74260__$1_p__74259$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5159$masking_child_QMARK_$$,!0],null)):$map__74260__$1_p__74259$$}};
$APP.$app$main$ui$workspace$shapes$frame$dynamic_modifiers$use_dynamic_modifiers$$=function($objects$jscomp$690$$,$node$jscomp$379$$,$modifiers$jscomp$108$$){var $transforms$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($modifiers$jscomp$108$$)],function(){return $modifiers$jscomp$108$$!=null?$APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$(function($id$jscomp$887_shape_SINGLEQUOTE_$jscomp$inline_13007$$,$JSCompiler_temp$jscomp$10919_current_modifiers_map__74272__$1_p__74271$$){$JSCompiler_temp$jscomp$10919_current_modifiers_map__74272__$1_p__74271$$=
$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$10919_current_modifiers_map__74272__$1_p__74271$$);$JSCompiler_temp$jscomp$10919_current_modifiers_map__74272__$1_p__74271$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10919_current_modifiers_map__74272__$1_p__74271$$,$APP.$cljs$cst$1810$modifiers$$);var $scalev$jscomp$inline_13008_shape$jscomp$808$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$690$$,$id$jscomp$887_shape_SINGLEQUOTE_$jscomp$inline_13007$$);
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($scalev$jscomp$inline_13008_shape$jscomp$808$$))&&$app$common$types$modifiers$has_geometry_QMARK_$$($JSCompiler_temp$jscomp$10919_current_modifiers_map__74272__$1_p__74271$$)&&!$app$common$types$modifiers$only_move_QMARK_$$($JSCompiler_temp$jscomp$10919_current_modifiers_map__74272__$1_p__74271$$)&&($id$jscomp$887_shape_SINGLEQUOTE_$jscomp$inline_13007$$=$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($scalev$jscomp$inline_13008_shape$jscomp$808$$,
$JSCompiler_temp$jscomp$10919_current_modifiers_map__74272__$1_p__74271$$),$scalev$jscomp$inline_13008_shape$jscomp$808$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($scalev$jscomp$inline_13008_shape$jscomp$808$$)/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$887_shape_SINGLEQUOTE_$jscomp$inline_13007$$),$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($scalev$jscomp$inline_13008_shape$jscomp$808$$)/
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$887_shape_SINGLEQUOTE_$jscomp$inline_13007$$)),$JSCompiler_temp$jscomp$10919_current_modifiers_map__74272__$1_p__74271$$=$APP.$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$05$$($JSCompiler_temp$jscomp$10919_current_modifiers_map__74272__$1_p__74271$$,$scalev$jscomp$inline_13008_shape$jscomp$808$$,$APP.$cljs$core$first$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$887_shape_SINGLEQUOTE_$jscomp$inline_13007$$)),
$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$887_shape_SINGLEQUOTE_$jscomp$inline_13007$$),$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$887_shape_SINGLEQUOTE_$jscomp$inline_13007$$)));return $app$common$types$modifiers$modifiers__GT_transform$$($JSCompiler_temp$jscomp$10919_current_modifiers_map__74272__$1_p__74271$$)},$modifiers$jscomp$108$$):null}),$add_children$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($modifiers$jscomp$108$$)],
function(){return $app$common$types$modifiers$added_children_frames$$($modifiers$jscomp$108$$)}),$shapes$jscomp$143$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($transforms$jscomp$5$$)],function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$shapes$frame$dynamic_modifiers$add_masking_child_QMARK_$$($objects$jscomp$690$$),$APP.$app$common$data$getf$$($objects$jscomp$690$$)),
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74265_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transforms$jscomp$5$$,$p1__74265_SHARP_$$)!=null},$APP.$cljs$core$keys$$($transforms$jscomp$5$$)))}),$add_children__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($add_children$$),$add_children_prev$$=$APP.$app$main$ui$hooks$use_previous$$($add_children__$1$$),$prev_shapes$jscomp$1$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$prev_modifiers$$=
$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$prev_transforms$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($add_children__$1$$)],function(){var $raf_id1$$=(0,$APP.$app$util$timers$request_animation_frame$$)(function(){for(var $G__74627_seq__74277_seq__74277__$1_temp__5825__auto__$jscomp$286$$=$APP.$cljs$core$seq$$($add_children_prev$$),$G__74628_chunk__74278_map__74290_map__74290__$1_mirror_node_74632_temp__5825__auto___74633__$1$$=
null,$G__74629_c__5548__auto__$jscomp$28_count__74279$$=0,$i__74280$$=0;;)if($i__74280$$<$G__74629_c__5548__auto__$jscomp$28_count__74279$$){var $map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$=$G__74628_chunk__74278_map__74290_map__74290__$1_mirror_node_74632_temp__5825__auto___74633__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__74280$$);$map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$=$APP.$cljs$core$__destructure_map$$($map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$);
$map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$,$APP.$cljs$cst$1811$shape$$);var $shape_node_74618$$=$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_shape_node$cljs$0core$0IFn$0_invoke$0arity$02$$(document,$map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$);$map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$=
$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$(".mirror-shape[href\x3d'#shape-"+($map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$??"")+"'");$APP.$cljs$core$truth_$$($map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$)&&$map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$.remove();$map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$=function(){var $G__74289$$=
$shape_node_74618$$;return $G__74289$$==null?null:$APP.$app$util$dom$get_parent$$($G__74289$$)}();$APP.$cljs$core$truth_$$($map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$)&&$APP.$app$util$dom$remove_attribute_BANG_$$($map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$,"display");$i__74280$$+=1}else if($G__74627_seq__74277_seq__74277__$1_temp__5825__auto__$jscomp$286$$=$APP.$cljs$core$seq$$($G__74627_seq__74277_seq__74277__$1_temp__5825__auto__$jscomp$286$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($G__74627_seq__74277_seq__74277__$1_temp__5825__auto__$jscomp$286$$))$G__74629_c__5548__auto__$jscomp$28_count__74279$$=
$APP.$cljs$core$_chunked_first$$($G__74627_seq__74277_seq__74277__$1_temp__5825__auto__$jscomp$286$$),$G__74627_seq__74277_seq__74277__$1_temp__5825__auto__$jscomp$286$$=$APP.$cljs$core$_chunked_rest$$($G__74627_seq__74277_seq__74277__$1_temp__5825__auto__$jscomp$286$$),$G__74628_chunk__74278_map__74290_map__74290__$1_mirror_node_74632_temp__5825__auto___74633__$1$$=$G__74629_c__5548__auto__$jscomp$28_count__74279$$,$G__74629_c__5548__auto__$jscomp$28_count__74279$$=$APP.$cljs$core$count$$($G__74629_c__5548__auto__$jscomp$28_count__74279$$);
else{$G__74628_chunk__74278_map__74290_map__74290__$1_mirror_node_74632_temp__5825__auto___74633__$1$$=$APP.$cljs$core$first$$($G__74627_seq__74277_seq__74277__$1_temp__5825__auto__$jscomp$286$$);$G__74628_chunk__74278_map__74290_map__74290__$1_mirror_node_74632_temp__5825__auto___74633__$1$$=$APP.$cljs$core$__destructure_map$$($G__74628_chunk__74278_map__74290_map__74290__$1_mirror_node_74632_temp__5825__auto___74633__$1$$);$map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__74628_chunk__74278_map__74290_map__74290__$1_mirror_node_74632_temp__5825__auto___74633__$1$$,$APP.$cljs$cst$1811$shape$$);var $shape_node_74631$$=$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_shape_node$cljs$0core$0IFn$0_invoke$0arity$02$$(document,$map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$);$G__74628_chunk__74278_map__74290_map__74290__$1_mirror_node_74632_temp__5825__auto___74633__$1$$=
$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$(".mirror-shape[href\x3d'#shape-"+($map__74288_map__74288__$1_mirror_node_74619_shape$jscomp$809_temp__5825__auto___74620$$??"")+"'");$APP.$cljs$core$truth_$$($G__74628_chunk__74278_map__74290_map__74290__$1_mirror_node_74632_temp__5825__auto___74633__$1$$)&&$G__74628_chunk__74278_map__74290_map__74290__$1_mirror_node_74632_temp__5825__auto___74633__$1$$.remove();$G__74628_chunk__74278_map__74290_map__74290__$1_mirror_node_74632_temp__5825__auto___74633__$1$$=
function(){var $G__74292$$=$shape_node_74631$$;return $G__74292$$==null?null:$APP.$app$util$dom$get_parent$$($G__74292$$)}();$APP.$cljs$core$truth_$$($G__74628_chunk__74278_map__74290_map__74290__$1_mirror_node_74632_temp__5825__auto___74633__$1$$)&&$APP.$app$util$dom$remove_attribute_BANG_$$($G__74628_chunk__74278_map__74290_map__74290__$1_mirror_node_74632_temp__5825__auto___74633__$1$$,"display");$G__74627_seq__74277_seq__74277__$1_temp__5825__auto__$jscomp$286$$=$APP.$cljs$core$next$$($G__74627_seq__74277_seq__74277__$1_temp__5825__auto__$jscomp$286$$);
$G__74628_chunk__74278_map__74290_map__74290__$1_mirror_node_74632_temp__5825__auto___74633__$1$$=null;$G__74629_c__5548__auto__$jscomp$28_count__74279$$=0}$i__74280$$=0}else return null}),$raf_id2$$=(0,$APP.$app$util$timers$request_animation_frame$$)(function(){for(var $G__74652_seq__74294_seq__74294__$1$$=$APP.$cljs$core$seq$$($add_children__$1$$),$c__5548__auto__$jscomp$29_chunk__74295_shape_node_74657$$=null,$G__74654_clip_id_74658_count__74296$$=0,$i__74297_use_node_74659$$=0;;)if($i__74297_use_node_74659$$<
$G__74654_clip_id_74658_count__74296$$){var $G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$=$c__5548__auto__$jscomp$29_chunk__74295_shape_node_74657$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__74297_use_node_74659$$);$G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$=$APP.$cljs$core$__destructure_map$$($G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$);
var $contents_node_74660_frame$jscomp$42_shape_node_74641$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$,$APP.$cljs$cst$1606$frame$$);$G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$,
$APP.$cljs$cst$1811$shape$$);var $frame_node_74640$$=$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_shape_node$cljs$0core$0IFn$0_invoke$0arity$02$$(document,$contents_node_74660_frame$jscomp$42_shape_node_74641$$);$contents_node_74660_frame$jscomp$42_shape_node_74641$$=$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_shape_node$cljs$0core$0IFn$0_invoke$0arity$02$$(document,$G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$);
if($frame_node_74640$$!=null&&$contents_node_74660_frame$jscomp$42_shape_node_74641$$!=null){var $clip_id_74642$$=$APP.$app$util$dom$get_attribute$$($APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($frame_node_74640$$,":scope \x3e defs \x3e .frame-clip-def"),"id"),$use_node_74643$$=$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$02$$(),$contents_node_74644$$=function(){var $or__5025__auto__$jscomp$968$$=$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($frame_node_74640$$,
".frame-children");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$968$$)?$or__5025__auto__$jscomp$968$$:$frame_node_74640$$}();$APP.$app$util$dom$set_attribute_BANG_$$($use_node_74643$$,"href","#shape-"+($G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$??""));$APP.$app$util$dom$set_attribute_BANG_$$($use_node_74643$$,"clip-path","url(#"+($clip_id_74642$$??"")+")");$APP.$app$util$dom$add_class_BANG_$$($use_node_74643$$,"mirror-shape");
$APP.$app$util$dom$append_child_BANG_$$($contents_node_74644$$,$use_node_74643$$);$APP.$app$util$dom$set_attribute_BANG_$$($APP.$app$util$dom$get_parent$$($contents_node_74660_frame$jscomp$42_shape_node_74641$$),"display","none")}$i__74297_use_node_74659$$+=1}else if($G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$=$APP.$cljs$core$seq$$($G__74652_seq__74294_seq__74294__$1$$)){$G__74652_seq__74294_seq__74294__$1$$=$G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$;
if($APP.$cljs$core$chunked_seq_QMARK_$$($G__74652_seq__74294_seq__74294__$1$$))$c__5548__auto__$jscomp$29_chunk__74295_shape_node_74657$$=$APP.$cljs$core$_chunked_first$$($G__74652_seq__74294_seq__74294__$1$$),$G__74652_seq__74294_seq__74294__$1$$=$APP.$cljs$core$_chunked_rest$$($G__74652_seq__74294_seq__74294__$1$$),$G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$=$c__5548__auto__$jscomp$29_chunk__74295_shape_node_74657$$,$G__74654_clip_id_74658_count__74296$$=
$APP.$cljs$core$count$$($c__5548__auto__$jscomp$29_chunk__74295_shape_node_74657$$),$c__5548__auto__$jscomp$29_chunk__74295_shape_node_74657$$=$G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$;else{$G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$=$APP.$cljs$core$first$$($G__74652_seq__74294_seq__74294__$1$$);$G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$=
$APP.$cljs$core$__destructure_map$$($G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$);$contents_node_74660_frame$jscomp$42_shape_node_74641$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$,$APP.$cljs$cst$1606$frame$$);$G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$,$APP.$cljs$cst$1811$shape$$);var $frame_node_74656$$=$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_shape_node$cljs$0core$0IFn$0_invoke$0arity$02$$(document,$contents_node_74660_frame$jscomp$42_shape_node_74641$$);$c__5548__auto__$jscomp$29_chunk__74295_shape_node_74657$$=$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_shape_node$cljs$0core$0IFn$0_invoke$0arity$02$$(document,
$G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$);$frame_node_74656$$!=null&&$c__5548__auto__$jscomp$29_chunk__74295_shape_node_74657$$!=null&&($G__74654_clip_id_74658_count__74296$$=$APP.$app$util$dom$get_attribute$$($APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($frame_node_74656$$,":scope \x3e defs \x3e .frame-clip-def"),"id"),$i__74297_use_node_74659$$=$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$02$$(),
$contents_node_74660_frame$jscomp$42_shape_node_74641$$=function(){var $or__5025__auto__$jscomp$969$$=$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($frame_node_74656$$,".frame-children");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$969$$)?$or__5025__auto__$jscomp$969$$:$frame_node_74656$$}(),$APP.$app$util$dom$set_attribute_BANG_$$($i__74297_use_node_74659$$,"href","#shape-"+($G__74653_map__74310_map__74310__$1_map__74315_map__74315__$1_shape$jscomp$810_temp__5825__auto__$jscomp$287$$??
"")),$APP.$app$util$dom$set_attribute_BANG_$$($i__74297_use_node_74659$$,"clip-path","url(#"+($G__74654_clip_id_74658_count__74296$$??"")+")"),$APP.$app$util$dom$add_class_BANG_$$($i__74297_use_node_74659$$,"mirror-shape"),$APP.$app$util$dom$append_child_BANG_$$($contents_node_74660_frame$jscomp$42_shape_node_74641$$,$i__74297_use_node_74659$$),$APP.$app$util$dom$set_attribute_BANG_$$($APP.$app$util$dom$get_parent$$($c__5548__auto__$jscomp$29_chunk__74295_shape_node_74657$$),"display","none"));$G__74652_seq__74294_seq__74294__$1$$=
$APP.$cljs$core$next$$($G__74652_seq__74294_seq__74294__$1$$);$c__5548__auto__$jscomp$29_chunk__74295_shape_node_74657$$=null;$G__74654_clip_id_74658_count__74296$$=0}$i__74297_use_node_74659$$=0}else return null});return function(){cancelAnimationFrame($raf_id1$$);return cancelAnimationFrame($raf_id2$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($transforms$jscomp$5$$)],function(){var $curr_shapes_set$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$shapes$jscomp$143$$),$prev_shapes_set$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$APP.$cljs$core$_deref$$($prev_shapes$jscomp$1$$)),$new_shapes$jscomp$10$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74266_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($prev_shapes_set$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__74266_SHARP_$$))},$shapes$jscomp$143$$),$removed_shapes$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74267_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($curr_shapes_set$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__74267_SHARP_$$))},$APP.$cljs$core$_deref$$($prev_shapes$jscomp$1$$)),$raf_id1$jscomp$1$$=$APP.$app$common$data$not_empty_QMARK_$$($new_shapes$jscomp$10$$)?(0,$APP.$app$util$timers$request_animation_frame$$)(function(){a:{var $G__74382$jscomp$inline_7559_JSCompiler_inline_result$jscomp$1372_seq__73873$jscomp$inline_7524_seq__73873__$1$jscomp$inline_7557_temp__5825__auto__$jscomp$inline_7556$$=
$APP.$cljs$core$seq$$($new_shapes$jscomp$10$$);for(var $G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$=null,$G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$=
0,$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$=0;;)if($G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$<
$G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$){var $G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$=$G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$);$G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$=
$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_nodes$$($node$jscomp$379$$,$G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$);if($APP.$cljs$core$truth_$$($G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$)){$G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$=
$APP.$cljs$core$seq$$($G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$);for(var $G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$=null,$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$=
0,$i__73922_74338$jscomp$inline_7533_old_y_74369$jscomp$inline_7553_old_y_74399$jscomp$inline_7572$$=0;;)if($i__73922_74338$jscomp$inline_7533_old_y_74369$jscomp$inline_7553_old_y_74399$jscomp$inline_7572$$<$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$){var $node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$=
$G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__73922_74338$jscomp$inline_7533_old_y_74369$jscomp$inline_7553_old_y_74399$jscomp$inline_7572$$),$gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$=
$APP.$app$util$dom$get_attribute$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$,"transform");$gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$!=null&&$APP.$app$util$dom$set_attribute_BANG_$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$,
"data-old-transform",$gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$),"linearGradient")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$),
"radialGradient"))$gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$=$APP.$app$util$dom$get_attribute$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$,"gradientTransform"),$gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$!=
null&&$APP.$app$util$dom$set_attribute_BANG_$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$,"data-old-gradientTransform",$gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$),
"pattern")&&($gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$=$APP.$app$util$dom$get_attribute$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$,"patternTransform"),$gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$!=
null&&$APP.$app$util$dom$set_attribute_BANG_$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$,"data-old-patternTransform",$gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$),
"mask")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$),"filter")){$gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$=$APP.$app$util$dom$get_attribute$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$,
"x");var $old_y_74349$jscomp$inline_7539$$=$APP.$app$util$dom$get_attribute$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$,"y"),$old_width_74350$jscomp$inline_7540$$=$APP.$app$util$dom$get_attribute$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$,"width"),$old_height_74351$jscomp$inline_7541$$=$APP.$app$util$dom$get_attribute$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$,
"height");$APP.$app$util$dom$set_attribute_BANG_$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$,"data-old-x",$gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$);$APP.$app$util$dom$set_attribute_BANG_$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$,
"data-old-y",$old_y_74349$jscomp$inline_7539$$);$APP.$app$util$dom$set_attribute_BANG_$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$,"data-old-width",$old_width_74350$jscomp$inline_7540$$);$APP.$app$util$dom$set_attribute_BANG_$$($node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$,"data-old-height",$old_height_74351$jscomp$inline_7541$$)}$i__73922_74338$jscomp$inline_7533_old_y_74369$jscomp$inline_7553_old_y_74399$jscomp$inline_7572$$+=
1}else if($G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$=$APP.$cljs$core$seq$$($G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$))$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$=
$APP.$cljs$core$_chunked_first$$($G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$),$G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$=
$APP.$cljs$core$_chunked_rest$$($G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$),$G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$=$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$,
$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$=$APP.$cljs$core$count$$($G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$);
else{$G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$=$APP.$cljs$core$first$$($G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$);$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$=
$APP.$app$util$dom$get_attribute$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"transform");$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$!=
null&&$APP.$app$util$dom$set_attribute_BANG_$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"data-old-transform",$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$);
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$),"linearGradient")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$),
"radialGradient"))$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$=$APP.$app$util$dom$get_attribute$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,
"gradientTransform"),$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$!=null&&$APP.$app$util$dom$set_attribute_BANG_$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,
"data-old-gradientTransform",$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$),
"pattern")&&($G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$=$APP.$app$util$dom$get_attribute$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,
"patternTransform"),$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$!=null&&$APP.$app$util$dom$set_attribute_BANG_$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,
"data-old-patternTransform",$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$),
"mask")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$),"filter"))$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$=
$APP.$app$util$dom$get_attribute$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"x"),$i__73922_74338$jscomp$inline_7533_old_y_74369$jscomp$inline_7553_old_y_74399$jscomp$inline_7572$$=$APP.$app$util$dom$get_attribute$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,
"y"),$node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$=$APP.$app$util$dom$get_attribute$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"width"),$gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$=
$APP.$app$util$dom$get_attribute$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"height"),$APP.$app$util$dom$set_attribute_BANG_$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"data-old-x",$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$),
$APP.$app$util$dom$set_attribute_BANG_$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"data-old-y",$i__73922_74338$jscomp$inline_7533_old_y_74369$jscomp$inline_7553_old_y_74399$jscomp$inline_7572$$),$APP.$app$util$dom$set_attribute_BANG_$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,
"data-old-width",$node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$),$APP.$app$util$dom$set_attribute_BANG_$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"data-old-height",$gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$);
$G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$=$APP.$cljs$core$next$$($G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$);
$G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$=null;$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$=
0}$i__73922_74338$jscomp$inline_7533_old_y_74369$jscomp$inline_7553_old_y_74399$jscomp$inline_7572$$=0}else break}$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$+=1}else if($G__74382$jscomp$inline_7559_JSCompiler_inline_result$jscomp$1372_seq__73873$jscomp$inline_7524_seq__73873__$1$jscomp$inline_7557_temp__5825__auto__$jscomp$inline_7556$$=
$APP.$cljs$core$seq$$($G__74382$jscomp$inline_7559_JSCompiler_inline_result$jscomp$1372_seq__73873$jscomp$inline_7524_seq__73873__$1$jscomp$inline_7557_temp__5825__auto__$jscomp$inline_7556$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($G__74382$jscomp$inline_7559_JSCompiler_inline_result$jscomp$1372_seq__73873$jscomp$inline_7524_seq__73873__$1$jscomp$inline_7557_temp__5825__auto__$jscomp$inline_7556$$))$G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$=
$APP.$cljs$core$_chunked_first$$($G__74382$jscomp$inline_7559_JSCompiler_inline_result$jscomp$1372_seq__73873$jscomp$inline_7524_seq__73873__$1$jscomp$inline_7557_temp__5825__auto__$jscomp$inline_7556$$),$G__74382$jscomp$inline_7559_JSCompiler_inline_result$jscomp$1372_seq__73873$jscomp$inline_7524_seq__73873__$1$jscomp$inline_7557_temp__5825__auto__$jscomp$inline_7556$$=$APP.$cljs$core$_chunked_rest$$($G__74382$jscomp$inline_7559_JSCompiler_inline_result$jscomp$1372_seq__73873$jscomp$inline_7524_seq__73873__$1$jscomp$inline_7557_temp__5825__auto__$jscomp$inline_7556$$),
$G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$=$G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,$G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$=
$APP.$cljs$core$count$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$);else{$G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$=
$APP.$cljs$core$first$$($G__74382$jscomp$inline_7559_JSCompiler_inline_result$jscomp$1372_seq__73873$jscomp$inline_7524_seq__73873__$1$jscomp$inline_7557_temp__5825__auto__$jscomp$inline_7556$$);$G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$=$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_nodes$$($node$jscomp$379$$,
$G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$);if($APP.$cljs$core$truth_$$($G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$))for($G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$=
$APP.$cljs$core$seq$$($G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$),$G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$=null,$G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$=
$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$=0;;)if($G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$<
$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$){$G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$=$G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$);$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$=
$APP.$app$util$dom$get_attribute$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"transform");$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$!=
null&&$APP.$app$util$dom$set_attribute_BANG_$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"data-old-transform",$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$);
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$),"linearGradient")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$),
"radialGradient"))$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$=$APP.$app$util$dom$get_attribute$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,
"gradientTransform"),$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$!=null&&$APP.$app$util$dom$set_attribute_BANG_$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,
"data-old-gradientTransform",$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$),
"pattern")&&($G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$=$APP.$app$util$dom$get_attribute$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,
"patternTransform"),$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$!=null&&$APP.$app$util$dom$set_attribute_BANG_$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,
"data-old-patternTransform",$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$),
"mask")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$),"filter"))$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$=
$APP.$app$util$dom$get_attribute$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"x"),$i__73922_74338$jscomp$inline_7533_old_y_74369$jscomp$inline_7553_old_y_74399$jscomp$inline_7572$$=$APP.$app$util$dom$get_attribute$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,
"y"),$node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$=$APP.$app$util$dom$get_attribute$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"width"),$gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$=
$APP.$app$util$dom$get_attribute$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"height"),$APP.$app$util$dom$set_attribute_BANG_$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"data-old-x",$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$),
$APP.$app$util$dom$set_attribute_BANG_$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"data-old-y",$i__73922_74338$jscomp$inline_7533_old_y_74369$jscomp$inline_7553_old_y_74399$jscomp$inline_7572$$),$APP.$app$util$dom$set_attribute_BANG_$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,
"data-old-width",$node_74339$jscomp$inline_7534_old_width_74370$jscomp$inline_7554_old_width_74400$jscomp$inline_7573$$),$APP.$app$util$dom$set_attribute_BANG_$$($G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$,"data-old-height",$gradient_transform_74343$jscomp$inline_7536_old_height_74371$jscomp$inline_7555_old_height_74401$jscomp$inline_7574_old_transform_74340$jscomp$inline_7535_old_x_74348$jscomp$inline_7538_pattern_transform_74344$jscomp$inline_7537$$);
$G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$+=1}else if($G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$=
$APP.$cljs$core$seq$$($G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$))$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$=
$APP.$cljs$core$_chunked_first$$($G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$),$G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$=
$APP.$cljs$core$_chunked_rest$$($G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$),$G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$=$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$,
$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$=$APP.$cljs$core$count$$($G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$);
else{$G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$=$APP.$cljs$core$first$$($G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$);$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$=
$APP.$app$util$dom$get_attribute$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,"transform");$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$!=
null&&$APP.$app$util$dom$set_attribute_BANG_$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,"data-old-transform",$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$);
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$),"linearGradient")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$),
"radialGradient"))$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$=$APP.$app$util$dom$get_attribute$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,
"gradientTransform"),$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$!=null&&$APP.$app$util$dom$set_attribute_BANG_$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,
"data-old-gradientTransform",$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$),
"pattern")&&($G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$=$APP.$app$util$dom$get_attribute$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,
"patternTransform"),$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$!=null&&$APP.$app$util$dom$set_attribute_BANG_$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,
"data-old-patternTransform",$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$),
"mask")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$),"filter"))$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$=
$APP.$app$util$dom$get_attribute$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,"x"),$G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$=
$APP.$app$util$dom$get_attribute$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,"y"),$G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$=$APP.$app$util$dom$get_attribute$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,
"width"),$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$=$APP.$app$util$dom$get_attribute$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,
"height"),$APP.$app$util$dom$set_attribute_BANG_$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,"data-old-x",$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$),
$APP.$app$util$dom$set_attribute_BANG_$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,"data-old-y",$G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$),
$APP.$app$util$dom$set_attribute_BANG_$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,"data-old-width",$G__74360$jscomp$inline_7546_chunk__73920_74336$jscomp$inline_7531_node_74363$jscomp$inline_7548_node_74392$jscomp$inline_7567_old_width_74424$jscomp$inline_7587$$),$APP.$app$util$dom$set_attribute_BANG_$$($G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$,
"data-old-height",$G__74361$jscomp$inline_7547_c__5548__auto___74358$jscomp$inline_7544_count__73921_74337$jscomp$inline_7532_gradient_transform_74365$jscomp$inline_7550_gradient_transform_74396$jscomp$inline_7569_old_height_74425$jscomp$inline_7588_old_transform_74364$jscomp$inline_7549_old_transform_74393$jscomp$inline_7568_old_x_74368$jscomp$inline_7552_old_x_74398$jscomp$inline_7571_pattern_transform_74366$jscomp$inline_7551_pattern_transform_74397$jscomp$inline_7570$$);$G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$=
$APP.$cljs$core$next$$($G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$);$G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$=null;$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$=
0}$G__74359$jscomp$inline_7545_i__73958_74391$jscomp$inline_7566_old_y_74423$jscomp$inline_7586_seq__73919_74335$jscomp$inline_7530_seq__73919_74357__$1$jscomp$inline_7543_shape$jscomp$inline_7528_temp__5825__auto___74333$jscomp$inline_7529_temp__5825__auto___74356__$1$jscomp$inline_7542$$=0}else break;$G__74382$jscomp$inline_7559_JSCompiler_inline_result$jscomp$1372_seq__73873$jscomp$inline_7524_seq__73873__$1$jscomp$inline_7557_temp__5825__auto__$jscomp$inline_7556$$=$APP.$cljs$core$next$$($G__74382$jscomp$inline_7559_JSCompiler_inline_result$jscomp$1372_seq__73873$jscomp$inline_7524_seq__73873__$1$jscomp$inline_7557_temp__5825__auto__$jscomp$inline_7556$$);
$G__74383$jscomp$inline_7560_G__74411$jscomp$inline_7578_chunk__73874$jscomp$inline_7525_seq__73955_74388$jscomp$inline_7563_seq__73955_74409__$1$jscomp$inline_7576_temp__5825__auto___74386__$1$jscomp$inline_7562_temp__5825__auto___74408__$2$jscomp$inline_7575$$=null;$G__74384$jscomp$inline_7561_G__74412$jscomp$inline_7579_c__5548__auto__$jscomp$inline_7558_chunk__73956_74389$jscomp$inline_7564_count__73875$jscomp$inline_7526_node_74415$jscomp$inline_7581$$=0}$G__74413$jscomp$inline_7580_c__5548__auto___74410$jscomp$inline_7577_count__73957_74390$jscomp$inline_7565_gradient_transform_74417$jscomp$inline_7583_i__73876$jscomp$inline_7527_old_transform_74416$jscomp$inline_7582_old_x_74422$jscomp$inline_7585_pattern_transform_74418$jscomp$inline_7584$$=
0}else{$G__74382$jscomp$inline_7559_JSCompiler_inline_result$jscomp$1372_seq__73873$jscomp$inline_7524_seq__73873__$1$jscomp$inline_7557_temp__5825__auto__$jscomp$inline_7556$$=null;break a}$G__74382$jscomp$inline_7559_JSCompiler_inline_result$jscomp$1372_seq__73873$jscomp$inline_7524_seq__73873__$1$jscomp$inline_7557_temp__5825__auto__$jscomp$inline_7556$$=void 0}return $G__74382$jscomp$inline_7559_JSCompiler_inline_result$jscomp$1372_seq__73873$jscomp$inline_7524_seq__73873__$1$jscomp$inline_7557_temp__5825__auto__$jscomp$inline_7556$$}):
null,$raf_id2$jscomp$1$$=$APP.$app$common$data$not_empty_QMARK_$$($shapes$jscomp$143$$)?(0,$APP.$app$util$timers$request_animation_frame$$)(function(){a:{for(var $G__74481$jscomp$inline_7629_seq__73986$jscomp$inline_7594_seq__73986__$1$jscomp$inline_7627$$=$APP.$cljs$core$seq$$($shapes$jscomp$143$$),$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$=null,$G__74483$jscomp$inline_7631_count__73988$jscomp$inline_7596_modifiers_74488__$1$jscomp$inline_7637$$=
0,$G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$=0;;)if($G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$<$G__74483$jscomp$inline_7631_count__73988$jscomp$inline_7596_modifiers_74488__$1$jscomp$inline_7637$$){var $G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$=
$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$);var $G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$=
$APP.$cljs$core$__destructure_map$$($G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$);$G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$=$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$;
var $G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$,
$APP.$cljs$cst$266$id$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$,$cljs$cst$5160$_type$$);$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$=
$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_nodes$$($node$jscomp$379$$,$G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$);if($APP.$cljs$core$truth_$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$)){var $G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$=
$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$;$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transforms$jscomp$5$$,
$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$);$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$108$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$,$APP.$cljs$cst$1810$modifiers$$],null));$G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$=
$APP.$cljs$core$seq$$($G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$);for(var $G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$=null,$G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$=
0,$i__74065_74445$jscomp$inline_7609_zoom_74467$jscomp$inline_7623_zoom_74500$jscomp$inline_7644$$=0;;)if($i__74065_74445$jscomp$inline_7609_zoom_74467$jscomp$inline_7623_zoom_74500$jscomp$inline_7644$$<$G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$){var $edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$=
$G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__74065_74445$jscomp$inline_7609_zoom_74467$jscomp$inline_7623_zoom_74500$jscomp$inline_7644$$);if($APP.$app$util$dom$class_QMARK_$$($edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$,"frame-children"))$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$,
"transform",$app$common$geom$matrix$inverse$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$));else if($APP.$app$util$dom$class_QMARK_$$($edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$,"frame-title")){var $mtx_74450$jscomp$inline_7614_shape_74447__$1$jscomp$inline_7611$$=
$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$,$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$),
$zoom_74448$jscomp$inline_7612$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2196$zoom$$],null),1),$edit_grid_QMARK__74449$jscomp$inline_7613$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_data$$($edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$,
"edit-grid"),"true");$mtx_74450$jscomp$inline_7614_shape_74447__$1$jscomp$inline_7611$$=$APP.$app$main$ui$workspace$viewport$utils$title_transform$$($mtx_74450$jscomp$inline_7614_shape_74447__$1$jscomp$inline_7611$$,$zoom_74448$jscomp$inline_7612$$,$edit_grid_QMARK__74449$jscomp$inline_7613$$);$app$main$ui$workspace$shapes$frame$dynamic_modifiers$override_transform_att_BANG_$$($edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$,$mtx_74450$jscomp$inline_7614_shape_74447__$1$jscomp$inline_7611$$)}else $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$),
"mask")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$),"filter")?$app$main$ui$workspace$shapes$frame$dynamic_modifiers$transform_region_BANG_$$($edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$,$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$),"linearGradient")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$),"radialGradient")?$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$,
"gradientTransform",$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$),"pattern")?$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$,
"patternTransform",$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$):$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$!=null&&$edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$!=
null&&$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$,"transform",$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$);$i__74065_74445$jscomp$inline_7609_zoom_74467$jscomp$inline_7623_zoom_74500$jscomp$inline_7644$$+=
1}else if($G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$=$APP.$cljs$core$seq$$($G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$)?
($G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$=$APP.$cljs$core$_chunked_first$$($G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$),
$G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$=$APP.$cljs$core$_chunked_rest$$($G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$),
$G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$=$G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$,$G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$=
$APP.$cljs$core$count$$($G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$)):($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$=$APP.$cljs$core$first$$($G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$),
$APP.$app$util$dom$class_QMARK_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,"frame-children")?$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,"transform",$app$common$geom$matrix$inverse$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$)):
$APP.$app$util$dom$class_QMARK_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,"frame-title")?($G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$=$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$,
$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$),$i__74065_74445$jscomp$inline_7609_zoom_74467$jscomp$inline_7623_zoom_74500$jscomp$inline_7644$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2196$zoom$$],null),1),$edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_data$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,"edit-grid"),"true"),$G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$=
$APP.$app$main$ui$workspace$viewport$utils$title_transform$$($G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$,$i__74065_74445$jscomp$inline_7609_zoom_74467$jscomp$inline_7623_zoom_74500$jscomp$inline_7644$$,$edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$),
$app$main$ui$workspace$shapes$frame$dynamic_modifiers$override_transform_att_BANG_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,$G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$),
"mask")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$),"filter")?$app$main$ui$workspace$shapes$frame$dynamic_modifiers$transform_region_BANG_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,
$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$),"linearGradient")||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$),"radialGradient")?$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,
"gradientTransform",$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$),"pattern")?
$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,"patternTransform",$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$):$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$!=
null&&$G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$!=null&&$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,"transform",$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$),
$G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$=$APP.$cljs$core$next$$($G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$),
$G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$=null,$G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$=0),$i__74065_74445$jscomp$inline_7609_zoom_74467$jscomp$inline_7623_zoom_74500$jscomp$inline_7644$$=
0;else break}$G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$+=1}else if($G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$=$APP.$cljs$core$seq$$($G__74481$jscomp$inline_7629_seq__73986$jscomp$inline_7594_seq__73986__$1$jscomp$inline_7627$$)){$G__74481$jscomp$inline_7629_seq__73986$jscomp$inline_7594_seq__73986__$1$jscomp$inline_7627$$=
$G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($G__74481$jscomp$inline_7629_seq__73986$jscomp$inline_7594_seq__73986__$1$jscomp$inline_7627$$))$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$=
$APP.$cljs$core$_chunked_first$$($G__74481$jscomp$inline_7629_seq__73986$jscomp$inline_7594_seq__73986__$1$jscomp$inline_7627$$),$G__74481$jscomp$inline_7629_seq__73986$jscomp$inline_7594_seq__73986__$1$jscomp$inline_7627$$=$APP.$cljs$core$_chunked_rest$$($G__74481$jscomp$inline_7629_seq__73986$jscomp$inline_7594_seq__73986__$1$jscomp$inline_7627$$),$G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$=
$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$,$G__74483$jscomp$inline_7631_count__73988$jscomp$inline_7596_modifiers_74488__$1$jscomp$inline_7637$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$),
$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$=$G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$;else{$G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$=
$APP.$cljs$core$first$$($G__74481$jscomp$inline_7629_seq__73986$jscomp$inline_7594_seq__73986__$1$jscomp$inline_7627$$);$G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$=$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$=$APP.$cljs$core$__destructure_map$$($G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$);
$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$,$APP.$cljs$cst$266$id$$);
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$,$cljs$cst$5160$_type$$);$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$=$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_nodes$$($node$jscomp$379$$,
$G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$);if($APP.$cljs$core$truth_$$($c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$))for($G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$=
$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$,$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transforms$jscomp$5$$,$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$),
$G__74483$jscomp$inline_7631_count__73988$jscomp$inline_7596_modifiers_74488__$1$jscomp$inline_7637$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$108$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$,
$APP.$cljs$cst$1810$modifiers$$],null)),$G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$=$APP.$cljs$core$seq$$($G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$),$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$=
null,$G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$=$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$=0;;)if($G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$<
$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$)$G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$=$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$),$APP.$app$util$dom$class_QMARK_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,"frame-children")?$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,
"transform",$app$common$geom$matrix$inverse$$($c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$)):$APP.$app$util$dom$class_QMARK_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,"frame-title")?($G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$=
$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$,$G__74483$jscomp$inline_7631_count__73988$jscomp$inline_7596_modifiers_74488__$1$jscomp$inline_7637$$),$i__74065_74445$jscomp$inline_7609_zoom_74467$jscomp$inline_7623_zoom_74500$jscomp$inline_7644$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2196$zoom$$],null),1),$edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_data$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,
"edit-grid"),"true"),$G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$=$APP.$app$main$ui$workspace$viewport$utils$title_transform$$($G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$,
$i__74065_74445$jscomp$inline_7609_zoom_74467$jscomp$inline_7623_zoom_74500$jscomp$inline_7644$$,$edit_grid_QMARK__74468$jscomp$inline_7624_edit_grid_QMARK__74501$jscomp$inline_7645_node_74446$jscomp$inline_7610$$),$app$main$ui$workspace$shapes$frame$dynamic_modifiers$override_transform_att_BANG_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,$G__74463$jscomp$inline_7620_c__5548__auto___74460$jscomp$inline_7617_count__74064_74444$jscomp$inline_7608_mtx_74469$jscomp$inline_7625_mtx_74502$jscomp$inline_7646_shape_74466__$1$jscomp$inline_7622_shape_74499__$1$jscomp$inline_7643$$)):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$),"mask")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$),
"filter")?$app$main$ui$workspace$shapes$frame$dynamic_modifiers$transform_region_BANG_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,$G__74483$jscomp$inline_7631_count__73988$jscomp$inline_7596_modifiers_74488__$1$jscomp$inline_7637$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$),
"linearGradient")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$),"radialGradient")?$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,
"gradientTransform",$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$),"pattern")?$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,
"patternTransform",$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$):$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$!=null&&$G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$!=
null&&$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$,"transform",$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$),$G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$+=
1;else if($G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$=$APP.$cljs$core$seq$$($G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$)?
($G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$=$APP.$cljs$core$_chunked_first$$($G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$),$G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$=
$APP.$cljs$core$_chunked_rest$$($G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$),$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$=$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$,
$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$=$APP.$cljs$core$count$$($G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$)):($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$=
$APP.$cljs$core$first$$($G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$),$APP.$app$util$dom$class_QMARK_$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$,"frame-children")?
$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$,"transform",$app$common$geom$matrix$inverse$$($c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$)):
$APP.$app$util$dom$class_QMARK_$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$,"frame-title")?($G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$=$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$,
$G__74483$jscomp$inline_7631_count__73988$jscomp$inline_7596_modifiers_74488__$1$jscomp$inline_7637$$),$G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2196$zoom$$],null),1),$G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_data$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$,
"edit-grid"),"true"),$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$=$APP.$app$main$ui$workspace$viewport$utils$title_transform$$($G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$,
$G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$,$G__74462$jscomp$inline_7619_chunk__74063_74443$jscomp$inline_7607_edit_grid_QMARK__74517$jscomp$inline_7656_node_74465$jscomp$inline_7621_node_74497$jscomp$inline_7642$$),$app$main$ui$workspace$shapes$frame$dynamic_modifiers$override_transform_att_BANG_$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$,
$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$),
"mask")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$),"filter")?$app$main$ui$workspace$shapes$frame$dynamic_modifiers$transform_region_BANG_$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$,
$G__74483$jscomp$inline_7631_count__73988$jscomp$inline_7596_modifiers_74488__$1$jscomp$inline_7637$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$),"linearGradient")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$),
"radialGradient")?$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$,"gradientTransform",$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$),"pattern")?$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$,
"patternTransform",$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$):$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$!=null&&$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$!=
null&&$app$main$ui$workspace$shapes$frame$dynamic_modifiers$set_transform_att_BANG_$$($G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$,"transform",$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$),$G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$=
$APP.$cljs$core$next$$($G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$),$G__74511$jscomp$inline_7651_chunk__74111_74490$jscomp$inline_7639_map__74061__$1$jscomp$inline_7599_node_74514$jscomp$inline_7653_temp__5825__auto___74438$jscomp$inline_7602_transform_74440$jscomp$inline_7604$$=null,$G__74512$jscomp$inline_7652_c__5548__auto___74509$jscomp$inline_7649_count__74112_74491$jscomp$inline_7640_id$jscomp$inline_7601_modifiers_74441__$1$jscomp$inline_7605_mtx_74518$jscomp$inline_7657_shape_74515__$1$jscomp$inline_7654$$=
0),$G__74461$jscomp$inline_7618_i__74113_74492$jscomp$inline_7641_nodes_74439$jscomp$inline_7603_seq__74062_74442$jscomp$inline_7606_seq__74062_74459__$1$jscomp$inline_7616_temp__5825__auto___74458__$1$jscomp$inline_7615_zoom_74516$jscomp$inline_7655$$=0;else break;$G__74481$jscomp$inline_7629_seq__73986$jscomp$inline_7594_seq__73986__$1$jscomp$inline_7627$$=$APP.$cljs$core$next$$($G__74481$jscomp$inline_7629_seq__73986$jscomp$inline_7594_seq__73986__$1$jscomp$inline_7627$$);$c__5548__auto__$jscomp$inline_7628_chunk__73987$jscomp$inline_7595_map__74103__$1$jscomp$inline_7633_temp__5825__auto___74485__$1$jscomp$inline_7634_transform_74487$jscomp$inline_7636$$=
null;$G__74483$jscomp$inline_7631_count__73988$jscomp$inline_7596_modifiers_74488__$1$jscomp$inline_7637$$=0}$G__74510$jscomp$inline_7650_i__73989$jscomp$inline_7597_nodes_74486$jscomp$inline_7635_seq__74110_74489$jscomp$inline_7638_seq__74110_74508__$1$jscomp$inline_7648_temp__5825__auto___74507__$2$jscomp$inline_7647$$=0}else{$G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$=
null;break a}$G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$=void 0}return $G__74482$jscomp$inline_7630_JSCompiler_inline_result$jscomp$1373_map__74061$jscomp$inline_7598_map__74103$jscomp$inline_7632_shape$jscomp$inline_7600_temp__5825__auto__$jscomp$inline_7626$$}):null,$raf_id3$$=$APP.$app$common$data$not_empty_QMARK_$$($removed_shapes$$)?(0,$APP.$app$util$timers$request_animation_frame$$)(function(){a:{var $G__74570$jscomp$inline_7690_JSCompiler_inline_result$jscomp$1374_seq__74143$jscomp$inline_7661_seq__74143__$1$jscomp$inline_7688_temp__5825__auto__$jscomp$inline_7687$$=
$APP.$cljs$core$seq$$($removed_shapes$$);for(var $G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$=null,$G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$=
0,$G__74598$jscomp$inline_7708_c__5548__auto___74592$jscomp$inline_7705_count__74235_74578$jscomp$inline_7696_i__74146$jscomp$inline_7664_old_x_74601$jscomp$inline_7710$$=0;;)if($G__74598$jscomp$inline_7708_c__5548__auto___74592$jscomp$inline_7705_count__74235_74578$jscomp$inline_7696_i__74146$jscomp$inline_7664_old_x_74601$jscomp$inline_7710$$<$G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$){var $G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$=
$G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__74598$jscomp$inline_7708_c__5548__auto___74592$jscomp$inline_7705_count__74235_74578$jscomp$inline_7696_i__74146$jscomp$inline_7664_old_x_74601$jscomp$inline_7710$$);$G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$=
$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_nodes$$($node$jscomp$379$$,$G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$);if($APP.$cljs$core$truth_$$($G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$)){$G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$=
$APP.$cljs$core$seq$$($G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$);for(var $G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$=null,$G__74551$jscomp$inline_7681_c__5548__auto___74548$jscomp$inline_7678_count__74216_74534$jscomp$inline_7669_old_height_74604$jscomp$inline_7713_old_x_74554$jscomp$inline_7683_old_x_74581$jscomp$inline_7699$$=
0,$i__74217_74535$jscomp$inline_7670_old_y_74555$jscomp$inline_7684_old_y_74582$jscomp$inline_7700$$=0;;)if($i__74217_74535$jscomp$inline_7670_old_y_74555$jscomp$inline_7684_old_y_74582$jscomp$inline_7700$$<$G__74551$jscomp$inline_7681_c__5548__auto___74548$jscomp$inline_7678_count__74216_74534$jscomp$inline_7669_old_height_74604$jscomp$inline_7713_old_x_74554$jscomp$inline_7683_old_x_74581$jscomp$inline_7699$$){var $node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$=
$G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__74217_74535$jscomp$inline_7670_old_y_74555$jscomp$inline_7684_old_y_74582$jscomp$inline_7700$$);if($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$!=null&&!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$),
"foreignObject"))if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$),"mask")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$),"filter")){var $old_height_74557$jscomp$inline_7686_old_height_74584$jscomp$inline_7702_old_x_74537$jscomp$inline_7672$$=
$APP.$app$util$dom$get_attribute$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,"data-old-x"),$old_y_74538$jscomp$inline_7673$$=$APP.$app$util$dom$get_attribute$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,"data-old-y"),$old_width_74539$jscomp$inline_7674$$=$APP.$app$util$dom$get_attribute$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,
"data-old-width"),$old_height_74540$jscomp$inline_7675$$=$APP.$app$util$dom$get_attribute$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,"data-old-height");$APP.$app$util$dom$set_attribute_BANG_$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,"x",$old_height_74557$jscomp$inline_7686_old_height_74584$jscomp$inline_7702_old_x_74537$jscomp$inline_7672$$);$APP.$app$util$dom$set_attribute_BANG_$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,
"y",$old_y_74538$jscomp$inline_7673$$);$APP.$app$util$dom$set_attribute_BANG_$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,"width",$old_width_74539$jscomp$inline_7674$$);$APP.$app$util$dom$set_attribute_BANG_$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,"height",$old_height_74540$jscomp$inline_7675$$);$APP.$app$util$dom$remove_attribute_BANG_$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,
"data-old-x");$APP.$app$util$dom$remove_attribute_BANG_$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,"data-old-y");$APP.$app$util$dom$remove_attribute_BANG_$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,"data-old-width");$APP.$app$util$dom$remove_attribute_BANG_$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,"data-old-height")}else $APP.$app$util$dom$class_QMARK_$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,
"frame-title")?$APP.$app$util$dom$remove_attribute_BANG_$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,"data-old-transform"):$APP.$app$util$dom$get_attribute$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,"data-old-transform")!=null?$APP.$app$util$dom$remove_attribute_BANG_$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,"data-old-transform"):
$APP.$app$util$dom$remove_attribute_BANG_$$($node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$,"transform");$i__74217_74535$jscomp$inline_7670_old_y_74555$jscomp$inline_7684_old_y_74582$jscomp$inline_7700$$+=1}else if($G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$=
$APP.$cljs$core$seq$$($G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$)?
($G__74551$jscomp$inline_7681_c__5548__auto___74548$jscomp$inline_7678_count__74216_74534$jscomp$inline_7669_old_height_74604$jscomp$inline_7713_old_x_74554$jscomp$inline_7683_old_x_74581$jscomp$inline_7699$$=$APP.$cljs$core$_chunked_first$$($G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$),
$G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$=$APP.$cljs$core$_chunked_rest$$($G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$),
$G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$=$G__74551$jscomp$inline_7681_c__5548__auto___74548$jscomp$inline_7678_count__74216_74534$jscomp$inline_7669_old_height_74604$jscomp$inline_7713_old_x_74554$jscomp$inline_7683_old_x_74581$jscomp$inline_7699$$,$G__74551$jscomp$inline_7681_c__5548__auto___74548$jscomp$inline_7678_count__74216_74534$jscomp$inline_7669_old_height_74604$jscomp$inline_7713_old_x_74554$jscomp$inline_7683_old_x_74581$jscomp$inline_7699$$=
$APP.$cljs$core$count$$($G__74551$jscomp$inline_7681_c__5548__auto___74548$jscomp$inline_7678_count__74216_74534$jscomp$inline_7669_old_height_74604$jscomp$inline_7713_old_x_74554$jscomp$inline_7683_old_x_74581$jscomp$inline_7699$$)):($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$=$APP.$cljs$core$first$$($G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$),
$G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$),"foreignObject")||($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$),
"mask")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$),"filter")?($G__74551$jscomp$inline_7681_c__5548__auto___74548$jscomp$inline_7678_count__74216_74534$jscomp$inline_7669_old_height_74604$jscomp$inline_7713_old_x_74554$jscomp$inline_7683_old_x_74581$jscomp$inline_7699$$=$APP.$app$util$dom$get_attribute$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,
"data-old-x"),$i__74217_74535$jscomp$inline_7670_old_y_74555$jscomp$inline_7684_old_y_74582$jscomp$inline_7700$$=$APP.$app$util$dom$get_attribute$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"data-old-y"),$node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$=$APP.$app$util$dom$get_attribute$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,
"data-old-width"),$old_height_74557$jscomp$inline_7686_old_height_74584$jscomp$inline_7702_old_x_74537$jscomp$inline_7672$$=$APP.$app$util$dom$get_attribute$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"data-old-height"),$APP.$app$util$dom$set_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,
"x",$G__74551$jscomp$inline_7681_c__5548__auto___74548$jscomp$inline_7678_count__74216_74534$jscomp$inline_7669_old_height_74604$jscomp$inline_7713_old_x_74554$jscomp$inline_7683_old_x_74581$jscomp$inline_7699$$),$APP.$app$util$dom$set_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"y",$i__74217_74535$jscomp$inline_7670_old_y_74555$jscomp$inline_7684_old_y_74582$jscomp$inline_7700$$),
$APP.$app$util$dom$set_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"width",$node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$),$APP.$app$util$dom$set_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,
"height",$old_height_74557$jscomp$inline_7686_old_height_74584$jscomp$inline_7702_old_x_74537$jscomp$inline_7672$$),$APP.$app$util$dom$remove_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"data-old-x"),$APP.$app$util$dom$remove_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,
"data-old-y"),$APP.$app$util$dom$remove_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"data-old-width"),$APP.$app$util$dom$remove_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"data-old-height")):$APP.$app$util$dom$class_QMARK_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,
"frame-title")?$APP.$app$util$dom$remove_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"data-old-transform"):$APP.$app$util$dom$get_attribute$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"data-old-transform")!=null?$APP.$app$util$dom$remove_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,
"data-old-transform"):$APP.$app$util$dom$remove_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"transform")),$G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$=
$APP.$cljs$core$next$$($G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$),$G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$=null,$G__74551$jscomp$inline_7681_c__5548__auto___74548$jscomp$inline_7678_count__74216_74534$jscomp$inline_7669_old_height_74604$jscomp$inline_7713_old_x_74554$jscomp$inline_7683_old_x_74581$jscomp$inline_7699$$=
0),$i__74217_74535$jscomp$inline_7670_old_y_74555$jscomp$inline_7684_old_y_74582$jscomp$inline_7700$$=0;else break}$G__74598$jscomp$inline_7708_c__5548__auto___74592$jscomp$inline_7705_count__74235_74578$jscomp$inline_7696_i__74146$jscomp$inline_7664_old_x_74601$jscomp$inline_7710$$+=1}else if($G__74570$jscomp$inline_7690_JSCompiler_inline_result$jscomp$1374_seq__74143$jscomp$inline_7661_seq__74143__$1$jscomp$inline_7688_temp__5825__auto__$jscomp$inline_7687$$=$APP.$cljs$core$seq$$($G__74570$jscomp$inline_7690_JSCompiler_inline_result$jscomp$1374_seq__74143$jscomp$inline_7661_seq__74143__$1$jscomp$inline_7688_temp__5825__auto__$jscomp$inline_7687$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($G__74570$jscomp$inline_7690_JSCompiler_inline_result$jscomp$1374_seq__74143$jscomp$inline_7661_seq__74143__$1$jscomp$inline_7688_temp__5825__auto__$jscomp$inline_7687$$))$G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$=
$APP.$cljs$core$_chunked_first$$($G__74570$jscomp$inline_7690_JSCompiler_inline_result$jscomp$1374_seq__74143$jscomp$inline_7661_seq__74143__$1$jscomp$inline_7688_temp__5825__auto__$jscomp$inline_7687$$),$G__74570$jscomp$inline_7690_JSCompiler_inline_result$jscomp$1374_seq__74143$jscomp$inline_7661_seq__74143__$1$jscomp$inline_7688_temp__5825__auto__$jscomp$inline_7687$$=$APP.$cljs$core$_chunked_rest$$($G__74570$jscomp$inline_7690_JSCompiler_inline_result$jscomp$1374_seq__74143$jscomp$inline_7661_seq__74143__$1$jscomp$inline_7688_temp__5825__auto__$jscomp$inline_7687$$),
$G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$=$G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,$G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$=
$APP.$cljs$core$count$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$);else{$G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$=
$APP.$cljs$core$first$$($G__74570$jscomp$inline_7690_JSCompiler_inline_result$jscomp$1374_seq__74143$jscomp$inline_7661_seq__74143__$1$jscomp$inline_7688_temp__5825__auto__$jscomp$inline_7687$$);$G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$=$app$main$ui$workspace$shapes$frame$dynamic_modifiers$get_nodes$$($node$jscomp$379$$,
$G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$);if($APP.$cljs$core$truth_$$($G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$))for($G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$=
$APP.$cljs$core$seq$$($G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$),$G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$=null,$G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$=
$G__74598$jscomp$inline_7708_c__5548__auto___74592$jscomp$inline_7705_count__74235_74578$jscomp$inline_7696_i__74146$jscomp$inline_7664_old_x_74601$jscomp$inline_7710$$=0;;)if($G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$<$G__74598$jscomp$inline_7708_c__5548__auto___74592$jscomp$inline_7705_count__74235_74578$jscomp$inline_7696_i__74146$jscomp$inline_7664_old_x_74601$jscomp$inline_7710$$)$G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$=
$G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$),
$G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$),"foreignObject")||($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$),
"mask")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$),"filter")?($G__74551$jscomp$inline_7681_c__5548__auto___74548$jscomp$inline_7678_count__74216_74534$jscomp$inline_7669_old_height_74604$jscomp$inline_7713_old_x_74554$jscomp$inline_7683_old_x_74581$jscomp$inline_7699$$=$APP.$app$util$dom$get_attribute$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,
"data-old-x"),$i__74217_74535$jscomp$inline_7670_old_y_74555$jscomp$inline_7684_old_y_74582$jscomp$inline_7700$$=$APP.$app$util$dom$get_attribute$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"data-old-y"),$node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$=$APP.$app$util$dom$get_attribute$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,
"data-old-width"),$old_height_74557$jscomp$inline_7686_old_height_74584$jscomp$inline_7702_old_x_74537$jscomp$inline_7672$$=$APP.$app$util$dom$get_attribute$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"data-old-height"),$APP.$app$util$dom$set_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,
"x",$G__74551$jscomp$inline_7681_c__5548__auto___74548$jscomp$inline_7678_count__74216_74534$jscomp$inline_7669_old_height_74604$jscomp$inline_7713_old_x_74554$jscomp$inline_7683_old_x_74581$jscomp$inline_7699$$),$APP.$app$util$dom$set_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"y",$i__74217_74535$jscomp$inline_7670_old_y_74555$jscomp$inline_7684_old_y_74582$jscomp$inline_7700$$),
$APP.$app$util$dom$set_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"width",$node_74536$jscomp$inline_7671_old_width_74556$jscomp$inline_7685_old_width_74583$jscomp$inline_7701$$),$APP.$app$util$dom$set_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,
"height",$old_height_74557$jscomp$inline_7686_old_height_74584$jscomp$inline_7702_old_x_74537$jscomp$inline_7672$$),$APP.$app$util$dom$remove_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"data-old-x"),$APP.$app$util$dom$remove_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,
"data-old-y"),$APP.$app$util$dom$remove_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"data-old-width"),$APP.$app$util$dom$remove_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"data-old-height")):$APP.$app$util$dom$class_QMARK_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,
"frame-title")?$APP.$app$util$dom$remove_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"data-old-transform"):$APP.$app$util$dom$get_attribute$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"data-old-transform")!=null?$APP.$app$util$dom$remove_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,
"data-old-transform"):$APP.$app$util$dom$remove_attribute_BANG_$$($G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$,"transform")),$G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$+=
1;else if($G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$=$APP.$cljs$core$seq$$($G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$)?
($G__74598$jscomp$inline_7708_c__5548__auto___74592$jscomp$inline_7705_count__74235_74578$jscomp$inline_7696_i__74146$jscomp$inline_7664_old_x_74601$jscomp$inline_7710$$=$APP.$cljs$core$_chunked_first$$($G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$),$G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$=
$APP.$cljs$core$_chunked_rest$$($G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$),$G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$=$G__74598$jscomp$inline_7708_c__5548__auto___74592$jscomp$inline_7705_count__74235_74578$jscomp$inline_7696_i__74146$jscomp$inline_7664_old_x_74601$jscomp$inline_7710$$,
$G__74598$jscomp$inline_7708_c__5548__auto___74592$jscomp$inline_7705_count__74235_74578$jscomp$inline_7696_i__74146$jscomp$inline_7664_old_x_74601$jscomp$inline_7710$$=$APP.$cljs$core$count$$($G__74598$jscomp$inline_7708_c__5548__auto___74592$jscomp$inline_7705_count__74235_74578$jscomp$inline_7696_i__74146$jscomp$inline_7664_old_x_74601$jscomp$inline_7710$$)):($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$=
$APP.$cljs$core$first$$($G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$),$G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$),
"foreignObject")||($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$),"mask")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$),
"filter")?($G__74598$jscomp$inline_7708_c__5548__auto___74592$jscomp$inline_7705_count__74235_74578$jscomp$inline_7696_i__74146$jscomp$inline_7664_old_x_74601$jscomp$inline_7710$$=$APP.$app$util$dom$get_attribute$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,"data-old-x"),$G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$=
$APP.$app$util$dom$get_attribute$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,"data-old-y"),$G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$=$APP.$app$util$dom$get_attribute$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,
"data-old-width"),$G__74551$jscomp$inline_7681_c__5548__auto___74548$jscomp$inline_7678_count__74216_74534$jscomp$inline_7669_old_height_74604$jscomp$inline_7713_old_x_74554$jscomp$inline_7683_old_x_74581$jscomp$inline_7699$$=$APP.$app$util$dom$get_attribute$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,"data-old-height"),$APP.$app$util$dom$set_attribute_BANG_$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,
"x",$G__74598$jscomp$inline_7708_c__5548__auto___74592$jscomp$inline_7705_count__74235_74578$jscomp$inline_7696_i__74146$jscomp$inline_7664_old_x_74601$jscomp$inline_7710$$),$APP.$app$util$dom$set_attribute_BANG_$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,"y",$G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$),
$APP.$app$util$dom$set_attribute_BANG_$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,"width",$G__74550$jscomp$inline_7680_chunk__74215_74533$jscomp$inline_7668_node_74553$jscomp$inline_7682_node_74580$jscomp$inline_7698_old_width_74603$jscomp$inline_7712$$),$APP.$app$util$dom$set_attribute_BANG_$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,
"height",$G__74551$jscomp$inline_7681_c__5548__auto___74548$jscomp$inline_7678_count__74216_74534$jscomp$inline_7669_old_height_74604$jscomp$inline_7713_old_x_74554$jscomp$inline_7683_old_x_74581$jscomp$inline_7699$$),$APP.$app$util$dom$remove_attribute_BANG_$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,"data-old-x"),$APP.$app$util$dom$remove_attribute_BANG_$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,
"data-old-y"),$APP.$app$util$dom$remove_attribute_BANG_$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,"data-old-width"),$APP.$app$util$dom$remove_attribute_BANG_$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,
"data-old-height")):$APP.$app$util$dom$class_QMARK_$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,"frame-title")?$APP.$app$util$dom$remove_attribute_BANG_$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,
"data-old-transform"):$APP.$app$util$dom$get_attribute$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,"data-old-transform")!=null?$APP.$app$util$dom$remove_attribute_BANG_$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,
"data-old-transform"):$APP.$app$util$dom$remove_attribute_BANG_$$($G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$,"transform")),$G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$=
$APP.$cljs$core$next$$($G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$),$G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$=null,$G__74598$jscomp$inline_7708_c__5548__auto___74592$jscomp$inline_7705_count__74235_74578$jscomp$inline_7696_i__74146$jscomp$inline_7664_old_x_74601$jscomp$inline_7710$$=
0),$G__74549$jscomp$inline_7679_i__74236_74579$jscomp$inline_7697_old_y_74602$jscomp$inline_7711_seq__74214_74532$jscomp$inline_7667_seq__74214_74547__$1$jscomp$inline_7677_shape$jscomp$inline_7665_temp__5825__auto___74530$jscomp$inline_7666_temp__5825__auto___74546__$1$jscomp$inline_7676$$=0;else break;$G__74570$jscomp$inline_7690_JSCompiler_inline_result$jscomp$1374_seq__74143$jscomp$inline_7661_seq__74143__$1$jscomp$inline_7688_temp__5825__auto__$jscomp$inline_7687$$=$APP.$cljs$core$next$$($G__74570$jscomp$inline_7690_JSCompiler_inline_result$jscomp$1374_seq__74143$jscomp$inline_7661_seq__74143__$1$jscomp$inline_7688_temp__5825__auto__$jscomp$inline_7687$$);
$G__74571$jscomp$inline_7691_G__74596$jscomp$inline_7706_chunk__74144$jscomp$inline_7662_seq__74233_74576$jscomp$inline_7694_seq__74233_74591__$1$jscomp$inline_7704_temp__5825__auto___74574__$1$jscomp$inline_7693_temp__5825__auto___74590__$2$jscomp$inline_7703$$=null;$G__74572$jscomp$inline_7692_G__74597$jscomp$inline_7707_c__5548__auto__$jscomp$inline_7689_chunk__74234_74577$jscomp$inline_7695_count__74145$jscomp$inline_7663_node_74600$jscomp$inline_7709$$=0}$G__74598$jscomp$inline_7708_c__5548__auto___74592$jscomp$inline_7705_count__74235_74578$jscomp$inline_7696_i__74146$jscomp$inline_7664_old_x_74601$jscomp$inline_7710$$=
0}else{$G__74570$jscomp$inline_7690_JSCompiler_inline_result$jscomp$1374_seq__74143$jscomp$inline_7661_seq__74143__$1$jscomp$inline_7688_temp__5825__auto__$jscomp$inline_7687$$=null;break a}$G__74570$jscomp$inline_7690_JSCompiler_inline_result$jscomp$1374_seq__74143$jscomp$inline_7661_seq__74143__$1$jscomp$inline_7688_temp__5825__auto__$jscomp$inline_7687$$=void 0}return $G__74570$jscomp$inline_7690_JSCompiler_inline_result$jscomp$1374_seq__74143$jscomp$inline_7661_seq__74143__$1$jscomp$inline_7688_temp__5825__auto__$jscomp$inline_7687$$}):
null;$APP.$cljs$core$reset_BANG_$$($prev_modifiers$$,$modifiers$jscomp$108$$);$APP.$cljs$core$reset_BANG_$$($prev_transforms$$,$transforms$jscomp$5$$);$APP.$cljs$core$reset_BANG_$$($prev_shapes$jscomp$1$$,$shapes$jscomp$143$$);return function(){$APP.$cljs$core$truth_$$($raf_id1$jscomp$1$$)&&cancelAnimationFrame($raf_id1$jscomp$1$$);$APP.$cljs$core$truth_$$($raf_id2$jscomp$1$$)&&cancelAnimationFrame($raf_id2$jscomp$1$$);return $APP.$cljs$core$truth_$$($raf_id3$$)?cancelAnimationFrame($raf_id3$$):null}})};
$app$main$ui$workspace$shapes$frame$frame_shape_factory$$=function($shape_wrapper$jscomp$16$$){var $frame_shape$jscomp$4$$=$APP.$app$main$ui$shapes$frame$frame_shape$$($shape_wrapper$jscomp$16$$);return function($p1__74330_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__74330_SHARP_$$,$app$main$ui$workspace$shapes$common$check_shape_props$$)}((0,$APP.$rumext$v2$forward_ref$$)(function($props_74341_shape$jscomp$811$$,$ref$jscomp$43$$){$props_74341_shape$jscomp$811$$=$props_74341_shape$jscomp$811$$.shape;
var $shape_id$jscomp$136$$=$props_74341_shape$jscomp$811$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_74341_shape$jscomp$811$$,$APP.$cljs$cst$266$id$$),$childs$jscomp$16_childs_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$136$$)],function(){return $app$main$refs$children_objects$$($shape_id$jscomp$136$$)});$childs$jscomp$16_childs_ref$$=$APP.$rumext$v2$deref$$($childs$jscomp$16_childs_ref$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$app$main$ui$shapes$shape$shape_container$$,
{shape:$props_74341_shape$jscomp$811$$,ref:$ref$jscomp$43$$,children:[(0,$APP.$rumext$v2$jsx$$)($frame_shape$jscomp$4$$,{shape:$props_74341_shape$jscomp$811$$,childs:$childs$jscomp$16_childs_ref$$}),$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$debug$shape_debug$$,{shape:$props_74341_shape$jscomp$811$$}):null]})}))};
$app$main$ui$workspace$shapes$frame$check_props$$=function($new_props$jscomp$2$$,$old_props$jscomp$1$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props$jscomp$2$$["thumbnail?"],$old_props$jscomp$1$$["thumbnail?"])&&$new_props$jscomp$2$$.objects===$old_props$jscomp$1$$.objects&&$app$main$ui$workspace$shapes$common$check_shape_props$$($new_props$jscomp$2$$,$old_props$jscomp$1$$)};
$app$main$ui$workspace$shapes$path$make_content_modifiers_ref$$=function($id$jscomp$888$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($local$jscomp$24$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$24$$,$APP.$cljs$cst$1923$edit_path$$),$id$jscomp$888$$),$APP.$cljs$cst$1924$content_modifiers$$)},$APP.$app$main$refs$workspace_local$$)};
$app$main$ui$workspace$shapes$path$path_wrapper$$=function($content_modifiers_ref_editing_QMARK_$jscomp$1_editing_id_props_73758$$){var $shape$jscomp$816$$=$content_modifiers_ref_editing_QMARK_$jscomp$1_editing_id_props_73758$$.shape,$shape_id$jscomp$138$$=$shape$jscomp$816$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$816$$,$APP.$cljs$cst$266$id$$);$content_modifiers_ref_editing_QMARK_$jscomp$1_editing_id_props_73758$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$138$$)],
function(){return $app$main$ui$workspace$shapes$path$make_content_modifiers_ref$$($shape_id$jscomp$138$$)});var $content_modifiers$jscomp$4$$=$APP.$rumext$v2$deref$$($content_modifiers_ref_editing_QMARK_$jscomp$1_editing_id_props_73758$$);$content_modifiers_ref_editing_QMARK_$jscomp$1_editing_id_props_73758$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_edition$$);$content_modifiers_ref_editing_QMARK_$jscomp$1_editing_id_props_73758$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($content_modifiers_ref_editing_QMARK_$jscomp$1_editing_id_props_73758$$,
$shape_id$jscomp$138$$);var $shape__$1$jscomp$67$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$816$$),$APP.$rumext$v2$adapt$$($content_modifiers$jscomp$4$$)],function(){if($content_modifiers$jscomp$4$$!=null){var $JSCompiler_temp$jscomp$1375_shape__$1$jscomp$inline_7717$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$816$$,$APP.$cljs$cst$1637$content$$,$APP.$app$common$types$path$apply_content_modifiers$$,$content_modifiers$jscomp$4$$);
$JSCompiler_temp$jscomp$1375_shape__$1$jscomp$inline_7717$$=$app$common$types$path$update_geometry$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1375_shape__$1$jscomp$inline_7717$$)}else $JSCompiler_temp$jscomp$1375_shape__$1$jscomp$inline_7717$$=$shape$jscomp$816$$;return $JSCompiler_temp$jscomp$1375_shape__$1$jscomp$inline_7717$$});return(0,$APP.$rumext$v2$jsxs$$)($APP.$app$main$ui$shapes$shape$shape_container$$,{shape:$shape__$1$jscomp$67$$,pointerEvents:$content_modifiers_ref_editing_QMARK_$jscomp$1_editing_id_props_73758$$?
"none":null,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$shapes$path$path_shape$$,{shape:$shape__$1$jscomp$67$$}),$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$debug$shape_debug$$,{shape:$shape__$1$jscomp$67$$}):null]})};
$app$main$ui$workspace$shapes$text$text_wrapper$$=function($props_73792_shape$jscomp$818_shape__$1$jscomp$68$$){$props_73792_shape$jscomp$818_shape__$1$jscomp$68$$=$props_73792_shape$jscomp$818_shape__$1$jscomp$68$$.shape;var $shape_id$jscomp$139$$=$props_73792_shape$jscomp$818_shape__$1$jscomp$68$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_73792_shape$jscomp$818_shape__$1$jscomp$68$$,$APP.$cljs$cst$266$id$$),$text_modifier$jscomp$2_text_modifier_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$139$$)],
function(){return $APP.$app$main$refs$workspace_text_modifier_by_id$$($shape_id$jscomp$139$$)});$text_modifier$jscomp$2_text_modifier_ref$$=$APP.$rumext$v2$deref$$($text_modifier$jscomp$2_text_modifier_ref$$);$props_73792_shape$jscomp$818_shape__$1$jscomp$68$$=$props_73792_shape$jscomp$818_shape__$1$jscomp$68$$!=null&&$text_modifier$jscomp$2_text_modifier_ref$$!=null?$APP.$app$main$data$workspace$texts$apply_text_modifier$$($props_73792_shape$jscomp$818_shape__$1$jscomp$68$$,$text_modifier$jscomp$2_text_modifier_ref$$):
$props_73792_shape$jscomp$818_shape__$1$jscomp$68$$;return(0,$APP.$rumext$v2$jsxs$$)($APP.$app$main$ui$shapes$shape$shape_container$$,{shape:$props_73792_shape$jscomp$818_shape__$1$jscomp$68$$,children:[(0,$APP.$rumext$v2$jsx$$)("g",{className:"text-shape",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$shapes$text$text_shape$$,{shape:$props_73792_shape$jscomp$818_shape__$1$jscomp$68$$})},""+($shape_id$jscomp$139$$??"")),$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$debug$shape_debug$$,
{shape:$props_73792_shape$jscomp$818_shape__$1$jscomp$68$$}):null]})};
$app$main$ui$workspace$shapes$make_is_frame_overlap$$=function($vbox$jscomp$32$$,$objects$jscomp$693$$){return function($JSCompiler_temp$jscomp$1376_shape$jscomp$819$$){if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1376_shape$jscomp$819$$?.$show_content$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1376_shape$jscomp$819$$,$APP.$cljs$cst$1876$show_content$$))){var $children$jscomp$inline_7719$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$693$$),
$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$693$$,$JSCompiler_temp$jscomp$1376_shape$jscomp$819$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1376_shape$jscomp$819$$,$APP.$cljs$cst$266$id$$)));$JSCompiler_temp$jscomp$1376_shape$jscomp$819$$=$APP.$app$common$geom$shapes$shapes__GT_rect$$($APP.$cljs$core$cons$$($JSCompiler_temp$jscomp$1376_shape$jscomp$819$$,$children$jscomp$inline_7719$$))}else $JSCompiler_temp$jscomp$1376_shape$jscomp$819$$=
$JSCompiler_temp$jscomp$1376_shape$jscomp$819$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1376_shape$jscomp$819$$,$APP.$cljs$cst$1605$selrect$$);return $APP.$app$common$geom$rect$overlaps_rects_QMARK_$$($vbox$jscomp$32$$,$JSCompiler_temp$jscomp$1376_shape$jscomp$819$$)}};
$app$main$ui$exports$assets$export_multiple_dialog_STAR_$$=function($in_progress_QMARK__lstate_props_74694$$){function $change_all$$(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($exports__$2$$,function($exports__$3$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74692_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__74692_SHARP_$$,$APP.$cljs$cst$3109$enabled$$,!$all_checked_QMARK_$$)},$exports__$3$$)})}function $accept_fn$$($event$jscomp$203$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$203$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$exports$assets$request_multiple_export$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1870$exports$$,$enabled_exports$$,$APP.$cljs$cst$3115$cmd$$,$cmd$jscomp$9$$,$APP.$cljs$cst$725$name$$,$name$jscomp$417$$],null)),$APP.$app$main$data$exports$assets$export_shapes_event$$($enabled_exports$$,
$origin$jscomp$52$$)]))}function $cancel_fn$$($event$jscomp$202$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$202$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())}var $cmd$jscomp$9$$=$in_progress_QMARK__lstate_props_74694$$.cmd,$name$jscomp$417$$=$in_progress_QMARK__lstate_props_74694$$.name,$title$jscomp$22$$=$in_progress_QMARK__lstate_props_74694$$.title,$no_selection$$=$in_progress_QMARK__lstate_props_74694$$.noSelection,$all_exports_exports__$1$jscomp$9$$=
$in_progress_QMARK__lstate_props_74694$$.exports,$origin$jscomp$52$$=$in_progress_QMARK__lstate_props_74694$$.origin;$in_progress_QMARK__lstate_props_74694$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$export$0$$);$in_progress_QMARK__lstate_props_74694$$=$APP.$cljs$cst$4762$in_progress$$.$cljs$core$IFn$_invoke$arity$1$($in_progress_QMARK__lstate_props_74694$$);var $exports__$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($all_exports_exports__$1$jscomp$9$$);$all_exports_exports__$1$jscomp$9$$=
$APP.$cljs$core$_deref$$($exports__$2$$);var $all_checked_QMARK_$$=$APP.$cljs$core$every_QMARK_$$($APP.$cljs$cst$3109$enabled$$,$all_exports_exports__$1$jscomp$9$$),$all_unchecked_QMARK_$$=$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$complement$$($APP.$cljs$cst$3109$enabled$$),$all_exports_exports__$1$jscomp$9$$),$enabled_exports$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3109$enabled$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__74691_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__74691_SHARP_$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3109$enabled$$]))})),$all_exports_exports__$1$jscomp$9$$),$on_toggle_enabled$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($exports__$2$$)],function($event$jscomp$204_index$jscomp$387$$){$event$jscomp$204_index$jscomp$387$$=
$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$204_index$jscomp$387$$),"value"));return $event$jscomp$204_index$jscomp$387$$!=null?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($exports__$2$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$event$jscomp$204_index$jscomp$387$$,$APP.$cljs$cst$3109$enabled$$],
null),$APP.$cljs$core$not$$):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_assets__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_assets__modal-container "+($APP.$cljs$core$empty_QMARK_$$($all_exports_exports__$1$jscomp$9$$)?"main_ui_exports_assets__empty":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_assets__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_exports_assets__modal-title",
children:$title$jscomp$22$$}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$cancel_fn$$,className:"main_ui_exports_assets__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_assets__modal-content",children:$APP.$cljs$core$count$$($all_exports_exports__$1$jscomp$9$$)>0?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_exports_assets__selection-header",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$change_all$$,className:"main_ui_exports_assets__selection-btn",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_exports_assets__checkbox-wrapper",children:$all_checked_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_exports_assets__checkobox-tick checked",children:$APP.$app$main$ui$icons$tick$$}):$all_unchecked_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_exports_assets__checkobox-tick uncheked"}):
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_exports_assets__checkobox-tick intermediate",children:$APP.$app$main$ui$icons$remove_icon$$})})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_assets__selection-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.export-multiple.selected",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($enabled_exports$$)),$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($all_exports_exports__$1$jscomp$9$$))]))})]}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_assets__selection-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_assets__selection-list "+($APP.$cljs$core$count$$($all_exports_exports__$1$jscomp$9$$)>8?"main_ui_exports_assets__selection-shadow":""),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$60$$,$JSCompiler_temp_const$jscomp$10920_map__74699_p__74695$$){var $JSCompiler_temp_const$jscomp$inline_13016_index$jscomp$388$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$10920_map__74699_p__74695$$,0,null);$JSCompiler_temp_const$jscomp$10920_map__74699_p__74695$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$10920_map__74699_p__74695$$,1,null);var $JSCompiler_inline_result$jscomp$10922_map__74699__$1$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp_const$jscomp$10920_map__74699_p__74695$$),$shape$jscomp$822$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10922_map__74699__$1$$,
$APP.$cljs$cst$1811$shape$$),$JSCompiler_inline_result$jscomp$inline_13019_suffix$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10922_map__74699__$1$$,$APP.$cljs$cst$1371$suffix$$);$JSCompiler_temp_const$jscomp$10920_map__74699_p__74695$$=$out_arr__44124__auto__$jscomp$60$$.push;var $map__74700$jscomp$inline_13010_width$jscomp$inline_13014$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$822$$),$height$jscomp$inline_13015_map__74700__$1$jscomp$inline_13011$$=
$APP.$cljs$core$__destructure_map$$($map__74700$jscomp$inline_13010_width$jscomp$inline_13014$$),$JSCompiler_temp_const$jscomp$inline_13018_x$jscomp$inline_13012$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13015_map__74700__$1$jscomp$inline_13011$$,$APP.$cljs$cst$1510$x$$),$G__74701$jscomp$inline_13020_y$jscomp$inline_13013$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13015_map__74700__$1$jscomp$inline_13011$$,$APP.$cljs$cst$1511$y$$);
$map__74700$jscomp$inline_13010_width$jscomp$inline_13014$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13015_map__74700__$1$jscomp$inline_13011$$,$APP.$cljs$cst$290$width$$);$height$jscomp$inline_13015_map__74700__$1$jscomp$inline_13011$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13015_map__74700__$1$jscomp$inline_13011$$,$APP.$cljs$cst$1522$height$$);$JSCompiler_temp_const$jscomp$inline_13016_index$jscomp$388$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$inline_13016_index$jscomp$388$$);
var $JSCompiler_temp_const$jscomp$inline_13017$$=(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_exports_assets__checkbox-wrapper",children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$3109$enabled$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10922_map__74699__$1$$))?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_exports_assets__checkobox-tick checked",children:$APP.$app$main$ui$icons$tick$$}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_exports_assets__checkobox-tick uncheked"})});
$JSCompiler_temp_const$jscomp$inline_13018_x$jscomp$inline_13012$$=(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_assets__image-wrapper",children:$APP.$cljs$cst$5161$thumbnail$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$822$$)!=null?(0,$APP.$rumext$v2$jsx$$)("img",{src:$APP.$cljs$cst$5161$thumbnail$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$822$$)}):(0,$APP.$rumext$v2$jsx$$)("svg",{width:24,xmlns:"http://www.w3.org/2000/svg",height:20,children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$workspace$shapes$shape_wrapper$$,
{shape:$shape$jscomp$822$$}),viewBox:""+($JSCompiler_temp_const$jscomp$inline_13018_x$jscomp$inline_13012$$??"")+" "+($G__74701$jscomp$inline_13020_y$jscomp$inline_13013$$??"")+" "+($map__74700$jscomp$inline_13010_width$jscomp$inline_13014$$??"")+" "+($height$jscomp$inline_13015_map__74700__$1$jscomp$inline_13011$$??""),style:{WebkitPrintColorAdjust:$cljs$cst$3785$exact$$},xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",version:"1.1"})});$G__74701$jscomp$inline_13020_y$jscomp$inline_13013$$=
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$822$$);$JSCompiler_inline_result$jscomp$inline_13019_suffix$jscomp$28$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_13019_suffix$jscomp$28$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__74701$jscomp$inline_13020_y$jscomp$inline_13013$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$inline_13019_suffix$jscomp$28$$)].join(""):$G__74701$jscomp$inline_13020_y$jscomp$inline_13013$$;
$JSCompiler_inline_result$jscomp$10922_map__74699__$1$$=(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_assets__selection-row",children:(0,$APP.$rumext$v2$jsxs$$)("button",{"data-value":$JSCompiler_temp_const$jscomp$inline_13016_index$jscomp$388$$,onClick:$on_toggle_enabled$$,className:"main_ui_exports_assets__selection-btn",children:[$JSCompiler_temp_const$jscomp$inline_13017$$,$JSCompiler_temp_const$jscomp$inline_13018_x$jscomp$inline_13012$$,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_assets__selection-name",
children:$JSCompiler_inline_result$jscomp$inline_13019_suffix$jscomp$28$$}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1902$scale$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10922_map__74699__$1$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_assets__selection-scale",children:""+($APP.$app$util$strings$format_precision$$($map__74700$jscomp$inline_13010_width$jscomp$inline_13014$$*$APP.$cljs$cst$1902$scale$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10922_map__74699__$1$$),
2)??"")+"x"+($APP.$app$util$strings$format_precision$$($height$jscomp$inline_13015_map__74700__$1$jscomp$inline_13011$$*$APP.$cljs$cst$1902$scale$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10922_map__74699__$1$$),2)??"")}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10922_map__74699__$1$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_assets__selection-extension",children:$APP.$cuerdas$core$upper$$($APP.$app$common$data$name$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10922_map__74699__$1$$)))}):
null]})},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$822$$));$JSCompiler_temp_const$jscomp$10920_map__74699_p__74695$$.call($out_arr__44124__auto__$jscomp$60$$,$JSCompiler_inline_result$jscomp$10922_map__74699__$1$$);return $out_arr__44124__auto__$jscomp$60$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$_deref$$($exports__$2$$)))})})]}):(0,$APP.$rumext$v2$jsx$$)($no_selection$$,{})}),$APP.$cljs$core$count$$($all_exports_exports__$1$jscomp$9$$)>
0?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_assets__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_assets__action-buttons",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel"),onClick:$cancel_fn$$,className:"main_ui_exports_assets__cancel-button"}),(0,$APP.$rumext$v2$jsx$$)("input",{disabled:$APP.$cljs$core$truth_$$($in_progress_QMARK__lstate_props_74694$$)?
$in_progress_QMARK__lstate_props_74694$$:$all_unchecked_QMARK_$$,type:"button",value:$APP.$cljs$core$truth_$$($in_progress_QMARK__lstate_props_74694$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.exporting-object"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.export"),onClick:$APP.$cljs$core$truth_$$($in_progress_QMARK__lstate_props_74694$$)?null:$accept_fn$$,className:"main_ui_exports_assets__accept-btn "+($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($in_progress_QMARK__lstate_props_74694$$)?
$in_progress_QMARK__lstate_props_74694$$:$all_unchecked_QMARK_$$)?"main_ui_exports_assets__btn-disabled":"")})]})}):null]})]})})};
$app$main$ui$exports$assets$shapes_no_selection$$=function(){return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_assets__no-selection",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_exports_assets__modal-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.export-shapes.no-elements")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_exports_assets__modal-scd-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.export-shapes.how-to")}),
(0,$APP.$rumext$v2$jsx$$)("a",{target:"_blank",href:"https://help.penpot.app/user-guide/exporting/ ",className:"main_ui_exports_assets__modal-link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.export-shapes.how-to-link")})]})};
$app$main$ui$exports$assets$export_shapes_dialog$$=function($exports__$1$jscomp$10_map__74705_props_74704$$){$exports__$1$jscomp$10_map__74705_props_74704$$=$APP.$rumext$v2$util$wrap_props$$($exports__$1$jscomp$10_map__74705_props_74704$$);var $map__74705__$1_name$jscomp$418$$=$APP.$cljs$core$__destructure_map$$($exports__$1$jscomp$10_map__74705_props_74704$$);$exports__$1$jscomp$10_map__74705_props_74704$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74705__$1_name$jscomp$418$$,$APP.$cljs$cst$1870$exports$$);
var $origin$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74705__$1_name$jscomp$418$$,$APP.$cljs$cst$1786$origin$$);$map__74705__$1_name$jscomp$418$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74705__$1_name$jscomp$418$$,$APP.$cljs$cst$725$name$$);var $title$jscomp$23$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.export-shapes.title");return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$exports$assets$export_multiple_dialog_STAR_$$,{exports:$exports__$1$jscomp$10_map__74705_props_74704$$,
title:$title$jscomp$23$$,cmd:$APP.$cljs$cst$4125$export_shapes$$,noSelection:$app$main$ui$exports$assets$shapes_no_selection$$,origin:$origin$jscomp$53$$,name:$map__74705__$1_name$jscomp$418$$})};
$app$main$ui$exports$assets$export_frames$$=function($exports__$1$jscomp$11_map__74707_props_74706$$){$exports__$1$jscomp$11_map__74707_props_74706$$=$APP.$rumext$v2$util$wrap_props$$($exports__$1$jscomp$11_map__74707_props_74706$$);var $map__74707__$1_name$jscomp$419$$=$APP.$cljs$core$__destructure_map$$($exports__$1$jscomp$11_map__74707_props_74706$$);$exports__$1$jscomp$11_map__74707_props_74706$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74707__$1_name$jscomp$419$$,$APP.$cljs$cst$1870$exports$$);
var $origin$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74707__$1_name$jscomp$419$$,$APP.$cljs$cst$1786$origin$$);$map__74707__$1_name$jscomp$419$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74707__$1_name$jscomp$419$$,$APP.$cljs$cst$725$name$$);var $title$jscomp$24$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.export-frames.title");return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$exports$assets$export_multiple_dialog_STAR_$$,{exports:$exports__$1$jscomp$11_map__74707_props_74706$$,
title:$title$jscomp$24$$,cmd:$APP.$cljs$cst$4760$export_frames$$,origin:$origin$jscomp$54$$,name:$map__74707__$1_name$jscomp$419$$})};
$app$common$files$repair$repair_file$$=function($map__74160__$1_map__74161_map__74161__$1_p__74159$$,$libraries$jscomp$102$$,$errors$jscomp$26$$){$map__74160__$1_map__74161_map__74161__$1_p__74159$$=$APP.$cljs$core$__destructure_map$$($map__74160__$1_map__74161_map__74161__$1_p__74159$$);var $data$jscomp$441$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74160__$1_map__74161_map__74161__$1_p__74159$$,$APP.$cljs$cst$142$data$$),$id$jscomp$889$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74160__$1_map__74161_map__74161__$1_p__74159$$,
$APP.$cljs$cst$266$id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing file"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$889$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$count$$($errors$jscomp$26$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);$map__74160__$1_map__74161_map__74161__$1_p__74159$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes$jscomp$319$$,$error$jscomp$136$$){return $APP.$app$common$files$changes_builder$concat_changes$$($changes$jscomp$319$$,
$app$common$files$repair$repair_error$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$136$$),$error$jscomp$136$$,$data$jscomp$441$$,$libraries$jscomp$102$$))},$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$errors$jscomp$26$$);$map__74160__$1_map__74161_map__74161__$1_p__74159$$=$APP.$cljs$core$__destructure_map$$($map__74160__$1_map__74161_map__74161__$1_p__74159$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74160__$1_map__74161_map__74161__$1_p__74159$$,
$APP.$cljs$cst$3133$redo_changes$$)};
$app$common$files$validate$build_children_sets$$=function($objects$jscomp$697$$){return $APP.$cljs$core$reduce_kv$$(function($m$jscomp$220$$,$_$jscomp$2868_temp__5823__auto__$jscomp$203$$,$shape$jscomp$859$$){$_$jscomp$2868_temp__5823__auto__$jscomp$203$$=$APP.$cljs$core$not_empty$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$859$$));return $APP.$cljs$core$truth_$$($_$jscomp$2868_temp__5823__auto__$jscomp$203$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$220$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$859$$),
$APP.$cljs$core$set$$($_$jscomp$2868_temp__5823__auto__$jscomp$203$$)):$m$jscomp$220$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$objects$jscomp$697$$)};
$app$common$files$validate$find_ref_shape_STAR_$$=function($file$jscomp$101_result$jscomp$326$$,$page$jscomp$118$$,$libraries$jscomp$103$$,$shape$jscomp$860$$){var $temp__5823__auto__$jscomp$204$$=$app$common$files$validate$_STAR_ref_shape_cache_STAR_$$;if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$204$$)){var $id$jscomp$890$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$860$$);if($APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($temp__5823__auto__$jscomp$204$$),
$id$jscomp$890$$))return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($temp__5823__auto__$jscomp$204$$),$id$jscomp$890$$);$file$jscomp$101_result$jscomp$326$$=$app$common$types$file$find_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($file$jscomp$101_result$jscomp$326$$,$page$jscomp$118$$,$libraries$jscomp$103$$,$shape$jscomp$860$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0]));$APP.$cljs$core$_vreset_BANG_$$($temp__5823__auto__$jscomp$204$$,
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($temp__5823__auto__$jscomp$204$$),$id$jscomp$890$$,$file$jscomp$101_result$jscomp$326$$));return $file$jscomp$101_result$jscomp$326$$}return $app$common$types$file$find_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($file$jscomp$101_result$jscomp$326$$,$page$jscomp$118$$,$libraries$jscomp$103$$,$shape$jscomp$860$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2540$include_deleted_QMARK_$$,
!0]))};$app$common$files$validate$library_exists_QMARK_$$=function($file$jscomp$102$$,$libraries$jscomp$104$$,$shape$jscomp$861$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$861$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$102$$))||$APP.$cljs$core$contains_QMARK_$$($libraries$jscomp$104$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$861$$))};
$app$common$files$validate$report_error$$=function($var_args$jscomp$1400$$){for(var $args__5755__auto__$jscomp$241$$=[],$len__5749__auto___74227$$=arguments.length,$i__5750__auto___74228$$=0;;)if($i__5750__auto___74228$$<$len__5749__auto___74227$$)$args__5755__auto__$jscomp$241$$.push(arguments[$i__5750__auto___74228$$]),$i__5750__auto___74228$$+=1;else break;return $app$common$files$validate$report_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],arguments[2],arguments[3],
arguments[4],5<$args__5755__auto__$jscomp$241$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$241$$.slice(5),0,null):null)};
$app$common$files$validate$report_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($code$jscomp$51_error$jscomp$137$$,$hint$jscomp$15$$,$shape$jscomp$862$$,$file$jscomp$103$$,$page$jscomp$119$$,$args$jscomp$261_p__73896$$){$args$jscomp$261_p__73896$$=$APP.$cljs$core$__destructure_map$$($args$jscomp$261_p__73896$$);$code$jscomp$51_error$jscomp$137$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$273$code$$,
$code$jscomp$51_error$jscomp$137$$,$APP.$cljs$cst$275$hint$$,$hint$jscomp$15$$,$APP.$cljs$cst$1811$shape$$,$shape$jscomp$862$$,$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$103$$),$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$119$$),$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$862$$),$cljs$cst$578$args$$,$args$jscomp$261_p__73896$$],null));
return $APP.$cljs$core$_vreset_BANG_$$($app$common$files$validate$_STAR_errors_STAR_$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($app$common$files$validate$_STAR_errors_STAR_$$),$code$jscomp$51_error$jscomp$137$$))};
$app$common$files$validate$check_geometry$$=function($shape$jscomp$863$$,$file$jscomp$104$$,$page$jscomp$120$$){$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$863$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$863$$)||$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$863$$)!=null&&$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$863$$)!=null&&$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$863$$)!=
null&&$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$863$$)!=null&&$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$863$$)!=null&&$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$863$$)!=null||$app$common$files$validate$report_error$$($cljs$cst$5162$invalid_geometry$$,"Shape geometry is invalid",$shape$jscomp$863$$,$file$jscomp$104$$,$page$jscomp$120$$)};
$app$common$files$validate$check_parent_children$$=function($shape$jscomp$864$$,$file$jscomp$105$$,$page$jscomp$121$$){var $parent$jscomp$292$$=$app$common$types$shape_tree$get_shape$$($page$jscomp$121$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$864$$)),$shape_id$jscomp$141$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$864$$),$G__74244_seq__73907_seq__73907__$1_shapes$jscomp$146_temp__5825__auto__$jscomp$291$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$864$$);
if($parent$jscomp$292$$==null)$app$common$files$validate$report_error$$($cljs$cst$5163$parent_not_found$$,"Parent "+($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$864$$)??"")+" not found",$shape$jscomp$864$$,$file$jscomp$105$$,$page$jscomp$121$$);else{$APP.$app$common$files$helpers$root_QMARK_$$($shape$jscomp$864$$)||$APP.$cljs$core$truth_$$(function(){var $temp__5823__auto__$jscomp$205$$=$app$common$files$validate$_STAR_children_sets_STAR_$$;return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$205$$)?
$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$205$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$292$$)),$shape_id$jscomp$141$$):$APP.$cljs$core$some$$(function($p1__73904_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_id$jscomp$141$$,$p1__73904_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$292$$))}())||$app$common$files$validate$report_error$$($cljs$cst$5164$child_not_in_parent$$,
"Shape "+($shape_id$jscomp$141$$??"")+" not in parent's children list",$shape$jscomp$864$$,$file$jscomp$105$$,$page$jscomp$121$$);$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($seen$jscomp$14$$,$id$jscomp$891$$){return $APP.$cljs$core$contains_QMARK_$$($seen$jscomp$14$$,$id$jscomp$891$$)?$APP.$cljs$core$reduced$$(!0):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($seen$jscomp$14$$,$id$jscomp$891$$)},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$G__74244_seq__73907_seq__73907__$1_shapes$jscomp$146_temp__5825__auto__$jscomp$291$$)===
!0&&$app$common$files$validate$report_error$$($cljs$cst$5165$duplicated_children$$,"Shape "+($shape_id$jscomp$141$$??"")+" has duplicated children",$shape$jscomp$864$$,$file$jscomp$105$$,$page$jscomp$121$$);$G__74244_seq__73907_seq__73907__$1_shapes$jscomp$146_temp__5825__auto__$jscomp$291$$=$APP.$cljs$core$seq$$($G__74244_seq__73907_seq__73907__$1_shapes$jscomp$146_temp__5825__auto__$jscomp$291$$);for(var $c__5548__auto__$jscomp$30_child_74248_chunk__73908$$=null,$G__74246_count__73909$$=0,$i__73910$$=
0;;)if($i__73910$$<$G__74246_count__73909$$){var $G__74245_child_id$jscomp$9$$=$c__5548__auto__$jscomp$30_child_74248_chunk__73908$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__73910$$),$child_74238$$=$app$common$types$shape_tree$get_shape$$($page$jscomp$121$$,$G__74245_child_id$jscomp$9$$);$child_74238$$==null?$app$common$files$validate$report_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cljs$cst$5166$child_not_found$$,"Child "+($G__74245_child_id$jscomp$9$$??"")+" not found in parent "+($shape_id$jscomp$141$$??
""),$shape$jscomp$864$$,$file$jscomp$105$$,$page$jscomp$121$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$parent_id$$,$shape_id$jscomp$141$$,$cljs$cst$5167$child_id$$,$G__74245_child_id$jscomp$9$$])):$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($child_74238$$),$shape_id$jscomp$141$$)&&$app$common$files$validate$report_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cljs$cst$5168$invalid_parent$$,
"Child "+($G__74245_child_id$jscomp$9$$??"")+" has invalid parent "+($shape_id$jscomp$141$$??""),$child_74238$$,$file$jscomp$105$$,$page$jscomp$121$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$parent_id$$,$shape_id$jscomp$141$$]));$i__73910$$+=1}else if($G__74244_seq__73907_seq__73907__$1_shapes$jscomp$146_temp__5825__auto__$jscomp$291$$=$APP.$cljs$core$seq$$($G__74244_seq__73907_seq__73907__$1_shapes$jscomp$146_temp__5825__auto__$jscomp$291$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__74244_seq__73907_seq__73907__$1_shapes$jscomp$146_temp__5825__auto__$jscomp$291$$)?
($c__5548__auto__$jscomp$30_child_74248_chunk__73908$$=$APP.$cljs$core$_chunked_first$$($G__74244_seq__73907_seq__73907__$1_shapes$jscomp$146_temp__5825__auto__$jscomp$291$$),$G__74244_seq__73907_seq__73907__$1_shapes$jscomp$146_temp__5825__auto__$jscomp$291$$=$APP.$cljs$core$_chunked_rest$$($G__74244_seq__73907_seq__73907__$1_shapes$jscomp$146_temp__5825__auto__$jscomp$291$$),$G__74245_child_id$jscomp$9$$=$c__5548__auto__$jscomp$30_child_74248_chunk__73908$$,$G__74246_count__73909$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$30_child_74248_chunk__73908$$),
$c__5548__auto__$jscomp$30_child_74248_chunk__73908$$=$G__74245_child_id$jscomp$9$$):($G__74245_child_id$jscomp$9$$=$APP.$cljs$core$first$$($G__74244_seq__73907_seq__73907__$1_shapes$jscomp$146_temp__5825__auto__$jscomp$291$$),$c__5548__auto__$jscomp$30_child_74248_chunk__73908$$=$app$common$types$shape_tree$get_shape$$($page$jscomp$121$$,$G__74245_child_id$jscomp$9$$),$c__5548__auto__$jscomp$30_child_74248_chunk__73908$$==null?$app$common$files$validate$report_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cljs$cst$5166$child_not_found$$,
"Child "+($G__74245_child_id$jscomp$9$$??"")+" not found in parent "+($shape_id$jscomp$141$$??""),$shape$jscomp$864$$,$file$jscomp$105$$,$page$jscomp$121$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$parent_id$$,$shape_id$jscomp$141$$,$cljs$cst$5167$child_id$$,$G__74245_child_id$jscomp$9$$])):$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto__$jscomp$30_child_74248_chunk__73908$$),
$shape_id$jscomp$141$$)&&$app$common$files$validate$report_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cljs$cst$5168$invalid_parent$$,"Child "+($G__74245_child_id$jscomp$9$$??"")+" has invalid parent "+($shape_id$jscomp$141$$??""),$c__5548__auto__$jscomp$30_child_74248_chunk__73908$$,$file$jscomp$105$$,$page$jscomp$121$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$parent_id$$,$shape_id$jscomp$141$$])),$G__74244_seq__73907_seq__73907__$1_shapes$jscomp$146_temp__5825__auto__$jscomp$291$$=
$APP.$cljs$core$next$$($G__74244_seq__73907_seq__73907__$1_shapes$jscomp$146_temp__5825__auto__$jscomp$291$$),$c__5548__auto__$jscomp$30_child_74248_chunk__73908$$=null,$G__74246_count__73909$$=0),$i__73910$$=0;else break}};
$app$common$files$validate$check_frame$$=function($map__73927__$1_p__73926$$,$file$jscomp$106$$,$page$jscomp$122$$){$map__73927__$1_p__73926$$=$APP.$cljs$core$__destructure_map$$($map__73927__$1_p__73926$$);var $frame_id$jscomp$116$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73927__$1_p__73926$$,$APP.$cljs$cst$1607$frame_id$$),$frame$jscomp$45_parent$jscomp$293$$=$app$common$types$shape_tree$get_shape$$($page$jscomp$122$$,$frame_id$jscomp$116$$);$frame$jscomp$45_parent$jscomp$293$$==
null?$app$common$files$validate$report_error$$($cljs$cst$5169$frame_not_found$$,"Frame "+($frame_id$jscomp$116$$??"")+" not found",$map__73927__$1_p__73926$$,$file$jscomp$106$$,$page$jscomp$122$$):$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$45_parent$jscomp$293$$),$APP.$cljs$cst$1606$frame$$)?$app$common$files$validate$report_error$$($cljs$cst$5170$invalid_frame$$,"Frame "+($frame_id$jscomp$116$$??"")+" is not actually a frame",
$map__73927__$1_p__73926$$,$file$jscomp$106$$,$page$jscomp$122$$):($frame$jscomp$45_parent$jscomp$293$$=$app$common$types$shape_tree$get_shape$$($page$jscomp$122$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($map__73927__$1_p__73926$$)),$frame$jscomp$45_parent$jscomp$293$$!=null&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$45_parent$jscomp$293$$),$APP.$cljs$cst$1606$frame$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$116$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$45_parent$jscomp$293$$))||$app$common$files$validate$report_error$$($cljs$cst$5170$invalid_frame$$,"Frame-id should point to parent "+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$45_parent$jscomp$293$$)??""),$map__73927__$1_p__73926$$,$file$jscomp$106$$,$page$jscomp$122$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$116$$,$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$45_parent$jscomp$293$$))||
$app$common$files$validate$report_error$$($cljs$cst$5170$invalid_frame$$,"Frame-id should point to parent frame "+($frame_id$jscomp$116$$??""),$map__73927__$1_p__73926$$,$file$jscomp$106$$,$page$jscomp$122$$)))};
$app$common$files$validate$check_component_main_head$$=function($shape$jscomp$866$$,$file$jscomp$107$$,$page$jscomp$123$$,$component$jscomp$106_libraries$jscomp$105_main_component$jscomp$2$$){$APP.$cljs$cst$2045$main_instance$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$866$$)==null&&$app$common$files$validate$report_error$$($cljs$cst$5171$component_not_main$$,"Shape expected to be main instance",$shape$jscomp$866$$,$file$jscomp$107$$,$page$jscomp$123$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$866$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$107$$))||$app$common$files$validate$report_error$$($cljs$cst$5172$component_main_external$$,"Main instance should refer to a component in the same file",$shape$jscomp$866$$,$file$jscomp$107$$,$page$jscomp$123$$);$component$jscomp$106_libraries$jscomp$105_main_component$jscomp$2$$=$APP.$app$common$types$file$resolve_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape$jscomp$866$$,$file$jscomp$107$$,$component$jscomp$106_libraries$jscomp$105_main_component$jscomp$2$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0]));if($component$jscomp$106_libraries$jscomp$105_main_component$jscomp$2$$==null)$app$common$files$validate$report_error$$($cljs$cst$5173$component_not_found$$,"Component "+($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$866$$)??"")+" not found in file "+($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$866$$)??""),$shape$jscomp$866$$,
$file$jscomp$107$$,$page$jscomp$123$$);else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$106_libraries$jscomp$105_main_component$jscomp$2$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$866$$))||$app$common$files$validate$report_error$$($cljs$cst$5174$invalid_main_instance_id$$,"Main instance id of component "+($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$866$$)??
"")+" is not valid",$shape$jscomp$866$$,$file$jscomp$107$$,$page$jscomp$123$$),!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$106_libraries$jscomp$105_main_component$jscomp$2$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$123$$))){var $component_page$jscomp$7$$=$APP.$app$common$types$file$get_component_page$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$107$$),
$component$jscomp$106_libraries$jscomp$105_main_component$jscomp$2$$);$component$jscomp$106_libraries$jscomp$105_main_component$jscomp$2$$=$app$common$types$shape_tree$get_shape$$($component_page$jscomp$7$$,$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$106_libraries$jscomp$105_main_component$jscomp$2$$));$APP.$cljs$core$truth_$$($APP.$cljs$cst$2045$main_instance$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$106_libraries$jscomp$105_main_component$jscomp$2$$))?
$app$common$files$validate$report_error$$($cljs$cst$5177$component_main$$,"Shape not expected to be main instance",$shape$jscomp$866$$,$file$jscomp$107$$,$page$jscomp$123$$):$app$common$files$validate$report_error$$($cljs$cst$5175$invalid_main_instance_page$$,"Main instance page of component "+($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$866$$)??"")+" is not valid",$shape$jscomp$866$$,$file$jscomp$107$$,$page$jscomp$123$$)}};
$app$common$files$validate$check_component_not_main_head$$=function($shape$jscomp$867$$,$file$jscomp$108$$,$page$jscomp$124$$,$component$jscomp$107_libraries$jscomp$106$$){$APP.$cljs$cst$2045$main_instance$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$867$$)===!0&&$app$common$files$validate$report_error$$($cljs$cst$5171$component_not_main$$,"Shape not expected to be main instance",$shape$jscomp$867$$,$file$jscomp$108$$,$page$jscomp$124$$);var $library_exists$$=$app$common$files$validate$library_exists_QMARK_$$($file$jscomp$108$$,
$component$jscomp$107_libraries$jscomp$106$$,$shape$jscomp$867$$);$component$jscomp$107_libraries$jscomp$106$$=$library_exists$$?$APP.$app$common$types$file$resolve_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape$jscomp$867$$,$file$jscomp$108$$,$component$jscomp$107_libraries$jscomp$106$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!0],null)])):null;$component$jscomp$107_libraries$jscomp$106$$==
null?$library_exists$$&&$app$common$files$validate$report_error$$($cljs$cst$5173$component_not_found$$,"Component "+($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$867$$)??"")+" not found in file "+($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$867$$)??""),$shape$jscomp$867$$,$file$jscomp$108$$,$page$jscomp$124$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$107_libraries$jscomp$106$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$867$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2063$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$107_libraries$jscomp$106$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$124$$))&&$app$common$files$validate$report_error$$($cljs$cst$5176$invalid_main_instance$$,"Main instance of component "+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$107_libraries$jscomp$106$$)??
"")+" should not be this shape",$shape$jscomp$867$$,$file$jscomp$108$$,$page$jscomp$124$$)};
$app$common$files$validate$check_component_not_main_not_head$$=function($shape$jscomp$868$$,$file$jscomp$109$$,$page$jscomp$125$$){$APP.$cljs$cst$2045$main_instance$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$868$$)===!0&&$app$common$files$validate$report_error$$($cljs$cst$5177$component_main$$,"Shape not expected to be main instance",$shape$jscomp$868$$,$file$jscomp$109$$,$page$jscomp$125$$);$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$868$$)==null&&$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$868$$)==
null||$app$common$files$validate$report_error$$($cljs$cst$5177$component_main$$,"Shape not expected to be component head",$shape$jscomp$868$$,$file$jscomp$109$$,$page$jscomp$125$$)};
$app$common$files$validate$check_component_root$$=function($shape$jscomp$869$$,$file$jscomp$110$$,$page$jscomp$126$$){$APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$869$$)==null&&$app$common$files$validate$report_error$$($cljs$cst$5178$should_be_component_root$$,"Shape should be component root",$shape$jscomp$869$$,$file$jscomp$110$$,$page$jscomp$126$$)};
$app$common$files$validate$check_component_not_root$$=function($shape$jscomp$870$$,$file$jscomp$111$$,$page$jscomp$127$$){$APP.$cljs$cst$2044$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$870$$)===!0&&$app$common$files$validate$report_error$$($cljs$cst$5179$should_not_be_component_root$$,"Shape should not be component root",$shape$jscomp$870$$,$file$jscomp$111$$,$page$jscomp$127$$)};
$app$common$files$validate$check_component_ref$$=function($shape$jscomp$871$$,$file$jscomp$112$$,$page$jscomp$128$$,$libraries$jscomp$107_ref_shape$jscomp$5$$){var $library_exists$jscomp$1$$=$app$common$files$validate$library_exists_QMARK_$$($file$jscomp$112$$,$libraries$jscomp$107_ref_shape$jscomp$5$$,$shape$jscomp$871$$);$libraries$jscomp$107_ref_shape$jscomp$5$$=$library_exists$jscomp$1$$?$app$common$files$validate$find_ref_shape_STAR_$$($file$jscomp$112$$,$page$jscomp$128$$,$libraries$jscomp$107_ref_shape$jscomp$5$$,
$shape$jscomp$871$$):null;$library_exists$jscomp$1$$&&$libraries$jscomp$107_ref_shape$jscomp$5$$==null&&$app$common$files$validate$report_error$$($cljs$cst$5180$ref_shape_not_found$$,"Referenced shape "+($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$871$$)??"")+" not found in near component",$shape$jscomp$871$$,$file$jscomp$112$$,$page$jscomp$128$$)};
$app$common$files$validate$check_component_not_ref$$=function($shape$jscomp$872$$,$file$jscomp$113$$,$page$jscomp$129$$){$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$872$$)!=null&&$app$common$files$validate$report_error$$($cljs$cst$5186$shape_ref_in_main$$,"Shape inside main instance should not have shape-ref",$shape$jscomp$872$$,$file$jscomp$113$$,$page$jscomp$129$$)};
$app$common$files$validate$check_ref_is_not_head$$=function($shape$jscomp$873$$,$file$jscomp$114$$,$page$jscomp$130$$,$libraries$jscomp$108_ref_shape$jscomp$6$$){$libraries$jscomp$108_ref_shape$jscomp$6$$=$app$common$files$validate$find_ref_shape_STAR_$$($file$jscomp$114$$,$page$jscomp$130$$,$libraries$jscomp$108_ref_shape$jscomp$6$$,$shape$jscomp$873$$);$libraries$jscomp$108_ref_shape$jscomp$6$$!=null&&$APP.$app$common$types$component$instance_head_QMARK_$$($libraries$jscomp$108_ref_shape$jscomp$6$$)&&
$app$common$files$validate$report_error$$($cljs$cst$5183$ref_shape_is_head$$,"Referenced shape "+($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$873$$)??"")+" is a component, so the copy must also be",$shape$jscomp$873$$,$file$jscomp$114$$,$page$jscomp$130$$)};
$app$common$files$validate$check_ref_is_head$$=function($shape$jscomp$874$$,$file$jscomp$115$$,$page$jscomp$131$$,$libraries$jscomp$109_ref_shape$jscomp$7$$){$libraries$jscomp$109_ref_shape$jscomp$7$$=$app$common$files$validate$find_ref_shape_STAR_$$($file$jscomp$115$$,$page$jscomp$131$$,$libraries$jscomp$109_ref_shape$jscomp$7$$,$shape$jscomp$874$$);$libraries$jscomp$109_ref_shape$jscomp$7$$==null||$APP.$app$common$types$component$instance_head_QMARK_$$($libraries$jscomp$109_ref_shape$jscomp$7$$)||
$app$common$files$validate$report_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cljs$cst$5181$ref_shape_is_not_head$$,"Referenced shape "+($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$874$$)??"")+" of a head copy must also be a head",$shape$jscomp$874$$,$file$jscomp$115$$,$page$jscomp$131$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1643$component_file$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($libraries$jscomp$109_ref_shape$jscomp$7$$),
$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($libraries$jscomp$109_ref_shape$jscomp$7$$)]))};
$app$common$files$validate$check_ref_component_id$$=function($shape$jscomp$875$$,$file$jscomp$116$$,$page$jscomp$132$$,$libraries$jscomp$110_temp__5825__auto__$jscomp$292$$){$APP.$app$common$types$component$get_swap_slot$$($shape$jscomp$875$$)==null&&($libraries$jscomp$110_temp__5825__auto__$jscomp$292$$=$app$common$files$validate$find_ref_shape_STAR_$$($file$jscomp$116$$,$page$jscomp$132$$,$libraries$jscomp$110_temp__5825__auto__$jscomp$292$$,$shape$jscomp$875$$),$APP.$cljs$core$truth_$$($libraries$jscomp$110_temp__5825__auto__$jscomp$292$$)&&
($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$875$$),$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($libraries$jscomp$110_temp__5825__auto__$jscomp$292$$))||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$875$$),$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($libraries$jscomp$110_temp__5825__auto__$jscomp$292$$)))&&
$app$common$files$validate$report_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cljs$cst$5182$component_id_mismatch$$,"Nested copy component-id and component-file must be the same as the near main",$shape$jscomp$875$$,$file$jscomp$116$$,$page$jscomp$132$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($libraries$jscomp$110_temp__5825__auto__$jscomp$292$$),$APP.$cljs$cst$1643$component_file$$,
$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($libraries$jscomp$110_temp__5825__auto__$jscomp$292$$)])))};$app$common$files$validate$check_empty_swap_slot$$=function($shape$jscomp$876$$,$file$jscomp$117$$,$page$jscomp$133$$){$APP.$app$common$types$component$get_swap_slot$$($shape$jscomp$876$$)!=null&&$app$common$files$validate$report_error$$($cljs$cst$5198$misplaced_slot$$,"This shape should not have swap slot",$shape$jscomp$876$$,$file$jscomp$117$$,$page$jscomp$133$$)};
$app$common$files$validate$has_duplicate_swap_slot_QMARK_$$=function($shape$jscomp$877$$,$container$jscomp$80$$){var $objects$jscomp$698$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$80$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($seen$jscomp$15$$,$child_id$jscomp$10_slot$jscomp$1$$){$child_id$jscomp$10_slot$jscomp$1$$=$APP.$app$common$types$component$get_swap_slot$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$698$$,
$child_id$jscomp$10_slot$jscomp$1$$));return $child_id$jscomp$10_slot$jscomp$1$$==null?$seen$jscomp$15$$:$APP.$cljs$core$contains_QMARK_$$($seen$jscomp$15$$,$child_id$jscomp$10_slot$jscomp$1$$)?$APP.$cljs$core$reduced$$(!0):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($seen$jscomp$15$$,$child_id$jscomp$10_slot$jscomp$1$$)},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$877$$))===!0};
$app$common$files$validate$check_duplicate_swap_slot$$=function($shape$jscomp$878$$,$file$jscomp$118$$,$page$jscomp$134$$){$app$common$files$validate$has_duplicate_swap_slot_QMARK_$$($shape$jscomp$878$$,$page$jscomp$134$$)&&$app$common$files$validate$report_error$$($cljs$cst$5199$duplicate_slot$$,"This shape has children with the same swap slot",$shape$jscomp$878$$,$file$jscomp$118$$,$page$jscomp$134$$)};
$app$common$files$validate$check_required_swap_slot$$=function($shape$jscomp$879$$,$file$jscomp$119$$,$page$jscomp$135$$,$libraries$jscomp$111_or__5025__auto__$jscomp$inline_7725_parent_ref_shape$jscomp$inline_14514$$){if($APP.$app$common$types$component$get_swap_slot$$($shape$jscomp$879$$)==null){var $JSCompiler_inline_result$jscomp$1385_JSCompiler_temp$jscomp$inline_14518_map__51819__$1$jscomp$inline_14510_near_match$jscomp$1_with_context_QMARK_$jscomp$inline_14512$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2540$include_deleted_QMARK_$$,
!0,$cljs$cst$2591$with_context_QMARK_$$,!1]));var $include_deleted_QMARK_$jscomp$inline_14511_ref_container$jscomp$inline_14515$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1385_JSCompiler_temp$jscomp$inline_14518_map__51819__$1$jscomp$inline_14510_near_match$jscomp$1_with_context_QMARK_$jscomp$inline_14512$$,$APP.$cljs$cst$2540$include_deleted_QMARK_$$,!1);$JSCompiler_inline_result$jscomp$1385_JSCompiler_temp$jscomp$inline_14518_map__51819__$1$jscomp$inline_14510_near_match$jscomp$1_with_context_QMARK_$jscomp$inline_14512$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1385_JSCompiler_temp$jscomp$inline_14518_map__51819__$1$jscomp$inline_14510_near_match$jscomp$1_with_context_QMARK_$jscomp$inline_14512$$,$cljs$cst$2591$with_context_QMARK_$$,!1);var $G__51820$jscomp$inline_14519_near_match_id$jscomp$inline_14517_parent_shape$jscomp$inline_14513_shape_index$jscomp$inline_14516$$=$app$common$types$shape_tree$get_shape$$($page$jscomp$135$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$879$$));
$libraries$jscomp$111_or__5025__auto__$jscomp$inline_7725_parent_ref_shape$jscomp$inline_14514$$=$APP.$cljs$core$truth_$$($G__51820$jscomp$inline_14519_near_match_id$jscomp$inline_14517_parent_shape$jscomp$inline_14513_shape_index$jscomp$inline_14516$$)?$app$common$types$file$find_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($file$jscomp$119$$,$page$jscomp$135$$,$libraries$jscomp$111_or__5025__auto__$jscomp$inline_7725_parent_ref_shape$jscomp$inline_14514$$,$G__51820$jscomp$inline_14519_near_match_id$jscomp$inline_14517_parent_shape$jscomp$inline_14513_shape_index$jscomp$inline_14516$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2540$include_deleted_QMARK_$$,$include_deleted_QMARK_$jscomp$inline_14511_ref_container$jscomp$inline_14515$$,$cljs$cst$2591$with_context_QMARK_$$,!0])):null;$include_deleted_QMARK_$jscomp$inline_14511_ref_container$jscomp$inline_14515$$=$APP.$cljs$core$truth_$$($libraries$jscomp$111_or__5025__auto__$jscomp$inline_7725_parent_ref_shape$jscomp$inline_14514$$)?$APP.$cljs$cst$2588$container$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($libraries$jscomp$111_or__5025__auto__$jscomp$inline_7725_parent_ref_shape$jscomp$inline_14514$$)):
null;$G__51820$jscomp$inline_14519_near_match_id$jscomp$inline_14517_parent_shape$jscomp$inline_14513_shape_index$jscomp$inline_14516$$=$APP.$cljs$core$truth_$$($G__51820$jscomp$inline_14519_near_match_id$jscomp$inline_14517_parent_shape$jscomp$inline_14513_shape_index$jscomp$inline_14516$$)?$APP.$app$common$data$index_of$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($G__51820$jscomp$inline_14519_near_match_id$jscomp$inline_14517_parent_shape$jscomp$inline_14513_shape_index$jscomp$inline_14516$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$879$$)):null;$G__51820$jscomp$inline_14519_near_match_id$jscomp$inline_14517_parent_shape$jscomp$inline_14513_shape_index$jscomp$inline_14516$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($libraries$jscomp$111_or__5025__auto__$jscomp$inline_7725_parent_ref_shape$jscomp$inline_14514$$)?$G__51820$jscomp$inline_14519_near_match_id$jscomp$inline_14517_parent_shape$jscomp$inline_14513_shape_index$jscomp$inline_14516$$:$libraries$jscomp$111_or__5025__auto__$jscomp$inline_7725_parent_ref_shape$jscomp$inline_14514$$)?
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($libraries$jscomp$111_or__5025__auto__$jscomp$inline_7725_parent_ref_shape$jscomp$inline_14514$$),$G__51820$jscomp$inline_14519_near_match_id$jscomp$inline_14517_parent_shape$jscomp$inline_14513_shape_index$jscomp$inline_14516$$):null;$APP.$cljs$core$truth_$$($G__51820$jscomp$inline_14519_near_match_id$jscomp$inline_14517_parent_shape$jscomp$inline_14513_shape_index$jscomp$inline_14516$$)?
($G__51820$jscomp$inline_14519_near_match_id$jscomp$inline_14517_parent_shape$jscomp$inline_14513_shape_index$jscomp$inline_14516$$=$app$common$types$shape_tree$get_shape$$($include_deleted_QMARK_$jscomp$inline_14511_ref_container$jscomp$inline_14515$$,$G__51820$jscomp$inline_14519_near_match_id$jscomp$inline_14517_parent_shape$jscomp$inline_14513_shape_index$jscomp$inline_14516$$),$JSCompiler_inline_result$jscomp$1385_JSCompiler_temp$jscomp$inline_14518_map__51819__$1$jscomp$inline_14510_near_match$jscomp$1_with_context_QMARK_$jscomp$inline_14512$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1385_JSCompiler_temp$jscomp$inline_14518_map__51819__$1$jscomp$inline_14510_near_match$jscomp$1_with_context_QMARK_$jscomp$inline_14512$$)?$APP.$cljs$core$with_meta$$($G__51820$jscomp$inline_14519_near_match_id$jscomp$inline_14517_parent_shape$jscomp$inline_14513_shape_index$jscomp$inline_14516$$,$APP.$cljs$core$meta$$($libraries$jscomp$111_or__5025__auto__$jscomp$inline_7725_parent_ref_shape$jscomp$inline_14514$$)):$G__51820$jscomp$inline_14519_near_match_id$jscomp$inline_14517_parent_shape$jscomp$inline_14513_shape_index$jscomp$inline_14516$$):
$JSCompiler_inline_result$jscomp$1385_JSCompiler_temp$jscomp$inline_14518_map__51819__$1$jscomp$inline_14510_near_match$jscomp$1_with_context_QMARK_$jscomp$inline_14512$$=null;$JSCompiler_inline_result$jscomp$1385_JSCompiler_temp$jscomp$inline_14518_map__51819__$1$jscomp$inline_14510_near_match$jscomp$1_with_context_QMARK_$jscomp$inline_14512$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$879$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1385_JSCompiler_temp$jscomp$inline_14518_map__51819__$1$jscomp$inline_14510_near_match$jscomp$1_with_context_QMARK_$jscomp$inline_14512$$))&&
($libraries$jscomp$111_or__5025__auto__$jscomp$inline_7725_parent_ref_shape$jscomp$inline_14514$$=$APP.$app$common$types$component$get_swap_slot$$($JSCompiler_inline_result$jscomp$1385_JSCompiler_temp$jscomp$inline_14518_map__51819__$1$jscomp$inline_14510_near_match$jscomp$1_with_context_QMARK_$jscomp$inline_14512$$),$JSCompiler_inline_result$jscomp$1385_JSCompiler_temp$jscomp$inline_14518_map__51819__$1$jscomp$inline_14510_near_match$jscomp$1_with_context_QMARK_$jscomp$inline_14512$$=$APP.$cljs$core$truth_$$($libraries$jscomp$111_or__5025__auto__$jscomp$inline_7725_parent_ref_shape$jscomp$inline_14514$$)?
$libraries$jscomp$111_or__5025__auto__$jscomp$inline_7725_parent_ref_shape$jscomp$inline_14514$$:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1385_JSCompiler_temp$jscomp$inline_14518_map__51819__$1$jscomp$inline_14510_near_match$jscomp$1_with_context_QMARK_$jscomp$inline_14512$$),$app$common$files$validate$report_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cljs$cst$5201$missing_slot$$,"Shape has been swapped, should have swap slot",$shape$jscomp$879$$,
$file$jscomp$119$$,$page$jscomp$135$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5202$swap_slot$$,$JSCompiler_inline_result$jscomp$1385_JSCompiler_temp$jscomp$inline_14518_map__51819__$1$jscomp$inline_14510_near_match$jscomp$1_with_context_QMARK_$jscomp$inline_14512$$])))}};
$app$common$files$validate$check_valid_touched$$=function($shape$jscomp$880$$,$file$jscomp$120$$,$page$jscomp$136$$){var $text_touched_QMARK__touched_groups$$=$app$common$types$component$normal_touched_groups$$($shape$jscomp$880$$),$content_touched_QMARK_$$=$text_touched_QMARK__touched_groups$$.$cljs$core$IFn$_invoke$arity$1$?$text_touched_QMARK__touched_groups$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$2070$content_group$$):$text_touched_QMARK__touched_groups$$($cljs$cst$2070$content_group$$);var $or__5025__auto__$jscomp$inline_13022_or__5025__auto____$1$jscomp$inline_13023$$=
$text_touched_QMARK__touched_groups$$.$cljs$core$IFn$_invoke$arity$1$?$text_touched_QMARK__touched_groups$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1774$text_content_text$$):$text_touched_QMARK__touched_groups$$($cljs$cst$1774$text_content_text$$);$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_13022_or__5025__auto____$1$jscomp$inline_13023$$)?$text_touched_QMARK__touched_groups$$=$or__5025__auto__$jscomp$inline_13022_or__5025__auto____$1$jscomp$inline_13023$$:($or__5025__auto__$jscomp$inline_13022_or__5025__auto____$1$jscomp$inline_13023$$=
$text_touched_QMARK__touched_groups$$.$cljs$core$IFn$_invoke$arity$1$?$text_touched_QMARK__touched_groups$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1775$text_content_attribute$$):$text_touched_QMARK__touched_groups$$($cljs$cst$1775$text_content_attribute$$),$text_touched_QMARK__touched_groups$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_13022_or__5025__auto____$1$jscomp$inline_13023$$)?$or__5025__auto__$jscomp$inline_13022_or__5025__auto____$1$jscomp$inline_13023$$:$text_touched_QMARK__touched_groups$$.$cljs$core$IFn$_invoke$arity$1$?
$text_touched_QMARK__touched_groups$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1773$text_content_structure$$):$text_touched_QMARK__touched_groups$$($cljs$cst$1773$text_content_structure$$));$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($text_touched_QMARK__touched_groups$$)?$APP.$cljs$core$not$$($content_touched_QMARK_$$):$text_touched_QMARK__touched_groups$$)&&$app$common$files$validate$report_error$$($cljs$cst$5197$invalid_text_touched$$,"This thape has text type touched but not content touched",
$shape$jscomp$880$$,$file$jscomp$120$$,$page$jscomp$136$$)};
$app$common$files$validate$check_shape_main_root_top$$=function($shape$jscomp$881$$,$file$jscomp$121$$,$page$jscomp$137$$,$libraries$jscomp$112$$){$app$common$files$validate$check_component_main_head$$($shape$jscomp$881$$,$file$jscomp$121$$,$page$jscomp$137$$,$libraries$jscomp$112$$);$app$common$files$validate$check_component_root$$($shape$jscomp$881$$,$file$jscomp$121$$,$page$jscomp$137$$);$app$common$files$validate$check_component_not_ref$$($shape$jscomp$881$$,$file$jscomp$121$$,$page$jscomp$137$$);
$app$common$files$validate$check_empty_swap_slot$$($shape$jscomp$881$$,$file$jscomp$121$$,$page$jscomp$137$$);$app$common$files$validate$check_duplicate_swap_slot$$($shape$jscomp$881$$,$file$jscomp$121$$,$page$jscomp$137$$);return $APP.$cljs$core$run_BANG_$$(function($p1__74007_SHARP_$$){return $app$common$files$validate$check_shape$$.$cljs$core$IFn$_invoke$arity$6$?$app$common$files$validate$check_shape$$.$cljs$core$IFn$_invoke$arity$6$($p1__74007_SHARP_$$,$file$jscomp$121$$,$page$jscomp$137$$,$libraries$jscomp$112$$,
$APP.$cljs$cst$2312$context$$,$cljs$cst$5212$main_top$$):$app$common$files$validate$check_shape$$($p1__74007_SHARP_$$,$file$jscomp$121$$,$page$jscomp$137$$,$libraries$jscomp$112$$,$APP.$cljs$cst$2312$context$$,$cljs$cst$5212$main_top$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$881$$))};
$app$common$files$validate$check_shape_main_root_nested$$=function($shape$jscomp$882$$,$file$jscomp$122$$,$page$jscomp$138$$,$libraries$jscomp$113$$){$app$common$files$validate$check_component_main_head$$($shape$jscomp$882$$,$file$jscomp$122$$,$page$jscomp$138$$,$libraries$jscomp$113$$);$app$common$files$validate$check_component_not_root$$($shape$jscomp$882$$,$file$jscomp$122$$,$page$jscomp$138$$);$app$common$files$validate$check_component_not_ref$$($shape$jscomp$882$$,$file$jscomp$122$$,$page$jscomp$138$$);
$app$common$files$validate$check_empty_swap_slot$$($shape$jscomp$882$$,$file$jscomp$122$$,$page$jscomp$138$$);return $APP.$cljs$core$run_BANG_$$(function($p1__74017_SHARP_$$){return $app$common$files$validate$check_shape$$.$cljs$core$IFn$_invoke$arity$6$?$app$common$files$validate$check_shape$$.$cljs$core$IFn$_invoke$arity$6$($p1__74017_SHARP_$$,$file$jscomp$122$$,$page$jscomp$138$$,$libraries$jscomp$113$$,$APP.$cljs$cst$2312$context$$,$cljs$cst$5213$main_nested$$):$app$common$files$validate$check_shape$$($p1__74017_SHARP_$$,
$file$jscomp$122$$,$page$jscomp$138$$,$libraries$jscomp$113$$,$APP.$cljs$cst$2312$context$$,$cljs$cst$5213$main_nested$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$882$$))};
$app$common$files$validate$check_shape_copy_root_top$$=function($shape$jscomp$883$$,$file$jscomp$123$$,$page$jscomp$139$$,$libraries$jscomp$114$$){var $library_exists$jscomp$2$$=$app$common$files$validate$library_exists_QMARK_$$($file$jscomp$123$$,$libraries$jscomp$114$$,$shape$jscomp$883$$);$app$common$files$validate$check_component_not_main_head$$($shape$jscomp$883$$,$file$jscomp$123$$,$page$jscomp$139$$,$libraries$jscomp$114$$);$app$common$files$validate$check_component_root$$($shape$jscomp$883$$,
$file$jscomp$123$$,$page$jscomp$139$$);$app$common$files$validate$check_component_ref$$($shape$jscomp$883$$,$file$jscomp$123$$,$page$jscomp$139$$,$libraries$jscomp$114$$);$app$common$files$validate$check_ref_is_head$$($shape$jscomp$883$$,$file$jscomp$123$$,$page$jscomp$139$$,$libraries$jscomp$114$$);$app$common$files$validate$check_empty_swap_slot$$($shape$jscomp$883$$,$file$jscomp$123$$,$page$jscomp$139$$);$app$common$files$validate$check_duplicate_swap_slot$$($shape$jscomp$883$$,$file$jscomp$123$$,
$page$jscomp$139$$);$app$common$files$validate$check_valid_touched$$($shape$jscomp$883$$,$file$jscomp$123$$,$page$jscomp$139$$);return $APP.$cljs$core$run_BANG_$$(function($p1__74020_SHARP_$$){return $app$common$files$validate$check_shape$$.$cljs$core$IFn$_invoke$arity$8$?$app$common$files$validate$check_shape$$.$cljs$core$IFn$_invoke$arity$8$($p1__74020_SHARP_$$,$file$jscomp$123$$,$page$jscomp$139$$,$libraries$jscomp$114$$,$APP.$cljs$cst$2312$context$$,$cljs$cst$5214$copy_top$$,$cljs$cst$5215$library_exists$$,
$library_exists$jscomp$2$$):$app$common$files$validate$check_shape$$($p1__74020_SHARP_$$,$file$jscomp$123$$,$page$jscomp$139$$,$libraries$jscomp$114$$,$APP.$cljs$cst$2312$context$$,$cljs$cst$5214$copy_top$$,$cljs$cst$5215$library_exists$$,$library_exists$jscomp$2$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$883$$))};
$app$common$files$validate$check_shape_copy_root_nested$$=function($shape$jscomp$884$$,$file$jscomp$124$$,$page$jscomp$140$$,$libraries$jscomp$115$$,$library_exists$jscomp$3$$){$app$common$files$validate$check_component_not_main_head$$($shape$jscomp$884$$,$file$jscomp$124$$,$page$jscomp$140$$,$libraries$jscomp$115$$);$app$common$files$validate$check_component_not_root$$($shape$jscomp$884$$,$file$jscomp$124$$,$page$jscomp$140$$);$app$common$files$validate$check_valid_touched$$($shape$jscomp$884$$,
$file$jscomp$124$$,$page$jscomp$140$$);$app$common$files$validate$check_ref_component_id$$($shape$jscomp$884$$,$file$jscomp$124$$,$page$jscomp$140$$,$libraries$jscomp$115$$);$app$common$files$validate$check_required_swap_slot$$($shape$jscomp$884$$,$file$jscomp$124$$,$page$jscomp$140$$,$libraries$jscomp$115$$);$APP.$cljs$core$truth_$$($library_exists$jscomp$3$$)&&($app$common$files$validate$check_component_ref$$($shape$jscomp$884$$,$file$jscomp$124$$,$page$jscomp$140$$,$libraries$jscomp$115$$),$app$common$files$validate$check_ref_is_head$$($shape$jscomp$884$$,
$file$jscomp$124$$,$page$jscomp$140$$,$libraries$jscomp$115$$));return $APP.$cljs$core$run_BANG_$$(function($p1__74025_SHARP_$$){return $app$common$files$validate$check_shape$$.$cljs$core$IFn$_invoke$arity$6$?$app$common$files$validate$check_shape$$.$cljs$core$IFn$_invoke$arity$6$($p1__74025_SHARP_$$,$file$jscomp$124$$,$page$jscomp$140$$,$libraries$jscomp$115$$,$APP.$cljs$cst$2312$context$$,$cljs$cst$5216$copy_nested$$):$app$common$files$validate$check_shape$$($p1__74025_SHARP_$$,$file$jscomp$124$$,
$page$jscomp$140$$,$libraries$jscomp$115$$,$APP.$cljs$cst$2312$context$$,$cljs$cst$5216$copy_nested$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$884$$))};
$app$common$files$validate$check_shape_main_not_root$$=function($shape$jscomp$885$$,$file$jscomp$125$$,$page$jscomp$141$$,$libraries$jscomp$116$$){$app$common$files$validate$check_component_not_main_not_head$$($shape$jscomp$885$$,$file$jscomp$125$$,$page$jscomp$141$$);$app$common$files$validate$check_component_not_root$$($shape$jscomp$885$$,$file$jscomp$125$$,$page$jscomp$141$$);$app$common$files$validate$check_component_not_ref$$($shape$jscomp$885$$,$file$jscomp$125$$,$page$jscomp$141$$);$app$common$files$validate$check_empty_swap_slot$$($shape$jscomp$885$$,
$file$jscomp$125$$,$page$jscomp$141$$);return $APP.$cljs$core$run_BANG_$$(function($p1__74036_SHARP_$$){return $app$common$files$validate$check_shape$$.$cljs$core$IFn$_invoke$arity$6$?$app$common$files$validate$check_shape$$.$cljs$core$IFn$_invoke$arity$6$($p1__74036_SHARP_$$,$file$jscomp$125$$,$page$jscomp$141$$,$libraries$jscomp$116$$,$APP.$cljs$cst$2312$context$$,$cljs$cst$5217$main_any$$):$app$common$files$validate$check_shape$$($p1__74036_SHARP_$$,$file$jscomp$125$$,$page$jscomp$141$$,$libraries$jscomp$116$$,
$APP.$cljs$cst$2312$context$$,$cljs$cst$5217$main_any$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$885$$))};
$app$common$files$validate$check_shape_copy_not_root$$=function($shape$jscomp$886$$,$file$jscomp$126$$,$page$jscomp$142$$,$libraries$jscomp$117$$){$app$common$files$validate$check_component_not_main_not_head$$($shape$jscomp$886$$,$file$jscomp$126$$,$page$jscomp$142$$);$app$common$files$validate$check_component_not_root$$($shape$jscomp$886$$,$file$jscomp$126$$,$page$jscomp$142$$);$app$common$files$validate$check_component_ref$$($shape$jscomp$886$$,$file$jscomp$126$$,$page$jscomp$142$$,$libraries$jscomp$117$$);
$app$common$files$validate$check_ref_is_not_head$$($shape$jscomp$886$$,$file$jscomp$126$$,$page$jscomp$142$$,$libraries$jscomp$117$$);$app$common$files$validate$check_empty_swap_slot$$($shape$jscomp$886$$,$file$jscomp$126$$,$page$jscomp$142$$);$app$common$files$validate$check_valid_touched$$($shape$jscomp$886$$,$file$jscomp$126$$,$page$jscomp$142$$);return $APP.$cljs$core$run_BANG_$$(function($p1__74038_SHARP_$$){return $app$common$files$validate$check_shape$$.$cljs$core$IFn$_invoke$arity$6$?$app$common$files$validate$check_shape$$.$cljs$core$IFn$_invoke$arity$6$($p1__74038_SHARP_$$,
$file$jscomp$126$$,$page$jscomp$142$$,$libraries$jscomp$117$$,$APP.$cljs$cst$2312$context$$,$cljs$cst$5218$copy_any$$):$app$common$files$validate$check_shape$$($p1__74038_SHARP_$$,$file$jscomp$126$$,$page$jscomp$142$$,$libraries$jscomp$117$$,$APP.$cljs$cst$2312$context$$,$cljs$cst$5218$copy_any$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$886$$))};
$app$common$files$validate$check_shape_not_component$$=function($shape$jscomp$887$$,$file$jscomp$127$$,$page$jscomp$143$$,$libraries$jscomp$118$$){$app$common$files$validate$check_component_not_main_not_head$$($shape$jscomp$887$$,$file$jscomp$127$$,$page$jscomp$143$$);$app$common$files$validate$check_component_not_root$$($shape$jscomp$887$$,$file$jscomp$127$$,$page$jscomp$143$$);$app$common$files$validate$check_component_not_ref$$($shape$jscomp$887$$,$file$jscomp$127$$,$page$jscomp$143$$);$app$common$files$validate$check_empty_swap_slot$$($shape$jscomp$887$$,
$file$jscomp$127$$,$page$jscomp$143$$);return $APP.$cljs$core$run_BANG_$$(function($p1__74046_SHARP_$$){return $app$common$files$validate$check_shape$$.$cljs$core$IFn$_invoke$arity$6$?$app$common$files$validate$check_shape$$.$cljs$core$IFn$_invoke$arity$6$($p1__74046_SHARP_$$,$file$jscomp$127$$,$page$jscomp$143$$,$libraries$jscomp$118$$,$APP.$cljs$cst$2312$context$$,$cljs$cst$5219$not_component$$):$app$common$files$validate$check_shape$$($p1__74046_SHARP_$$,$file$jscomp$127$$,$page$jscomp$143$$,$libraries$jscomp$118$$,
$APP.$cljs$cst$2312$context$$,$cljs$cst$5219$not_component$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$887$$))};
$app$common$files$validate$check_variant_container$$=function($shape$jscomp$888_shapes$jscomp$147$$,$file$jscomp$128$$,$page$jscomp$144$$){var $shape_id$jscomp$142$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$888_shapes$jscomp$147$$);$shape$jscomp$888_shapes$jscomp$147$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$888_shapes$jscomp$147$$);var $objects$jscomp$699$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$144$$),
$file_data$jscomp$113$$=$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$128$$),$first_child$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$699$$,$APP.$cljs$core$first$$($shape$jscomp$888_shapes$jscomp$147$$)),$prop_names$jscomp$2$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($file_data$jscomp$113$$,
$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($first_child$jscomp$1$$),!0)));$APP.$cljs$core$run_BANG_$$(function($child_id$jscomp$11_temp__5825__auto__$jscomp$293$$){$child_id$jscomp$11_temp__5825__auto__$jscomp$293$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$699$$,$child_id$jscomp$11_temp__5825__auto__$jscomp$293$$);return $APP.$cljs$core$truth_$$($child_id$jscomp$11_temp__5825__auto__$jscomp$293$$)?$APP.$app$common$types$component$is_variant_QMARK_$$($child_id$jscomp$11_temp__5825__auto__$jscomp$293$$)?
($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($child_id$jscomp$11_temp__5825__auto__$jscomp$293$$),$shape_id$jscomp$142$$)&&$app$common$files$validate$report_error$$($cljs$cst$5204$invalid_variant_id$$,"Variant "+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_id$jscomp$11_temp__5825__auto__$jscomp$293$$)??"")+" has invalid variant-id "+($APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($child_id$jscomp$11_temp__5825__auto__$jscomp$293$$)??
""),$child_id$jscomp$11_temp__5825__auto__$jscomp$293$$,$file$jscomp$128$$,$page$jscomp$144$$),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop_names$jscomp$2$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($file_data$jscomp$113$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($child_id$jscomp$11_temp__5825__auto__$jscomp$293$$),
!0))))?$app$common$files$validate$report_error$$($cljs$cst$5205$invalid_variant_properties$$,"Variant "+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_id$jscomp$11_temp__5825__auto__$jscomp$293$$)??"")+" has invalid properties "+($APP.$cljs$core$vec$$($prop_names$jscomp$2$$)??""),$child_id$jscomp$11_temp__5825__auto__$jscomp$293$$,$file$jscomp$128$$,$page$jscomp$144$$):null):$app$common$files$validate$report_error$$($cljs$cst$5203$not_a_variant$$,"Shape "+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_id$jscomp$11_temp__5825__auto__$jscomp$293$$)??
"")+" should be a variant",$child_id$jscomp$11_temp__5825__auto__$jscomp$293$$,$file$jscomp$128$$,$page$jscomp$144$$):null},$shape$jscomp$888_shapes$jscomp$147$$)};
$app$common$files$validate$check_variant$$=function($shape$jscomp$889$$,$file$jscomp$129$$,$page$jscomp$145$$){var $parent$jscomp$294$$=$app$common$types$shape_tree$get_shape$$($page$jscomp$145$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$889$$)),$component$jscomp$108$$=$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$129$$),$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$889$$),
!0),$name$jscomp$420$$=$APP.$app$common$types$variant$properties_to_name$$($APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$108$$));$APP.$app$common$types$component$main_instance_QMARK_$$($shape$jscomp$889$$)||$app$common$files$validate$report_error$$($cljs$cst$5206$variant_not_main$$,"Variant "+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$889$$)??"")+" is not a main instance",$shape$jscomp$889$$,$file$jscomp$129$$,$page$jscomp$145$$);
$APP.$cljs$core$truth_$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($parent$jscomp$294$$))||$app$common$files$validate$report_error$$($cljs$cst$5207$parent_not_variant$$,"Variant "+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$889$$)??"")+" has an invalid parent",$shape$jscomp$889$$,$file$jscomp$129$$,$page$jscomp$145$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$420$$,$APP.$cljs$cst$2002$variant_name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$889$$))||
$app$common$files$validate$report_error$$($cljs$cst$5209$variant_bad_variant_name$$,"Variant "+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$889$$)??"")+" has an invalid variant-name",$shape$jscomp$889$$,$file$jscomp$129$$,$page$jscomp$145$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$294$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$889$$))||$app$common$files$validate$report_error$$($cljs$cst$5208$variant_bad_name$$,
"Variant "+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$889$$)??"")+" has an invalid name",$shape$jscomp$889$$,$file$jscomp$129$$,$page$jscomp$145$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$294$$),$APP.$app$common$path_names$merge_path_item$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$108$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$108$$)))||
$app$common$files$validate$report_error$$($cljs$cst$5210$variant_component_bad_name$$,"Component "+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$889$$)??"")+" has an invalid name",$shape$jscomp$889$$,$file$jscomp$129$$,$page$jscomp$145$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$108$$),$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$889$$))||$app$common$files$validate$report_error$$($cljs$cst$5211$variant_component_bad_id$$,
"Variant "+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$889$$)??"")+" has adifferent variant-id than its component",$shape$jscomp$889$$,$file$jscomp$129$$,$page$jscomp$145$$)};
$app$common$files$validate$check_shape$$=function($var_args$jscomp$1401$$){for(var $args__5755__auto__$jscomp$242$$=[],$len__5749__auto___74303$$=arguments.length,$i__5750__auto___74304$$=0;;)if($i__5750__auto___74304$$<$len__5749__auto___74303$$)$args__5755__auto__$jscomp$242$$.push(arguments[$i__5750__auto___74304$$]),$i__5750__auto___74304$$+=1;else break;return $app$common$files$validate$check_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],arguments[2],arguments[3],
4<$args__5755__auto__$jscomp$242$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$242$$.slice(4),0,null):null)};
$app$common$files$validate$check_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($in_main_QMARK__shape_id$jscomp$143$$,$file$jscomp$130$$,$page$jscomp$146$$,$libraries$jscomp$119$$,$library_exists$jscomp$4_map__74085__$1_p__74084$$){$library_exists$jscomp$4_map__74085__$1_p__74084$$=$APP.$cljs$core$__destructure_map$$($library_exists$jscomp$4_map__74085__$1_p__74084$$);var $context$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($library_exists$jscomp$4_map__74085__$1_p__74084$$,
$APP.$cljs$cst$2312$context$$,$cljs$cst$5219$not_component$$);$library_exists$jscomp$4_map__74085__$1_p__74084$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($library_exists$jscomp$4_map__74085__$1_p__74084$$,$cljs$cst$5215$library_exists$$,!1);var $shape$jscomp$890$$=$app$common$types$shape_tree$get_shape$$($page$jscomp$146$$,$in_main_QMARK__shape_id$jscomp$143$$);if($shape$jscomp$890$$!=null){$app$common$files$validate$check_geometry$$($shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$);
$app$common$files$validate$check_parent_children$$($shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$);$app$common$files$validate$check_frame$$($shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$);$APP.$cljs$core$truth_$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$890$$))&&$app$common$files$validate$check_variant_container$$($shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$);$APP.$app$common$types$component$is_variant_QMARK_$$($shape$jscomp$890$$)&&
$app$common$files$validate$check_variant$$($shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$);if($APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$890$$))return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$890$$))?$app$common$files$validate$report_error$$($cljs$cst$5194$instance_head_not_frame$$,"Instance head should be a frame",$shape$jscomp$890$$,$file$jscomp$130$$,
$page$jscomp$146$$):$APP.$app$common$types$component$instance_root_QMARK_$$($shape$jscomp$890$$)?$APP.$app$common$types$component$main_instance_QMARK_$$($shape$jscomp$890$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($context$jscomp$30$$,$cljs$cst$5219$not_component$$)?$app$common$files$validate$report_error$$($cljs$cst$5187$root_main_not_allowed$$,"Root main component not allowed inside other component",$shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$):$app$common$files$validate$check_shape_main_root_top$$($shape$jscomp$890$$,
$file$jscomp$130$$,$page$jscomp$146$$,$libraries$jscomp$119$$):$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($context$jscomp$30$$,$cljs$cst$5219$not_component$$)?$app$common$files$validate$report_error$$($cljs$cst$5189$root_copy_not_allowed$$,"Root copy component not allowed inside other component",$shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$):$app$common$files$validate$check_shape_copy_root_top$$($shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$,$libraries$jscomp$119$$):
$APP.$app$common$types$component$main_instance_QMARK_$$($shape$jscomp$890$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($context$jscomp$30$$,$cljs$cst$5219$not_component$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($context$jscomp$30$$,$cljs$cst$5212$main_top$$)?$app$common$files$validate$report_error$$($cljs$cst$5188$nested_main_not_allowed$$,"Component main not allowed inside other component",$shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$):$app$common$files$validate$check_shape_main_root_nested$$($shape$jscomp$890$$,
$file$jscomp$130$$,$page$jscomp$146$$,$libraries$jscomp$119$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($context$jscomp$30$$,$cljs$cst$5219$not_component$$)?$app$common$files$validate$report_error$$($cljs$cst$5190$nested_copy_not_allowed$$,"Nested copy component only allowed inside other component",$shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$):$app$common$files$validate$check_shape_copy_root_nested$$($shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$,$libraries$jscomp$119$$,
$library_exists$jscomp$4_map__74085__$1_p__74084$$);if($APP.$app$common$types$component$in_component_copy_QMARK_$$($shape$jscomp$890$$))return $APP.$cljs$core$not$$(function(){var $fexpr__74092$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5214$copy_top$$,null,$cljs$cst$5216$copy_nested$$,null,$cljs$cst$5218$copy_any$$,null],null),null);return $fexpr__74092$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__74092$$.$cljs$core$IFn$_invoke$arity$1$($context$jscomp$30$$):
$fexpr__74092$$($context$jscomp$30$$)}())?$app$common$files$validate$report_error$$($cljs$cst$5192$not_head_copy_not_allowed$$,"Non-root copy only allowed inside a copy",$shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$):$app$common$files$validate$check_shape_copy_not_root$$($shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$,$libraries$jscomp$119$$);$in_main_QMARK__shape_id$jscomp$143$$=function(){var $JSCompiler_temp$jscomp$10784_fexpr__74096$jscomp$inline_7727_objects$jscomp$inline_13025_or__5025__auto__$jscomp$978$$=
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5212$main_top$$,null,$cljs$cst$5217$main_any$$,null,$cljs$cst$5213$main_nested$$,null],null),null);$JSCompiler_temp$jscomp$10784_fexpr__74096$jscomp$inline_7727_objects$jscomp$inline_13025_or__5025__auto__$jscomp$978$$=$JSCompiler_temp$jscomp$10784_fexpr__74096$jscomp$inline_7727_objects$jscomp$inline_13025_or__5025__auto__$jscomp$978$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_temp$jscomp$10784_fexpr__74096$jscomp$inline_7727_objects$jscomp$inline_13025_or__5025__auto__$jscomp$978$$.$cljs$core$IFn$_invoke$arity$1$($context$jscomp$30$$):
$JSCompiler_temp$jscomp$10784_fexpr__74096$jscomp$inline_7727_objects$jscomp$inline_13025_or__5025__auto__$jscomp$978$$($context$jscomp$30$$);$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10784_fexpr__74096$jscomp$inline_7727_objects$jscomp$inline_13025_or__5025__auto__$jscomp$978$$)||($JSCompiler_temp$jscomp$10784_fexpr__74096$jscomp$inline_7727_objects$jscomp$inline_13025_or__5025__auto__$jscomp$978$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$146$$),$JSCompiler_temp$jscomp$10784_fexpr__74096$jscomp$inline_7727_objects$jscomp$inline_13025_or__5025__auto__$jscomp$978$$=
$APP.$app$common$types$container$find_component_main$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$10784_fexpr__74096$jscomp$inline_7727_objects$jscomp$inline_13025_or__5025__auto__$jscomp$978$$,$shape$jscomp$890$$,!0)!=null);return $JSCompiler_temp$jscomp$10784_fexpr__74096$jscomp$inline_7727_objects$jscomp$inline_13025_or__5025__auto__$jscomp$978$$}();return $APP.$cljs$core$truth_$$($in_main_QMARK__shape_id$jscomp$143$$)?$APP.$cljs$core$not$$(function(){var $fexpr__74099$$=new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5212$main_top$$,null,$cljs$cst$5217$main_any$$,null,$cljs$cst$5213$main_nested$$,null],null),null);return $fexpr__74099$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__74099$$.$cljs$core$IFn$_invoke$arity$1$($context$jscomp$30$$):$fexpr__74099$$($context$jscomp$30$$)}())?$app$common$files$validate$report_error$$($cljs$cst$5191$not_head_main_not_allowed$$,"Non-root main only allowed inside a main component",$shape$jscomp$890$$,$file$jscomp$130$$,
$page$jscomp$146$$):$app$common$files$validate$check_shape_main_not_root$$($shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$,$libraries$jscomp$119$$):$APP.$cljs$core$truth_$$(function(){var $fexpr__74100$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5212$main_top$$,null,$cljs$cst$5217$main_any$$,null,$cljs$cst$5213$main_nested$$,null],null),null);return $fexpr__74100$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__74100$$.$cljs$core$IFn$_invoke$arity$1$($context$jscomp$30$$):
$fexpr__74100$$($context$jscomp$30$$)}())?$app$common$files$validate$report_error$$($cljs$cst$5193$not_component_not_allowed$$,"Not compoments are not allowed inside a main",$shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$):$app$common$files$validate$check_shape_not_component$$($shape$jscomp$890$$,$file$jscomp$130$$,$page$jscomp$146$$,$libraries$jscomp$119$$)}return null};
$app$common$files$validate$check_ref_cycles$$=function($component$jscomp$110$$,$file$jscomp$132$$){var $cycles_ids$$=$APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce_kv$$(function($acc$jscomp$149$$,$id$jscomp$892$$,$shape$jscomp$892$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$892$$,$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$892$$))?$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$149$$,$id$jscomp$892$$):
$acc$jscomp$149$$},$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$110$$)));$APP.$cljs$core$seq$$($cycles_ids$$)&&$app$common$files$validate$report_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cljs$cst$5184$shape_ref_cycle$$,"This deleted component has shapes with shape-ref pointing to self",$component$jscomp$110$$,$file$jscomp$132$$,null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5185$cycles_ids$$,
$cycles_ids$$]))};
$app$common$files$validate$get_orphan_shapes$$=function($map__74138__$1_p__74137$$){$map__74138__$1_p__74137$$=$APP.$cljs$core$__destructure_map$$($map__74138__$1_p__74137$$);var $objects$jscomp$700$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74138__$1_p__74137$$,$APP.$cljs$cst$1631$objects$$);return $APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce_kv$$(function($result$jscomp$328$$,$id$jscomp$893$$,$shape$jscomp$893$$){return $APP.$app$common$files$helpers$root_QMARK_$$($shape$jscomp$893$$)||$APP.$cljs$core$contains_QMARK_$$($objects$jscomp$700$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$893$$))?$result$jscomp$328$$:$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$328$$,$id$jscomp$893$$)},$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$objects$jscomp$700$$))};
$app$common$files$validate$validate_file$$=function($data$jscomp$442_p__74147$$,$libraries$jscomp$120$$){var $map__74148__$1$$=$APP.$cljs$core$__destructure_map$$($data$jscomp$442_p__74147$$);$data$jscomp$442_p__74147$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74148__$1$$,$APP.$cljs$cst$142$data$$);var $_STAR_errors_STAR__orig_val__74153_features__$1$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74148__$1$$,$APP.$cljs$cst$227$features$$);if($APP.$cljs$core$contains_QMARK_$$($_STAR_errors_STAR__orig_val__74153_features__$1$jscomp$26$$,
"components/v2")){$_STAR_errors_STAR__orig_val__74153_features__$1$jscomp$26$$=$app$common$files$validate$_STAR_errors_STAR_$$;$app$common$files$validate$_STAR_errors_STAR_$$=$APP.$cljs$core$volatile_BANG_$$($APP.$cljs$core$PersistentVector$EMPTY$$);try{return $APP.$cljs$core$reduce_kv$$(function($_$jscomp$2869__STAR_ref_shape_cache_STAR__orig_val__74155$$,$_STAR_children_sets_STAR__orig_val__74156____$1$jscomp$2004$$,$page$jscomp$147$$){if($page$jscomp$147$$!=null){$_$jscomp$2869__STAR_ref_shape_cache_STAR__orig_val__74155$$=
$app$common$files$validate$_STAR_ref_shape_cache_STAR_$$;$_STAR_children_sets_STAR__orig_val__74156____$1$jscomp$2004$$=$app$common$files$validate$_STAR_children_sets_STAR_$$;var $_STAR_ref_shape_cache_STAR__temp_val__74157$$=$APP.$cljs$core$volatile_BANG_$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$_STAR_children_sets_STAR__temp_val__74158$$=$app$common$files$validate$build_children_sets$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$147$$));$app$common$files$validate$_STAR_ref_shape_cache_STAR_$$=
$_STAR_ref_shape_cache_STAR__temp_val__74157$$;$app$common$files$validate$_STAR_children_sets_STAR_$$=$_STAR_children_sets_STAR__temp_val__74158$$;try{return $app$common$files$validate$check_shape$$($APP.$app$common$uuid$zero$$,$map__74148__$1$$,$page$jscomp$147$$,$libraries$jscomp$120$$),$APP.$cljs$core$run_BANG_$$(function($p1__74142_SHARP_$$){return $app$common$files$validate$check_shape$$($p1__74142_SHARP_$$,$map__74148__$1$$,$page$jscomp$147$$,$libraries$jscomp$120$$)},$app$common$files$validate$get_orphan_shapes$$($page$jscomp$147$$))}finally{$app$common$files$validate$_STAR_children_sets_STAR_$$=
$_STAR_children_sets_STAR__orig_val__74156____$1$jscomp$2004$$,$app$common$files$validate$_STAR_ref_shape_cache_STAR_$$=$_$jscomp$2869__STAR_ref_shape_cache_STAR__orig_val__74155$$}}else return null},null,$APP.$cljs$cst$1630$pages_index$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$442_p__74147$$)),$APP.$cljs$core$reduce_kv$$(function($_$jscomp$2870_component_page$jscomp$inline_13030_component_page$jscomp$inline_13042_shape$jscomp$inline_13038$$,$___$1$jscomp$2005_main_instance$jscomp$inline_13031$$,
$JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$){$APP.$cljs$core$contains_QMARK_$$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$,$APP.$cljs$cst$1631$objects$$)&&$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$)==null&&$app$common$files$validate$report_error$$($cljs$cst$5195$component_nil_objects_not_allowed$$,"Objects list cannot be nil",
$JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$,$map__74148__$1$$,null);$APP.$cljs$core$truth_$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$))||($_$jscomp$2870_component_page$jscomp$inline_13030_component_page$jscomp$inline_13042_shape$jscomp$inline_13038$$=$APP.$app$common$types$file$get_component_page$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($map__74148__$1$$),
$JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$),$___$1$jscomp$2005_main_instance$jscomp$inline_13031$$=$app$common$types$shape_tree$get_shape$$($_$jscomp$2870_component_page$jscomp$inline_13030_component_page$jscomp$inline_13042_shape$jscomp$inline_13038$$,$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$)),$APP.$cljs$core$boolean$0$$($APP.$cljs$core$some$$($APP.$app$common$types$component$main_instance_QMARK_$$,
$APP.$app$common$files$helpers$get_parents$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2870_component_page$jscomp$inline_13030_component_page$jscomp$inline_13042_shape$jscomp$inline_13038$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($___$1$jscomp$2005_main_instance$jscomp$inline_13031$$))))&&$app$common$files$validate$report_error$$($cljs$cst$5188$nested_main_not_allowed$$,"Component main not allowed inside other component",$___$1$jscomp$2005_main_instance$jscomp$inline_13031$$,
$map__74148__$1$$,$_$jscomp$2870_component_page$jscomp$inline_13030_component_page$jscomp$inline_13042_shape$jscomp$inline_13038$$),$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$))&&$app$common$files$validate$report_error$$($cljs$cst$5196$non_deleted_component_cannot_have_objects$$,"A non-deleted component cannot have shapes inside",$JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$,
$map__74148__$1$$,null));$APP.$cljs$core$truth_$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$))&&($_$jscomp$2870_component_page$jscomp$inline_13030_component_page$jscomp$inline_13042_shape$jscomp$inline_13038$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$objects$$,$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$)],null)),$app$common$files$validate$has_duplicate_swap_slot_QMARK_$$($_$jscomp$2870_component_page$jscomp$inline_13030_component_page$jscomp$inline_13042_shape$jscomp$inline_13038$$,$JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$)&&
$app$common$files$validate$report_error$$($cljs$cst$5200$component_duplicate_slot$$,"This deleted component has children with the same swap slot",$JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$,$map__74148__$1$$,null),$app$common$files$validate$check_ref_cycles$$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$,$map__74148__$1$$));$APP.$app$common$types$component$is_variant_QMARK_$$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$)?
($_$jscomp$2870_component_page$jscomp$inline_13030_component_page$jscomp$inline_13042_shape$jscomp$inline_13038$$=$APP.$app$common$types$file$get_component_page$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($map__74148__$1$$),$JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$),$JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$))?
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$,$APP.$cljs$cst$1631$objects$$),$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$)):$app$common$types$shape_tree$get_shape$$($_$jscomp$2870_component_page$jscomp$inline_13030_component_page$jscomp$inline_13042_shape$jscomp$inline_13038$$,
$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$)),$JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$)?!$APP.$app$common$types$component$is_variant_QMARK_$$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$):
$JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$)?$app$common$files$validate$report_error$$($cljs$cst$5203$not_a_variant$$,"Shape "+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$)??"")+" should be a variant",$JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$,$map__74148__$1$$,$_$jscomp$2870_component_page$jscomp$inline_13030_component_page$jscomp$inline_13042_shape$jscomp$inline_13038$$):
null):$JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$=null;return $JSCompiler_temp$jscomp$10923_component$jscomp$115_main_component$jscomp$inline_13043$$},null,$APP.$cljs$cst$1638$components$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$442_p__74147$$)),$APP.$cljs$core$not_empty$$($APP.$cljs$core$_deref$$($app$common$files$validate$_STAR_errors_STAR_$$))}finally{$app$common$files$validate$_STAR_errors_STAR_$$=$_STAR_errors_STAR__orig_val__74153_features__$1$jscomp$26$$}}else return null};
$app$main$data$viewer$set_interactions_mode$$=function($mode$jscomp$40$$){typeof $app$main$data$viewer$set_interactions_mode_74230$$==="undefined"&&($app$main$data$viewer$set_interactions_mode_74230$$=function($mode$jscomp$41$$,$meta74231$$){this.mode=$mode$jscomp$41$$;this.$meta74231$=$meta74231$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$set_interactions_mode_74230$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$viewer$set_interactions_mode_74230$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5269$app_DOT_main_DOT_data_DOT_viewer_SLASH_set_interactions_mode$$},$app$main$data$viewer$set_interactions_mode_74230$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74232$$,$meta74231__$1$$){return new $app$main$data$viewer$set_interactions_mode_74230$$(this.mode,$meta74231__$1$$)},$app$main$data$viewer$set_interactions_mode_74230$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta74231$},$app$main$data$viewer$set_interactions_mode_74230$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$set_interactions_mode_74230$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2905$$,$state$jscomp$1117$$){var $self__$jscomp$7185$$=this;return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$1117$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$5231$interactions_mode$$],null),$self__$jscomp$7185$$.mode),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$cljs$cst$5232$show_interactions$$],null),function(){var $G__74239_G__74239__$1$$=$self__$jscomp$7185$$.mode;$G__74239_G__74239__$1$$=$G__74239_G__74239__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__74239_G__74239__$1$$.$fqn$:null;switch($G__74239_G__74239__$1$$){case "hide":return!1;
case "show":return!0;case "show-on-click":return!1;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__74239_G__74239__$1$$)].join(""));}}())},$app$main$data$viewer$set_interactions_mode_74230$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$set_interactions_mode_74230$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2906_params$jscomp$391$$,$state$jscomp$1118$$){$_$jscomp$2906_params$jscomp$391$$=
$APP.$app$main$router$get_params$$($state$jscomp$1118$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1592$viewer$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$2906_params$jscomp$391$$,$APP.$cljs$cst$5231$interactions_mode$$,this.mode)))});return new $app$main$data$viewer$set_interactions_mode_74230$$($mode$jscomp$40$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$flash_interactions$$=function(){typeof $app$main$data$viewer$flash_interactions_74253$$==="undefined"&&($app$main$data$viewer$flash_interactions_74253$$=function($meta74254$$){this.$meta74254$=$meta74254$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$flash_interactions_74253$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$flash_interactions_74253$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5270$app_DOT_main_DOT_data_DOT_viewer_SLASH_flash_interactions$$},$app$main$data$viewer$flash_interactions_74253$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74255$$,$meta74254__$1$$){return new $app$main$data$viewer$flash_interactions_74253$$($meta74254__$1$$)},$app$main$data$viewer$flash_interactions_74253$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74254$},$app$main$data$viewer$flash_interactions_74253$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$flash_interactions_74253$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2907$$,$state$jscomp$1119$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$1119$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$cljs$cst$5232$show_interactions$$],null),!0)},$app$main$data$viewer$flash_interactions_74253$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$flash_interactions_74253$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2908_stopper$jscomp$40$$,$___$1$jscomp$2040$$,$stream$jscomp$102$$){$_$jscomp$2908_stopper$jscomp$40$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$5270$app_DOT_main_DOT_data_DOT_viewer_SLASH_flash_interactions$$),$stream$jscomp$102$$);return $APP.$beicon$v2$core$take_until$$($_$jscomp$2908_stopper$jscomp$40$$,
$APP.$beicon$v2$core$delay$$(500,(0,$APP.$beicon$v2$core$of$$)($app$main$data$viewer$flash_done$$)))});return new $app$main$data$viewer$flash_interactions_74253$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$set_nav_scroll$$=function($scroll$jscomp$2$$){typeof $app$main$data$viewer$set_nav_scroll_74261$$==="undefined"&&($app$main$data$viewer$set_nav_scroll_74261$$=function($scroll$jscomp$3$$,$meta74262$$){this.scroll=$scroll$jscomp$3$$;this.$meta74262$=$meta74262$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$set_nav_scroll_74261$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$set_nav_scroll_74261$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5272$app_DOT_main_DOT_data_DOT_viewer_SLASH_set_nav_scroll$$},$app$main$data$viewer$set_nav_scroll_74261$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74263$$,$meta74262__$1$$){return new $app$main$data$viewer$set_nav_scroll_74261$$(this.scroll,$meta74262__$1$$)},$app$main$data$viewer$set_nav_scroll_74261$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74262$},$app$main$data$viewer$set_nav_scroll_74261$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$set_nav_scroll_74261$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2910$$,$state$jscomp$1121$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$1121$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$5273$nav_scroll$$],null),this.scroll)});return new $app$main$data$viewer$set_nav_scroll_74261$$($scroll$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$viewer$go_to_frame_by_index$$=function($index$jscomp$394$$){typeof $app$main$data$viewer$go_to_frame_by_index_74283$$==="undefined"&&($app$main$data$viewer$go_to_frame_by_index_74283$$=function($index$jscomp$395$$,$meta74284$$){this.index=$index$jscomp$395$$;this.$meta74284$=$meta74284$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$go_to_frame_by_index_74283$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$viewer$go_to_frame_by_index_74283$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5276$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_frame_by_index$$},$app$main$data$viewer$go_to_frame_by_index_74283$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74285$$,$meta74284__$1$$){return new $app$main$data$viewer$go_to_frame_by_index_74283$$(this.index,$meta74284__$1$$)},$app$main$data$viewer$go_to_frame_by_index_74283$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta74284$},$app$main$data$viewer$go_to_frame_by_index_74283$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_frame_by_index_74283$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2913$$,$state$jscomp$1124$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1124$$,$APP.$cljs$cst$2232$viewer_overlays$$,$APP.$cljs$core$PersistentVector$EMPTY$$)},$app$main$data$viewer$go_to_frame_by_index_74283$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_frame_by_index_74283$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2914_params$jscomp$392$$,$state$jscomp$1125$$){$_$jscomp$2914_params$jscomp$392$$=$APP.$app$main$router$get_params$$($state$jscomp$1125$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1592$viewer$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$2914_params$jscomp$392$$,
$APP.$cljs$cst$1795$index$$,this.index)))});return new $app$main$data$viewer$go_to_frame_by_index_74283$$($index$jscomp$394$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$01$$=function($frame_id$jscomp$118$$){return $APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($frame_id$jscomp$118$$,null)};
$APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$02$$=function($frame_id$jscomp$119$$,$animation$jscomp$2$$){typeof $app$main$data$viewer$go_to_frame_74300$$==="undefined"&&($app$main$data$viewer$go_to_frame_74300$$=function($frame_id$jscomp$120$$,$animation$jscomp$3$$,$meta74301$$){this.$frame_id$=$frame_id$jscomp$120$$;this.animation=$animation$jscomp$3$$;this.$meta74301$=$meta74301$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$viewer$go_to_frame_74300$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_frame_74300$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5277$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_frame$$},$app$main$data$viewer$go_to_frame_74300$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74302$$,$meta74301__$1$$){return new $app$main$data$viewer$go_to_frame_74300$$(this.$frame_id$,this.animation,
$meta74301__$1$$)},$app$main$data$viewer$go_to_frame_74300$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74301$},$app$main$data$viewer$go_to_frame_74300$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_frame_74300$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2915_frame$jscomp$46_index$jscomp$396_route$jscomp$11$$,$G__74309__$1_state$jscomp$1126$$){$_$jscomp$2915_frame$jscomp$46_index$jscomp$396_route$jscomp$11$$=
$APP.$cljs$cst$2171$route$$.$cljs$core$IFn$_invoke$arity$1$($G__74309__$1_state$jscomp$1126$$);var $qparams$jscomp$1$$=$APP.$cljs$cst$2269$query_params$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2915_frame$jscomp$46_index$jscomp$396_route$jscomp$11$$),$frames$jscomp$21_page_id$jscomp$395$$=function(){var $G__74307$$=$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($qparams$jscomp$1$$);return $G__74307$$==null?null:$APP.$app$common$uuid$parse$$($G__74307$$)}();$_$jscomp$2915_frame$jscomp$46_index$jscomp$396_route$jscomp$11$$=
function(){var $G__74308$$=$APP.$app$main$router$get_query_param$$($qparams$jscomp$1$$,$APP.$cljs$cst$1795$index$$);return $G__74308$$==null?null:$APP.$cljs$core$parse_long$$($G__74308$$)}();$frames$jscomp$21_page_id$jscomp$395$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($G__74309__$1_state$jscomp$1126$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$2228$pages$$,$frames$jscomp$21_page_id$jscomp$395$$,
$APP.$cljs$cst$5241$frames$$],null));$_$jscomp$2915_frame$jscomp$46_index$jscomp$396_route$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frames$jscomp$21_page_id$jscomp$395$$,$_$jscomp$2915_frame$jscomp$46_index$jscomp$396_route$jscomp$11$$);$G__74309__$1_state$jscomp$1126$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__74309__$1_state$jscomp$1126$$,$APP.$cljs$cst$2232$viewer_overlays$$,$APP.$cljs$core$PersistentVector$EMPTY$$);return this.animation!=null?$APP.$cljs$core$assoc_in$$($G__74309__$1_state$jscomp$1126$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5266$viewer_animations$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2915_frame$jscomp$46_index$jscomp$396_route$jscomp$11$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$947$kind$$,$APP.$cljs$cst$5278$go_to_frame$$,$APP.$cljs$cst$5279$orig_frame_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2915_frame$jscomp$46_index$jscomp$396_route$jscomp$11$$),
$APP.$cljs$cst$1969$animation$$,this.animation],null)):$G__74309__$1_state$jscomp$1126$$},$app$main$data$viewer$go_to_frame_74300$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_frame_74300$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2916_page_id$jscomp$396_route$jscomp$12$$,$frames$jscomp$22_index$jscomp$397_state$jscomp$1127$$){var $self__$jscomp$7217$$=this;$_$jscomp$2916_page_id$jscomp$396_route$jscomp$12$$=$APP.$cljs$cst$2171$route$$.$cljs$core$IFn$_invoke$arity$1$($frames$jscomp$22_index$jscomp$397_state$jscomp$1127$$);
var $qparams$jscomp$2$$=$APP.$cljs$cst$2269$query_params$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2916_page_id$jscomp$396_route$jscomp$12$$);$_$jscomp$2916_page_id$jscomp$396_route$jscomp$12$$=function(){var $G__74311$$=$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($qparams$jscomp$2$$);return $G__74311$$==null?null:$APP.$app$common$uuid$parse$$($G__74311$$)}();$frames$jscomp$22_index$jscomp$397_state$jscomp$1127$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($frames$jscomp$22_index$jscomp$397_state$jscomp$1127$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$2228$pages$$,$_$jscomp$2916_page_id$jscomp$396_route$jscomp$12$$,$APP.$cljs$cst$5241$frames$$],null));$frames$jscomp$22_index$jscomp$397_state$jscomp$1127$$=$APP.$app$common$data$index_of_pred$$($frames$jscomp$22_index$jscomp$397_state$jscomp$1127$$,function($p1__74291_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__74291_SHARP_$$),
$self__$jscomp$7217$$.$frame_id$)});return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$viewer$go_to_frame_by_index$$($APP.$cljs$core$truth_$$($frames$jscomp$22_index$jscomp$397_state$jscomp$1127$$)?$frames$jscomp$22_index$jscomp$397_state$jscomp$1127$$:0))});return new $app$main$data$viewer$go_to_frame_74300$$($frame_id$jscomp$119$$,$animation$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$viewer$go_to_section$$=function($section$jscomp$17$$){typeof $app$main$data$viewer$go_to_section_74318$$==="undefined"&&($app$main$data$viewer$go_to_section_74318$$=function($section$jscomp$18$$,$meta74319$$){this.section=$section$jscomp$18$$;this.$meta74319$=$meta74319$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$go_to_section_74318$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$viewer$go_to_section_74318$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5281$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_section$$},$app$main$data$viewer$go_to_section_74318$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74320$$,$meta74319__$1$$){return new $app$main$data$viewer$go_to_section_74318$$(this.section,$meta74319__$1$$)},$app$main$data$viewer$go_to_section_74318$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74319$},
$app$main$data$viewer$go_to_section_74318$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_section_74318$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"viewer",$APP.$cljs$cst$1366$section$$,$APP.$cljs$core$name$$(this.section)],null)},$app$main$data$viewer$go_to_section_74318$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_section_74318$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2919$$,$state$jscomp$1129$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1129$$,$APP.$cljs$cst$2232$viewer_overlays$$,$APP.$cljs$core$PersistentVector$EMPTY$$)},$app$main$data$viewer$go_to_section_74318$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_section_74318$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2920_params$jscomp$393$$,$state$jscomp$1130$$){$_$jscomp$2920_params$jscomp$393$$=$APP.$app$main$router$get_params$$($state$jscomp$1130$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1592$viewer$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$2920_params$jscomp$393$$,$APP.$cljs$cst$1366$section$$,this.section)))});return new $app$main$data$viewer$go_to_section_74318$$($section$jscomp$17$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$open_overlay_STAR_$$=function($G__74327__$1_state$jscomp$1131$$,$frame$jscomp$47$$,$position$jscomp$181$$,$snap_to$$,$close_click_outside$jscomp$1$$,$background_overlay$jscomp$1$$,$animation$jscomp$4$$,$fixed_source_QMARK_$$){$G__74327__$1_state$jscomp$1131$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__74327__$1_state$jscomp$1131$$,$APP.$cljs$cst$2232$viewer_overlays$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1606$frame$$,
$frame$jscomp$47$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$47$$),$APP.$cljs$cst$1676$position$$,$position$jscomp$181$$,$APP.$cljs$cst$5282$snap_to$$,$snap_to$$,$APP.$cljs$cst$1972$close_click_outside$$,$close_click_outside$jscomp$1$$,$APP.$cljs$cst$1973$background_overlay$$,$background_overlay$jscomp$1$$,$APP.$cljs$cst$1969$animation$$,$animation$jscomp$4$$,$APP.$cljs$cst$5283$fixed_source_QMARK_$$,$fixed_source_QMARK_$$],null));return $animation$jscomp$4$$!=
null?$APP.$cljs$core$assoc_in$$($G__74327__$1_state$jscomp$1131$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5266$viewer_animations$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$47$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$947$kind$$,$APP.$cljs$cst$1946$open_overlay$$,$APP.$cljs$cst$5284$overlay_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$47$$),
$APP.$cljs$cst$1969$animation$$,$animation$jscomp$4$$],null)):$G__74327__$1_state$jscomp$1131$$};
$app$main$data$viewer$close_overlay_STAR_$$=function($state$jscomp$1132$$,$frame_id$jscomp$122$$,$animation$jscomp$5$$){return $animation$jscomp$5$$==null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1132$$,$APP.$cljs$cst$2232$viewer_overlays$$,function($overlays$$){return $APP.$app$common$data$removev$$(function($p1__74328_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1606$frame$$.$cljs$core$IFn$_invoke$arity$1$($p1__74328_SHARP_$$)),$frame_id$jscomp$122$$)},
$overlays$$)}):$APP.$cljs$core$assoc_in$$($state$jscomp$1132$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5266$viewer_animations$$,$frame_id$jscomp$122$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$947$kind$$,$APP.$cljs$cst$1942$close_overlay$$,$APP.$cljs$cst$5284$overlay_id$$,$frame_id$jscomp$122$$,$APP.$cljs$cst$1969$animation$$,$animation$jscomp$5$$],null))};
$app$main$data$viewer$open_overlay$$=function($frame_id$jscomp$123$$,$position$jscomp$182$$,$snap_to$jscomp$1$$,$close_click_outside$jscomp$2$$,$background_overlay$jscomp$2$$,$animation$jscomp$6$$,$fixed_source_QMARK_$jscomp$1$$){typeof $app$main$data$viewer$open_overlay_74345$$==="undefined"&&($app$main$data$viewer$open_overlay_74345$$=function($frame_id$jscomp$124$$,$position$jscomp$183$$,$snap_to$jscomp$2$$,$close_click_outside$jscomp$3$$,$background_overlay$jscomp$3$$,$animation$jscomp$7$$,$fixed_source_QMARK_$jscomp$2$$,
$meta74346$$){this.$frame_id$=$frame_id$jscomp$124$$;this.position=$position$jscomp$183$$;this.$snap_to$=$snap_to$jscomp$2$$;this.$close_click_outside$=$close_click_outside$jscomp$3$$;this.$background_overlay$=$background_overlay$jscomp$3$$;this.animation=$animation$jscomp$7$$;this.$fixed_source_QMARK_$=$fixed_source_QMARK_$jscomp$2$$;this.$meta74346$=$meta74346$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$open_overlay_74345$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$open_overlay_74345$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5285$app_DOT_main_DOT_data_DOT_viewer_SLASH_open_overlay$$},$app$main$data$viewer$open_overlay_74345$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74347$$,$meta74346__$1$$){return new $app$main$data$viewer$open_overlay_74345$$(this.$frame_id$,this.position,this.$snap_to$,this.$close_click_outside$,this.$background_overlay$,this.animation,
this.$fixed_source_QMARK_$,$meta74346__$1$$)},$app$main$data$viewer$open_overlay_74345$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74346$},$app$main$data$viewer$open_overlay_74345$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$open_overlay_74345$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2921_frames$jscomp$23_overlays$jscomp$1_page_id$jscomp$398_route$jscomp$14$$,$state$jscomp$1133$$){var $self__$jscomp$7231$$=
this;$_$jscomp$2921_frames$jscomp$23_overlays$jscomp$1_page_id$jscomp$398_route$jscomp$14$$=$APP.$cljs$cst$2171$route$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1133$$);var $qparams$jscomp$4$$=$APP.$cljs$cst$2269$query_params$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2921_frames$jscomp$23_overlays$jscomp$1_page_id$jscomp$398_route$jscomp$14$$);$_$jscomp$2921_frames$jscomp$23_overlays$jscomp$1_page_id$jscomp$398_route$jscomp$14$$=function(){var $G__74380$$=$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($qparams$jscomp$4$$);
return $G__74380$$==null?null:$APP.$app$common$uuid$parse$$($G__74380$$)}();$_$jscomp$2921_frames$jscomp$23_overlays$jscomp$1_page_id$jscomp$398_route$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1133$$,$APP.$cljs$cst$1592$viewer$$),$APP.$cljs$cst$2228$pages$$),$_$jscomp$2921_frames$jscomp$23_overlays$jscomp$1_page_id$jscomp$398_route$jscomp$14$$),
$APP.$cljs$cst$5242$all_frames$$);var $frame$jscomp$48$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__74331_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__74331_SHARP_$$),$self__$jscomp$7231$$.$frame_id$)},$_$jscomp$2921_frames$jscomp$23_overlays$jscomp$1_page_id$jscomp$398_route$jscomp$14$$);$_$jscomp$2921_frames$jscomp$23_overlays$jscomp$1_page_id$jscomp$398_route$jscomp$14$$=$APP.$cljs$cst$2232$viewer_overlays$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1133$$);
return $APP.$cljs$core$not$$($APP.$cljs$core$some$$(function($p1__74332_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$.$cljs$core$IFn$_invoke$arity$1$($p1__74332_SHARP_$$),$frame$jscomp$48$$)},$_$jscomp$2921_frames$jscomp$23_overlays$jscomp$1_page_id$jscomp$398_route$jscomp$14$$))?$app$main$data$viewer$open_overlay_STAR_$$($state$jscomp$1133$$,$frame$jscomp$48$$,$self__$jscomp$7231$$.position,$self__$jscomp$7231$$.$snap_to$,$self__$jscomp$7231$$.$close_click_outside$,
$self__$jscomp$7231$$.$background_overlay$,$self__$jscomp$7231$$.animation,$self__$jscomp$7231$$.$fixed_source_QMARK_$):$state$jscomp$1133$$});return new $app$main$data$viewer$open_overlay_74345$$($frame_id$jscomp$123$$,$position$jscomp$182$$,$snap_to$jscomp$1$$,$close_click_outside$jscomp$2$$,$background_overlay$jscomp$2$$,$animation$jscomp$6$$,$fixed_source_QMARK_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$toggle_overlay$$=function($frame_id$jscomp$125$$,$position$jscomp$184$$,$snap_to$jscomp$3$$,$close_click_outside$jscomp$4$$,$background_overlay$jscomp$4$$,$animation$jscomp$8$$,$fixed_source_QMARK_$jscomp$3$$){typeof $app$main$data$viewer$toggle_overlay_74419$$==="undefined"&&($app$main$data$viewer$toggle_overlay_74419$$=function($frame_id$jscomp$126$$,$position$jscomp$185$$,$snap_to$jscomp$4$$,$close_click_outside$jscomp$5$$,$background_overlay$jscomp$5$$,$animation$jscomp$9$$,
$fixed_source_QMARK_$jscomp$4$$,$meta74420$$){this.$frame_id$=$frame_id$jscomp$126$$;this.position=$position$jscomp$185$$;this.$snap_to$=$snap_to$jscomp$4$$;this.$close_click_outside$=$close_click_outside$jscomp$5$$;this.$background_overlay$=$background_overlay$jscomp$5$$;this.animation=$animation$jscomp$9$$;this.$fixed_source_QMARK_$=$fixed_source_QMARK_$jscomp$4$$;this.$meta74420$=$meta74420$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$toggle_overlay_74419$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$toggle_overlay_74419$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5286$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_overlay$$},$app$main$data$viewer$toggle_overlay_74419$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74421$$,$meta74420__$1$$){return new $app$main$data$viewer$toggle_overlay_74419$$(this.$frame_id$,this.position,this.$snap_to$,this.$close_click_outside$,this.$background_overlay$,
this.animation,this.$fixed_source_QMARK_$,$meta74420__$1$$)},$app$main$data$viewer$toggle_overlay_74419$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74420$},$app$main$data$viewer$toggle_overlay_74419$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$toggle_overlay_74419$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2922_frames$jscomp$24_overlays$jscomp$2_page_id$jscomp$399_route$jscomp$15$$,$state$jscomp$1134$$){var $self__$jscomp$7235$$=
this;$_$jscomp$2922_frames$jscomp$24_overlays$jscomp$2_page_id$jscomp$399_route$jscomp$15$$=$APP.$cljs$cst$2171$route$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1134$$);var $qparams$jscomp$5$$=$APP.$cljs$cst$2269$query_params$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2922_frames$jscomp$24_overlays$jscomp$2_page_id$jscomp$399_route$jscomp$15$$);$_$jscomp$2922_frames$jscomp$24_overlays$jscomp$2_page_id$jscomp$399_route$jscomp$15$$=function(){var $G__74451$$=$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($qparams$jscomp$5$$);
return $G__74451$$==null?null:$APP.$app$common$uuid$parse$$($G__74451$$)}();$_$jscomp$2922_frames$jscomp$24_overlays$jscomp$2_page_id$jscomp$399_route$jscomp$15$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1134$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$2228$pages$$,$_$jscomp$2922_frames$jscomp$24_overlays$jscomp$2_page_id$jscomp$399_route$jscomp$15$$,$APP.$cljs$cst$5242$all_frames$$],
null));var $frame$jscomp$49$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__74402_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__74402_SHARP_$$),$self__$jscomp$7235$$.$frame_id$)},$_$jscomp$2922_frames$jscomp$24_overlays$jscomp$2_page_id$jscomp$399_route$jscomp$15$$);$_$jscomp$2922_frames$jscomp$24_overlays$jscomp$2_page_id$jscomp$399_route$jscomp$15$$=$APP.$cljs$cst$2232$viewer_overlays$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1134$$);
return $APP.$cljs$core$not$$($APP.$cljs$core$some$$(function($p1__74407_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$.$cljs$core$IFn$_invoke$arity$1$($p1__74407_SHARP_$$),$frame$jscomp$49$$)},$_$jscomp$2922_frames$jscomp$24_overlays$jscomp$2_page_id$jscomp$399_route$jscomp$15$$))?$app$main$data$viewer$open_overlay_STAR_$$($state$jscomp$1134$$,$frame$jscomp$49$$,$self__$jscomp$7235$$.position,$self__$jscomp$7235$$.$snap_to$,$self__$jscomp$7235$$.$close_click_outside$,
$self__$jscomp$7235$$.$background_overlay$,$self__$jscomp$7235$$.animation,$self__$jscomp$7235$$.$fixed_source_QMARK_$):$app$main$data$viewer$close_overlay_STAR_$$($state$jscomp$1134$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$49$$),$APP.$app$common$types$shape$interactions$invert_direction$$($self__$jscomp$7235$$.animation))});return new $app$main$data$viewer$toggle_overlay_74419$$($frame_id$jscomp$125$$,$position$jscomp$184$$,$snap_to$jscomp$3$$,$close_click_outside$jscomp$4$$,
$background_overlay$jscomp$4$$,$animation$jscomp$8$$,$fixed_source_QMARK_$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$=function($frame_id$jscomp$128$$,$animation$jscomp$10$$){typeof $app$main$data$viewer$close_overlay_74493$$==="undefined"&&($app$main$data$viewer$close_overlay_74493$$=function($frame_id$jscomp$129$$,$animation$jscomp$11$$,$meta74494$$){this.$frame_id$=$frame_id$jscomp$129$$;this.animation=$animation$jscomp$11$$;this.$meta74494$=$meta74494$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$viewer$close_overlay_74493$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$close_overlay_74493$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5287$app_DOT_main_DOT_data_DOT_viewer_SLASH_close_overlay$$},$app$main$data$viewer$close_overlay_74493$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74495$$,$meta74494__$1$$){return new $app$main$data$viewer$close_overlay_74493$$(this.$frame_id$,this.animation,
$meta74494__$1$$)},$app$main$data$viewer$close_overlay_74493$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74494$},$app$main$data$viewer$close_overlay_74493$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$close_overlay_74493$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2923$$,$state$jscomp$1135$$){return $app$main$data$viewer$close_overlay_STAR_$$($state$jscomp$1135$$,this.$frame_id$,this.animation)});
return new $app$main$data$viewer$close_overlay_74493$$($frame_id$jscomp$128$$,$animation$jscomp$10$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$select_all$$=function(){typeof $app$main$data$viewer$select_all_74645$$==="undefined"&&($app$main$data$viewer$select_all_74645$$=function($meta74646$$){this.$meta74646$=$meta74646$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$select_all_74645$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$select_all_74645$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5292$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_all$$},
$app$main$data$viewer$select_all_74645$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74647$$,$meta74646__$1$$){return new $app$main$data$viewer$select_all_74645$$($meta74646__$1$$)},$app$main$data$viewer$select_all_74645$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74646$},$app$main$data$viewer$select_all_74645$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$select_all_74645$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2928_page_id$jscomp$401_route$jscomp$17_selection$jscomp$13$$,$state$jscomp$1140$$){$_$jscomp$2928_page_id$jscomp$401_route$jscomp$17_selection$jscomp$13$$=$APP.$cljs$cst$2171$route$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1140$$);var $qparams$jscomp$7$$=$APP.$cljs$cst$2269$query_params$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2928_page_id$jscomp$401_route$jscomp$17_selection$jscomp$13$$);$_$jscomp$2928_page_id$jscomp$401_route$jscomp$17_selection$jscomp$13$$=function(){var $G__74665$$=
$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($qparams$jscomp$7$$);return $G__74665$$==null?null:$APP.$app$common$uuid$parse$$($G__74665$$)}();var $index$jscomp$398$$=function(){var $G__74666$$=$APP.$app$main$router$get_query_param$$($qparams$jscomp$7$$,$APP.$cljs$cst$1795$index$$);return $G__74666$$==null?null:$APP.$cljs$core$parse_long$$($G__74666$$)}(),$objects$jscomp$703$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1140$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$2228$pages$$,$_$jscomp$2928_page_id$jscomp$401_route$jscomp$17_selection$jscomp$13$$,$APP.$cljs$cst$1631$objects$$],null)),$frame_id$jscomp$130$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1140$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$2228$pages$$,$_$jscomp$2928_page_id$jscomp$401_route$jscomp$17_selection$jscomp$13$$,
$APP.$cljs$cst$5241$frames$$,$index$jscomp$398$$,$APP.$cljs$cst$266$id$$],null));$_$jscomp$2928_page_id$jscomp$401_route$jscomp$17_selection$jscomp$13$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$frame_id$jscomp$130$$]),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74639_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__74639_SHARP_$$)),
$frame_id$jscomp$130$$)},$objects$jscomp$703$$)));return $APP.$cljs$core$assoc_in$$($state$jscomp$1140$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$1921$selected$$],null),$_$jscomp$2928_page_id$jscomp$401_route$jscomp$17_selection$jscomp$13$$)});return new $app$main$data$viewer$select_all_74645$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$go_to_dashboard$$=function(){typeof $app$main$data$viewer$go_to_dashboard_74678$$==="undefined"&&($app$main$data$viewer$go_to_dashboard_74678$$=function($meta74679$$){this.$meta74679$=$meta74679$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$go_to_dashboard_74678$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_dashboard_74678$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5295$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_dashboard$$},$app$main$data$viewer$go_to_dashboard_74678$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74680$$,$meta74679__$1$$){return new $app$main$data$viewer$go_to_dashboard_74678$$($meta74679__$1$$)},$app$main$data$viewer$go_to_dashboard_74678$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74679$},$app$main$data$viewer$go_to_dashboard_74678$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_dashboard_74678$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2931_team_id$jscomp$131$$,$state$jscomp$1143$$){$_$jscomp$2931_team_id$jscomp$131$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1143$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$2230$project$$,$APP.$cljs$cst$1927$team_id$$],null));
return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,$_$jscomp$2931_team_id$jscomp$131$$])))});return new $app$main$data$viewer$go_to_dashboard_74678$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$go_to_page$$=function($page_id$jscomp$402$$){typeof $app$main$data$viewer$go_to_page_74682$$==="undefined"&&($app$main$data$viewer$go_to_page_74682$$=function($page_id$jscomp$403$$,$meta74683$$){this.$page_id$=$page_id$jscomp$403$$;this.$meta74683$=$meta74683$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$go_to_page_74682$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_page_74682$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5296$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_page$$},$app$main$data$viewer$go_to_page_74682$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74684$$,$meta74683__$1$$){return new $app$main$data$viewer$go_to_page_74682$$(this.$page_id$,$meta74683__$1$$)},$app$main$data$viewer$go_to_page_74682$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74683$},$app$main$data$viewer$go_to_page_74682$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$viewer$go_to_page_74682$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2932$$,$state$jscomp$1144$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$1144$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$cljs$cst$5297$overlays$$],null),$APP.$cljs$core$PersistentVector$EMPTY$$)},$app$main$data$viewer$go_to_page_74682$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$viewer$go_to_page_74682$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2933_params$jscomp$394$$,$state$jscomp$1145$$){$_$jscomp$2933_params$jscomp$394$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$router$get_params$$($state$jscomp$1145$$),$APP.$cljs$cst$1795$index$$,0),$APP.$cljs$cst$2043$page_id$$,this.$page_id$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$navigate$$($APP.$cljs$cst$1592$viewer$$,
$_$jscomp$2933_params$jscomp$394$$))});return new $app$main$data$viewer$go_to_page_74682$$($page_id$jscomp$402$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$01$$=function($page_id$jscomp$404$$){typeof $app$main$data$viewer$go_to_workspace_74687$$==="undefined"&&($app$main$data$viewer$go_to_workspace_74687$$=function($page_id$jscomp$405$$,$meta74688$$){this.$page_id$=$page_id$jscomp$405$$;this.$meta74688$=$meta74688$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$go_to_workspace_74687$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_workspace_74687$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5298$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_workspace$$},$app$main$data$viewer$go_to_workspace_74687$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74689$$,$meta74688__$1$$){return new $app$main$data$viewer$go_to_workspace_74687$$(this.$page_id$,$meta74688__$1$$)},$app$main$data$viewer$go_to_workspace_74687$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta74688$},$app$main$data$viewer$go_to_workspace_74687$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_workspace_74687$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2934_file_id$jscomp$350$$,$state$jscomp$1146_team_id$jscomp$132$$){var $G__74693$jscomp$inline_7868_page_id__$1$jscomp$22_params$jscomp$395$$=$APP.$app$main$router$get_params$$($state$jscomp$1146_team_id$jscomp$132$$);$_$jscomp$2934_file_id$jscomp$350$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1146_team_id$jscomp$132$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$266$id$$],null));$state$jscomp$1146_team_id$jscomp$132$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1146_team_id$jscomp$132$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$2230$project$$,$APP.$cljs$cst$1927$team_id$$],null));var $or__5025__auto__$jscomp$inline_7867$$=this.$page_id$;$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_7867$$)?$G__74693$jscomp$inline_7868_page_id__$1$jscomp$22_params$jscomp$395$$=$or__5025__auto__$jscomp$inline_7867$$:($G__74693$jscomp$inline_7868_page_id__$1$jscomp$22_params$jscomp$395$$=$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($G__74693$jscomp$inline_7868_page_id__$1$jscomp$22_params$jscomp$395$$),
$G__74693$jscomp$inline_7868_page_id__$1$jscomp$22_params$jscomp$395$$=$G__74693$jscomp$inline_7868_page_id__$1$jscomp$22_params$jscomp$395$$==null?null:$APP.$app$common$uuid$parse$$($G__74693$jscomp$inline_7868_page_id__$1$jscomp$22_params$jscomp$395$$));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2532$workspace$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2043$page_id$$,$G__74693$jscomp$inline_7868_page_id__$1$jscomp$22_params$jscomp$395$$,
$APP.$cljs$cst$1644$file_id$$,$_$jscomp$2934_file_id$jscomp$350$$,$APP.$cljs$cst$1927$team_id$$,$state$jscomp$1146_team_id$jscomp$132$$],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2456$app_DOT_main_DOT_router_SLASH_new_window$$,!0,$APP.$cljs$cst$2458$app_DOT_main_DOT_router_SLASH_window_name$$,"workspace-"+($_$jscomp$2934_file_id$jscomp$350$$??"")])))});return new $app$main$data$viewer$go_to_workspace_74687$$($page_id$jscomp$404$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$shortcuts$get_tooltip$$=function($shortcut$jscomp$5$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$viewer$shortcuts$shortcuts$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shortcut$jscomp$5$$,$APP.$cljs$cst$2946$tooltip$$],null))};
$app$main$data$workspace$path$shortcuts$esc_pressed$$=function(){typeof $app$main$data$workspace$path$shortcuts$esc_pressed_74132$$==="undefined"&&($app$main$data$workspace$path$shortcuts$esc_pressed_74132$$=function($meta74133$$){this.$meta74133$=$meta74133$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$shortcuts$esc_pressed_74132$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$shortcuts$esc_pressed_74132$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4214$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_shortcuts_SLASH_esc_pressed$$},$app$main$data$workspace$path$shortcuts$esc_pressed_74132$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74134$$,$meta74133__$1$$){return new $app$main$data$workspace$path$shortcuts$esc_pressed_74132$$($meta74133__$1$$)},$app$main$data$workspace$path$shortcuts$esc_pressed_74132$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74133$},$app$main$data$workspace$path$shortcuts$esc_pressed_74132$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$shortcuts$esc_pressed_74132$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2169$interrupt$$)});return new $app$main$data$workspace$path$shortcuts$esc_pressed_74132$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$debug$disable_BANG_$$=function($option$jscomp$13$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$debug$state$$,$APP.$cljs$core$disj$$,$option$jscomp$13$$);switch($option$jscomp$13$$ instanceof $APP.$cljs$core$Keyword$$?$option$jscomp$13$$.$fqn$:null){case "events":$app$main$store$_STAR_debug_events_STAR_$$=!1;break;case "events-times":$app$main$store$_STAR_debug_events_time_STAR_$$=!1}return $APP.$app$main$reinit$$()};
$debug$tap$$=function($effect_fn$jscomp$1$$){return function($rf$jscomp$26$$){return function(){function $G__74812__2$$($result$jscomp$332$$,$input$jscomp$68$$){$effect_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$effect_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($input$jscomp$68$$):$effect_fn$jscomp$1$$($input$jscomp$68$$);return $rf$jscomp$26$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$26$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$332$$,$input$jscomp$68$$):$rf$jscomp$26$$($result$jscomp$332$$,
$input$jscomp$68$$)}function $G__74812__1$$($result$jscomp$331$$){return $rf$jscomp$26$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$26$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$331$$):$rf$jscomp$26$$($result$jscomp$331$$)}function $G__74812__0$$(){return $rf$jscomp$26$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$26$$.$cljs$core$IFn$_invoke$arity$0$():$rf$jscomp$26$$()}var $G__74812$$=null;$G__74812$$=function($result$jscomp$333$$,$input$jscomp$69$$){switch(arguments.length){case 0:return $G__74812__0$$.call(this);
case 1:return $G__74812__1$$.call(this,$result$jscomp$333$$);case 2:return $G__74812__2$$.call(this,$result$jscomp$333$$,$input$jscomp$69$$)}throw Error("Invalid arity: "+arguments.length);};$G__74812$$.$cljs$core$IFn$_invoke$arity$0$=$G__74812__0$$;$G__74812$$.$cljs$core$IFn$_invoke$arity$1$=$G__74812__1$$;$G__74812$$.$cljs$core$IFn$_invoke$arity$2$=$G__74812__2$$;return $G__74812$$}()}};
$debug$wasm_read_len_prefixed_utf8$$=function($end$jscomp$93_ptr$jscomp$10$$){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($end$jscomp$93_ptr$jscomp$10$$)?$end$jscomp$93_ptr$jscomp$10$$!==0:$end$jscomp$93_ptr$jscomp$10$$)){var $heap_u8$jscomp$2_text$jscomp$68$$=$APP.$app$render_wasm$mem$get_heap_u8$$(),$start$jscomp$230$$=$end$jscomp$93_ptr$jscomp$10$$+4;$end$jscomp$93_ptr$jscomp$10$$=$start$jscomp$230$$+$APP.$app$render_wasm$mem$get_heap_u32$$()[$end$jscomp$93_ptr$jscomp$10$$>>2];$heap_u8$jscomp$2_text$jscomp$68$$=
(new TextDecoder("utf-8")).decode($heap_u8$jscomp$2_text$jscomp$68$$.subarray($start$jscomp$230$$,$end$jscomp$93_ptr$jscomp$10$$));$APP.$app$render_wasm$mem$free$$();return $heap_u8$jscomp$2_text$jscomp$68$$}return null};
$debug$get_object$$=function($state$jscomp$1148$$,$name$jscomp$424$$){var $objects$jscomp$705$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1148$$);return function(){var $or__5025__auto__$jscomp$985$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($shape$jscomp$896$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$424$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$896$$))},
$APP.$cljs$core$vals$$($objects$jscomp$705$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$985$$)?$or__5025__auto__$jscomp$985$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$705$$,$APP.$app$common$uuid$parse$$($name$jscomp$424$$))}()};$APP.$debug$dump_object$$=function($name$jscomp$425$$){return $APP.$cljs$core$clj__GT_js$$($debug$get_object$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$name$jscomp$425$$))};
$debug$get_selected$$=function(){var $state$jscomp$1149$$=$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$);return $APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$1149$$)};
$debug$dump_tree_SINGLEQUOTE_$cljs$0core$0IFn$0_invoke$0arity$04$$=function($libraries$jscomp$127_state$jscomp$1153$$,$show_ids$jscomp$7$$,$show_touched$jscomp$2$$,$show_modified$jscomp$1$$){var $page_id$jscomp$407$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$127_state$jscomp$1153$$,$APP.$cljs$cst$1918$current_page_id$$),$file$jscomp$147$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($libraries$jscomp$127_state$jscomp$1153$$);$libraries$jscomp$127_state$jscomp$1153$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$127_state$jscomp$1153$$,$APP.$cljs$cst$1916$files$$);return $app$common$types$file$dump_tree$$($file$jscomp$147$$,$page_id$jscomp$407$$,$libraries$jscomp$127_state$jscomp$1153$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$2593$show_ids$$,$show_ids$jscomp$7$$,$cljs$cst$2594$show_touched$$,$show_touched$jscomp$2$$,$cljs$cst$2595$show_modified$$,$show_modified$jscomp$1$$],null))};
$debug$apply_changes$$=function($changes$jscomp$326_changes_STAR_$$){var $file_id$jscomp$351$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));$changes$jscomp$326_changes_STAR_$$=$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$326_changes_STAR_$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$changes$commit_changes$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$3133$redo_changes$$,$changes$jscomp$326_changes_STAR_$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!0,$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$351$$],null)))};
$debug$modif__GT_js$$=function($modif_tree$jscomp$62$$,$objects$jscomp$710$$){return $APP.$cljs$core$clj__GT_js$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p__74787_v$jscomp$628$$){var $k$jscomp$670$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74787_v$jscomp$628$$,0,null);$p__74787_v$jscomp$628$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74787_v$jscomp$628$$,
1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$710$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$670$$,$APP.$cljs$cst$725$name$$],null)),$p__74787_v$jscomp$628$$],null)}),$modif_tree$jscomp$62$$))};
$debug$set_shape_ref_STAR_$$=function($id$jscomp$909$$,$shape_ref$$){typeof $debug$set_shape_ref_74799$$==="undefined"&&($debug$set_shape_ref_74799$$=function($id$jscomp$910$$,$shape_ref$jscomp$1$$,$meta74800$$){this.id=$id$jscomp$910$$;this.$shape_ref$=$shape_ref$jscomp$1$$;this.$meta74800$=$meta74800$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$debug$set_shape_ref_74799$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$debug$set_shape_ref_74799$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5322$debug_SLASH_set_shape_ref$$},$debug$set_shape_ref_74799$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74801$$,$meta74800__$1$$){return new $debug$set_shape_ref_74799$$(this.id,this.$shape_ref$,$meta74800__$1$$)},$debug$set_shape_ref_74799$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74800$},$debug$set_shape_ref_74799$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$debug$set_shape_ref_74799$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $shape_id$jscomp$156$$=$APP.$app$common$uuid$parse$$(this.id),$shape_ref__$1$$=$APP.$app$common$uuid$parse$$(this.$shape_ref$);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$update_shape$$($shape_id$jscomp$156$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2047$shape_ref$$,$shape_ref__$1$$],null)))});return new $debug$set_shape_ref_74799$$($id$jscomp$909$$,$shape_ref$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$workspace$sidebar$layer_name$layer_name_STAR_$$=function($depth$jscomp$15_props_74317$$){var $type_comp$$=$depth$jscomp$15_props_74317$$.typeComp,$is_blocked$$=$depth$jscomp$15_props_74317$$.isBlocked,$variant_id$jscomp$46$$=$depth$jscomp$15_props_74317$$.variantId,$type_frame$$=$depth$jscomp$15_props_74317$$.typeFrame,$default_value$jscomp$4_shape_name$jscomp$1$$=$depth$jscomp$15_props_74317$$.shapeName,$disabled_double_click$$=$depth$jscomp$15_props_74317$$.disabledDoubleClick,$is_shape_touched$$=
$depth$jscomp$15_props_74317$$.isShapeTouched,$has_path_QMARK__ref$jscomp$44$$=$depth$jscomp$15_props_74317$$.ref,$is_selected$$=$depth$jscomp$15_props_74317$$.isSelected,$on_start_edit$$=$depth$jscomp$15_props_74317$$.onStartEdit,$on_stop_edit$$=$depth$jscomp$15_props_74317$$.onStopEdit,$on_key_down$jscomp$7_variant_name$jscomp$3$$=$depth$jscomp$15_props_74317$$.variantName,$variant_properties$jscomp$4$$=$depth$jscomp$15_props_74317$$.variantProperties,$shape_id$jscomp$157$$=$depth$jscomp$15_props_74317$$.shapeId,
$variant_error$$=$depth$jscomp$15_props_74317$$.variantError,$rename_id$$=$depth$jscomp$15_props_74317$$.renameId,$on_tab_press$$=$depth$jscomp$15_props_74317$$.onTabPress,$is_hidden$jscomp$1$$=$depth$jscomp$15_props_74317$$.isHidden,$component_id$jscomp$89$$=$depth$jscomp$15_props_74317$$.componentId,$parent_size_parent_size__$1$$=$depth$jscomp$15_props_74317$$.parentSize;$depth$jscomp$15_props_74317$$=$depth$jscomp$15_props_74317$$.depth;var $edition_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$edition_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($edition_STAR_$$),$local_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(),$ref__$1$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($has_path_QMARK__ref$jscomp$44$$,$local_ref$jscomp$1$$),$shape_name__$1$$=$APP.$cljs$core$truth_$$($variant_id$jscomp$46$$)?$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($variant_error$$,$on_key_down$jscomp$7_variant_name$jscomp$3$$):$default_value$jscomp$4_shape_name$jscomp$1$$;$default_value$jscomp$4_shape_name$jscomp$1$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_id$jscomp$46$$),$APP.$rumext$v2$adapt$$($variant_error$$),$APP.$rumext$v2$adapt$$($variant_properties$jscomp$4$$),$APP.$rumext$v2$adapt$$($shape_name__$1$$)],function(){return $APP.$cljs$core$truth_$$($variant_id$jscomp$46$$)?$APP.$cljs$core$truth_$$($variant_error$$)?$variant_error$$:$app$common$types$variant$properties_map__GT_formula$$($variant_properties$jscomp$4$$):$shape_name__$1$$});$has_path_QMARK__ref$jscomp$44$$=
$APP.$cuerdas$core$includes_QMARK_$$($shape_name__$1$$,"/");var $start_edit$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disabled_double_click$$),$APP.$rumext$v2$adapt$$($on_start_edit$$),$APP.$rumext$v2$adapt$$($shape_id$jscomp$157$$),$APP.$rumext$v2$adapt$$($is_blocked$$)],function(){return $APP.$cljs$core$not$$($is_blocked$$)&&$APP.$cljs$core$not$$($disabled_double_click$$)?($on_start_edit$$.$cljs$core$IFn$_invoke$arity$0$?$on_start_edit$$.$cljs$core$IFn$_invoke$arity$0$():
$on_start_edit$$(),$APP.$cljs$core$reset_BANG_$$($edition_STAR_$$,!0),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$start_rename_shape$$($shape_id$jscomp$157$$))):null}),$accept_edit$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($edition_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($shape_id$jscomp$157$$),$APP.$rumext$v2$adapt$$($on_stop_edit$$),$APP.$rumext$v2$adapt$$($component_id$jscomp$89$$),$APP.$rumext$v2$adapt$$($variant_id$jscomp$46$$),
$APP.$rumext$v2$adapt$$($on_key_down$jscomp$7_variant_name$jscomp$3$$),$APP.$rumext$v2$adapt$$($variant_properties$jscomp$4$$)],function(){if($APP.$cljs$core$truth_$$($edition_QMARK_$jscomp$1$$)){var $name$jscomp$426$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_value$$($APP.$rumext$v2$ref_val$$($ref__$1$jscomp$1$$)));$on_stop_edit$$.$cljs$core$IFn$_invoke$arity$0$?$on_stop_edit$$.$cljs$core$IFn$_invoke$arity$0$():$on_stop_edit$$();$APP.$cljs$core$reset_BANG_$$($edition_STAR_$$,
!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$rename_shape_or_variant$cljs$0core$0IFn$0_invoke$0arity$04$$(null,null,$shape_id$jscomp$157$$,$name$jscomp$426$$))}return null}),$cancel_edit$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$157$$),$APP.$rumext$v2$adapt$$($on_stop_edit$$)],function(){$on_stop_edit$$.$cljs$core$IFn$_invoke$arity$0$?$on_stop_edit$$.$cljs$core$IFn$_invoke$arity$0$():
$on_stop_edit$$();$APP.$cljs$core$reset_BANG_$$($edition_STAR_$$,!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$end_rename_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_id$jscomp$157$$,null))});$on_key_down$jscomp$7_variant_name$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($edition_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($accept_edit$$),$APP.$rumext$v2$adapt$$($cancel_edit$$),$APP.$rumext$v2$adapt$$($on_tab_press$$),
$APP.$rumext$v2$adapt$$($shape_id$jscomp$157$$),$APP.$rumext$v2$adapt$$($on_stop_edit$$)],function($event$jscomp$205$$){$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$205$$))&&($accept_edit$$.$cljs$core$IFn$_invoke$arity$0$?$accept_edit$$.$cljs$core$IFn$_invoke$arity$0$():$accept_edit$$());$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$205$$))&&($cancel_edit$$.$cljs$core$IFn$_invoke$arity$0$?$cancel_edit$$.$cljs$core$IFn$_invoke$arity$0$():
$cancel_edit$$());if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$tab_QMARK_$$)($event$jscomp$205$$))&&($APP.$app$util$dom$prevent_default$$($event$jscomp$205$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$205$$),$APP.$cljs$core$truth_$$($edition_QMARK_$jscomp$1$$))){var $name$jscomp$427$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_value$$($APP.$rumext$v2$ref_val$$($ref__$1$jscomp$1$$)));$on_stop_edit$$.$cljs$core$IFn$_invoke$arity$0$?$on_stop_edit$$.$cljs$core$IFn$_invoke$arity$0$():
$on_stop_edit$$();$APP.$cljs$core$reset_BANG_$$($edition_STAR_$$,!1);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$end_rename_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_id$jscomp$157$$,$name$jscomp$427$$));return $APP.$cljs$core$fn_QMARK_$$($on_tab_press$$)?$on_tab_press$$.$cljs$core$IFn$_invoke$arity$1$?$on_tab_press$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$205$$):$on_tab_press$$($event$jscomp$205$$):null}return null});$parent_size_parent_size__$1$$=
""+($parent_size_parent_size__$1$$-110)+"px";$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($rename_id$$),$APP.$rumext$v2$adapt$$($edition_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($start_edit$$),$APP.$rumext$v2$adapt$$($shape_id$jscomp$157$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($rename_id$$,$shape_id$jscomp$157$$)&&!$edition_QMARK_$jscomp$1$$?$start_edit$$.$cljs$core$IFn$_invoke$arity$0$?$start_edit$$.$cljs$core$IFn$_invoke$arity$0$():
$start_edit$$():null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($edition_QMARK_$jscomp$1$$)],function(){if($APP.$cljs$core$truth_$$($edition_QMARK_$jscomp$1$$)){var $G__74329_74367$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$1$$);$G__74329_74367$$!=null&&$APP.$app$util$dom$select_text_BANG_$$($G__74329_74367$$)}return null});return $edition_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)("input",{className:"main_ui_workspace_sidebar_layer_name__element-name main_ui_workspace_sidebar_layer_name__element-name-input main_ui_workspace_sidebar_layer_name__selected",
id:"layer-name-"+($shape_id$jscomp$157$$??""),style:{"--depth":$depth$jscomp$15_props_74317$$,"--parent-size":$parent_size_parent_size__$1$$},onBlur:$accept_edit$$,type:"text",ref:$ref__$1$jscomp$1$$,defaultValue:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($default_value$jscomp$4_shape_name$jscomp$1$$,""),onKeyDown:$on_key_down$jscomp$7_variant_name$jscomp$3$$,autoFocus:!0}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("span",{id:"layer-name-"+
($shape_id$jscomp$157$$??""),style:{"--depth":$depth$jscomp$15_props_74317$$,"--parent-size":$parent_size_parent_size__$1$$},ref:$ref__$1$jscomp$1$$,onDoubleClick:$start_edit$$,className:"main_ui_workspace_sidebar_layer_name__element-name "+($APP.$cljs$core$truth_$$($has_path_QMARK__ref$jscomp$44$$)?"main_ui_workspace_sidebar_layer_name__left-ellipsis":"")+" "+($APP.$cljs$core$truth_$$($is_selected$$)?"main_ui_workspace_sidebar_layer_name__selected":"")+" "+($APP.$cljs$core$truth_$$($is_hidden$jscomp$1$$)?
"main_ui_workspace_sidebar_layer_name__hidden":"")+" "+($APP.$cljs$core$truth_$$($type_comp$$)?"main_ui_workspace_sidebar_layer_name__type-comp":"")+" "+($APP.$cljs$core$truth_$$($type_frame$$)?"main_ui_workspace_sidebar_layer_name__type-frame":""),children:$APP.$app$util$debug$enabled_QMARK_$$($cljs$cst$2593$show_ids$$)?""+($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($shape_name__$1$$,"")??"")+" | "+($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$157$$),
24)??""):$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($shape_name__$1$$,"")}),$APP.$app$util$debug$enabled_QMARK_$$($cljs$cst$2594$show_touched$$)&&$is_shape_touched$$?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layer_name__element-name-touched",children:"*"}):null]})};
$app$main$ui$workspace$sidebar$layer_item$schedule_sidebar_hover_flush$$=function(){return $APP.$cljs$core$compare_and_set_BANG_$$($app$main$ui$workspace$sidebar$layer_item$sidebar_hover_pending_QMARK_$$,!1,!0)?(0,$APP.$app$util$timers$request_animation_frame$$)(function(){var $enter$jscomp$2_enter__$1$jscomp$1_map__74711$$=$APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$layer_item$sidebar_hover_queue$$),$leave$jscomp$2_leave__$1$jscomp$1_leave__$2_map__74711__$1$$=$APP.$cljs$core$__destructure_map$$($enter$jscomp$2_enter__$1$jscomp$1_map__74711$$);
$enter$jscomp$2_enter__$1$jscomp$1_map__74711$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($leave$jscomp$2_leave__$1$jscomp$1_leave__$2_map__74711__$1$$,$APP.$cljs$cst$381$enter$$);$leave$jscomp$2_leave__$1$jscomp$1_leave__$2_map__74711__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($leave$jscomp$2_leave__$1$jscomp$1_leave__$2_map__74711__$1$$,$cljs$cst$382$leave$$);$enter$jscomp$2_enter__$1$jscomp$1_map__74711$$=$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($enter$jscomp$2_enter__$1$jscomp$1_map__74711$$,
$leave$jscomp$2_leave__$1$jscomp$1_leave__$2_map__74711__$1$$);$leave$jscomp$2_leave__$1$jscomp$1_leave__$2_map__74711__$1$$=$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($leave$jscomp$2_leave__$1$jscomp$1_leave__$2_map__74711__$1$$,$enter$jscomp$2_enter__$1$jscomp$1_map__74711$$);var $search_match$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$4298$search_match_highlight$$],null));$leave$jscomp$2_leave__$1$jscomp$1_leave__$2_map__74711__$1$$=$search_match$$!=null?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($leave$jscomp$2_leave__$1$jscomp$1_leave__$2_map__74711__$1$$,$search_match$$):$leave$jscomp$2_leave__$1$jscomp$1_leave__$2_map__74711__$1$$;$APP.$cljs$core$reset_BANG_$$($app$main$ui$workspace$sidebar$layer_item$sidebar_hover_queue$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$381$enter$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,$cljs$cst$382$leave$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$],null));$APP.$cljs$core$reset_BANG_$$($app$main$ui$workspace$sidebar$layer_item$sidebar_hover_pending_QMARK_$$,!1);$APP.$cljs$core$seq$$($leave$jscomp$2_leave__$1$jscomp$1_leave__$2_map__74711__$1$$)&&$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$dehighlight_shape$$,
$leave$jscomp$2_leave__$1$jscomp$1_leave__$2_map__74711__$1$$));return $APP.$cljs$core$seq$$($enter$jscomp$2_enter__$1$jscomp$1_map__74711$$)?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$highlight_shape$$,$enter$jscomp$2_enter__$1$jscomp$1_map__74711$$)):null}):null};
$APP.$app$main$ui$workspace$sidebar$layer_item$layer_item_inner_STAR_$$=function($depth$jscomp$16_props_74715$$){var $on_zoom_to_selected$$=$depth$jscomp$16_props_74715$$.onZoomToSelected,$is_component_tree$$=$depth$jscomp$16_props_74715$$.isComponentTree,$is_filtered$$=$depth$jscomp$16_props_74715$$.isFiltered,$name_ref$$=$depth$jscomp$16_props_74715$$.nameRef,$children$jscomp$284$$=$depth$jscomp$16_props_74715$$.children,$hide_toggle$$=$depth$jscomp$16_props_74715$$.hideToggle,$on_disable_drag$$=
$depth$jscomp$16_props_74715$$.onDisableDrag,$dnd_over_top$$=$depth$jscomp$16_props_74715$$.dndOverTop,$on_select_shape$$=$depth$jscomp$16_props_74715$$.onSelectShape,$on_pointer_leave$jscomp$1$$=$depth$jscomp$16_props_74715$$.onPointerLeave,$dnd_over_bot$$=$depth$jscomp$16_props_74715$$.dndOverBot,$ref$jscomp$45$$=$depth$jscomp$16_props_74715$$.ref,$is_selected$jscomp$1$$=$depth$jscomp$16_props_74715$$.isSelected,$is_read_only$$=$depth$jscomp$16_props_74715$$.isReadOnly,$on_pointer_enter$jscomp$1$$=
$depth$jscomp$16_props_74715$$.onPointerEnter,$on_enable_drag$$=$depth$jscomp$16_props_74715$$.onEnableDrag,$item$jscomp$109$$=$depth$jscomp$16_props_74715$$.item,$is_highlighted$jscomp$1$$=$depth$jscomp$16_props_74715$$.isHighlighted,$on_context_menu$$=$depth$jscomp$16_props_74715$$.onContextMenu,$on_toggle_collapse$$=$depth$jscomp$16_props_74715$$.onToggleCollapse,$style$jscomp$59$$=$depth$jscomp$16_props_74715$$.style,$dnd_over$$=$depth$jscomp$16_props_74715$$.dndOver,$rename_id$jscomp$1$$=$depth$jscomp$16_props_74715$$.renameId,
$on_toggle_visibility$$=$depth$jscomp$16_props_74715$$.onToggleVisibility,$is_expanded$$=$depth$jscomp$16_props_74715$$.isExpanded,$on_tab_press$jscomp$1$$=$depth$jscomp$16_props_74715$$.onTabPress,$parent_size$jscomp$1$$=$depth$jscomp$16_props_74715$$.parentSize,$on_toggle_blocking$$=$depth$jscomp$16_props_74715$$.onToggleBlocking;$depth$jscomp$16_props_74715$$=$depth$jscomp$16_props_74715$$.depth;var $id$jscomp$912$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$),$name$jscomp$428$$=
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$),$blocked_QMARK_$jscomp$1$$=$APP.$cljs$cst$1623$blocked$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$),$hidden_QMARK_$jscomp$1$$=$APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$),$has_shapes_QMARK_$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$core$seq$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$))),$touched_QMARK_$jscomp$5$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$core$seq$$($APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$))),
$root_board_QMARK_$$=$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$)),$absolute_QMARK_$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($item$jscomp$109$$),$is_variant_QMARK_$jscomp$2_variant_error$jscomp$1$$=$APP.$app$common$types$component$is_variant_QMARK_$$($item$jscomp$109$$),
$is_variant_container_QMARK_$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($item$jscomp$109$$),$variant_id$jscomp$47$$=$is_variant_QMARK_$jscomp$2_variant_error$jscomp$1$$?$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$):null,$variant_name$jscomp$4$$=$is_variant_QMARK_$jscomp$2_variant_error$jscomp$1$$?$APP.$cljs$cst$2002$variant_name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$):null;$is_variant_QMARK_$jscomp$2_variant_error$jscomp$1$$=
$is_variant_QMARK_$jscomp$2_variant_error$jscomp$1$$?$APP.$cljs$cst$2003$variant_error$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$):null;var $component_id$jscomp$90$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$109$$,$APP.$cljs$cst$1627$component_id$$),$data$jscomp$448_variant_properties$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_data$$);$data$jscomp$448_variant_properties$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$448_variant_properties$jscomp$5$$,
$component_id$jscomp$90$$),$APP.$cljs$cst$2001$variant_properties$$);var $icon_shape$$=$APP.$app$util$shape_icon$get_shape_icon$$($item$jscomp$109$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{role:"checkbox",className:"main_ui_workspace_sidebar_layer_item__layer-row "+($APP.$cljs$core$truth_$$($is_highlighted$jscomp$1$$)?"main_ui_workspace_sidebar_layer_item__highlight":"")+" "+($APP.$app$common$types$component$instance_head_QMARK_$$($item$jscomp$109$$)?
"main_ui_workspace_sidebar_layer_item__component":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$cst$1609$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$))?"main_ui_workspace_sidebar_layer_item__masked":"")+" "+($APP.$cljs$core$truth_$$($is_selected$jscomp$1$$)?"main_ui_workspace_sidebar_layer_item__selected":"")+" "+($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$)?"main_ui_workspace_sidebar_layer_item__type-frame":"")+" "+($APP.$app$common$files$helpers$bool_shape_QMARK_$$($item$jscomp$109$$)?
"main_ui_workspace_sidebar_layer_item__type-bool":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_component_tree$$)?$is_component_tree$$:$is_variant_container_QMARK_$$)?"main_ui_workspace_sidebar_layer_item__type-comp":"")+" "+($APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$1$$)?"main_ui_workspace_sidebar_layer_item__hidden":"")+" "+($APP.$cljs$core$truth_$$($dnd_over$$)?"main_ui_workspace_sidebar_layer_item__dnd-over":"")+" "+($APP.$cljs$core$truth_$$($dnd_over_top$$)?"main_ui_workspace_sidebar_layer_item__dnd-over-top":
"")+" "+($APP.$cljs$core$truth_$$($dnd_over_bot$$)?"main_ui_workspace_sidebar_layer_item__dnd-over-bot":"")+" "+($root_board_QMARK_$$?"main_ui_workspace_sidebar_layer_item__root-board":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{style:{"--depth":$depth$jscomp$16_props_74715$$},className:"main_ui_workspace_sidebar_layer_item__tab-indentation "+($APP.$cljs$core$truth_$$($is_filtered$$)?"main_ui_workspace_sidebar_layer_item__filtered":"")}),(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--depth":$depth$jscomp$16_props_74715$$},
onPointerEnter:$on_pointer_enter$jscomp$1$$,onPointerLeave:$on_pointer_leave$jscomp$1$$,onDoubleClick:$APP.$app$util$dom$stop_propagation$$,className:"main_ui_workspace_sidebar_layer_item__element-list-body "+($APP.$cljs$core$truth_$$($is_filtered$$)?"main_ui_workspace_sidebar_layer_item__filtered":"")+" "+($APP.$cljs$core$truth_$$($is_selected$jscomp$1$$)?"main_ui_workspace_sidebar_layer_item__selected":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$),
$APP.$cljs$cst$1721$icon$$)?"main_ui_workspace_sidebar_layer_item__icon-layer":""),children:[0<$APP.$cljs$core$count$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layer_item__button-content",children:[$APP.$cljs$core$not$$($hide_toggle$$)&&$APP.$cljs$core$not$$($is_filtered$$)?(0,$APP.$rumext$v2$jsx$$)("button",{"data-testid":"toggle-content","aria-expanded":$is_expanded$$,onClick:$on_toggle_collapse$$,
className:"main_ui_workspace_sidebar_layer_item__toggle-content "+($APP.$cljs$core$truth_$$($is_expanded$$)?"main_ui_workspace_sidebar_layer_item__inverse":""),children:$APP.$app$main$ui$icons$arrow$$}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{onDoubleClick:$on_zoom_to_selected$$,className:"main_ui_workspace_sidebar_layer_item__icon-shape",children:[$absolute_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_layer_item__absolute"}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:$icon_shape$$,size:"s","data-testid":["icon-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($icon_shape$$)].join("")})]})]}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layer_item__button-content",children:[$is_filtered$$?null:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layer_item__toggle-content"}),(0,$APP.$rumext$v2$jsxs$$)("div",{onDoubleClick:$on_zoom_to_selected$$,className:"main_ui_workspace_sidebar_layer_item__icon-shape",
children:[$absolute_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_layer_item__absolute"}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon_shape$$,size:"s","data-testid":["icon-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($icon_shape$$)].join("")})]})]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layer_name$layer_name_STAR_$$,{typeComp:$APP.$cljs$core$truth_$$($is_component_tree$$)?$is_component_tree$$:
$is_variant_container_QMARK_$$,variantName:$variant_name$jscomp$4$$,onStopEdit:$on_enable_drag$$,variantError:$is_variant_QMARK_$jscomp$2_variant_error$jscomp$1$$,shapeId:$id$jscomp$912$$,disabledDoubleClick:$is_read_only$$,componentId:$component_id$jscomp$90$$,parentSize:$parent_size$jscomp$1$$,typeFrame:$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$),isBlocked:$blocked_QMARK_$jscomp$1$$,isShapeTouched:$touched_QMARK_$jscomp$5$$,isHidden:$hidden_QMARK_$jscomp$1$$,
ref:$name_ref$$,depth:$depth$jscomp$16_props_74715$$,onTabPress:$on_tab_press$jscomp$1$$,isSelected:$is_selected$jscomp$1$$,shapeName:$name$jscomp$428$$,onStartEdit:$on_disable_drag$$,variantId:$variant_id$jscomp$47$$,renameId:$rename_id$jscomp$1$$,variantProperties:$data$jscomp$448_variant_properties$jscomp$5$$})]}),$is_read_only$$?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layer_item__element-actions "+($has_shapes_QMARK_$$?"main_ui_workspace_sidebar_layer_item__is-parent":
"")+" "+($APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$1$$)?"main_ui_workspace_sidebar_layer_item__selected":"")+" "+($APP.$cljs$core$truth_$$($blocked_QMARK_$jscomp$1$$)?"main_ui_workspace_sidebar_layer_item__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.show"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.hide"),
onClick:$on_toggle_visibility$$,className:"main_ui_workspace_sidebar_layer_item__toggle-element "+($APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$1$$)?"main_ui_workspace_sidebar_layer_item__selected":""),children:$hidden_QMARK_$jscomp$1$$?$app$main$ui$icons$hide$$:$app$main$ui$icons$shown$$}),(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1623$blocked$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$109$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.unlock"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.lock"),onClick:$on_toggle_blocking$$,className:"main_ui_workspace_sidebar_layer_item__block-element "+($APP.$cljs$core$truth_$$($blocked_QMARK_$jscomp$1$$)?"main_ui_workspace_sidebar_layer_item__selected":""),children:$blocked_QMARK_$jscomp$1$$?$app$main$ui$icons$lock$$:$app$main$ui$icons$unlock$$})]})],id:$id$jscomp$912$$,"data-testid":"layer-row",onContextMenu:$on_context_menu$$,style:$style$jscomp$59$$,"aria-checked":$is_selected$jscomp$1$$,
onClick:$on_select_shape$$,ref:$ref$jscomp$45$$}),$children$jscomp$284$$]})};
$app$main$ui$components$copy_button$copy_button_STAR_$$=function($active_QMARK_$jscomp$3_props_74728$$){var $aria_label$jscomp$6$$=$active_QMARK_$jscomp$3_props_74728$$["aria-label"],$data$jscomp$449$$=$active_QMARK_$jscomp$3_props_74728$$.data,$children$jscomp$285$$=$active_QMARK_$jscomp$3_props_74728$$.children,$on_copied$$=$active_QMARK_$jscomp$3_props_74728$$.onCopied,$class$$jscomp$48_class$__$1$jscomp$8$$=$active_QMARK_$jscomp$3_props_74728$$.className,$active_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);
$active_QMARK_$jscomp$3_props_74728$$=$APP.$cljs$core$_deref$$($active_STAR_$$);$class$$jscomp$48_class$__$1$jscomp$8$$=""+($class$$jscomp$48_class$__$1$jscomp$8$$??"")+" "+(($children$jscomp$285$$==null?"main_ui_components_copy_button__copy-button":"")+" "+($children$jscomp$285$$!=null?"main_ui_components_copy_button__copy-wrapper":""));var $on_click$jscomp$21$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($data$jscomp$449$$)],function($event$jscomp$213$$){if($APP.$cljs$core$truth_$$($app$util$dom$get_boolean_data$$($event$jscomp$213$$)))return null;
$APP.$cljs$core$reset_BANG_$$($active_STAR_$$,!0);$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(1E3,function(){return $APP.$cljs$core$reset_BANG_$$($active_STAR_$$,!1)});$APP.$cljs$core$fn_QMARK_$$($on_copied$$)&&($on_copied$$.$cljs$core$IFn$_invoke$arity$1$?$on_copied$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$213$$):$on_copied$$($event$jscomp$213$$));return $APP.$app$util$clipboard$to_clipboard$$($APP.$cljs$core$fn_QMARK_$$($data$jscomp$449$$)?$data$jscomp$449$$.$cljs$core$IFn$_invoke$arity$0$?
$data$jscomp$449$$.$cljs$core$IFn$_invoke$arity$0$():$data$jscomp$449$$():$data$jscomp$449$$)});return(0,$APP.$rumext$v2$jsxs$$)("button",{"aria-label":$APP.$cljs$core$truth_$$($aria_label$jscomp$6$$)?$aria_label$jscomp$6$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.copy"),"data-active":""+($active_QMARK_$jscomp$3_props_74728$$??""),onClick:$on_click$jscomp$21$$,className:$class$$jscomp$48_class$__$1$jscomp$8$$,children:[$children$jscomp$285$$,(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_components_copy_button__icon-btn",children:$APP.$cljs$core$truth_$$($active_QMARK_$jscomp$3_props_74728$$)?$APP.$app$main$ui$icons$tick$$:$APP.$app$main$ui$icons$clipboard$$})]})};
$app$main$ui$inspect$annotation$annotation$$=function($content$jscomp$240_map__74803_map__74803__$1_props_74802$$){$content$jscomp$240_map__74803_map__74803__$1_props_74802$$=$APP.$rumext$v2$util$wrap_props$$($content$jscomp$240_map__74803_map__74803__$1_props_74802$$);$content$jscomp$240_map__74803_map__74803__$1_props_74802$$=$APP.$cljs$core$__destructure_map$$($content$jscomp$240_map__74803_map__74803__$1_props_74802$$);$content$jscomp$240_map__74803_map__74803__$1_props_74802$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$240_map__74803_map__74803__$1_props_74802$$,
$APP.$cljs$cst$1637$content$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_annotation__attributes-block",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!1,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.annotation"),className:"main_ui_inspect_annotation__title-spacing-annotation",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$content$jscomp$240_map__74803_map__74803__$1_props_74802$$,
className:"main_ui_inspect_annotation__copy-btn-title"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_annotation__annotation-content",children:$content$jscomp$240_map__74803_map__74803__$1_props_74802$$})]})};$app$main$ui$inspect$attributes$blur$has_blur_QMARK_$$=function($shape$jscomp$899$$){return $APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$899$$)};
$app$main$ui$inspect$attributes$blur$blur_css_property$$=function($shape$jscomp$900$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1197$background_blur$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$900$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$139$type$$],null)))?$cljs$cst$4060$backdrop_filter$$:$APP.$cljs$cst$2691$filter$$};
$app$main$ui$inspect$attributes$blur$blur_panel$$=function($map__74815_map__74815__$1_props_74814_shapes$jscomp$151$$){$map__74815_map__74815__$1_props_74814_shapes$jscomp$151$$=$APP.$rumext$v2$util$wrap_props$$($map__74815_map__74815__$1_props_74814_shapes$jscomp$151$$);$map__74815_map__74815__$1_props_74814_shapes$jscomp$151$$=$APP.$cljs$core$__destructure_map$$($map__74815_map__74815__$1_props_74814_shapes$jscomp$151$$);var $objects$jscomp$713$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74815_map__74815__$1_props_74814_shapes$jscomp$151$$,
$APP.$cljs$cst$1631$objects$$);$map__74815_map__74815__$1_props_74814_shapes$jscomp$151$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74815_map__74815__$1_props_74814_shapes$jscomp$151$$,$APP.$cljs$cst$1614$shapes$$);var $shapes__$1$jscomp$19$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$attributes$blur$has_blur_QMARK_$$,$map__74815_map__74815__$1_props_74814_shapes$jscomp$151$$);return $APP.$cljs$core$seq$$($shapes__$1$jscomp$19$$)?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_inspect_attributes_blur__attributes-block",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$title_bar$inspect_title_bar_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.blur"),className:"main_ui_inspect_attributes_blur__title-wrapper",titleClass:"main_ui_inspect_attributes_blur__blur-attr-title",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes__$1$jscomp$19$$),1)?function(){var $JSCompiler_inline_result$jscomp$10889_prop$jscomp$32$$=
$app$main$ui$inspect$attributes$blur$blur_css_property$$($APP.$cljs$core$first$$($shapes__$1$jscomp$19$$)),$shape$jscomp$inline_13051$$=$APP.$cljs$core$first$$($shapes__$1$jscomp$19$$);$JSCompiler_inline_result$jscomp$10889_prop$jscomp$32$$=$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$713$$,$shape$jscomp$inline_13051$$,$JSCompiler_inline_result$jscomp$10889_prop$jscomp$32$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,
{data:$JSCompiler_inline_result$jscomp$10889_prop$jscomp$32$$,className:"main_ui_inspect_attributes_blur__copy-btn-title"})}():null}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_blur__attributes-content",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$62$$,$JSCompiler_inline_result$jscomp$1397_shape$jscomp$901$$){var $JSCompiler_temp_const$jscomp$1395$$=$out_arr__44124__auto__$jscomp$62$$.push,$prop$jscomp$inline_7879$$=
$app$main$ui$inspect$attributes$blur$blur_css_property$$($JSCompiler_inline_result$jscomp$1397_shape$jscomp$901$$);$JSCompiler_inline_result$jscomp$1397_shape$jscomp$901$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_blur__blur-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$inline_7879$$,$cljs$cst$4060$backdrop_filter$$)?"Backdrop Filter":"Filter"}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$713$$,$JSCompiler_inline_result$jscomp$1397_shape$jscomp$901$$,$prop$jscomp$inline_7879$$),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_blur__button-children",children:$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$713$$,
$JSCompiler_inline_result$jscomp$1397_shape$jscomp$901$$,$prop$jscomp$inline_7879$$)})})})]},"block-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1397_shape$jscomp$901$$)??"")+"-blur");$JSCompiler_temp_const$jscomp$1395$$.call($out_arr__44124__auto__$jscomp$62$$,$JSCompiler_inline_result$jscomp$1397_shape$jscomp$901$$);return $out_arr__44124__auto__$jscomp$62$$},[],$shapes__$1$jscomp$19$$)})]}):null};
$app$main$ui$inspect$common$colors$make_colors_library_ref$$=function($file_id$jscomp$352$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$1159$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1159$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,$file_id$jscomp$352$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2212$colors$$],null))},$APP.$app$main$store$state$$)};
$app$main$ui$inspect$common$colors$use_colors_library$$=function($library$jscomp$31_map__74826__$1_p__74825$$){$library$jscomp$31_map__74826__$1_p__74825$$=$APP.$cljs$core$__destructure_map$$($library$jscomp$31_map__74826__$1_p__74825$$);var $ref_file$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($library$jscomp$31_map__74826__$1_p__74825$$,$APP.$cljs$cst$1736$ref_file$$);$library$jscomp$31_map__74826__$1_p__74825$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ref_file$jscomp$11$$)],
function(){return $app$main$ui$inspect$common$colors$make_colors_library_ref$$($ref_file$jscomp$11$$)});return $APP.$rumext$v2$deref$$($library$jscomp$31_map__74826__$1_p__74825$$)};
$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$=function($$__$1$jscomp$22_$__$2$jscomp$5_$__$3$jscomp$2_property$jscomp$44$$){$$__$1$jscomp$22_$__$2$jscomp$5_$__$3$jscomp$2_property$jscomp$44$$=$APP.$app$common$data$name$$($$__$1$jscomp$22_$__$2$jscomp$5_$__$3$jscomp$2_property$jscomp$44$$);$$__$1$jscomp$22_$__$2$jscomp$5_$__$3$jscomp$2_property$jscomp$44$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($$__$1$jscomp$22_$__$2$jscomp$5_$__$3$jscomp$2_property$jscomp$44$$,
"-");$$__$1$jscomp$22_$__$2$jscomp$5_$__$3$jscomp$2_property$jscomp$44$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$$__$1$jscomp$22_$__$2$jscomp$5_$__$3$jscomp$2_property$jscomp$44$$);return $APP.$cuerdas$core$capital$$($$__$1$jscomp$22_$__$2$jscomp$5_$__$3$jscomp$2_property$jscomp$44$$)};
$app$main$ui$inspect$attributes$common$color_row$$=function($copy_data$jscomp$1_map__74830_props_74829$$){$copy_data$jscomp$1_map__74830_props_74829$$=$APP.$rumext$v2$util$wrap_props$$($copy_data$jscomp$1_map__74830_props_74829$$);var $color_library_name_colors_library_map__74830__$1$$=$APP.$cljs$core$__destructure_map$$($copy_data$jscomp$1_map__74830_props_74829$$),$color$jscomp$125_name$jscomp$429$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color_library_name_colors_library_map__74830__$1$$,
$APP.$cljs$cst$1298$color$$),$format$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color_library_name_colors_library_map__74830__$1$$,$APP.$cljs$cst$954$format$$);$copy_data$jscomp$1_map__74830_props_74829$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color_library_name_colors_library_map__74830__$1$$,$cljs$cst$5323$copy_data$$);var $property$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color_library_name_colors_library_map__74830__$1$$,$cljs$cst$827$property$$),
$on_change_format$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color_library_name_colors_library_map__74830__$1$$,$cljs$cst$5324$on_change_format$$);$color_library_name_colors_library_map__74830__$1$$=$app$main$ui$inspect$common$colors$use_colors_library$$($color$jscomp$125_name$jscomp$429$$);var $file_colors_file_colors_ref$$=$APP.$rumext$v2$deref$$($app$main$ui$inspect$common$colors$file_colors_ref$$),$file_colors_wokspace$$=$APP.$rumext$v2$deref$$($app$main$refs$workspace_file_colors$$);
$file_colors_file_colors_ref$$=$APP.$cljs$core$truth_$$($file_colors_file_colors_ref$$)?$file_colors_file_colors_ref$$:$file_colors_wokspace$$;$color_library_name_colors_library_map__74830__$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($color_library_name_colors_library_map__74830__$1$$)?$color_library_name_colors_library_map__74830__$1$$:$file_colors_file_colors_ref$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$125_name$jscomp$429$$),$APP.$cljs$cst$725$name$$],null));var $color__$1$jscomp$17$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$125_name$jscomp$429$$,$APP.$cljs$cst$725$name$$,$color_library_name_colors_library_map__74830__$1$$),$image$jscomp$33$$=$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$17$$);return $APP.$cljs$core$truth_$$($image$jscomp$33$$)?($color$jscomp$125_name$jscomp$429$$=
function(){var $or__5025__auto__$jscomp$992$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($image$jscomp$33$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$992$$)?$or__5025__auto__$jscomp$992$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.image")}(),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_common__attributes-image-as-color-row",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_common__attributes-color-row",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{"--bullet-size":"16px"},className:"main_ui_inspect_attributes_common__bullet-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet$$,{color:$color__$1$jscomp$17$$,mini:!0})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_common__format-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_common__image-format",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.image.short")})}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$copy_data$jscomp$1_map__74830_props_74829$$,className:"main_ui_inspect_attributes_common__color-row-copy-btn",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_common__color-info "+($color_library_name_colors_library_map__74830__$1$$!=null?"main_ui_inspect_attributes_common__two-line":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_common__first-row",
children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_inspect_attributes_common__opacity-info",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(100*$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$17$$)),"%"].join("")})}),$APP.$cljs$core$truth_$$($color_library_name_colors_library_map__74830__$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_common__second-row",children:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"color-library-name",
className:"main_ui_inspect_attributes_common__color-name-library",children:$color_library_name_colors_library_map__74830__$1$$})}):null]})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_common__image-download",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_common__image-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($image$jscomp$33$$),className:"main_ui_inspect_attributes_common__resolved-image"})}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:"main_ui_inspect_attributes_common__download-button",type:"button",variant:"secondary",target:"_blank",download:$color$jscomp$125_name$jscomp$429$$,to:$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($image$jscomp$33$$),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.image.download")})]})]})})):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_common__attributes-color-row",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{"--bullet-size":"16px"},className:"main_ui_inspect_attributes_common__bullet-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet$$,{color:$color__$1$jscomp$17$$,mini:!0})}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1220$inspect_styles$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:$property$jscomp$45$$}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_common__format-wrapper",
children:[$APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($on_change_format$$)){var $or__5025__auto__$jscomp$993$$=$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$17$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$993$$)?$or__5025__auto__$jscomp$993$$:$image$jscomp$33$$}return $on_change_format$$}())?null:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$format$jscomp$36$$,"class":"main_ui_inspect_attributes_common__select-format-wrapper",
options:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2687$hex$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.color.hex")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$cljs$cst$5325$rgba$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.color.rgba")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$cljs$cst$5326$hsla$$,$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.color.hsla")],null)],null),"on-change":$on_change_format$$}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$17$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_common__format-info",children:"rgba"}):null]}),
(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$copy_data$jscomp$1_map__74830_props_74829$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.copy-color"),className:"main_ui_inspect_attributes_common__color-row-copy-btn "+($APP.$cljs$core$not$$($color_library_name_colors_library_map__74830__$1$$)?"main_ui_inspect_attributes_common__one-line":"")+" "+($color_library_name_colors_library_map__74830__$1$$!=null?"main_ui_inspect_attributes_common__two-line":
""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_common__first-row",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_common__name-opacity",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_inspect_attributes_common__color-value-wrapper "+($APP.$cljs$core$truth_$$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$17$$))?"main_ui_inspect_attributes_common__gradient-name":""),children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$17$$))?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$color_bullet$color_name$$,{color:$color__$1$jscomp$17$$,size:90}):function(){var $G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$=$format$jscomp$36$$ instanceof $APP.$cljs$core$Keyword$$?$format$jscomp$36$$.$fqn$:null;switch($G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$){case "hex":return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$color_bullet$color_name$$,
{color:$color__$1$jscomp$17$$});case "rgba":$G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$=$app$common$types$color$hex__GT_rgba$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$17$$),$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$17$$));var $h$jscomp$166_opacity$jscomp$inline_7882_r$jscomp$118$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$,
0,null),$g$jscomp$139_s$jscomp$558$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$,1,null),$b$jscomp$339_l$jscomp$101$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$,2,null);$G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$,
3,null);$G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$=$app$common$types$color$format_rgba$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$166_opacity$jscomp$inline_7882_r$jscomp$118$$,$g$jscomp$139_s$jscomp$558$$,$b$jscomp$339_l$jscomp$101$$,$G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$],null));return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,
{children:$G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$});case "hsla":return $G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$17$$),$h$jscomp$166_opacity$jscomp$inline_7882_r$jscomp$118$$=$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$17$$),$G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$color$hex__GT_hsl$$($G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$),$h$jscomp$166_opacity$jscomp$inline_7882_r$jscomp$118$$),$h$jscomp$166_opacity$jscomp$inline_7882_r$jscomp$118$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$,0,null),$g$jscomp$139_s$jscomp$558$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$,
1,null),$b$jscomp$339_l$jscomp$101$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$,2,null),$G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$,3,null),$G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$=
$app$common$types$color$format_hsla$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$166_opacity$jscomp$inline_7882_r$jscomp$118$$,$g$jscomp$139_s$jscomp$558$$,$b$jscomp$339_l$jscomp$101$$,$G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$],null)),(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$});
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__74831__$1_a$jscomp$418_data$jscomp$inline_7881_result$jscomp$338_vec__74832_vec__74835$$)].join(""));}}()}),$APP.$cljs$core$not$$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$17$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2687$hex$$,$format$jscomp$36$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_inspect_attributes_common__opacity-info",
children:""+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$coalesce$$($APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$17$$))*100)??"")+"%"}):null]})}),$APP.$cljs$core$truth_$$($color_library_name_colors_library_map__74830__$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_common__second-row",children:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"color-library-name",className:"main_ui_inspect_attributes_common__color-name-library",
children:$color_library_name_colors_library_map__74830__$1$$})}):null]})]})};
$app$main$ui$inspect$attributes$fill$has_fill_QMARK_$$=function($shape$jscomp$902$$){var $and__5023__auto__$jscomp$652_or__5025__auto__$jscomp$994_or__5025__auto____$1$jscomp$108$$=!$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1608$group$$,null,$APP.$cljs$cst$1588$text$$,null],null),null),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$902$$));if($and__5023__auto__$jscomp$652_or__5025__auto__$jscomp$994_or__5025__auto____$1$jscomp$108$$){$and__5023__auto__$jscomp$652_or__5025__auto__$jscomp$994_or__5025__auto____$1$jscomp$108$$=
$APP.$cljs$cst$1746$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$902$$);if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$652_or__5025__auto__$jscomp$994_or__5025__auto____$1$jscomp$108$$))return $and__5023__auto__$jscomp$652_or__5025__auto__$jscomp$994_or__5025__auto____$1$jscomp$108$$;$and__5023__auto__$jscomp$652_or__5025__auto__$jscomp$994_or__5025__auto____$1$jscomp$108$$=$APP.$cljs$cst$1748$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$902$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$652_or__5025__auto__$jscomp$994_or__5025__auto____$1$jscomp$108$$)?
$and__5023__auto__$jscomp$652_or__5025__auto__$jscomp$994_or__5025__auto____$1$jscomp$108$$:$APP.$cljs$core$seq$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$902$$))}return $and__5023__auto__$jscomp$652_or__5025__auto__$jscomp$994_or__5025__auto____$1$jscomp$108$$};
$app$main$ui$inspect$attributes$fill$fill_block$$=function($props_74839_shape$jscomp$903$$){var $objects$jscomp$714$$=$props_74839_shape$jscomp$903$$.objects;$props_74839_shape$jscomp$903$$=$props_74839_shape$jscomp$903$$.shape;var $format_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2687$hex$$),$format$jscomp$37$$=$APP.$cljs$core$_deref$$($format_STAR_$$),$color$jscomp$126$$=$APP.$app$common$types$fills$fill__GT_color$$($props_74839_shape$jscomp$903$$),$on_change$jscomp$28$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($format__$1$jscomp$1$$){return $APP.$cljs$core$reset_BANG_$$($format_STAR_$$,$format__$1$jscomp$1$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_fill__attributes-fill-block",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$common$color_row$$,{color:$color$jscomp$126$$,format:$format$jscomp$37$$,property:"Background","on-change-format":$on_change$jscomp$28$$,"copy-data":$app$util$code_gen$style_css$get_shape_properties_css$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$714$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1634$fills$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$props_74839_shape$jscomp$903$$],null)],null),$app$main$ui$inspect$attributes$fill$properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$954$format$$,$format$jscomp$37$$],null))})})};
$app$main$ui$inspect$attributes$fill$fill_block_styles_STAR_$$=function($props_74841_shape$jscomp$904$$){var $color_space$$=$props_74841_shape$jscomp$904$$.colorSpace,$objects$jscomp$715$$=$props_74841_shape$jscomp$904$$.objects;$props_74841_shape$jscomp$904$$=$props_74841_shape$jscomp$904$$.shape;var $color$jscomp$127$$=$APP.$app$common$types$fills$fill__GT_color$$($props_74841_shape$jscomp$904$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_fill__attributes-fill-block",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$common$color_row$$,{color:$color$jscomp$127$$,property:"Background",format:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($color_space$$),$APP.$cljs$cst$2687$hex$$),"copy-data":$app$util$code_gen$style_css$get_shape_properties_css$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$715$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1634$fills$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$props_74841_shape$jscomp$904$$],null)],null),$app$main$ui$inspect$attributes$fill$properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$954$format$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($color_space$$)],null))})})};
$app$main$ui$inspect$attributes$fill$fill_panel_STAR_$$=function($props_74842_shapes__$1$jscomp$20$$){var $color_space$jscomp$1$$=$props_74842_shapes__$1$jscomp$20$$.colorSpace;$props_74842_shapes__$1$jscomp$20$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$attributes$fill$has_fill_QMARK_$$,$props_74842_shapes__$1$jscomp$20$$.shapes);return $APP.$cljs$core$seq$$($props_74842_shapes__$1$jscomp$20$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_fill__attributes-block",
children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$title_bar$inspect_title_bar_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.fill"),className:"main_ui_inspect_attributes_fill__title-wrapper",classTitle:"main_ui_inspect_attributes_fill__fill-attr-title"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_fill__attributes-content",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$63$$,
$shape$jscomp$905$$){$out_arr__44124__auto__$jscomp$63$$.push($APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1220$inspect_styles$$)?$APP.$cljs$core$seq$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$905$$))?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$2$$,$value$jscomp$755$$){$out_arr__44124__auto____$1$jscomp$2$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$fill$fill_block_styles_STAR_$$,
{colorSpace:$color_space$jscomp$1$$,shape:$value$jscomp$755$$},["fill-block-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$905$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$755$$)].join("")));return $out_arr__44124__auto____$1$jscomp$2$$},[],$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$905$$,$APP.$cljs$core$PersistentVector$EMPTY$$)):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$fill$fill_block_styles_STAR_$$,
{colorSpace:$color_space$jscomp$1$$,shape:$shape$jscomp$905$$},["fill-block-only",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$905$$))].join("")):$APP.$cljs$core$seq$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$905$$))?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$3$$,$value$jscomp$756$$){$out_arr__44124__auto____$1$jscomp$3$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$fill$fill_block$$,
{shape:$value$jscomp$756$$},["fill-block-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$905$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$756$$)].join("")));return $out_arr__44124__auto____$1$jscomp$3$$},[],$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$905$$,$APP.$cljs$core$PersistentVector$EMPTY$$)):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$fill$fill_block$$,
{shape:$shape$jscomp$905$$},["fill-block-only",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$905$$))].join("")));return $out_arr__44124__auto__$jscomp$63$$},[],$props_74842_shapes__$1$jscomp$20$$)})]}):null};
$app$main$ui$inspect$attributes$geometry$geometry_block$$=function($map__74843_map__74843__$1_props_74840$$){$map__74843_map__74843__$1_props_74840$$=$APP.$rumext$v2$util$wrap_props$$($map__74843_map__74843__$1_props_74840$$);$map__74843_map__74843__$1_props_74840$$=$APP.$cljs$core$__destructure_map$$($map__74843_map__74843__$1_props_74840$$);var $objects$jscomp$716$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74843_map__74843__$1_props_74840$$,$APP.$cljs$cst$1631$objects$$),$shape$jscomp$906$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74843_map__74843__$1_props_74840$$,$APP.$cljs$cst$1811$shape$$);return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$64$$,$JSCompiler_temp_const$jscomp$1398_p__74844$$){var $JSCompiler_inline_result$jscomp$1400_idx$jscomp$103$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1398_p__74844$$,
0,null),$property$jscomp$46$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1398_p__74844$$,1,null);$JSCompiler_temp_const$jscomp$1398_p__74844$$=$out_arr__44124__auto__$jscomp$64$$.push;var $temp__5825__auto__$jscomp$inline_7884$$=$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$716$$,$shape$jscomp$906$$,$property$jscomp$46$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_7884$$)){var $property_name$jscomp$inline_7885$$=
$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($property$jscomp$46$$);$JSCompiler_inline_result$jscomp$1400_idx$jscomp$103$$=(0,$APP.$rumext$v2$jsxs$$)("div",{title:$property_name$jscomp$inline_7885$$,className:"main_ui_inspect_attributes_geometry__geometry-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:$property_name$jscomp$inline_7885$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,
{data:$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$716$$,$shape$jscomp$906$$,$property$jscomp$46$$),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_geometry__button-children",children:$temp__5825__auto__$jscomp$inline_7884$$})})})]},"block-"+($JSCompiler_inline_result$jscomp$1400_idx$jscomp$103$$??"")+"-"+($APP.$app$common$data$name$$($property$jscomp$46$$)??""))}else $JSCompiler_inline_result$jscomp$1400_idx$jscomp$103$$=
null;$JSCompiler_temp_const$jscomp$1398_p__74844$$.call($out_arr__44124__auto__$jscomp$64$$,$JSCompiler_inline_result$jscomp$1400_idx$jscomp$103$$);return $out_arr__44124__auto__$jscomp$64$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$inspect$attributes$geometry$properties$$))})};
$app$main$ui$inspect$attributes$geometry$geometry_panel$$=function($map__74849_map__74849__$1_props_74848_shapes$jscomp$153$$){$map__74849_map__74849__$1_props_74848_shapes$jscomp$153$$=$APP.$rumext$v2$util$wrap_props$$($map__74849_map__74849__$1_props_74848_shapes$jscomp$153$$);$map__74849_map__74849__$1_props_74848_shapes$jscomp$153$$=$APP.$cljs$core$__destructure_map$$($map__74849_map__74849__$1_props_74848_shapes$jscomp$153$$);var $objects$jscomp$717$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74849_map__74849__$1_props_74848_shapes$jscomp$153$$,
$APP.$cljs$cst$1631$objects$$);$map__74849_map__74849__$1_props_74848_shapes$jscomp$153$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74849_map__74849__$1_props_74848_shapes$jscomp$153$$,$APP.$cljs$cst$1614$shapes$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_geometry__attributes-block",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$title_bar$inspect_title_bar_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.size"),
className:"main_ui_inspect_attributes_geometry__title-wrapper",titleClass:"main_ui_inspect_attributes_geometry__geometry-attr-title",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($map__74849_map__74849__$1_props_74848_shapes$jscomp$153$$),1)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$util$code_gen$style_css$get_shape_properties_css$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$717$$,$APP.$cljs$core$first$$($map__74849_map__74849__$1_props_74848_shapes$jscomp$153$$),
$app$main$ui$inspect$attributes$geometry$properties$$),className:"main_ui_inspect_attributes_geometry__copy-btn-title"}):null}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$65$$,$shape$jscomp$907$$){$out_arr__44124__auto__$jscomp$65$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$geometry$geometry_block$$,{shape:$shape$jscomp$907$$,objects:$objects$jscomp$717$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$907$$)));
return $out_arr__44124__auto__$jscomp$65$$},[],$map__74849_map__74849__$1_props_74848_shapes$jscomp$153$$)]})};
$app$main$ui$inspect$attributes$layout$layout_block$$=function($map__74851_map__74851__$1_props_74850$$){$map__74851_map__74851__$1_props_74850$$=$APP.$rumext$v2$util$wrap_props$$($map__74851_map__74851__$1_props_74850$$);$map__74851_map__74851__$1_props_74850$$=$APP.$cljs$core$__destructure_map$$($map__74851_map__74851__$1_props_74850$$);var $objects$jscomp$718$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74851_map__74851__$1_props_74850$$,$APP.$cljs$cst$1631$objects$$),$shape$jscomp$908$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74851_map__74851__$1_props_74850$$,$APP.$cljs$cst$1811$shape$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$66$$,$JSCompiler_inline_result$jscomp$1403_property$jscomp$47$$){var $JSCompiler_temp_const$jscomp$1401$$=$out_arr__44124__auto__$jscomp$66$$.push;var $temp__5825__auto__$jscomp$inline_7887$$=$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$718$$,
$shape$jscomp$908$$,$JSCompiler_inline_result$jscomp$1403_property$jscomp$47$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_7887$$)){var $property_name$jscomp$inline_7888$$=$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($JSCompiler_inline_result$jscomp$1403_property$jscomp$47$$);$JSCompiler_inline_result$jscomp$1403_property$jscomp$47$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_layout__layout-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{title:$property_name$jscomp$inline_7888$$,className:"attr-label",children:$property_name$jscomp$inline_7888$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$718$$,$shape$jscomp$908$$,$JSCompiler_inline_result$jscomp$1403_property$jscomp$47$$),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_layout__button-children",
children:$temp__5825__auto__$jscomp$inline_7887$$})})})]},"layout-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$908$$)??"")+"-"+($APP.$app$common$data$name$$($JSCompiler_inline_result$jscomp$1403_property$jscomp$47$$)??""))}else $JSCompiler_inline_result$jscomp$1403_property$jscomp$47$$=null;$JSCompiler_temp_const$jscomp$1401$$.call($out_arr__44124__auto__$jscomp$66$$,$JSCompiler_inline_result$jscomp$1403_property$jscomp$47$$);return $out_arr__44124__auto__$jscomp$66$$},
[],$app$main$ui$inspect$attributes$layout$properties$$)};
$app$main$ui$inspect$attributes$layout$layout_panel$$=function($map__74853_map__74853__$1_props_74852_shapes$jscomp$154_shapes__$1$jscomp$21$$){$map__74853_map__74853__$1_props_74852_shapes$jscomp$154_shapes__$1$jscomp$21$$=$APP.$rumext$v2$util$wrap_props$$($map__74853_map__74853__$1_props_74852_shapes$jscomp$154_shapes__$1$jscomp$21$$);$map__74853_map__74853__$1_props_74852_shapes$jscomp$154_shapes__$1$jscomp$21$$=$APP.$cljs$core$__destructure_map$$($map__74853_map__74853__$1_props_74852_shapes$jscomp$154_shapes__$1$jscomp$21$$);var $objects$jscomp$719$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74853_map__74853__$1_props_74852_shapes$jscomp$154_shapes__$1$jscomp$21$$,$APP.$cljs$cst$1631$objects$$);$map__74853_map__74853__$1_props_74852_shapes$jscomp$154_shapes__$1$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74853_map__74853__$1_props_74852_shapes$jscomp$154_shapes__$1$jscomp$21$$,$APP.$cljs$cst$1614$shapes$$);$map__74853_map__74853__$1_props_74852_shapes$jscomp$154_shapes__$1$jscomp$21$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$layout$any_layout_QMARK_$$,
$map__74853_map__74853__$1_props_74852_shapes$jscomp$154_shapes__$1$jscomp$21$$);return $APP.$cljs$core$seq$$($map__74853_map__74853__$1_props_74852_shapes$jscomp$154_shapes__$1$jscomp$21$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_layout__attributes-block",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$title_bar$inspect_title_bar_STAR_$$,{title:"Layout",className:"main_ui_inspect_attributes_layout__title-wrapper",titleClass:"main_ui_inspect_attributes_layout__layout-attr-title",
children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($map__74853_map__74853__$1_props_74852_shapes$jscomp$154_shapes__$1$jscomp$21$$),1)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$util$code_gen$style_css$get_shape_properties_css$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$719$$,$APP.$cljs$core$first$$($map__74853_map__74853__$1_props_74852_shapes$jscomp$154_shapes__$1$jscomp$21$$),$app$main$ui$inspect$attributes$layout$properties$$),
className:"main_ui_inspect_attributes_layout__copy-btn-title"}):null}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$67$$,$shape$jscomp$909$$){$out_arr__44124__auto__$jscomp$67$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$layout$layout_block$$,{shape:$shape$jscomp$909$$,objects:$objects$jscomp$719$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$909$$)));return $out_arr__44124__auto__$jscomp$67$$},[],
$map__74853_map__74853__$1_props_74852_shapes$jscomp$154_shapes__$1$jscomp$21$$)]}):null};
$app$main$ui$inspect$attributes$layout_element$layout_element_block$$=function($map__74855_map__74855__$1_props_74854$$){$map__74855_map__74855__$1_props_74854$$=$APP.$rumext$v2$util$wrap_props$$($map__74855_map__74855__$1_props_74854$$);$map__74855_map__74855__$1_props_74854$$=$APP.$cljs$core$__destructure_map$$($map__74855_map__74855__$1_props_74854$$);var $objects$jscomp$720$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74855_map__74855__$1_props_74854$$,$APP.$cljs$cst$1631$objects$$),
$shape$jscomp$910$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74855_map__74855__$1_props_74854$$,$APP.$cljs$cst$1811$shape$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$68$$,$JSCompiler_inline_result$jscomp$1406_property$jscomp$48$$){var $JSCompiler_temp_const$jscomp$1404$$=$out_arr__44124__auto__$jscomp$68$$.push;var $temp__5825__auto__$jscomp$inline_7890$$=$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$720$$,
$shape$jscomp$910$$,$JSCompiler_inline_result$jscomp$1406_property$jscomp$48$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_7890$$)){var $property_name$jscomp$inline_7891$$=$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($JSCompiler_inline_result$jscomp$1406_property$jscomp$48$$);$JSCompiler_inline_result$jscomp$1406_property$jscomp$48$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_layout_element__layout-element-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"attr-label",children:$property_name$jscomp$inline_7891$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$720$$,$shape$jscomp$910$$,$JSCompiler_inline_result$jscomp$1406_property$jscomp$48$$),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_layout_element__button-children",
children:$temp__5825__auto__$jscomp$inline_7890$$})})})]},"layout-element-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$910$$)??"")+"-"+($APP.$app$common$data$name$$($JSCompiler_inline_result$jscomp$1406_property$jscomp$48$$)??""))}else $JSCompiler_inline_result$jscomp$1406_property$jscomp$48$$=null;$JSCompiler_temp_const$jscomp$1404$$.call($out_arr__44124__auto__$jscomp$68$$,$JSCompiler_inline_result$jscomp$1406_property$jscomp$48$$);return $out_arr__44124__auto__$jscomp$68$$},
[],$app$main$ui$inspect$attributes$layout_element$properties$$)};
$app$main$ui$inspect$attributes$layout_element$layout_element_panel$$=function($map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$){$map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$=$APP.$rumext$v2$util$wrap_props$$($map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$);$map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$=$APP.$cljs$core$__destructure_map$$($map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$);var $objects$jscomp$721$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$,$APP.$cljs$cst$1631$objects$$);$map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$,$APP.$cljs$cst$1614$shapes$$);$map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74856_SHARP_$$){return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$721$$,
$p1__74856_SHARP_$$)},$map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$);var $only_flex_QMARK_$$=$APP.$cljs$core$every_QMARK_$$(function($p1__74857_SHARP_$$){return $APP.$app$common$types$shape$layout$flex_layout_immediate_child_QMARK_$$($objects$jscomp$721$$,$p1__74857_SHARP_$$)},$map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$),$only_grid_QMARK_$$=$APP.$cljs$core$every_QMARK_$$(function($p1__74858_SHARP_$$){return $APP.$app$common$types$shape$layout$grid_layout_immediate_child_QMARK_$$($objects$jscomp$721$$,
$p1__74858_SHARP_$$)},$map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$);return $APP.$cljs$core$seq$$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($shape$jscomp$911$$){return $APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__74859_SHARP_$$){return $app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$721$$,$shape$jscomp$911$$,$p1__74859_SHARP_$$)},$app$main$ui$inspect$attributes$layout_element$properties$$)},
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$])))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_layout_element__attributes-block",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!1,title:$only_flex_QMARK_$$?"Flex element":$only_grid_QMARK_$$?"Flex element":"Layout element",className:"main_ui_inspect_attributes_layout_element__title-wrapper",
titleClass:"main_ui_inspect_attributes_layout_element__layout-element-attr-title",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$),1)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$util$code_gen$style_css$get_shape_properties_css$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$721$$,$APP.$cljs$core$first$$($map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$),
$app$main$ui$inspect$attributes$layout_element$properties$$),className:"main_ui_inspect_attributes_layout_element__copy-btn-title"}):null}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$69$$,$shape$jscomp$912$$){$out_arr__44124__auto__$jscomp$69$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$layout_element$layout_element_block$$,{shape:$shape$jscomp$912$$,objects:$objects$jscomp$721$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$912$$)));
return $out_arr__44124__auto__$jscomp$69$$},[],$map__74861_map__74861__$1_props_74860_shapes$jscomp$155_shapes__$1$jscomp$22$$)]}):null};$app$main$ui$inspect$attributes$shadow$has_shadow_QMARK_$$=function($shape$jscomp$913$$){return $APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$913$$)};
$app$main$ui$inspect$attributes$shadow$copy_color_data$$=function($color$jscomp$128$$,$format$jscomp$38$$){return $app$util$code_gen$style_css_formats$format_color_value$$($color$jscomp$128$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$954$format$$,$format$jscomp$38$$],null))};
$app$main$ui$inspect$attributes$shadow$shadow_block$$=function($map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$){$map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$=$APP.$rumext$v2$util$wrap_props$$($map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$);$map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$=$APP.$cljs$core$__destructure_map$$($map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$);$map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$,$APP.$cljs$cst$1654$shadow$$);var $color_format$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2687$hex$$),$color_format_STAR_$$=$APP.$cljs$core$_deref$$($color_format$$),$label$jscomp$36$$=$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$)),
$on_change_format$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($format$jscomp$39$$){return $APP.$cljs$core$reset_BANG_$$($color_format$$,$format$jscomp$39$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_shadow__attributes-shadow-block",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_shadow__shadow-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:$label$jscomp$36$$}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:"box-shadow: "+($app$util$code_gen$style_css_formats$format_shadow__GT_css$$($map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)??"")+";",className:"main_ui_inspect_attributes_shadow__color-row-copy-btn",children:(0,$APP.$rumext$v2$jsxs$$)("div",{title:""+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.offsetx")??
"")+" "+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.offsety")??"")+" "+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.blur")??"")+" "+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.spread")??""),className:"main_ui_inspect_attributes_shadow__button-children",children:[[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1650$offset_x$$.$cljs$core$IFn$_invoke$arity$1$($map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$)),
"px"].join("")," ",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1651$offset_y$$.$cljs$core$IFn$_invoke$arity$1$($map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$)),"px"].join("")," ",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$)),"px"].join("")," ",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1652$spread$$.$cljs$core$IFn$_invoke$arity$1$($map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$)),
"px"].join("")]})})})]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$common$color_row$$,{color:$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$),format:$APP.$cljs$core$_deref$$($color_format$$),"copy-data":$app$main$ui$inspect$attributes$shadow$copy_color_data$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($map__74863_map__74863__$1_props_74862_shadow__$1$jscomp$13$$),$color_format_STAR_$$),"on-change-format":$on_change_format$jscomp$1$$})]})};
$app$main$ui$inspect$attributes$shadow$shadow_panel$$=function($map__74866_map__74866__$1_props_74865_shapes$jscomp$156_shapes__$1$jscomp$23$$){$map__74866_map__74866__$1_props_74865_shapes$jscomp$156_shapes__$1$jscomp$23$$=$APP.$rumext$v2$util$wrap_props$$($map__74866_map__74866__$1_props_74865_shapes$jscomp$156_shapes__$1$jscomp$23$$);$map__74866_map__74866__$1_props_74865_shapes$jscomp$156_shapes__$1$jscomp$23$$=$APP.$cljs$core$__destructure_map$$($map__74866_map__74866__$1_props_74865_shapes$jscomp$156_shapes__$1$jscomp$23$$);
$map__74866_map__74866__$1_props_74865_shapes$jscomp$156_shapes__$1$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74866_map__74866__$1_props_74865_shapes$jscomp$156_shapes__$1$jscomp$23$$,$APP.$cljs$cst$1614$shapes$$);$map__74866_map__74866__$1_props_74865_shapes$jscomp$156_shapes__$1$jscomp$23$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$attributes$shadow$has_shadow_QMARK_$$,$map__74866_map__74866__$1_props_74865_shapes$jscomp$156_shapes__$1$jscomp$23$$);
return $APP.$cljs$core$seq$$($map__74866_map__74866__$1_props_74865_shapes$jscomp$156_shapes__$1$jscomp$23$$)&&$APP.$cljs$core$count$$($map__74866_map__74866__$1_props_74865_shapes$jscomp$156_shapes__$1$jscomp$23$$)>0?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_shadow__attributes-block",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$title_bar$inspect_title_bar_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.shadow"),
className:"main_ui_inspect_attributes_shadow__title-wrapper",titleClass:"main_ui_inspect_attributes_shadow__shadow-attr-title"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_shadow__attributes-content",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$70$$,$shape$jscomp$914$$){$out_arr__44124__auto__$jscomp$70$$.push($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$4$$,
$shadow__$1$jscomp$14$$){$out_arr__44124__auto____$1$jscomp$4$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$shadow$shadow_block$$,{shape:$shape$jscomp$914$$,shadow:$shadow__$1$jscomp$14$$},"block-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$914$$)??"")+"-shadow"));return $out_arr__44124__auto____$1$jscomp$4$$},[],$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$914$$)));return $out_arr__44124__auto__$jscomp$70$$},[],$map__74866_map__74866__$1_props_74865_shapes$jscomp$156_shapes__$1$jscomp$23$$)})]}):
null};
$app$main$ui$inspect$attributes$stroke$stroke__GT_color$$=function($shape$jscomp$915$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1739$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$915$$),$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1740$stroke_opacity$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$915$$),$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$cst$1741$stroke_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$915$$),$APP.$cljs$cst$266$id$$,
$APP.$cljs$cst$1742$stroke_color_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$915$$),$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$1641$stroke_color_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$915$$),$APP.$cljs$cst$1612$image$$,$APP.$cljs$cst$1635$stroke_image$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$915$$)],null)};$app$main$ui$inspect$attributes$stroke$has_stroke_QMARK_$$=function($shape$jscomp$916$$){return $APP.$cljs$core$seq$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$916$$))};
$app$main$ui$inspect$attributes$stroke$stroke_block$$=function($format$jscomp$40_props_74864$$){var $stroke$jscomp$29$$=$format$jscomp$40_props_74864$$.stroke,$objects$jscomp$722$$=$format$jscomp$40_props_74864$$.objects,$shape$jscomp$917$$=$format$jscomp$40_props_74864$$.shape,$format_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2687$hex$$);$format$jscomp$40_props_74864$$=$APP.$cljs$core$_deref$$($format_STAR_$jscomp$1$$);var $color$jscomp$129$$=
$app$main$ui$inspect$attributes$stroke$stroke__GT_color$$($stroke$jscomp$29$$),$on_change$jscomp$29$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($format__$1$jscomp$2$$){return $APP.$cljs$core$reset_BANG_$$($format_STAR_$jscomp$1$$,$format__$1$jscomp$2$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_stroke__attributes-fill-block",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$71$$,
$JSCompiler_inline_result$jscomp$1409_property$jscomp$49$$){var $JSCompiler_temp_const$jscomp$1407$$=$out_arr__44124__auto__$jscomp$71$$.push,$property_name$jscomp$inline_7893$$=$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($JSCompiler_inline_result$jscomp$1409_property$jscomp$49$$),$property_value$jscomp$inline_7894$$=$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$722$$,$stroke$jscomp$29$$,$JSCompiler_inline_result$jscomp$1409_property$jscomp$49$$);
$JSCompiler_inline_result$jscomp$1409_property$jscomp$49$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_stroke__stroke-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:$property_name$jscomp$inline_7893$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$722$$,
$stroke$jscomp$29$$,$JSCompiler_inline_result$jscomp$1409_property$jscomp$49$$),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_stroke__button-children",children:$property_value$jscomp$inline_7894$$})})})]},["stroke-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$917$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1409_property$jscomp$49$$)].join(""));
$JSCompiler_temp_const$jscomp$1407$$.call($out_arr__44124__auto__$jscomp$71$$,$JSCompiler_inline_result$jscomp$1409_property$jscomp$49$$);return $out_arr__44124__auto__$jscomp$71$$},[],$app$main$ui$inspect$attributes$stroke$properties$$),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$common$color_row$$,{color:$color$jscomp$129$$,property:"Border color",format:$format$jscomp$40_props_74864$$,"on-change-format":$on_change$jscomp$29$$,"copy-data":$app$util$code_gen$style_css$get_shape_properties_css$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$722$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1636$strokes$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$917$$],null)],null),$app$main$ui$inspect$attributes$stroke$properties$$)})]})};
$app$main$ui$inspect$attributes$stroke$stroke_block_styles_STAR_$$=function($color$jscomp$130_props_74867$$){var $color_space$jscomp$2$$=$color$jscomp$130_props_74867$$.colorSpace,$stroke$jscomp$30$$=$color$jscomp$130_props_74867$$.stroke,$objects$jscomp$723$$=$color$jscomp$130_props_74867$$.objects,$shape$jscomp$918$$=$color$jscomp$130_props_74867$$.shape;$color$jscomp$130_props_74867$$=$app$main$ui$inspect$attributes$stroke$stroke__GT_color$$($stroke$jscomp$30$$);return(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_inspect_attributes_stroke__attributes-fill-block",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$72$$,$JSCompiler_inline_result$jscomp$1412_property$jscomp$50$$){var $JSCompiler_temp_const$jscomp$1410$$=$out_arr__44124__auto__$jscomp$72$$.push,$property_name$jscomp$inline_7896$$=$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($JSCompiler_inline_result$jscomp$1412_property$jscomp$50$$),$property_value$jscomp$inline_7897$$=
$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$723$$,$stroke$jscomp$30$$,$JSCompiler_inline_result$jscomp$1412_property$jscomp$50$$);$JSCompiler_inline_result$jscomp$1412_property$jscomp$50$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_stroke__stroke-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:$property_name$jscomp$inline_7896$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$723$$,$stroke$jscomp$30$$,$JSCompiler_inline_result$jscomp$1412_property$jscomp$50$$),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_stroke__button-children",children:$property_value$jscomp$inline_7897$$})})})]},["stroke-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$918$$)),
"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1412_property$jscomp$50$$)].join(""));$JSCompiler_temp_const$jscomp$1410$$.call($out_arr__44124__auto__$jscomp$72$$,$JSCompiler_inline_result$jscomp$1412_property$jscomp$50$$);return $out_arr__44124__auto__$jscomp$72$$},[],$app$main$ui$inspect$attributes$stroke$properties$$),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$common$color_row$$,{color:$color$jscomp$130_props_74867$$,property:"Border color",
format:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($color_space$jscomp$2$$),$APP.$cljs$cst$2687$hex$$),copyData:$app$util$code_gen$style_css$get_shape_properties_css$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$723$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1636$strokes$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$918$$],null)],
null),$app$main$ui$inspect$attributes$stroke$properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$954$format$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($color_space$jscomp$2$$)],null))})]})};
$app$main$ui$inspect$attributes$stroke$stroke_panel_STAR_$$=function($props_74868_shapes__$1$jscomp$24$$){var $color_space$jscomp$3$$=$props_74868_shapes__$1$jscomp$24$$.colorSpace;$props_74868_shapes__$1$jscomp$24$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$attributes$stroke$has_stroke_QMARK_$$,$props_74868_shapes__$1$jscomp$24$$.shapes);return $APP.$cljs$core$seq$$($props_74868_shapes__$1$jscomp$24$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_stroke__attributes-block",
children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$title_bar$inspect_title_bar_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.stroke"),className:"main_ui_inspect_attributes_stroke__title-wrapper",titleClass:"main_ui_inspect_attributes_stroke__stroke-attr-title"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_stroke__attributes-content",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$73$$,
$shape$jscomp$919$$){$out_arr__44124__auto__$jscomp$73$$.push($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$5$$,$stroke$jscomp$31$$){$out_arr__44124__auto____$1$jscomp$5$$.push($APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1220$inspect_styles$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$stroke$stroke_block_styles_STAR_$$,{shape:$shape$jscomp$919$$,colorSpace:$color_space$jscomp$3$$,stroke:$stroke$jscomp$31$$},
["stroke-color-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$919$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$31$$)].join("")):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$stroke$stroke_block$$,{shape:$shape$jscomp$919$$,stroke:$stroke$jscomp$31$$},["stroke-color-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$919$$)),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$31$$)].join("")));return $out_arr__44124__auto____$1$jscomp$5$$},[],$APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$919$$)));return $out_arr__44124__auto__$jscomp$73$$},[],$props_74868_shapes__$1$jscomp$24$$)})]}):null};
$app$main$ui$inspect$attributes$svg$map__GT_css$$=function($attr$jscomp$59$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("; ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($attr_value$jscomp$1_p__74869$$){var $attr_key$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value$jscomp$1_p__74869$$,0,null);$attr_value$jscomp$1_p__74869$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value$jscomp$1_p__74869$$,1,null);return[$APP.$app$common$data$name$$($attr_key$jscomp$1$$),
":",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attr_value$jscomp$1_p__74869$$)].join("")},$attr$jscomp$59$$))};
$app$main$ui$inspect$attributes$svg$svg_block$$=function($map__74880_map__74880__$1_props_74879_shape$jscomp$920$$){$map__74880_map__74880__$1_props_74879_shape$jscomp$920$$=$APP.$rumext$v2$util$wrap_props$$($map__74880_map__74880__$1_props_74879_shape$jscomp$920$$);$map__74880_map__74880__$1_props_74879_shape$jscomp$920$$=$APP.$cljs$core$__destructure_map$$($map__74880_map__74880__$1_props_74879_shape$jscomp$920$$);$map__74880_map__74880__$1_props_74879_shape$jscomp$920$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74880_map__74880__$1_props_74879_shape$jscomp$920$$,
$APP.$cljs$cst$1811$shape$$);return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$75$$,$attr_value$jscomp$3_p__74881$$){var $attr_key$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value$jscomp$3_p__74881$$,0,null);$attr_value$jscomp$3_p__74881$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value$jscomp$3_p__74881$$,1,null);$out_arr__44124__auto__$jscomp$75$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$svg$svg_attr$$,
{attr:$attr_key$jscomp$3$$,value:$attr_value$jscomp$3_p__74881$$},$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("svg-block-key-",$APP.$app$common$data$name$$($attr_key$jscomp$3$$))));return $out_arr__44124__auto__$jscomp$75$$},[],$APP.$cljs$cst$1890$svg_attrs$$.$cljs$core$IFn$_invoke$arity$1$($map__74880_map__74880__$1_props_74879_shape$jscomp$920$$))})};
$app$main$ui$inspect$attributes$svg$svg_panel$$=function($map__74886_map__74886__$1_props_74885_shape$jscomp$921_shapes$jscomp$158$$){$map__74886_map__74886__$1_props_74885_shape$jscomp$921_shapes$jscomp$158$$=$APP.$rumext$v2$util$wrap_props$$($map__74886_map__74886__$1_props_74885_shape$jscomp$921_shapes$jscomp$158$$);$map__74886_map__74886__$1_props_74885_shape$jscomp$921_shapes$jscomp$158$$=$APP.$cljs$core$__destructure_map$$($map__74886_map__74886__$1_props_74885_shape$jscomp$921_shapes$jscomp$158$$);
$map__74886_map__74886__$1_props_74885_shape$jscomp$921_shapes$jscomp$158$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74886_map__74886__$1_props_74885_shape$jscomp$921_shapes$jscomp$158$$,$APP.$cljs$cst$1614$shapes$$);$map__74886_map__74886__$1_props_74885_shape$jscomp$921_shapes$jscomp$158$$=$APP.$cljs$core$first$$($map__74886_map__74886__$1_props_74885_shape$jscomp$921_shapes$jscomp$158$$);return $APP.$cljs$core$seq$$($APP.$cljs$cst$1890$svg_attrs$$.$cljs$core$IFn$_invoke$arity$1$($map__74886_map__74886__$1_props_74885_shape$jscomp$921_shapes$jscomp$158$$))?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_svg__attributes-block",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$title_bar$inspect_title_bar_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.options.svg-attrs.title"),className:"main_ui_inspect_attributes_svg__title-wrapper",titleClass:"main_ui_inspect_attributes_svg__svg-attr-title"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$svg$svg_block$$,{shape:$map__74886_map__74886__$1_props_74885_shape$jscomp$921_shapes$jscomp$158$$})]}):
null};
$app$main$ui$inspect$common$typography$make_typographies_library_ref$$=function($file_id$jscomp$353$$){function $get_library$jscomp$1$$($state$jscomp$1160$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1160$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5328$viewer_libraries$$,$file_id$jscomp$353$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2215$typographies$$],null))}return function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($get_library$jscomp$1$$,$APP.$app$main$store$state$$)}};
$app$main$ui$inspect$common$typography$get_typography$$=function($or__5025__auto__$jscomp$inline_13054_style$jscomp$61$$){var $typography_library_typography_library_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$1642$typography_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$inline_13054_style$jscomp$61$$))],$app$main$ui$inspect$common$typography$make_typographies_library_ref$$($APP.$cljs$cst$1642$typography_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$inline_13054_style$jscomp$61$$)));
$typography_library_typography_library_ref$$=$APP.$rumext$v2$deref$$($typography_library_typography_library_ref$$);var $file_typographies_viewer$$=$APP.$rumext$v2$deref$$($app$main$ui$inspect$common$typography$file_typographies_ref$$),$file_typographies_workspace$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_file_typography$$),$file_library_workspace_typography_external_lib$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$),$APP.$cljs$cst$1642$typography_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$inline_13054_style$jscomp$61$$));
$file_library_workspace_typography_external_lib$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file_library_workspace_typography_external_lib$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2215$typographies$$,$APP.$cljs$cst$1756$typography_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$inline_13054_style$jscomp$61$$)],null));$or__5025__auto__$jscomp$inline_13054_style$jscomp$61$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($typography_library_typography_library_ref$$)?$typography_library_typography_library_ref$$:$APP.$cljs$core$truth_$$($file_typographies_viewer$$)?$file_typographies_viewer$$:$file_typographies_workspace$$,$APP.$cljs$cst$1756$typography_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$inline_13054_style$jscomp$61$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_13054_style$jscomp$61$$)?
$or__5025__auto__$jscomp$inline_13054_style$jscomp$61$$:$file_library_workspace_typography_external_lib$$};$app$main$ui$inspect$attributes$text$has_text_QMARK_$$=function($shape$jscomp$922$$){return $APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$922$$)};
$app$main$ui$inspect$attributes$text$copy_style_data$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($style$jscomp$62$$,$properties$jscomp$103$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74887_SHARP_$$){return""+($APP.$app$common$data$name$$($p1__74887_SHARP_$$)??"")+": "+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($style$jscomp$62$$,$p1__74887_SHARP_$$)??"")+";"},$properties$jscomp$103$$))};
$app$main$ui$inspect$attributes$text$typography_block$$=function($map__74898_props_74892_text$jscomp$69$$){$map__74898_props_74892_text$jscomp$69$$=$APP.$rumext$v2$util$wrap_props$$($map__74898_props_74892_text$jscomp$69$$);var $map__74898__$1_style$jscomp$63$$=$APP.$cljs$core$__destructure_map$$($map__74898_props_74892_text$jscomp$69$$);$map__74898_props_74892_text$jscomp$69$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74898__$1_style$jscomp$63$$,$APP.$cljs$cst$1588$text$$);$map__74898__$1_style$jscomp$63$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74898__$1_style$jscomp$63$$,$APP.$cljs$cst$1904$style$$);var $color_format_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2687$hex$$),$color_format$jscomp$1$$=$APP.$cljs$core$_deref$$($color_format_STAR_$jscomp$1$$),$typography$jscomp$28$$=$app$main$ui$inspect$common$typography$get_typography$$($map__74898__$1_style$jscomp$63$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_text__attributes-content",
children:[$APP.$cljs$core$truth_$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$76$$,$fill$jscomp$23_p__74904$$){var $idx$jscomp$104$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill$jscomp$23_p__74904$$,0,null);$fill$jscomp$23_p__74904$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill$jscomp$23_p__74904$$,1,null);$out_arr__44124__auto__$jscomp$76$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$common$color_row$$,
{format:$color_format$jscomp$1$$,color:$APP.$app$common$types$fills$fill__GT_color$$($fill$jscomp$23_p__74904$$),"copy-data":$app$main$ui$inspect$attributes$text$copy_style_data$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($fill$jscomp$23_p__74904$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1746$fill_color$$,$APP.$cljs$cst$1748$fill_color_gradient$$])),"on-change-format":function($p1__74890_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($color_format_STAR_$jscomp$1$$,
$p1__74890_SHARP_$$)}},$idx$jscomp$104$$));return $out_arr__44124__auto__$jscomp$76$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1756$typography_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_text__text-row",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$main$ui$inspect$attributes$text$copy_style_data$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($typography$jscomp$28$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1758$font_family$$,
$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1762$font_style$$])),className:"main_ui_inspect_attributes_text__copy-btn-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_text__button-children",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$28$$)})})})]}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_text__text-row",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:"Font Family"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$main$ui$inspect$attributes$text$copy_style_data$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($map__74898__$1_style$jscomp$63$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1758$font_family$$])),children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_inspect_attributes_text__button-children",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$fonts$get_font_data$$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$)))})})})]}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_text__text-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"attr-label",children:"Font Style"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$main$ui$inspect$attributes$text$copy_style_data$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($map__74898__$1_style$jscomp$63$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1762$font_style$$])),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_text__button-children",
children:""+($APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$)??"")})})})]}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_text__text-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:"Font Size"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,
{data:$app$main$ui$inspect$attributes$text$copy_style_data$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__74898__$1_style$jscomp$63$$,$APP.$cljs$cst$1760$font_size$$,$APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1760$font_size$$])),children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_inspect_attributes_text__button-children",children:$APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))})})})]}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_text__text-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"attr-label",children:"Font Weight"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$main$ui$inspect$attributes$text$copy_style_data$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($map__74898__$1_style$jscomp$63$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1761$font_weight$$])),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_text__button-children",
children:""+($APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$)??"")})})})]}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1765$line_height$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_text__text-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:"Line Height"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,
{data:$app$main$ui$inspect$attributes$text$copy_style_data$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($map__74898__$1_style$jscomp$63$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1765$line_height$$])),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_text__button-children",children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1765$line_height$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))})})})]}):
null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1766$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_text__text-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:"Letter Spacing"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$main$ui$inspect$attributes$text$copy_style_data$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($map__74898__$1_style$jscomp$63$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1766$letter_spacing$$])),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_text__button-children",children:$APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1766$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))})})})]}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_text__text-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:"Text Decoration"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$main$ui$inspect$attributes$text$copy_style_data$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($map__74898__$1_style$jscomp$63$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1768$text_decoration$$])),
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_text__button-children",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.text-decoration."+($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$)??""))})})})]}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$))?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_inspect_attributes_text__text-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:"Text Transform"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$main$ui$inspect$attributes$text$copy_style_data$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($map__74898__$1_style$jscomp$63$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1769$text_transform$$])),
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_text__button-children",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.text-transform."+($APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$)??""))})})})]}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($map__74898_props_74892_text$jscomp$69$$),
className:"main_ui_inspect_attributes_text__attributes-content-row",children:(0,$APP.$rumext$v2$jsx$$)("span",{style:{fontFamily:$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$),fontWeight:$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$),fontStyle:$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($map__74898__$1_style$jscomp$63$$)},className:"main_ui_inspect_attributes_text__content",
children:$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($map__74898_props_74892_text$jscomp$69$$)})})]})};
$app$main$ui$inspect$attributes$text$text_block$$=function($map__74916_map__74916__$1_props_74913_style_text_blocks$$){$map__74916_map__74916__$1_props_74913_style_text_blocks$$=$APP.$rumext$v2$util$wrap_props$$($map__74916_map__74916__$1_props_74913_style_text_blocks$$);$map__74916_map__74916__$1_props_74913_style_text_blocks$$=$APP.$cljs$core$__destructure_map$$($map__74916_map__74916__$1_props_74913_style_text_blocks$$);var $shape$jscomp$923$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74916_map__74916__$1_props_74913_style_text_blocks$$,
$APP.$cljs$cst$1811$shape$$);$map__74916_map__74916__$1_props_74913_style_text_blocks$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__74918_text$jscomp$70$$){var $style$jscomp$64$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74918_text$jscomp$70$$,0,null);$p__74918_text$jscomp$70$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74918_text$jscomp$70$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$get_default_text_attrs$$(),$style$jscomp$64$$])),$p__74918_text$jscomp$70$$],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p__74922_text$jscomp$71$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74922_text$jscomp$71$$,0,null);$p__74922_text$jscomp$71$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74922_text$jscomp$71$$,
1,null);return $APP.$cuerdas$core$empty_QMARK_$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($p__74922_text$jscomp$71$$))},$app$common$text$content__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$923$$))));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$77$$,$full_style_p__74926$$){var $idx$jscomp$105$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($full_style_p__74926$$,
0,null),$text$jscomp$72_vec__74933$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($full_style_p__74926$$,1,null);$full_style_p__74926$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text$jscomp$72_vec__74933$$,0,null);$text$jscomp$72_vec__74933$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text$jscomp$72_vec__74933$$,1,null);$out_arr__44124__auto__$jscomp$77$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$text$typography_block$$,{shape:$shape$jscomp$923$$,
style:$full_style_p__74926$$,text:$text$jscomp$72_vec__74933$$},$idx$jscomp$105$$));return $out_arr__44124__auto__$jscomp$77$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$map__74916_map__74916__$1_props_74913_style_text_blocks$$))};
$app$main$ui$inspect$attributes$text$text_panel$$=function($map__74937_map__74937__$1_props_74936_shapes$jscomp$159_temp__5825__auto__$jscomp$300$$){$map__74937_map__74937__$1_props_74936_shapes$jscomp$159_temp__5825__auto__$jscomp$300$$=$APP.$rumext$v2$util$wrap_props$$($map__74937_map__74937__$1_props_74936_shapes$jscomp$159_temp__5825__auto__$jscomp$300$$);$map__74937_map__74937__$1_props_74936_shapes$jscomp$159_temp__5825__auto__$jscomp$300$$=$APP.$cljs$core$__destructure_map$$($map__74937_map__74937__$1_props_74936_shapes$jscomp$159_temp__5825__auto__$jscomp$300$$);
$map__74937_map__74937__$1_props_74936_shapes$jscomp$159_temp__5825__auto__$jscomp$300$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74937_map__74937__$1_props_74936_shapes$jscomp$159_temp__5825__auto__$jscomp$300$$,$APP.$cljs$cst$1614$shapes$$);return($map__74937_map__74937__$1_props_74936_shapes$jscomp$159_temp__5825__auto__$jscomp$300$$=$APP.$cljs$core$seq$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$attributes$text$has_text_QMARK_$$,$map__74937_map__74937__$1_props_74936_shapes$jscomp$159_temp__5825__auto__$jscomp$300$$)))?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_text__attributes-block",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$title_bar$inspect_title_bar_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography"),className:"main_ui_inspect_attributes_text__title-wrapper",titleClass:"main_ui_inspect_attributes_text__text-atrr-title"}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$78$$,
$shape$jscomp$924$$){$out_arr__44124__auto__$jscomp$78$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$text$text_block$$,{shape:$shape$jscomp$924$$},"text-block"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$924$$)??"")));return $out_arr__44124__auto__$jscomp$78$$},[],$map__74937_map__74937__$1_props_74936_shapes$jscomp$159_temp__5825__auto__$jscomp$300$$)]}):null};
$app$main$ui$inspect$attributes$variant$variant_block_STAR_$$=function($props_74891$$){var $value$jscomp$761$$=$props_74891$$.value;return(0,$APP.$rumext$v2$jsxs$$)("div",{title:$value$jscomp$761$$,className:"main_ui_inspect_attributes_variant__variant-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:$props_74891$$.name}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,
{data:$value$jscomp$761$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_variant__button-children",children:$value$jscomp$761$$})})})]})};
$app$main$ui$inspect$attributes$variant$variant_panel_STAR_$$=function($properties$jscomp$104_props_74896$$){var $file_id$jscomp$354$$=$properties$jscomp$104_props_74896$$.fileId,$libraries$jscomp$130$$=$properties$jscomp$104_props_74896$$.libraries,$objects$jscomp$724$$=$properties$jscomp$104_props_74896$$.objects,$shape$jscomp$925$$=$APP.$cljs$core$first$$($properties$jscomp$104_props_74896$$.shapes),$is_container_QMARK_$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$925$$);
$properties$jscomp$104_props_74896$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$724$$),$APP.$rumext$v2$adapt$$($shape$jscomp$925$$)],function(){var $data$jscomp$450$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$130$$,$file_id$jscomp$354$$),$APP.$cljs$cst$142$data$$),$component$jscomp$118$$=$APP.$cljs$core$truth_$$($is_container_QMARK_$$)?null:$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$450$$,
$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$925$$));return $APP.$cljs$core$truth_$$($is_container_QMARK_$$)?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74894_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__74894_SHARP_$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cuerdas$core$join$$,", "))},$APP.$app$common$files$variant$extract_properties_values$$($data$jscomp$450$$,
$objects$jscomp$724$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$925$$))):$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74895_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__74895_SHARP_$$,$APP.$cljs$cst$260$value$$,function($v$jscomp$629$$){return $APP.$cuerdas$core$blank_QMARK_$$($v$jscomp$629$$)?"--":$v$jscomp$629$$})},$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$118$$))});
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_variant__attributes-block",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$title_bar$inspect_title_bar_STAR_$$,{title:$APP.$cljs$core$truth_$$($is_container_QMARK_$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.variants"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.variant"),className:"main_ui_inspect_attributes_variant__title-wrapper",titleClass:"main_ui_inspect_attributes_variant__variant-attr-title"}),
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$79$$,$p__74899_property$jscomp$51$$){var $pos$jscomp$131$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74899_property$jscomp$51$$,0,null);$p__74899_property$jscomp$51$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74899_property$jscomp$51$$,1,null);$out_arr__44124__auto__$jscomp$79$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$variant$variant_block_STAR_$$,
{name:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p__74899_property$jscomp$51$$),value:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p__74899_property$jscomp$51$$)},"variant-property-"+($pos$jscomp$131$$??"")));return $out_arr__44124__auto__$jscomp$79$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$properties$jscomp$104_props_74896$$))]})};
$app$main$ui$inspect$attributes$visibility$has_visibility_props_QMARK_$$=function($shape$jscomp$926$$){var $and__5023__auto__$jscomp$653_or__5025__auto__$jscomp$997_or__5025__auto____$1$jscomp$110_shape_type$jscomp$5$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$926$$);if($and__5023__auto__$jscomp$653_or__5025__auto__$jscomp$997_or__5025__auto____$1$jscomp$110_shape_type$jscomp$5$$=!($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$653_or__5025__auto__$jscomp$997_or__5025__auto____$1$jscomp$110_shape_type$jscomp$5$$,
$APP.$cljs$cst$1588$text$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$653_or__5025__auto__$jscomp$997_or__5025__auto____$1$jscomp$110_shape_type$jscomp$5$$,$APP.$cljs$cst$1608$group$$))){$and__5023__auto__$jscomp$653_or__5025__auto__$jscomp$997_or__5025__auto____$1$jscomp$110_shape_type$jscomp$5$$=$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$926$$);if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$653_or__5025__auto__$jscomp$997_or__5025__auto____$1$jscomp$110_shape_type$jscomp$5$$))return $and__5023__auto__$jscomp$653_or__5025__auto__$jscomp$997_or__5025__auto____$1$jscomp$110_shape_type$jscomp$5$$;
$and__5023__auto__$jscomp$653_or__5025__auto__$jscomp$997_or__5025__auto____$1$jscomp$110_shape_type$jscomp$5$$=$APP.$cljs$cst$1867$blend_mode$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$926$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$653_or__5025__auto__$jscomp$997_or__5025__auto____$1$jscomp$110_shape_type$jscomp$5$$)?$and__5023__auto__$jscomp$653_or__5025__auto__$jscomp$997_or__5025__auto____$1$jscomp$110_shape_type$jscomp$5$$:$cljs$cst$2933$visibility$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$926$$)}return $and__5023__auto__$jscomp$653_or__5025__auto__$jscomp$997_or__5025__auto____$1$jscomp$110_shape_type$jscomp$5$$};
$app$main$ui$inspect$attributes$visibility$visibility_block_STAR_$$=function($props_74893$$){var $objects$jscomp$725$$=$props_74893$$.objects,$shape$jscomp$927$$=$props_74893$$.shape;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$80$$,$JSCompiler_inline_result$jscomp$1415_property$jscomp$52$$){var $JSCompiler_temp_const$jscomp$1413$$=$out_arr__44124__auto__$jscomp$80$$.push;var $temp__5825__auto__$jscomp$inline_7899$$=$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$725$$,
$shape$jscomp$927$$,$JSCompiler_inline_result$jscomp$1415_property$jscomp$52$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_7899$$)){var $property_name$jscomp$inline_7900$$=$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($JSCompiler_inline_result$jscomp$1415_property$jscomp$52$$);$JSCompiler_inline_result$jscomp$1415_property$jscomp$52$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_visibility__visibility-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{title:$property_name$jscomp$inline_7900$$,className:"attr-label",children:$property_name$jscomp$inline_7900$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$725$$,$shape$jscomp$927$$,$JSCompiler_inline_result$jscomp$1415_property$jscomp$52$$),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_attributes_visibility__button-children",
children:$temp__5825__auto__$jscomp$inline_7899$$})})})]},$APP.$app$common$data$name$$($JSCompiler_inline_result$jscomp$1415_property$jscomp$52$$))}else $JSCompiler_inline_result$jscomp$1415_property$jscomp$52$$=null;$JSCompiler_temp_const$jscomp$1413$$.call($out_arr__44124__auto__$jscomp$80$$,$JSCompiler_inline_result$jscomp$1415_property$jscomp$52$$);return $out_arr__44124__auto__$jscomp$80$$},[],$app$main$ui$inspect$attributes$visibility$properties$$)};
$app$main$ui$inspect$attributes$visibility$visibility_panel_STAR_$$=function($props_74909_shapes__$1$jscomp$26$$){var $shapes$jscomp$161$$=$props_74909_shapes__$1$jscomp$26$$.shapes,$objects$jscomp$726$$=$props_74909_shapes__$1$jscomp$26$$.objects;$props_74909_shapes__$1$jscomp$26$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$161$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$attributes$visibility$has_visibility_props_QMARK_$$,
$shapes$jscomp$161$$)});return $APP.$cljs$core$seq$$($props_74909_shapes__$1$jscomp$26$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_visibility__attributes-block",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$title_bar$inspect_title_bar_STAR_$$,{title:"Visibility",className:"main_ui_inspect_attributes_visibility__title-wrapper",titleClass:"main_ui_inspect_attributes_visibility__visibility-attr-title",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($props_74909_shapes__$1$jscomp$26$$),
1)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$util$code_gen$style_css$get_shape_properties_css$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$726$$,$APP.$cljs$core$first$$($props_74909_shapes__$1$jscomp$26$$),$app$main$ui$inspect$attributes$visibility$properties$$),className:"main_ui_inspect_attributes_visibility__copy-btn-title"}):null}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$81$$,
$shape$jscomp$928$$){$out_arr__44124__auto__$jscomp$81$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$visibility$visibility_block_STAR_$$,{shape:$shape$jscomp$928$$,objects:$objects$jscomp$726$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$928$$)));return $out_arr__44124__auto__$jscomp$81$$},[],$props_74909_shapes__$1$jscomp$26$$)]}):null};
$app$main$ui$inspect$attributes$attributes_STAR_$$=function($data$jscomp$451_props_74945_type$jscomp$599$$){var $color_space$jscomp$4$$=$data$jscomp$451_props_74945_type$jscomp$599$$.colorSpace,$frame$jscomp$50$$=$data$jscomp$451_props_74945_type$jscomp$599$$.frame,$file_id$jscomp$356$$=$data$jscomp$451_props_74945_type$jscomp$599$$.fileId,$libraries$jscomp$131$$=$data$jscomp$451_props_74945_type$jscomp$599$$.libraries,$objects$jscomp$727$$=$data$jscomp$451_props_74945_type$jscomp$599$$.objects,$page_id$jscomp$410$$=
$data$jscomp$451_props_74945_type$jscomp$599$$.pageId,$from$jscomp$23$$=$data$jscomp$451_props_74945_type$jscomp$599$$.from,$share_id$jscomp$23$$=$data$jscomp$451_props_74945_type$jscomp$599$$.shareId,$shapes__$1$jscomp$27$$=$APP.$app$main$ui$hooks$use_equal_memo$$($data$jscomp$451_props_74945_type$jscomp$599$$.shapes),$first_shape$jscomp$7$$=$APP.$cljs$core$first$$($shapes__$1$jscomp$27$$);$data$jscomp$451_props_74945_type$jscomp$599$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$131$$,
$file_id$jscomp$356$$),$APP.$cljs$cst$142$data$$);var $first_component$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$451_props_74945_type$jscomp$599$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$7$$));$data$jscomp$451_props_74945_type$jscomp$599$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$654_or__5025__auto__$jscomp$998$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes__$1$jscomp$27$$),
1);return $and__5023__auto__$jscomp$654_or__5025__auto__$jscomp$998$$?($and__5023__auto__$jscomp$654_or__5025__auto__$jscomp$998$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($first_shape$jscomp$7$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$654_or__5025__auto__$jscomp$998$$)?$and__5023__auto__$jscomp$654_or__5025__auto__$jscomp$998$$:$APP.$app$common$types$component$is_variant_QMARK_$$($first_component$$)):$and__5023__auto__$jscomp$654_or__5025__auto__$jscomp$998$$}())?
$APP.$cljs$cst$1994$variant$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes__$1$jscomp$27$$),1)?$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$7$$):$APP.$cljs$cst$1616$multiple$$;var $options$jscomp$601$$=$app$main$ui$inspect$attributes$type__GT_options$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$ui$inspect$attributes$type__GT_options$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$451_props_74945_type$jscomp$599$$):$app$main$ui$inspect$attributes$type__GT_options$$($data$jscomp$451_props_74945_type$jscomp$599$$),
$annotation_content$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes__$1$jscomp$27$$),1)?$app$common$types$components_list$get_component_annotation$$($first_shape$jscomp$7$$,$libraries$jscomp$131$$):null;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes__element-options "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from$jscomp$23$$,$APP.$cljs$cst$2532$workspace$$)?"main_ui_inspect_attributes__workspace-element-options":
""),children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$83$$,$p__74946$$){var $idx$jscomp$106$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74946$$,0,null),$option$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74946$$,1,null);$out_arr__44124__auto__$jscomp$83$$.push((0,$APP.$rumext$v2$jsx$$)(function(){var $G__74950__$1$$=$option$jscomp$15$$ instanceof $APP.$cljs$core$Keyword$$?$option$jscomp$15$$.$fqn$:
null;switch($G__74950__$1$$){case "geometry":return $app$main$ui$inspect$attributes$geometry$geometry_panel$$;case "layout":return $app$main$ui$inspect$attributes$layout$layout_panel$$;case "layout-element":return $app$main$ui$inspect$attributes$layout_element$layout_element_panel$$;case "fill":return $app$main$ui$inspect$attributes$fill$fill_panel_STAR_$$;case "stroke":return $app$main$ui$inspect$attributes$stroke$stroke_panel_STAR_$$;case "shadow":return $app$main$ui$inspect$attributes$shadow$shadow_panel$$;
case "blur":return $app$main$ui$inspect$attributes$blur$blur_panel$$;case "visibility":return $app$main$ui$inspect$attributes$visibility$visibility_panel_STAR_$$;case "text":return $app$main$ui$inspect$attributes$text$text_panel$$;case "svg":return $app$main$ui$inspect$attributes$svg$svg_panel$$;case "variant":return $app$main$ui$inspect$attributes$variant$variant_panel_STAR_$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__74950__$1$$)].join(""));
}}(),{shapes:$shapes__$1$jscomp$27$$,colorSpace:$color_space$jscomp$4$$,objects:$objects$jscomp$727$$,frame:$frame$jscomp$50$$,from:$from$jscomp$23$$,libraries:$libraries$jscomp$131$$,fileId:$file_id$jscomp$356$$},$idx$jscomp$106$$));return $out_arr__44124__auto__$jscomp$83$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$options$jscomp$601$$)),$APP.$cljs$core$truth_$$($annotation_content$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$annotation$annotation$$,
{content:$annotation_content$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$exports$exports$$,{shapes:$shapes__$1$jscomp$27$$,type:$data$jscomp$451_props_74945_type$jscomp$599$$,"page-id":$page_id$jscomp$410$$,"file-id":$file_id$jscomp$356$$,"share-id":$share_id$jscomp$23$$})]})};
$APP.$app$main$ui$components$code_block$code_block$$=function($code$jscomp$52_code__$1$jscomp$3_props_74951$$){var $type$jscomp$600$$=$code$jscomp$52_code__$1$jscomp$3_props_74951$$.type;$code$jscomp$52_code__$1$jscomp$3_props_74951$$=$code$jscomp$52_code__$1$jscomp$3_props_74951$$.code;var $block_ref$$=(0,$APP.$rumext$v2$use_ref$$)();$code$jscomp$52_code__$1$jscomp$3_props_74951$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($code$jscomp$52_code__$1$jscomp$3_props_74951$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($code$jscomp$52_code__$1$jscomp$3_props_74951$$),
$APP.$rumext$v2$adapt$$($type$jscomp$600$$)],function(){var $temp__5825__auto__$jscomp$302$$=$APP.$rumext$v2$ref_val$$($block_ref$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$302$$)?$promesa$core$fnly$cljs$0core$0IFn$0_invoke$0arity$02$$(function($f$jscomp$849$$,$cause$jscomp$97$$){return $APP.$cljs$core$truth_$$($cause$jscomp$97$$)?console.error($cause$jscomp$97$$):$f$jscomp$849$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$849$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto__$jscomp$302$$):
$f$jscomp$849$$($temp__5825__auto__$jscomp$302$$)},$APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($f$jscomp$850$$){return $f$jscomp$850$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$850$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$850$$()},$APP.$cljs$core$_deref$$($app$main$ui$components$code_block$highlight_fn$$))):null});return(0,$APP.$rumext$v2$jsx$$)("pre",{ref:$block_ref$$,className:""+($type$jscomp$600$$??"")+" main_ui_components_code_block__code-display",children:$code$jscomp$52_code__$1$jscomp$3_props_74951$$})};
$app$main$ui$inspect$code$get_viewer_objects$cljs$0core$0IFn$0_invoke$0arity$01$$=function($page_id$jscomp$412$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($state$jscomp$1161$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1161$$,$APP.$cljs$cst$1592$viewer$$),$APP.$cljs$cst$2228$pages$$),
$page_id$jscomp$412$$),$APP.$cljs$cst$1631$objects$$)},$APP.$app$main$store$state$$,$APP.$cljs$core$_EQ_$$)};
$app$main$ui$inspect$code$use_objects$$=function($from$jscomp$24$$){var $page_objects_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($from$jscomp$24$$)],function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from$jscomp$24$$,$APP.$cljs$cst$2532$workspace$$))var $JSCompiler_temp$jscomp$1416_page_id$jscomp$inline_7906_route$jscomp$inline_7905$$=$APP.$app$main$refs$workspace_page_objects$$;else $JSCompiler_temp$jscomp$1416_page_id$jscomp$inline_7906_route$jscomp$inline_7905$$=
$APP.$cljs$core$_deref$$($APP.$app$main$refs$route$$),$JSCompiler_temp$jscomp$1416_page_id$jscomp$inline_7906_route$jscomp$inline_7905$$=$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2269$query_params$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1416_page_id$jscomp$inline_7906_route$jscomp$inline_7905$$)),$JSCompiler_temp$jscomp$1416_page_id$jscomp$inline_7906_route$jscomp$inline_7905$$=$app$main$ui$inspect$code$get_viewer_objects$cljs$0core$0IFn$0_invoke$0arity$01$$($JSCompiler_temp$jscomp$1416_page_id$jscomp$inline_7906_route$jscomp$inline_7905$$);
return $JSCompiler_temp$jscomp$1416_page_id$jscomp$inline_7906_route$jscomp$inline_7905$$});return $APP.$rumext$v2$deref$$($page_objects_ref$$)};
$app$main$ui$inspect$code$shapes__GT_images$$=function($shapes$jscomp$164$$){return $APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($shape$jscomp$929$$){var $or__5025__auto__$jscomp$inline_7908_or__5025__auto____$1$jscomp$inline_7909_temp__5825__auto__$jscomp$303$$=$cljs$cst$1633$metadata$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$929$$);$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_7908_or__5025__auto____$1$jscomp$inline_7909_temp__5825__auto__$jscomp$303$$)||($or__5025__auto__$jscomp$inline_7908_or__5025__auto____$1$jscomp$inline_7909_temp__5825__auto__$jscomp$303$$=
$APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$929$$),$or__5025__auto__$jscomp$inline_7908_or__5025__auto____$1$jscomp$inline_7909_temp__5825__auto__$jscomp$303$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_7908_or__5025__auto____$1$jscomp$inline_7909_temp__5825__auto__$jscomp$303$$)?$or__5025__auto__$jscomp$inline_7908_or__5025__auto____$1$jscomp$inline_7909_temp__5825__auto__$jscomp$303$$:$APP.$cljs$cst$1632$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$929$$))));
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_7908_or__5025__auto____$1$jscomp$inline_7909_temp__5825__auto__$jscomp$303$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$929$$),$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$inline_7908_or__5025__auto____$1$jscomp$inline_7909_temp__5825__auto__$jscomp$303$$)],null):
null},$shapes$jscomp$164$$)};
$app$main$ui$inspect$code$replace_map$$=function($value$jscomp$764$$,$map$jscomp$23$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($value__$1$jscomp$33$$,$new$$jscomp$4_p__74955$$){var $old$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new$$jscomp$4_p__74955$$,0,null);$new$$jscomp$4_p__74955$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new$$jscomp$4_p__74955$$,1,null);return $APP.$cuerdas$core$replace$$($value__$1$jscomp$33$$,$old$jscomp$5$$,
$new$$jscomp$4_p__74955$$)},$value$jscomp$764$$,$map$jscomp$23$$)};
$app$main$ui$inspect$code$code_STAR_$$=function($collapsed_css_QMARK__props_74962_style_type_STAR_$$){var $on_expand$$=$collapsed_css_QMARK__props_74962_style_type_STAR_$$.onExpand,$shapes$jscomp$165$$=$collapsed_css_QMARK__props_74962_style_type_STAR_$$.shapes,$frame$jscomp$51$$=$collapsed_css_QMARK__props_74962_style_type_STAR_$$.frame,$from$jscomp$25$$=$collapsed_css_QMARK__props_74962_style_type_STAR_$$.from;$collapsed_css_QMARK__props_74962_style_type_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("css");
var $markup_type_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("html"),$fontfaces_css_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$images_data_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$style_type$$=$APP.$cljs$core$_deref$$($collapsed_css_QMARK__props_74962_style_type_STAR_$$),$markup_type$$=$APP.$cljs$core$_deref$$($markup_type_STAR_$$),$fontfaces_css$jscomp$1$$=$APP.$cljs$core$_deref$$($fontfaces_css_STAR_$$),
$images_data$jscomp$1$$=$APP.$cljs$core$_deref$$($images_data_STAR_$$),$collapsed_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$);$collapsed_css_QMARK__props_74962_style_type_STAR_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($collapsed_STAR_$$),$cljs$cst$5332$css$$);var $collapsed_markup_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($collapsed_STAR_$$),$cljs$cst$5333$markup$$),$objects$jscomp$729$$=
$app$main$ui$inspect$code$use_objects$$($from$jscomp$25$$),$shapes__$1$jscomp$28$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$165$$),$APP.$rumext$v2$adapt$$($frame$jscomp$51$$)],function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74961_SHARP_$$){return $APP.$app$common$geom$shapes$translate_to_frame$$($p1__74961_SHARP_$$,$frame$jscomp$51$$)},$shapes$jscomp$165$$)}),$all_children$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes__$1$jscomp$28$$),
$APP.$rumext$v2$adapt$$($objects$jscomp$729$$)],function(){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$729$$),$APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$729$$,$APP.$app$common$files$helpers$selected_with_children$$($objects$jscomp$729$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$shapes__$1$jscomp$28$$))))}),$fonts$jscomp$28$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($all_children$jscomp$4$$)],
function(){return $APP.$app$main$ui$shapes$text$fontfaces$shapes__GT_fonts$$($all_children$jscomp$4$$)}),$images_urls$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($all_children$jscomp$4$$)],function(){return $app$main$ui$inspect$code$shapes__GT_images$$($all_children$jscomp$4$$)}),$style_code$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fontfaces_css$jscomp$1$$),$APP.$rumext$v2$adapt$$($style_type$$),
$APP.$rumext$v2$adapt$$($shapes__$1$jscomp$28$$),$APP.$rumext$v2$adapt$$($all_children$jscomp$4$$),$APP.$rumext$v2$adapt$$($APP.$app$util$code_gen$generate_style_code$$)],function(){return""+($fontfaces_css$jscomp$1$$??"")+"\n"+($APP.$app$util$code_beautify$format_code$$($APP.$app$util$code_gen$generate_style_code$$.$cljs$core$IFn$_invoke$arity$4$($objects$jscomp$729$$,$style_type$$,$shapes__$1$jscomp$28$$,$all_children$jscomp$4$$),$style_type$$)??"")}),$markup_code$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($markup_type$$),
$APP.$rumext$v2$adapt$$($shapes__$1$jscomp$28$$),$APP.$rumext$v2$adapt$$($images_data$jscomp$1$$)],function(){return $APP.$app$util$code_gen$generate_formatted_markup_code$$($objects$jscomp$729$$,$markup_type$$,$shapes__$1$jscomp$28$$)}),$on_markup_copied$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($markup_type$$),$APP.$rumext$v2$adapt$$($from$jscomp$25$$)],function(){var $origin$jscomp$55$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2532$workspace$$,
$from$jscomp$25$$)?"workspace":"viewer";return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"copy-inspect-code",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$origin$jscomp$55$$,$APP.$cljs$cst$139$type$$,$markup_type$$],null)))}),$on_style_copied$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($style_type$$),
$APP.$rumext$v2$adapt$$($from$jscomp$25$$)],function(){var $origin$jscomp$56$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2532$workspace$$,$from$jscomp$25$$)?"workspace":"viewer";return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"copy-inspect-style",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
$origin$jscomp$56$$,$APP.$cljs$cst$139$type$$,$style_type$$],null)))}),$map__74963_on_markup_pointer_down$$=$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$($APP.$cljs$cst$273$code$$,400,100,800,$APP.$cljs$cst$1511$y$$,!1,$APP.$cljs$cst$1563$bottom$$,null),$map__74963__$1_markup_size$$=$APP.$cljs$core$__destructure_map$$($map__74963_on_markup_pointer_down$$);$map__74963_on_markup_pointer_down$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74963__$1_markup_size$$,
$APP.$cljs$cst$4542$on_pointer_down$$);var $on_markup_lost_pointer_capture$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74963__$1_markup_size$$,$APP.$cljs$cst$4543$on_lost_pointer_capture$$),$on_markup_pointer_move$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74963__$1_markup_size$$,$APP.$cljs$cst$4544$on_pointer_move$$);$map__74963__$1_markup_size$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74963__$1_markup_size$$,$APP.$cljs$cst$874$size$$);var $map__74964_on_style_pointer_down$$=
$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$($APP.$cljs$cst$273$code$$,400,100,800,$APP.$cljs$cst$1511$y$$,!1,$APP.$cljs$cst$1563$bottom$$,null),$map__74964__$1_style_size$$=$APP.$cljs$core$__destructure_map$$($map__74964_on_style_pointer_down$$);$map__74964_on_style_pointer_down$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74964__$1_style_size$$,$APP.$cljs$cst$4542$on_pointer_down$$);var $on_style_lost_pointer_capture$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74964__$1_style_size$$,
$APP.$cljs$cst$4543$on_lost_pointer_capture$$),$on_style_pointer_move$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74964__$1_style_size$$,$APP.$cljs$cst$4544$on_pointer_move$$);$map__74964__$1_style_size$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74964__$1_style_size$$,$APP.$cljs$cst$874$size$$);var $set_markup$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($markup_type_STAR_$$)],function($value$jscomp$765$$){return $APP.$cljs$core$reset_BANG_$$($markup_type_STAR_$$,
$value$jscomp$765$$)}),$handle_copy_all_code$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($style_code$jscomp$2$$),$APP.$rumext$v2$adapt$$($markup_code$jscomp$2$$),$APP.$rumext$v2$adapt$$($images_data$jscomp$1$$)],function(){var $JSCompiler_inline_result$jscomp$10927_markup_code__$1$jscomp$inline_13059_origin$jscomp$57$$=$app$main$ui$inspect$code$replace_map$$($markup_code$jscomp$2$$,$images_data$jscomp$1$$);var $style_code__$1$jscomp$inline_13060$$=$app$main$ui$inspect$code$replace_map$$($style_code$jscomp$2$$,
$images_data$jscomp$1$$);$JSCompiler_inline_result$jscomp$10927_markup_code__$1$jscomp$inline_13059_origin$jscomp$57$$=$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("\x3c!DOCTYPE html\x3e\n\x3chtml\x3e\n  \x3chead\x3e\n    \x3cstyle\x3e\n    %s\n    \x3c/style\x3e\n  \x3c/head\x3e\n  \x3cbody\x3e\n  %s\n  \x3c/body\x3e\n\x3c/html\x3e",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$style_code__$1$jscomp$inline_13060$$,$JSCompiler_inline_result$jscomp$10927_markup_code__$1$jscomp$inline_13059_origin$jscomp$57$$]));
$APP.$app$util$clipboard$to_clipboard$$($JSCompiler_inline_result$jscomp$10927_markup_code__$1$jscomp$inline_13059_origin$jscomp$57$$);$JSCompiler_inline_result$jscomp$10927_markup_code__$1$jscomp$inline_13059_origin$jscomp$57$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2532$workspace$$,$from$jscomp$25$$)?"workspace":"viewer";return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"copy-inspect-code",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$JSCompiler_inline_result$jscomp$10927_markup_code__$1$jscomp$inline_13059_origin$jscomp$57$$,$APP.$cljs$cst$139$type$$,"all"],null)))}),$handle_collapse$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$219$$){var $panel_type$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$219$$),
"type"));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($collapsed_STAR_$$,function($collapsed$jscomp$1$$){return $APP.$cljs$core$contains_QMARK_$$($collapsed$jscomp$1$$,$panel_type$$)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($collapsed$jscomp$1$$,$panel_type$$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($collapsed$jscomp$1$$,$panel_type$$)})}),$copy_css_fn$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($style_code$jscomp$2$$),
$APP.$rumext$v2$adapt$$($images_data$jscomp$1$$)],function(){return $app$main$ui$inspect$code$replace_map$$($style_code$jscomp$2$$,$images_data$jscomp$1$$)}),$copy_html_fn$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($markup_code$jscomp$2$$),$APP.$rumext$v2$adapt$$($images_data$jscomp$1$$)],function(){return $app$main$ui$inspect$code$replace_map$$($markup_code$jscomp$2$$,$images_data$jscomp$1$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts$jscomp$28$$)],
function(){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($css$jscomp$10_result$jscomp$339$$){$css$jscomp$10_result$jscomp$339$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$css$jscomp$10_result$jscomp$339$$);return $APP.$cljs$core$reset_BANG_$$($fontfaces_css_STAR_$$,$css$jscomp$10_result$jscomp$339$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$merge_map$$($APP.$app$main$fonts$fetch_font_css$$,
$APP.$beicon$v2$core$from$$($fonts$jscomp$28$$))))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($images_urls$$)],function(){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($result$jscomp$340$$){return $APP.$cljs$core$reset_BANG_$$($images_data_STAR_$$,$result$jscomp$340$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$merge_map$$(function($p__74965$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74965$$,
0,null);var $uri$jscomp$104$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74965$$,1,null);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$PersistentHashMap$fromArrays$$([$uri$jscomp$104$$],[$uri$jscomp$104$$]))},$app$util$http$fetch_data_uri$$.$cljs$core$IFn$_invoke$arity$2$($uri$jscomp$104$$,!0))},$APP.$beicon$v2$core$from$$($images_urls$$))))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_code__element-options "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1592$viewer$$,$from$jscomp$25$$)?"main_ui_inspect_code__viewer-code-block":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_code__attributes-block",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_copy_all_code$$,className:"main_ui_inspect_code__download-button",children:"Copy all code"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_code__code-block "+($collapsed_css_QMARK__props_74962_style_type_STAR_$$?
"main_ui_inspect_code__collapsed":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_code__code-row-lang",children:[(0,$APP.$rumext$v2$jsx$$)("button",{"data-type":"css",onClick:$handle_collapse$$,className:"main_ui_inspect_code__toggle-btn",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_inspect_code__collapsabled-icon "+($collapsed_css_QMARK__props_74962_style_type_STAR_$$?"main_ui_inspect_code__rotated":""),children:$APP.$app$main$ui$icons$arrow$$})}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_inspect_code__code-lang-option",children:"CSS"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_code__action-btns",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_expand$$,className:"main_ui_inspect_code__expand-button",children:$app$main$ui$icons$code$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$copy_css_fn$$,className:"main_ui_inspect_code__css-copy-btn",onCopied:$on_style_copied$$})]})]}),$collapsed_css_QMARK__props_74962_style_type_STAR_$$?
null:(0,$APP.$rumext$v2$jsx$$)("div",{style:{"--code-height":""+(($APP.$cljs$core$truth_$$($map__74964__$1_style_size$$)?$map__74964__$1_style_size$$:400)??"")+"px"},className:"main_ui_inspect_code__code-row-display",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$code_block$code_block$$,{type:$style_type$$,code:$style_code$jscomp$2$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{onPointerDown:$map__74964_on_style_pointer_down$$,onLostPointerCapture:$on_style_lost_pointer_capture$$,onPointerMove:$on_style_pointer_move$$,
className:"main_ui_inspect_code__resize-area"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_code__code-block "+($collapsed_markup_QMARK_$$?"main_ui_inspect_code__collapsed":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_code__code-row-lang",children:[(0,$APP.$rumext$v2$jsx$$)("button",{"data-type":"markup",onClick:$handle_collapse$$,className:"main_ui_inspect_code__toggle-btn",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_inspect_code__collapsabled-icon "+
($collapsed_markup_QMARK_$$?"main_ui_inspect_code__rotated":""),children:$APP.$app$main$ui$icons$arrow$$})}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$markup_type$$,"on-change":$set_markup$$,"class":"main_ui_inspect_code__code-lang-options",wide:!0,name:"listing-style",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"html",id:$cljs$cst$5334$html$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"svg",id:$APP.$cljs$cst$1538$svg$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_code__action-btns",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_expand$$,className:"main_ui_inspect_code__expand-button",children:$app$main$ui$icons$code$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$copy_html_fn$$,className:"main_ui_inspect_code__html-copy-btn",onCopied:$on_markup_copied$$})]})]}),$collapsed_markup_QMARK_$$?null:(0,$APP.$rumext$v2$jsx$$)("div",
{style:{"--code-height":""+(($APP.$cljs$core$truth_$$($map__74963__$1_markup_size$$)?$map__74963__$1_markup_size$$:400)??"")+"px"},className:"main_ui_inspect_code__code-row-display",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$code_block$code_block$$,{type:$markup_type$$,code:$markup_code$jscomp$2$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{onPointerDown:$map__74963_on_markup_pointer_down$$,onLostPointerCapture:$on_markup_lost_pointer_capture$$,onPointerMove:$on_markup_pointer_move$$,className:"main_ui_inspect_code__resize-area"})]})]})};
$app$main$ui$measurements$calculate_guides$$=function($bounds$jscomp$76$$,$selrect$jscomp$74_x$jscomp$1237$$){var $bounds_height_map__74970__$1$$=$APP.$cljs$core$__destructure_map$$($bounds$jscomp$76$$),$bounds_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds_height_map__74970__$1$$,$APP.$cljs$cst$290$width$$);$bounds_height_map__74970__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds_height_map__74970__$1$$,$APP.$cljs$cst$1522$height$$);var $height$jscomp$154_map__74971__$1$$=
$APP.$cljs$core$__destructure_map$$($selrect$jscomp$74_x$jscomp$1237$$);$selrect$jscomp$74_x$jscomp$1237$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$154_map__74971__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$457$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$154_map__74971__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$177$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$154_map__74971__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$154_map__74971__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$154_map__74971__$1$$,$APP.$cljs$cst$1522$height$$);return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$76$$),$y$jscomp$457$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$76$$)+$bounds_width$$,
$y$jscomp$457$$],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$76$$),$y$jscomp$457$$+$height$jscomp$154_map__74971__$1$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$76$$)+$bounds_width$$,$y$jscomp$457$$+$height$jscomp$154_map__74971__$1$$],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$selrect$jscomp$74_x$jscomp$1237$$,
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$76$$),$selrect$jscomp$74_x$jscomp$1237$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$76$$)+$bounds_height_map__74970__$1$$],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$selrect$jscomp$74_x$jscomp$1237$$+$width$jscomp$177$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$76$$),$selrect$jscomp$74_x$jscomp$1237$$+$width$jscomp$177$$,
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$76$$)+$bounds_height_map__74970__$1$$],null)],null)};
$app$main$ui$measurements$calculate_distance_lines$$=function($G__74972__$2_G__74972__$3_from_s$$,$from_e$$,$es$jscomp$11_to_s$$,$ee$jscomp$1_to_e$$){var $ss$jscomp$8$$=$es$jscomp$11_to_s$$-$G__74972__$2_G__74972__$3_from_s$$,$se$$=$ee$jscomp$1_to_e$$-$G__74972__$2_G__74972__$3_from_s$$;$es$jscomp$11_to_s$$-=$from_e$$;$ee$jscomp$1_to_e$$-=$from_e$$;var $G__74972_G__74972__$1$$=$APP.$cljs$core$PersistentVector$EMPTY$$;$G__74972_G__74972__$1$$=$ss$jscomp$8$$<0&&$se$$>0||$ss$jscomp$8$$>0&&$ee$jscomp$1_to_e$$<
0||$ss$jscomp$8$$<0&&$ss$jscomp$8$$>$se$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__74972_G__74972__$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__74972__$2_G__74972__$3_from_s$$,$G__74972__$2_G__74972__$3_from_s$$+$ss$jscomp$8$$],null)):$G__74972_G__74972__$1$$;$G__74972__$2_G__74972__$3_from_s$$=$se$$<0&&$ss$jscomp$8$$<=$se$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__74972_G__74972__$1$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__74972__$2_G__74972__$3_from_s$$,$G__74972__$2_G__74972__$3_from_s$$+$se$$],null)):$G__74972_G__74972__$1$$;$G__74972__$2_G__74972__$3_from_s$$=$es$jscomp$11_to_s$$>0&&$es$jscomp$11_to_s$$<=$ee$jscomp$1_to_e$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__74972__$2_G__74972__$3_from_s$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from_e$$,$from_e$$+$es$jscomp$11_to_s$$],null)):$G__74972__$2_G__74972__$3_from_s$$;
return $ee$jscomp$1_to_e$$>0&&$es$jscomp$11_to_s$$<0||$ee$jscomp$1_to_e$$<0&&$ss$jscomp$8$$>0||$ee$jscomp$1_to_e$$>0&&$ee$jscomp$1_to_e$$<$es$jscomp$11_to_s$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__74972__$2_G__74972__$3_from_s$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from_e$$,$from_e$$+$ee$jscomp$1_to_e$$],null)):$G__74972__$2_G__74972__$3_from_s$$};
$APP.$app$main$ui$measurements$size_display$$=function($map__74974_map__74974__$1_props_74973_zoom$jscomp$53$$){$map__74974_map__74974__$1_props_74973_zoom$jscomp$53$$=$APP.$rumext$v2$util$wrap_props$$($map__74974_map__74974__$1_props_74973_zoom$jscomp$53$$);$map__74974_map__74974__$1_props_74973_zoom$jscomp$53$$=$APP.$cljs$core$__destructure_map$$($map__74974_map__74974__$1_props_74973_zoom$jscomp$53$$);var $selrect$jscomp$75_x$jscomp$1238$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74974_map__74974__$1_props_74973_zoom$jscomp$53$$,
$APP.$cljs$cst$1605$selrect$$);$map__74974_map__74974__$1_props_74973_zoom$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74974_map__74974__$1_props_74973_zoom$jscomp$53$$,$APP.$cljs$cst$2196$zoom$$);var $height$jscomp$155_map__74975__$1$$=$APP.$cljs$core$__destructure_map$$($selrect$jscomp$75_x$jscomp$1238$$);$selrect$jscomp$75_x$jscomp$1238$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$155_map__74975__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$458$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$155_map__74975__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$178$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$155_map__74975__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$155_map__74975__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$155_map__74975__$1$$,$APP.$cljs$cst$1522$height$$);var $size_label$$=""+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($width$jscomp$178$$)??
"")+" x "+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($height$jscomp$155_map__74975__$1$$)??""),$rect_height$jscomp$1$$=16/$map__74974_map__74974__$1_props_74973_zoom$jscomp$53$$,$rect_width$jscomp$1$$=($APP.$cljs$core$count$$($size_label$$)<=9?50:75)/$map__74974_map__74974__$1_props_74973_zoom$jscomp$53$$,$text_padding$$=4/$map__74974_map__74974__$1_props_74973_zoom$jscomp$53$$;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"size-display",children:[(0,$APP.$rumext$v2$jsx$$)("rect",
{x:$selrect$jscomp$75_x$jscomp$1238$$+$width$jscomp$178$$/2+-($rect_width$jscomp$1$$/2),y:$y$jscomp$458$$+$height$jscomp$155_map__74975__$1$$-$rect_height$jscomp$1$$,width:$rect_width$jscomp$1$$,height:$rect_height$jscomp$1$$,style:{fill:"var(--app-white)",fillOpacity:.7}}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$selrect$jscomp$75_x$jscomp$1238$$+$width$jscomp$178$$/2+-($rect_width$jscomp$1$$/2)+$rect_width$jscomp$1$$/2,y:$y$jscomp$458$$+$height$jscomp$155_map__74975__$1$$+($text_padding$$+$rect_height$jscomp$1$$/
2)-$rect_height$jscomp$1$$,width:$rect_width$jscomp$1$$,height:$rect_height$jscomp$1$$,textAnchor:"middle",style:{fill:"var(--app-black)",fontSize:11/$map__74974_map__74974__$1_props_74973_zoom$jscomp$53$$},children:$size_label$$})]})};
$app$main$ui$measurements$distance_display_pill$$=function($map__74977_props_74976_x$jscomp$1239$$){$map__74977_props_74976_x$jscomp$1239$$=$APP.$rumext$v2$util$wrap_props$$($map__74977_props_74976_x$jscomp$1239$$);var $distance_pill_width_map__74977__$1$$=$APP.$cljs$core$__destructure_map$$($map__74977_props_74976_x$jscomp$1239$$);$map__74977_props_74976_x$jscomp$1239$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($distance_pill_width_map__74977__$1$$,$APP.$cljs$cst$1510$x$$);var $text_y_y$jscomp$459$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($distance_pill_width_map__74977__$1$$,$APP.$cljs$cst$1511$y$$),$distance_border_radius_zoom$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($distance_pill_width_map__74977__$1$$,$APP.$cljs$cst$2196$zoom$$),$distance$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($distance_pill_width_map__74977__$1$$,$APP.$cljs$cst$2684$distance$$),$bounds$jscomp$77_offset_y$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($distance_pill_width_map__74977__$1$$,
$APP.$cljs$cst$3850$bounds$$);$distance_pill_width_map__74977__$1$$=50/$distance_border_radius_zoom$jscomp$54$$;var $distance_pill_height$$=16/$distance_border_radius_zoom$jscomp$54$$,$font_size$jscomp$9$$=11/$distance_border_radius_zoom$jscomp$54$$,$offset_x$jscomp$11_text_padding$jscomp$1$$=3/$distance_border_radius_zoom$jscomp$54$$;$distance_border_radius_zoom$jscomp$54$$=2/$distance_border_radius_zoom$jscomp$54$$;var $map__74978__$1_rect_x$$=$APP.$cljs$core$__destructure_map$$($bounds$jscomp$77_offset_y$jscomp$11$$),
$bounds_width$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74978__$1_rect_x$$,$APP.$cljs$cst$290$width$$),$bounds_height$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74978__$1_rect_x$$,$APP.$cljs$cst$1522$height$$);$map__74978__$1_rect_x$$=$map__74977_props_74976_x$jscomp$1239$$-$distance_pill_width_map__74977__$1$$/2;var $rect_y$$=$text_y_y$jscomp$459$$-$distance_pill_height$$/2;$text_y_y$jscomp$459$$+=$offset_x$jscomp$11_text_padding$jscomp$1$$;
$offset_x$jscomp$11_text_padding$jscomp$1$$=$map__74978__$1_rect_x$$<$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$77_offset_y$jscomp$11$$)?$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$77_offset_y$jscomp$11$$)-$map__74978__$1_rect_x$$:$map__74978__$1_rect_x$$+$distance_pill_width_map__74977__$1$$>$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$77_offset_y$jscomp$11$$)+$bounds_width$jscomp$1$$?$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$77_offset_y$jscomp$11$$)+
$bounds_width$jscomp$1$$-($map__74978__$1_rect_x$$+$distance_pill_width_map__74977__$1$$):0;$bounds$jscomp$77_offset_y$jscomp$11$$=$rect_y$$<$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$77_offset_y$jscomp$11$$)?$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$77_offset_y$jscomp$11$$)-$rect_y$$:$rect_y$$+$distance_pill_height$$>$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$77_offset_y$jscomp$11$$)+$bounds_height$jscomp$1$$?$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$77_offset_y$jscomp$11$$)+
$bounds_height$jscomp$1$$-($rect_y$$+$distance_pill_height$$+$distance_pill_height$$/2):0;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"distance-pill",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$map__74978__$1_rect_x$$+$offset_x$jscomp$11_text_padding$jscomp$1$$,y:$rect_y$$+$bounds$jscomp$77_offset_y$jscomp$11$$,rx:$distance_border_radius_zoom$jscomp$54$$,ry:$distance_border_radius_zoom$jscomp$54$$,width:$distance_pill_width_map__74977__$1$$,height:$distance_pill_height$$,style:{fill:"var(--color-accent-quaternary)"}}),
(0,$APP.$rumext$v2$jsx$$)("text",{width:$distance_pill_width_map__74977__$1$$,height:$distance_pill_height$$,children:$APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($distance$jscomp$7$$),x:$map__74977_props_74976_x$jscomp$1239$$+$offset_x$jscomp$11_text_padding$jscomp$1$$,style:{fill:"var(--app-white)",fontSize:$font_size$jscomp$9$$},ry:$distance_border_radius_zoom$jscomp$54$$,rx:$distance_border_radius_zoom$jscomp$54$$,y:$text_y_y$jscomp$459$$+$bounds$jscomp$77_offset_y$jscomp$11$$,
textAnchor:"middle"})]})};
$app$main$ui$measurements$selection_rect$$=function($map__74980_map__74980__$1_props_74979_zoom$jscomp$55$$){$map__74980_map__74980__$1_props_74979_zoom$jscomp$55$$=$APP.$rumext$v2$util$wrap_props$$($map__74980_map__74980__$1_props_74979_zoom$jscomp$55$$);$map__74980_map__74980__$1_props_74979_zoom$jscomp$55$$=$APP.$cljs$core$__destructure_map$$($map__74980_map__74980__$1_props_74979_zoom$jscomp$55$$);var $selrect$jscomp$76_x$jscomp$1240$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74980_map__74980__$1_props_74979_zoom$jscomp$55$$,$APP.$cljs$cst$1605$selrect$$);
$map__74980_map__74980__$1_props_74979_zoom$jscomp$55$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74980_map__74980__$1_props_74979_zoom$jscomp$55$$,$APP.$cljs$cst$2196$zoom$$);var $height$jscomp$156_map__74981__$1$$=$APP.$cljs$core$__destructure_map$$($selrect$jscomp$76_x$jscomp$1240$$);$selrect$jscomp$76_x$jscomp$1240$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$156_map__74981__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$460$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$156_map__74981__$1$$,
$APP.$cljs$cst$1511$y$$),$width$jscomp$179$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$156_map__74981__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$156_map__74981__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$156_map__74981__$1$$,$APP.$cljs$cst$1522$height$$);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"selection-rect",children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:$selrect$jscomp$76_x$jscomp$1240$$,y:$y$jscomp$460$$,width:$width$jscomp$179$$,
height:$height$jscomp$156_map__74981__$1$$,style:{fill:"none",stroke:"var(--color-accent-quaternary)",strokeWidth:1/$map__74980_map__74980__$1_props_74979_zoom$jscomp$55$$}})})};
$APP.$app$main$ui$measurements$distance_display$$=function($from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$){$from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$=$APP.$rumext$v2$util$wrap_props$$($from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$);var $map__74983__$1_v_lines$$=$APP.$cljs$core$__destructure_map$$($from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$);$from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74983__$1_v_lines$$,
$APP.$cljs$cst$1863$from$$);var $to$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74983__$1_v_lines$$,$APP.$cljs$cst$1864$to$$),$zoom$jscomp$56$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74983__$1_v_lines$$,$APP.$cljs$cst$2196$zoom$$),$bounds$jscomp$78$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74983__$1_v_lines$$,$APP.$cljs$cst$3850$bounds$$),$fixed_x$$=$app$common$geom$shapes$fully_contained_QMARK_$$($from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$,
$to$jscomp$26$$)?$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$26$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$26$$)/2:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$)/2,$fixed_y$$=$app$common$geom$shapes$fully_contained_QMARK_$$($from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$,
$to$jscomp$26$$)?$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$26$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$26$$)/2:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$)+$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$)/2;$map__74983__$1_v_lines$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($end$jscomp$94_p__74984$$){var $start$jscomp$231$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$94_p__74984$$,0,null);$end$jscomp$94_p__74984$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$94_p__74984$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$fixed_x$$,$start$jscomp$231$$,$fixed_x$$,$end$jscomp$94_p__74984$$],null)},$app$main$ui$measurements$calculate_distance_lines$$($APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$),
$APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$),$APP.$cljs$cst$1524$y1$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$26$$),$APP.$cljs$cst$1526$y2$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$26$$)));$from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($end$jscomp$95_p__74988$$){var $start$jscomp$232$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$95_p__74988$$,
0,null);$end$jscomp$95_p__74988$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$95_p__74988$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$start$jscomp$232$$,$fixed_y$$,$end$jscomp$95_p__74988$$,$fixed_y$$],null)},$app$main$ui$measurements$calculate_distance_lines$$($APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$),$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$),
$APP.$cljs$cst$1523$x1$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$26$$),$APP.$cljs$cst$1525$x2$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$26$$)));$from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$=$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($map__74983__$1_v_lines$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$]));var $distance_line_stroke$$=1/$zoom$jscomp$56$$;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$84$$,
$JSCompiler_temp_const$jscomp$1417_p__74992$$){var $JSCompiler_inline_result$jscomp$1419_x1$jscomp$38$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1417_p__74992$$,0,null),$y1$jscomp$40$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1417_p__74992$$,1,null),$x2$jscomp$36$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1417_p__74992$$,2,null),$y2$jscomp$38$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1417_p__74992$$,
3,null);$JSCompiler_temp_const$jscomp$1417_p__74992$$=$out_arr__44124__auto__$jscomp$84$$.push;var $center_x$jscomp$inline_7911$$=$JSCompiler_inline_result$jscomp$1419_x1$jscomp$38$$+($x2$jscomp$36$$-$JSCompiler_inline_result$jscomp$1419_x1$jscomp$38$$)/2,$center_y$jscomp$inline_7912$$=$y1$jscomp$40$$+($y2$jscomp$38$$-$y1$jscomp$40$$)/2,$distance$jscomp$inline_7913$$=$APP.$app$common$geom$point$distance$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1419_x1$jscomp$38$$,
$y1$jscomp$40$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x2$jscomp$36$$,$y2$jscomp$38$$));$JSCompiler_inline_result$jscomp$1419_x1$jscomp$38$$=$APP.$app$common$math$almost_zero_QMARK_$$($distance$jscomp$inline_7913$$)?null:(0,$APP.$rumext$v2$jsxs$$)("g",{className:"distance-line",children:[(0,$APP.$rumext$v2$jsx$$)("line",{x1:$JSCompiler_inline_result$jscomp$1419_x1$jscomp$38$$,y1:$y1$jscomp$40$$,x2:$x2$jscomp$36$$,y2:$y2$jscomp$38$$,style:{stroke:"var(--color-accent-quaternary)",
strokeWidth:$distance_line_stroke$$}}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$measurements$distance_display_pill$$,{x:$center_x$jscomp$inline_7911$$,y:$center_y$jscomp$inline_7912$$,zoom:$zoom$jscomp$56$$,distance:$distance$jscomp$inline_7913$$,bounds:$bounds$jscomp$78$$})]},"line-"+($JSCompiler_inline_result$jscomp$1419_x1$jscomp$38$$??"")+"-"+($y1$jscomp$40$$??"")+"-"+($x2$jscomp$36$$??"")+"-"+($y2$jscomp$38$$??""));$JSCompiler_temp_const$jscomp$1417_p__74992$$.call($out_arr__44124__auto__$jscomp$84$$,
$JSCompiler_inline_result$jscomp$1419_x1$jscomp$38$$);return $out_arr__44124__auto__$jscomp$84$$},[],$from$jscomp$26_h_lines_lines$jscomp$6_map__74983_props_74982$$)};
$app$main$ui$measurements$selection_guides$$=function($map__74997_map__74997__$1_props_74996$$){$map__74997_map__74997__$1_props_74996$$=$APP.$rumext$v2$util$wrap_props$$($map__74997_map__74997__$1_props_74996$$);$map__74997_map__74997__$1_props_74996$$=$APP.$cljs$core$__destructure_map$$($map__74997_map__74997__$1_props_74996$$);var $bounds$jscomp$79$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74997_map__74997__$1_props_74996$$,$APP.$cljs$cst$3850$bounds$$),$selrect$jscomp$77$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74997_map__74997__$1_props_74996$$,$APP.$cljs$cst$1605$selrect$$),$zoom$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74997_map__74997__$1_props_74996$$,$APP.$cljs$cst$2196$zoom$$);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"selection-guides",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$85$$,$p__74998_x1$jscomp$39$$){var $idx$jscomp$107$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74998_x1$jscomp$39$$,
0,null),$vec__75002_y2$jscomp$39$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74998_x1$jscomp$39$$,1,null);$p__74998_x1$jscomp$39$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__75002_y2$jscomp$39$$,0,null);var $y1$jscomp$41$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__75002_y2$jscomp$39$$,1,null),$x2$jscomp$37$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__75002_y2$jscomp$39$$,2,null);$vec__75002_y2$jscomp$39$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__75002_y2$jscomp$39$$,
3,null);$out_arr__44124__auto__$jscomp$85$$.push((0,$APP.$rumext$v2$jsx$$)("line",{x1:$p__74998_x1$jscomp$39$$,y1:$y1$jscomp$41$$,x2:$x2$jscomp$37$$,y2:$vec__75002_y2$jscomp$39$$,style:{stroke:"var(--color-accent-tertiary)",strokeWidth:1/$zoom$jscomp$57$$,strokeDasharray:5/$zoom$jscomp$57$$}},"guide-"+($idx$jscomp$107$$??"")));return $out_arr__44124__auto__$jscomp$85$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$measurements$calculate_guides$$($bounds$jscomp$79$$,
$selrect$jscomp$77$$)))})};
$APP.$app$main$ui$measurements$measurement$$=function($JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$){$JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$=$APP.$rumext$v2$util$wrap_props$$($JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$);var $map__75006__$1_zoom$jscomp$58$$=
$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$),$JSCompiler_temp_const$jscomp$10930_bounds$jscomp$80$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75006__$1_zoom$jscomp$58$$,$APP.$cljs$cst$3850$bounds$$);$JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75006__$1_zoom$jscomp$58$$,$APP.$cljs$cst$1606$frame$$);var $JSCompiler_temp_const$jscomp$10929_selected_shapes$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75006__$1_zoom$jscomp$58$$,$APP.$cljs$cst$5335$selected_shapes$$),$hover_shape$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75006__$1_zoom$jscomp$58$$,$cljs$cst$5336$hover_shape$$);$map__75006__$1_zoom$jscomp$58$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75006__$1_zoom$jscomp$58$$,
$APP.$cljs$cst$2196$zoom$$);var $hover_selected_shape_QMARK__selected_ids$jscomp$6$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$JSCompiler_temp_const$jscomp$10929_selected_shapes$jscomp$9$$),$selected_selrect$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($JSCompiler_temp_const$jscomp$10929_selected_shapes$jscomp$9$$),$hover_selrect$$=$APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($hover_shape$$));
var $bounds_selrect$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10930_bounds$jscomp$80$$),$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10930_bounds$jscomp$80$$),$APP.$cljs$cst$1523$x1$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10930_bounds$jscomp$80$$),$APP.$cljs$cst$1524$y1$$,
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10930_bounds$jscomp$80$$),$APP.$cljs$cst$1525$x2$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10930_bounds$jscomp$80$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10930_bounds$jscomp$80$$),$APP.$cljs$cst$1526$y2$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10930_bounds$jscomp$80$$)+
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10930_bounds$jscomp$80$$),$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10930_bounds$jscomp$80$$),$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$10930_bounds$jscomp$80$$)],null);$hover_selected_shape_QMARK__selected_ids$jscomp$6$$=!$APP.$cljs$core$contains_QMARK_$$($hover_selected_shape_QMARK__selected_ids$jscomp$6$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($hover_shape$$));$APP.$cljs$core$seq$$($JSCompiler_temp_const$jscomp$10929_selected_shapes$jscomp$9$$)?($JSCompiler_temp_const$jscomp$10930_bounds$jscomp$80$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$measurements$selection_guides$$,{selrect:$selected_selrect$$,bounds:$JSCompiler_temp_const$jscomp$10930_bounds$jscomp$80$$,zoom:$map__75006__$1_zoom$jscomp$58$$}),$JSCompiler_temp_const$jscomp$10929_selected_shapes$jscomp$9$$=$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$size_display$$,
{selrect:$selected_selrect$$,zoom:$map__75006__$1_zoom$jscomp$58$$}),$APP.$cljs$core$not$$($hover_shape$$)||!$hover_selected_shape_QMARK__selected_ids$jscomp$6$$?$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$)):
$JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$)?($JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$=$APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$)),
$JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$=(0,$APP.$rumext$v2$jsxs$$)("g",{className:"hover-shapes",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$measurements$selection_rect$$,{type:$APP.$cljs$cst$2204$hover$$,selrect:$JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$,zoom:$map__75006__$1_zoom$jscomp$58$$}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$distance_display$$,{from:$JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$,to:$selected_selrect$$,zoom:$map__75006__$1_zoom$jscomp$58$$,bounds:$bounds_selrect$$})]})):$JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$=null:$JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$=
(0,$APP.$rumext$v2$jsxs$$)("g",{className:"hover-shapes",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$measurements$selection_rect$$,{type:$APP.$cljs$cst$2204$hover$$,selrect:$hover_selrect$$,zoom:$map__75006__$1_zoom$jscomp$58$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$size_display$$,{selrect:$hover_selrect$$,zoom:$map__75006__$1_zoom$jscomp$58$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$distance_display$$,{from:$hover_selrect$$,to:$selected_selrect$$,zoom:$map__75006__$1_zoom$jscomp$58$$,
bounds:$bounds_selrect$$})]}),$JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$=(0,$APP.$rumext$v2$jsxs$$)("g",{className:"measurement-feedback",pointerEvents:"none",children:[$JSCompiler_temp_const$jscomp$10930_bounds$jscomp$80$$,$JSCompiler_temp_const$jscomp$10929_selected_shapes$jscomp$9$$,$JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$]})):
$JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$=null;return $JSCompiler_temp$jscomp$10928_JSCompiler_temp$jscomp$10931_JSCompiler_temp$jscomp$10932_frame$jscomp$52_frame_bb$jscomp$inline_13062_map__75006_props_75005$$};
$APP.$app$main$ui$inspect$selection_feedback$resolve_shapes$$=function($objects$jscomp$730$$,$ids$jscomp$270$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$730$$)),$ids$jscomp$270$$)};
$app$main$data$workspace$tokens$format$format_map_entries$$=function($entries$jscomp$25$$){return["\n",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__75019_v$jscomp$630$$){var $G__75024$jscomp$inline_7915_JSCompiler_inline_result$jscomp$1422_k$jscomp$671$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__75019_v$jscomp$630$$,0,null);$p__75019_v$jscomp$630$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__75019_v$jscomp$630$$,1,null);var $JSCompiler_temp_const$jscomp$1421$$=$APP.$cljs$core$str$$,$JSCompiler_temp_const$jscomp$1420$$=$JSCompiler_temp_const$jscomp$1421$$.$cljs$core$IFn$_invoke$arity$1$;$G__75024$jscomp$inline_7915_JSCompiler_inline_result$jscomp$1422_k$jscomp$671$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__75024$jscomp$inline_7915_JSCompiler_inline_result$jscomp$1422_k$jscomp$671$$);$G__75024$jscomp$inline_7915_JSCompiler_inline_result$jscomp$1422_k$jscomp$671$$=
$APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$($G__75024$jscomp$inline_7915_JSCompiler_inline_result$jscomp$1422_k$jscomp$671$$):(0,$APP.$app$main$data$workspace$tokens$format$category_dictionary$$)($G__75024$jscomp$inline_7915_JSCompiler_inline_result$jscomp$1422_k$jscomp$671$$);return["- ",$JSCompiler_temp_const$jscomp$1420$$.call($JSCompiler_temp_const$jscomp$1421$$,
$G__75024$jscomp$inline_7915_JSCompiler_inline_result$jscomp$1422_k$jscomp$671$$),": ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$format$format_token_value$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$data$workspace$tokens$format$format_token_value$$.$cljs$core$IFn$_invoke$arity$1$($p__75019_v$jscomp$630$$):$APP.$app$main$data$workspace$tokens$format$format_token_value$$($p__75019_v$jscomp$630$$))].join("")},$entries$jscomp$25$$)))].join("")};
$app$main$ui$inspect$styles$property_detail_copiable$property_detail_copiable_STAR_$$=function($JSCompiler_temp_const$jscomp$10935_props_75025$$){var $children$jscomp$286_color_library_name$jscomp$inline_13068_colors_library$jscomp$inline_13064$$=$JSCompiler_temp_const$jscomp$10935_props_75025$$.children,$JSCompiler_temp$jscomp$10937_JSCompiler_temp$jscomp$10938_color$jscomp$131_color__$1$jscomp$inline_13069$$=$JSCompiler_temp_const$jscomp$10935_props_75025$$.color,$copied$jscomp$1$$=$JSCompiler_temp_const$jscomp$10935_props_75025$$.copied,
$file_colors$jscomp$inline_13067_file_colors_ref$jscomp$inline_13065_token$jscomp$101$$=$JSCompiler_temp_const$jscomp$10935_props_75025$$.token,$JSCompiler_temp_const$jscomp$10936$$=$JSCompiler_temp_const$jscomp$10935_props_75025$$.onClick;$JSCompiler_temp_const$jscomp$10935_props_75025$$=$JSCompiler_temp_const$jscomp$10935_props_75025$$.ref;var $JSCompiler_temp_const$jscomp$10934$$="main_ui_inspect_styles_property_detail_copiable__property-detail-copiable "+($APP.$cljs$core$truth_$$($copied$jscomp$1$$)?
"main_ui_inspect_styles_property_detail_copiable__property-detail-copied":"")+" "+($JSCompiler_temp$jscomp$10937_JSCompiler_temp$jscomp$10938_color$jscomp$131_color__$1$jscomp$inline_13069$$!=null?"main_ui_inspect_styles_property_detail_copiable__property-detail-copiable-color":""),$JSCompiler_temp_const$jscomp$10933$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10937_JSCompiler_temp$jscomp$10938_color$jscomp$131_color__$1$jscomp$inline_13069$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,
{background:$JSCompiler_temp$jscomp$10937_JSCompiler_temp$jscomp$10938_color$jscomp$131_color__$1$jscomp$inline_13069$$,size:"small"}):null;if($APP.$cljs$core$truth_$$($file_colors$jscomp$inline_13067_file_colors_ref$jscomp$inline_13065_token$jscomp$101$$))$JSCompiler_temp$jscomp$10937_JSCompiler_temp$jscomp$10938_color$jscomp$131_color__$1$jscomp$inline_13069$$=(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_inspect_styles_property_detail_copiable__property-detail-text main_ui_inspect_styles_property_detail_copiable__property-detail-text-token",
children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file_colors$jscomp$inline_13067_file_colors_ref$jscomp$inline_13065_token$jscomp$101$$)});else if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10937_JSCompiler_temp$jscomp$10938_color$jscomp$131_color__$1$jscomp$inline_13069$$))){$children$jscomp$286_color_library_name$jscomp$inline_13068_colors_library$jscomp$inline_13064$$=$app$main$ui$inspect$common$colors$use_colors_library$$($JSCompiler_temp$jscomp$10937_JSCompiler_temp$jscomp$10938_color$jscomp$131_color__$1$jscomp$inline_13069$$);
$file_colors$jscomp$inline_13067_file_colors_ref$jscomp$inline_13065_token$jscomp$101$$=$APP.$rumext$v2$deref$$($app$main$ui$inspect$common$colors$file_colors_ref$$);var $file_colors_wokspace$jscomp$inline_13066$$=$APP.$rumext$v2$deref$$($app$main$refs$workspace_file_colors$$);$file_colors$jscomp$inline_13067_file_colors_ref$jscomp$inline_13065_token$jscomp$101$$=$APP.$cljs$core$truth_$$($file_colors$jscomp$inline_13067_file_colors_ref$jscomp$inline_13065_token$jscomp$101$$)?$file_colors$jscomp$inline_13067_file_colors_ref$jscomp$inline_13065_token$jscomp$101$$:
$file_colors_wokspace$jscomp$inline_13066$$;$children$jscomp$286_color_library_name$jscomp$inline_13068_colors_library$jscomp$inline_13064$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($children$jscomp$286_color_library_name$jscomp$inline_13068_colors_library$jscomp$inline_13064$$)?$children$jscomp$286_color_library_name$jscomp$inline_13068_colors_library$jscomp$inline_13064$$:$file_colors$jscomp$inline_13067_file_colors_ref$jscomp$inline_13065_token$jscomp$101$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10937_JSCompiler_temp$jscomp$10938_color$jscomp$131_color__$1$jscomp$inline_13069$$),$APP.$cljs$cst$725$name$$],null));$JSCompiler_temp$jscomp$10937_JSCompiler_temp$jscomp$10938_color$jscomp$131_color__$1$jscomp$inline_13069$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$10937_JSCompiler_temp$jscomp$10938_color$jscomp$131_color__$1$jscomp$inline_13069$$,
$APP.$cljs$cst$725$name$$,$children$jscomp$286_color_library_name$jscomp$inline_13068_colors_library$jscomp$inline_13064$$);$JSCompiler_temp$jscomp$10937_JSCompiler_temp$jscomp$10938_color$jscomp$131_color__$1$jscomp$inline_13069$$=(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_inspect_styles_property_detail_copiable__property-detail-text",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10937_JSCompiler_temp$jscomp$10938_color$jscomp$131_color__$1$jscomp$inline_13069$$)})}else $JSCompiler_temp$jscomp$10937_JSCompiler_temp$jscomp$10938_color$jscomp$131_color__$1$jscomp$inline_13069$$=
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_inspect_styles_property_detail_copiable__property-detail-text",children:$children$jscomp$286_color_library_name$jscomp$inline_13068_colors_library$jscomp$inline_13064$$});return(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$JSCompiler_temp_const$jscomp$10936$$,ref:$JSCompiler_temp_const$jscomp$10935_props_75025$$,className:$JSCompiler_temp_const$jscomp$10934$$,children:[$JSCompiler_temp_const$jscomp$10933$$,$JSCompiler_temp$jscomp$10937_JSCompiler_temp$jscomp$10938_color$jscomp$131_color__$1$jscomp$inline_13069$$,
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{className:"main_ui_inspect_styles_property_detail_copiable__property-detail-icon",iconId:$APP.$cljs$core$truth_$$($copied$jscomp$1$$)?"tick":"clipboard",size:"s","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.tabs.styles.copy-to-clipboard")})]})};
$app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$=function($props_75026$$){var $detail$jscomp$6$$=$props_75026$$.detail,$property$jscomp$53$$=$props_75026$$.property,$copiable$$=$props_75026$$.copiable,$term$jscomp$2$$=$props_75026$$.term,$token$jscomp$102$$=$props_75026$$.token,$class$$jscomp$49$$=$props_75026$$.className,$copiable_QMARK_$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($copiable$$,!1),$detail_QMARK_$$=!($detail$jscomp$6$$==null||$APP.$cuerdas$core$blank_QMARK_$$($detail$jscomp$6$$)),
$detail__$1$$=$detail_QMARK_$$?$detail$jscomp$6$$:"-",$copied_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$copied$jscomp$2$$=$APP.$cljs$core$_deref$$($copied_STAR_$jscomp$1$$),$copiable_value$$=$token$jscomp$102$$!=null?$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$102$$):$property$jscomp$53$$,$row_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$copy_attr$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($copied$jscomp$2$$)],
function(){$APP.$cljs$core$reset_BANG_$$($copied_STAR_$jscomp$1$$,!0);$APP.$app$util$clipboard$to_clipboard$$($copiable_value$$);return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(1E3,function(){return $APP.$cljs$core$reset_BANG_$$($copied_STAR_$jscomp$1$$,!1)})});return(0,$APP.$rumext$v2$jsxs$$)("dl",{"data-testid":"property-row",className:"main_ui_inspect_styles_rows_properties_row__property-row "+($class$$jscomp$49$$??""),children:[(0,$APP.$rumext$v2$jsx$$)("dt",{className:"main_ui_inspect_styles_rows_properties_row__property-term",
children:$term$jscomp$2$$}),(0,$APP.$rumext$v2$jsx$$)("dd",{className:"main_ui_inspect_styles_rows_properties_row__property-detail",children:$APP.$cljs$core$truth_$$($copiable_QMARK_$$)?$APP.$cljs$core$truth_$$($token$jscomp$102$$)?function(){var $token_type$jscomp$13$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$102$$);return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{id:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$102$$),
className:"main_ui_inspect_styles_rows_properties_row__tooltip-token-wrapper",triggerRef:$row_ref$$,content:function(){return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_styles_rows_properties_row__tooltip-token",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_rows_properties_row__tooltip-token-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.tabs.styles.token-resolved-value")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_rows_properties_row__tooltip-token-value",
children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1981$typography$$,$token_type$jscomp$13$$)?(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_inspect_styles_rows_properties_row__tooltip-token-resolved-values",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$86$$,$p__75027_value$jscomp$766$$){var $property__$1$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__75027_value$jscomp$766$$,0,
null);$p__75027_value$jscomp$766$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__75027_value$jscomp$766$$,1,null);$out_arr__44124__auto__$jscomp$86$$.push((0,$APP.$rumext$v2$jsx$$)("li",{children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$($property__$1$jscomp$1$$):(0,$APP.$app$main$data$workspace$tokens$format$category_dictionary$$)($property__$1$jscomp$1$$)),
": ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$format$format_token_value$$($p__75027_value$jscomp$766$$))].join("")},$property__$1$jscomp$1$$));return $out_arr__44124__auto__$jscomp$86$$},[],$APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$102$$))}):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1654$shadow$$,$token_type$jscomp$13$$)?(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_inspect_styles_rows_properties_row__tooltip-token-resolved-values",
children:$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return function $app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR__$_iter__75031$$($s__75032$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__75032__$1$$=$s__75032$$;;){var $fs__5500__auto__$jscomp$6_temp__5825__auto__$jscomp$304$$=$APP.$cljs$core$seq$$($s__75032__$1$$);if($fs__5500__auto__$jscomp$6_temp__5825__auto__$jscomp$304$$){var $xs__6385__auto__$jscomp$18$$=$fs__5500__auto__$jscomp$6_temp__5825__auto__$jscomp$304$$,
$property__$1$jscomp$2$$=$APP.$cljs$core$first$$($xs__6385__auto__$jscomp$18$$);if($fs__5500__auto__$jscomp$6_temp__5825__auto__$jscomp$304$$=$APP.$cljs$core$seq$$(function($s__75032__$1$jscomp$1$$,$property__$1$jscomp$3$$,$xs__6385__auto__$jscomp$19$$,$temp__5825__auto__$jscomp$305$$,$token_type$jscomp$14$$,$copiable_QMARK_$jscomp$1$$,$detail_QMARK_$jscomp$1$$,$detail__$1$jscomp$1$$,$copied_STAR_$jscomp$2$$,$copied$jscomp$3$$,$copiable_value$jscomp$1$$,$row_ref$jscomp$1$$,$copy_attr$jscomp$1$$,$detail$jscomp$7$$,
$property$jscomp$54$$,$copiable$jscomp$1$$,$term$jscomp$3$$,$token$jscomp$103$$,$class$$jscomp$50$$){return function $app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR__$_iter__75031_$_iter__75033$$($s__75034$$){return new $APP.$cljs$core$LazySeq$$(null,function(){return function(){for(;;){var $s__75034__$2_temp__5825__auto____$1$jscomp$20$$=$APP.$cljs$core$seq$$($s__75034$$);if($s__75034__$2_temp__5825__auto____$1$jscomp$20$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__75034__$2_temp__5825__auto____$1$jscomp$20$$)){var $JSCompiler_inline_result$jscomp$1423_c__5501__auto__$jscomp$37_value$jscomp$767_vec__75040$$=
$APP.$cljs$core$_chunked_first$$($s__75034__$2_temp__5825__auto____$1$jscomp$20$$),$size__5502__auto__$jscomp$37$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1423_c__5501__auto__$jscomp$37_value$jscomp$767_vec__75040$$),$b__75036_key$jscomp$396$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$37$$);a:{for(var $i__75035$jscomp$inline_7917$$=0;;)if($i__75035$jscomp$inline_7917$$<$size__5502__auto__$jscomp$37$$){var $b$jscomp$inline_13071_vec__75037$jscomp$inline_7918$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1423_c__5501__auto__$jscomp$37_value$jscomp$767_vec__75040$$,
$i__75035$jscomp$inline_7917$$),$key$jscomp$inline_7919_x$jscomp$inline_13072$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13071_vec__75037$jscomp$inline_7918$$,0,null),$value$jscomp$inline_7920$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13071_vec__75037$jscomp$inline_7918$$,1,null);$b$jscomp$inline_13071_vec__75037$jscomp$inline_7918$$=$b__75036_key$jscomp$396$$;$key$jscomp$inline_7919_x$jscomp$inline_13072$$=(0,$APP.$rumext$v2$jsx$$)("li",
{children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$inline_7919_x$jscomp$inline_13072$$):(0,$APP.$app$main$data$workspace$tokens$format$category_dictionary$$)($key$jscomp$inline_7919_x$jscomp$inline_13072$$)),": ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$format$format_token_value$$($value$jscomp$inline_7920$$))].join("")},
$key$jscomp$inline_7919_x$jscomp$inline_13072$$);$b$jscomp$inline_13071_vec__75037$jscomp$inline_7918$$.add($key$jscomp$inline_7919_x$jscomp$inline_13072$$);$i__75035$jscomp$inline_7917$$+=1}else{$JSCompiler_inline_result$jscomp$1423_c__5501__auto__$jscomp$37_value$jscomp$767_vec__75040$$=!0;break a}$JSCompiler_inline_result$jscomp$1423_c__5501__auto__$jscomp$37_value$jscomp$767_vec__75040$$=void 0}return $JSCompiler_inline_result$jscomp$1423_c__5501__auto__$jscomp$37_value$jscomp$767_vec__75040$$?
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75036_key$jscomp$396$$),$app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR__$_iter__75031_$_iter__75033$$($APP.$cljs$core$_chunked_rest$$($s__75034__$2_temp__5825__auto____$1$jscomp$20$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75036_key$jscomp$396$$),null)}$JSCompiler_inline_result$jscomp$1423_c__5501__auto__$jscomp$37_value$jscomp$767_vec__75040$$=$APP.$cljs$core$first$$($s__75034__$2_temp__5825__auto____$1$jscomp$20$$);
$b__75036_key$jscomp$396$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1423_c__5501__auto__$jscomp$37_value$jscomp$767_vec__75040$$,0,null);$JSCompiler_inline_result$jscomp$1423_c__5501__auto__$jscomp$37_value$jscomp$767_vec__75040$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1423_c__5501__auto__$jscomp$37_value$jscomp$767_vec__75040$$,1,null);return $APP.$cljs$core$cons$$((0,$APP.$rumext$v2$jsx$$)("li",{children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$($b__75036_key$jscomp$396$$):(0,$APP.$app$main$data$workspace$tokens$format$category_dictionary$$)($b__75036_key$jscomp$396$$)),": ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$format$format_token_value$$($JSCompiler_inline_result$jscomp$1423_c__5501__auto__$jscomp$37_value$jscomp$767_vec__75040$$))].join("")},$b__75036_key$jscomp$396$$),$app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR__$_iter__75031_$_iter__75033$$($APP.$cljs$core$rest$$($s__75034__$2_temp__5825__auto____$1$jscomp$20$$)))}return null}}}($s__75032__$1$jscomp$1$$,
$property__$1$jscomp$3$$,$xs__6385__auto__$jscomp$19$$,$temp__5825__auto__$jscomp$305$$,$token_type$jscomp$14$$,$copiable_QMARK_$jscomp$1$$,$detail_QMARK_$jscomp$1$$,$detail__$1$jscomp$1$$,$copied_STAR_$jscomp$2$$,$copied$jscomp$3$$,$copiable_value$jscomp$1$$,$row_ref$jscomp$1$$,$copy_attr$jscomp$1$$,$detail$jscomp$7$$,$property$jscomp$54$$,$copiable$jscomp$1$$,$term$jscomp$3$$,$token$jscomp$103$$,$class$$jscomp$50$$),null,null)}}($s__75032__$1$$,$property__$1$jscomp$2$$,$xs__6385__auto__$jscomp$18$$,
$fs__5500__auto__$jscomp$6_temp__5825__auto__$jscomp$304$$,$token_type$jscomp$13$$,$copiable_QMARK_$$,$detail_QMARK_$$,$detail__$1$$,$copied_STAR_$jscomp$1$$,$copied$jscomp$2$$,$copiable_value$$,$row_ref$$,$copy_attr$$,$detail$jscomp$6$$,$property$jscomp$53$$,$copiable$$,$term$jscomp$2$$,$token$jscomp$102$$,$class$$jscomp$49$$)($property__$1$jscomp$2$$)))return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($fs__5500__auto__$jscomp$6_temp__5825__auto__$jscomp$304$$,$app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR__$_iter__75031$$($APP.$cljs$core$rest$$($s__75032__$1$$)));
$s__75032__$1$$=$APP.$cljs$core$rest$$($s__75032__$1$$)}else return null}},null,null)}($APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$102$$))}())}):$APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$102$$)})]})},children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$property_detail_copiable$property_detail_copiable_STAR_$$,{token:$token$jscomp$102$$,copied:$copied$jscomp$2$$,ref:$row_ref$$,onClick:$copy_attr$$,children:$detail__$1$$})})}():
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$property_detail_copiable$property_detail_copiable_STAR_$$,{copied:$copied$jscomp$2$$,onClick:$copy_attr$$,children:$detail__$1$$}):$detail__$1$$})]})};
$app$main$ui$inspect$styles$panels$blur$blur_panel_STAR_$$=function($props_75045$$){var $objects$jscomp$732$$=$props_75045$$.objects;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_blur__blur-panel",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$87$$,$shape$jscomp$930$$){var $JSCompiler_temp_const$jscomp$1424$$=$out_arr__44124__auto__$jscomp$87$$.push;var $JSCompiler_inline_result$jscomp$1426_value$jscomp$inline_7922$$=
$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$732$$,$shape$jscomp$930$$,$APP.$cljs$cst$2691$filter$$);var $property_name$jscomp$inline_7923$$=$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($APP.$cljs$cst$2691$filter$$),$property_value$jscomp$inline_7924$$=$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$732$$,$shape$jscomp$930$$,$APP.$cljs$cst$2691$filter$$);$JSCompiler_inline_result$jscomp$1426_value$jscomp$inline_7922$$=
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:$property_name$jscomp$inline_7923$$,detail:""+($JSCompiler_inline_result$jscomp$1426_value$jscomp$inline_7922$$??""),property:$property_value$jscomp$inline_7924$$,copiable:!0},"blur-property-"+($APP.$cljs$cst$2691$filter$$??""));$JSCompiler_temp_const$jscomp$1424$$.call($out_arr__44124__auto__$jscomp$87$$,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_blur__blur-shape",
children:$JSCompiler_inline_result$jscomp$1426_value$jscomp$inline_7922$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$930$$)));return $out_arr__44124__auto__$jscomp$87$$},[],$props_75045$$.shapes)})};
$app$main$ui$inspect$styles$rows$color_properties_row$color_properties_row_STAR_$$=function($class$$jscomp$52_props_75046$$){var $format$jscomp$41$$=$class$$jscomp$52_props_75046$$.format,$color$jscomp$132$$=$class$$jscomp$52_props_75046$$.color,$term$jscomp$5$$=$class$$jscomp$52_props_75046$$.term,$token$jscomp$105$$=$class$$jscomp$52_props_75046$$.token;$class$$jscomp$52_props_75046$$=$class$$jscomp$52_props_75046$$.className;var $copied_STAR_$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$copied$jscomp$5$$=$APP.$cljs$core$_deref$$($copied_STAR_$jscomp$4$$),$color_value$jscomp$1$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$132$$),$color_gradient$$=$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$132$$),$color_image_row_ref$jscomp$3$$=$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$132$$),$color_image_name$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color_image_row_ref$jscomp$3$$),
$color_image_url$$=$color_image_row_ref$jscomp$3$$!=null?$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($color_image_row_ref$jscomp$3$$):null;$color_image_row_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(null);var $color_opacity$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$132$$)],function(){return""+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$coalesce$$($APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$132$$))*
100)??"")+"%"}),$formatted_color_value$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$132$$),$APP.$rumext$v2$adapt$$($format$jscomp$41$$),$APP.$rumext$v2$adapt$$($color_opacity$$)],function(){if($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$132$$)!=null)switch($format$jscomp$41$$){case "hex":return""+($color_value$jscomp$1$$??"")+" "+($color_opacity$$??"");case "rgba":var $a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$=
$app$common$types$color$hex__GT_rgba$$($color_value$jscomp$1$$,$color_opacity$$),$h$jscomp$167_r$jscomp$119$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$,0,null),$g$jscomp$140_s$jscomp$559$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$,1,null),$b$jscomp$340_l$jscomp$102$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$,
2,null);$a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$,3,null);return $a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$=$app$common$types$color$format_rgba$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$167_r$jscomp$119$$,$g$jscomp$140_s$jscomp$559$$,$b$jscomp$340_l$jscomp$102$$,$a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$],
null));case "hsla":return $a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$color$hex__GT_hsl$$($color_value$jscomp$1$$),$color_opacity$$),$h$jscomp$167_r$jscomp$119$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$,0,null),$g$jscomp$140_s$jscomp$559$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$,
1,null),$b$jscomp$340_l$jscomp$102$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$,2,null),$a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$,3,null),$a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$=$app$common$types$color$format_hsla$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$h$jscomp$167_r$jscomp$119$$,$g$jscomp$140_s$jscomp$559$$,$b$jscomp$340_l$jscomp$102$$,$a$jscomp$419_result$jscomp$341_vec__75048_vec__75051$$],null));default:return $color_value$jscomp$1$$}else return $APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$132$$)!=null?$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($color_gradient$$)):$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$132$$)!=
null?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.image"):"none"}),$css_term$$=$APP.$cuerdas$core$replace$$($APP.$cuerdas$core$lower$$($APP.$cuerdas$core$replace$$($APP.$cuerdas$core$replace$$($term$jscomp$5$$,/ /,"-"),/([A-Z])/,"-$1")),/^-/,""),$copiable_value$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$132$$),$APP.$rumext$v2$adapt$$($token$jscomp$105$$),$APP.$rumext$v2$adapt$$($format$jscomp$41$$),$APP.$rumext$v2$adapt$$($color_opacity$$)],
function(){return $token$jscomp$105$$!=null?$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$105$$):$APP.$cljs$core$truth_$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$132$$))?""+($css_term$$??"")+": "+($app$util$color$color__GT_format__GT_background$$($color$jscomp$132$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($format$jscomp$41$$))??"")+";":$APP.$cljs$core$truth_$$($APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$132$$))?
""+($css_term$$??"")+": "+($app$util$color$color__GT_background$$($color$jscomp$132$$)??"")+";":$APP.$cljs$core$truth_$$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$132$$))?""+($css_term$$??"")+": url("+($color_image_url$$??"")+") no-repeat center center / cover;":"none"}),$copy_attr$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($copied$jscomp$5$$),$APP.$rumext$v2$adapt$$($copiable_value$jscomp$3$$)],function(){$APP.$cljs$core$reset_BANG_$$($copied_STAR_$jscomp$4$$,
!0);$APP.$app$util$clipboard$to_clipboard$$($copiable_value$jscomp$3$$);return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(1E3,function(){return $APP.$cljs$core$reset_BANG_$$($copied_STAR_$jscomp$4$$,!1)})});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("dl",{"data-testid":"property-row",className:"main_ui_inspect_styles_rows_color_properties_row__property-row "+($class$$jscomp$52_props_75046$$??""),children:[(0,$APP.$rumext$v2$jsx$$)("dt",
{className:"main_ui_inspect_styles_rows_color_properties_row__property-term",children:$term$jscomp$5$$}),(0,$APP.$rumext$v2$jsx$$)("dd",{className:"main_ui_inspect_styles_rows_color_properties_row__property-detail",children:$APP.$cljs$core$truth_$$($token$jscomp$105$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{id:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$105$$),className:"main_ui_inspect_styles_rows_color_properties_row__tooltip-token-wrapper",
triggerRef:$color_image_row_ref$jscomp$3$$,content:function(){return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_styles_rows_color_properties_row__tooltip-token",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_rows_color_properties_row__tooltip-token-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.tabs.styles.token-resolved-value")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_rows_color_properties_row__tooltip-token-value",
children:$APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$105$$)})]})},children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$property_detail_copiable$property_detail_copiable_STAR_$$,{color:$color$jscomp$132$$,token:$token$jscomp$105$$,ref:$color_image_row_ref$jscomp$3$$,copied:$copied$jscomp$5$$,onClick:$copy_attr$jscomp$3$$,children:$formatted_color_value$$})}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$property_detail_copiable$property_detail_copiable_STAR_$$,
{color:$color$jscomp$132$$,copied:$copied$jscomp$5$$,onClick:$copy_attr$jscomp$3$$,children:$formatted_color_value$$})})]}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$132$$))?(0,$APP.$rumext$v2$jsxs$$)("figure",{className:"main_ui_inspect_styles_rows_color_properties_row__color-image-preview",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_rows_color_properties_row__color-image-preview-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("img",
{src:$color_image_url$$,title:$color_image_name$$,alt:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.image.preview"),className:"main_ui_inspect_styles_rows_color_properties_row__color-image"})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",to:$color_image_url$$,type:"button",target:"_blank",download:$color_image_name$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.image.download")})]}):
null]})};
$app$main$ui$inspect$styles$panels$fill$generate_fill_shorthand$$=function($shape$jscomp$932$$,$color_space$jscomp$5$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$150$$,$fill$jscomp$24_full_value_prefix$jscomp$65$$){var $color$jscomp$133_value$jscomp$770$$=$APP.$app$common$types$fills$fill__GT_color$$($fill$jscomp$24_full_value_prefix$jscomp$65$$);$fill$jscomp$24_full_value_prefix$jscomp$65$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$133_value$jscomp$770$$))?"background-color: ":
"background-image: ";var $JSCompiler_inline_result$jscomp$1427_or__5025__auto__$jscomp$inline_7929$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$133_value$jscomp$770$$);$JSCompiler_inline_result$jscomp$1427_or__5025__auto__$jscomp$inline_7929$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1427_or__5025__auto__$jscomp$inline_7929$$)?$JSCompiler_inline_result$jscomp$1427_or__5025__auto__$jscomp$inline_7929$$:$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$133_value$jscomp$770$$);
$color$jscomp$133_value$jscomp$770$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1427_or__5025__auto__$jscomp$inline_7929$$)?$app$util$color$color__GT_format__GT_background$$($color$jscomp$133_value$jscomp$770$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($color_space$jscomp$5$$)):$APP.$cljs$core$truth_$$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$133_value$jscomp$770$$))?["url('",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$133_value$jscomp$770$$))),
"')"].join(""):"";$fill$jscomp$24_full_value_prefix$jscomp$65$$=[$fill$jscomp$24_full_value_prefix$jscomp$65$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$133_value$jscomp$770$$),";"].join("");return $APP.$cljs$core$empty_QMARK_$$($acc$jscomp$150$$)?$fill$jscomp$24_full_value_prefix$jscomp$65$$:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($acc$jscomp$150$$)," ",$fill$jscomp$24_full_value_prefix$jscomp$65$$].join("")},"",$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$932$$))};
$app$main$ui$inspect$styles$panels$fill$fill_panel_STAR_$$=function($props_75055$$){var $shapes$jscomp$168$$=$props_75055$$.shapes,$color_space$jscomp$6$$=$props_75055$$.colorSpace,$resolved_tokens$jscomp$7$$=$props_75055$$.resolvedTokens,$on_fill_shorthand$$=$props_75055$$.onFillShorthand,$shorthand_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$main$ui$inspect$styles$panels$fill$generate_fill_shorthand$$($APP.$cljs$core$first$$($shapes$jscomp$168$$),
$color_space$jscomp$6$$)}),$shorthand$$=$APP.$cljs$core$_deref$$($shorthand_STAR_$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shorthand$$),$APP.$rumext$v2$adapt$$($on_fill_shorthand$$),$APP.$rumext$v2$adapt$$($shapes$jscomp$168$$)],function(){$APP.$cljs$core$reset_BANG_$$($shorthand_STAR_$$,$app$main$ui$inspect$styles$panels$fill$generate_fill_shorthand$$($APP.$cljs$core$first$$($shapes$jscomp$168$$),$color_space$jscomp$6$$));var $G__75056$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$cljs$cst$5340$panel$$,$APP.$cljs$cst$1403$fill$$,$cljs$cst$827$property$$,$shorthand$$],null);return $on_fill_shorthand$$.$cljs$core$IFn$_invoke$arity$1$?$on_fill_shorthand$$.$cljs$core$IFn$_invoke$arity$1$($G__75056$$):$on_fill_shorthand$$($G__75056$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_fill__fill-panel",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$88$$,$shape$jscomp$933$$){$out_arr__44124__auto__$jscomp$88$$.push((0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_inspect_styles_panels_fill__fill-shape",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$6$$,$JSCompiler_temp_const$jscomp$1428_p__75057$$){var $JSCompiler_inline_result$jscomp$1430_idx$jscomp$109$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1428_p__75057$$,0,null),$color_type$jscomp$inline_7931_fill$jscomp$25$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1428_p__75057$$,
1,null);$JSCompiler_temp_const$jscomp$1428_p__75057$$=$out_arr__44124__auto____$1$jscomp$6$$.push;$color_type$jscomp$inline_7931_fill$jscomp$25$$=$APP.$app$common$types$fills$fill__GT_color$$($color_type$jscomp$inline_7931_fill$jscomp$25$$);var $property_name$jscomp$inline_7932$$=$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($APP.$cljs$cst$2058$background$$);var $applied_tokens_in_shape$jscomp$inline_13077_resolved_token$jscomp$inline_7933_shape_tokens$jscomp$inline_13076$$=$APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$933$$);
$applied_tokens_in_shape$jscomp$inline_13077_resolved_token$jscomp$inline_7933_shape_tokens$jscomp$inline_13076$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens_in_shape$jscomp$inline_13077_resolved_token$jscomp$inline_7933_shape_tokens$jscomp$inline_13076$$,$APP.$cljs$cst$1403$fill$$);$applied_tokens_in_shape$jscomp$inline_13077_resolved_token$jscomp$inline_7933_shape_tokens$jscomp$inline_13076$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$7$$,
$applied_tokens_in_shape$jscomp$inline_13077_resolved_token$jscomp$inline_7933_shape_tokens$jscomp$inline_13076$$);var $has_token$jscomp$inline_7934$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens_in_shape$jscomp$inline_13077_resolved_token$jscomp$inline_7933_shape_tokens$jscomp$inline_13076$$),$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color_type$jscomp$inline_7931_fill$jscomp$25$$))&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$JSCompiler_inline_result$jscomp$1430_idx$jscomp$109$$);$JSCompiler_inline_result$jscomp$1430_idx$jscomp$109$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color_type$jscomp$inline_7931_fill$jscomp$25$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$color_properties_row$color_properties_row_STAR_$$,{term:$property_name$jscomp$inline_7932$$,color:$color_type$jscomp$inline_7931_fill$jscomp$25$$,
token:$has_token$jscomp$inline_7934$$?$applied_tokens_in_shape$jscomp$inline_13077_resolved_token$jscomp$inline_7933_shape_tokens$jscomp$inline_13076$$:null,format:$color_space$jscomp$6$$,copiable:!0},$JSCompiler_inline_result$jscomp$1430_idx$jscomp$109$$):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$color_properties_row$color_properties_row_STAR_$$,{term:$property_name$jscomp$inline_7932$$,color:$color_type$jscomp$inline_7931_fill$jscomp$25$$,copiable:!0},$JSCompiler_inline_result$jscomp$1430_idx$jscomp$109$$);
$JSCompiler_temp_const$jscomp$1428_p__75057$$.call($out_arr__44124__auto____$1$jscomp$6$$,$JSCompiler_inline_result$jscomp$1430_idx$jscomp$109$$);return $out_arr__44124__auto____$1$jscomp$6$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$933$$)))},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$933$$)));return $out_arr__44124__auto__$jscomp$88$$},[],$shapes$jscomp$168$$)})};
$app$main$ui$inspect$styles$panels$geometry$has_border_radius_QMARK_$$=function($shape$jscomp$934$$){return $APP.$cljs$core$some$$(function($key$jscomp$398$$){return $APP.$cljs$core$contains_QMARK_$$($shape$jscomp$934$$,$key$jscomp$398$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$934$$,$key$jscomp$398$$))},new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1646$r1$$,
$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1649$r4$$],null))};
$app$main$ui$inspect$styles$panels$geometry$generate_geometry_shorthand$$=function($shape$jscomp$inline_13084_shapes$jscomp$169$$,$JSCompiler_temp$jscomp$10890_objects$jscomp$733$$){var $JSCompiler_inline_result$jscomp$1431_and__5023__auto__$jscomp$inline_7936$$=($JSCompiler_inline_result$jscomp$1431_and__5023__auto__$jscomp$inline_7936$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shape$jscomp$inline_13084_shapes$jscomp$169$$),1))?$app$main$ui$inspect$styles$panels$geometry$has_border_radius_QMARK_$$($APP.$cljs$core$first$$($shape$jscomp$inline_13084_shapes$jscomp$169$$)):
$JSCompiler_inline_result$jscomp$1431_and__5023__auto__$jscomp$inline_7936$$;$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1431_and__5023__auto__$jscomp$inline_7936$$)?($shape$jscomp$inline_13084_shapes$jscomp$169$$=$APP.$cljs$core$first$$($shape$jscomp$inline_13084_shapes$jscomp$169$$),$JSCompiler_temp$jscomp$10890_objects$jscomp$733$$=$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($JSCompiler_temp$jscomp$10890_objects$jscomp$733$$,$shape$jscomp$inline_13084_shapes$jscomp$169$$,
$APP.$cljs$cst$1982$border_radius$$)):$JSCompiler_temp$jscomp$10890_objects$jscomp$733$$=null;return $JSCompiler_temp$jscomp$10890_objects$jscomp$733$$};
$app$main$ui$inspect$styles$panels$geometry$geometry_panel_STAR_$$=function($props_75061$$){var $shapes$jscomp$170$$=$props_75061$$.shapes,$on_geometry_shorthand$$=$props_75061$$.onGeometryShorthand,$objects$jscomp$734$$=$props_75061$$.objects,$resolved_tokens$jscomp$9$$=$props_75061$$.resolvedTokens,$shorthand_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$main$ui$inspect$styles$panels$geometry$generate_geometry_shorthand$$($shapes$jscomp$170$$,$objects$jscomp$734$$)}),
$shorthand$jscomp$1$$=$APP.$cljs$core$_deref$$($shorthand_STAR_$jscomp$1$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shorthand$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_geometry_shorthand$$),$APP.$rumext$v2$adapt$$($shapes$jscomp$170$$),$APP.$rumext$v2$adapt$$($objects$jscomp$734$$)],function(){$APP.$cljs$core$reset_BANG_$$($shorthand_STAR_$jscomp$1$$,$app$main$ui$inspect$styles$panels$geometry$generate_geometry_shorthand$$($shapes$jscomp$170$$,$objects$jscomp$734$$));
var $G__75062$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5340$panel$$,$cljs$cst$5330$geometry$$,$cljs$cst$827$property$$,$shorthand$jscomp$1$$],null);return $on_geometry_shorthand$$.$cljs$core$IFn$_invoke$arity$1$?$on_geometry_shorthand$$.$cljs$core$IFn$_invoke$arity$1$($G__75062$$):$on_geometry_shorthand$$($G__75062$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_geometry__geometry-panel",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$89$$,
$shape$jscomp$936$$){$out_arr__44124__auto__$jscomp$89$$.push((0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_geometry__geometry-shape",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$7$$,$JSCompiler_inline_result$jscomp$1434_property$jscomp$61$$){var $JSCompiler_temp_const$jscomp$1432$$=$out_arr__44124__auto____$1$jscomp$7$$.push;var $temp__5825__auto__$jscomp$inline_7938$$=$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$734$$,
$shape$jscomp$936$$,$JSCompiler_inline_result$jscomp$1434_property$jscomp$61$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_7938$$)){var $property_name$jscomp$inline_7939$$=$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($JSCompiler_inline_result$jscomp$1434_property$jscomp$61$$);var $applied_tokens_in_shape$jscomp$inline_13091_resolved_token$jscomp$inline_7940_shape_tokens$jscomp$inline_14542$$=$APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$936$$);
var $border_prop$jscomp$inline_14544_property_value$jscomp$inline_7941$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$styles$panels$geometry$shape_prop__GT_border_radius_prop$$,$JSCompiler_inline_result$jscomp$1434_property$jscomp$61$$);$applied_tokens_in_shape$jscomp$inline_13091_resolved_token$jscomp$inline_7940_shape_tokens$jscomp$inline_14542$$=$APP.$cljs$core$truth_$$($border_prop$jscomp$inline_14544_property_value$jscomp$inline_7941$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens_in_shape$jscomp$inline_13091_resolved_token$jscomp$inline_7940_shape_tokens$jscomp$inline_14542$$,
$border_prop$jscomp$inline_14544_property_value$jscomp$inline_7941$$):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens_in_shape$jscomp$inline_13091_resolved_token$jscomp$inline_7940_shape_tokens$jscomp$inline_14542$$,$JSCompiler_inline_result$jscomp$1434_property$jscomp$61$$);$applied_tokens_in_shape$jscomp$inline_13091_resolved_token$jscomp$inline_7940_shape_tokens$jscomp$inline_14542$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$9$$,$applied_tokens_in_shape$jscomp$inline_13091_resolved_token$jscomp$inline_7940_shape_tokens$jscomp$inline_14542$$);
$border_prop$jscomp$inline_14544_property_value$jscomp$inline_7941$$=$APP.$cljs$core$not$$($applied_tokens_in_shape$jscomp$inline_13091_resolved_token$jscomp$inline_7940_shape_tokens$jscomp$inline_14542$$)?$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$734$$,$shape$jscomp$936$$,$JSCompiler_inline_result$jscomp$1434_property$jscomp$61$$):"";$JSCompiler_inline_result$jscomp$1434_property$jscomp$61$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,
{term:$property_name$jscomp$inline_7939$$,detail:$temp__5825__auto__$jscomp$inline_7938$$,token:$applied_tokens_in_shape$jscomp$inline_13091_resolved_token$jscomp$inline_7940_shape_tokens$jscomp$inline_14542$$,property:$border_prop$jscomp$inline_14544_property_value$jscomp$inline_7941$$,copiable:!0},"geometry-property-"+($JSCompiler_inline_result$jscomp$1434_property$jscomp$61$$??""))}else $JSCompiler_inline_result$jscomp$1434_property$jscomp$61$$=null;$JSCompiler_temp_const$jscomp$1432$$.call($out_arr__44124__auto____$1$jscomp$7$$,
$JSCompiler_inline_result$jscomp$1434_property$jscomp$61$$);return $out_arr__44124__auto____$1$jscomp$7$$},[],$app$main$ui$inspect$styles$panels$geometry$properties$$)},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$936$$)));return $out_arr__44124__auto__$jscomp$89$$},[],$shapes$jscomp$170$$)})};
$app$main$ui$inspect$styles$panels$layout$has_padding_QMARK_$$=function($shape$jscomp$937$$){var $padding$jscomp$10$$=$APP.$cljs$cst$1686$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$937$$);return $APP.$cljs$core$some$$(function($key$jscomp$399$$){return $APP.$cljs$core$contains_QMARK_$$($padding$jscomp$10$$,$key$jscomp$399$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding$jscomp$10$$,$key$jscomp$399$$))},
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1093$p1$$,$APP.$cljs$cst$1091$p2$$,$APP.$cljs$cst$1687$p3$$,$APP.$cljs$cst$1688$p4$$],null))};
$app$main$ui$inspect$styles$panels$layout$generate_layout_shorthand$$=function($shapes$jscomp$171_shorthand_grid$$,$objects$jscomp$735$$){var $shape$jscomp$939$$=$APP.$cljs$core$first$$($shapes$jscomp$171_shorthand_grid$$);var $JSCompiler_inline_result$jscomp$10939_and__5023__auto__$jscomp$inline_13093_shorthand_padding$$=($JSCompiler_inline_result$jscomp$10939_and__5023__auto__$jscomp$inline_13093_shorthand_padding$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$171_shorthand_grid$$),
1))?$app$main$ui$inspect$styles$panels$layout$has_padding_QMARK_$$($shape$jscomp$939$$):$JSCompiler_inline_result$jscomp$10939_and__5023__auto__$jscomp$inline_13093_shorthand_padding$$;$JSCompiler_inline_result$jscomp$10939_and__5023__auto__$jscomp$inline_13093_shorthand_padding$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10939_and__5023__auto__$jscomp$inline_13093_shorthand_padding$$)?$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$735$$,
$shape$jscomp$939$$,$APP.$cljs$cst$256$padding$$):null;$shapes$jscomp$171_shorthand_grid$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$171_shorthand_grid$$),1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1659$grid$$,$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$939$$))?["grid: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$735$$,
$shape$jscomp$939$$,$cljs$cst$4059$grid_template_rows$$))," / ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$735$$,$shape$jscomp$939$$,$cljs$cst$4070$grid_template_columns$$)),";"].join(""):null;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10939_and__5023__auto__$jscomp$inline_13093_shorthand_padding$$)?$JSCompiler_inline_result$jscomp$10939_and__5023__auto__$jscomp$inline_13093_shorthand_padding$$:
$shapes$jscomp$171_shorthand_grid$$)?[$shapes$jscomp$171_shorthand_grid$$," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10939_and__5023__auto__$jscomp$inline_13093_shorthand_padding$$)].join(""):null};
$app$main$ui$inspect$styles$panels$layout$layout_panel_STAR_$$=function($props_75063$$){var $shapes$jscomp$172$$=$props_75063$$.shapes,$objects$jscomp$736$$=$props_75063$$.objects,$resolved_tokens$jscomp$11$$=$props_75063$$.resolvedTokens,$on_layout_shorthand$$=$props_75063$$.onLayoutShorthand,$shorthand_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$main$ui$inspect$styles$panels$layout$generate_layout_shorthand$$($shapes$jscomp$172$$,$objects$jscomp$736$$)}),
$shorthand$jscomp$3$$=$APP.$cljs$core$_deref$$($shorthand_STAR_$jscomp$2$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shorthand$jscomp$3$$),$APP.$rumext$v2$adapt$$($on_layout_shorthand$$),$APP.$rumext$v2$adapt$$($shapes$jscomp$172$$),$APP.$rumext$v2$adapt$$($objects$jscomp$736$$)],function(){$APP.$cljs$core$reset_BANG_$$($shorthand_STAR_$jscomp$2$$,$app$main$ui$inspect$styles$panels$layout$generate_layout_shorthand$$($shapes$jscomp$172$$,$objects$jscomp$736$$));
var $G__75064$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5340$panel$$,$APP.$cljs$cst$1615$layout$$,$cljs$cst$827$property$$,$shorthand$jscomp$3$$],null);return $on_layout_shorthand$$.$cljs$core$IFn$_invoke$arity$1$?$on_layout_shorthand$$.$cljs$core$IFn$_invoke$arity$1$($G__75064$$):$on_layout_shorthand$$($G__75064$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_layout__variants-panel",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$90$$,
$shape$jscomp$940$$){$out_arr__44124__auto__$jscomp$90$$.push((0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_layout__layout-shape",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$8$$,$JSCompiler_inline_result$jscomp$1437_property$jscomp$64$$){var $JSCompiler_temp_const$jscomp$1435$$=$out_arr__44124__auto____$1$jscomp$8$$.push;var $temp__5825__auto__$jscomp$inline_7943$$=$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$736$$,
$shape$jscomp$940$$,$JSCompiler_inline_result$jscomp$1437_property$jscomp$64$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_7943$$)){var $property_name$jscomp$inline_7944$$=$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($JSCompiler_inline_result$jscomp$1437_property$jscomp$64$$);var $applied_tokens_in_shape$jscomp$inline_13099_resolved_token$jscomp$inline_7945_shape_tokens$jscomp$inline_14546$$=$APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$940$$);
var $padding_prop$jscomp$inline_14548_property_value$jscomp$inline_7946$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$styles$panels$layout$shape_prop__GT_padding_prop$$,$JSCompiler_inline_result$jscomp$1437_property$jscomp$64$$);$applied_tokens_in_shape$jscomp$inline_13099_resolved_token$jscomp$inline_7945_shape_tokens$jscomp$inline_14546$$=$APP.$cljs$core$truth_$$($padding_prop$jscomp$inline_14548_property_value$jscomp$inline_7946$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens_in_shape$jscomp$inline_13099_resolved_token$jscomp$inline_7945_shape_tokens$jscomp$inline_14546$$,
$padding_prop$jscomp$inline_14548_property_value$jscomp$inline_7946$$):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens_in_shape$jscomp$inline_13099_resolved_token$jscomp$inline_7945_shape_tokens$jscomp$inline_14546$$,$JSCompiler_inline_result$jscomp$1437_property$jscomp$64$$);$applied_tokens_in_shape$jscomp$inline_13099_resolved_token$jscomp$inline_7945_shape_tokens$jscomp$inline_14546$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$11$$,$applied_tokens_in_shape$jscomp$inline_13099_resolved_token$jscomp$inline_7945_shape_tokens$jscomp$inline_14546$$);
$padding_prop$jscomp$inline_14548_property_value$jscomp$inline_7946$$=$APP.$cljs$core$not$$($applied_tokens_in_shape$jscomp$inline_13099_resolved_token$jscomp$inline_7945_shape_tokens$jscomp$inline_14546$$)?$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$736$$,$shape$jscomp$940$$,$JSCompiler_inline_result$jscomp$1437_property$jscomp$64$$):"";$JSCompiler_inline_result$jscomp$1437_property$jscomp$64$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,
{term:$property_name$jscomp$inline_7944$$,detail:$temp__5825__auto__$jscomp$inline_7943$$,token:$applied_tokens_in_shape$jscomp$inline_13099_resolved_token$jscomp$inline_7945_shape_tokens$jscomp$inline_14546$$,property:$padding_prop$jscomp$inline_14548_property_value$jscomp$inline_7946$$,copiable:!0},"layout-property-"+($JSCompiler_inline_result$jscomp$1437_property$jscomp$64$$??""))}else $JSCompiler_inline_result$jscomp$1437_property$jscomp$64$$=null;$JSCompiler_temp_const$jscomp$1435$$.call($out_arr__44124__auto____$1$jscomp$8$$,
$JSCompiler_inline_result$jscomp$1437_property$jscomp$64$$);return $out_arr__44124__auto____$1$jscomp$8$$},[],$app$main$ui$inspect$styles$panels$layout$properties$$)},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$940$$)));return $out_arr__44124__auto__$jscomp$90$$},[],$shapes$jscomp$172$$)})};
$app$main$ui$inspect$styles$panels$layout_element$has_margin_QMARK_$$=function($shape$jscomp$941$$){var $margin$jscomp$1$$=$APP.$cljs$cst$1699$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$941$$);return $APP.$cljs$core$some$$(function($key$jscomp$400$$){return $APP.$cljs$core$contains_QMARK_$$($margin$jscomp$1$$,$key$jscomp$400$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($margin$jscomp$1$$,$key$jscomp$400$$))},
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1700$m1$$,$APP.$cljs$cst$1701$m2$$,$APP.$cljs$cst$1702$m3$$,$APP.$cljs$cst$1703$m4$$],null))};
$app$main$ui$inspect$styles$panels$layout_element$generate_layout_element_shorthand$$=function($shapes$jscomp$173$$,$objects$jscomp$737$$){var $shape$jscomp$943$$=$APP.$cljs$core$first$$($shapes$jscomp$173$$),$shorthand_margin$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$658$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$173$$),1);return $and__5023__auto__$jscomp$658$$?$app$main$ui$inspect$styles$panels$layout_element$has_margin_QMARK_$$($shape$jscomp$943$$):
$and__5023__auto__$jscomp$658$$}())?$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$737$$,$shape$jscomp$943$$,$APP.$cljs$cst$1929$margin$$):null,$shorthand_grow$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$173$$),1)&&$APP.$app$common$types$shape$layout$flex_layout_immediate_child_QMARK_$$($objects$jscomp$737$$,$shape$jscomp$943$$)?function(){var $temp__5823__auto__$jscomp$210$$=$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$737$$,
$shape$jscomp$943$$,$APP.$cljs$cst$1660$flex$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$210$$)?$temp__5823__auto__$jscomp$210$$:0}():null,$shorthand_shrink$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$173$$),1)&&$APP.$app$common$types$shape$layout$flex_layout_immediate_child_QMARK_$$($objects$jscomp$737$$,$shape$jscomp$943$$)?function(){var $temp__5823__auto__$jscomp$211$$=$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$737$$,
$shape$jscomp$943$$,$cljs$cst$4082$flex_shrink$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$211$$)?$temp__5823__auto__$jscomp$211$$:0}():null;return""+($shorthand_margin$$??"")+" flex: "+(($shorthand_grow$$??"")+" 0 "+($shorthand_shrink$$??"")+";")};
$app$main$ui$inspect$styles$panels$layout_element$layout_element_panel_STAR_$$=function($props_75066$$){var $objects$jscomp$738$$=$props_75066$$.objects,$resolved_tokens$jscomp$13$$=$props_75066$$.resolvedTokens,$on_layout_element_shorthand$$=$props_75066$$.onLayoutElementShorthand,$layout_element_properties$$=$props_75066$$.layoutElementProperties,$shapes__$1$jscomp$29$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75065_SHARP_$$){return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$738$$,
$p1__75065_SHARP_$$)},$props_75066$$.shapes),$shorthand_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$main$ui$inspect$styles$panels$layout_element$generate_layout_element_shorthand$$($shapes__$1$jscomp$29$$,$objects$jscomp$738$$)}),$shorthand$jscomp$5$$=$APP.$cljs$core$_deref$$($shorthand_STAR_$jscomp$3$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shorthand$jscomp$5$$),$APP.$rumext$v2$adapt$$($on_layout_element_shorthand$$),
$APP.$rumext$v2$adapt$$($shapes__$1$jscomp$29$$),$APP.$rumext$v2$adapt$$($objects$jscomp$738$$)],function(){$APP.$cljs$core$reset_BANG_$$($shorthand_STAR_$jscomp$3$$,$app$main$ui$inspect$styles$panels$layout_element$generate_layout_element_shorthand$$($shapes__$1$jscomp$29$$,$objects$jscomp$738$$));var $G__75067$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5340$panel$$,$cljs$cst$5329$layout_element$$,$cljs$cst$827$property$$,$shorthand$jscomp$5$$],null);return $on_layout_element_shorthand$$.$cljs$core$IFn$_invoke$arity$1$?
$on_layout_element_shorthand$$.$cljs$core$IFn$_invoke$arity$1$($G__75067$$):$on_layout_element_shorthand$$($G__75067$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_layout_element__layout-element-panel",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$91$$,$shape$jscomp$944$$){$out_arr__44124__auto__$jscomp$91$$.push((0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_layout_element__layout-element-shape",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$9$$,$JSCompiler_inline_result$jscomp$1440_property$jscomp$67$$){var $JSCompiler_temp_const$jscomp$1438$$=$out_arr__44124__auto____$1$jscomp$9$$.push;var $temp__5825__auto__$jscomp$inline_7948$$=$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$738$$,$shape$jscomp$944$$,$JSCompiler_inline_result$jscomp$1440_property$jscomp$67$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_7948$$)){var $property_name$jscomp$inline_7949$$=
$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($JSCompiler_inline_result$jscomp$1440_property$jscomp$67$$);var $applied_tokens_in_shape$jscomp$inline_13105_resolved_token$jscomp$inline_7950_temp__5825__auto__$jscomp$inline_13104$$=$APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$944$$);if($APP.$cljs$core$truth_$$($applied_tokens_in_shape$jscomp$inline_13105_resolved_token$jscomp$inline_7950_temp__5825__auto__$jscomp$inline_13104$$)){var $property_value$jscomp$inline_7951_temp__5823__auto__$jscomp$inline_14552$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$styles$panels$layout_element$shape_prop__GT_margin_prop$$,$JSCompiler_inline_result$jscomp$1440_property$jscomp$67$$);$applied_tokens_in_shape$jscomp$inline_13105_resolved_token$jscomp$inline_7950_temp__5825__auto__$jscomp$inline_13104$$=$APP.$cljs$core$truth_$$($property_value$jscomp$inline_7951_temp__5823__auto__$jscomp$inline_14552$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens_in_shape$jscomp$inline_13105_resolved_token$jscomp$inline_7950_temp__5825__auto__$jscomp$inline_13104$$,
$property_value$jscomp$inline_7951_temp__5823__auto__$jscomp$inline_14552$$):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens_in_shape$jscomp$inline_13105_resolved_token$jscomp$inline_7950_temp__5825__auto__$jscomp$inline_13104$$,$JSCompiler_inline_result$jscomp$1440_property$jscomp$67$$);$applied_tokens_in_shape$jscomp$inline_13105_resolved_token$jscomp$inline_7950_temp__5825__auto__$jscomp$inline_13104$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$13$$,
$applied_tokens_in_shape$jscomp$inline_13105_resolved_token$jscomp$inline_7950_temp__5825__auto__$jscomp$inline_13104$$)}else $applied_tokens_in_shape$jscomp$inline_13105_resolved_token$jscomp$inline_7950_temp__5825__auto__$jscomp$inline_13104$$=null;$property_value$jscomp$inline_7951_temp__5823__auto__$jscomp$inline_14552$$=$APP.$cljs$core$not$$($applied_tokens_in_shape$jscomp$inline_13105_resolved_token$jscomp$inline_7950_temp__5825__auto__$jscomp$inline_13104$$)?$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$738$$,
$shape$jscomp$944$$,$JSCompiler_inline_result$jscomp$1440_property$jscomp$67$$):"";$JSCompiler_inline_result$jscomp$1440_property$jscomp$67$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:$property_name$jscomp$inline_7949$$,detail:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto__$jscomp$inline_7948$$),token:$applied_tokens_in_shape$jscomp$inline_13105_resolved_token$jscomp$inline_7950_temp__5825__auto__$jscomp$inline_13104$$,
property:$property_value$jscomp$inline_7951_temp__5823__auto__$jscomp$inline_14552$$,copiable:!0},"layout-element-property-"+($JSCompiler_inline_result$jscomp$1440_property$jscomp$67$$??""))}else $JSCompiler_inline_result$jscomp$1440_property$jscomp$67$$=null;$JSCompiler_temp_const$jscomp$1438$$.call($out_arr__44124__auto____$1$jscomp$9$$,$JSCompiler_inline_result$jscomp$1440_property$jscomp$67$$);return $out_arr__44124__auto____$1$jscomp$9$$},[],$layout_element_properties$$)},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$944$$)));
return $out_arr__44124__auto__$jscomp$91$$},[],$shapes__$1$jscomp$29$$)})};
$app$main$ui$inspect$styles$panels$shadow$get_resolved_token$$=function($applied_tokens_in_shape$jscomp$4_shape$jscomp$945_shape_tokens$jscomp$9$$,$resolved_tokens$jscomp$14$$){$applied_tokens_in_shape$jscomp$4_shape$jscomp$945_shape_tokens$jscomp$9$$=$APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens_in_shape$jscomp$4_shape$jscomp$945_shape_tokens$jscomp$9$$);$applied_tokens_in_shape$jscomp$4_shape$jscomp$945_shape_tokens$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens_in_shape$jscomp$4_shape$jscomp$945_shape_tokens$jscomp$9$$,
$APP.$cljs$cst$1654$shadow$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$14$$,$applied_tokens_in_shape$jscomp$4_shape$jscomp$945_shape_tokens$jscomp$9$$)};
$app$main$ui$inspect$styles$panels$shadow$generate_shadow_shorthand$$=function($shapes$jscomp$175$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$175$$),1)?"box-shadow: "+($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$151$$,$shadow__$1$jscomp$15_value$jscomp$774$$){$shadow__$1$jscomp$15_value$jscomp$774$$=$app$util$code_gen$style_css_formats$format_shadow__GT_css$$($shadow__$1$jscomp$15_value$jscomp$774$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);
return $APP.$cljs$core$empty_QMARK_$$($acc$jscomp$151$$)?$shadow__$1$jscomp$15_value$jscomp$774$$:""+($acc$jscomp$151$$??"")+", "+($shadow__$1$jscomp$15_value$jscomp$774$$??"")},"",$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$175$$)))??"")+";":null};
$app$main$ui$inspect$styles$panels$shadow$shadow_panel_STAR_$$=function($props_75068$$){var $on_shadow_shorthand$$=$props_75068$$.onShadowShorthand,$shapes$jscomp$176$$=$props_75068$$.shapes,$color_space$jscomp$7$$=$props_75068$$.colorSpace,$resolved_tokens$jscomp$15$$=$props_75068$$.resolvedTokens,$shorthand_STAR_$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$main$ui$inspect$styles$panels$shadow$generate_shadow_shorthand$$($shapes$jscomp$176$$)}),
$shorthand$jscomp$6$$=$APP.$cljs$core$_deref$$($shorthand_STAR_$jscomp$4$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shorthand$jscomp$6$$),$APP.$rumext$v2$adapt$$($on_shadow_shorthand$$),$APP.$rumext$v2$adapt$$($shapes$jscomp$176$$)],function(){$APP.$cljs$core$reset_BANG_$$($shorthand_STAR_$jscomp$4$$,$app$main$ui$inspect$styles$panels$shadow$generate_shadow_shorthand$$($shapes$jscomp$176$$));var $G__75069$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$cljs$cst$5340$panel$$,$APP.$cljs$cst$1654$shadow$$,$cljs$cst$827$property$$,$shorthand$jscomp$6$$],null);return $on_shadow_shorthand$$.$cljs$core$IFn$_invoke$arity$1$?$on_shadow_shorthand$$.$cljs$core$IFn$_invoke$arity$1$($G__75069$$):$on_shadow_shorthand$$($G__75069$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_shadow__shadow-panel",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$92$$,$shape$jscomp$946$$){$out_arr__44124__auto__$jscomp$92$$.push(function(){var $composite_shadow_token$$=
$app$main$ui$inspect$styles$panels$shadow$get_resolved_token$$($shape$jscomp$946$$,$resolved_tokens$jscomp$15$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$10$$,$JSCompiler_temp_const$jscomp$1443_p__75071$$){var $idx$jscomp$110$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1443_p__75071$$,0,null),$property_value$jscomp$inline_7955_shadow__$1$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1443_p__75071$$,
1,null);$JSCompiler_temp_const$jscomp$1443_p__75071$$=$out_arr__44124__auto____$1$jscomp$10$$.push;var $JSCompiler_temp_const$jscomp$1442$$=$APP.$cljs$core$truth_$$($composite_shadow_token$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:"Shadow",detail:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($composite_shadow_token$$),token:$composite_shadow_token$$,property:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($composite_shadow_token$$),
copiable:!0}):null,$JSCompiler_temp_const$jscomp$1441$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$color_properties_row$color_properties_row_STAR_$$,{term:"Shadow Color",color:$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($property_value$jscomp$inline_7955_shadow__$1$jscomp$16$$),format:$color_space$jscomp$7$$,copiable:!0});var $JSCompiler_inline_result$jscomp$1445_value$jscomp$inline_7953$$=""+($APP.$cljs$cst$1650$offset_x$$.$cljs$core$IFn$_invoke$arity$1$($property_value$jscomp$inline_7955_shadow__$1$jscomp$16$$)??
"")+"px "+($APP.$cljs$cst$1651$offset_y$$.$cljs$core$IFn$_invoke$arity$1$($property_value$jscomp$inline_7955_shadow__$1$jscomp$16$$)??"")+"px "+($APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($property_value$jscomp$inline_7955_shadow__$1$jscomp$16$$)??"")+"px "+($APP.$cljs$cst$1652$spread$$.$cljs$core$IFn$_invoke$arity$1$($property_value$jscomp$inline_7955_shadow__$1$jscomp$16$$)??"")+"px";var $property_name$jscomp$inline_7954$$=$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($property_value$jscomp$inline_7955_shadow__$1$jscomp$16$$));
$property_value$jscomp$inline_7955_shadow__$1$jscomp$16$$="box-shadow: "+($app$util$code_gen$style_css_formats$format_shadow__GT_css$$($property_value$jscomp$inline_7955_shadow__$1$jscomp$16$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)??"")+";";$JSCompiler_inline_result$jscomp$1445_value$jscomp$inline_7953$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:$property_name$jscomp$inline_7954$$,detail:""+($JSCompiler_inline_result$jscomp$1445_value$jscomp$inline_7953$$??
""),property:$property_value$jscomp$inline_7955_shadow__$1$jscomp$16$$,copiable:!0});$JSCompiler_temp_const$jscomp$1443_p__75071$$.call($out_arr__44124__auto____$1$jscomp$10$$,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_styles_panels_shadow__shadow-shape",children:[$JSCompiler_temp_const$jscomp$1442$$,$JSCompiler_temp_const$jscomp$1441$$,$JSCompiler_inline_result$jscomp$1445_value$jscomp$inline_7953$$]},""+($idx$jscomp$110$$??"")));return $out_arr__44124__auto____$1$jscomp$10$$},
[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$946$$)))}());return $out_arr__44124__auto__$jscomp$92$$},[],$shapes$jscomp$176$$)})};
$app$main$ui$inspect$styles$panels$stroke$generate_stroke_shorthand$$=function($shape$jscomp$948_shapes$jscomp$177$$,$color_space$jscomp$8$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shape$jscomp$948_shapes$jscomp$177$$),1)?($shape$jscomp$948_shapes$jscomp$177$$=$APP.$cljs$core$first$$($shape$jscomp$948_shapes$jscomp$177$$),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$152$$,$stroke$jscomp$32_stroke_style$jscomp$2$$){var $color_image$jscomp$1_stroke_type$jscomp$1$$=
$APP.$app$common$types$color$stroke__GT_color$$($stroke$jscomp$32_stroke_style$jscomp$2$$),$stroke_width$jscomp$7_value$jscomp$776$$=$APP.$cljs$cst$1655$stroke_width$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$32_stroke_style$jscomp$2$$);$stroke$jscomp$32_stroke_style$jscomp$2$$=$APP.$cljs$cst$1866$stroke_style$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$32_stroke_style$jscomp$2$$);var $color_value$jscomp$2$$=$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($color_image$jscomp$1_stroke_type$jscomp$1$$),
$formatted_color_value$jscomp$1$$=$app$util$color$color__GT_format__GT_background$$($color_image$jscomp$1_stroke_type$jscomp$1$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($color_space$jscomp$8$$)),$color_gradient$jscomp$1$$=$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color_image$jscomp$1_stroke_type$jscomp$1$$),$gradient_data$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($color_image$jscomp$1_stroke_type$jscomp$1$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$cst$139$type$$],null)),$APP.$cljs$cst$1733$stops$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($color_image$jscomp$1_stroke_type$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1724$gradient$$,$APP.$cljs$cst$1733$stops$$],null))],null);$color_image$jscomp$1_stroke_type$jscomp$1$$=
$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color_image$jscomp$1_stroke_type$jscomp$1$$);$stroke_width$jscomp$7_value$jscomp$776$$=$APP.$cljs$core$truth_$$($color_value$jscomp$2$$)?"border: "+($stroke_width$jscomp$7_value$jscomp$776$$??"")+"px "+($APP.$app$common$data$name$$($stroke$jscomp$32_stroke_style$jscomp$2$$)??"")+" "+($formatted_color_value$jscomp$1$$??"")+";":$APP.$cljs$core$truth_$$($color_gradient$jscomp$1$$)?"border-image: "+($app$util$color$gradient__GT_css$$($gradient_data$jscomp$1$$)??
"")+" 100 / "+($stroke_width$jscomp$7_value$jscomp$776$$??"")+"px;":$APP.$cljs$core$truth_$$($color_image$jscomp$1_stroke_type$jscomp$1$$)?"border-image: url("+($APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($color_image$jscomp$1_stroke_type$jscomp$1$$)??"")+") 100 / "+($stroke_width$jscomp$7_value$jscomp$776$$??"")+"px;":"";return $APP.$cljs$core$empty_QMARK_$$($acc$jscomp$152$$)?$stroke_width$jscomp$7_value$jscomp$776$$:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($acc$jscomp$152$$),
" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($stroke_width$jscomp$7_value$jscomp$776$$)].join("")},"",$APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$948_shapes$jscomp$177$$))):null};
$app$main$ui$inspect$styles$panels$stroke$stroke_panel_STAR_$$=function($props_75070$$){var $shapes$jscomp$178$$=$props_75070$$.shapes,$color_space$jscomp$9$$=$props_75070$$.colorSpace,$objects$jscomp$739$$=$props_75070$$.objects,$resolved_tokens$jscomp$17$$=$props_75070$$.resolvedTokens,$on_stroke_shorthand$$=$props_75070$$.onStrokeShorthand,$shorthand_STAR_$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$main$ui$inspect$styles$panels$stroke$generate_stroke_shorthand$$($shapes$jscomp$178$$,
$color_space$jscomp$9$$)}),$shorthand$jscomp$7$$=$APP.$cljs$core$_deref$$($shorthand_STAR_$jscomp$5$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shorthand$jscomp$7$$),$APP.$rumext$v2$adapt$$($on_stroke_shorthand$$),$APP.$rumext$v2$adapt$$($shapes$jscomp$178$$)],function(){$APP.$cljs$core$reset_BANG_$$($shorthand_STAR_$jscomp$5$$,$app$main$ui$inspect$styles$panels$stroke$generate_stroke_shorthand$$($shapes$jscomp$178$$,$color_space$jscomp$9$$));var $G__75079$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5340$panel$$,$APP.$cljs$cst$2903$stroke$$,$cljs$cst$827$property$$,$shorthand$jscomp$7$$],null);return $on_stroke_shorthand$$.$cljs$core$IFn$_invoke$arity$1$?$on_stroke_shorthand$$.$cljs$core$IFn$_invoke$arity$1$($G__75079$$):$on_stroke_shorthand$$($G__75079$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_stroke__stroke-panel",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$93$$,
$shape$jscomp$949$$){$out_arr__44124__auto__$jscomp$93$$.push((0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_stroke__stroke-shape",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$11$$,$p__75081$$){var $idx$jscomp$113$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__75081$$,0,null),$stroke$jscomp$33$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__75081$$,1,null);$out_arr__44124__auto____$1$jscomp$11$$.push($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$2$$,
$JSCompiler_inline_result$jscomp$1448_property$jscomp$72$$){var $JSCompiler_temp_const$jscomp$1446$$=$out_arr__44124__auto____$2$$.push,$value$jscomp$inline_7957$$=$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$739$$,$stroke$jscomp$33$$,$JSCompiler_inline_result$jscomp$1448_property$jscomp$72$$),$stroke_type$jscomp$inline_7958$$=$APP.$app$common$types$color$stroke__GT_color$$($stroke$jscomp$33$$),$property_name$jscomp$inline_7959$$=$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($JSCompiler_inline_result$jscomp$1448_property$jscomp$72$$),
$property_value$jscomp$inline_7960$$=$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$739$$,$stroke$jscomp$33$$,$JSCompiler_inline_result$jscomp$1448_property$jscomp$72$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$idx$jscomp$113$$)){var $JSCompiler_temp$jscomp$10940_applied_tokens_in_shape$jscomp$inline_13111_resolved_token$jscomp$inline_7961_shape_tokens$jscomp$inline_14554$$=$APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$949$$);
var $border_prop$jscomp$inline_14556_has_color_token$jscomp$inline_7962$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$styles$panels$stroke$shape_prop__GT_stroke_prop$$,$JSCompiler_inline_result$jscomp$1448_property$jscomp$72$$);$JSCompiler_temp$jscomp$10940_applied_tokens_in_shape$jscomp$inline_13111_resolved_token$jscomp$inline_7961_shape_tokens$jscomp$inline_14554$$=$APP.$cljs$core$truth_$$($border_prop$jscomp$inline_14556_has_color_token$jscomp$inline_7962$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10940_applied_tokens_in_shape$jscomp$inline_13111_resolved_token$jscomp$inline_7961_shape_tokens$jscomp$inline_14554$$,
$border_prop$jscomp$inline_14556_has_color_token$jscomp$inline_7962$$):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10940_applied_tokens_in_shape$jscomp$inline_13111_resolved_token$jscomp$inline_7961_shape_tokens$jscomp$inline_14554$$,$JSCompiler_inline_result$jscomp$1448_property$jscomp$72$$);$JSCompiler_temp$jscomp$10940_applied_tokens_in_shape$jscomp$inline_13111_resolved_token$jscomp$inline_7961_shape_tokens$jscomp$inline_14554$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$17$$,
$JSCompiler_temp$jscomp$10940_applied_tokens_in_shape$jscomp$inline_13111_resolved_token$jscomp$inline_7961_shape_tokens$jscomp$inline_14554$$)}else $JSCompiler_temp$jscomp$10940_applied_tokens_in_shape$jscomp$inline_13111_resolved_token$jscomp$inline_7961_shape_tokens$jscomp$inline_14554$$=null;$border_prop$jscomp$inline_14556_has_color_token$jscomp$inline_7962$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4605$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10940_applied_tokens_in_shape$jscomp$inline_13111_resolved_token$jscomp$inline_7961_shape_tokens$jscomp$inline_14554$$),
$APP.$cljs$cst$1298$color$$.$cljs$core$IFn$_invoke$arity$1$($stroke_type$jscomp$inline_7958$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$idx$jscomp$113$$);$JSCompiler_inline_result$jscomp$1448_property$jscomp$72$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1448_property$jscomp$72$$,$cljs$cst$4067$border_color$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$color_properties_row$color_properties_row_STAR_$$,{term:$property_name$jscomp$inline_7959$$,
color:$stroke_type$jscomp$inline_7958$$,token:$border_prop$jscomp$inline_14556_has_color_token$jscomp$inline_7962$$?$JSCompiler_temp$jscomp$10940_applied_tokens_in_shape$jscomp$inline_13111_resolved_token$jscomp$inline_7961_shape_tokens$jscomp$inline_14554$$:null,format:$color_space$jscomp$9$$,copiable:!0},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($idx$jscomp$113$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1448_property$jscomp$72$$)].join("")):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:$APP.$app$common$data$name$$($property_name$jscomp$inline_7959$$),detail:""+($value$jscomp$inline_7957$$??""),token:$JSCompiler_temp$jscomp$10940_applied_tokens_in_shape$jscomp$inline_13111_resolved_token$jscomp$inline_7961_shape_tokens$jscomp$inline_14554$$,property:$property_value$jscomp$inline_7960$$,copiable:!0},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($idx$jscomp$113$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1448_property$jscomp$72$$)].join(""));
$JSCompiler_temp_const$jscomp$1446$$.call($out_arr__44124__auto____$2$$,$JSCompiler_inline_result$jscomp$1448_property$jscomp$72$$);return $out_arr__44124__auto____$2$$},[],$app$main$ui$inspect$styles$panels$stroke$properties$$));return $out_arr__44124__auto____$1$jscomp$11$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$949$$)))},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$949$$)));
return $out_arr__44124__auto__$jscomp$93$$},[],$shapes$jscomp$178$$)})};
$app$main$ui$inspect$styles$panels$svg$map__GT_css$$=function($attr$jscomp$61$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("; ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($attr_value$jscomp$4_p__75075$$){var $attr_key$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value$jscomp$4_p__75075$$,0,null);$attr_value$jscomp$4_p__75075$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value$jscomp$4_p__75075$$,1,null);return[$APP.$app$common$data$name$$($attr_key$jscomp$4$$),
":",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attr_value$jscomp$4_p__75075$$)].join("")},$attr$jscomp$61$$))};
$app$main$ui$inspect$styles$panels$svg$svg_panel_STAR_$$=function($props_75080_shape$jscomp$950$$){$props_75080_shape$jscomp$950$$=$props_75080_shape$jscomp$950$$.shape;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_svg__svg-panel",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_svg__svg-shape",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$94$$,$attr_value$jscomp$5_p__75085$$){var $attr_key$jscomp$5$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value$jscomp$5_p__75085$$,0,null);$attr_value$jscomp$5_p__75085$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value$jscomp$5_p__75085$$,1,null);$out_arr__44124__auto__$jscomp$94$$.push($APP.$cljs$core$map_QMARK_$$($attr_value$jscomp$5_p__75085$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$12$$,$JSCompiler_temp_const$jscomp$1449_p__75089$$){var $JSCompiler_inline_result$jscomp$1451_sub_attr_key$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1449_p__75089$$,0,null),$sub_attr_value$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1449_p__75089$$,1,null);$JSCompiler_temp_const$jscomp$1449_p__75089$$=$out_arr__44124__auto____$1$jscomp$12$$.push;var $property_value$jscomp$inline_7964$$=$app$main$ui$inspect$styles$panels$svg$map__GT_css$$($sub_attr_value$$);$JSCompiler_inline_result$jscomp$1451_sub_attr_key$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,
{term:$APP.$app$common$data$name$$($JSCompiler_inline_result$jscomp$1451_sub_attr_key$$),detail:""+($sub_attr_value$$??""),property:$property_value$jscomp$inline_7964$$,copiable:!0},"svg-property-"+($APP.$app$common$data$name$$($JSCompiler_inline_result$jscomp$1451_sub_attr_key$$)??""));$JSCompiler_temp_const$jscomp$1449_p__75089$$.call($out_arr__44124__auto____$1$jscomp$12$$,$JSCompiler_inline_result$jscomp$1451_sub_attr_key$$);return $out_arr__44124__auto____$1$jscomp$12$$},[],$attr_value$jscomp$5_p__75085$$):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:$APP.$app$common$data$name$$($attr_key$jscomp$5$$),detail:""+($attr_value$jscomp$5_p__75085$$??""),property:""+($attr_key$jscomp$5$$??"")+": "+($attr_value$jscomp$5_p__75085$$??"")+";",copiable:!0},"svg-property-"+($APP.$app$common$data$name$$($attr_key$jscomp$5$$)??"")));return $out_arr__44124__auto__$jscomp$94$$},[],$APP.$cljs$cst$1890$svg_attrs$$.$cljs$core$IFn$_invoke$arity$1$($props_75080_shape$jscomp$950$$))},
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($props_75080_shape$jscomp$950$$))})};
$app$main$ui$inspect$styles$panels$text$get_resolved_token$$=function($applied_tokens_in_shape$jscomp$6_property$jscomp$74$$,$shape$jscomp$951_shape_tokens$jscomp$13$$,$resolved_tokens$jscomp$18$$){$shape$jscomp$951_shape_tokens$jscomp$13$$=$APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$951_shape_tokens$jscomp$13$$);$applied_tokens_in_shape$jscomp$6_property$jscomp$74$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$951_shape_tokens$jscomp$13$$,
$applied_tokens_in_shape$jscomp$6_property$jscomp$74$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$18$$,$applied_tokens_in_shape$jscomp$6_property$jscomp$74$$)};
$app$main$ui$inspect$styles$panels$text$get_style_text$$=function($shape$jscomp$952$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__75093_text$jscomp$73$$){var $style$jscomp$65$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__75093_text$jscomp$73$$,0,null);$p__75093_text$jscomp$73$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__75093_text$jscomp$73$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$get_default_text_attrs$$(),$style$jscomp$65$$])),$p__75093_text$jscomp$73$$],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p__75097_text$jscomp$74$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__75097_text$jscomp$74$$,0,null);$p__75097_text$jscomp$74$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__75097_text$jscomp$74$$,
1,null);return $APP.$cuerdas$core$empty_QMARK_$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($p__75097_text$jscomp$74$$))},$APP.$app$common$types$text$content__GT_text_PLUS_styles$$($APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$952$$))))};
$app$main$ui$inspect$styles$panels$text$generate_typography_shorthand$$=function($shape$jscomp$953_shapes$jscomp$179_style_text_blocks$jscomp$1$$){$shape$jscomp$953_shapes$jscomp$179_style_text_blocks$jscomp$1$$=$APP.$cljs$core$first$$($shape$jscomp$953_shapes$jscomp$179_style_text_blocks$jscomp$1$$);$shape$jscomp$953_shapes$jscomp$179_style_text_blocks$jscomp$1$$=$app$main$ui$inspect$styles$panels$text$get_style_text$$($shape$jscomp$953_shapes$jscomp$179_style_text_blocks$jscomp$1$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$153$$,
$font_style$jscomp$12_p__75101$$){var $style$jscomp$66_text_transform$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font_style$jscomp$12_p__75101$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font_style$jscomp$12_p__75101$$,1,null);$font_style$jscomp$12_p__75101$$=$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$66_text_transform$jscomp$6$$);var $font_family$jscomp$9$$=""+($APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$66_text_transform$jscomp$6$$)??
""),$font_size$jscomp$10$$=$APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$66_text_transform$jscomp$6$$),$font_weight$jscomp$11$$=$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$66_text_transform$jscomp$6$$),$line_height$jscomp$18$$=$APP.$cljs$cst$1765$line_height$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$66_text_transform$jscomp$6$$);$style$jscomp$66_text_transform$jscomp$6$$=$APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$66_text_transform$jscomp$6$$);
return""+($acc$jscomp$153$$??"")+"font:"+($font_style$jscomp$12_p__75101$$??"")+" "+($style$jscomp$66_text_transform$jscomp$6$$??"")+" "+($font_weight$jscomp$11$$??"")+" "+($font_size$jscomp$10$$??"")+"/"+($line_height$jscomp$18$$??"")+' "'+($font_family$jscomp$9$$??"")+'";'},"",$shape$jscomp$953_shapes$jscomp$179_style_text_blocks$jscomp$1$$)};
$app$main$ui$inspect$styles$panels$text$typography_name_block_STAR_$$=function($props_75106_typography$jscomp$29$$){$props_75106_typography$jscomp$29$$=$app$main$ui$inspect$common$typography$get_typography$$($props_75106_typography$jscomp$29$$.style);var $property_value$jscomp$10$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($props_75106_typography$jscomp$29$$);return $APP.$cljs$core$truth_$$($props_75106_typography$jscomp$29$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,
{term:"Typography",detail:$property_value$jscomp$10$$,property:$property_value$jscomp$10$$,copiable:!0}):null};
$app$main$ui$inspect$styles$panels$text$typography_color_row_STAR_$$=function($color$jscomp$134_props_75107$$){var $color_space$jscomp$10$$=$color$jscomp$134_props_75107$$.colorSpace,$resolved_token$jscomp$8_resolved_tokens$jscomp$19$$=$color$jscomp$134_props_75107$$.resolvedTokens,$shape$jscomp$954$$=$color$jscomp$134_props_75107$$.shape;$color$jscomp$134_props_75107$$=$APP.$app$common$types$fills$fill__GT_color$$($color$jscomp$134_props_75107$$.fill);$resolved_token$jscomp$8_resolved_tokens$jscomp$19$$=
$app$main$ui$inspect$styles$panels$text$get_resolved_token$$($APP.$cljs$cst$1403$fill$$,$shape$jscomp$954$$,$resolved_token$jscomp$8_resolved_tokens$jscomp$19$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$color_properties_row$color_properties_row_STAR_$$,{term:"Font Color",color:$color$jscomp$134_props_75107$$,token:$resolved_token$jscomp$8_resolved_tokens$jscomp$19$$,format:$color_space$jscomp$10$$,copiable:!0})};
$app$main$ui$inspect$styles$panels$text$style_text_block_STAR_$$=function($copied$jscomp$6_props_75108$$){var $copy_text_text$jscomp$75$$=$copied$jscomp$6_props_75108$$.text,$color_space$jscomp$11$$=$copied$jscomp$6_props_75108$$.colorSpace,$resolved_tokens$jscomp$20$$=$copied$jscomp$6_props_75108$$.resolvedTokens,$style$jscomp$68$$=$copied$jscomp$6_props_75108$$.style,$shape$jscomp$955$$=$copied$jscomp$6_props_75108$$.shape,$copied_STAR_$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);
$copied$jscomp$6_props_75108$$=$APP.$cljs$core$_deref$$($copied_STAR_$jscomp$5$$);var $text__$1$jscomp$1$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($copy_text_text$jscomp$75$$);$copy_text_text$jscomp$75$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($copied$jscomp$6_props_75108$$)],function(){var $formatted_text$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$),
"uppercase")?$text__$1$jscomp$1$$.toUpperCase():$text__$1$jscomp$1$$;$APP.$cljs$core$reset_BANG_$$($copied_STAR_$jscomp$5$$,!0);$APP.$app$util$clipboard$to_clipboard$$($formatted_text$$);return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(1E3,function(){return $APP.$cljs$core$reset_BANG_$$($copied_STAR_$jscomp$5$$,!1)})});var $composite_typography_token$$=$app$main$ui$inspect$styles$panels$text$get_resolved_token$$($APP.$cljs$cst$1981$typography$$,$shape$jscomp$955$$,$resolved_tokens$jscomp$20$$);
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_styles_panels_text__text-properties",children:[$APP.$cljs$core$truth_$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$))?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$95$$,$fill$jscomp$27_p__75109$$){var $idx$jscomp$114$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill$jscomp$27_p__75109$$,0,null);$fill$jscomp$27_p__75109$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill$jscomp$27_p__75109$$,
1,null);$out_arr__44124__auto__$jscomp$95$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$text$typography_color_row_STAR_$$,{fill:$fill$jscomp$27_p__75109$$,shape:$shape$jscomp$955$$,resolvedTokens:$resolved_tokens$jscomp$20$$,colorSpace:$color_space$jscomp$11$$},$idx$jscomp$114$$));return $out_arr__44124__auto__$jscomp$95$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$))):
null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$659$$=$APP.$cljs$core$not$$($composite_typography_token$$);return $and__5023__auto__$jscomp$659$$?$APP.$cljs$cst$1756$typography_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$):$and__5023__auto__$jscomp$659$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$text$typography_name_block_STAR_$$,{style:$style$jscomp$68$$}):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$660$$=$APP.$cljs$core$not$$($APP.$cljs$cst$1756$typography_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$));
return $and__5023__auto__$jscomp$660$$?$composite_typography_token$$:$and__5023__auto__$jscomp$660$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:"Typography",detail:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($composite_typography_token$$),token:$composite_typography_token$$,property:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($composite_typography_token$$),copiable:!0}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$))?
function(){var $name$jscomp$431$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$fonts$get_font_data$$($APP.$cljs$cst$1757$font_id$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$)),$APP.$cljs$cst$725$name$$),$resolved_token$jscomp$9$$=$app$main$ui$inspect$styles$panels$text$get_resolved_token$$($APP.$cljs$cst$1758$font_family$$,$shape$jscomp$955$$,$resolved_tokens$jscomp$20$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,
{term:"Font Family",detail:$name$jscomp$431$$,token:$resolved_token$jscomp$9$$,property:['font-family: "',$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$431$$),'";'].join(""),copiable:!0})}():null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:"Font Style",detail:$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$),
property:["font-style: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$)),";"].join(""),copiable:!0}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$))?function(){var $font_size$jscomp$11$$=$APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$)),
$resolved_token$jscomp$10$$=$app$main$ui$inspect$styles$panels$text$get_resolved_token$$($APP.$cljs$cst$1760$font_size$$,$shape$jscomp$955$$,$resolved_tokens$jscomp$20$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:"Font Size",detail:$font_size$jscomp$11$$,token:$resolved_token$jscomp$10$$,property:["font-size: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($font_size$jscomp$11$$),";"].join(""),copiable:!0})}():null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$))?
function(){var $resolved_token$jscomp$11$$=$app$main$ui$inspect$styles$panels$text$get_resolved_token$$($APP.$cljs$cst$1761$font_weight$$,$shape$jscomp$955$$,$resolved_tokens$jscomp$20$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:"Font Weight",detail:$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$),token:$resolved_token$jscomp$11$$,property:["font-weight: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$)),
";"].join(""),copiable:!0})}():null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1765$line_height$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$))?function(){var $line_height$jscomp$19$$=$APP.$cljs$cst$1765$line_height$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$),$resolved_token$jscomp$12$$=$app$main$ui$inspect$styles$panels$text$get_resolved_token$$($APP.$cljs$cst$1765$line_height$$,$shape$jscomp$955$$,$resolved_tokens$jscomp$20$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,
{term:"Line Height",detail:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($line_height$jscomp$19$$),token:$resolved_token$jscomp$12$$,property:["line-height: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($line_height$jscomp$19$$),";"].join(""),copiable:!0})}():null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1766$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$))?function(){var $letter_spacing$jscomp$6$$=$APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1766$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$)),
$resolved_token$jscomp$13$$=$app$main$ui$inspect$styles$panels$text$get_resolved_token$$($APP.$cljs$cst$1766$letter_spacing$$,$shape$jscomp$955$$,$resolved_tokens$jscomp$20$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:"Letter Spacing",detail:$letter_spacing$jscomp$6$$,token:$resolved_token$jscomp$13$$,property:["letter-spacing: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($letter_spacing$jscomp$6$$),";"].join(""),copiable:!0})}():
null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$))?function(){var $resolved_token$jscomp$14$$=$app$main$ui$inspect$styles$panels$text$get_resolved_token$$($APP.$cljs$cst$1768$text_decoration$$,$shape$jscomp$955$$,$resolved_tokens$jscomp$20$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:"Text Decoration",detail:$APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$),
token:$resolved_token$jscomp$14$$,property:["text-decoration: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$)),";"].join(""),copiable:!0})}():null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$))?function(){var $resolved_token$jscomp$15$$=$app$main$ui$inspect$styles$panels$text$get_resolved_token$$($APP.$cljs$cst$1979$text_case$$,$shape$jscomp$955$$,
$resolved_tokens$jscomp$20$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:"Text Transform",detail:$APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$),token:$resolved_token$jscomp$15$$,property:["text-transform: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$)),";"].join(""),copiable:!0})}():null,(0,$APP.$rumext$v2$jsx$$)("pre",
{role:"presentation",className:"main_ui_inspect_styles_panels_text__text-content-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$property_detail_copiable$property_detail_copiable_STAR_$$,{copied:$copied$jscomp$6_props_75108$$,onClick:$copy_text_text$jscomp$75$$,children:(0,$APP.$rumext$v2$jsx$$)("span",{style:{fontFamily:$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$),fontWeight:$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$),
textTransform:$APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$),letterSpacing:$APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1766$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$)),fontStyle:$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$68$$)},className:"main_ui_inspect_styles_panels_text__text-content",children:$text__$1$jscomp$1$$})})})]})};
$app$main$ui$inspect$styles$panels$text$text_panel_STAR_$$=function($props_75113$$){var $shapes$jscomp$180$$=$props_75113$$.shapes,$color_space$jscomp$12$$=$props_75113$$.colorSpace,$on_font_shorthand$$=$props_75113$$.onFontShorthand,$resolved_tokens$jscomp$21$$=$props_75113$$.resolvedTokens,$shorthand_STAR_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$main$ui$inspect$styles$panels$text$generate_typography_shorthand$$($shapes$jscomp$180$$)}),$shorthand$jscomp$8$$=
$APP.$cljs$core$_deref$$($shorthand_STAR_$jscomp$6$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shorthand$jscomp$8$$),$APP.$rumext$v2$adapt$$($on_font_shorthand$$),$APP.$rumext$v2$adapt$$($shapes$jscomp$180$$)],function(){$APP.$cljs$core$reset_BANG_$$($shorthand_STAR_$jscomp$6$$,$app$main$ui$inspect$styles$panels$text$generate_typography_shorthand$$($shapes$jscomp$180$$));var $G__75114$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5340$panel$$,
$APP.$cljs$cst$1588$text$$,$cljs$cst$827$property$$,$shorthand$jscomp$8$$],null);return $on_font_shorthand$$.$cljs$core$IFn$_invoke$arity$1$?$on_font_shorthand$$.$cljs$core$IFn$_invoke$arity$1$($G__75114$$):$on_font_shorthand$$($G__75114$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_text__text-panel",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$96$$,$shape$jscomp$956$$){$out_arr__44124__auto__$jscomp$96$$.push(function(){var $style_text_blocks$jscomp$2$$=
$app$main$ui$inspect$styles$panels$text$get_style_text$$($shape$jscomp$956$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_text__text-shape",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$13$$,$p__75115_text$jscomp$76$$){var $style$jscomp$69$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__75115_text$jscomp$76$$,0,null);$p__75115_text$jscomp$76$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__75115_text$jscomp$76$$,
1,null);$out_arr__44124__auto____$1$jscomp$13$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$text$style_text_block_STAR_$$,{shape:$shape$jscomp$956$$,style:$style$jscomp$69$$,text:$p__75115_text$jscomp$76$$,resolvedTokens:$resolved_tokens$jscomp$21$$,colorSpace:$color_space$jscomp$12$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$956$$)));return $out_arr__44124__auto____$1$jscomp$13$$},[],$style_text_blocks$jscomp$2$$)},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$956$$))}());
return $out_arr__44124__auto__$jscomp$96$$},[],$shapes$jscomp$180$$)})};
$app$main$ui$inspect$styles$panels$tokens_panel$tokens_panel_STAR_$$=function($props_75102$$){var $set_names$jscomp$10$$=$props_75102$$.setNames,$theme_paths$jscomp$1$$=$props_75102$$.themePaths;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_styles_panels_tokens_panel__tokens-panel",children:[$APP.$cljs$core$seq$$($theme_paths$jscomp$1$$)?function(){var $theme_list$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$theme_paths$jscomp$1$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,
{className:"main_ui_inspect_styles_panels_tokens_panel__token-theme",term:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.tabs.styles.active-themes"),detail:$theme_list$$})}():null,$APP.$cljs$core$seq$$($set_names$jscomp$10$$)?function(){var $sets_list$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$set_names$jscomp$10$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{className:"main_ui_inspect_styles_panels_tokens_panel__token-sets",
term:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.tabs.styles.active-sets"),detail:$sets_list$$})}():null]})};
$app$main$ui$inspect$styles$panels$variants_panel$variants_panel_STAR_$$=function($properties$jscomp$105_props_75121$$){var $data$jscomp$453$$=$properties$jscomp$105_props_75121$$.data,$objects$jscomp$740$$=$properties$jscomp$105_props_75121$$.objects,$component$jscomp$119$$=$properties$jscomp$105_props_75121$$.component,$shape$jscomp$957$$=$properties$jscomp$105_props_75121$$.shape,$is_container_QMARK_$jscomp$1$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$957$$);
$properties$jscomp$105_props_75121$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$740$$),$APP.$rumext$v2$adapt$$($shape$jscomp$957$$)],function(){return $APP.$cljs$core$truth_$$($is_container_QMARK_$jscomp$1$$)?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75119_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__75119_SHARP_$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cuerdas$core$join$$,
", "))},$APP.$app$common$files$variant$extract_properties_values$$($data$jscomp$453$$,$objects$jscomp$740$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$957$$))):$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75120_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__75120_SHARP_$$,$APP.$cljs$cst$260$value$$,function($v$jscomp$631$$){return $APP.$cuerdas$core$blank_QMARK_$$($v$jscomp$631$$)?"--":$v$jscomp$631$$})},$APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$119$$))});
return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_variants_panel__variants-panel",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$97$$,$property$jscomp$75$$){$out_arr__44124__auto__$jscomp$97$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($property$jscomp$75$$),detail:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($property$jscomp$75$$)},
"variant-property-"+($property$jscomp$75$$??"")));return $out_arr__44124__auto__$jscomp$97$$},[],$properties$jscomp$105_props_75121$$)})};
$app$main$ui$inspect$styles$panels$visibility$visibility_panel_STAR_$$=function($props_75123$$){var $objects$jscomp$741$$=$props_75123$$.objects,$resolved_tokens$jscomp$23$$=$props_75123$$.resolvedTokens;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_panels_visibility__visibility-panel",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$98$$,$shape$jscomp$959$$){$out_arr__44124__auto__$jscomp$98$$.push((0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_inspect_styles_panels_visibility__visibility-shape",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto____$1$jscomp$14$$,$JSCompiler_inline_result$jscomp$1454_property$jscomp$78$$){var $JSCompiler_temp_const$jscomp$1452$$=$out_arr__44124__auto____$1$jscomp$14$$.push;var $temp__5825__auto__$jscomp$inline_7966$$=$app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$741$$,$shape$jscomp$959$$,
$JSCompiler_inline_result$jscomp$1454_property$jscomp$78$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_7966$$)){var $property_name$jscomp$inline_7967$$=$app$main$ui$inspect$attributes$common$get_css_rule_humanized$$($JSCompiler_inline_result$jscomp$1454_property$jscomp$78$$);var $applied_tokens_in_shape$jscomp$inline_13121_resolved_token$jscomp$inline_7968_shape_tokens$jscomp$inline_13120$$=$APP.$cljs$cst$1873$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$959$$);
$applied_tokens_in_shape$jscomp$inline_13121_resolved_token$jscomp$inline_7968_shape_tokens$jscomp$inline_13120$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens_in_shape$jscomp$inline_13121_resolved_token$jscomp$inline_7968_shape_tokens$jscomp$inline_13120$$,$JSCompiler_inline_result$jscomp$1454_property$jscomp$78$$);$applied_tokens_in_shape$jscomp$inline_13121_resolved_token$jscomp$inline_7968_shape_tokens$jscomp$inline_13120$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$23$$,
$applied_tokens_in_shape$jscomp$inline_13121_resolved_token$jscomp$inline_7968_shape_tokens$jscomp$inline_13120$$);var $property_value$jscomp$inline_7969$$=$APP.$cljs$core$not$$($applied_tokens_in_shape$jscomp$inline_13121_resolved_token$jscomp$inline_7968_shape_tokens$jscomp$inline_13120$$)?$app$util$code_gen$style_css$get_css_property$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$741$$,$shape$jscomp$959$$,$JSCompiler_inline_result$jscomp$1454_property$jscomp$78$$):"";$JSCompiler_inline_result$jscomp$1454_property$jscomp$78$$=
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$rows$properties_row$properties_row_STAR_$$,{term:$property_name$jscomp$inline_7967$$,detail:""+($temp__5825__auto__$jscomp$inline_7966$$??""),token:$applied_tokens_in_shape$jscomp$inline_13121_resolved_token$jscomp$inline_7968_shape_tokens$jscomp$inline_13120$$,property:$property_value$jscomp$inline_7969$$,copiable:!0},"visibility-property-"+($JSCompiler_inline_result$jscomp$1454_property$jscomp$78$$??""))}else $JSCompiler_inline_result$jscomp$1454_property$jscomp$78$$=
null;$JSCompiler_temp_const$jscomp$1452$$.call($out_arr__44124__auto____$1$jscomp$14$$,$JSCompiler_inline_result$jscomp$1454_property$jscomp$78$$);return $out_arr__44124__auto____$1$jscomp$14$$},[],$app$main$ui$inspect$styles$panels$visibility$properties$$)},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$959$$)));return $out_arr__44124__auto__$jscomp$98$$},[],$props_75123$$.shapes)})};
$app$main$ui$inspect$styles$style_box$panel__GT_title$$=function($type$jscomp$601$$){switch($type$jscomp$601$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$601$$.$fqn$:null){case "variant":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.tabs.styles.variants-panel");case "token":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.tabs.styles.token-panel");case "geometry":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.size");
case "fill":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.fill");case "stroke":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.stroke");case "text":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.text");case "blur":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.blur");case "shadow":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.shadow");case "layout":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.layout");
case "flex-element":return"Flex Element";case "grid-element":return"Grid Element";case "layout-element":return"Layout Element";case "visibility":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.visibility");case "svg":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.svg");default:return null}};
$app$main$ui$inspect$styles$style_box$style_box_STAR_$$=function($panel_props_75124$$){var $shorthand$jscomp$9$$=$panel_props_75124$$.shorthand,$children$jscomp$287$$=$panel_props_75124$$.children;$panel_props_75124$$=$panel_props_75124$$.panel;var $expanded_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),$expanded$jscomp$6$$=$APP.$cljs$core$_deref$$($expanded_STAR_$$),$title$jscomp$26$$=$app$main$ui$inspect$styles$style_box$panel__GT_title$$($panel_props_75124$$),$toggle_panel$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($expanded$jscomp$6$$)],function(){return $APP.$cljs$core$reset_BANG_$$($expanded_STAR_$$,$APP.$cljs$core$not$$($expanded$jscomp$6$$))}),$copy_shorthand$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shorthand$jscomp$9$$)],function(){return $APP.$app$util$clipboard$to_clipboard$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shorthand$jscomp$9$$))});return(0,$APP.$rumext$v2$jsxs$$)("article",
{className:"main_ui_inspect_styles_style_box__style-box",children:[(0,$APP.$rumext$v2$jsxs$$)("header",{className:"main_ui_inspect_styles_style_box__disclosure-header",children:[(0,$APP.$rumext$v2$jsx$$)("button",{"aria-expanded":$expanded$jscomp$6$$,"aria-controls":["style-box-",$APP.$app$common$data$name$$($panel_props_75124$$)].join(""),onClick:$toggle_panel$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("inspect.tabs.styles.toggle-style",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$title$jscomp$26$$])),
className:"main_ui_inspect_styles_style_box__disclosure-button",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$APP.$cljs$core$truth_$$($expanded$jscomp$6$$)?"arrow-down":"arrow",className:"main_ui_inspect_styles_style_box__disclosure-icon",size:"s"})}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_inspect_styles_style_box__panel-title",children:$title$jscomp$26$$}),$APP.$cljs$core$truth_$$($shorthand$jscomp$9$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost",tooltipPlacement:"top-left","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.tabs.styles.copy-shorthand"),onClick:$copy_shorthand$$,icon:"clipboard"}):null]}),$APP.$cljs$core$truth_$$($expanded$jscomp$6$$)?(0,$APP.$rumext$v2$jsx$$)("div",{id:["style-box-",$APP.$app$common$data$name$$($panel_props_75124$$)].join(""),className:"main_ui_inspect_styles_style_box__style-box-content",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles_style_box__style-box-panel-wrapper",
children:$children$jscomp$287$$})}):null]})};$app$main$ui$inspect$styles$has_fill_QMARK_$$=function($shape$jscomp$960$$){return!$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1608$group$$,null,$APP.$cljs$cst$1588$text$$,null],null),null),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$960$$))&&$APP.$cljs$core$seq$$($APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$960$$))};
$app$main$ui$inspect$styles$has_stroke_QMARK_$$=function($shape$jscomp$961$$){return $APP.$cljs$core$seq$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$961$$))};$app$main$ui$inspect$styles$has_blur_QMARK_$$=function($shape$jscomp$962$$){return $APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$962$$)};$app$main$ui$inspect$styles$has_text_QMARK_$$=function($shape$jscomp$963$$){return $APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$963$$)};
$app$main$ui$inspect$styles$has_shadow_QMARK_$$=function($shape$jscomp$964$$){return $APP.$cljs$core$seq$$($APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$964$$))};
$app$main$ui$inspect$styles$get_shape_type$$=function($or__5025__auto__$jscomp$inline_7971_shapes$jscomp$182$$,$JSCompiler_temp$jscomp$1455_first_shape$jscomp$8$$,$JSCompiler_inline_result$jscomp$1456_first_component$jscomp$1$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($or__5025__auto__$jscomp$inline_7971_shapes$jscomp$182$$),1)?($or__5025__auto__$jscomp$inline_7971_shapes$jscomp$182$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($JSCompiler_temp$jscomp$1455_first_shape$jscomp$8$$),
$JSCompiler_inline_result$jscomp$1456_first_component$jscomp$1$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_7971_shapes$jscomp$182$$)?$or__5025__auto__$jscomp$inline_7971_shapes$jscomp$182$$:$APP.$app$common$types$component$is_variant_QMARK_$$($JSCompiler_inline_result$jscomp$1456_first_component$jscomp$1$$),$JSCompiler_temp$jscomp$1455_first_shape$jscomp$8$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1456_first_component$jscomp$1$$)?$APP.$cljs$cst$1994$variant$$:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1455_first_shape$jscomp$8$$)):
$JSCompiler_temp$jscomp$1455_first_shape$jscomp$8$$=$APP.$cljs$cst$1616$multiple$$;return $JSCompiler_temp$jscomp$1455_first_shape$jscomp$8$$};
$app$main$ui$inspect$styles$styles_tab_STAR_$$=function($panels_props_75130_shape_type$jscomp$6$$){var $shapes$jscomp$183$$=$panels_props_75130_shape_type$jscomp$6$$.shapes,$color_space$jscomp$13$$=$panels_props_75130_shape_type$jscomp$6$$.colorSpace,$file_id$jscomp$357$$=$panels_props_75130_shape_type$jscomp$6$$.fileId,$objects$jscomp$742$$=$panels_props_75130_shape_type$jscomp$6$$.objects,$page_id$jscomp$413$$=$panels_props_75130_shape_type$jscomp$6$$.pageId,$from$jscomp$27$$=$panels_props_75130_shape_type$jscomp$6$$.from,
$share_id$jscomp$24$$=$panels_props_75130_shape_type$jscomp$6$$.shareId,$data$jscomp$454$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($panels_props_75130_shape_type$jscomp$6$$.libraries,$file_id$jscomp$357$$),$APP.$cljs$cst$142$data$$),$first_shape$jscomp$9$$=$APP.$cljs$core$first$$($shapes$jscomp$183$$),$first_component$jscomp$2$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$454$$,
$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$9$$));$panels_props_75130_shape_type$jscomp$6$$=$app$main$ui$inspect$styles$get_shape_type$$($shapes$jscomp$183$$,$first_shape$jscomp$9$$,$first_component$jscomp$2$$);$panels_props_75130_shape_type$jscomp$6$$=$app$main$ui$inspect$styles$type__GT_panel_group$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$ui$inspect$styles$type__GT_panel_group$$.$cljs$core$IFn$_invoke$arity$1$($panels_props_75130_shape_type$jscomp$6$$):
$app$main$ui$inspect$styles$type__GT_panel_group$$($panels_props_75130_shape_type$jscomp$6$$);var $tokens_lib$jscomp$34$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$tokens_lib$$),$active_themes$jscomp$8$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_active_theme_paths_no_hidden$$),$active_sets$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$34$$)],function(){return $tokens_lib$jscomp$34$$==null?null:$APP.$app$common$types$tokens_lib$get_active_themes_set_names$$($tokens_lib$jscomp$34$$)}),
$active_tokens$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$34$$)],function(){return $tokens_lib$jscomp$34$$==null?null:$APP.$app$common$types$tokens_lib$get_tokens_in_active_sets$$($tokens_lib$jscomp$34$$)}),$resolved_active_tokens$$=$APP.$app$main$data$style_dictionary$use_resolved_tokens_STAR_$$($active_tokens$jscomp$3$$),$has_visibility_props_QMARK_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($shape$jscomp$965$$){var $and__5023__auto__$jscomp$661_or__5025__auto__$jscomp$1008_or__5025__auto____$1$jscomp$112_shape_type__$1$$=
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$965$$);if($and__5023__auto__$jscomp$661_or__5025__auto__$jscomp$1008_or__5025__auto____$1$jscomp$112_shape_type__$1$$=!($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$661_or__5025__auto__$jscomp$1008_or__5025__auto____$1$jscomp$112_shape_type__$1$$,$APP.$cljs$cst$1588$text$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$661_or__5025__auto__$jscomp$1008_or__5025__auto____$1$jscomp$112_shape_type__$1$$,
$APP.$cljs$cst$1608$group$$))){$and__5023__auto__$jscomp$661_or__5025__auto__$jscomp$1008_or__5025__auto____$1$jscomp$112_shape_type__$1$$=$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$965$$);if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$661_or__5025__auto__$jscomp$1008_or__5025__auto____$1$jscomp$112_shape_type__$1$$))return $and__5023__auto__$jscomp$661_or__5025__auto__$jscomp$1008_or__5025__auto____$1$jscomp$112_shape_type__$1$$;$and__5023__auto__$jscomp$661_or__5025__auto__$jscomp$1008_or__5025__auto____$1$jscomp$112_shape_type__$1$$=
$APP.$cljs$cst$1867$blend_mode$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$965$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$661_or__5025__auto__$jscomp$1008_or__5025__auto____$1$jscomp$112_shape_type__$1$$)?$and__5023__auto__$jscomp$661_or__5025__auto__$jscomp$1008_or__5025__auto____$1$jscomp$112_shape_type__$1$$:$cljs$cst$2933$visibility$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$965$$)}return $and__5023__auto__$jscomp$661_or__5025__auto__$jscomp$1008_or__5025__auto____$1$jscomp$112_shape_type__$1$$}),
$shorthands_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$1994$variant$$,$APP.$cljs$cst$1615$layout$$,$APP.$cljs$cst$1403$fill$$,$cljs$cst$5342$grid_element$$,$cljs$cst$5330$geometry$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1538$svg$$,$APP.$cljs$cst$1654$shadow$$,$cljs$cst$5329$layout_element$$,$cljs$cst$2933$visibility$$,$APP.$cljs$cst$1588$text$$],[null,null,
null,null,null,null,null,null,null,null,null,null])}),$shorthands$$=$APP.$cljs$core$_deref$$($shorthands_STAR_$$),$set_shorthands$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shorthands_STAR_$$)],function($shorthand$jscomp$10$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($shorthands_STAR_$$,$APP.$cljs$core$assoc$$,$cljs$cst$5340$panel$$.$cljs$core$IFn$_invoke$arity$1$($shorthand$jscomp$10$$),$cljs$cst$827$property$$.$cljs$core$IFn$_invoke$arity$1$($shorthand$jscomp$10$$))});
return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.styles"),className:"main_ui_inspect_styles__styles-tab "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from$jscomp$27$$,$APP.$cljs$cst$2532$workspace$$)?"main_ui_inspect_styles__styles-tab-workspace":""),children:[(0,$APP.$rumext$v2$jsxs$$)("ol",{children:[$APP.$cljs$core$seq$$($active_themes$jscomp$8$$)||$APP.$cljs$core$seq$$($active_sets$$)?(0,$APP.$rumext$v2$jsx$$)("li",
{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$style_box$style_box_STAR_$$,{panel:$APP.$cljs$cst$1136$token$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$tokens_panel$tokens_panel_STAR_$$,{themePaths:$active_themes$jscomp$8$$,setNames:$active_sets$$})})}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$99$$,$panel$jscomp$1$$){$out_arr__44124__auto__$jscomp$99$$.push((0,$APP.$rumext$v2$jsx$$)("li",{children:function(){switch($panel$jscomp$1$$ instanceof
$APP.$cljs$core$Keyword$$?$panel$jscomp$1$$.$fqn$:null){case "variant":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$style_box$style_box_STAR_$$,{panel:$APP.$cljs$cst$1994$variant$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$variants_panel$variants_panel_STAR_$$,{component:$first_component$jscomp$2$$,objects:$objects$jscomp$742$$,shape:$first_shape$jscomp$9$$,data:$data$jscomp$454$$})});case "geometry":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$style_box$style_box_STAR_$$,
{panel:$cljs$cst$5330$geometry$$,shorthand:$cljs$cst$5330$geometry$$.$cljs$core$IFn$_invoke$arity$1$($shorthands$$),children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$geometry$geometry_panel_STAR_$$,{shapes:$shapes$jscomp$183$$,objects:$objects$jscomp$742$$,resolvedTokens:$resolved_active_tokens$$,onGeometryShorthand:$set_shorthands$$})});case "layout":var $layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$layout$any_layout_QMARK_$$,
$shapes$jscomp$183$$);return $APP.$cljs$core$seq$$($layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$style_box$style_box_STAR_$$,{panel:$APP.$cljs$cst$1615$layout$$,shorthand:$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($shorthands$$),children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$layout$layout_panel_STAR_$$,{shapes:$layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$,objects:$objects$jscomp$742$$,
resolvedTokens:$resolved_active_tokens$$,onLayoutShorthand:$set_shorthands$$})}):null;case "layout-element":$layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75126_SHARP_$$){return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$742$$,$p1__75126_SHARP_$$)},$shapes$jscomp$183$$);if($APP.$cljs$core$seq$$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($shape$jscomp$967$$){return $APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__75127_SHARP_$$){return $app$util$code_gen$style_css$get_css_value$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$742$$,
$shape$jscomp$967$$,$p1__75127_SHARP_$$)},$app$main$ui$inspect$styles$layout_element_properties$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$])))){var $only_flex_QMARK_$jscomp$1$$=$APP.$cljs$core$every_QMARK_$$(function($p1__75128_SHARP_$$){return $APP.$app$common$types$shape$layout$flex_layout_immediate_child_QMARK_$$($objects$jscomp$742$$,$p1__75128_SHARP_$$)},$layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$),$only_grid_QMARK_$jscomp$1$$=
$APP.$cljs$core$every_QMARK_$$(function($p1__75129_SHARP_$$){return $APP.$app$common$types$shape$layout$grid_layout_immediate_child_QMARK_$$($objects$jscomp$742$$,$p1__75129_SHARP_$$)},$layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$style_box$style_box_STAR_$$,{panel:$only_flex_QMARK_$jscomp$1$$?$cljs$cst$5343$flex_element$$:$only_grid_QMARK_$jscomp$1$$?$cljs$cst$5342$grid_element$$:$cljs$cst$5329$layout_element$$,shorthand:$cljs$cst$5329$layout_element$$.$cljs$core$IFn$_invoke$arity$1$($shorthands$$),
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$layout_element$layout_element_panel_STAR_$$,{shapes:$layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$,objects:$objects$jscomp$742$$,resolvedTokens:$resolved_active_tokens$$,layoutElementProperties:$app$main$ui$inspect$styles$layout_element_properties$$,onLayoutElementShorthand:$set_shorthands$$})})}return null;case "fill":return $layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$styles$has_fill_QMARK_$$,
$shapes$jscomp$183$$),$APP.$cljs$core$seq$$($layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$style_box$style_box_STAR_$$,{panel:$APP.$cljs$cst$1403$fill$$,shorthand:$APP.$cljs$cst$1403$fill$$.$cljs$core$IFn$_invoke$arity$1$($shorthands$$),children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$fill$fill_panel_STAR_$$,{colorSpace:$color_space$jscomp$13$$,shapes:$layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$,resolvedTokens:$resolved_active_tokens$$,
onFillShorthand:$set_shorthands$$})}):null;case "stroke":return $layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$styles$has_stroke_QMARK_$$,$shapes$jscomp$183$$),$APP.$cljs$core$seq$$($layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$style_box$style_box_STAR_$$,{panel:$APP.$cljs$cst$2903$stroke$$,shorthand:$APP.$cljs$cst$2903$stroke$$.$cljs$core$IFn$_invoke$arity$1$($shorthands$$),
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$stroke$stroke_panel_STAR_$$,{colorSpace:$color_space$jscomp$13$$,shapes:$layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$,objects:$objects$jscomp$742$$,resolvedTokens:$resolved_active_tokens$$,onStrokeShorthand:$set_shorthands$$})}):null;case "visibility":return $layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($has_visibility_props_QMARK_$$,$shapes$jscomp$183$$),
$APP.$cljs$core$seq$$($layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$style_box$style_box_STAR_$$,{panel:$cljs$cst$2933$visibility$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$visibility$visibility_panel_STAR_$$,{shapes:$layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$,objects:$objects$jscomp$742$$,resolvedTokens:$resolved_active_tokens$$})}):null;case "svg":return $layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$=
$APP.$cljs$core$first$$($shapes$jscomp$183$$),$APP.$cljs$core$seq$$($APP.$cljs$cst$1890$svg_attrs$$.$cljs$core$IFn$_invoke$arity$1$($layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$style_box$style_box_STAR_$$,{panel:$APP.$cljs$cst$1538$svg$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$svg$svg_panel_STAR_$$,{shape:$layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$,objects:$objects$jscomp$742$$})}):null;case "blur":return $layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$=
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$styles$has_blur_QMARK_$$,$shapes$jscomp$183$$),$APP.$cljs$core$seq$$($layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$style_box$style_box_STAR_$$,{panel:$APP.$cljs$cst$1653$blur$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$blur$blur_panel_STAR_$$,{shapes:$layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$,objects:$objects$jscomp$742$$})}):
null;case "text":return $layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$styles$has_text_QMARK_$$,$shapes$jscomp$183$$),$APP.$cljs$core$seq$$($layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$style_box$style_box_STAR_$$,{panel:$APP.$cljs$cst$1588$text$$,shorthand:$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($shorthands$$),children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$text$text_panel_STAR_$$,
{shapes:$layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$,colorSpace:$color_space$jscomp$13$$,resolvedTokens:$resolved_active_tokens$$,onFontShorthand:$set_shorthands$$})}):null;case "shadow":return $layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$inspect$styles$has_shadow_QMARK_$$,$shapes$jscomp$183$$),$APP.$cljs$core$seq$$($layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$style_box$style_box_STAR_$$,
{panel:$APP.$cljs$cst$1654$shadow$$,shorthand:$APP.$cljs$cst$1654$shadow$$.$cljs$core$IFn$_invoke$arity$1$($shorthands$$),children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$panels$shadow$shadow_panel_STAR_$$,{shapes:$layout_shapes_shape$jscomp$966_shapes__$1$jscomp$30$$,resolvedTokens:$resolved_active_tokens$$,colorSpace:$color_space$jscomp$13$$,onShadowShorthand:$set_shorthands$$})}):null;default:return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$style_box$style_box_STAR_$$,
{panel:$panel$jscomp$1$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{children:$color_space$jscomp$13$$})})}}()},$APP.$app$common$data$name$$($panel$jscomp$1$$)));return $out_arr__44124__auto__$jscomp$99$$},[],$panels_props_75130_shape_type$jscomp$6$$)]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_styles__exports-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$exports$exports$$,{shapes:$shapes$jscomp$183$$,type:$APP.$cljs$core$type$$,"page-id":$page_id$jscomp$413$$,
"file-id":$file_id$jscomp$357$$,"share-id":$share_id$jscomp$24$$})})]})};
$app$main$ui$inspect$right_sidebar$get_libraries$$=function($from$jscomp$28_local$jscomp$26$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from$jscomp$28_local$jscomp$26$$,$APP.$cljs$cst$2532$workspace$$))return $APP.$cljs$core$_deref$$($APP.$app$main$refs$libraries$$);var $libraries$jscomp$133_viewer_data$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$viewer_data$$);$from$jscomp$28_local$jscomp$26$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$133_viewer_data$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$142$data$$],null));var $id$jscomp$914$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($from$jscomp$28_local$jscomp$26$$,$APP.$cljs$cst$266$id$$);$libraries$jscomp$133_viewer_data$$=$APP.$cljs$cst$5244$libraries$$.$cljs$core$IFn$_invoke$arity$1$($libraries$jscomp$133_viewer_data$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($libraries$jscomp$133_viewer_data$$,$id$jscomp$914$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$266$id$$,$id$jscomp$914$$,$APP.$cljs$cst$142$data$$,$from$jscomp$28_local$jscomp$26$$],null))};
$APP.$app$main$ui$inspect$right_sidebar$right_sidebar_STAR_$$=function($props_75136_subtitle$$){var $on_expand$jscomp$1$$=$props_75136_subtitle$$.onExpand,$navigate_to_help_shapes$jscomp$184$$=$props_75136_subtitle$$.shapes,$on_change_section$$=$props_75136_subtitle$$.onChangeSection,$handle_change_color_space_selected$jscomp$136$$=$props_75136_subtitle$$.selected,$frame$jscomp$55$$=$props_75136_subtitle$$.frame,$color_spaces_file_id$jscomp$358$$=$props_75136_subtitle$$.fileId,$objects$jscomp$743_tabs$jscomp$2$$=
$props_75136_subtitle$$.objects,$file$jscomp$152$$=$props_75136_subtitle$$.file,$page$jscomp$153$$=$props_75136_subtitle$$.page,$page_id$jscomp$414$$=$props_75136_subtitle$$.pageId,$from$jscomp$29$$=$props_75136_subtitle$$.from??$APP.$cljs$cst$1592$viewer$$,$share_id$jscomp$25$$=$props_75136_subtitle$$.shareId,$color_space_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("hex"),$color_space$jscomp$14$$=$APP.$cljs$core$_deref$$($color_space_STAR_$$),$section$jscomp$19$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$cljs$cst$1220$inspect_styles$$)?$APP.$cljs$cst$2940$styles$$:$APP.$cljs$cst$1161$info$$}),$objects__$1$jscomp$33$$=$APP.$cljs$core$truth_$$($objects$jscomp$743_tabs$jscomp$2$$)?$objects$jscomp$743_tabs$jscomp$2$$:$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$153$$),$shapes__$1$jscomp$31$$=$APP.$cljs$core$truth_$$($navigate_to_help_shapes$jscomp$184$$)?$navigate_to_help_shapes$jscomp$184$$:$APP.$app$main$ui$inspect$selection_feedback$resolve_shapes$$($objects__$1$jscomp$33$$,
$handle_change_color_space_selected$jscomp$136$$),$first_shape$jscomp$10$$=$APP.$cljs$core$first$$($shapes__$1$jscomp$31$$),$page_id__$1$jscomp$23$$=$APP.$cljs$core$truth_$$($page_id$jscomp$414$$)?$page_id$jscomp$414$$:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$153$$),$file_id__$1$jscomp$9$$=$APP.$cljs$core$truth_$$($color_spaces_file_id$jscomp$358$$)?$color_spaces_file_id$jscomp$358$$:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$152$$),$libraries$jscomp$134$$=
$app$main$ui$inspect$right_sidebar$get_libraries$$($from$jscomp$29$$),$main_instance_QMARK_$jscomp$2$$=$APP.$app$common$types$component$main_instance_QMARK_$$($first_shape$jscomp$10$$);$props_75136_subtitle$$=$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1013$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($first_shape$jscomp$10$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1013$$)?$or__5025__auto__$jscomp$1013$$:!$APP.$app$common$types$component$is_variant_QMARK_$$($first_shape$jscomp$10$$)&&
$main_instance_QMARK_$jscomp$2$$}())?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.subtitle.main"):$APP.$app$common$types$component$is_variant_QMARK_$$($first_shape$jscomp$10$$)&&$main_instance_QMARK_$jscomp$2$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.variant"):$APP.$app$common$types$component$instance_head_QMARK_$$($first_shape$jscomp$10$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.subtitle.copy"):null;var $handle_change_tab$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($from$jscomp$29$$),$APP.$rumext$v2$adapt$$($on_change_section$$)],function($new_section$$){$APP.$cljs$core$reset_BANG_$$($section$jscomp$19$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($new_section$$));if($APP.$cljs$core$truth_$$($on_change_section$$)){var $G__75137_75142$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($new_section$$);$on_change_section$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change_section$$.$cljs$core$IFn$_invoke$arity$1$($G__75137_75142$$):$on_change_section$$($G__75137_75142$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"change-inspect-tab",$APP.$cljs$cst$5344$tab$$,$new_section$$],null)))}return null}),$handle_expand$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_expand$jscomp$1$$)],
function(){return $APP.$cljs$core$truth_$$($on_expand$jscomp$1$$)?$on_expand$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$on_expand$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_expand$jscomp$1$$():null});$navigate_to_help_shapes$jscomp$184$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://help.penpot.app/user-guide/inspect/")});$handle_change_color_space_selected$jscomp$136$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($color_space__$1$$){return $APP.$cljs$core$reset_BANG_$$($color_space_STAR_$$,
$color_space__$1$$)});$color_spaces_file_id$jscomp$358$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.color.hex"),$APP.$cljs$cst$266$id$$,"hex"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.color.rgba"),$APP.$cljs$cst$266$id$$,"rgba"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.color.hsla"),$APP.$cljs$cst$266$id$$,"hsla"],null)],null)});$objects$jscomp$743_tabs$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$cljs$cst$1220$inspect_styles$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.styles"),$APP.$cljs$cst$266$id$$,"styles"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.computed"),$APP.$cljs$cst$266$id$$,"computed"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.code"),$cljs$cst$4555$data_testid$$,"code",$APP.$cljs$cst$266$id$$,"code"],null)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.info"),$APP.$cljs$cst$266$id$$,
"info"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.code"),$cljs$cst$4555$data_testid$$,"code",$APP.$cljs$cst$266$id$$,"code"],null)],null)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes__$1$jscomp$31$$),$APP.$rumext$v2$adapt$$($handle_change_tab$$)],function(){if($APP.$cljs$core$seq$$($shapes__$1$jscomp$31$$))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"inspect-mode-click-element"],null)));var $G__75138$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1220$inspect_styles$$)?$APP.$cljs$cst$2940$styles$$:$APP.$cljs$cst$1161$info$$;return $handle_change_tab$$.$cljs$core$IFn$_invoke$arity$1$?$handle_change_tab$$.$cljs$core$IFn$_invoke$arity$1$($G__75138$$):$handle_change_tab$$($G__75138$$)});return(0,$APP.$rumext$v2$jsx$$)("aside",{className:"main_ui_inspect_right_sidebar__settings-bar-right "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from$jscomp$29$$,$APP.$cljs$cst$1592$viewer$$)?"main_ui_inspect_right_sidebar__viewer-code":""),children:$APP.$cljs$core$seq$$($shapes__$1$jscomp$31$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_right_sidebar__tool-windows",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_right_sidebar__shape-info "+($props_75136_subtitle$$!=null?"main_ui_inspect_right_sidebar__shape-info-subtitle":""),children:$APP.$cljs$core$count$$($shapes__$1$jscomp$31$$)>
1?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_right_sidebar__layers-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"layers",size:"s"})}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_inspect_right_sidebar__layer-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("inspect.multiple-selected",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$count$$($shapes__$1$jscomp$31$$)]))})]}):
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_right_sidebar__shape-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$APP.$app$util$shape_icon$get_shape_icon$$($first_shape$jscomp$10$$),size:"s"})}),(0,$APP.$rumext$v2$jsx$$)("div",{children:$props_75136_subtitle$$!=null?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_right_sidebar__layer-title main_ui_inspect_right_sidebar__layer-title-with-subtitle",
children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$10$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_right_sidebar__layer-subtitle",children:$props_75136_subtitle$$})]}):(0,$APP.$rumext$v2$jsx$$)("div",{children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_right_sidebar__layer-title",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$10$$)})})})]})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_right_sidebar__inspect-content",
children:[$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1220$inspect_styles$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_right_sidebar__inspect-tab-switcher",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_inspect_right_sidebar__inspect-tab-switcher-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.layer-info")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_right_sidebar__inspect-tab-switcher-controls",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_right_sidebar__inspect-tab-switcher-controls-color-space",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$select$select_STAR_$$,{className:"main_ui_inspect_right_sidebar__inspect-tab-switcher-controls-color-space-select","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.color-space-label"),options:$color_spaces_file_id$jscomp$358$$,defaultSelected:"hex",variant:"ghost",onChange:$handle_change_color_space_selected$jscomp$136$$})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_right_sidebar__inspect-tab-switcher-controls-tab",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$select$select_STAR_$$,{options:$objects$jscomp$743_tabs$jscomp$2$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.tabs-switcher-label"),defaultSelected:$APP.$cljs$core$name$$($APP.$cljs$core$_deref$$($section$jscomp$19$$)),onChange:$handle_change_tab$$})})]})]}):null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$cljs$cst$1220$inspect_styles$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_right_sidebar__inspect-tab main_ui_inspect_right_sidebar__viewer-tab-switcher main_ui_inspect_right_sidebar__viewer-tab-switcher-layout",children:function(){var $G__75139_G__75139__$1$$=$APP.$cljs$core$_deref$$($section$jscomp$19$$);$G__75139_G__75139__$1$$=$G__75139_G__75139__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__75139_G__75139__$1$$.$fqn$:null;switch($G__75139_G__75139__$1$$){case "styles":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$styles$styles_tab_STAR_$$,
{colorSpace:$color_space$jscomp$14$$,objects:$objects__$1$jscomp$33$$,shapes:$shapes__$1$jscomp$31$$,from:$from$jscomp$29$$,libraries:$libraries$jscomp$134$$,pageId:$page_id__$1$jscomp$23$$,fileId:$file_id__$1$jscomp$9$$,shareId:$share_id$jscomp$25$$});case "computed":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$attributes_STAR_$$,{pageId:$page_id__$1$jscomp$23$$,libraries:$libraries$jscomp$134$$,objects:$objects__$1$jscomp$33$$,shareId:$share_id$jscomp$25$$,shapes:$shapes__$1$jscomp$31$$,
colorSpace:$color_space$jscomp$14$$,from:$from$jscomp$29$$,frame:$frame$jscomp$55$$,fileId:$file_id__$1$jscomp$9$$});case "code":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$code$code_STAR_$$,{frame:$frame$jscomp$55$$,shapes:$shapes__$1$jscomp$31$$,onExpand:$handle_expand$$,from:$from$jscomp$29$$});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75139_G__75139__$1$$)].join(""));}}()}):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$layout$tab_switcher$tab_switcher_STAR_$$,
{tabs:$objects$jscomp$743_tabs$jscomp$2$$,selected:$APP.$cljs$core$name$$($APP.$cljs$core$_deref$$($section$jscomp$19$$)),onChange:$handle_change_tab$$,className:"main_ui_inspect_right_sidebar__viewer-tab-switcher",children:function(){var $G__75140_G__75140__$1$$=$APP.$cljs$core$_deref$$($section$jscomp$19$$);$G__75140_G__75140__$1$$=$G__75140_G__75140__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__75140_G__75140__$1$$.$fqn$:null;switch($G__75140_G__75140__$1$$){case "info":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$attributes_STAR_$$,
{pageId:$page_id__$1$jscomp$23$$,objects:$objects__$1$jscomp$33$$,fileId:$file_id__$1$jscomp$9$$,frame:$frame$jscomp$55$$,shapes:$shapes__$1$jscomp$31$$,from:$from$jscomp$29$$,libraries:$libraries$jscomp$134$$,shareId:$share_id$jscomp$25$$});case "code":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$code$code_STAR_$$,{frame:$frame$jscomp$55$$,shapes:$shapes__$1$jscomp$31$$,onExpand:$handle_expand$$,from:$from$jscomp$29$$});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75140_G__75140__$1$$)].join(""));
}}()})]})]}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_right_sidebar__empty",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"code",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.empty.select")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"help",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.empty.help")})]}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_right_sidebar__empty-button",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",onClick:$navigate_to_help_shapes$jscomp$184$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.empty.more")})})]})})};
$APP.$app$main$ui$ds$controls$switch$0$switch_STAR_$$=function($id$jscomp$915_props_75134$$,$props__$1$jscomp$62_ref$jscomp$47$$){var $aria_label$jscomp$7$$=void 0,$on_change$jscomp$30$$=void 0,$disabled$jscomp$11_has_label_QMARK_$$=void 0,$default_checked$$=void 0,$label$jscomp$37$$=void 0,$class$$jscomp$53$$=void 0,$props$jscomp$278$$=void 0;({className:$class$$jscomp$53$$,label:$label$jscomp$37$$,"aria-label":$aria_label$jscomp$7$$,defaultChecked:$default_checked$$,onChange:$on_change$jscomp$30$$,
disabled:$disabled$jscomp$11_has_label_QMARK_$$,...$props$jscomp$278$$}=$id$jscomp$915_props_75134$$);var $checked_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($default_checked$$),$checked_QMARK_$jscomp$5$$=$APP.$cljs$core$_deref$$($checked_STAR_$$);$id$jscomp$915_props_75134$$=(0,$APP.$rumext$v2$use_id$$)();var $disabled_QMARK_$jscomp$4$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($disabled$jscomp$11_has_label_QMARK_$$,!1);$disabled$jscomp$11_has_label_QMARK_$$=
!$APP.$cuerdas$core$blank_QMARK_$$($label$jscomp$37$$);var $handle_toggle$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$30$$),$APP.$rumext$v2$adapt$$($checked_QMARK_$jscomp$5$$),$APP.$rumext$v2$adapt$$($disabled_QMARK_$jscomp$4$$)],function(){if($APP.$cljs$core$truth_$$($disabled_QMARK_$jscomp$4$$))return null;var $updated_checked_QMARK_$$=$APP.$cljs$core$not$$($checked_QMARK_$jscomp$5$$);$APP.$cljs$core$reset_BANG_$$($checked_STAR_$$,$updated_checked_QMARK_$$);
return $APP.$cljs$core$truth_$$($on_change$jscomp$30$$)?$on_change$jscomp$30$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$30$$.$cljs$core$IFn$_invoke$arity$1$($updated_checked_QMARK_$$):$on_change$jscomp$30$$($updated_checked_QMARK_$$):null}),$handle_keydown$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_toggle$$)],function($JSCompiler_temp$jscomp$1457_event$jscomp$220$$){$APP.$app$util$dom$prevent_default$$($JSCompiler_temp$jscomp$1457_event$jscomp$220$$);
if($APP.$cljs$core$truth_$$($disabled_QMARK_$jscomp$4$$))$JSCompiler_temp$jscomp$1457_event$jscomp$220$$=null;else{var $JSCompiler_inline_result$jscomp$1458_or__5025__auto__$jscomp$inline_7973$$=(0,$APP.$app$util$keyboard$space_QMARK_$$)($JSCompiler_temp$jscomp$1457_event$jscomp$220$$);$JSCompiler_inline_result$jscomp$1458_or__5025__auto__$jscomp$inline_7973$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1458_or__5025__auto__$jscomp$inline_7973$$)?$JSCompiler_inline_result$jscomp$1458_or__5025__auto__$jscomp$inline_7973$$:
(0,$APP.$app$util$keyboard$enter_QMARK_$$)($JSCompiler_temp$jscomp$1457_event$jscomp$220$$);$JSCompiler_temp$jscomp$1457_event$jscomp$220$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1458_or__5025__auto__$jscomp$inline_7973$$)?$handle_toggle$$.$cljs$core$IFn$_invoke$arity$1$?$handle_toggle$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1457_event$jscomp$220$$):$handle_toggle$$($JSCompiler_temp$jscomp$1457_event$jscomp$220$$):null}return $JSCompiler_temp$jscomp$1457_event$jscomp$220$$});
$props__$1$jscomp$62_ref$jscomp$47$$={...$props$jscomp$278$$,role:"switch","aria-label":$disabled$jscomp$11_has_label_QMARK_$$?null:$aria_label$jscomp$7$$,tabIndex:$APP.$cljs$core$truth_$$($disabled_QMARK_$jscomp$4$$)?-1:0,className:($class$$jscomp$53$$??"")+" main_ui_ds_controls_switch__switch "+(($checked_QMARK_$jscomp$5$$===!1?"main_ui_ds_controls_switch__off":"")+" "+($checked_QMARK_$jscomp$5$$==null?"main_ui_ds_controls_switch__neutral":"")+" "+($checked_QMARK_$jscomp$5$$===!0?"main_ui_ds_controls_switch__on":
"")),"aria-checked":$checked_QMARK_$jscomp$5$$,onClick:$handle_toggle$$,ref:$props__$1$jscomp$62_ref$jscomp$47$$,onKeyDown:$handle_keydown$jscomp$2$$,disabled:$disabled_QMARK_$jscomp$4$$};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($default_checked$$)],function(){return $APP.$cljs$core$reset_BANG_$$($checked_STAR_$$,$default_checked$$)});return(0,$APP.$rumext$v2$create_element$$)("div",$props__$1$jscomp$62_ref$jscomp$47$$,(0,$APP.$rumext$v2$jsx$$)("div",
{id:$id$jscomp$915_props_75134$$,className:"main_ui_ds_controls_switch__switch-track",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_controls_switch__switch-thumb"})}),$disabled$jscomp$11_has_label_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:$id$jscomp$915_props_75134$$,className:"main_ui_ds_controls_switch__switch-label",children:$label$jscomp$37$$}):null)};
$APP.$app$main$ui$forms$form_input_STAR_$$=function($props_75141_touched_QMARK_$jscomp$6$$){var $error$jscomp$138_name$jscomp$432$$=void 0,$trim$jscomp$4$$=void 0,$props$jscomp$279_props__$1$jscomp$63_props__$2$jscomp$4$$=void 0;({name:$error$jscomp$138_name$jscomp$432$$,trim:$trim$jscomp$4$$,...$props$jscomp$279_props__$1$jscomp$63_props__$2$jscomp$4$$}=$props_75141_touched_QMARK_$jscomp$6$$);var $form$jscomp$179$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$4$$=
$error$jscomp$138_name$jscomp$432$$;$props_75141_touched_QMARK_$jscomp$6$$=function(){var $and__5023__auto__$jscomp$662$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$179$$)),$input_name$jscomp$4$$);return $and__5023__auto__$jscomp$662$$?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$179$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1626$touched$$,$input_name$jscomp$4$$],null)):$and__5023__auto__$jscomp$662$$}();$error$jscomp$138_name$jscomp$432$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$179$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$input_name$jscomp$4$$],null));var $extra_error$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$179$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5073$extra_errors$$,$input_name$jscomp$4$$],null)),$value$jscomp$779$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$179$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$input_name$jscomp$4$$],null),""),$on_change$jscomp$31$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($input_name$jscomp$4$$)],
function($event$jscomp$221_value__$1$jscomp$34$$){$event$jscomp$221_value__$1$jscomp$34$$=$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$221_value__$1$jscomp$34$$));return $APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$179$$,$input_name$jscomp$4$$,$event$jscomp$221_value__$1$jscomp$34$$,$trim$jscomp$4$$)});$props$jscomp$279_props__$1$jscomp$63_props__$2$jscomp$4$$={...$props$jscomp$279_props__$1$jscomp$63_props__$2$jscomp$4$$,
onChange:$on_change$jscomp$31$$,value:$value$jscomp$779$$};$props$jscomp$279_props__$1$jscomp$63_props__$2$jscomp$4$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($extra_error$$)?$extra_error$$:$APP.$cljs$core$truth_$$($error$jscomp$138_name$jscomp$432$$)?$props_75141_touched_QMARK_$jscomp$6$$:$error$jscomp$138_name$jscomp$432$$)?{...$props$jscomp$279_props__$1$jscomp$63_props__$2$jscomp$4$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($error$jscomp$138_name$jscomp$432$$)?
$error$jscomp$138_name$jscomp$432$$:$extra_error$$)}:$props$jscomp$279_props__$1$jscomp$63_props__$2$jscomp$4$$;return(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$279_props__$1$jscomp$63_props__$2$jscomp$4$$)};
$APP.$app$main$ui$forms$form_submit_STAR_$$=function($handle_key_down_save_props_75144$$){var $disabled$jscomp$12$$=void 0,$on_submit$jscomp$11$$=void 0,$props$jscomp$281_props__$1$jscomp$65$$=void 0;({disabled:$disabled$jscomp$12$$,onSubmit:$on_submit$jscomp$11$$,...$props$jscomp$281_props__$1$jscomp$65$$}=$handle_key_down_save_props_75144$$);var $form$jscomp$181$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$form_state$$=$APP.$cljs$core$truth_$$($form$jscomp$181$$)?$APP.$cljs$core$_deref$$($form$jscomp$181$$):
null,$disabled_QMARK_$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($form$jscomp$181$$),$APP.$rumext$v2$adapt$$($form_state$$),$APP.$rumext$v2$adapt$$($disabled$jscomp$12$$)],function(){return $APP.$cljs$core$boolean$0$$($form$jscomp$181$$==null||$disabled$jscomp$12$$===!0||$APP.$cljs$core$not$$($APP.$cljs$cst$5075$valid$$.$cljs$core$IFn$_invoke$arity$1$($form_state$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$5345$async_errors$$.$cljs$core$IFn$_invoke$arity$1$($form_state$$))||
$APP.$cljs$core$seq$$($APP.$cljs$cst$5073$extra_errors$$.$cljs$core$IFn$_invoke$arity$1$($form_state$$)))});$handle_key_down_save_props_75144$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_submit$jscomp$11$$),$APP.$rumext$v2$adapt$$($form$jscomp$181$$),$APP.$rumext$v2$adapt$$($disabled_QMARK_$jscomp$5$$)],function($e$jscomp$331$$){var $and__5023__auto__$jscomp$inline_13123_or__5025__auto__$jscomp$inline_13124$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($e$jscomp$331$$);
$and__5023__auto__$jscomp$inline_13123_or__5025__auto__$jscomp$inline_13124$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13123_or__5025__auto__$jscomp$inline_13124$$)?$and__5023__auto__$jscomp$inline_13123_or__5025__auto__$jscomp$inline_13124$$:(0,$APP.$app$util$keyboard$space_QMARK_$$)($e$jscomp$331$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13123_or__5025__auto__$jscomp$inline_13124$$)?$APP.$cljs$core$not$$($disabled_QMARK_$jscomp$5$$):
$and__5023__auto__$jscomp$inline_13123_or__5025__auto__$jscomp$inline_13124$$)?($APP.$app$util$dom$prevent_default$$($e$jscomp$331$$),$on_submit$jscomp$11$$.$cljs$core$IFn$_invoke$arity$2$?$on_submit$jscomp$11$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$181$$,$e$jscomp$331$$):$on_submit$jscomp$11$$($form$jscomp$181$$,$e$jscomp$331$$)):null});$props$jscomp$281_props__$1$jscomp$65$$={...$props$jscomp$281_props__$1$jscomp$65$$,onKeyDown:$handle_key_down_save_props_75144$$,type:"submit"};return $APP.$rumext$v2$create_element$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,
$APP.$cljs$core$truth_$$($disabled_QMARK_$jscomp$5$$)?{...$props$jscomp$281_props__$1$jscomp$65$$,disabled:!0,onKeyDown:$handle_key_down_save_props_75144$$,type:"submit"}:$props$jscomp$281_props__$1$jscomp$65$$)};
$APP.$app$main$ui$forms$form_STAR_$$=function($on_submit_SINGLEQUOTE_$jscomp$1_props_75147$$){var $form$jscomp$182$$=$on_submit_SINGLEQUOTE_$jscomp$1_props_75147$$.form,$children$jscomp$288$$=$on_submit_SINGLEQUOTE_$jscomp$1_props_75147$$.children,$class$$jscomp$54$$=$on_submit_SINGLEQUOTE_$jscomp$1_props_75147$$.className,$on_submit$jscomp$12$$=$on_submit_SINGLEQUOTE_$jscomp$1_props_75147$$.onSubmit;$on_submit_SINGLEQUOTE_$jscomp$1_props_75147$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_submit$jscomp$12$$)],
function($event$jscomp$223$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$223$$);return $APP.$cljs$core$fn_QMARK_$$($on_submit$jscomp$12$$)?$on_submit$jscomp$12$$.$cljs$core$IFn$_invoke$arity$2$?$on_submit$jscomp$12$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$182$$,$event$jscomp$223$$):$on_submit$jscomp$12$$($form$jscomp$182$$,$event$jscomp$223$$):null});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$forms$context$$),{value:$form$jscomp$182$$,children:(0,$APP.$rumext$v2$jsx$$)("form",
{onSubmit:$on_submit_SINGLEQUOTE_$jscomp$1_props_75147$$,className:$class$$jscomp$54$$,children:$children$jscomp$288$$})})};
$APP.$$jscomp$scope$1820006746$3$normalizeWheel$$=function($event$jscomp$224$$){var $sX$$=0,$sY$$=0;"detail"in $event$jscomp$224$$&&($sY$$=$event$jscomp$224$$.detail);"wheelDelta"in $event$jscomp$224$$&&($sY$$=-$event$jscomp$224$$.wheelDelta/120);"wheelDeltaY"in $event$jscomp$224$$&&($sY$$=-$event$jscomp$224$$.wheelDeltaY/120);"wheelDeltaX"in $event$jscomp$224$$&&($sX$$=-$event$jscomp$224$$.wheelDeltaX/120);"axis"in $event$jscomp$224$$&&$event$jscomp$224$$.axis===$event$jscomp$224$$.HORIZONTAL_AXIS&&
($sX$$=$sY$$,$sY$$=0);var $pX$$=$sX$$*$$jscomp$scope$1820006746$0$PIXEL_STEP$$;var $pY$$=$sY$$*$$jscomp$scope$1820006746$0$PIXEL_STEP$$;"deltaY"in $event$jscomp$224$$&&($pY$$=$event$jscomp$224$$.deltaY);"deltaX"in $event$jscomp$224$$&&($pX$$=$event$jscomp$224$$.deltaX);($pX$$||$pY$$)&&$event$jscomp$224$$.deltaMode&&($event$jscomp$224$$.deltaMode==1?($pX$$*=$$jscomp$scope$1820006746$1$LINE_HEIGHT$$,$pY$$*=$$jscomp$scope$1820006746$1$LINE_HEIGHT$$):($pX$$*=$$jscomp$scope$1820006746$2$PAGE_HEIGHT$$,
$pY$$*=$$jscomp$scope$1820006746$2$PAGE_HEIGHT$$));$pX$$&&!$sX$$&&($sX$$=$pX$$<1?-1:1);$pY$$&&!$sY$$&&($sY$$=$pY$$<1?-1:1);return{spinX:$sX$$,spinY:$sY$$,pixelX:$pX$$,pixelY:$pY$$}};
$APP.$app$main$ui$dashboard$import$0$use_import_file$$=function($project_id$jscomp$30$$,$on_finish_import$$){return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$30$$),$APP.$rumext$v2$adapt$$($on_finish_import$$)],function($entries$jscomp$26_entries__$1$jscomp$1$$){$entries$jscomp$26_entries__$1$jscomp$1$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($file$jscomp$153$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$725$name$$,$file$jscomp$153$$.name,$APP.$cljs$cst$1579$uri$$,$APP.$app$util$webapi$create_uri$$($file$jscomp$153$$)],null)},$entries$jscomp$26_entries__$1$jscomp$1$$));return $APP.$cljs$core$truth_$$($entries$jscomp$26_entries__$1$jscomp$1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5346$import$$,$APP.$cljs$cst$2181$project_id$$,
$project_id$jscomp$30$$,$APP.$cljs$cst$4379$entries$$,$entries$jscomp$26_entries__$1$jscomp$1$$,$APP.$cljs$cst$5347$on_finish_import$$,$on_finish_import$$],null))):null})};
$app$main$ui$dashboard$import$0$update_entry_name$$=function($entries$jscomp$27$$,$file_id$jscomp$359$$,$new_name$jscomp$35$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($entry$jscomp$61$$){var $new_name__$1$jscomp$4$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($new_name$jscomp$35$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$61$$),$file_id$jscomp$359$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",
$new_name__$1$jscomp$4$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($entry$jscomp$61$$,$APP.$cljs$cst$725$name$$,$new_name__$1$jscomp$4$$):$entry$jscomp$61$$},$entries$jscomp$27$$)};
$app$main$ui$dashboard$import$0$remove_entry$$=function($entries$jscomp$28$$,$file_id$jscomp$360$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($entry$jscomp$62$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$62$$),$file_id$jscomp$360$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($entry$jscomp$62$$,$APP.$cljs$cst$2541$deleted$$,!0):$entry$jscomp$62$$},$entries$jscomp$28$$)};
$app$main$ui$dashboard$import$0$update_with_analyze_result$$=function($entries$jscomp$29_entries__$1$jscomp$2$$,$map__75156__$1_p__75155$$){$map__75156__$1_p__75155$$=$APP.$cljs$core$__destructure_map$$($map__75156__$1_p__75155$$);var $file_id$jscomp$361$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75156__$1_p__75155$$,$APP.$cljs$cst$1644$file_id$$),$status$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75156__$1_p__75155$$,$APP.$cljs$cst$109$status$$);$entries$jscomp$29_entries__$1$jscomp$2$$=
$APP.$cljs$core$filterv$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$uuid_QMARK_$$,$APP.$cljs$cst$1644$file_id$$),$entries$jscomp$29_entries__$1$jscomp$2$$);var $status__$1$jscomp$1$$=function(){var $G__75157__$1$$=$status$jscomp$22$$ instanceof $APP.$cljs$core$Keyword$$?$status$jscomp$22$$.$fqn$:null;switch($G__75157__$1$$){case "success":return $cljs$cst$5348$import_ready$$;case "error":return $cljs$cst$5349$analyze_error$$;default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75157__$1$$)].join(""));}}(),$updated__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__75156__$1_p__75155$$,$APP.$cljs$cst$109$status$$,$status__$1$jscomp$1$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__75154_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$361$$,$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__75154_SHARP_$$))},$entries$jscomp$29_entries__$1$jscomp$2$$))?
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($entry$jscomp$63$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$63$$),$file_id$jscomp$361$$)?$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$entry$jscomp$63$$,$updated__$1$$])):$entry$jscomp$63$$},$entries$jscomp$29_entries__$1$jscomp$2$$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($entries$jscomp$29_entries__$1$jscomp$2$$,
$updated__$1$$)};
$app$main$ui$dashboard$import$0$update_entry_status$$=function($entries$jscomp$30$$,$message$jscomp$108$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($entry$jscomp$64$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$64$$),$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($message$jscomp$108$$))){var $status$jscomp$23$$=function(){var $G__75158_G__75158__$1$$=$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($message$jscomp$108$$);
$G__75158_G__75158__$1$$=$G__75158_G__75158__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__75158_G__75158__$1$$.$fqn$:null;switch($G__75158_G__75158__$1$$){case "progress":return $cljs$cst$5350$import_progress$$;case "finish":return $cljs$cst$5351$import_success$$;case "error":return $cljs$cst$5352$import_error$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75158_G__75158__$1$$)].join(""));}}();return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($entry$jscomp$64$$,
$APP.$cljs$cst$2244$progress$$,$APP.$cljs$cst$2244$progress$$.$cljs$core$IFn$_invoke$arity$1$($message$jscomp$108$$)),$APP.$cljs$cst$109$status$$,$status$jscomp$23$$),$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($message$jscomp$108$$)))}return $entry$jscomp$64$$},$entries$jscomp$30$$)};
$app$main$ui$dashboard$import$0$parse_progress_message$$=function($message$jscomp$109$$){var $G__75159$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($message$jscomp$109$$);switch($G__75159$$ instanceof $APP.$cljs$core$Keyword$$?$G__75159$$.$fqn$:null){case "upload-data":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.import.progress.upload-data",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$1401$current$$.$cljs$core$IFn$_invoke$arity$1$($message$jscomp$109$$),
$APP.$cljs$cst$2328$total$$.$cljs$core$IFn$_invoke$arity$1$($message$jscomp$109$$)]));case "upload-media":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.import.progress.upload-media",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$208$file$$.$cljs$core$IFn$_invoke$arity$1$($message$jscomp$109$$)]));case "process-page":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.import.progress.process-page",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$208$file$$.$cljs$core$IFn$_invoke$arity$1$($message$jscomp$109$$)]));
case "process-colors":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.progress.process-colors");case "process-typographies":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.progress.process-typographies");case "process-media":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.progress.process-media");case "process-components":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.progress.process-components");
case "process-deleted-components":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.progress.process-components");default:return""}};$app$main$ui$dashboard$import$0$has_status_analyze_QMARK_$$=function($item$jscomp$111$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$111$$),$cljs$cst$5353$analyze$$)};
$app$main$ui$dashboard$import$0$has_status_import_success_QMARK_$$=function($item$jscomp$112$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$112$$),$cljs$cst$5351$import_success$$)};
$app$main$ui$dashboard$import$0$has_status_error_QMARK_$$=function($item$jscomp$113$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$113$$),$cljs$cst$5352$import_error$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$113$$),$cljs$cst$5349$analyze_error$$)};
$app$main$ui$dashboard$import$0$has_status_ready_QMARK_$$=function($item$jscomp$114$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5348$import_ready$$,$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$114$$))&&$APP.$cljs$core$not$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$114$$))};
$app$main$ui$dashboard$import$0$analyze_entries$$=function($state$jscomp$1162$$,$entries$jscomp$31$$){var $features__$1$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$227$features$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($message$jscomp$110$$){$APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($message$jscomp$110$$)!=null&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"import-files-error",$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($message$jscomp$110$$)],null)));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1162$$,$app$main$ui$dashboard$import$0$update_with_analyze_result$$,$message$jscomp$110$$)},$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,$APP.$beicon$v2$core$mapcat$$(function($p1__75160_SHARP_$$){return $APP.$beicon$v2$core$delay$$(200,
(0,$APP.$beicon$v2$core$of$$)($p1__75160_SHARP_$$))},$APP.$app$main$worker$ask_many_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3115$cmd$$,$cljs$cst$5354$analyze_import$$,$APP.$cljs$cst$1916$files$$,$entries$jscomp$31$$,$APP.$cljs$cst$227$features$$,$features__$1$jscomp$30$$],null)))))};
$app$main$ui$dashboard$import$0$import_files$$=function($state$jscomp$1163$$,$project_id$jscomp$32$$,$entries$jscomp$32$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"import-files",$APP.$cljs$cst$4963$num_files$$,$APP.$cljs$core$count$$($entries$jscomp$32$$)],null)));var $features__$1$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
$APP.$cljs$cst$227$features$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($message$jscomp$111$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1163$$,$app$main$ui$dashboard$import$0$update_entry_status$$,$message$jscomp$111$$)},$APP.$beicon$v2$core$filter$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$uuid_QMARK_$$,$APP.$cljs$cst$1644$file_id$$),$APP.$app$main$worker$ask_many_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$3115$cmd$$,$cljs$cst$5355$import_files$$,$APP.$cljs$cst$2181$project_id$$,$project_id$jscomp$32$$,$APP.$cljs$cst$1916$files$$,$entries$jscomp$32$$,$APP.$cljs$cst$227$features$$,$features__$1$jscomp$31$$],null))))};
$app$main$ui$dashboard$import$0$initialize_state$$=function($entries$jscomp$34$$){return function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75163_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__75163_SHARP_$$,$APP.$cljs$cst$109$status$$,$cljs$cst$5353$analyze$$)},$entries$jscomp$34$$)}};
$app$main$ui$dashboard$import$0$import_dialog$$=function($on_cancel$jscomp$5_props_75168$$){var $on_finish_import$jscomp$2$$=$on_cancel$jscomp$5_props_75168$$["on-finish-import"],$project_id$jscomp$33$$=$on_cancel$jscomp$5_props_75168$$["project-id"],$entries$jscomp$35$$=$on_cancel$jscomp$5_props_75168$$.entries,$template$jscomp$8$$=$on_cancel$jscomp$5_props_75168$$.template;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return function(){return $APP.$cljs$core$run_BANG_$$($APP.$app$util$webapi$revoke_uri$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1579$uri$$,$entries$jscomp$35$$))}});var $state_STAR_$jscomp$8$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$dashboard$import$0$initialize_state$$($entries$jscomp$35$$)),$entries__$1$jscomp$3$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$8$$),$status_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$5353$analyze$$),$status$jscomp$25$$=$APP.$cljs$core$_deref$$($status_STAR_$$),
$edition_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$edition$jscomp$5$$=$APP.$cljs$core$_deref$$($edition_STAR_$jscomp$1$$),$continue_entries$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entries__$1$jscomp$3$$)],function(){var $entries__$2$jscomp$1$$=$APP.$cljs$core$filterv$$($app$main$ui$dashboard$import$0$has_status_ready_QMARK_$$,$entries__$1$jscomp$3$$);$APP.$cljs$core$reset_BANG_$$($status_STAR_$$,$cljs$cst$5350$import_progress$$);
return $app$main$ui$dashboard$import$0$import_files$$($state_STAR_$jscomp$8$$,$project_id$jscomp$33$$,$entries__$2$jscomp$1$$)}),$continue_template$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_finish_import$jscomp$2$$)],function($params$jscomp$397_template__$1$jscomp$1$$){$params$jscomp$397_template__$1$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2181$project_id$$,$project_id$jscomp$33$$,$APP.$cljs$cst$4966$template_id$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$397_template__$1$jscomp$1$$)],null);$APP.$cljs$core$reset_BANG_$$($status_STAR_$$,$cljs$cst$5350$import_progress$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$dashboard$clone_template$$($APP.$cljs$core$with_meta$$($params$jscomp$397_template__$1$jscomp$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,function(){$APP.$cljs$core$reset_BANG_$$($status_STAR_$$,
$cljs$cst$5351$import_success$$);return $APP.$cljs$core$fn_QMARK_$$($on_finish_import$jscomp$2$$)?$on_finish_import$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_finish_import$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_finish_import$jscomp$2$$():null},$APP.$cljs$cst$1295$on_error$$,function($cause$jscomp$98$$){$APP.$cljs$core$reset_BANG_$$($status_STAR_$$,$APP.$cljs$cst$849$error$$);$APP.$app$common$exceptions$print_throwable$$($cause$jscomp$98$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$modal$hide$$(),
$APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.libraries-and-templates.import-error")))}],null))))}),$on_edit$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($file_id$jscomp$363$$){return $APP.$cljs$core$reset_BANG_$$($edition_STAR_$jscomp$1$$,$file_id$jscomp$363$$)}),$on_entry_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($file_id$jscomp$364$$,$value$jscomp$782$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($edition_STAR_$jscomp$1$$,
$APP.$cljs$core$constantly$$(null));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$8$$,$app$main$ui$dashboard$import$0$update_entry_name$$,$file_id$jscomp$364$$,$value$jscomp$782$$)}),$on_entry_delete$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($file_id$jscomp$365$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($state_STAR_$jscomp$8$$,$app$main$ui$dashboard$import$0$remove_entry$$,$file_id$jscomp$365$$)});$on_cancel$jscomp$5_props_75168$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($edition$jscomp$5$$)],function($event$jscomp$229$$){return $edition$jscomp$5$$==null?($APP.$app$util$dom$prevent_default$$($event$jscomp$229$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())):null});var $on_continue$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($continue_template$$),$APP.$rumext$v2$adapt$$($continue_entries$$)],
function($event$jscomp$230$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$230$$);return $template$jscomp$8$$!=null?$continue_template$$.$cljs$core$IFn$_invoke$arity$1$?$continue_template$$.$cljs$core$IFn$_invoke$arity$1$($template$jscomp$8$$):$continue_template$$($template$jscomp$8$$):$continue_entries$$.$cljs$core$IFn$_invoke$arity$0$?$continue_entries$$.$cljs$core$IFn$_invoke$arity$0$():$continue_entries$$()}),$on_accept$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_finish_import$jscomp$2$$)],
function($event$jscomp$231$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$231$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$());return $APP.$cljs$core$fn_QMARK_$$($on_finish_import$jscomp$2$$)?$on_finish_import$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_finish_import$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_finish_import$jscomp$2$$():null}),$entries__$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entries__$1$jscomp$3$$)],
function(){return $APP.$cljs$core$filterv$$($APP.$cljs$core$complement$$($APP.$cljs$cst$2541$deleted$$),$entries__$1$jscomp$3$$)}),$import_success_total$$=$template$jscomp$8$$!=null?1:$APP.$cljs$core$count$$($APP.$cljs$core$filterv$$($app$main$ui$dashboard$import$0$has_status_import_success_QMARK_$$,$entries__$2$$)),$errors_QMARK_$$=$template$jscomp$8$$!=null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($status$jscomp$25$$,$APP.$cljs$cst$849$error$$):function(){var $or__5025__auto__$jscomp$1021$$=
$APP.$cljs$core$some$$($app$main$ui$dashboard$import$0$has_status_error_QMARK_$$,$entries__$2$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1021$$)?$or__5025__auto__$jscomp$1021$$:$APP.$cljs$core$count$$($entries__$2$$)===0}(),$pending_analysis_QMARK_$$=$APP.$cljs$core$some$$($app$main$ui$dashboard$import$0$has_status_analyze_QMARK_$$,$entries__$2$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entries__$2$$)],function(){return $template$jscomp$8$$!=
null?$APP.$cljs$core$reset_BANG_$$($status_STAR_$$,$cljs$cst$5348$import_ready$$):$APP.$cljs$core$seq$$($entries__$2$$)&&$APP.$cljs$core$every_QMARK_$$(function($p1__75164_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5348$import_ready$$,$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($p1__75164_SHARP_$$))},$entries__$2$$)?$APP.$cljs$core$reset_BANG_$$($status_STAR_$$,$cljs$cst$5348$import_ready$$):$APP.$cljs$core$seq$$($entries__$2$$)&&$APP.$cljs$core$every_QMARK_$$(function($p1__75165_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5351$import_success$$,
$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($p1__75165_SHARP_$$))},$entries__$2$$)?$APP.$cljs$core$reset_BANG_$$($status_STAR_$$,$cljs$cst$5351$import_success$$):$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$666_and__5023__auto____$1$jscomp$112$$=$APP.$cljs$core$seq$$($entries__$2$$);return $and__5023__auto__$jscomp$666_and__5023__auto____$1$jscomp$112$$?($and__5023__auto__$jscomp$666_and__5023__auto____$1$jscomp$112$$=$APP.$cljs$core$every_QMARK_$$(function($p1__75166_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5348$import_ready$$,
$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($p1__75166_SHARP_$$))},$entries__$2$$))?$APP.$cljs$core$some$$(function($p1__75167_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5352$import_error$$,$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($p1__75167_SHARP_$$))},$entries__$2$$):$and__5023__auto__$jscomp$666_and__5023__auto____$1$jscomp$112$$:$and__5023__auto__$jscomp$666_and__5023__auto____$1$jscomp$112$$}())?$APP.$cljs$core$reset_BANG_$$($status_STAR_$$,
$cljs$cst$5352$import_error$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $sub$jscomp$22$$=$app$main$ui$dashboard$import$0$analyze_entries$$($state_STAR_$jscomp$8$$,$entries__$2$$);return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$dispose_BANG_$$,$sub$jscomp$22$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_import__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_import__modal-container",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_import__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_dashboard_import__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_cancel$jscomp$5_props_75168$$,className:"main_ui_dashboard_import__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_import__modal-content",
children:[$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$667$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5353$analyze$$,$status$jscomp$25$$);return $and__5023__auto__$jscomp$667$$?$errors_QMARK_$$:$and__5023__auto__$jscomp$667$$}())?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$context_notification$context_notification$$,{level:$APP.$cljs$cst$2343$warning$$,"class":"main_ui_dashboard_import__context-notification-error",content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.import-warning")}):
null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5351$import_success$$,$status$jscomp$25$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$context_notification$context_notification$$,{level:$import_success_total$$===0?$APP.$cljs$cst$2343$warning$$:$APP.$cljs$cst$2344$success$$,content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.import.import-message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($import_success_total$$)]))}):
null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5352$import_error$$,$status$jscomp$25$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$context_notification$context_notification$$,{level:$APP.$cljs$cst$849$error$$,"class":"main_ui_dashboard_import__context-notification-error",content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.import-error.disclaimer")}):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$668_or__5025__auto__$jscomp$1022$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5352$import_error$$,$status$jscomp$25$$);return $and__5023__auto__$jscomp$668_or__5025__auto__$jscomp$1022$$?$and__5023__auto__$jscomp$668_or__5025__auto__$jscomp$1022$$:($and__5023__auto__$jscomp$668_or__5025__auto__$jscomp$1022$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5353$analyze$$,$status$jscomp$25$$))?$errors_QMARK_$$:$and__5023__auto__$jscomp$668_or__5025__auto__$jscomp$1022$$}())?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_import__import-error-disclaimer",children:[(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.import-error.message1")}),(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_dashboard_import__import-error-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$101$$,$entry$jscomp$66$$){$out_arr__44124__auto__$jscomp$101$$.push($APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5352$import_error$$,null,$cljs$cst$5349$analyze_error$$,null],null),null),$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$66$$))?(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_dashboard_import__import-error-list-enry",children:[(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$66$$)}),function(){var $temp__5825__auto__$jscomp$312$$=$APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$66$$);
return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$312$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_import__import-error-detail",children:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$669$$=typeof $temp__5825__auto__$jscomp$312$$==="string";return $and__5023__auto__$jscomp$669$$?$APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($temp__5825__auto__$jscomp$312$$),"check error"):$and__5023__auto__$jscomp$669$$}())?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.import-error.check-error"):
$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$670$$=typeof $temp__5825__auto__$jscomp$312$$==="string";return $and__5023__auto__$jscomp$670$$?$APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($temp__5825__auto__$jscomp$312$$),"corrupt"):$and__5023__auto__$jscomp$670$$}())?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.import-error.corrupt-file"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.import-error.unknown-error")}):
null}()]},""+(function(){var $or__5025__auto__$jscomp$1023_or__5025__auto____$1$jscomp$114$$=$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$66$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1023_or__5025__auto____$1$jscomp$114$$))return $or__5025__auto__$jscomp$1023_or__5025__auto____$1$jscomp$114$$;$or__5025__auto__$jscomp$1023_or__5025__auto____$1$jscomp$114$$=$APP.$cljs$cst$1579$uri$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$66$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1023_or__5025__auto____$1$jscomp$114$$)?
$or__5025__auto__$jscomp$1023_or__5025__auto____$1$jscomp$114$$:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$66$$)}()??"")):null);return $out_arr__44124__auto__$jscomp$101$$},[],$entries__$2$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.import-error.message2")})]}):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$102$$,$entry$jscomp$67$$){$out_arr__44124__auto__$jscomp$102$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$import$0$import_entry_STAR_$$,
{entries:$entries__$2$$,onDelete:$on_entry_delete$$,"importing?":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5350$import_progress$$,$status$jscomp$25$$),onEdit:$on_edit$jscomp$3$$,entry:$entry$jscomp$67$$,edition:$edition$jscomp$5$$,canBeDeleted:$APP.$cljs$core$count$$($entries__$2$$)>1,onChange:$on_entry_change$$},""+($APP.$cljs$cst$1579$uri$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$67$$)??"")+"/"+($APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$67$$)??
"")));return $out_arr__44124__auto__$jscomp$102$$},[],$entries__$2$$),$template$jscomp$8$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$import$0$import_entry_STAR_$$,{entry:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($template$jscomp$8$$,$APP.$cljs$cst$109$status$$,$status$jscomp$25$$),canBeDeleted:!1}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5350$import_progress$$,$status$jscomp$25$$)?(0,$APP.$rumext$v2$jsx$$)("div",{role:"status","aria-live":"polite",
className:"main_ui_dashboard_import__status-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.uploading-file")}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_import__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_import__action-buttons",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5353$analyze$$,$status$jscomp$25$$)?(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel"),
onClick:$on_cancel$jscomp$5_props_75168$$,className:"main_ui_dashboard_import__cancel-button"}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($status$jscomp$25$$,$cljs$cst$5348$import_ready$$)?(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue"),disabled:$pending_analysis_QMARK_$$,onClick:$on_continue$$,className:"main_ui_dashboard_import__accept-btn"}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5351$import_success$$,
$status$jscomp$25$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5352$import_error$$,$status$jscomp$25$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5350$import_progress$$,$status$jscomp$25$$)?(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.accept"),disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5350$import_progress$$,$status$jscomp$25$$),onClick:$on_accept$jscomp$7$$,
className:"main_ui_dashboard_import__accept-btn"}):null]})})]})})};
$APP.$app$main$ui$dashboard$inline_edition$inline_edition$$=function($map__75149_map__75149__$1_max_length$jscomp$5_props_75148$$){$map__75149_map__75149__$1_max_length$jscomp$5_props_75148$$=$APP.$rumext$v2$util$wrap_props$$($map__75149_map__75149__$1_max_length$jscomp$5_props_75148$$);$map__75149_map__75149__$1_max_length$jscomp$5_props_75148$$=$APP.$cljs$core$__destructure_map$$($map__75149_map__75149__$1_max_length$jscomp$5_props_75148$$);var $content$jscomp$241_on_input$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75149_map__75149__$1_max_length$jscomp$5_props_75148$$,
$APP.$cljs$cst$1637$content$$),$on_end$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75149_map__75149__$1_max_length$jscomp$5_props_75148$$,$cljs$cst$5356$on_end$$);$map__75149_map__75149__$1_max_length$jscomp$5_props_75148$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75149_map__75149__$1_max_length$jscomp$5_props_75148$$,$cljs$cst$4742$max_length$$);var $name$jscomp$434$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($content$jscomp$241_on_input$$),
$input_ref$jscomp$5$$=(0,$APP.$rumext$v2$use_ref$$)();$content$jscomp$241_on_input$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$232$$){return $APP.$cljs$core$reset_BANG_$$($name$jscomp$434$$,(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$232$$))});var $on_cancel$jscomp$6$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($G__75150_event$jscomp$233$$){$APP.$app$util$dom$prevent_default$$($G__75150_event$jscomp$233$$);$APP.$app$util$dom$stop_propagation$$($G__75150_event$jscomp$233$$);
$G__75150_event$jscomp$233$$=$APP.$cljs$core$_deref$$($name$jscomp$434$$);return $on_end$$.$cljs$core$IFn$_invoke$arity$1$?$on_end$$.$cljs$core$IFn$_invoke$arity$1$($G__75150_event$jscomp$233$$):$on_end$$($G__75150_event$jscomp$233$$)}),$on_click$jscomp$23$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$234$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$234$$);return $APP.$app$util$dom$stop_propagation$$($event$jscomp$234$$)}),$on_blur$jscomp$6$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$235_name__$1$jscomp$16$$){$event$jscomp$235_name__$1$jscomp$16$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$235_name__$1$jscomp$16$$);return $on_end$$.$cljs$core$IFn$_invoke$arity$1$?$on_end$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$235_name__$1$jscomp$16$$):$on_end$$($event$jscomp$235_name__$1$jscomp$16$$)}),$on_keyup$jscomp$2$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$236_name__$1$jscomp$17$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$236_name__$1$jscomp$17$$);
return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$236_name__$1$jscomp$17$$))?$on_cancel$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$?$on_cancel$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$():$on_cancel$jscomp$6$$():$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$236_name__$1$jscomp$17$$))?($event$jscomp$236_name__$1$jscomp$17$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$236_name__$1$jscomp$17$$),$on_end$$.$cljs$core$IFn$_invoke$arity$1$?
$on_end$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$236_name__$1$jscomp$17$$):$on_end$$($event$jscomp$236_name__$1$jscomp$17$$)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $node$jscomp$384$$=$APP.$rumext$v2$ref_val$$($input_ref$jscomp$5$$);$APP.$app$util$dom$focus_BANG_$$($node$jscomp$384$$);return $APP.$app$util$dom$select_text_BANG_$$($node$jscomp$384$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_inline_edition__edit-wrapper",
children:[(0,$APP.$rumext$v2$jsx$$)("input",{value:$APP.$cljs$core$_deref$$($name$jscomp$434$$),ref:$input_ref$jscomp$5$$,onClick:$on_click$jscomp$23$$,onChange:$content$jscomp$241_on_input$$,onKeyDown:$on_keyup$jscomp$2$$,onBlur:$on_blur$jscomp$6$$,maxLength:$map__75149_map__75149__$1_max_length$jscomp$5_props_75148$$,className:"main_ui_dashboard_inline_edition__element-title"}),(0,$APP.$rumext$v2$jsx$$)("span",{onClick:$on_cancel$jscomp$6$$,className:"main_ui_dashboard_inline_edition__close",children:$APP.$app$main$ui$icons$close$$})]})};
$APP.$app$main$ui$ds$foundations$assets$raw_svg$raw_svg_STAR_$$=function($props_75195$$){var $id$jscomp$916$$=void 0,$props$jscomp$283$$=void 0;({id:$id$jscomp$916$$,...$props$jscomp$283$$}=$props_75195$$);return(0,$APP.$rumext$v2$create_element$$)("svg",$props$jscomp$283$$,(0,$APP.$rumext$v2$jsx$$)("use",{href:"#asset-"+($id$jscomp$916$$??"")}))};
$APP.$app$main$ui$dashboard$project_menu$project_menu_STAR_$$=function($on_edit$jscomp$4_options$jscomp$602_props_75194$$){function $on_import_files$$(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($file_input$$))}function $on_delete$jscomp$8$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,
$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-project-confirm.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-project-confirm.message"),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-project-confirm.accept"),$APP.$cljs$cst$2479$on_accept$$,$delete_fn$$],null)))}function $delete_fn$$(){var $team_id$jscomp$135$$=$APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$17$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.success-delete-project")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$delete_project$$($project$jscomp$17$$),$APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,
$team_id$jscomp$135$$]))]))}function $on_move$$($team_id$jscomp$134$$){var $data$jscomp$455$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$17$$),$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$134$$],null),$mdata$jscomp$11$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2488$on_success$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,
$team_id$jscomp$134$$])))}],null);return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.success-move-project")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$move_project$$($APP.$cljs$core$with_meta$$($data$jscomp$455$$,$mdata$jscomp$11$$))]))}}function $toggle_pin$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$dashboard$toggle_project_pin$$($project$jscomp$17$$))}
function $on_duplicate$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$duplicate_project$$($APP.$cljs$core$with_meta$$($project$jscomp$17$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2488$on_success$$,$on_duplicate_success$$],null))))}function $on_duplicate_success$$($new_project$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.success-duplicate-project")),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$common$go_to_dashboard_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,$APP.$cljs$cst$1927$team_id$$.$cljs$core$IFn$_invoke$arity$1$($new_project$$),$APP.$cljs$cst$2181$project_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_project$$)]))]))}var $on_import$$=$on_edit$jscomp$4_options$jscomp$602_props_75194$$.onImport,
$show$jscomp$6$$=$on_edit$jscomp$4_options$jscomp$602_props_75194$$.show,$left$jscomp$28_left__$1$jscomp$3$$=$on_edit$jscomp$4_options$jscomp$602_props_75194$$.left,$on_close$jscomp$8$$=$on_edit$jscomp$4_options$jscomp$602_props_75194$$.onClose,$top$jscomp$9_top__$1$jscomp$1$$=$on_edit$jscomp$4_options$jscomp$602_props_75194$$.top,$project$jscomp$17$$=$on_edit$jscomp$4_options$jscomp$602_props_75194$$.project;$on_edit$jscomp$4_options$jscomp$602_props_75194$$=$on_edit$jscomp$4_options$jscomp$602_props_75194$$.onEdit;
$top$jscomp$9_top__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($top$jscomp$9_top__$1$jscomp$1$$)?$top$jscomp$9_top__$1$jscomp$1$$:0;$left$jscomp$28_left__$1$jscomp$3$$=$APP.$cljs$core$truth_$$($left$jscomp$28_left__$1$jscomp$3$$)?$left$jscomp$28_left__$1$jscomp$3$$:0;var $current_team_id$jscomp$2_on_finish_import$jscomp$3$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_team_id$$),$teams$jscomp$10$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$teams$$),$teams__$1$jscomp$1$$=$APP.$cljs$core$vec$$($APP.$cljs$core$vals$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($teams$jscomp$10$$,
$current_team_id$jscomp$2_on_finish_import$jscomp$3$$))),$file_input$$=(0,$APP.$rumext$v2$use_ref$$)(null);$current_team_id$jscomp$2_on_finish_import$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$fn_QMARK_$$($on_import$$)?$on_import$$.$cljs$core$IFn$_invoke$arity$0$?$on_import$$.$cljs$core$IFn$_invoke$arity$0$():$on_import$$():null});$on_edit$jscomp$4_options$jscomp$602_props_75194$$=new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$17$$))?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename"),$APP.$cljs$cst$266$id$$,"project-rename",$APP.$cljs$cst$2402$handler$$,$on_edit$jscomp$4_options$jscomp$602_props_75194$$],null),$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$17$$))?
null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.duplicate"),$APP.$cljs$cst$266$id$$,"project-duplicate",$APP.$cljs$cst$2402$handler$$,$on_duplicate$$],null),$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$17$$))?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.pin-unpin"),
$APP.$cljs$cst$266$id$$,"project-pin",$APP.$cljs$cst$2402$handler$$,$toggle_pin$$],null),$APP.$cljs$core$seq$$($teams__$1$jscomp$1$$)&&$APP.$cljs$core$not$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$17$$))?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.move-to"),$APP.$cljs$cst$266$id$$,"project-move-to",$APP.$cljs$cst$873$options$$,function(){return function $app$main$ui$dashboard$project_menu$project_menu_STAR__$_iter__75197$$($s__75198$$){return new $APP.$cljs$core$LazySeq$$(null,
function(){for(;;){var $s__75198__$2_temp__5825__auto__$jscomp$313$$=$APP.$cljs$core$seq$$($s__75198$$);if($s__75198__$2_temp__5825__auto__$jscomp$313$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__75198__$2_temp__5825__auto__$jscomp$313$$)){var $JSCompiler_inline_result$jscomp$1460_c__5501__auto__$jscomp$38$$=$APP.$cljs$core$_chunked_first$$($s__75198__$2_temp__5825__auto__$jscomp$313$$),$size__5502__auto__$jscomp$38$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1460_c__5501__auto__$jscomp$38$$),
$b__75200_team$jscomp$44$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$38$$);a:{for(var $i__75199$jscomp$inline_7979$$=0;;)if($i__75199$jscomp$inline_7979$$<$size__5502__auto__$jscomp$38$$){var $team$jscomp$inline_7980_x$jscomp$inline_13127$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1460_c__5501__auto__$jscomp$38$$,$i__75199$jscomp$inline_7979$$),$b$jscomp$inline_13126$$=$b__75200_team$jscomp$44$$;$team$jscomp$inline_7980_x$jscomp$inline_13127$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$inline_7980_x$jscomp$inline_13127$$),$APP.$cljs$cst$266$id$$,["move-to-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$inline_7980_x$jscomp$inline_13127$$))].join(""),$APP.$cljs$cst$2402$handler$$,$on_move$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$inline_7980_x$jscomp$inline_13127$$))],null);$b$jscomp$inline_13126$$.add($team$jscomp$inline_7980_x$jscomp$inline_13127$$);
$i__75199$jscomp$inline_7979$$+=1}else{$JSCompiler_inline_result$jscomp$1460_c__5501__auto__$jscomp$38$$=!0;break a}$JSCompiler_inline_result$jscomp$1460_c__5501__auto__$jscomp$38$$=void 0}return $JSCompiler_inline_result$jscomp$1460_c__5501__auto__$jscomp$38$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75200_team$jscomp$44$$),$app$main$ui$dashboard$project_menu$project_menu_STAR__$_iter__75197$$($APP.$cljs$core$_chunked_rest$$($s__75198__$2_temp__5825__auto__$jscomp$313$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__75200_team$jscomp$44$$),
null)}$b__75200_team$jscomp$44$$=$APP.$cljs$core$first$$($s__75198__$2_temp__5825__auto__$jscomp$313$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($b__75200_team$jscomp$44$$),$APP.$cljs$cst$266$id$$,["move-to-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($b__75200_team$jscomp$44$$))].join(""),$APP.$cljs$cst$2402$handler$$,
$on_move$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($b__75200_team$jscomp$44$$))],null),$app$main$ui$dashboard$project_menu$project_menu_STAR__$_iter__75197$$($APP.$cljs$core$rest$$($s__75198__$2_temp__5825__auto__$jscomp$313$$)))}return null}},null,null)}($teams__$1$jscomp$1$$)}()],null):null,$on_import$$!=null?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import"),$APP.$cljs$cst$266$id$$,
"file-import",$APP.$cljs$cst$2402$handler$$,$on_import_files$$],null):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$17$$))?null:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$1472$separator$$],null),$APP.$cljs$core$truth_$$($APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$17$$))?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),
$APP.$cljs$cst$266$id$$,"project-delete",$APP.$cljs$cst$2402$handler$$,$on_delete$jscomp$8$$],null)],null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($show$jscomp$6$$),$APP.$rumext$v2$adapt$$($on_close$jscomp$8$$)],function(){if($show$jscomp$6$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5054$dropdown_SLASH_open$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,"project-menu"],null)));var $stream$jscomp$103$$=$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__75193_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("project-menu",$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__75193_SHARP_$$))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$5054$dropdown_SLASH_open$$),
$APP.$app$main$store$stream$$)))),$subs$jscomp$21$$=$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$04$$($stream$jscomp$103$$,null,null,$on_close$jscomp$8$$);return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$21$$)}}return null});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$context_menu_a11y$context_menu_STAR_$$,{onClose:$on_close$jscomp$8$$,show:$show$jscomp$6$$,fixed:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($top$jscomp$9_top__$1$jscomp$1$$,
0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($left$jscomp$28_left__$1$jscomp$3$$,0),minWidth:!0,top:$top$jscomp$9_top__$1$jscomp$1$$,left:$left$jscomp$28_left__$1$jscomp$3$$,options:$on_edit$jscomp$4_options$jscomp$602_props_75194$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$import$0$import_form$$,{ref:$file_input$$,"project-id":$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$17$$),"on-finish-import":$current_team_id$jscomp$2_on_finish_import$jscomp$3$$})]})};
$APP.$app$main$ui$components$link$link$$=function($props_75196$$){var $children$jscomp$289$$=$props_75196$$.children,$data_testid$jscomp$3$$=$props_75196$$["data-testid"],$class$$jscomp$55$$=$props_75196$$.class,$action$jscomp$3$$=$props_75196$$.action,$keyboard_action__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_75196$$["keyboard-action"],$action$jscomp$3$$);return(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$action$jscomp$3$$,onKeyDown:function($event$jscomp$237$$){return(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$237$$)?
$keyboard_action__$1$$.$cljs$core$IFn$_invoke$arity$1$?$keyboard_action__$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$237$$):$keyboard_action__$1$$($event$jscomp$237$$):null},tabIndex:"0","data-testid":$data_testid$jscomp$3$$,className:$class$$jscomp$55$$,children:$children$jscomp$289$$})};
$app$main$ui$dashboard$comments$comments_icon_STAR_$$=function($profile$jscomp$48_props_75202_tgroups$jscomp$1$$){var $on_show_comments$$=$profile$jscomp$48_props_75202_tgroups$jscomp$1$$.onShowComments;$profile$jscomp$48_props_75202_tgroups$jscomp$1$$=$profile$jscomp$48_props_75202_tgroups$jscomp$1$$.profile;var $threads_map$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comment_threads$$);$profile$jscomp$48_props_75202_tgroups$jscomp$1$$=$app$main$data$comments$group_threads_by_file_and_page$$($APP.$app$main$data$comments$apply_filters$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$profile$jscomp$48_props_75202_tgroups$jscomp$1$$,$APP.$cljs$core$reverse$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1737$modified_at$$,$APP.$cljs$core$vals$$($threads_map$jscomp$2$$)))));return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_comments__dashboard-comments-section",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",tabIndex:"0",className:"main_ui_dashboard_comments__comment-button",
"data-testid":"open-comments","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.notifications.view"),onClick:$on_show_comments$$,icon:"comments",children:$APP.$cljs$core$seq$$($profile$jscomp$48_props_75202_tgroups$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_comments__unread"}):null})})};
$app$main$ui$dashboard$comments$comments_section$$=function($map__75205_map__75205__$1_on_hide_comments_props_75204$$){$map__75205_map__75205__$1_on_hide_comments_props_75204$$=$APP.$rumext$v2$util$wrap_props$$($map__75205_map__75205__$1_on_hide_comments_props_75204$$);$map__75205_map__75205__$1_on_hide_comments_props_75204$$=$APP.$cljs$core$__destructure_map$$($map__75205_map__75205__$1_on_hide_comments_props_75204$$);var $profile$jscomp$49_tgroups$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75205_map__75205__$1_on_hide_comments_props_75204$$,
$APP.$cljs$cst$1914$profile$$),$on_read_all_team$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75205_map__75205__$1_on_hide_comments_props_75204$$,$APP.$cljs$cst$2492$team$$),$show_QMARK_$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75205_map__75205__$1_on_hide_comments_props_75204$$,$APP.$cljs$cst$5357$show_QMARK_$$);$map__75205_map__75205__$1_on_hide_comments_props_75204$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75205_map__75205__$1_on_hide_comments_props_75204$$,
$cljs$cst$5358$on_hide_comments$$);var $threads_map$jscomp$3$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comment_threads$$),$team_id$jscomp$136$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($on_read_all_team$jscomp$46$$);$profile$jscomp$49_tgroups$jscomp$2$$=$app$main$data$comments$group_threads_by_file_and_page$$($APP.$app$main$data$comments$apply_filters$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$profile$jscomp$49_tgroups$jscomp$2$$,$APP.$cljs$core$reverse$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1737$modified_at$$,
$APP.$cljs$core$vals$$($threads_map$jscomp$3$$)))));var $on_navigate$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($thread$jscomp$42$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($app$main$data$workspace$comments$navigate_to_comment_from_dashboard$$($thread$jscomp$42$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard"],null)))});$on_read_all_team$jscomp$46$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$136$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$mark_all_threads_as_read$$($team_id$jscomp$136$$))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$136$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$retrieve_unread_comment_threads$$($team_id$jscomp$136$$))});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($show_QMARK_$jscomp$4$$)],function(){return $APP.$cljs$core$truth_$$($show_QMARK_$jscomp$4$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"open-comment-notifications",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard"],
null))):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_comments__dashboard-comments-section",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$show_QMARK_$jscomp$4$$,"on-close":$map__75205_map__75205__$1_on_hide_comments_props_75204$$,"dropdown-id":"dashboard-comments",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_comments__dropdown main_ui_dashboard_comments__comments-section main_ui_dashboard_comments__comment-threads-section",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_comments__header",children:[(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_dashboard_comments__header-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.notifications")}),$APP.$cljs$core$seq$$($profile$jscomp$49_tgroups$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_dashboard_comments__mark-all-as-read-button main_ui_dashboard_comments__notifications-button",
variant:"action",tabIndex:$APP.$cljs$core$truth_$$($show_QMARK_$jscomp$4$$)?"0":"-1","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("label.mark-all-as-read"),onClick:$on_read_all_team$jscomp$46$$,icon:"tick"}):null,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_dashboard_comments__notifications-button",variant:"action",tabIndex:$APP.$cljs$core$truth_$$($show_QMARK_$jscomp$4$$)?"0":"-1","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),
onClick:$map__75205_map__75205__$1_on_hide_comments_props_75204$$,icon:"close"})]}),$APP.$cljs$core$seq$$($profile$jscomp$49_tgroups$jscomp$2$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_comments__thread-groups",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_dashboard_thread_group_STAR_$$,{group:$APP.$cljs$core$first$$($profile$jscomp$49_tgroups$jscomp$2$$),onThreadClick:$on_navigate$$,showFileName:!0}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$103$$,
$tgroup$jscomp$1$$){$out_arr__44124__auto__$jscomp$103$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_dashboard_thread_group_STAR_$$,{group:$tgroup$jscomp$1$$,onThreadClick:$on_navigate$$,showFileName:!0},$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($tgroup$jscomp$1$$)));return $out_arr__44124__auto__$jscomp$103$$},[],$APP.$cljs$core$rest$$($profile$jscomp$49_tgroups$jscomp$2$$))]}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_comments__thread-groups-placeholder",
children:[$app$main$ui$dashboard$comments$comments_icon_svg$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.no-comments-available")]})]})})})};
$app$main$ui$nitrate$nitrate_activation_success_modal$nitrate_activation_success_modal_STAR_$$=function($profile$jscomp$50_props_75203_svg_id$$){var $cancel_at_date_str_props$jscomp$284$$=$APP.$rumext$v2$util$wrap_props$$($profile$jscomp$50_props_75203_svg_id$$);$profile$jscomp$50_props_75203_svg_id$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);$profile$jscomp$50_props_75203_svg_id$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("light",$APP.$cljs$cst$3184$theme$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$50_props_75203_svg_id$$))?
"logo-subscription-light":"logo-subscription";$cancel_at_date_str_props$jscomp$284$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel_at_date_str_props$jscomp$284$$,$APP.$cljs$cst$3201$subscription$$),$APP.$cljs$cst$5359$cancel_at$$);$cancel_at_date_str_props$jscomp$284$$=$APP.$cljs$core$truth_$$($cancel_at_date_str_props$jscomp$284$$)?$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($cancel_at_date_str_props$jscomp$284$$,
"d MMMM, yyyy"):null;var $on_create_org$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$data$modal$hide_BANG_$$();return $app$main$data$nitrate$go_to_nitrate_cc_create_org$$()});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_nitrate_nitrate_activation_success_modal__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_nitrate_nitrate_activation_success_modal__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,
className:"main_ui_nitrate_nitrate_activation_success_modal__close-btn",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"close",size:"m"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_nitrate_nitrate_activation_success_modal__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_nitrate_nitrate_activation_success_modal__modal-start",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$raw_svg$raw_svg_STAR_$$,
{id:$profile$jscomp$50_props_75203_svg_id$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_nitrate_nitrate_activation_success_modal__modal-end",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_nitrate_nitrate_activation_success_modal__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.activation-success.title")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_nitrate_nitrate_activation_success_modal__modal-text-primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("nitrate.activation-success.active-until",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cancel_at_date_str_props$jscomp$284$$]))}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_nitrate_nitrate_activation_success_modal__modal-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.activation-success.manage-info")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_nitrate_nitrate_activation_success_modal__modal-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.activation-success.enjoy")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",onClick:$on_create_org$$,className:"main_ui_nitrate_nitrate_activation_success_modal__modal-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.activation-success.create-org")})]})]})]})})};
$app$main$ui$nitrate$nitrate_code_activation_modal$nitrate_code_activation_modal_STAR_$$=function(){var $value_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$error_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$on_change$jscomp$33$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$238$$){$APP.$cljs$core$reset_BANG_$$($error_STAR_$$,null);return $APP.$cljs$core$reset_BANG_$$($value_STAR_$$,(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$238$$))}),
$on_accept$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value_STAR_$$)],function(){var $code$jscomp$53$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($value_STAR_$$));return $APP.$cljs$core$seq$$($code$jscomp$53$$)?$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$342$$){$APP.$app$main$data$modal$hide_BANG_$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5360$nitrate_activation_success$$,$APP.$cljs$cst$3201$subscription$$,$result$jscomp$342$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$profile$refresh_profile$$()]))},function($JSCompiler_inline_result$jscomp$1461_code__$1$jscomp$4_error$jscomp$139$$){$JSCompiler_inline_result$jscomp$1461_code__$1$jscomp$4_error$jscomp$139$$=$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($JSCompiler_inline_result$jscomp$1461_code__$1$jscomp$4_error$jscomp$139$$));
a:switch($JSCompiler_inline_result$jscomp$1461_code__$1$jscomp$4_error$jscomp$139$$ instanceof $APP.$cljs$core$Keyword$$?$JSCompiler_inline_result$jscomp$1461_code__$1$jscomp$4_error$jscomp$139$$.$fqn$:null){case "expired-activation-code":$JSCompiler_inline_result$jscomp$1461_code__$1$jscomp$4_error$jscomp$139$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.activation-code.expired-error");break a;default:$JSCompiler_inline_result$jscomp$1461_code__$1$jscomp$4_error$jscomp$139$$=
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.activation-code.invalid-error")}return $APP.$cljs$core$reset_BANG_$$($error_STAR_$$,$JSCompiler_inline_result$jscomp$1461_code__$1$jscomp$4_error$jscomp$139$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5361$app_DOT_main_DOT_ui_DOT_nitrate_DOT_nitrate_code_activation_modal_SLASH_redeem_nitrate_activation_code$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5362$activation_code$$,$code$jscomp$53$$],
null))):null}),$on_key_down$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_accept$jscomp$8$$)],function($event$jscomp$239$$){var $and__5023__auto__$jscomp$inline_7983$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("Enter",$event$jscomp$239$$.key);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_7983$$?$event$jscomp$239$$.ctrlKey:$and__5023__auto__$jscomp$inline_7983$$)?$on_accept$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$?
$on_accept$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$239$$):$on_accept$jscomp$8$$($event$jscomp$239$$):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_nitrate_nitrate_code_activation_modal__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_nitrate_nitrate_code_activation_modal__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",className:"main_ui_nitrate_nitrate_code_activation_modal__close-btn",
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$APP.$app$main$data$modal$hide_BANG_$$,icon:"close"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_nitrate_nitrate_code_activation_modal__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_nitrate_nitrate_code_activation_modal__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.code-activation.title")})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_nitrate_nitrate_code_activation_modal__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_nitrate_nitrate_code_activation_modal__code-field "+($APP.$cljs$core$_deref$$($error_STAR_$$)!=null?"main_ui_nitrate_nitrate_code_activation_modal__invalid":""),children:[(0,$APP.$rumext$v2$jsx$$)("label",{className:"main_ui_nitrate_nitrate_code_activation_modal__code-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.code-activation.input-label")}),
(0,$APP.$rumext$v2$jsx$$)("textarea",{autoFocus:!0,value:$APP.$cljs$core$_deref$$($value_STAR_$$),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.code-activation.placeholder"),onChange:$on_change$jscomp$33$$,onKeyDown:$on_key_down$jscomp$8$$,className:"main_ui_nitrate_nitrate_code_activation_modal__code-textarea"}),$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($error_STAR_$$))?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_nitrate_nitrate_code_activation_modal__error-msg",
children:$APP.$cljs$core$_deref$$($error_STAR_$$)}):null]}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",disabled:$APP.$cljs$core$empty_QMARK_$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($value_STAR_$$))),value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.code-activation.submit"),onClick:$on_accept$jscomp$8$$,className:"main_ui_nitrate_nitrate_code_activation_modal__accept-btn "+($APP.$cljs$core$empty_QMARK_$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($value_STAR_$$)))?
"disabled":"")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_nitrate_nitrate_code_activation_modal__footer-text",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.code-activation.footer")," ",(0,$APP.$rumext$v2$jsx$$)("a",{href:"mailto:sales@nitrate.com",className:"main_ui_nitrate_nitrate_code_activation_modal__link",children:"sales@nitrate.com"})]})]})]})})};
$app$main$ui$nitrate$nitrate_form$nitrate_form_modal_STAR_$$=function($connectivity$jscomp$1_online_QMARK__props_75209$$){$connectivity$jscomp$1_online_QMARK__props_75209$$=$APP.$rumext$v2$util$wrap_props$$($connectivity$jscomp$1_online_QMARK__props_75209$$);$connectivity$jscomp$1_online_QMARK__props_75209$$=$APP.$cljs$cst$5366$licenses$$.$cljs$core$IFn$_invoke$arity$1$($connectivity$jscomp$1_online_QMARK__props_75209$$);var $profile$jscomp$51$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),
$initial$jscomp$33_on_click$jscomp$24$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3201$subscription$$,"yearly"],null)}),$form$jscomp$183$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$app$main$ui$nitrate$nitrate_form$schema_COLON_nitrate_form$$,$APP.$cljs$cst$5076$initial$$,$initial$jscomp$33_on_click$jscomp$24$$):
$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$nitrate$nitrate_form$schema_COLON_nitrate_form$$,$APP.$cljs$cst$5076$initial$$,$initial$jscomp$33_on_click$jscomp$24$$);$initial$jscomp$33_on_click$jscomp$24$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($form$jscomp$183$$)],function(){var $subscription$jscomp$inline_7985$$=$APP.$cljs$core$name$$($APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$183$$))));
return $APP.$app$main$data$nitrate$go_to_buy_nitrate_license$cljs$0core$0IFn$0_invoke$0arity$02$$($subscription$jscomp$inline_7985$$,null)});var $on_activate_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5363$nitrate_code_activation$$],null)))});
return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_nitrate_nitrate_form__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_nitrate_nitrate_form__modal-dialog main_ui_nitrate_nitrate_form__subscription-success",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_nitrate_nitrate_form__close-btn",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"close",size:"m"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_nitrate_nitrate_form__modal-success-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_nitrate_nitrate_form__modal-start",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$raw_svg$raw_svg_STAR_$$,{id:"nitrate-welcome"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_nitrate_nitrate_form__modal-end",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_nitrate_nitrate_form__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.form.title")}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_nitrate_nitrate_form__modal-text-large",children:"Prow scuttle parrel provost."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_nitrate_nitrate_form__modal-text-large",children:"Sail ho shrouds spirits boom mizzenmast yardarm. Pinnace holystone mizzenmast quarter crow's nest nipperkin grog yardarm hempen halter furl."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_nitrate_nitrate_form__modal-text-large",children:"Deadlights jack lad schooner scallywag dance the hempen jig carouser broadside cable strike colors."}),
$APP.$cljs$core$truth_$$($connectivity$jscomp$1_online_QMARK__props_75209$$)?$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,{form:$form$jscomp$183$$,children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_nitrate_nitrate_form__modal-text-large",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$radio_buttons$$,{options:new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,
[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.form.billing-monthly"),$APP.$cljs$cst$260$value$$,"monthly"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.form.billing-yearly"),$APP.$cljs$cst$260$value$$,"yearly"],null)],null),name:$APP.$cljs$cst$3201$subscription$$,"class":"main_ui_nitrate_nitrate_form__radio-btns"})}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_nitrate_nitrate_form__modal-text-large main_ui_nitrate_nitrate_form__modal-buttons-section",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_nitrate_nitrate_form__modal-buttons-section",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",onClick:$initial$jscomp$33_on_click$jscomp$24$$,className:"main_ui_nitrate_nitrate_form__modal-button",children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$51$$))?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.form.upgrade"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.form.try-free")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_nitrate_nitrate_form__modal-text-small main_ui_nitrate_nitrate_form__modal-info",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.form.cancel-anytime")})]})}),(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_nitrate_nitrate_form__modal-text-medium",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.form.have-code"),
" ",(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$on_activate_click$$,className:"main_ui_nitrate_nitrate_form__link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.form.enter-code")})]}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_nitrate_nitrate_form__modal-text-medium",children:(0,$APP.$rumext$v2$jsx$$)("a",{href:$APP.$app$main$data$nitrate$go_to_subscription_url$$,className:"main_ui_nitrate_nitrate_form__link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.form.see-plan")})})]}):
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_nitrate_nitrate_form__contact",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_nitrate_nitrate_form__modal-text-large",children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$51$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.form.contact-upgrade"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.form.contact-trial")}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_nitrate_nitrate_form__modal-text-large",children:(0,$APP.$rumext$v2$jsx$$)("a",{href:"mailto:sales@penpot.app",className:"main_ui_nitrate_nitrate_form__link",children:"sales@penpot.app"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_nitrate_nitrate_form__activation-code",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_nitrate_nitrate_form__modal-text-large",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.form.have-code")}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_nitrate_nitrate_form__modal-text-large",children:(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$on_activate_click$$,className:"main_ui_nitrate_nitrate_form__link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.form.enter-code")})})]})]})]})]})]})})};
$app$main$ui$dashboard$sidebar$sidebar_project_STAR_$$=function($dstate_local$jscomp$27_props_75211$$){var $is_selected$jscomp$3$$=$dstate_local$jscomp$27_props_75211$$.isSelected,$item$jscomp$115$$=$dstate_local$jscomp$27_props_75211$$.item;$dstate_local$jscomp$27_props_75211$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$dashboard_local$$);var $selected_files$$=$APP.$cljs$cst$2183$selected_files$$.$cljs$core$IFn$_invoke$arity$1$($dstate_local$jscomp$27_props_75211$$),$selected_project$$=$APP.$cljs$cst$2184$selected_project$$.$cljs$core$IFn$_invoke$arity$1$($dstate_local$jscomp$27_props_75211$$),
$edit_id$jscomp$2$$=$APP.$cljs$cst$4936$project_for_edit$$.$cljs$core$IFn$_invoke$arity$1$($dstate_local$jscomp$27_props_75211$$),$local_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$4927$menu_open$$,!1,$APP.$cljs$cst$4928$menu_pos$$,null,$cljs$cst$5367$edition_QMARK_$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$115$$),
$edit_id$jscomp$2$$),$APP.$cljs$cst$5368$dragging_QMARK_$$,!1],null)});$dstate_local$jscomp$27_props_75211$$=$APP.$cljs$core$_deref$$($local_STAR_$$);var $project_id$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$115$$,$APP.$cljs$cst$266$id$$),$on_click$jscomp$25$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$34$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2181$project_id$$,
$project_id$jscomp$34$$])))}),$on_key_down$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$34$$)],function($event$jscomp$240$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$240$$))?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2181$project_id$$,
$project_id$jscomp$34$$]))),$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $temp__5825__auto__$jscomp$314$$=$APP.$app$util$dom$get_element$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($project_id$jscomp$34$$));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$314$$)?($APP.$app$util$dom$set_attribute_BANG_$$($temp__5825__auto__$jscomp$314$$,"tabindex","0"),$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$314$$),$APP.$app$util$dom$set_attribute_BANG_$$($temp__5825__auto__$jscomp$314$$,
"tabindex","-1")):null})):null}),$on_menu_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$241$$){var $position$jscomp$186$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$241$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$241$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($local_STAR_$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4927$menu_open$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4928$menu_pos$$,
$position$jscomp$186$$]))}),$on_menu_close$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local_STAR_$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4927$menu_open$$,!1)}),$on_edit_open$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local_STAR_$$,$APP.$cljs$core$assoc$$,$cljs$cst$5367$edition_QMARK_$$,!0)}),$on_edit$jscomp$5$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($item$jscomp$115$$)],function($name$jscomp$435$$){$APP.$cuerdas$core$blank_QMARK_$$($name$jscomp$435$$)||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$dashboard$rename_project$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($item$jscomp$115$$,$APP.$cljs$cst$725$name$$,$name$jscomp$435$$)),new $APP.$cljs$core$PersistentArrayMap$$(null,1,
[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard:sidebar"],null)));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local_STAR_$$,$APP.$cljs$core$assoc$$,$cljs$cst$5367$edition_QMARK_$$,!1)}),$on_drag_enter$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_project$$)],function($e$jscomp$332$$){return $APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$332$$,"penpot/files"))?
($APP.$app$util$dom$prevent_default$$($e$jscomp$332$$),$APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($e$jscomp$332$$))?null:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected_project$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$115$$))?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local_STAR_$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5368$dragging_QMARK_$$,!0):null):null}),$on_drag_over$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$333$$){return $APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$333$$,
"penpot/files"))?$APP.$app$util$dom$prevent_default$$($e$jscomp$333$$):null}),$on_drag_leave$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$334$$){return $APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($e$jscomp$334$$))?null:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local_STAR_$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5368$dragging_QMARK_$$,!1)}),$on_drop_success$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$34$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$common$go_to_dashboard_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2181$project_id$$,$project_id$jscomp$34$$])),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.success-move-file"))]))}),
$on_drop$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($item$jscomp$115$$),$APP.$rumext$v2$adapt$$($selected_files$$)],function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local_STAR_$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5368$dragging_QMARK_$$,!1);if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected_project$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$115$$))){var $data$jscomp$456$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1723$ids$$,$selected_files$$,$APP.$cljs$cst$2181$project_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$115$$)],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$dashboard$move_files$$($APP.$cljs$core$with_meta$$($data$jscomp$456$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2488$on_success$$,$on_drop_success$$],null))))}return null});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)("li",{onDoubleClick:$on_edit_open$$,onDragEnter:$on_drag_enter$jscomp$1$$,tabIndex:"0",onDragLeave:$on_drag_leave$jscomp$1$$,className:"main_ui_dashboard_sidebar__project-element main_ui_dashboard_sidebar__sidebar-nav-item "+($APP.$cljs$core$truth_$$($is_selected$jscomp$3$$)?"main_ui_dashboard_sidebar__current":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$cst$5368$dragging_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($dstate_local$jscomp$27_props_75211$$))?"main_ui_dashboard_sidebar__dragging":
""),children:$APP.$cljs$core$truth_$$($cljs$cst$5367$edition_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($dstate_local$jscomp$27_props_75211$$))?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$dashboard$inline_edition$inline_edition$$,{content:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$115$$),"on-end":$on_edit$jscomp$5$$}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__element-title",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$115$$)}),
onContextMenu:$on_menu_click$$,onDrop:$on_drop$jscomp$2$$,onDragOver:$on_drag_over$jscomp$1$$,onClick:$on_click$jscomp$25$$,onKeyDown:$on_key_down$jscomp$9$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$dashboard$project_menu$project_menu_STAR_$$,{project:$item$jscomp$115$$,show:$APP.$cljs$cst$4927$menu_open$$.$cljs$core$IFn$_invoke$arity$1$($dstate_local$jscomp$27_props_75211$$),left:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4928$menu_pos$$.$cljs$core$IFn$_invoke$arity$1$($dstate_local$jscomp$27_props_75211$$)),
top:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4928$menu_pos$$.$cljs$core$IFn$_invoke$arity$1$($dstate_local$jscomp$27_props_75211$$)),onEdit:$on_edit_open$$,onClose:$on_menu_close$$})]})};
$app$main$ui$dashboard$sidebar$sidebar_search_STAR_$$=function($on_search_blur_props_75213$$){var $on_key_press$jscomp$1_team_id$jscomp$137$$=$on_search_blur_props_75213$$.teamId,$search_term__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($on_search_blur_props_75213$$.searchTerm,""),$focused_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$emit_BANG_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$goog$functions$debounce$$($APP.$app$main$store$emit_BANG_$$,
500)});$on_search_blur_props_75213$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($focused_QMARK_$$,!1)});var $on_search_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($G__75215_event$jscomp$242_value$jscomp$783$$){$G__75215_event$jscomp$242_value$jscomp$783$$=(0,$APP.$app$util$dom$get_target_val$$)($G__75215_event$jscomp$242_value$jscomp$783$$);$G__75215_event$jscomp$242_value$jscomp$783$$=$app$main$data$common$go_to_dashboard_search$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2513$term$$,
$G__75215_event$jscomp$242_value$jscomp$783$$]));return $emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($G__75215_event$jscomp$242_value$jscomp$783$$):$emit_BANG_$$($G__75215_event$jscomp$242_value$jscomp$783$$)}),$on_clear_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_key_press$jscomp$1_team_id$jscomp$137$$)],function($e$jscomp$335$$){var $G__75216_75330_search_input$$=$app$main$data$common$go_to_dashboard_search$$();
$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($G__75216_75330_search_input$$):$emit_BANG_$$($G__75216_75330_search_input$$);$G__75216_75330_search_input$$=$APP.$goog$dom$getElement$$("search-input");$G__75216_75330_search_input$$!=null&&($G__75216_75330_search_input$$.value="");$APP.$app$util$dom$focus_BANG_$$($G__75216_75330_search_input$$);$APP.$app$util$dom$prevent_default$$($e$jscomp$335$$);return $APP.$app$util$dom$stop_propagation$$($e$jscomp$335$$)});
$on_key_press$jscomp$1_team_id$jscomp$137$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$336$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($e$jscomp$336$$))?($APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $search_title$$=$APP.$goog$dom$getElement$$("dashboard-search-title");return $APP.$cljs$core$truth_$$($search_title$$)?($APP.$app$util$dom$set_attribute_BANG_$$($search_title$$,"tabindex","0"),$APP.$app$util$dom$focus_BANG_$$($search_title$$),
$APP.$app$util$dom$set_attribute_BANG_$$($search_title$$,"tabindex","-1")):null}),$APP.$app$util$dom$prevent_default$$($e$jscomp$336$$),$APP.$app$util$dom$stop_propagation$$($e$jscomp$336$$)):null});var $handle_clear_search$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_clear_click$$)],function($event$jscomp$243$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$243$$))?$on_clear_click$$.$cljs$core$IFn$_invoke$arity$1$?
$on_clear_click$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$243$$):$on_clear_click$$($event$jscomp$243$$):null});return(0,$APP.$rumext$v2$jsxs$$)("form",{className:"main_ui_dashboard_sidebar__sidebar-search",children:[(0,$APP.$rumext$v2$jsx$$)("input",{onKeyPress:$on_key_press$jscomp$1_team_id$jscomp$137$$,onChange:$on_search_change$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.search-placeholder"),className:"main_ui_dashboard_sidebar__input-text",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.search-placeholder"),
id:"search-input",onBlur:$on_search_blur_props_75213$$,autoComplete:"off",type:"text",ref:function($p1__75212_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__75212_SHARP_$$)?$p1__75212_SHARP_$$.value=$search_term__$1$$:null},defaultValue:$search_term__$1$$},"images-search-box"),$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1026$$=$APP.$cljs$core$_deref$$($focused_QMARK_$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1026$$)?$or__5025__auto__$jscomp$1026$$:$APP.$cljs$core$seq$$($search_term__$1$$)}())?
(0,$APP.$rumext$v2$jsx$$)("button",{tabIndex:"0","aria-label":"dashboard-clear-search",onClick:$on_clear_click$$,onKeyDown:$handle_clear_search$$,className:"main_ui_dashboard_sidebar__search-btn main_ui_dashboard_sidebar__clear-search-btn",children:$app$main$ui$dashboard$sidebar$clear_search_icon$$}):(0,$APP.$rumext$v2$jsx$$)("button",{"aria-label":"dashboard-search",onClick:$on_clear_click$$,className:"main_ui_dashboard_sidebar__search-btn",children:$app$main$ui$dashboard$sidebar$search_icon$$})]})};
$app$main$ui$dashboard$sidebar$organizations_selector_dropdown_STAR_$$=function($on_create_org_click_props_75220$$){var $profile$jscomp$52$$=void 0,$organization$jscomp$5$$=void 0,$organizations$jscomp$2_organizations__$1$jscomp$1$$=void 0,$props$jscomp$285$$=void 0;({organization:$organization$jscomp$5$$,organizations:$organizations$jscomp$2_organizations__$1$jscomp$1$$,profile:$profile$jscomp$52$$,...$props$jscomp$285$$}=$on_create_org_click_props_75220$$);var $on_org_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$244_team_id$jscomp$138$$){$event$jscomp$244_team_id$jscomp$138$$=
$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$244_team_id$jscomp$138$$),"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,$event$jscomp$244_team_id$jscomp$138$$])))});$on_create_org_click_props_75220$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$52$$)],
function(){return $APP.$app$main$data$nitrate$is_valid_license_QMARK_$$($profile$jscomp$52$$)?$app$main$data$nitrate$go_to_nitrate_cc_create_org$$():$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$nitrate$show_nitrate_popup$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5068$nitrate_form$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$))});var $on_go_to_cc_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($organization$jscomp$5$$),
$APP.$rumext$v2$adapt$$($profile$jscomp$52$$)],function(){var $JSCompiler_inline_result$jscomp$1463_and__5023__auto__$jscomp$inline_7987$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($organization$jscomp$5$$);$JSCompiler_inline_result$jscomp$1463_and__5023__auto__$jscomp$inline_7987$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1463_and__5023__auto__$jscomp$inline_7987$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$52$$),
$APP.$cljs$cst$3324$owner_id$$.$cljs$core$IFn$_invoke$arity$1$($organization$jscomp$5$$)):$JSCompiler_inline_result$jscomp$1463_and__5023__auto__$jscomp$inline_7987$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1463_and__5023__auto__$jscomp$inline_7987$$)?$APP.$app$main$data$nitrate$go_to_nitrate_cc$$.$cljs$core$IFn$_invoke$arity$1$($organization$jscomp$5$$):$APP.$app$main$data$nitrate$go_to_nitrate_cc$$.$cljs$core$IFn$_invoke$arity$0$()}),$empty_org$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__75217_SHARP_$$){return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__75217_SHARP_$$)==
null},$organizations$jscomp$2_organizations__$1$jscomp$1$$),$default_team_id$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1027$$=$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($empty_org$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1027$$)?$or__5025__auto__$jscomp$1027$$:$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$52$$)}();$organizations$jscomp$2_organizations__$1$jscomp$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$organizations$jscomp$2_organizations__$1$jscomp$1$$);var $is_valid_license_QMARK_$$=$APP.$app$main$data$nitrate$is_valid_license_QMARK_$$($profile$jscomp$52$$);return $APP.$rumext$v2$create_element$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,$props$jscomp$285$$,$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$on_org_click$$,"data-value":$default_team_id$jscomp$2$$,className:"main_ui_dashboard_sidebar__org-dropdown-item",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__org-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$raw_svg$raw_svg_STAR_$$,{id:"penpot-logo-icon"})}),"Penpot",$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($default_team_id$jscomp$2$$,$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($organization$jscomp$5$$))?$app$main$ui$dashboard$sidebar$tick_icon$$:null]}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$104$$,
$org_item$$){$out_arr__44124__auto__$jscomp$104$$.push($APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$on_org_click$$,"data-value":$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($org_item$$),className:"main_ui_dashboard_sidebar__org-dropdown-item",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$org_avatar$org_avatar_STAR_$$,{org:$org_item$$,size:"xxl"}),(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($org_item$$),
className:"main_ui_dashboard_sidebar__team-text",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($org_item$$)}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($org_item$$),$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($organization$jscomp$5$$))?$app$main$ui$dashboard$sidebar$tick_icon$$:null]},$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($org_item$$))));
return $out_arr__44124__auto__$jscomp$104$$},[],$organizations$jscomp$2_organizations__$1$jscomp$1$$),(0,$APP.$rumext$v2$jsx$$)("hr",{role:"separator",className:"main_ui_dashboard_sidebar__team-separator"}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$on_create_org_click_props_75220$$,className:"main_ui_dashboard_sidebar__org-dropdown-item main_ui_dashboard_sidebar__action",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__icon-wrapper",
children:$app$main$ui$dashboard$sidebar$add_org_icon$$}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__team-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.create-new-org")})]}),$is_valid_license_QMARK_$$?$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$on_go_to_cc_click$$,className:"main_ui_dashboard_sidebar__org-dropdown-item main_ui_dashboard_sidebar__action",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_dashboard_sidebar__icon-wrapper",children:$app$main$ui$dashboard$sidebar$arrow_up_right_icon$$}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__team-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.go-to-control-center")})]}):null)};
$app$main$ui$dashboard$sidebar$teams_selector_dropdown_STAR_$$=function($default_team_id$jscomp$3_props_75235$$){var $profile$jscomp$53$$=void 0,$teams$jscomp$11$$=void 0,$team$jscomp$47$$=void 0,$props$jscomp$286$$=void 0;({team:$team$jscomp$47$$,profile:$profile$jscomp$53$$,teams:$teams$jscomp$11$$,...$props$jscomp$286$$}=$default_team_id$jscomp$3_props_75235$$);$default_team_id$jscomp$3_props_75235$$=function(){var $or__5025__auto__$jscomp$1028$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4902$is_default$$,
$APP.$cljs$core$vals$$($teams$jscomp$11$$))));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1028$$)?$or__5025__auto__$jscomp$1028$$:$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$53$$)}();var $teams__$1$jscomp$2$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($teams$jscomp$11$$,$default_team_id$jscomp$3_props_75235$$),$on_create_team_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$47$$)],
function(){var $JSCompiler_inline_result$jscomp$1464_and__5023__auto__$jscomp$inline_7989_params$jscomp$398$$=($JSCompiler_inline_result$jscomp$1464_and__5023__auto__$jscomp$inline_7989_params$jscomp$398$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1233$nitrate$$))?$APP.$cljs$cst$3256$organization_id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$47$$):$JSCompiler_inline_result$jscomp$1464_and__5023__auto__$jscomp$inline_7989_params$jscomp$398$$;$JSCompiler_inline_result$jscomp$1464_and__5023__auto__$jscomp$inline_7989_params$jscomp$398$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1464_and__5023__auto__$jscomp$inline_7989_params$jscomp$398$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3256$organization_id$$,$APP.$cljs$cst$3256$organization_id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$47$$)],null):$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5107$team_form$$,
$JSCompiler_inline_result$jscomp$1464_and__5023__auto__$jscomp$inline_7989_params$jscomp$398$$))}),$on_team_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$245_team_id$jscomp$139$$){$event$jscomp$245_team_id$jscomp$139$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$245_team_id$jscomp$139$$),"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,
$event$jscomp$245_team_id$jscomp$139$$])))});return $APP.$rumext$v2$create_element$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,$props$jscomp$286$$,$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$on_team_click$$,"data-value":$default_team_id$jscomp$3_props_75235$$,className:"main_ui_dashboard_sidebar__team-dropdown-item",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__penpot-icon",children:$APP.$app$main$ui$icons$logo_icon$$}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__team-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot")}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($default_team_id$jscomp$3_props_75235$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$47$$))?$app$main$ui$dashboard$sidebar$tick_icon$$:null]}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$105$$,
$team_item$$){var $JSCompiler_temp_const$jscomp$1467$$=$out_arr__44124__auto__$jscomp$105$$.push,$JSCompiler_temp_const$jscomp$1466$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team_item$$),$JSCompiler_temp_const$jscomp$1465$$=(0,$APP.$rumext$v2$jsx$$)("img",{src:$APP.$app$config$resolve_team_photo_url$$($team_item$$),alt:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team_item$$),className:"main_ui_dashboard_sidebar__team-picture"}),$G__75237$jscomp$inline_7992_JSCompiler_inline_result$jscomp$1469_and__5023__auto__$jscomp$inline_7991$$;
if($G__75237$jscomp$inline_7992_JSCompiler_inline_result$jscomp$1469_and__5023__auto__$jscomp$inline_7991$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1223$subscriptions$$)){$G__75237$jscomp$inline_7992_JSCompiler_inline_result$jscomp$1469_and__5023__auto__$jscomp$inline_7991$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($team_item$$));var $fexpr__75236$jscomp$inline_7993$$=new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,["enterprise",null,"unlimited",null],null),null);$G__75237$jscomp$inline_7992_JSCompiler_inline_result$jscomp$1469_and__5023__auto__$jscomp$inline_7991$$=$fexpr__75236$jscomp$inline_7993$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__75236$jscomp$inline_7993$$.$cljs$core$IFn$_invoke$arity$1$($G__75237$jscomp$inline_7992_JSCompiler_inline_result$jscomp$1469_and__5023__auto__$jscomp$inline_7991$$):$fexpr__75236$jscomp$inline_7993$$($G__75237$jscomp$inline_7992_JSCompiler_inline_result$jscomp$1469_and__5023__auto__$jscomp$inline_7991$$)}$JSCompiler_temp_const$jscomp$1467$$.call($out_arr__44124__auto__$jscomp$105$$,
$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$on_team_click$$,"data-value":$JSCompiler_temp_const$jscomp$1466$$,className:"main_ui_dashboard_sidebar__team-dropdown-item",children:[$JSCompiler_temp_const$jscomp$1465$$,$APP.$cljs$core$truth_$$($G__75237$jscomp$inline_7992_JSCompiler_inline_result$jscomp$1469_and__5023__auto__$jscomp$inline_7991$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_sidebar__team-text-with-icon",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team_item$$),className:"main_ui_dashboard_sidebar__team-text",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team_item$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$menu_team_icon_STAR_$$,{subscriptionType:$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($APP.$cljs$cst$3201$subscription$$.$cljs$core$IFn$_invoke$arity$1$($team_item$$))})]}):(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team_item$$),
className:"main_ui_dashboard_sidebar__team-text",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team_item$$)}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team_item$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$47$$))?$app$main$ui$dashboard$sidebar$tick_icon$$:null]},$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team_item$$))));
return $out_arr__44124__auto__$jscomp$105$$},[],$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4902$is_default$$,$APP.$cljs$core$vals$$($teams__$1$jscomp$2$$))),(0,$APP.$rumext$v2$jsx$$)("hr",{role:"separator",className:"main_ui_dashboard_sidebar__team-separator"}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$on_create_team_click$$,className:"main_ui_dashboard_sidebar__team-dropdown-item main_ui_dashboard_sidebar__action",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__icon-wrapper",children:$app$main$ui$dashboard$sidebar$add_icon$$}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__team-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.create-new-team")})]}))};
$app$main$ui$dashboard$sidebar$team_options_dropdown_STAR_$$=function($members$jscomp$12_props_75238$$){function $on_error$jscomp$64$$($error$jscomp$140$$){var $expr__75241$$=$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($error$jscomp$140$$));return $APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5369$only_owner_can_delete_team$$,$expr__75241$$):$APP.$cljs$core$_EQ_$$($cljs$cst$5369$only_owner_can_delete_team$$,
$expr__75241$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.team-leave.only-owner-can-delete"))):$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5136$no_enough_members_for_leave$$,$expr__75241$$):$APP.$cljs$core$_EQ_$$($cljs$cst$5136$no_enough_members_for_leave$$,$expr__75241$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.team-leave.insufficient-members"))):
$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5137$member_does_not_exist$$,$expr__75241$$):$APP.$cljs$core$_EQ_$$($cljs$cst$5137$member_does_not_exist$$,$expr__75241$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.team-leave.member-does-not-exists"))):$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5138$owner_cant_leave_team$$,$expr__75241$$):$APP.$cljs$core$_EQ_$$($cljs$cst$5138$owner_cant_leave_team$$,$expr__75241$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.team-leave.owner-cant-leave"))):$APP.$beicon$v2$core$throw$0$$($error$jscomp$140$$)}function $on_success$jscomp$51$$(){var $team_id$jscomp$140$$=$APP.$cljs$cst$2496$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$54$$);
return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$140$$])),$APP.$app$main$data$modal$hide$$())}function $go_webhooks$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_dashboard_webhooks$$())}var $profile$jscomp$54$$=void 0,$team$jscomp$48$$=void 0,$props$jscomp$287$$=
void 0;({team:$team$jscomp$48$$,profile:$profile$jscomp$54$$,...$props$jscomp$287$$}=$members$jscomp$12_props_75238$$);$members$jscomp$12_props_75238$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$48$$,$APP.$cljs$cst$3264$members$$);var $permissions$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$48$$,$APP.$cljs$cst$1722$permissions$$),$can_rename_QMARK_$$=function(){var $or__5025__auto__$jscomp$1029$$=$APP.$cljs$cst$1598$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$29$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1029$$)?$or__5025__auto__$jscomp$1029$$:$APP.$cljs$cst$1597$is_admin$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$29$$)}(),$leave_fn$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_success$jscomp$51$$),$APP.$rumext$v2$adapt$$($on_error$jscomp$64$$)],function($member_id$jscomp$7_params$jscomp$399$$){var $G__75243$jscomp$inline_7995$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;$member_id$jscomp$7_params$jscomp$399$$=
$APP.$cljs$core$uuid_QMARK_$$($member_id$jscomp$7_params$jscomp$399$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__75243$jscomp$inline_7995$$,$cljs$cst$3296$reassign_to$$,$member_id$jscomp$7_params$jscomp$399$$):$G__75243$jscomp$inline_7995$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$leave_current_team$$($APP.$cljs$core$with_meta$$($member_id$jscomp$7_params$jscomp$399$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,
$on_success$jscomp$51$$,$APP.$cljs$cst$1295$on_error$$,$on_error$jscomp$64$$],null))))}),$delete_fn$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$48$$),$APP.$rumext$v2$adapt$$($on_success$jscomp$51$$),$APP.$rumext$v2$adapt$$($on_error$jscomp$64$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$delete_team$$($APP.$cljs$core$with_meta$$($team$jscomp$48$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2488$on_success$$,$on_success$jscomp$51$$,$APP.$cljs$cst$1295$on_error$$,$on_error$jscomp$64$$],null))))}),$on_rename_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$48$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5107$team_form$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2492$team$$,
$team$jscomp$48$$],null)))}),$on_leave_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($leave_fn$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-confirm.title"),
$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-confirm.message"),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-confirm.accept"),$APP.$cljs$cst$2479$on_accept$$,$leave_fn$$],null)))}),$on_leave_as_owner_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$48$$),$APP.$rumext$v2$adapt$$($profile$jscomp$54$$),$APP.$rumext$v2$adapt$$($leave_fn$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$5100$leave_and_reassign$$,$APP.$cljs$cst$1914$profile$$,$profile$jscomp$54$$,$APP.$cljs$cst$2492$team$$,$team$jscomp$48$$,
$APP.$cljs$cst$924$accept$$,$leave_fn$$],null))]))}),$leave_and_close$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$48$$),$APP.$rumext$v2$adapt$$($delete_fn$jscomp$1$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-confirm.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.leave-and-close-confirm.message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$48$$)])),$APP.$cljs$cst$5135$scd_message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-and-close-confirm.hint"),$APP.$cljs$cst$2476$accept_label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-confirm.accept"),$APP.$cljs$cst$2479$on_accept$$,$delete_fn$jscomp$1$$],null)))}),$on_delete_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$48$$),$APP.$rumext$v2$adapt$$($delete_fn$jscomp$1$$)],function(){var $message$jscomp$112$$=$APP.$cljs$cst$3256$organization_id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$48$$)!=null?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-org-team-confirm.message",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3257$organization_name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$48$$)])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-team-confirm.message");return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-team-confirm.title"),$APP.$cljs$cst$141$message$$,$message$jscomp$112$$,$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-team-confirm.accept"),$APP.$cljs$cst$2479$on_accept$$,$delete_fn$jscomp$1$$],null)))});return $APP.$rumext$v2$create_element$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,$props$jscomp$287$$,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_members$$())},className:"main_ui_dashboard_sidebar__team-options-item","data-testid":"team-members",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.members")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_dashboard_invitations$$())},
className:"main_ui_dashboard_sidebar__team-options-item","data-testid":"team-invitations",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.invitations")}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1215$webhooks$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$go_webhooks$$,className:"main_ui_dashboard_sidebar__team-options-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.webhooks")}):
null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_dashboard_settings$$())},className:"main_ui_dashboard_sidebar__team-options-item","data-testid":"team-settings",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.settings")}),(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_dashboard_sidebar__team-option-separator"}),
$APP.$cljs$core$truth_$$($can_rename_QMARK_$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$on_rename_clicked$$,className:"main_ui_dashboard_sidebar__team-options-item","data-testid":"rename-team",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename")}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($members$jscomp$12_props_75238$$),1)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{onClick:$leave_and_close$$,className:"main_ui_dashboard_sidebar__team-options-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.leave-team")}):$APP.$cljs$core$truth_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$48$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1722$permissions$$,$APP.$cljs$cst$1598$is_owner$$],null)))?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{onClick:$on_leave_as_owner_clicked$$,className:"main_ui_dashboard_sidebar__team-options-item","data-testid":"leave-team",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.leave-team")}):$APP.$cljs$core$count$$($members$jscomp$12_props_75238$$)>1?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$on_leave_clicked$$,className:"main_ui_dashboard_sidebar__team-options-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.leave-team")}):
null,$APP.$cljs$core$truth_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$48$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1722$permissions$$,$APP.$cljs$cst$1598$is_owner$$],null)))?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$on_delete_clicked$$,className:"main_ui_dashboard_sidebar__team-options-item main_ui_dashboard_sidebar__warning","data-testid":"delete-team",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-team")}):null)};
$app$main$ui$dashboard$sidebar$org_options_dropdown_STAR_$$=function($num_teams_to_leave_on_leave_clicked$jscomp$1_props_75249$$){var $profile$jscomp$55$$=void 0,$organization$jscomp$6$$=void 0,$teams$jscomp$12$$=void 0,$props$jscomp$288$$=void 0;({organization:$organization$jscomp$6$$,profile:$profile$jscomp$55$$,teams:$teams$jscomp$12$$,...$props$jscomp$288$$}=$num_teams_to_leave_on_leave_clicked$jscomp$1_props_75249$$);var $default_team_id$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($teams$jscomp$12$$)],
function(){return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4902$is_default$$,$teams$jscomp$12$$)))}),$non_default_teams$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($teams$jscomp$12$$)],function(){return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4902$is_default$$,$teams$jscomp$12$$)}),$owned_teams$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($non_default_teams$$)],
function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75244_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__75244_SHARP_$$,$APP.$cljs$cst$1722$permissions$$),$APP.$cljs$cst$1598$is_owner$$)},$non_default_teams$$)}),$not_owned_teams$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($non_default_teams$$)],function(){return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75245_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__75245_SHARP_$$,
$APP.$cljs$cst$1722$permissions$$),$APP.$cljs$cst$1598$is_owner$$)},$non_default_teams$$)}),$teams_to_delete$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($owned_teams$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75246_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($APP.$cljs$cst$3264$members$$.$cljs$core$IFn$_invoke$arity$1$($p1__75246_SHARP_$$)),1)},
$owned_teams$$)}),$teams_to_transfer$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($owned_teams$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75247_SHARP_$$){return $APP.$cljs$core$count$$($APP.$cljs$cst$3264$members$$.$cljs$core$IFn$_invoke$arity$1$($p1__75247_SHARP_$$))>1},$owned_teams$$)});$num_teams_to_leave_on_leave_clicked$jscomp$1_props_75249$$=$APP.$cljs$core$count$$($teams_to_transfer$jscomp$3$$)+
$APP.$cljs$core$count$$($not_owned_teams$$);var $num_teams_to_delete$jscomp$3$$=$APP.$cljs$core$count$$($teams_to_delete$jscomp$2$$),$num_teams_to_transfer$$=$APP.$cljs$core$count$$($teams_to_transfer$jscomp$3$$),$on_error$jscomp$65$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($error$jscomp$141$$){var $code$jscomp$55_temp__5823__auto__$jscomp$212$$=$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($error$jscomp$141$$));$code$jscomp$55_temp__5823__auto__$jscomp$212$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$5370$not_valid_teams$$,"errors.org-leave.no-valid-teams",$cljs$cst$5371$org_owner_cannot_leave$$,"errors.org-leave.org-owner-cannot-leave",$cljs$cst$5369$only_owner_can_delete_team$$,"errors.team-leave.only-owner-can-delete",$cljs$cst$5136$no_enough_members_for_leave$$,"errors.team-leave.insufficient-members",$cljs$cst$5137$member_does_not_exist$$,"errors.team-leave.member-does-not-exists",
$cljs$cst$5138$owner_cant_leave_team$$,"errors.team-leave.owner-cant-leave"],null),$code$jscomp$55_temp__5823__auto__$jscomp$212$$);return $APP.$cljs$core$truth_$$($code$jscomp$55_temp__5823__auto__$jscomp$212$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$fetch_teams$$(),$APP.$app$main$data$modal$hide$$(),$APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($code$jscomp$55_temp__5823__auto__$jscomp$212$$))):$APP.$beicon$v2$core$throw$0$$($error$jscomp$141$$)}),
$leave_fn$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_error$jscomp$65$$),$APP.$rumext$v2$adapt$$($organization$jscomp$6$$),$APP.$rumext$v2$adapt$$($default_team_id$jscomp$4$$),$APP.$rumext$v2$adapt$$($not_owned_teams$$),$APP.$rumext$v2$adapt$$($teams_to_delete$jscomp$2$$)],function($map__75252__$1_p__75251_teams_to_leave$jscomp$2$$){$map__75252__$1_p__75251_teams_to_leave$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__75252__$1_p__75251_teams_to_leave$jscomp$2$$);
var $teams_to_transfer__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75252__$1_p__75251_teams_to_leave$jscomp$2$$,$cljs$cst$5101$teams_to_transfer$$);$map__75252__$1_p__75251_teams_to_leave$jscomp$2$$=function(){var $G__75253__$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75248_SHARP_$$){return $APP.$cljs$core$select_keys$$($p1__75248_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$],
null))},$not_owned_teams$$);return $APP.$cljs$core$seq$$($teams_to_transfer__$1$jscomp$1$$)?$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($teams_to_transfer__$1$jscomp$1$$,$G__75253__$1$$):$G__75253__$1$$}();var $teams_to_delete__$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$teams_to_delete$jscomp$2$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$nitrate$leave_org$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($organization$jscomp$6$$),$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($organization$jscomp$6$$),$APP.$cljs$cst$2496$default_team_id$$,$default_team_id$jscomp$4$$,$cljs$cst$5059$teams_to_delete$$,$teams_to_delete__$1$$,$cljs$cst$5060$teams_to_leave$$,$map__75252__$1_p__75251_teams_to_leave$jscomp$2$$,$APP.$cljs$cst$1295$on_error$$,$on_error$jscomp$65$$],null)))});$num_teams_to_leave_on_leave_clicked$jscomp$1_props_75249$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($leave_fn$jscomp$1$$),$APP.$rumext$v2$adapt$$($profile$jscomp$55$$),$APP.$rumext$v2$adapt$$($organization$jscomp$6$$),$APP.$rumext$v2$adapt$$($teams_to_transfer$jscomp$3$$),$APP.$rumext$v2$adapt$$($num_teams_to_leave_on_leave_clicked$jscomp$1_props_75249$$),$APP.$rumext$v2$adapt$$($num_teams_to_delete$jscomp$3$$),$APP.$rumext$v2$adapt$$($num_teams_to_transfer$$)],function(){return $num_teams_to_delete$jscomp$3$$>
0&&$num_teams_to_transfer$$===0?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.before-leave-org.title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($organization$jscomp$6$$)])),
$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.before-leave-org.message"),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-org-confirm.accept"),$APP.$cljs$cst$2479$on_accept$$,$leave_fn$jscomp$1$$,$APP.$cljs$cst$5372$error_msg$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.before-leave-org.warning")],null))):$num_teams_to_transfer$$>0?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$cljs$cst$5105$leave_and_reassign_org$$,$APP.$cljs$cst$1914$profile$$,$profile$jscomp$55$$,$cljs$cst$5101$teams_to_transfer$$,$teams_to_transfer$jscomp$3$$,$cljs$cst$5102$num_teams_to_delete$$,$num_teams_to_delete$jscomp$3$$,$APP.$cljs$cst$924$accept$$,$leave_fn$jscomp$1$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.leave-org-confirm.title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($organization$jscomp$6$$)])),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-org-confirm.message"),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-org-confirm.accept"),
$APP.$cljs$cst$2479$on_accept$$,$leave_fn$jscomp$1$$],null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){for(var $c__5548__auto__$jscomp$31_seq__75254_temp__5825__auto__$jscomp$315$$=$APP.$cljs$core$seq$$($owned_teams$$),$G__75373_chunk__75255_seq__75254__$1$$=null,$G__75372_count__75256$$=0,$i__75257$$=0;;)if($i__75257$$<$G__75372_count__75256$$){var $G__75374_team$jscomp$49$$=$G__75373_chunk__75255_seq__75254__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__75257$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__75374_team$jscomp$49$$)));$i__75257$$+=1}else if($c__5548__auto__$jscomp$31_seq__75254_temp__5825__auto__$jscomp$315$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$31_seq__75254_temp__5825__auto__$jscomp$315$$))$G__75373_chunk__75255_seq__75254__$1$$=$c__5548__auto__$jscomp$31_seq__75254_temp__5825__auto__$jscomp$315$$,
$APP.$cljs$core$chunked_seq_QMARK_$$($G__75373_chunk__75255_seq__75254__$1$$)?($c__5548__auto__$jscomp$31_seq__75254_temp__5825__auto__$jscomp$315$$=$APP.$cljs$core$_chunked_first$$($G__75373_chunk__75255_seq__75254__$1$$),$G__75372_count__75256$$=$APP.$cljs$core$_chunked_rest$$($G__75373_chunk__75255_seq__75254__$1$$),$G__75373_chunk__75255_seq__75254__$1$$=$c__5548__auto__$jscomp$31_seq__75254_temp__5825__auto__$jscomp$315$$,$G__75374_team$jscomp$49$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$31_seq__75254_temp__5825__auto__$jscomp$315$$),
$c__5548__auto__$jscomp$31_seq__75254_temp__5825__auto__$jscomp$315$$=$G__75372_count__75256$$,$G__75372_count__75256$$=$G__75374_team$jscomp$49$$):($G__75374_team$jscomp$49$$=$APP.$cljs$core$first$$($G__75373_chunk__75255_seq__75254__$1$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__75374_team$jscomp$49$$))),$c__5548__auto__$jscomp$31_seq__75254_temp__5825__auto__$jscomp$315$$=
$APP.$cljs$core$next$$($G__75373_chunk__75255_seq__75254__$1$$),$G__75373_chunk__75255_seq__75254__$1$$=null,$G__75372_count__75256$$=0),$i__75257$$=0;else return null});return $APP.$rumext$v2$create_element$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,$props$jscomp$288$$,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$num_teams_to_leave_on_leave_clicked$jscomp$1_props_75249$$,className:"main_ui_dashboard_sidebar__team-options-item",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.leave-org")}))};
$app$main$ui$dashboard$sidebar$sidebar_org_switch_STAR_$$=function($orgs$jscomp$2_props_75260$$){var $profile$jscomp$56$$=$orgs$jscomp$2_props_75260$$.profile,$org_teams_team$jscomp$50$$=$orgs$jscomp$2_props_75260$$.team,$teams$jscomp$13$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$teams$$);$orgs$jscomp$2_props_75260$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($teams$jscomp$13$$)],function(){return $APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$team$team__GT_organization$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4902$is_default$$,$APP.$cljs$core$vals$$($teams$jscomp$13$$))))});var $show_dropdown_QMARK_$$=$APP.$app$main$data$nitrate$is_valid_license_QMARK_$$($profile$jscomp$56$$)||$APP.$cljs$core$count$$($orgs$jscomp$2_props_75260$$)>1,$current_org$$=$APP.$app$main$data$team$team__GT_organization$$($org_teams_team$jscomp$50$$);$org_teams_team$jscomp$50$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($teams$jscomp$13$$),$APP.$rumext$v2$adapt$$($current_org$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75259_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3256$organization_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__75259_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current_org$$))},$APP.$cljs$core$vals$$($teams$jscomp$13$$))});
var $default_org_QMARK_$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current_org$$)==null,$show_options_QMARK_$$=!$default_org_QMARK_$$&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$56$$),$APP.$cljs$cst$3324$owner_id$$.$cljs$core$IFn$_invoke$arity$1$($current_org$$)),$show_orgs_menu_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_orgs_menu_QMARK_$$=$APP.$cljs$core$_deref$$($show_orgs_menu_STAR_$$),
$show_org_options_menu_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_org_options_menu_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($show_org_options_menu_STAR_$jscomp$1$$),$on_show_options_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$246$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$246$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_org_options_menu_STAR_$jscomp$1$$,
$APP.$cljs$core$not$$)}),$close_org_options_menu$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_org_options_menu_STAR_$jscomp$1$$,!1)}),$on_show_orgs_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$247$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$247$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_orgs_menu_STAR_$$,$APP.$cljs$core$not$$)}),
$on_show_orgs_keydown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($G__75262_event$jscomp$248$$){var $JSCompiler_inline_result$jscomp$1470_or__5025__auto__$jscomp$inline_7997$$=(0,$APP.$app$util$keyboard$space_QMARK_$$)($G__75262_event$jscomp$248$$);$JSCompiler_inline_result$jscomp$1470_or__5025__auto__$jscomp$inline_7997$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1470_or__5025__auto__$jscomp$inline_7997$$)?$JSCompiler_inline_result$jscomp$1470_or__5025__auto__$jscomp$inline_7997$$:
(0,$APP.$app$util$keyboard$enter_QMARK_$$)($G__75262_event$jscomp$248$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1470_or__5025__auto__$jscomp$inline_7997$$)?($APP.$app$util$dom$prevent_default$$($G__75262_event$jscomp$248$$),$APP.$app$util$dom$stop_propagation$$($G__75262_event$jscomp$248$$),$G__75262_event$jscomp$248$$=$APP.$app$util$dom$get_current_target$$($G__75262_event$jscomp$248$$),$G__75262_event$jscomp$248$$==null?null:$APP.$app$util$dom$click$$($G__75262_event$jscomp$248$$)):
null}),$close_orgs_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_orgs_menu_STAR_$$,!1)}),$on_create_org_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$56$$)],function(){return $APP.$app$main$data$nitrate$is_valid_license_QMARK_$$($profile$jscomp$56$$)?$app$main$data$nitrate$go_to_nitrate_cc_create_org$$():$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$nitrate$show_nitrate_popup$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5068$nitrate_form$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$))});return $show_dropdown_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_sidebar__sidebar-org-switch",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_sidebar__org-switch-content",children:[(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_show_orgs_click$$,onKeyDown:$on_show_orgs_keydown$$,"aria-expanded":$show_orgs_menu_QMARK_$$,"aria-haspopup":"menu",className:"main_ui_dashboard_sidebar__current-org "+($show_options_QMARK_$$?
"":"main_ui_dashboard_sidebar__current-org-no-options"),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_sidebar__team-name",children:$default_org_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__org-penpot-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$raw_svg$raw_svg_STAR_$$,{id:"penpot-logo-icon"})}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__team-text",
children:"Penpot"})]}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$org_avatar$org_avatar_STAR_$$,{org:$current_org$$,size:"xxxl"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__team-text",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($current_org$$)})]})}),$app$main$ui$dashboard$sidebar$arrow_icon$$]}),$show_options_QMARK_$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,
{variant:"ghost",type:"button",className:"main_ui_dashboard_sidebar__org-options-btn",onClick:$on_show_options_click$jscomp$1$$,children:$APP.$cljs$core$truth_$$($show_org_options_menu_QMARK_$jscomp$1$$)?$app$main$ui$dashboard$sidebar$org_menu_icon_open$$:$app$main$ui$dashboard$sidebar$org_menu_icon$$}):null]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$sidebar$organizations_selector_dropdown_STAR_$$,{show:$show_orgs_menu_QMARK_$$,onClose:$close_orgs_menu$$,id:"organizations-list",className:"main_ui_dashboard_sidebar__dropdown main_ui_dashboard_sidebar__teams-dropdown",
organization:$current_org$$,profile:$profile$jscomp$56$$,organizations:$APP.$cljs$core$vals$$($orgs$jscomp$2_props_75260$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$sidebar$org_options_dropdown_STAR_$$,{show:$show_org_options_menu_QMARK_$jscomp$1$$,onClose:$close_org_options_menu$jscomp$1$$,id:"team-options",className:"main_ui_dashboard_sidebar__dropdown main_ui_dashboard_sidebar__options-dropdown",organization:$current_org$$,profile:$profile$jscomp$56$$,teams:$org_teams_team$jscomp$50$$})]}):
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_sidebar__selected-org",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__org-penpot-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$raw_svg$raw_svg_STAR_$$,{id:"penpot-logo-icon"})}),"Penpot",$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"ghost",type:"button",className:"main_ui_dashboard_sidebar__create-org",onClick:$on_create_org_click$jscomp$1$$,
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.plus-create-new-org")})]})};
$app$main$ui$dashboard$sidebar$sidebar_team_switch_STAR_$$=function($props_75265_team$jscomp$51$$){var $profile$jscomp$57$$=$props_75265_team$jscomp$51$$.profile;$props_75265_team$jscomp$51$$=$props_75265_team$jscomp$51$$.team;var $nitrate_QMARK_$jscomp$3$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1233$nitrate$$),$organization_id$jscomp$12$$=$nitrate_QMARK_$jscomp$3$$?$APP.$cljs$cst$3256$organization_id$$.$cljs$core$IFn$_invoke$arity$1$($props_75265_team$jscomp$51$$):
null,$teams$jscomp$14$$=function(){var $G__75266_G__75266__$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$teams$$);$G__75266_G__75266__$1$$=$nitrate_QMARK_$jscomp$3$$?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75264_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3256$organization_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_val$$($p1__75264_SHARP_$$)),$organization_id$jscomp$12$$)},$G__75266_G__75266__$1$$):$G__75266_G__75266__$1$$;
return $nitrate_QMARK_$jscomp$3$$?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$G__75266_G__75266__$1$$):$G__75266_G__75266__$1$$}(),$subscription$jscomp$9_subscription_type$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_75265_team$jscomp$51$$,$APP.$cljs$cst$3201$subscription$$);$subscription$jscomp$9_subscription_type$jscomp$8$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($subscription$jscomp$9_subscription_type$jscomp$8$$);
var $show_team_options_menu_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_team_options_menu_QMARK_$$=$APP.$cljs$core$_deref$$($show_team_options_menu_STAR_$$),$show_teams_menu_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_teams_menu_QMARK_$$=$APP.$cljs$core$_deref$$($show_teams_menu_STAR_$$),$is_default_QMARK_$$=$APP.$cljs$cst$4902$is_default$$.$cljs$core$IFn$_invoke$arity$1$($props_75265_team$jscomp$51$$),$on_show_teams_click$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$249$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$249$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_teams_menu_STAR_$$,$APP.$cljs$core$not$$)}),$on_show_teams_keydown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($G__75267_event$jscomp$250$$){var $JSCompiler_inline_result$jscomp$1471_or__5025__auto__$jscomp$inline_7999$$=(0,$APP.$app$util$keyboard$space_QMARK_$$)($G__75267_event$jscomp$250$$);
$JSCompiler_inline_result$jscomp$1471_or__5025__auto__$jscomp$inline_7999$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1471_or__5025__auto__$jscomp$inline_7999$$)?$JSCompiler_inline_result$jscomp$1471_or__5025__auto__$jscomp$inline_7999$$:(0,$APP.$app$util$keyboard$enter_QMARK_$$)($G__75267_event$jscomp$250$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1471_or__5025__auto__$jscomp$inline_7999$$)?($APP.$app$util$dom$prevent_default$$($G__75267_event$jscomp$250$$),
$APP.$app$util$dom$stop_propagation$$($G__75267_event$jscomp$250$$),$G__75267_event$jscomp$250$$=$APP.$app$util$dom$get_current_target$$($G__75267_event$jscomp$250$$),$G__75267_event$jscomp$250$$==null?null:$APP.$app$util$dom$click$$($G__75267_event$jscomp$250$$)):null}),$close_team_options_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_team_options_menu_STAR_$$,!1)}),$on_show_options_click$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$251$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$251$$);
return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_team_options_menu_STAR_$$,$APP.$cljs$core$not$$)}),$on_show_options_keydown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($G__75271_event$jscomp$252$$){var $JSCompiler_inline_result$jscomp$1472_or__5025__auto__$jscomp$inline_8001$$=(0,$APP.$app$util$keyboard$space_QMARK_$$)($G__75271_event$jscomp$252$$);$JSCompiler_inline_result$jscomp$1472_or__5025__auto__$jscomp$inline_8001$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1472_or__5025__auto__$jscomp$inline_8001$$)?
$JSCompiler_inline_result$jscomp$1472_or__5025__auto__$jscomp$inline_8001$$:(0,$APP.$app$util$keyboard$enter_QMARK_$$)($G__75271_event$jscomp$252$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1472_or__5025__auto__$jscomp$inline_8001$$)?($APP.$app$util$dom$prevent_default$$($G__75271_event$jscomp$252$$),$APP.$app$util$dom$stop_propagation$$($G__75271_event$jscomp$252$$),$G__75271_event$jscomp$252$$=$APP.$app$util$dom$get_current_target$$($G__75271_event$jscomp$252$$),$G__75271_event$jscomp$252$$==
null?null:$APP.$app$util$dom$click$$($G__75271_event$jscomp$252$$)):null}),$close_teams_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_teams_menu_STAR_$$,!1)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_sidebar__sidebar-team-switch",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_sidebar__switch-content",children:[(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_show_teams_click$$,
onKeyDown:$on_show_teams_keydown$$,"aria-expanded":$show_teams_menu_QMARK_$$,"aria-haspopup":"menu",className:"main_ui_dashboard_sidebar__current-team",children:[$APP.$cljs$core$truth_$$($is_default_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_sidebar__team-name",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__penpot-icon",children:$APP.$app$main$ui$icons$logo_icon$$}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__team-text",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.default-team-name")})]}):$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1223$subscriptions$$)&&$APP.$cljs$core$not$$($is_default_QMARK_$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("unlimited",$subscription$jscomp$9_subscription_type$jscomp$8$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("enterprise",$subscription$jscomp$9_subscription_type$jscomp$8$$))?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_sidebar__team-name",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:$APP.$app$config$resolve_team_photo_url$$($props_75265_team$jscomp$51$$),alt:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($props_75265_team$jscomp$51$$),className:"main_ui_dashboard_sidebar__team-picture"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_sidebar__team-text-with-icon",children:[(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($props_75265_team$jscomp$51$$),
className:"main_ui_dashboard_sidebar__team-text",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($props_75265_team$jscomp$51$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$menu_team_icon_STAR_$$,{subscriptionType:$subscription$jscomp$9_subscription_type$jscomp$8$$})]})]}):$APP.$cljs$core$not$$($is_default_QMARK_$$)&&($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("unlimited",$subscription$jscomp$9_subscription_type$jscomp$8$$)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("enterprise",
$subscription$jscomp$9_subscription_type$jscomp$8$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_sidebar__team-name",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:$APP.$app$config$resolve_team_photo_url$$($props_75265_team$jscomp$51$$),alt:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($props_75265_team$jscomp$51$$),className:"main_ui_dashboard_sidebar__team-picture"}),(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($props_75265_team$jscomp$51$$),
className:"main_ui_dashboard_sidebar__team-text",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($props_75265_team$jscomp$51$$)})]}):null,$app$main$ui$dashboard$sidebar$arrow_icon$$]}),$APP.$cljs$core$truth_$$($is_default_QMARK_$$)?null:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_show_options_click$jscomp$2$$,"aria-label":"team-management",tabIndex:"0",onKeyDown:$on_show_options_keydown$$,className:"main_ui_dashboard_sidebar__switch-options",children:$app$main$ui$dashboard$sidebar$menu_icon$$})]}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$sidebar$teams_selector_dropdown_STAR_$$,{show:$show_teams_menu_QMARK_$$,onClose:$close_teams_menu$$,id:"team-list",className:"main_ui_dashboard_sidebar__dropdown main_ui_dashboard_sidebar__teams-dropdown",team:$props_75265_team$jscomp$51$$,profile:$profile$jscomp$57$$,teams:$teams$jscomp$14$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$sidebar$team_options_dropdown_STAR_$$,{show:$show_team_options_menu_QMARK_$$,onClose:$close_team_options_menu$$,
id:"team-options",className:"main_ui_dashboard_sidebar__dropdown main_ui_dashboard_sidebar__options-dropdown",team:$props_75265_team$jscomp$51$$,profile:$profile$jscomp$57$$})]})};
$app$main$ui$dashboard$sidebar$sidebar_content_STAR_$$=function($projects_QMARK__props_75272$$){var $profile$jscomp$58$$=$projects_QMARK__props_75272$$.profile,$projects$jscomp$6$$=$projects_QMARK__props_75272$$.projects,$search_term$jscomp$2$$=$projects_QMARK__props_75272$$.searchTerm,$drafts_QMARK__section$jscomp$20$$=$projects_QMARK__props_75272$$.section,$project$jscomp$18$$=$projects_QMARK__props_75272$$.project,$team$jscomp$52$$=$projects_QMARK__props_75272$$.team,$default_project_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($projects_QMARK__props_75272$$.defaultProject,
$APP.$cljs$cst$266$id$$),$team_id$jscomp$141$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$52$$,$APP.$cljs$cst$266$id$$);$projects_QMARK__props_75272$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drafts_QMARK__section$jscomp$20$$,$APP.$cljs$cst$2522$dashboard_recent$$);var $fonts_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drafts_QMARK__section$jscomp$20$$,$APP.$cljs$cst$2520$dashboard_fonts$$),$libs_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drafts_QMARK__section$jscomp$20$$,
$APP.$cljs$cst$2518$dashboard_libraries$$);$drafts_QMARK__section$jscomp$20$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drafts_QMARK__section$jscomp$20$$,$APP.$cljs$cst$2512$dashboard_files$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$18$$),$default_project_id$$);var $container$jscomp$81$$=(0,$APP.$rumext$v2$use_ref$$)(null),$overflow_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$overflow_QMARK_$$=$APP.$cljs$core$_deref$$($overflow_STAR_$$),$nitrate_QMARK_$jscomp$4$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1233$nitrate$$),$go_projects$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_recent$$())}),$go_projects_with_key$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$141$$)],
function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$141$$])));return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $temp__5825__auto__$jscomp$316$$=$APP.$goog$dom$getElement$$("dashboard-projects-title");return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$316$$)?
($APP.$app$util$dom$set_attribute_BANG_$$($temp__5825__auto__$jscomp$316$$,"tabindex","0"),$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$316$$),$APP.$app$util$dom$set_attribute_BANG_$$($temp__5825__auto__$jscomp$316$$,"tabindex","-1")):null})}),$go_fonts$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$141$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_dashboard_fonts$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,
$team_id$jscomp$141$$])))}),$go_fonts_with_key$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$52$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_dashboard_fonts$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$141$$])));return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $font_title$$=
$APP.$goog$dom$getElement$$("dashboard-fonts-title");return $APP.$cljs$core$truth_$$($font_title$$)?($APP.$app$util$dom$set_attribute_BANG_$$($font_title$$,"tabindex","0"),$APP.$app$util$dom$focus_BANG_$$($font_title$$),$APP.$app$util$dom$set_attribute_BANG_$$($font_title$$,"tabindex","-1")):null})}),$go_drafts$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$141$$),$APP.$rumext$v2$adapt$$($default_project_id$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,
$team_id$jscomp$141$$,$APP.$cljs$cst$2181$project_id$$,$default_project_id$$])))}),$go_drafts_with_key$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$141$$),$APP.$rumext$v2$adapt$$($default_project_id$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,
$team_id$jscomp$141$$,$APP.$cljs$cst$2181$project_id$$,$default_project_id$$])));return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $temp__5825__auto__$jscomp$317$$=$APP.$goog$dom$getElement$$("dashboard-drafts-title");return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$317$$)?($APP.$app$util$dom$set_attribute_BANG_$$($temp__5825__auto__$jscomp$317$$,"tabindex","0"),$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$317$$),$APP.$app$util$dom$set_attribute_BANG_$$($temp__5825__auto__$jscomp$317$$,
"tabindex","-1")):null})}),$go_libs$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$141$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_dashboard_libraries$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$141$$])))}),$go_libs_with_key$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$141$$)],
function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_dashboard_libraries$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$141$$])));return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $libs_title$$=$APP.$goog$dom$getElement$$("dashboard-libraries-title");return $APP.$cljs$core$truth_$$($libs_title$$)?($APP.$app$util$dom$set_attribute_BANG_$$($libs_title$$,
"tabindex","0"),$APP.$app$util$dom$focus_BANG_$$($libs_title$$),$APP.$app$util$dom$set_attribute_BANG_$$($libs_title$$,"tabindex","-1")):null})}),$pinned_projects$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($projects$jscomp$6$$)],function(){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4903$is_pinned$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4902$is_default$$,
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2571$deleted_at$$,$projects$jscomp$6$$)))))});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($pinned_projects$$)],function(){var $node$jscomp$385$$=$APP.$rumext$v2$ref_val$$($container$jscomp$81$$);return $APP.$cljs$core$reset_BANG_$$($overflow_STAR_$$,$node$jscomp$385$$.scrollHeight>$node$jscomp$385$$.clientHeight)});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_sidebar__sidebar-content-wrapper",children:[$nitrate_QMARK_$jscomp$4$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_sidebar__orgs-container",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$sidebar$sidebar_org_switch_STAR_$$,{team:$team$jscomp$52$$,profile:$profile$jscomp$58$$})}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$container$jscomp$81$$,className:"main_ui_dashboard_sidebar__sidebar-content "+($nitrate_QMARK_$jscomp$4$$?"main_ui_dashboard_sidebar__sidebar-content-nitrate":
""),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$sidebar$sidebar_team_switch_STAR_$$,{team:$team$jscomp$52$$,profile:$profile$jscomp$58$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$sidebar$sidebar_search_STAR_$$,{searchTerm:$search_term$jscomp$2$$,teamId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$52$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_sidebar__sidebar-content-section",children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_dashboard_sidebar__sidebar-nav",
children:[(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_dashboard_sidebar__recent-projects main_ui_dashboard_sidebar__sidebar-nav-item "+($projects_QMARK__props_75272$$?"main_ui_dashboard_sidebar__current":""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$link$link$$,{action:$go_projects$$,"class":"main_ui_dashboard_sidebar__sidebar-link","keyboard-action":$go_projects_with_key$$,children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__element-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.projects")})})}),
(0,$APP.$rumext$v2$jsx$$)("li",{className:($drafts_QMARK__section$jscomp$20$$?"main_ui_dashboard_sidebar__current":"")+" main_ui_dashboard_sidebar__sidebar-nav-item",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$link$link$$,{action:$go_drafts$$,"class":"main_ui_dashboard_sidebar__sidebar-link","keyboard-action":$go_drafts_with_key$$,children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__element-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.drafts")})})})]})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_sidebar__sidebar-content-section",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_sidebar__sidebar-section-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.sources")}),(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_dashboard_sidebar__sidebar-nav",children:[(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_dashboard_sidebar__sidebar-nav-item "+($fonts_QMARK_$$?"main_ui_dashboard_sidebar__current":
""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$link$link$$,{action:$go_fonts$$,"class":"main_ui_dashboard_sidebar__sidebar-link","keyboard-action":$go_fonts_with_key$$,"data-testid":"fonts",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__element-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.fonts")})})}),(0,$APP.$rumext$v2$jsx$$)("li",{className:($libs_QMARK_$$?"main_ui_dashboard_sidebar__current":"")+" main_ui_dashboard_sidebar__sidebar-nav-item",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$link$link$$,{action:$go_libs$$,"data-testid":"libs-link-sidebar","class":"main_ui_dashboard_sidebar__sidebar-link","keyboard-action":$go_libs_with_key$$,children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__element-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.shared-libraries")})})})]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"pinned-projects",className:"main_ui_dashboard_sidebar__sidebar-content-section",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_sidebar__sidebar-section-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.pinned-projects")}),$pinned_projects$$!=null?(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_dashboard_sidebar__sidebar-nav main_ui_dashboard_sidebar__pinned-projects",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$106$$,$item$jscomp$116$$){$out_arr__44124__auto__$jscomp$106$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$sidebar$sidebar_project_STAR_$$,
{item:$item$jscomp$116$$,id:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$116$$),teamId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$52$$),isSelected:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$116$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$18$$))},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$116$$)??"")));return $out_arr__44124__auto__$jscomp$106$$},
[],$pinned_projects$$)}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_sidebar__sidebar-empty-placeholder",children:[$app$main$ui$dashboard$sidebar$pin_icon$$,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__empty-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.no-projects-placeholder")})]})]})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_sidebar__separator "+($APP.$cljs$core$truth_$$($overflow_QMARK_$$)?
"main_ui_dashboard_sidebar__overflow-separator":"")})]})})};
$app$main$ui$dashboard$sidebar$help_learning_menu_STAR_$$=function($handle_click_url_props_75294$$){var $on_close$jscomp$9$$=$handle_click_url_props_75294$$.onClose,$on_click$jscomp$26$$=$handle_click_url_props_75294$$.onClick;$handle_click_url_props_75294$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$253_eventname$$){var $url$jscomp$95$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$253_eventname$$),"url");$event$jscomp$253_eventname$$=
$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$253_eventname$$),"eventname");$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,$event$jscomp$253_eventname$$,$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"menu:in-app"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$($url$jscomp$95$$)});
var $handle_feedback_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__75290_SHARP_$$){return $on_click$jscomp$26$$.$cljs$core$IFn$_invoke$arity$2$?$on_click$jscomp$26$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2509$settings_feedback$$,$p1__75290_SHARP_$$):$on_click$jscomp$26$$($APP.$cljs$cst$2509$settings_feedback$$,$p1__75290_SHARP_$$)});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,{show:!0,className:"main_ui_dashboard_sidebar__sub-menu main_ui_dashboard_sidebar__help-learning",
onClose:$on_close$jscomp$9$$,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_dashboard_sidebar__submenu-item","data-url":"https://help.penpot.app",onClick:$handle_click_url_props_75294$$,"data-eventname":"explore-help-center-click",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.help-center")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_dashboard_sidebar__submenu-item",
"data-url":"https://penpot.app/learning-center",onClick:$handle_click_url_props_75294$$,"data-eventname":"explore-learning-center-click",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.learning-center")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_dashboard_sidebar__submenu-item","data-url":"https://penpot.app/penpothub",onClick:$handle_click_url_props_75294$$,"data-eventname":"explore-penpot-hub-click",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.penpot-hub")}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1227$user_feedback$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_dashboard_sidebar__submenu-item",onClick:$handle_feedback_click$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.give-feedback")}):null]})};
$app$main$ui$dashboard$sidebar$community_contributions_menu_STAR_$$=function($on_close$jscomp$10_props_75312$$){$on_close$jscomp$10_props_75312$$=$on_close$jscomp$10_props_75312$$.onClose;var $handle_click_url$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$254_eventname$jscomp$1$$){var $url$jscomp$96$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$254_eventname$jscomp$1$$),"url");$event$jscomp$254_eventname$jscomp$1$$=
$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$254_eventname$jscomp$1$$),"eventname");$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,$event$jscomp$254_eventname$jscomp$1$$,$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"menu:in-app"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$($url$jscomp$96$$)});
return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,{show:!0,className:"main_ui_dashboard_sidebar__sub-menu main_ui_dashboard_sidebar__community",onClose:$on_close$jscomp$10_props_75312$$,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_dashboard_sidebar__submenu-item","data-url":"https://github.com/penpot/penpot",onClick:$handle_click_url$jscomp$1$$,"data-eventname":"explore-github-repository-click",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.github-repo")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_dashboard_sidebar__submenu-item","data-url":"https://community.penpot.app",onClick:$handle_click_url$jscomp$1$$,"data-eventname":"explore-community-click",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.community")})]})};
$app$main$ui$dashboard$sidebar$about_penpot_menu_STAR_$$=function($on_close$jscomp$11_props_75314$$){$on_close$jscomp$11_props_75314$$=$on_close$jscomp$11_props_75314$$.onClose;var $show_release_notes$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$255$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"show-release-notes",$APP.$cljs$cst$2289$version$$,$APP.$cljs$cst$1280$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$)],null)));return $event$jscomp$255$$.altKey&&$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$255$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1222$onboarding$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5373$release_notes$$,$APP.$cljs$cst$2289$version$$,$APP.$cljs$cst$1280$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$)],null)))}),$handle_click_url$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$256_eventname$jscomp$2$$){var $url$jscomp$97$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$256_eventname$jscomp$2$$),"url");$event$jscomp$256_eventname$jscomp$2$$=
$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$256_eventname$jscomp$2$$),"eventname");$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,$event$jscomp$256_eventname$jscomp$2$$,$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"menu:in-app"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$($url$jscomp$97$$)});
return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,{show:!0,className:"main_ui_dashboard_sidebar__sub-menu main_ui_dashboard_sidebar__about",onClose:$on_close$jscomp$11_props_75314$$,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_dashboard_sidebar__submenu-item",onClick:$show_release_notes$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.version-notes",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$)]))}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_dashboard_sidebar__submenu-item","data-url":"https://github.com/penpot/penpot/blob/develop/CHANGES.md",onClick:$handle_click_url$jscomp$2$$,"data-eventname":"explore-changelog-click",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.penpot-changelog")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_dashboard_sidebar__submenu-item","data-url":"https://penpot.app/terms",onClick:$handle_click_url$jscomp$2$$,"data-eventname":"explore-terms-service-click",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.terms-of-service")})]})};
$APP.$app$main$ui$dashboard$sidebar$profile_section_STAR_$$=function($props_75319_team$jscomp$53$$){var $profile$jscomp$59$$=$props_75319_team$jscomp$53$$.profile;$props_75319_team$jscomp$53$$=$props_75319_team$jscomp$53$$.team;var $teams$jscomp$15$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$teams$$),$show_profile_menu_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_profile_menu_QMARK_$$=$APP.$cljs$core$_deref$$($show_profile_menu_STAR_$$),$sub_menu_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$sub_menu$$=$APP.$cljs$core$_deref$$($sub_menu_STAR_$$),$version$jscomp$23$$=$APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$),$close_sub_menu$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$257$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$257$$);return $APP.$cljs$core$reset_BANG_$$($sub_menu_STAR_$$,null)}),$photo$$=$APP.$app$config$resolve_profile_photo_url$$($profile$jscomp$59$$),$on_click$jscomp$27$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($section$jscomp$21$$,$event$jscomp$258$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$258$$);$APP.$cljs$core$reset_BANG_$$($show_profile_menu_STAR_$$,!1);return $section$jscomp$21$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($section$jscomp$21$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($section$jscomp$21$$)}),
$show_comments_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_comments_QMARK_$$=$APP.$cljs$core$_deref$$($show_comments_STAR_$$),$handle_hide_comments$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_comments_STAR_$$,!1)}),$handle_show_comments$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_comments_STAR_$$,!0)}),$handle_click$jscomp$2$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$259$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$259$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_profile_menu_STAR_$$,$APP.$cljs$core$not$$)}),$handle_key_down$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$260$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$260$$))?$APP.$cljs$core$reset_BANG_$$($show_profile_menu_STAR_$$,
!0):null}),$on_close$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_profile_menu_STAR_$$,!1)}),$handle_logout_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__75317_SHARP_$$){var $G__75323$$=$app$main$data$auth$logout$$();return $on_click$jscomp$27$$.$cljs$core$IFn$_invoke$arity$2$?$on_click$jscomp$27$$.$cljs$core$IFn$_invoke$arity$2$($G__75323$$,$p1__75317_SHARP_$$):$on_click$jscomp$27$$($G__75323$$,
$p1__75317_SHARP_$$)}),$handle_set_profile$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__75318_SHARP_$$){return $on_click$jscomp$27$$.$cljs$core$IFn$_invoke$arity$2$?$on_click$jscomp$27$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5374$settings_profile$$,$p1__75318_SHARP_$$):$on_click$jscomp$27$$($APP.$cljs$cst$5374$settings_profile$$,$p1__75318_SHARP_$$)}),$on_menu_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$261_menu$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$261_menu$$);
$event$jscomp$261_menu$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$261_menu$$),"testid"));return $APP.$cljs$core$reset_BANG_$$($sub_menu_STAR_$$,$event$jscomp$261_menu$$)}),$on_power_up_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-pricing-click",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard",$APP.$cljs$cst$1366$section$$,"sidebar"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://penpot.app/pricing")});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($show_profile_menu_QMARK_$$)],function(){return $APP.$cljs$core$truth_$$($show_profile_menu_QMARK_$$)?
null:$APP.$cljs$core$reset_BANG_$$($sub_menu_STAR_$$,null)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1233$nitrate$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$nitrate_sidebar_STAR_$$,{profile:$profile$jscomp$59$$,teams:$teams$jscomp$15$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$nitrate_current_plan_STAR_$$,
{profile:$profile$jscomp$59$$})]}):$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1223$subscriptions$$)?$app$main$ui$dashboard$subscription$show_subscription_dashboard_banner_QMARK_$$($profile$jscomp$59$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$dashboard_cta_STAR_$$,{profile:$profile$jscomp$59$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$subscription_sidebar_STAR_$$,{profile:$profile$jscomp$59$$}):null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1186$subscriptions_old$$)?(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_power_up_click$$,className:"main_ui_dashboard_sidebar__upgrade-plan-section",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_sidebar__penpot-free",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.upgrade-plan.penpot-free")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__no-limits",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.upgrade-plan.no-limits")})]}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_sidebar__power-up",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.upgrade-plan.power-up")})]}):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($props_75319_team$jscomp$53$$)?$profile$jscomp$59$$:$props_75319_team$jscomp$53$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$comments$comments_section$$,{profile:$profile$jscomp$59$$,team:$props_75319_team$jscomp$53$$,"show?":$show_comments_QMARK_$$,
"on-show-comments":$handle_show_comments$$,"on-hide-comments":$handle_hide_comments$$}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_sidebar__profile-section",children:[(0,$APP.$rumext$v2$jsxs$$)("button",{tabIndex:"0",onClick:$handle_click$jscomp$2$$,onKeyDown:$handle_key_down$jscomp$4$$,"data-testid":"profile-btn",className:"main_ui_dashboard_sidebar__profile",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:$photo$$,alt:$APP.$cljs$cst$1360$fullname$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$59$$),
className:"main_ui_dashboard_sidebar__profile-img"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__profile-fullname",children:$APP.$cljs$cst$1360$fullname$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$59$$)})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,{onClose:$on_close$jscomp$12$$,show:$show_profile_menu_QMARK_$$,id:"profile-menu",className:"main_ui_dashboard_sidebar__profile-dropdown",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_dashboard_sidebar__profile-dropdown-item",onClick:$handle_set_profile$$,"data-testid":"profile-profile-opt",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.your-account")}),(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_dashboard_sidebar__profile-separator"}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_dashboard_sidebar__profile-dropdown-item",onClick:$on_menu_click$jscomp$1$$,onKeyDown:function($event$jscomp$262$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$262$$))?
$on_menu_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$262$$):$on_menu_click$jscomp$1$$($event$jscomp$262$$):null},onPointerEnter:$on_menu_click$jscomp$1$$,"data-testid":"help-learning",id:"help-learning",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.help-learning")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow",className:"main_ui_dashboard_sidebar__open-arrow"})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_dashboard_sidebar__profile-dropdown-item",onClick:$on_menu_click$jscomp$1$$,onKeyDown:function($event$jscomp$263$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$263$$))?$on_menu_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$263$$):
$on_menu_click$jscomp$1$$($event$jscomp$263$$):null},onPointerEnter:$on_menu_click$jscomp$1$$,"data-testid":"community-contributions",id:"community-contributions",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.community-contributions")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow",className:"main_ui_dashboard_sidebar__open-arrow"})]}),
$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_dashboard_sidebar__profile-dropdown-item",onClick:$on_menu_click$jscomp$1$$,onKeyDown:function($event$jscomp$264$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$264$$))?$on_menu_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$264$$):$on_menu_click$jscomp$1$$($event$jscomp$264$$):
null},onPointerEnter:$on_menu_click$jscomp$1$$,"data-testid":"about-penpot",id:"about-penpot",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_sidebar__about-penpot",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_sidebar__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.about-penpot")}),(0,$APP.$rumext$v2$jsx$$)("span",{title:$version$jscomp$23$$,className:"main_ui_dashboard_sidebar__menu-version",children:$version$jscomp$23$$})]}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow",className:"main_ui_dashboard_sidebar__open-arrow"})]}),(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_dashboard_sidebar__profile-separator"}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_dashboard_sidebar__profile-dropdown-item main_ui_dashboard_sidebar__item-with-icon",onClick:$handle_logout_click$$,"data-testid":"logout-profile-opt",
children:[$app$main$ui$dashboard$sidebar$exit_icon$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.logout")]})]}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($props_75319_team$jscomp$53$$)?$profile$jscomp$59$$:$props_75319_team$jscomp$53$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$comments$comments_icon_STAR_$$,{profile:$profile$jscomp$59$$,onShowComments:$handle_show_comments$$}):null]}),$APP.$cljs$core$truth_$$($show_profile_menu_QMARK_$$)?function(){switch($sub_menu$$ instanceof
$APP.$cljs$core$Keyword$$?$sub_menu$$.$fqn$:null){case "help-learning":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$sidebar$help_learning_menu_STAR_$$,{onClose:$close_sub_menu$jscomp$1$$,onClick:$on_click$jscomp$27$$});case "community-contributions":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$sidebar$community_contributions_menu_STAR_$$,{onClose:$close_sub_menu$jscomp$1$$});case "about-penpot":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$sidebar$about_penpot_menu_STAR_$$,
{onClose:$close_sub_menu$jscomp$1$$});default:return null}}():null]})};
$app$main$ui$components$button_link$button_link$$=function($class$$jscomp$56_props_75210$$){var $icon$jscomp$18$$=$class$$jscomp$56_props_75210$$.icon,$on_click$jscomp$28$$=$class$$jscomp$56_props_75210$$["on-click"],$label$jscomp$38$$=$class$$jscomp$56_props_75210$$.label;$class$$jscomp$56_props_75210$$=$class$$jscomp$56_props_75210$$.class;var $on_key_down$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$28$$)],function($event$jscomp$265$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$265$$))?
$APP.$cljs$core$fn_QMARK_$$($on_click$jscomp$28$$)?$on_click$jscomp$28$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$28$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$265$$):$on_click$jscomp$28$$($event$jscomp$265$$):null:null});return(0,$APP.$rumext$v2$jsxs$$)("a",{tabIndex:"0",onClick:$on_click$jscomp$28$$,onKeyDown:$on_key_down$jscomp$10$$,className:""+($class$$jscomp$56_props_75210$$??"")+" main_ui_components_button_link__button",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"logo",
children:$icon$jscomp$18$$}),$label$jscomp$38$$]})};$app$main$ui$auth$login$login_with_sso$$=function($params__$1$jscomp$50_provider$jscomp$3$$,$params$jscomp$400$$){$params__$1$jscomp$50_provider$jscomp$3$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($params$jscomp$400$$,$cljs$cst$3348$provider$$,$params__$1$jscomp$50_provider$jscomp$3$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$auth$login_with_sso$$($params__$1$jscomp$50_provider$jscomp$3$$))};
$app$main$ui$auth$login$login_form_STAR_$$=function($origin$jscomp$58_props_75239$$){function $on_success$jscomp$52$$($data$jscomp$457$$){return $APP.$cljs$core$fn_QMARK_$$($on_success_callback$$)?$on_success_callback$$.$cljs$core$IFn$_invoke$arity$1$?$on_success_callback$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$457$$):$on_success_callback$$($data$jscomp$457$$):null}function $on_error$jscomp$66$$($cause$jscomp$99_cause__$1$jscomp$2$$){$cause$jscomp$99_cause__$1$jscomp$2$$=$APP.$cljs$core$ex_data$$($cause$jscomp$99_cause__$1$jscomp$2$$);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2561$restriction$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$99_cause__$1$jscomp$2$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5376$profile_blocked$$,$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$99_cause__$1$jscomp$2$$))?$APP.$cljs$core$reset_BANG_$$($error$jscomp$142$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.profile-blocked")):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2561$restriction$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$99_cause__$1$jscomp$2$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5377$ldap_not_initialized$$,$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$99_cause__$1$jscomp$2$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.ldap-disabled"))):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2561$restriction$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$99_cause__$1$jscomp$2$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5378$admin_only_profile$$,$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$99_cause__$1$jscomp$2$$))?$APP.$cljs$core$reset_BANG_$$($error$jscomp$142$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.profile-blocked")):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2252$validation$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$99_cause__$1$jscomp$2$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5379$wrong_credentials$$,$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$99_cause__$1$jscomp$2$$))?$APP.$cljs$core$reset_BANG_$$($error$jscomp$142$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.wrong-credentials")):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2252$validation$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$99_cause__$1$jscomp$2$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5380$account_without_password$$,$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$99_cause__$1$jscomp$2$$))?$APP.$cljs$core$reset_BANG_$$($error$jscomp$142$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.wrong-credentials")):
$APP.$cljs$core$reset_BANG_$$($error$jscomp$142$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.generic"))}var $params$jscomp$401$$=$origin$jscomp$58_props_75239$$.params,$handle_redirect$$=$origin$jscomp$58_props_75239$$.handleRedirect,$on_recovery_request$$=$origin$jscomp$58_props_75239$$.onRecoveryRequest,$on_success_callback$$=$origin$jscomp$58_props_75239$$.onSuccessCallback;$origin$jscomp$58_props_75239$$=$origin$jscomp$58_props_75239$$.origin;var $initial$jscomp$34_on_submit$jscomp$13$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($params$jscomp$401$$)],function(){return $params$jscomp$401$$}),$error$jscomp$142$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$form$jscomp$184$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$app$main$ui$auth$login$schema_COLON_login_form$$,$APP.$cljs$cst$5076$initial$$,$initial$jscomp$34_on_submit$jscomp$13$$):
$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$auth$login$schema_COLON_login_form$$,$APP.$cljs$cst$5076$initial$$,$initial$jscomp$34_on_submit$jscomp$13$$),$callback_url$jscomp$1$$=$cljs$cst$5375$callback_url$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$401$$),$show_password_field_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return!$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1171$login_with_custom_sso$$)}),
$show_password_field_QMARK_$$=$APP.$cljs$core$_deref$$($show_password_field_STAR_$$);$initial$jscomp$34_on_submit$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($show_password_field_QMARK_$$),$APP.$rumext$v2$adapt$$($params$jscomp$401$$)],function($data$jscomp$458_form__$1$jscomp$17_params__$1$jscomp$51$$){$APP.$cljs$core$reset_BANG_$$($error$jscomp$142$$,null);$data$jscomp$458_form__$1$jscomp$17_params__$1$jscomp$51$$=$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data$jscomp$458_form__$1$jscomp$17_params__$1$jscomp$51$$));
if($APP.$cljs$core$truth_$$($show_password_field_QMARK_$$))return $data$jscomp$458_form__$1$jscomp$17_params__$1$jscomp$51$$=$APP.$cljs$core$with_meta$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$params$jscomp$401$$,$data$jscomp$458_form__$1$jscomp$17_params__$1$jscomp$51$$])),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1295$on_error$$,$on_error$jscomp$66$$,$APP.$cljs$cst$2488$on_success$$,$on_success$jscomp$52$$],
null)),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$auth$login$$($data$jscomp$458_form__$1$jscomp$17_params__$1$jscomp$51$$));$data$jscomp$458_form__$1$jscomp$17_params__$1$jscomp$51$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$params$jscomp$401$$,$data$jscomp$458_form__$1$jscomp$17_params__$1$jscomp$51$$]));return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($sso_provider_id$$){return $APP.$cljs$core$truth_$$($sso_provider_id$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$auth$login_with_sso$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3348$provider$$,$sso_provider_id$$],null))):$APP.$cljs$core$reset_BANG_$$($show_password_field_STAR_$$,!0)},$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$100$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.ui.auth.login",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"error on retrieving sso provider"],null)],null)}),$cause$jscomp$100$$,"app.main.ui.auth.login",$APP.$cljs$cst$849$error$$,!1);return(0,$APP.$beicon$v2$core$of$$)(null)},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$266$id$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5381$get_sso_provider$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3183$email$$,$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$458_form__$1$jscomp$17_params__$1$jscomp$51$$)],null)))))});var $on_submit_ldap$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($form$jscomp$184$$)],function($event$jscomp$266_params__$1$jscomp$52_params__$2$jscomp$6$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$266_params__$1$jscomp$52_params__$2$jscomp$6$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$266_params__$1$jscomp$52_params__$2$jscomp$6$$);
$APP.$cljs$core$reset_BANG_$$($error$jscomp$142$$,null);$event$jscomp$266_params__$1$jscomp$52_params__$2$jscomp$6$$=$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$184$$));$event$jscomp$266_params__$1$jscomp$52_params__$2$jscomp$6$$=$APP.$cljs$core$with_meta$$($event$jscomp$266_params__$1$jscomp$52_params__$2$jscomp$6$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1295$on_error$$,$on_error$jscomp$66$$,$APP.$cljs$cst$2488$on_success$$,
$on_success$jscomp$52$$],null));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$auth$login_with_ldap$$($event$jscomp$266_params__$1$jscomp$52_params__$2$jscomp$6$$))}),$on_recovery_request__$1$$=function(){return $APP.$cljs$core$truth_$$($on_recovery_request$$)?$on_recovery_request$$:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$5382$auth_recovery_request$$))}}();
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_redirect$$),$APP.$rumext$v2$adapt$$($callback_url$jscomp$1$$)],function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($handle_redirect$$)?$handle_redirect$$:$callback_url$jscomp$1$$)){var $_STAR_sync_STAR__orig_val__75227$jscomp$inline_13130__STAR_sync_STAR__orig_val__75231$jscomp$inline_13132$$=$APP.$app$util$storage$_STAR_sync_STAR_$$;$APP.$app$util$storage$_STAR_sync_STAR_$$=!0;try{var $JSCompiler_temp$jscomp$10942$$=
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$session$$,$APP.$cljs$core$assoc$$,$cljs$cst$3340$login_redirect$$,$APP.$cljs$core$truth_$$($callback_url$jscomp$1$$)?$callback_url$jscomp$1$$:$APP.$app$util$globals$location$$.href)}finally{$APP.$app$util$storage$_STAR_sync_STAR_$$=$_STAR_sync_STAR__orig_val__75227$jscomp$inline_13130__STAR_sync_STAR__orig_val__75231$jscomp$inline_13132$$}}else{$_STAR_sync_STAR__orig_val__75227$jscomp$inline_13130__STAR_sync_STAR__orig_val__75231$jscomp$inline_13132$$=
$APP.$app$util$storage$_STAR_sync_STAR_$$;$APP.$app$util$storage$_STAR_sync_STAR_$$=!0;try{$JSCompiler_temp$jscomp$10942$$=$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$session$$,$APP.$cljs$core$dissoc$$,$cljs$cst$3340$login_redirect$$)}finally{$APP.$app$util$storage$_STAR_sync_STAR_$$=$_STAR_sync_STAR__orig_val__75227$jscomp$inline_13130__STAR_sync_STAR__orig_val__75231$jscomp$inline_13132$$}}return $JSCompiler_temp$jscomp$10942$$});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[function(){var $temp__5825__auto__$jscomp$318$$=$APP.$cljs$core$_deref$$($error$jscomp$142$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$318$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,{level:$APP.$cljs$cst$849$error$$,children:$temp__5825__auto__$jscomp$318$$}):null}(),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,{"on-submit":$initial$jscomp$34_on_submit$jscomp$13$$,"class":"main_ui_auth_login__login-form",
form:$form$jscomp$184$$,children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_login__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{name:$APP.$cljs$cst$3183$email$$,type:"email",label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.work-email"),"class":"main_ui_auth_login__form-field"})}),$APP.$cljs$core$truth_$$($show_password_field_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_login__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,
{type:"password",name:$APP.$cljs$cst$751$password$$,"auto-focus?":!0,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.password"),"class":"main_ui_auth_login__form-field"})}):null,$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$58_props_75239$$,$APP.$cljs$cst$1592$viewer$$)&&($APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1172$login$$)||$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1168$login_with_password$$))?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_login__fields-row main_ui_auth_login__forgot-password",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$link$link$$,{action:$on_recovery_request__$1$$,"class":"main_ui_auth_login__forgot-pass-link","data-testid":"forgot-password",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.forgot-password")})}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_auth_login__buttons-stack",children:[$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1172$login$$)||$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1168$login_with_password$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue"),"data-testid":"login-submit",className:"main_ui_auth_login__login-button"}):null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1179$login_with_ldap$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,
{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.login-with-ldap-submit"),className:"main_ui_auth_login__login-ldap-button",onClick:$on_submit_ldap$$}):null]})]})]})};
$app$main$ui$auth$login$login_sso_buttons_STAR_$$=function($login_with_google_props_75258$$){var $params$jscomp$402$$=$login_with_google_props_75258$$.params;$login_with_google_props_75258$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($params$jscomp$402$$)],function(){return $app$main$ui$auth$login$login_with_sso$$("google",$params$jscomp$402$$)});var $login_with_github$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($params$jscomp$402$$)],
function(){return $app$main$ui$auth$login$login_with_sso$$("github",$params$jscomp$402$$)}),$login_with_gitlab$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($params$jscomp$402$$)],function(){return $app$main$ui$auth$login$login_with_sso$$("gitlab",$params$jscomp$402$$)}),$login_with_oidc$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($params$jscomp$402$$)],function(){return $app$main$ui$auth$login$login_with_sso$$("oidc",
$params$jscomp$402$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_auth_login__auth-buttons",children:[$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1169$login_with_google$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$button_link$button_link$$,{"on-click":$login_with_google_props_75258$$,icon:$app$main$ui$icons$brand_google$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.login-with-google-submit"),"class":"main_ui_auth_login__login-btn main_ui_auth_login__btn-google-auth"}):
null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1173$login_with_github$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$button_link$button_link$$,{"on-click":$login_with_github$$,icon:$app$main$ui$icons$brand_github$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.login-with-github-submit"),"class":"main_ui_auth_login__login-btn main_ui_auth_login__btn-github-auth"}):null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1170$login_with_gitlab$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$button_link$button_link$$,{"on-click":$login_with_gitlab$$,icon:$app$main$ui$icons$brand_gitlab$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.login-with-gitlab-submit"),"class":"main_ui_auth_login__login-btn main_ui_auth_login__btn-gitlab-auth"}):null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1175$login_with_oidc$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$button_link$button_link$$,{"on-click":$login_with_oidc$$,
icon:$app$main$ui$icons$brand_openid$$,label:function(){var $or__5025__auto__$jscomp$1036$$=$APP.$cljs$core$not_empty$$($app$config$oidc_name$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1036$$)?$or__5025__auto__$jscomp$1036$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.login-with-oidc-submit")}(),"class":"main_ui_auth_login__login-btn main_ui_auth_login__btn-oidc-auth"}):null]})};
$APP.$app$main$ui$auth$login$login_dialog_STAR_$$=function($props_75263$$){var $params$jscomp$403$$=$props_75263$$.params;return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($app$main$ui$auth$login$show_sso_login_buttons_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$auth$login$login_sso_buttons_STAR_$$,{params:$params$jscomp$403$$}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1172$login$$)||$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1168$login_with_password$$)||$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1179$login_with_ldap$$)?(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_auth_login__separator"}):null]}):null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1172$login$$)||$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1168$login_with_password$$)||$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$cljs$cst$1179$login_with_ldap$$)?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$auth$login$login_form_STAR_$$,$props_75263$$):null]})};
$app$main$ui$auth$recovery_request$recovery_form$$=function($map__75222_map__75222__$1_on_submit$jscomp$14_props_75221$$){$map__75222_map__75222__$1_on_submit$jscomp$14_props_75221$$=$APP.$rumext$v2$util$wrap_props$$($map__75222_map__75222__$1_on_submit$jscomp$14_props_75221$$);$map__75222_map__75222__$1_on_submit$jscomp$14_props_75221$$=$APP.$cljs$core$__destructure_map$$($map__75222_map__75222__$1_on_submit$jscomp$14_props_75221$$);var $on_success_callback$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75222_map__75222__$1_on_submit$jscomp$14_props_75221$$,
$cljs$cst$5384$on_success_callback$$),$form$jscomp$185$$=function(){var $G__75226$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$app$main$ui$auth$recovery_request$schema_COLON_recovery_request_form$$,$APP.$cljs$cst$5076$initial$$,$G__75226$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$auth$recovery_request$schema_COLON_recovery_request_form$$,
$APP.$cljs$cst$5076$initial$$,$G__75226$$)}(),$submitted$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$default_success_finish$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$info$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.notifications.recovery-token-sent")))}),$on_success$jscomp$53$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($G__75229_cdata$jscomp$2$$){$APP.$cljs$core$reset_BANG_$$($submitted$$,
!1);if($on_success_callback$jscomp$1$$==null)return $default_success_finish$$.$cljs$core$IFn$_invoke$arity$0$?$default_success_finish$$.$cljs$core$IFn$_invoke$arity$0$():$default_success_finish$$();$G__75229_cdata$jscomp$2$$=$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($G__75229_cdata$jscomp$2$$);return $on_success_callback$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_success_callback$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__75229_cdata$jscomp$2$$):$on_success_callback$jscomp$1$$($G__75229_cdata$jscomp$2$$)}),
$on_error$jscomp$67$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($data$jscomp$459$$,$cause$jscomp$101$$){$APP.$cljs$core$reset_BANG_$$($submitted$$,!1);var $G__75230$$=$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($cause$jscomp$101$$));switch($G__75230$$ instanceof $APP.$cljs$core$Keyword$$?$G__75230$$.$fqn$:null){case "profile-not-verified":return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.notifications.profile-not-verified")));
case "profile-is-muted":return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.profile-is-muted")));case "email-has-permanent-bounces":case "email-has-complaints":return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.email-has-permanent-bounces",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$459$$)]))));
default:return $APP.$beicon$v2$core$throw$0$$($cause$jscomp$101$$)}});$map__75222_map__75222__$1_on_submit$jscomp$14_props_75221$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($submitted$$,!0);var $cdata$jscomp$3$$=$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$185$$)),$params$jscomp$405$$=$APP.$cljs$core$with_meta$$($cdata$jscomp$3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,
function($p1__75218_SHARP_$$){return $on_success$jscomp$53$$.$cljs$core$IFn$_invoke$arity$2$?$on_success$jscomp$53$$.$cljs$core$IFn$_invoke$arity$2$($cdata$jscomp$3$$,$p1__75218_SHARP_$$):$on_success$jscomp$53$$($cdata$jscomp$3$$,$p1__75218_SHARP_$$)},$APP.$cljs$cst$1295$on_error$$,function($p1__75219_SHARP_$$){return $on_error$jscomp$67$$.$cljs$core$IFn$_invoke$arity$2$?$on_error$jscomp$67$$.$cljs$core$IFn$_invoke$arity$2$($cdata$jscomp$3$$,$p1__75219_SHARP_$$):$on_error$jscomp$67$$($cdata$jscomp$3$$,
$p1__75219_SHARP_$$)}],null));$APP.$cljs$core$reset_BANG_$$($form$jscomp$185$$,null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$profile$request_profile_recovery$$($params$jscomp$405$$))});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,{"on-submit":$map__75222_map__75222__$1_on_submit$jscomp$14_props_75221$$,"class":"main_ui_auth_recovery_request__recovery-request-form",form:$form$jscomp$185$$,children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_auth_recovery_request__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{name:$APP.$cljs$cst$3183$email$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.work-email"),type:"text","class":"main_ui_auth_recovery_request__form-field"})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.recovery-request-submit"),"data-testid":"recovery-resquest-submit",
className:"main_ui_auth_recovery_request__recover-btn"})]})};
$APP.$app$main$ui$auth$recovery_request$recovery_request_page$$=function($map__75234_params$jscomp$406_props_75233$$){$map__75234_params$jscomp$406_props_75233$$=$APP.$rumext$v2$util$wrap_props$$($map__75234_params$jscomp$406_props_75233$$);var $go_back_go_back_callback_map__75234__$1$$=$APP.$cljs$core$__destructure_map$$($map__75234_params$jscomp$406_props_75233$$);$map__75234_params$jscomp$406_props_75233$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($go_back_go_back_callback_map__75234__$1$$,$APP.$cljs$cst$1430$params$$);
var $on_success_callback$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($go_back_go_back_callback_map__75234__$1$$,$cljs$cst$5384$on_success_callback$$);$go_back_go_back_callback_map__75234__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($go_back_go_back_callback_map__75234__$1$$,$cljs$cst$5385$go_back_callback$$);$go_back_go_back_callback_map__75234__$1$$=$APP.$cljs$core$truth_$$($go_back_go_back_callback_map__75234__$1$$)?$go_back_go_back_callback_map__75234__$1$$:
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3356$auth_login$$))};return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_auth_recovery_request__auth-form-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_auth_recovery_request__auth-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.recovery-request-title")}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_auth_recovery_request__auth-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.recovery-request-subtitle")}),(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_auth_recovery_request__separator"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$auth$recovery_request$recovery_form$$,{params:$map__75234_params$jscomp$406_props_75233$$,"on-success-callback":$on_success_callback$jscomp$2$$}),(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_auth_recovery_request__separator"}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_recovery_request__go-back",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$link$link$$,{action:$go_back_go_back_callback_map__75234__$1$$,"class":"main_ui_auth_recovery_request__go-back-link","data-testid":"go-back-link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.go-back")})})]})};
$APP.$app$main$ui$auth$register$newsletter_options_STAR_$$=function(){var $updates_label$$=$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{tagName:"div",content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding-v2.newsletter.updates")});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_register__fields-row main_ui_auth_register__input-visible main_ui_auth_register__newsletter-option-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,
{name:$cljs$cst$5386$accept_newsletter_updates$$,"class":"main_ui_auth_register__checkbox-newsletter-updates",type:"checkbox","default-checked":!1,label:$updates_label$$})})};
$APP.$app$main$ui$auth$register$terms_and_privacy_STAR_$$=function(){var $terms_label$$=$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{tagName:"div",content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("auth.terms-and-privacy-agreement",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$terms_of_service_uri$$,$app$config$privacy_policy_uri$$]))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_register__fields-row main_ui_auth_register__input-visible main_ui_auth_register__accept-terms-and-privacy-wrapper",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{name:$cljs$cst$5387$accept_terms_and_privacy$$,"show-error":!1,"class":"main_ui_auth_register__checkbox-terms-and-privacy",type:"checkbox","default-checked":!1,label:$terms_label$$})})};
$APP.$app$main$ui$auth$register$register_form_STAR_$$=function($initial$jscomp$35_on_submit$jscomp$15_props_75285$$){var $params$jscomp$407$$=$initial$jscomp$35_on_submit$jscomp$15_props_75285$$.params,$on_success_callback$jscomp$3$$=$initial$jscomp$35_on_submit$jscomp$15_props_75285$$.onSuccessCallback;$initial$jscomp$35_on_submit$jscomp$15_props_75285$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($params$jscomp$407$$)],$APP.$cljs$core$constantly$$($params$jscomp$407$$));
var $form$jscomp$186$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$app$main$ui$auth$register$schema_COLON_register_form$$,$APP.$cljs$cst$5076$initial$$,$initial$jscomp$35_on_submit$jscomp$15_props_75285$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$auth$register$schema_COLON_register_form$$,$APP.$cljs$cst$5076$initial$$,$initial$jscomp$35_on_submit$jscomp$15_props_75285$$),
$submitted_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$on_error$jscomp$68$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($cause$jscomp$102_map__75286__$1_temp__5825__auto___75327$$){$APP.$cljs$core$reset_BANG_$$($submitted_QMARK_$$,!1);$cause$jscomp$102_map__75286__$1_temp__5825__auto___75327$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$ex_data$$($cause$jscomp$102_map__75286__$1_temp__5825__auto___75327$$));var $type$jscomp$602$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause$jscomp$102_map__75286__$1_temp__5825__auto___75327$$,
$APP.$cljs$cst$139$type$$),$code$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause$jscomp$102_map__75286__$1_temp__5825__auto___75327$$,$APP.$cljs$cst$273$code$$),$expr__75288$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$type$jscomp$602$$,$code$jscomp$57$$],null);if($APP.$cljs$core$truth_$$(function(){var $G__75291$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2561$restriction$$,
$cljs$cst$5388$email_does_not_match_invitation$$],null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__75291$$,$expr__75288$$):$APP.$cljs$core$_EQ_$$($G__75291$$,$expr__75288$$)}()))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.email-does-not-match-invitation")));if($APP.$cljs$core$truth_$$(function(){var $G__75295$$=
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2561$restriction$$,$cljs$cst$5389$registration_disabled$$],null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__75295$$,$expr__75288$$):$APP.$cljs$core$_EQ_$$($G__75295$$,$expr__75288$$)}()))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.registration-disabled")));
if($APP.$cljs$core$truth_$$(function(){var $G__75297$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2561$restriction$$,$cljs$cst$5133$email_domain_is_not_allowed$$],null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__75297$$,$expr__75288$$):$APP.$cljs$core$_EQ_$$($G__75297$$,$expr__75288$$)}()))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.email-domain-not-allowed")));
if($APP.$cljs$core$truth_$$(function(){var $G__75299$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2561$restriction$$,$APP.$cljs$cst$5131$email_has_permanent_bounces$$],null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__75299$$,$expr__75288$$):$APP.$cljs$core$_EQ_$$($G__75299$$,$expr__75288$$)}())||$APP.$cljs$core$truth_$$(function(){var $G__75301$$=new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2561$restriction$$,$APP.$cljs$cst$5132$email_has_complaints$$],null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__75301$$,$expr__75288$$):$APP.$cljs$core$_EQ_$$($G__75301$$,$expr__75288$$)}()))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.email-has-permanent-bounces",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$102_map__75286__$1_temp__5825__auto___75327$$)]))));if($APP.$cljs$core$truth_$$(function(){var $G__75305$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2252$validation$$,$APP.$cljs$cst$5390$email_already_exists$$],null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__75305$$,
$expr__75288$$):$APP.$cljs$core$_EQ_$$($G__75305$$,$expr__75288$$)}()))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.email-already-exists")));if($APP.$cljs$core$truth_$$(function(){var $G__75307$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2252$validation$$,$cljs$cst$5391$email_as_password$$],null);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__75307$$,$expr__75288$$):$APP.$cljs$core$_EQ_$$($G__75307$$,$expr__75288$$)}()))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$186$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$751$password$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.email-as-password")],null));$cause$jscomp$102_map__75286__$1_temp__5825__auto___75327$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause$jscomp$102_map__75286__$1_temp__5825__auto___75327$$,$cljs$cst$650$explain$$);$APP.$cljs$core$truth_$$($cause$jscomp$102_map__75286__$1_temp__5825__auto___75327$$)&&$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cause$jscomp$102_map__75286__$1_temp__5825__auto___75327$$]));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.generic")))}),$on_success$jscomp$54$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_success_callback$jscomp$3$$)],function($G__75309_params__$1$jscomp$53_token$jscomp$114$$){if($APP.$cljs$core$fn_QMARK_$$($on_success_callback$jscomp$3$$))return $G__75309_params__$1$jscomp$53_token$jscomp$114$$=
$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($G__75309_params__$1$jscomp$53_token$jscomp$114$$),$on_success_callback$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_success_callback$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($G__75309_params__$1$jscomp$53_token$jscomp$114$$):$on_success_callback$jscomp$3$$($G__75309_params__$1$jscomp$53_token$jscomp$114$$);if($APP.$cljs$cst$1134$invitation_token$$.$cljs$core$IFn$_invoke$arity$1$($G__75309_params__$1$jscomp$53_token$jscomp$114$$)!=null)return $G__75309_params__$1$jscomp$53_token$jscomp$114$$=
$APP.$cljs$cst$1134$invitation_token$$.$cljs$core$IFn$_invoke$arity$1$($G__75309_params__$1$jscomp$53_token$jscomp$114$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3304$auth_verify_token$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1136$token$$,$G__75309_params__$1$jscomp$53_token$jscomp$114$$],null)));if($APP.$cljs$core$truth_$$($APP.$cljs$cst$3315$is_active$$.$cljs$core$IFn$_invoke$arity$1$($G__75309_params__$1$jscomp$53_token$jscomp$114$$)))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$auth$login_from_register$$());
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5392$app_DOT_main_DOT_ui_DOT_auth_DOT_register_SLASH_email$$,$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($G__75309_params__$1$jscomp$53_token$jscomp$114$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$5393$auth_register_success$$))}),$on_register_profile$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_success$jscomp$54$$),$APP.$rumext$v2$adapt$$($on_error$jscomp$68$$)],function($params__$1$jscomp$54$$){$APP.$cljs$core$reset_BANG_$$($submitted_QMARK_$$,!0);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($on_success$jscomp$54$$,$on_error$jscomp$68$$,function(){return $APP.$cljs$core$reset_BANG_$$($submitted_QMARK_$$,!1)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5394$register_profile$$,
$params__$1$jscomp$54$$))});$initial$jscomp$35_on_submit$jscomp$15_props_75285$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_success_callback$jscomp$3$$)],function($form__$1$jscomp$18$$){$APP.$cljs$core$reset_BANG_$$($submitted_QMARK_$$,!0);var $create_welcome_file_QMARK_$$=$APP.$app$config$external_feature_flag$$("onboarding-03"),$cdata$jscomp$4$$=function(){var $G__75310$$=$APP.$cljs$cst$5074$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form__$1$jscomp$18$$));
return $APP.$cljs$core$truth_$$($create_welcome_file_QMARK_$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__75310$$,$APP.$cljs$cst$5395$create_welcome_file$$,!0):$G__75310$$}();return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($on_register_profile$$,$on_error$jscomp$68$$,function(){return $APP.$cljs$core$reset_BANG_$$($submitted_QMARK_$$,!1)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5396$prepare_register_profile$$,$cdata$jscomp$4$$))});
return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,{"on-submit":$initial$jscomp$35_on_submit$jscomp$15_props_75285$$,form:$form$jscomp$186$$,children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_register__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{name:$APP.$cljs$cst$1360$fullname$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.fullname"),type:"text","show-success?":!0,"class":"main_ui_auth_register__form-field"})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_register__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{type:"text",name:$APP.$cljs$cst$3183$email$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.work-email"),"data-testid":"email-input","show-success?":!0,"class":"main_ui_auth_register__form-field"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_register__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,
{name:$APP.$cljs$cst$751$password$$,hint:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.password-length-hint"),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.password"),"show-success?":!0,type:"password","class":"main_ui_auth_register__form-field"})}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1231$terms_and_privacy_checkbox$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$terms_and_privacy_STAR_$$,{}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$newsletter_options_STAR_$$,
{}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.register-submit"),disabled:$APP.$cljs$core$_deref$$($submitted_QMARK_$$),"data-testid":"register-form-submit",className:"main_ui_auth_register__register-btn"})]})};
$APP.$app$main$ui$auth$register$register_methods_STAR_$$=function($on_success_callback$jscomp$4_props_75311$$){var $hide_separator$$=$on_success_callback$jscomp$4_props_75311$$.hideSeparator,$params$jscomp$408$$=$on_success_callback$jscomp$4_props_75311$$.params;$on_success_callback$jscomp$4_props_75311$$=$on_success_callback$jscomp$4_props_75311$$.onSuccessCallback;return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($app$main$ui$auth$login$show_sso_login_buttons_QMARK_$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$auth$login$login_sso_buttons_STAR_$$,{params:$params$jscomp$408$$}):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($app$main$ui$auth$login$show_sso_login_buttons_QMARK_$$)?$app$main$ui$auth$login$show_sso_login_buttons_QMARK_$$:$hide_separator$$===!1)?(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_auth_register__separator"}):null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1168$login_with_password$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$register_form_STAR_$$,
{params:$params$jscomp$408$$,onSuccessCallback:$on_success_callback$jscomp$4_props_75311$$}):null]})};
$APP.$app$main$ui$auth$register$register_success_page_STAR_$$=function($email$jscomp$17_or__5025__auto__$jscomp$inline_8003_props_75315$$){$email$jscomp$17_or__5025__auto__$jscomp$inline_8003_props_75315$$=$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($email$jscomp$17_or__5025__auto__$jscomp$inline_8003_props_75315$$.params);$email$jscomp$17_or__5025__auto__$jscomp$inline_8003_props_75315$$=$APP.$cljs$core$truth_$$($email$jscomp$17_or__5025__auto__$jscomp$inline_8003_props_75315$$)?
$email$jscomp$17_or__5025__auto__$jscomp$inline_8003_props_75315$$:$APP.$cljs$cst$5392$app_DOT_main_DOT_ui_DOT_auth_DOT_register_SLASH_email$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$user$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_auth_register__auth-form-wrapper main_ui_auth_register__register-success",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_auth_register__auth-title-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_auth_register__auth-title",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.check-mail")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_register__notification-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.verification-email-sent")})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_register__notification-text-email",children:$email$jscomp$17_or__5025__auto__$jscomp$inline_8003_props_75315$$})]})};
$APP.$app$main$ui$auth$register$terms_register_STAR_$$=function(){var $show_all_QMARK_$$=$APP.$cljs$core$truth_$$($APP.$app$config$terms_of_service_uri$$)?$app$config$privacy_policy_uri$$:$APP.$app$config$terms_of_service_uri$$,$show_terms_QMARK_$$=$APP.$app$config$terms_of_service_uri$$!=null,$show_privacy_QMARK_$$=$app$config$privacy_policy_uri$$!=null;return $APP.$cljs$core$truth_$$($show_all_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_auth_register__terms-register",children:[$show_terms_QMARK_$$?
(0,$APP.$rumext$v2$jsx$$)("a",{href:$APP.$app$config$terms_of_service_uri$$,target:"_blank",className:"main_ui_auth_register__auth-link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.terms-of-service")}):null,$APP.$cljs$core$truth_$$($show_all_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_auth_register__and-text",children:" "+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.and")??"")+"  "}):null,$show_privacy_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("a",
{href:$app$config$privacy_policy_uri$$,target:"_blank",className:"main_ui_auth_register__auth-link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.privacy-policy")}):null]}):null};
$app$main$ui$viewer$shapes$ignore_frame_shape$$=function($shape$jscomp$969_shape__$1$jscomp$100$$,$objects$jscomp$745_objects__$1$jscomp$34$$,$manual_QMARK_$$){var $and__5023__auto__$jscomp$inline_13135$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$969_shape__$1$jscomp$100$$);$shape$jscomp$969_shape__$1$jscomp$100$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13135$$)?$APP.$cljs$core$not$$($manual_QMARK_$$):$and__5023__auto__$jscomp$inline_13135$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$969_shape__$1$jscomp$100$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1611$rect$$):$shape$jscomp$969_shape__$1$jscomp$100$$;$objects$jscomp$745_objects__$1$jscomp$34$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$745_objects__$1$jscomp$34$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$969_shape__$1$jscomp$100$$),$shape$jscomp$969_shape__$1$jscomp$100$$);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$969_shape__$1$jscomp$100$$,$objects$jscomp$745_objects__$1$jscomp$34$$],null)};
$app$main$ui$viewer$shapes$activate_interaction$$=function($interaction$jscomp$42$$,$shape$jscomp$970$$,$base_frame$jscomp$2$$,$frame_offset$jscomp$1_position$jscomp$190_temp__5825__auto__$jscomp$321$$,$dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$,$overlays$jscomp$3$$){var $G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$=$APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$);switch($G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$ instanceof
$APP.$cljs$core$Keyword$$?$G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$.$fqn$:null){case "navigate":return $frame_offset$jscomp$1_position$jscomp$190_temp__5825__auto__$jscomp$321$$=$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$),$APP.$cljs$core$truth_$$($frame_offset$jscomp$1_position$jscomp$190_temp__5825__auto__$jscomp$321$$)?($dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$=$APP.$goog$dom$getElement$$("viewer-section"),
$dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1968$preserve_scroll$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$))?$dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$!=null?$dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$.scrollTop:null:0,$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$viewer$set_nav_scroll$$($dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($frame_offset$jscomp$1_position$jscomp$190_temp__5825__auto__$jscomp$321$$,$APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$))]))):null;case "open-overlay":var $close_click_outside$jscomp$6_manual_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1673$manual$$,$APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$));
$dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$=$app$main$ui$viewer$shapes$ignore_frame_shape$$($shape$jscomp$970$$,$dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$,$close_click_outside$jscomp$6_manual_QMARK_$jscomp$1$$);$G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$,
0,null);var $objects__$1$jscomp$35$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$,1,null);$dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$=$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$);var $dest_frame$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$35$$,$dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$),
$relative_to_id$$=$close_click_outside$jscomp$6_manual_QMARK_$jscomp$1$$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$),$APP.$cljs$cst$1606$frame$$)?$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$):$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$):
$APP.$cljs$cst$1974$position_relative_to$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$),$relative_to_shape$jscomp$1$$=function(){var $or__5025__auto__$jscomp$1040$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$35$$,$relative_to_id$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1040$$)?$or__5025__auto__$jscomp$1040$$:$base_frame$jscomp$2$$}();$close_click_outside$jscomp$6_manual_QMARK_$jscomp$1$$=$APP.$cljs$cst$1972$close_click_outside$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$);
var $background_overlay$jscomp$6$$=$APP.$cljs$cst$1973$background_overlay$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$),$fixed_base_QMARK__overlays_ids$jscomp$1$$=$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$overlays$jscomp$3$$)),$relative_to_base_frame$$=$app$main$ui$viewer$shapes$find_relative_to_base_frame$$($relative_to_shape$jscomp$1$$,$objects__$1$jscomp$35$$,$fixed_base_QMARK__overlays_ids$jscomp$1$$,$base_frame$jscomp$2$$);
$fixed_base_QMARK__overlays_ids$jscomp$1$$=$app$common$files$helpers$fixed_QMARK_$$($objects__$1$jscomp$35$$,$relative_to_id$$);$G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$=$app$common$types$shape$interactions$calc_overlay_position$$($interaction$jscomp$42$$,$G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$,$objects__$1$jscomp$35$$,$relative_to_shape$jscomp$1$$,$relative_to_base_frame$$,$dest_frame$jscomp$2$$,$frame_offset$jscomp$1_position$jscomp$190_temp__5825__auto__$jscomp$321$$);
$frame_offset$jscomp$1_position$jscomp$190_temp__5825__auto__$jscomp$321$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$,0,null);$G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$,1,null);return $APP.$cljs$core$truth_$$($dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$open_overlay$$($dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$,$frame_offset$jscomp$1_position$jscomp$190_temp__5825__auto__$jscomp$321$$,$G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$,$close_click_outside$jscomp$6_manual_QMARK_$jscomp$1$$,$background_overlay$jscomp$6$$,$APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$),
$fixed_base_QMARK__overlays_ids$jscomp$1$$)):null;case "toggle-overlay":return $close_click_outside$jscomp$6_manual_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1673$manual$$,$APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$)),$dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$=$app$main$ui$viewer$shapes$ignore_frame_shape$$($shape$jscomp$970$$,$dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$,
$close_click_outside$jscomp$6_manual_QMARK_$jscomp$1$$),$G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$,0,null),$objects__$1$jscomp$35$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$,1,null),$dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$=
$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$),$dest_frame$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$35$$,$dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$),$relative_to_id$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1673$manual$$,$APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$))?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$),
$APP.$cljs$cst$1606$frame$$)?$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$):$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$):$APP.$cljs$cst$1974$position_relative_to$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$),$relative_to_shape$jscomp$1$$=function(){var $or__5025__auto__$jscomp$1041$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$35$$,
$relative_to_id$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1041$$)?$or__5025__auto__$jscomp$1041$$:$base_frame$jscomp$2$$}(),$fixed_base_QMARK__overlays_ids$jscomp$1$$=$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$overlays$jscomp$3$$)),$relative_to_base_frame$$=$app$main$ui$viewer$shapes$find_relative_to_base_frame$$($relative_to_shape$jscomp$1$$,$objects__$1$jscomp$35$$,$fixed_base_QMARK__overlays_ids$jscomp$1$$,$base_frame$jscomp$2$$),
$fixed_base_QMARK__overlays_ids$jscomp$1$$=$app$common$files$helpers$fixed_QMARK_$$($objects__$1$jscomp$35$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($base_frame$jscomp$2$$)),$G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$=$app$common$types$shape$interactions$calc_overlay_position$$($interaction$jscomp$42$$,$G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$,$objects__$1$jscomp$35$$,$relative_to_shape$jscomp$1$$,$relative_to_base_frame$$,
$dest_frame$jscomp$2$$,$frame_offset$jscomp$1_position$jscomp$190_temp__5825__auto__$jscomp$321$$),$frame_offset$jscomp$1_position$jscomp$190_temp__5825__auto__$jscomp$321$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$,0,null),$G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$,
1,null),$close_click_outside$jscomp$6_manual_QMARK_$jscomp$1$$=$APP.$cljs$cst$1972$close_click_outside$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$),$background_overlay$jscomp$6$$=$APP.$cljs$cst$1973$background_overlay$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$),$APP.$cljs$core$truth_$$($dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$toggle_overlay$$($dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$,
$frame_offset$jscomp$1_position$jscomp$190_temp__5825__auto__$jscomp$321$$,$G__75337_shape__$1$jscomp$101_snap_to$jscomp$5_vec__75341_vec__75347$$,$close_click_outside$jscomp$6_manual_QMARK_$jscomp$1$$,$background_overlay$jscomp$6$$,$APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$),$fixed_base_QMARK__overlays_ids$jscomp$1$$)):null;case "close-overlay":return $dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$=function(){var $or__5025__auto__$jscomp$1042$$=
$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1042$$)?$or__5025__auto__$jscomp$1042$$:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$679$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$970$$),$APP.$cljs$cst$1606$frame$$);return $and__5023__auto__$jscomp$679$$?$APP.$cljs$core$some$$(function($p1__75336_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__75336_SHARP_$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$970$$))},$overlays$jscomp$3$$):$and__5023__auto__$jscomp$679$$}())?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$970$$):$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$970$$)}(),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($dest_frame_id_objects$jscomp$746_scroll$jscomp$4_vec__75338_vec__75344_viewer_section$$,
$APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$)));case "prev-screen":return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$router$nav_back_local$$());case "open-url":return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1975$url$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$42$$)));default:return null}};
$app$main$ui$viewer$shapes$deactivate_interaction$$=function($interaction$jscomp$43$$,$shape$jscomp$971$$,$base_frame$jscomp$3$$,$frame_id$jscomp$134_frame_offset$jscomp$2_position$jscomp$191$$,$dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$,$fixed_base_QMARK_$jscomp$1_overlays$jscomp$4_overlays_ids$jscomp$2$$){var $G__75350_close_click_outside$jscomp$7_manual_QMARK_$jscomp$2_vec__75354$$=$APP.$cljs$cst$1966$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$);
switch($G__75350_close_click_outside$jscomp$7_manual_QMARK_$jscomp$2_vec__75354$$ instanceof $APP.$cljs$core$Keyword$$?$G__75350_close_click_outside$jscomp$7_manual_QMARK_$jscomp$2_vec__75354$$.$fqn$:null){case "open-overlay":$frame_id$jscomp$134_frame_offset$jscomp$2_position$jscomp$191$$=function(){var $or__5025__auto__$jscomp$1043$$=$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1043$$)?$or__5025__auto__$jscomp$1043$$:
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$971$$),$APP.$cljs$cst$1606$frame$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$971$$):$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$971$$)}();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($frame_id$jscomp$134_frame_offset$jscomp$2_position$jscomp$191$$,
null));break;case "toggle-overlay":$G__75350_close_click_outside$jscomp$7_manual_QMARK_$jscomp$2_vec__75354$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1673$manual$$,$APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$));$dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$=$app$main$ui$viewer$shapes$ignore_frame_shape$$($shape$jscomp$971$$,$dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$,$G__75350_close_click_outside$jscomp$7_manual_QMARK_$jscomp$2_vec__75354$$);
var $shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$,0,null),$objects__$1$jscomp$36$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$,1,null);$dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$=$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$);
var $dest_frame$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$36$$,$dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$),$relative_to_id$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1673$manual$$,$APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$))?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$),
$APP.$cljs$cst$1606$frame$$)?$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$):$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$):$APP.$cljs$cst$1974$position_relative_to$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$),$relative_to_shape$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1044$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$36$$,
$relative_to_id$jscomp$1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1044$$)?$or__5025__auto__$jscomp$1044$$:$base_frame$jscomp$3$$}();$fixed_base_QMARK_$jscomp$1_overlays$jscomp$4_overlays_ids$jscomp$2$$=$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$fixed_base_QMARK_$jscomp$1_overlays$jscomp$4_overlays_ids$jscomp$2$$));var $relative_to_base_frame$jscomp$1$$=$app$main$ui$viewer$shapes$find_relative_to_base_frame$$($relative_to_shape$jscomp$2$$,
$objects__$1$jscomp$36$$,$fixed_base_QMARK_$jscomp$1_overlays$jscomp$4_overlays_ids$jscomp$2$$,$base_frame$jscomp$3$$);$fixed_base_QMARK_$jscomp$1_overlays$jscomp$4_overlays_ids$jscomp$2$$=$app$common$files$helpers$fixed_QMARK_$$($objects__$1$jscomp$36$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($base_frame$jscomp$3$$));$G__75350_close_click_outside$jscomp$7_manual_QMARK_$jscomp$2_vec__75354$$=$app$common$types$shape$interactions$calc_overlay_position$$($interaction$jscomp$43$$,$shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$,
$objects__$1$jscomp$36$$,$relative_to_shape$jscomp$2$$,$relative_to_base_frame$jscomp$1$$,$dest_frame$jscomp$3$$,$frame_id$jscomp$134_frame_offset$jscomp$2_position$jscomp$191$$);$frame_id$jscomp$134_frame_offset$jscomp$2_position$jscomp$191$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__75350_close_click_outside$jscomp$7_manual_QMARK_$jscomp$2_vec__75354$$,0,null);$shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__75350_close_click_outside$jscomp$7_manual_QMARK_$jscomp$2_vec__75354$$,
1,null);$G__75350_close_click_outside$jscomp$7_manual_QMARK_$jscomp$2_vec__75354$$=$APP.$cljs$cst$1972$close_click_outside$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$);var $background_overlay$jscomp$7$$=$APP.$cljs$cst$1973$background_overlay$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$);$APP.$cljs$core$truth_$$($dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$toggle_overlay$$($dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$,
$frame_id$jscomp$134_frame_offset$jscomp$2_position$jscomp$191$$,$shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$,$G__75350_close_click_outside$jscomp$7_manual_QMARK_$jscomp$2_vec__75354$$,$background_overlay$jscomp$7$$,$APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$),$fixed_base_QMARK_$jscomp$1_overlays$jscomp$4_overlays_ids$jscomp$2$$));break;case "close-overlay":$G__75350_close_click_outside$jscomp$7_manual_QMARK_$jscomp$2_vec__75354$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1673$manual$$,
$APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$)),$dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$=$app$main$ui$viewer$shapes$ignore_frame_shape$$($shape$jscomp$971$$,$dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$,$G__75350_close_click_outside$jscomp$7_manual_QMARK_$jscomp$2_vec__75354$$),$shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$,
0,null),$objects__$1$jscomp$36$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$,1,null),$dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$=$APP.$cljs$cst$1967$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$),$dest_frame$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$36$$,$dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$),$relative_to_id$jscomp$1$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1673$manual$$,$APP.$cljs$cst$1971$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$))?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$),$APP.$cljs$cst$1606$frame$$)?$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$):$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$):
$APP.$cljs$cst$1974$position_relative_to$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$),$relative_to_shape$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1045$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$36$$,$relative_to_id$jscomp$1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1045$$)?$or__5025__auto__$jscomp$1045$$:$base_frame$jscomp$3$$}(),$G__75350_close_click_outside$jscomp$7_manual_QMARK_$jscomp$2_vec__75354$$=$APP.$cljs$cst$1972$close_click_outside$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$),
$background_overlay$jscomp$7$$=$APP.$cljs$cst$1973$background_overlay$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$),$fixed_base_QMARK_$jscomp$1_overlays$jscomp$4_overlays_ids$jscomp$2$$=$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$fixed_base_QMARK_$jscomp$1_overlays$jscomp$4_overlays_ids$jscomp$2$$)),$relative_to_base_frame$jscomp$1$$=$app$main$ui$viewer$shapes$find_relative_to_base_frame$$($relative_to_shape$jscomp$2$$,$objects__$1$jscomp$36$$,
$fixed_base_QMARK_$jscomp$1_overlays$jscomp$4_overlays_ids$jscomp$2$$,$base_frame$jscomp$3$$),$fixed_base_QMARK_$jscomp$1_overlays$jscomp$4_overlays_ids$jscomp$2$$=$app$common$files$helpers$fixed_QMARK_$$($objects__$1$jscomp$36$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($base_frame$jscomp$3$$)),$shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$=$app$common$types$shape$interactions$calc_overlay_position$$($interaction$jscomp$43$$,$shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$,
$objects__$1$jscomp$36$$,$relative_to_shape$jscomp$2$$,$relative_to_base_frame$jscomp$1$$,$dest_frame$jscomp$3$$,$frame_id$jscomp$134_frame_offset$jscomp$2_position$jscomp$191$$),$frame_id$jscomp$134_frame_offset$jscomp$2_position$jscomp$191$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$,0,null),$shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$,
1,null),$APP.$cljs$core$truth_$$($dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$open_overlay$$($dest_frame_id$jscomp$1_objects$jscomp$747_vec__75351_vec__75357$$,$frame_id$jscomp$134_frame_offset$jscomp$2_position$jscomp$191$$,$shape__$1$jscomp$102_snap_to$jscomp$6_vec__75360$$,$G__75350_close_click_outside$jscomp$7_manual_QMARK_$jscomp$2_vec__75354$$,$background_overlay$jscomp$7$$,$APP.$cljs$cst$1969$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$43$$),
$fixed_base_QMARK_$jscomp$1_overlays$jscomp$4_overlays_ids$jscomp$2$$))}};
$app$main$ui$viewer$shapes$on_pointer_down$$=function($c__5548__auto__$jscomp$32_event$jscomp$271_seq__75364_temp__5825__auto__$jscomp$322$$,$shape$jscomp$972$$,$base_frame$jscomp$4$$,$frame_offset$jscomp$3$$,$objects$jscomp$748$$,$overlays$jscomp$5$$){var $G__75528_chunk__75365_interactions$jscomp$14_seq__75364__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75363_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__75363_SHARP_$$),$APP.$cljs$cst$1939$click$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__75363_SHARP_$$),$cljs$cst$1940$mouse_press$$)},$APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$972$$));if($APP.$cljs$core$seq$$($G__75528_chunk__75365_interactions$jscomp$14_seq__75364__$1$$)){$APP.$app$util$dom$stop_propagation$$($c__5548__auto__$jscomp$32_event$jscomp$271_seq__75364_temp__5825__auto__$jscomp$322$$);$c__5548__auto__$jscomp$32_event$jscomp$271_seq__75364_temp__5825__auto__$jscomp$322$$=
$APP.$cljs$core$seq$$($G__75528_chunk__75365_interactions$jscomp$14_seq__75364__$1$$);$G__75528_chunk__75365_interactions$jscomp$14_seq__75364__$1$$=null;for(var $G__75527_count__75366$$=0,$i__75367$$=0;;)if($i__75367$$<$G__75527_count__75366$$){var $G__75529_interaction$jscomp$44$$=$G__75528_chunk__75365_interactions$jscomp$14_seq__75364__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__75367$$);$app$main$ui$viewer$shapes$activate_interaction$$($G__75529_interaction$jscomp$44$$,$shape$jscomp$972$$,
$base_frame$jscomp$4$$,$frame_offset$jscomp$3$$,$objects$jscomp$748$$,$overlays$jscomp$5$$);$i__75367$$+=1}else if($c__5548__auto__$jscomp$32_event$jscomp$271_seq__75364_temp__5825__auto__$jscomp$322$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$32_event$jscomp$271_seq__75364_temp__5825__auto__$jscomp$322$$))$G__75528_chunk__75365_interactions$jscomp$14_seq__75364__$1$$=$c__5548__auto__$jscomp$32_event$jscomp$271_seq__75364_temp__5825__auto__$jscomp$322$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__75528_chunk__75365_interactions$jscomp$14_seq__75364__$1$$)?
($c__5548__auto__$jscomp$32_event$jscomp$271_seq__75364_temp__5825__auto__$jscomp$322$$=$APP.$cljs$core$_chunked_first$$($G__75528_chunk__75365_interactions$jscomp$14_seq__75364__$1$$),$G__75527_count__75366$$=$APP.$cljs$core$_chunked_rest$$($G__75528_chunk__75365_interactions$jscomp$14_seq__75364__$1$$),$G__75528_chunk__75365_interactions$jscomp$14_seq__75364__$1$$=$c__5548__auto__$jscomp$32_event$jscomp$271_seq__75364_temp__5825__auto__$jscomp$322$$,$G__75529_interaction$jscomp$44$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$32_event$jscomp$271_seq__75364_temp__5825__auto__$jscomp$322$$),
$c__5548__auto__$jscomp$32_event$jscomp$271_seq__75364_temp__5825__auto__$jscomp$322$$=$G__75527_count__75366$$,$G__75527_count__75366$$=$G__75529_interaction$jscomp$44$$):($G__75529_interaction$jscomp$44$$=$APP.$cljs$core$first$$($G__75528_chunk__75365_interactions$jscomp$14_seq__75364__$1$$),$app$main$ui$viewer$shapes$activate_interaction$$($G__75529_interaction$jscomp$44$$,$shape$jscomp$972$$,$base_frame$jscomp$4$$,$frame_offset$jscomp$3$$,$objects$jscomp$748$$,$overlays$jscomp$5$$),$c__5548__auto__$jscomp$32_event$jscomp$271_seq__75364_temp__5825__auto__$jscomp$322$$=
$APP.$cljs$core$next$$($G__75528_chunk__75365_interactions$jscomp$14_seq__75364__$1$$),$G__75528_chunk__75365_interactions$jscomp$14_seq__75364__$1$$=null,$G__75527_count__75366$$=0),$i__75367$$=0;else return null}else return null};
$app$main$ui$viewer$shapes$on_pointer_up$$=function($c__5548__auto__$jscomp$33_event$jscomp$272_seq__75381_temp__5825__auto__$jscomp$323$$,$shape$jscomp$973$$,$base_frame$jscomp$5$$,$frame_offset$jscomp$4$$,$objects$jscomp$749$$,$overlays$jscomp$6$$){var $G__75542_chunk__75382_interactions$jscomp$15_seq__75381__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75380_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__75380_SHARP_$$),
$cljs$cst$1940$mouse_press$$)},$APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$973$$));if($APP.$cljs$core$seq$$($G__75542_chunk__75382_interactions$jscomp$15_seq__75381__$1$$)){$APP.$app$util$dom$stop_propagation$$($c__5548__auto__$jscomp$33_event$jscomp$272_seq__75381_temp__5825__auto__$jscomp$323$$);$c__5548__auto__$jscomp$33_event$jscomp$272_seq__75381_temp__5825__auto__$jscomp$323$$=$APP.$cljs$core$seq$$($G__75542_chunk__75382_interactions$jscomp$15_seq__75381__$1$$);
$G__75542_chunk__75382_interactions$jscomp$15_seq__75381__$1$$=null;for(var $G__75541_count__75384$$=0,$i__75385$$=0;;)if($i__75385$$<$G__75541_count__75384$$){var $G__75543_interaction$jscomp$45$$=$G__75542_chunk__75382_interactions$jscomp$15_seq__75381__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__75385$$);$app$main$ui$viewer$shapes$deactivate_interaction$$($G__75543_interaction$jscomp$45$$,$shape$jscomp$973$$,$base_frame$jscomp$5$$,$frame_offset$jscomp$4$$,$objects$jscomp$749$$,$overlays$jscomp$6$$);
$i__75385$$+=1}else if($c__5548__auto__$jscomp$33_event$jscomp$272_seq__75381_temp__5825__auto__$jscomp$323$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$33_event$jscomp$272_seq__75381_temp__5825__auto__$jscomp$323$$))$G__75542_chunk__75382_interactions$jscomp$15_seq__75381__$1$$=$c__5548__auto__$jscomp$33_event$jscomp$272_seq__75381_temp__5825__auto__$jscomp$323$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__75542_chunk__75382_interactions$jscomp$15_seq__75381__$1$$)?($c__5548__auto__$jscomp$33_event$jscomp$272_seq__75381_temp__5825__auto__$jscomp$323$$=
$APP.$cljs$core$_chunked_first$$($G__75542_chunk__75382_interactions$jscomp$15_seq__75381__$1$$),$G__75541_count__75384$$=$APP.$cljs$core$_chunked_rest$$($G__75542_chunk__75382_interactions$jscomp$15_seq__75381__$1$$),$G__75542_chunk__75382_interactions$jscomp$15_seq__75381__$1$$=$c__5548__auto__$jscomp$33_event$jscomp$272_seq__75381_temp__5825__auto__$jscomp$323$$,$G__75543_interaction$jscomp$45$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$33_event$jscomp$272_seq__75381_temp__5825__auto__$jscomp$323$$),
$c__5548__auto__$jscomp$33_event$jscomp$272_seq__75381_temp__5825__auto__$jscomp$323$$=$G__75541_count__75384$$,$G__75541_count__75384$$=$G__75543_interaction$jscomp$45$$):($G__75543_interaction$jscomp$45$$=$APP.$cljs$core$first$$($G__75542_chunk__75382_interactions$jscomp$15_seq__75381__$1$$),$app$main$ui$viewer$shapes$deactivate_interaction$$($G__75543_interaction$jscomp$45$$,$shape$jscomp$973$$,$base_frame$jscomp$5$$,$frame_offset$jscomp$4$$,$objects$jscomp$749$$,$overlays$jscomp$6$$),$c__5548__auto__$jscomp$33_event$jscomp$272_seq__75381_temp__5825__auto__$jscomp$323$$=
$APP.$cljs$core$next$$($G__75542_chunk__75382_interactions$jscomp$15_seq__75381__$1$$),$G__75542_chunk__75382_interactions$jscomp$15_seq__75381__$1$$=null,$G__75541_count__75384$$=0),$i__75385$$=0;else return null}else return null};
$app$main$ui$viewer$shapes$on_pointer_enter$$=function($c__5548__auto__$jscomp$34_event$jscomp$273_seq__75387_temp__5825__auto__$jscomp$324$$,$shape$jscomp$974$$,$base_frame$jscomp$6$$,$frame_offset$jscomp$5$$,$objects$jscomp$750$$,$overlays$jscomp$7$$){var $G__75558_chunk__75388_interactions$jscomp$16_seq__75387__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75386_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__75386_SHARP_$$),
$APP.$cljs$cst$1938$mouse_enter$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__75386_SHARP_$$),$cljs$cst$1937$mouse_over$$)},$APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$974$$));if($APP.$cljs$core$seq$$($G__75558_chunk__75388_interactions$jscomp$16_seq__75387__$1$$)){$APP.$app$util$dom$stop_propagation$$($c__5548__auto__$jscomp$34_event$jscomp$273_seq__75387_temp__5825__auto__$jscomp$324$$);
$c__5548__auto__$jscomp$34_event$jscomp$273_seq__75387_temp__5825__auto__$jscomp$324$$=$APP.$cljs$core$seq$$($G__75558_chunk__75388_interactions$jscomp$16_seq__75387__$1$$);$G__75558_chunk__75388_interactions$jscomp$16_seq__75387__$1$$=null;for(var $G__75557_count__75389$$=0,$i__75390$$=0;;)if($i__75390$$<$G__75557_count__75389$$){var $G__75559_interaction$jscomp$46$$=$G__75558_chunk__75388_interactions$jscomp$16_seq__75387__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__75390$$);$app$main$ui$viewer$shapes$activate_interaction$$($G__75559_interaction$jscomp$46$$,
$shape$jscomp$974$$,$base_frame$jscomp$6$$,$frame_offset$jscomp$5$$,$objects$jscomp$750$$,$overlays$jscomp$7$$);$i__75390$$+=1}else if($c__5548__auto__$jscomp$34_event$jscomp$273_seq__75387_temp__5825__auto__$jscomp$324$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$34_event$jscomp$273_seq__75387_temp__5825__auto__$jscomp$324$$))$G__75558_chunk__75388_interactions$jscomp$16_seq__75387__$1$$=$c__5548__auto__$jscomp$34_event$jscomp$273_seq__75387_temp__5825__auto__$jscomp$324$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__75558_chunk__75388_interactions$jscomp$16_seq__75387__$1$$)?
($c__5548__auto__$jscomp$34_event$jscomp$273_seq__75387_temp__5825__auto__$jscomp$324$$=$APP.$cljs$core$_chunked_first$$($G__75558_chunk__75388_interactions$jscomp$16_seq__75387__$1$$),$G__75557_count__75389$$=$APP.$cljs$core$_chunked_rest$$($G__75558_chunk__75388_interactions$jscomp$16_seq__75387__$1$$),$G__75558_chunk__75388_interactions$jscomp$16_seq__75387__$1$$=$c__5548__auto__$jscomp$34_event$jscomp$273_seq__75387_temp__5825__auto__$jscomp$324$$,$G__75559_interaction$jscomp$46$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$34_event$jscomp$273_seq__75387_temp__5825__auto__$jscomp$324$$),
$c__5548__auto__$jscomp$34_event$jscomp$273_seq__75387_temp__5825__auto__$jscomp$324$$=$G__75557_count__75389$$,$G__75557_count__75389$$=$G__75559_interaction$jscomp$46$$):($G__75559_interaction$jscomp$46$$=$APP.$cljs$core$first$$($G__75558_chunk__75388_interactions$jscomp$16_seq__75387__$1$$),$app$main$ui$viewer$shapes$activate_interaction$$($G__75559_interaction$jscomp$46$$,$shape$jscomp$974$$,$base_frame$jscomp$6$$,$frame_offset$jscomp$5$$,$objects$jscomp$750$$,$overlays$jscomp$7$$),$c__5548__auto__$jscomp$34_event$jscomp$273_seq__75387_temp__5825__auto__$jscomp$324$$=
$APP.$cljs$core$next$$($G__75558_chunk__75388_interactions$jscomp$16_seq__75387__$1$$),$G__75558_chunk__75388_interactions$jscomp$16_seq__75387__$1$$=null,$G__75557_count__75389$$=0),$i__75390$$=0;else return null}else return null};
$app$main$ui$viewer$shapes$on_pointer_leave$$=function($G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$,$shape$jscomp$975$$,$base_frame$jscomp$7$$,$frame_offset$jscomp$6$$,$objects$jscomp$751$$,$overlays$jscomp$8$$){var $G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75394_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__75394_SHARP_$$),
$APP.$cljs$cst$1936$mouse_leave$$)},$APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$975$$)),$c__5548__auto__$jscomp$35_interactions_inv_seq__75403_temp__5825__auto__$jscomp$325$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75395_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__75395_SHARP_$$),$cljs$cst$1937$mouse_over$$)},$APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$975$$));
if($APP.$cljs$core$seq$$($G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$)||$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$35_interactions_inv_seq__75403_temp__5825__auto__$jscomp$325$$)){$APP.$app$util$dom$stop_propagation$$($G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$);$G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$=
$APP.$cljs$core$seq$$($G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$);$G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$=null;for(var $G__75579_G__75592_count__75401_75567_count__75405$$=0,$G__75577_i__75402_75568_i__75406$$=0;;)if($G__75577_i__75402_75568_i__75406$$<$G__75579_G__75592_count__75401_75567_count__75405$$){var $interaction_75569$$=$G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$G__75577_i__75402_75568_i__75406$$);$app$main$ui$viewer$shapes$activate_interaction$$($interaction_75569$$,$shape$jscomp$975$$,$base_frame$jscomp$7$$,$frame_offset$jscomp$6$$,$objects$jscomp$751$$,$overlays$jscomp$8$$);$G__75577_i__75402_75568_i__75406$$+=1}else if($G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$=$APP.$cljs$core$seq$$($G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$))$G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$=
$G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$)?($G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$=$APP.$cljs$core$_chunked_first$$($G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$),
$G__75577_i__75402_75568_i__75406$$=$APP.$cljs$core$_chunked_rest$$($G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$),$G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$=$G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$,$G__75579_G__75592_count__75401_75567_count__75405$$=$APP.$cljs$core$count$$($G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$),
$G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$=$G__75577_i__75402_75568_i__75406$$):($G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$=$APP.$cljs$core$first$$($G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$),$app$main$ui$viewer$shapes$activate_interaction$$($G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$,
$shape$jscomp$975$$,$base_frame$jscomp$7$$,$frame_offset$jscomp$6$$,$objects$jscomp$751$$,$overlays$jscomp$8$$),$G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$=$APP.$cljs$core$next$$($G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$),$G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$=null,$G__75579_G__75592_count__75401_75567_count__75405$$=
0),$G__75577_i__75402_75568_i__75406$$=0;else break;$c__5548__auto__$jscomp$35_interactions_inv_seq__75403_temp__5825__auto__$jscomp$325$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$35_interactions_inv_seq__75403_temp__5825__auto__$jscomp$325$$);$G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$=null;for($G__75577_i__75402_75568_i__75406$$=$G__75579_G__75592_count__75401_75567_count__75405$$=0;;)if($G__75577_i__75402_75568_i__75406$$<
$G__75579_G__75592_count__75401_75567_count__75405$$)$G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$=$G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__75577_i__75402_75568_i__75406$$),$app$main$ui$viewer$shapes$deactivate_interaction$$($G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$,
$shape$jscomp$975$$,$base_frame$jscomp$7$$,$frame_offset$jscomp$6$$,$objects$jscomp$751$$,$overlays$jscomp$8$$),$G__75577_i__75402_75568_i__75406$$+=1;else if($c__5548__auto__$jscomp$35_interactions_inv_seq__75403_temp__5825__auto__$jscomp$325$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$35_interactions_inv_seq__75403_temp__5825__auto__$jscomp$325$$))$G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$=$c__5548__auto__$jscomp$35_interactions_inv_seq__75403_temp__5825__auto__$jscomp$325$$,
$APP.$cljs$core$chunked_seq_QMARK_$$($G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$)?($c__5548__auto__$jscomp$35_interactions_inv_seq__75403_temp__5825__auto__$jscomp$325$$=$APP.$cljs$core$_chunked_first$$($G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$),$G__75579_G__75592_count__75401_75567_count__75405$$=$APP.$cljs$core$_chunked_rest$$($G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$),
$G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$=$c__5548__auto__$jscomp$35_interactions_inv_seq__75403_temp__5825__auto__$jscomp$325$$,$G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$35_interactions_inv_seq__75403_temp__5825__auto__$jscomp$325$$),$c__5548__auto__$jscomp$35_interactions_inv_seq__75403_temp__5825__auto__$jscomp$325$$=
$G__75579_G__75592_count__75401_75567_count__75405$$,$G__75579_G__75592_count__75401_75567_count__75405$$=$G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$):($G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$=$APP.$cljs$core$first$$($G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$),$app$main$ui$viewer$shapes$deactivate_interaction$$($G__75578_G__75594_chunk__75400_75566_interaction$jscomp$47_interactions$jscomp$17_seq__75399_75575__$1$$,
$shape$jscomp$975$$,$base_frame$jscomp$7$$,$frame_offset$jscomp$6$$,$objects$jscomp$751$$,$overlays$jscomp$8$$),$c__5548__auto__$jscomp$35_interactions_inv_seq__75403_temp__5825__auto__$jscomp$325$$=$APP.$cljs$core$next$$($G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$),$G__75593_c__5548__auto___75576_chunk__75404_event$jscomp$274_interaction_75581_seq__75399_75565_seq__75403__$1_temp__5825__auto___75574$$=
null,$G__75579_G__75592_count__75401_75567_count__75405$$=0),$G__75577_i__75402_75568_i__75406$$=0;else return null}else return null};
$app$main$ui$viewer$shapes$on_load$$=function($shape$jscomp$976$$,$base_frame$jscomp$8$$,$frame_offset$jscomp$7$$,$objects$jscomp$752$$,$overlays$jscomp$9$$){for(var $interactions$jscomp$18$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75407_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__75407_SHARP_$$),$APP.$cljs$cst$1935$after_delay$$)},$APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$976$$)),
$G__75601_interactions__$1$jscomp$2$$=$APP.$cljs$core$seq$$($interactions$jscomp$18$$),$G__75602_sems$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $sem$jscomp$9_temp__5823__auto__$jscomp$214$$=$APP.$cljs$core$first$$($G__75601_interactions__$1$jscomp$2$$);if($APP.$cljs$core$truth_$$($sem$jscomp$9_temp__5823__auto__$jscomp$214$$)){var $interaction$jscomp$48$$=$sem$jscomp$9_temp__5823__auto__$jscomp$214$$;$sem$jscomp$9_temp__5823__auto__$jscomp$214$$=$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1325$delay$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$48$$),
function($interactions__$1$jscomp$3$$,$sems$jscomp$1$$,$interaction$jscomp$49$$){return function(){return $app$main$ui$viewer$shapes$activate_interaction$$($interaction$jscomp$49$$,$shape$jscomp$976$$,$base_frame$jscomp$8$$,$frame_offset$jscomp$7$$,$objects$jscomp$752$$,$overlays$jscomp$9$$)}}($G__75601_interactions__$1$jscomp$2$$,$G__75602_sems$$,$interaction$jscomp$48$$,$sem$jscomp$9_temp__5823__auto__$jscomp$214$$,$interactions$jscomp$18$$));$G__75601_interactions__$1$jscomp$2$$=$APP.$cljs$core$next$$($G__75601_interactions__$1$jscomp$2$$);
$G__75602_sems$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__75602_sems$$,$sem$jscomp$9_temp__5823__auto__$jscomp$214$$)}else return $G__75602_sems$$}};
$app$main$ui$viewer$shapes$interaction$$=function($map__75414_props_75412_shape$jscomp$977$$){$map__75414_props_75412_shape$jscomp$977$$=$APP.$rumext$v2$util$wrap_props$$($map__75414_props_75412_shape$jscomp$977$$);var $map__75414__$1_show_interactions$$=$APP.$cljs$core$__destructure_map$$($map__75414_props_75412_shape$jscomp$977$$);$map__75414_props_75412_shape$jscomp$977$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75414__$1_show_interactions$$,$APP.$cljs$cst$1811$shape$$);var $interactions$jscomp$20$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75414__$1_show_interactions$$,$APP.$cljs$cst$2051$interactions$$);$map__75414__$1_show_interactions$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75414__$1_show_interactions$$,$cljs$cst$5232$show_interactions$$);var $map__75415_x$jscomp$1242$$=$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($map__75414_props_75412_shape$jscomp$977$$),$height$jscomp$158_map__75415__$1$$=$APP.$cljs$core$__destructure_map$$($map__75415_x$jscomp$1242$$);
$map__75415_x$jscomp$1242$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$158_map__75415__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$462$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$158_map__75415__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$181$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$158_map__75415__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$158_map__75415__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$158_map__75415__$1$$,
$APP.$cljs$cst$1522$height$$);return $APP.$cljs$core$empty_QMARK_$$($interactions$jscomp$20$$)?null:(0,$APP.$rumext$v2$jsx$$)("rect",{width:$width$jscomp$181$$+2,height:$height$jscomp$158_map__75415__$1$$+2,x:$map__75415_x$jscomp$1242$$-1,transform:$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($map__75414_props_75412_shape$jscomp$977$$),stroke:"var(--color-accent-tertiary)",fill:"var(--color-accent-tertiary)",strokeWidth:$APP.$cljs$core$truth_$$($map__75414__$1_show_interactions$$)?
1:0,y:$y$jscomp$462$$-1,fillOpacity:$APP.$cljs$core$truth_$$($map__75414__$1_show_interactions$$)?.2:0})};
$app$main$ui$viewer$shapes$generic_wrapper_factory$$=function($component$jscomp$120$$){return function($props_75421$$){var $shape$jscomp$978$$=$props_75421$$.shape,$childs$jscomp$21$$=$props_75421$$.childs,$frame$jscomp$58$$=$props_75421$$.frame,$objects$jscomp$753$$=$props_75421$$.objects,$all_objects$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1046$$=$props_75421$$["all-objects"];return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1046$$)?$or__5025__auto__$jscomp$1046$$:$objects$jscomp$753$$}(),
$base_frame$jscomp$9$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$viewer$shapes$base_frame_ctx$$),$frame_offset$jscomp$8$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$viewer$shapes$frame_offset_ctx$$),$show_interactions$jscomp$1$$=$APP.$rumext$v2$deref$$($app$main$ui$viewer$shapes$ref_COLON_viewer_show_interactions$$),$overlays$jscomp$10$$=$APP.$rumext$v2$deref$$($app$main$refs$viewer_overlays$$),$interactions$jscomp$21$$=$APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$978$$),
$svg_element_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$svg_raw$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$978$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1538$svg$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$978$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$78$tag$$],null))),
$on_pointer_down$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$978$$),$APP.$rumext$v2$adapt$$($base_frame$jscomp$9$$),$APP.$rumext$v2$adapt$$($frame_offset$jscomp$8$$),$APP.$rumext$v2$adapt$$($all_objects$jscomp$2$$)],function($p1__75417_SHARP_$$){return $app$main$ui$viewer$shapes$on_pointer_down$$($p1__75417_SHARP_$$,$shape$jscomp$978$$,$base_frame$jscomp$9$$,$frame_offset$jscomp$8$$,$all_objects$jscomp$2$$,$overlays$jscomp$10$$)}),
$on_pointer_up$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$978$$),$APP.$rumext$v2$adapt$$($base_frame$jscomp$9$$),$APP.$rumext$v2$adapt$$($frame_offset$jscomp$8$$),$APP.$rumext$v2$adapt$$($all_objects$jscomp$2$$)],function($p1__75418_SHARP_$$){return $app$main$ui$viewer$shapes$on_pointer_up$$($p1__75418_SHARP_$$,$shape$jscomp$978$$,$base_frame$jscomp$9$$,$frame_offset$jscomp$8$$,$all_objects$jscomp$2$$,$overlays$jscomp$10$$)}),$on_pointer_enter$jscomp$3$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$978$$),$APP.$rumext$v2$adapt$$($base_frame$jscomp$9$$),$APP.$rumext$v2$adapt$$($frame_offset$jscomp$8$$),$APP.$rumext$v2$adapt$$($all_objects$jscomp$2$$)],function($p1__75419_SHARP_$$){return $app$main$ui$viewer$shapes$on_pointer_enter$$($p1__75419_SHARP_$$,$shape$jscomp$978$$,$base_frame$jscomp$9$$,$frame_offset$jscomp$8$$,$all_objects$jscomp$2$$,$overlays$jscomp$10$$)}),$on_pointer_leave$jscomp$3$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$978$$),$APP.$rumext$v2$adapt$$($base_frame$jscomp$9$$),$APP.$rumext$v2$adapt$$($frame_offset$jscomp$8$$),$APP.$rumext$v2$adapt$$($all_objects$jscomp$2$$)],function($p1__75420_SHARP_$$){return $app$main$ui$viewer$shapes$on_pointer_leave$$($p1__75420_SHARP_$$,$shape$jscomp$978$$,$base_frame$jscomp$9$$,$frame_offset$jscomp$8$$,$all_objects$jscomp$2$$,$overlays$jscomp$10$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){var $sems$jscomp$2$$=$app$main$ui$viewer$shapes$on_load$$($shape$jscomp$978$$,$base_frame$jscomp$9$$,$frame_offset$jscomp$8$$,$objects$jscomp$753$$,$overlays$jscomp$10$$);return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$run_BANG_$$,$app$util$timers$dispose_BANG_$$,$sems$jscomp$2$$)});return $svg_element_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($component$jscomp$120$$,{shape:$shape$jscomp$978$$,frame:$frame$jscomp$58$$,childs:$childs$jscomp$21$$,objects:$objects$jscomp$753$$}):
(0,$APP.$rumext$v2$jsxs$$)($APP.$app$main$ui$shapes$shape$shape_container$$,{shape:$shape$jscomp$978$$,cursor:$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$actionable_QMARK_$$($interactions$jscomp$21$$))?"pointer":null,onPointerDown:$on_pointer_down$jscomp$2$$,onPointerUp:$on_pointer_up$jscomp$1$$,onPointerEnter:$on_pointer_enter$jscomp$3$$,onPointerLeave:$on_pointer_leave$jscomp$3$$,children:[(0,$APP.$rumext$v2$jsx$$)($component$jscomp$120$$,{shape:$shape$jscomp$978$$,frame:$frame$jscomp$58$$,
childs:$childs$jscomp$21$$,"is-child-selected?":!0,objects:$objects$jscomp$753$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$shapes$interaction$$,{shape:$shape$jscomp$978$$,interactions:$interactions$jscomp$21$$,"show-interactions":$show_interactions$jscomp$1$$})]})}};
$app$main$ui$viewer$shapes$frame_container_factory$$=function($objects$jscomp$754$$,$all_objects$jscomp$3$$){var $shape_container$jscomp$4$$=$app$main$ui$viewer$shapes$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$ui$viewer$shapes$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$754$$,$all_objects$jscomp$3$$):$app$main$ui$viewer$shapes$shape_container_factory$$($objects$jscomp$754$$,$all_objects$jscomp$3$$),$frame_wrapper$jscomp$2$$=$app$main$ui$viewer$shapes$generic_wrapper_factory$$($APP.$app$main$ui$shapes$frame$frame_shape$$($shape_container$jscomp$4$$)),
$lookup_xf$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$754$$));return function($props_75460_props__$1$jscomp$66$$){var $childs$jscomp$22$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$lookup_xf$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($props_75460_props__$1$jscomp$66$$.shape));$props_75460_props__$1$jscomp$66$$=$APP.$app$util$object$merge$cljs$0core$0IFn$0_invoke$0arity$02$$($props_75460_props__$1$jscomp$66$$,
{childs:$childs$jscomp$22$$,objects:$objects$jscomp$754$$,"all-objects":$all_objects$jscomp$3$$});return(0,$APP.$rumext$v2$create_element$$)($frame_wrapper$jscomp$2$$,$props_75460_props__$1$jscomp$66$$)}};
$app$main$ui$viewer$shapes$group_container_factory$$=function($objects$jscomp$755$$,$all_objects$jscomp$4$$){var $shape_container$jscomp$5$$=$app$main$ui$viewer$shapes$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$ui$viewer$shapes$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$755$$,$all_objects$jscomp$4$$):$app$main$ui$viewer$shapes$shape_container_factory$$($objects$jscomp$755$$,$all_objects$jscomp$4$$),$group_wrapper$jscomp$2$$=$app$main$ui$viewer$shapes$generic_wrapper_factory$$($APP.$app$main$ui$shapes$group$group_shape$$($shape_container$jscomp$5$$));
return function($props_75470_props__$1$jscomp$67$$){var $childs$jscomp$23$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75468_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$755$$,$p1__75468_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($props_75470_props__$1$jscomp$67$$.shape));$props_75470_props__$1$jscomp$67$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$({},$props_75470_props__$1$jscomp$67$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([{childs:$childs$jscomp$23$$,objects:$objects$jscomp$755$$,"all-objects":$all_objects$jscomp$4$$}]));return $APP.$cljs$core$truth_$$($APP.$cljs$core$not_empty$$($childs$jscomp$23$$))?(0,$APP.$rumext$v2$create_element$$)($group_wrapper$jscomp$2$$,$props_75470_props__$1$jscomp$67$$):null}};
$app$main$ui$viewer$shapes$bool_container_factory$$=function($objects$jscomp$756$$,$all_objects$jscomp$5_shape_container$jscomp$6$$){$all_objects$jscomp$5_shape_container$jscomp$6$$=$app$main$ui$viewer$shapes$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$ui$viewer$shapes$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$756$$,$all_objects$jscomp$5_shape_container$jscomp$6$$):$app$main$ui$viewer$shapes$shape_container_factory$$($objects$jscomp$756$$,$all_objects$jscomp$5_shape_container$jscomp$6$$);
var $bool_wrapper$jscomp$1$$=$app$main$ui$viewer$shapes$generic_wrapper_factory$$($APP.$app$main$ui$shapes$bool$bool_shape$$($all_objects$jscomp$5_shape_container$jscomp$6$$));return function($props_75474_props__$1$jscomp$68$$){var $childs$jscomp$24$$=$APP.$cljs$core$select_keys$$($objects$jscomp$756$$,$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$756$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($props_75474_props__$1$jscomp$68$$.shape)));
$props_75474_props__$1$jscomp$68$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$({},$props_75474_props__$1$jscomp$68$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([{childs:$childs$jscomp$24$$,objects:$objects$jscomp$756$$}]));return(0,$APP.$rumext$v2$create_element$$)($bool_wrapper$jscomp$1$$,$props_75474_props__$1$jscomp$68$$)}};
$app$main$ui$viewer$shapes$svg_raw_container_factory$$=function($objects$jscomp$757$$,$all_objects$jscomp$6_shape_container$jscomp$7$$){$all_objects$jscomp$6_shape_container$jscomp$7$$=$app$main$ui$viewer$shapes$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$ui$viewer$shapes$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$757$$,$all_objects$jscomp$6_shape_container$jscomp$7$$):$app$main$ui$viewer$shapes$shape_container_factory$$($objects$jscomp$757$$,
$all_objects$jscomp$6_shape_container$jscomp$7$$);var $svg_raw_wrapper$jscomp$1$$=$app$main$ui$viewer$shapes$generic_wrapper_factory$$($APP.$app$main$ui$shapes$svg_raw$svg_raw_shape$$($all_objects$jscomp$6_shape_container$jscomp$7$$));return function($props_75480_props__$1$jscomp$69$$){var $childs$jscomp$25$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75478_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$757$$,$p1__75478_SHARP_$$)},
$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($props_75480_props__$1$jscomp$69$$.shape));$props_75480_props__$1$jscomp$69$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$({},$props_75480_props__$1$jscomp$69$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([{childs:$childs$jscomp$25$$,objects:$objects$jscomp$757$$}]));return(0,$APP.$rumext$v2$create_element$$)($svg_raw_wrapper$jscomp$1$$,$props_75480_props__$1$jscomp$69$$)}};
$app$main$ui$viewer$shapes$shape_container_factory$$=function($objects$jscomp$758$$,$all_objects$jscomp$7$$){var $path_wrapper$$=$app$main$ui$viewer$shapes$generic_wrapper_factory$$($APP.$app$main$ui$shapes$path$path_shape$$),$text_wrapper$$=$app$main$ui$viewer$shapes$generic_wrapper_factory$$($APP.$app$main$ui$shapes$text$text_shape$$),$rect_wrapper$$=$app$main$ui$viewer$shapes$generic_wrapper_factory$$($APP.$app$main$ui$shapes$rect$rect_shape$$),$image_wrapper$$=$app$main$ui$viewer$shapes$generic_wrapper_factory$$($APP.$app$main$ui$shapes$image$image_shape$$),
$circle_wrapper$$=$app$main$ui$viewer$shapes$generic_wrapper_factory$$($APP.$app$main$ui$shapes$circle$circle_shape$$);return $APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($frame$jscomp$59_props_75483$$){var $shape$jscomp$980_shape__$1$jscomp$103$$=$frame$jscomp$59_props_75483$$.shape;$frame$jscomp$59_props_75483$$=$frame$jscomp$59_props_75483$$.frame;var $group_container$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$758$$)],
function(){return $app$main$ui$viewer$shapes$group_container_factory$$($objects$jscomp$758$$,$all_objects$jscomp$7$$)}),$frame_container$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$758$$)],function(){return $app$main$ui$viewer$shapes$frame_container_factory$$($objects$jscomp$758$$,$all_objects$jscomp$7$$)}),$bool_container$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$758$$)],function(){return $app$main$ui$viewer$shapes$bool_container_factory$$($objects$jscomp$758$$,
$all_objects$jscomp$7$$)}),$svg_raw_container$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$758$$)],function(){return $app$main$ui$viewer$shapes$svg_raw_container_factory$$($objects$jscomp$758$$,$all_objects$jscomp$7$$)});if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($shape$jscomp$980_shape__$1$jscomp$103$$)?$APP.$cljs$core$not$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$980_shape__$1$jscomp$103$$)):
$shape$jscomp$980_shape__$1$jscomp$103$$)){$shape$jscomp$980_shape__$1$jscomp$103$$=$APP.$cljs$core$truth_$$($frame$jscomp$59_props_75483$$)?$APP.$app$common$geom$shapes$translate_to_frame$$($shape$jscomp$980_shape__$1$jscomp$103$$,$frame$jscomp$59_props_75483$$):$shape$jscomp$980_shape__$1$jscomp$103$$;var $opts$jscomp$306$$={shape:$shape$jscomp$980_shape__$1$jscomp$103$$,objects:$objects$jscomp$758$$,"all-objects":$all_objects$jscomp$7$$},$G__75485_G__75485__$1$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$980_shape__$1$jscomp$103$$);
$G__75485_G__75485__$1$$=$G__75485_G__75485__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__75485_G__75485__$1$$.$fqn$:null;switch($G__75485_G__75485__$1$$){case "frame":return(0,$APP.$rumext$v2$create_element$$)($frame_container$$,$opts$jscomp$306$$);case "text":return(0,$APP.$rumext$v2$create_element$$)($text_wrapper$$,$opts$jscomp$306$$);case "rect":return(0,$APP.$rumext$v2$create_element$$)($rect_wrapper$$,$opts$jscomp$306$$);case "path":return(0,$APP.$rumext$v2$create_element$$)($path_wrapper$$,
$opts$jscomp$306$$);case "image":return(0,$APP.$rumext$v2$create_element$$)($image_wrapper$$,$opts$jscomp$306$$);case "circle":return(0,$APP.$rumext$v2$create_element$$)($circle_wrapper$$,$opts$jscomp$306$$);case "group":return(0,$APP.$rumext$v2$jsx$$)($group_container$$,{shape:$shape$jscomp$980_shape__$1$jscomp$103$$,frame:$frame$jscomp$59_props_75483$$,objects:$objects$jscomp$758$$});case "bool":return(0,$APP.$rumext$v2$jsx$$)($bool_container$$,{shape:$shape$jscomp$980_shape__$1$jscomp$103$$,frame:$frame$jscomp$59_props_75483$$,
objects:$objects$jscomp$758$$});case "svg-raw":return(0,$APP.$rumext$v2$jsx$$)($svg_raw_container$$,{shape:$shape$jscomp$980_shape__$1$jscomp$103$$,frame:$frame$jscomp$59_props_75483$$,objects:$objects$jscomp$758$$});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75485_G__75485__$1$$)].join(""));}}else return null})};
$APP.$app$main$ui$viewer$interactions$prepare_objects$$=function($frame$jscomp$60_frame_id$jscomp$135$$,$size$jscomp$139$$,$delta$jscomp$56$$,$objects$jscomp$759$$){$frame$jscomp$60_frame_id$jscomp$135$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$60_frame_id$jscomp$135$$);var $vector$jscomp$27$$=$APP.$app$common$geom$point$negate$$($APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$139$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$139$$)),$delta$jscomp$56$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__75535_SHARP_$$,$p2__75536_SHARP_$$){return $APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($p1__75535_SHARP_$$,$p2__75536_SHARP_$$,$APP.$app$common$geom$shapes$transform_shape$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$modifiers$move_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$($vector$jscomp$27$$)]))},
$objects$jscomp$759$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame$jscomp$60_frame_id$jscomp$135$$],null),$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$759$$,$frame$jscomp$60_frame_id$jscomp$135$$)))};
$app$main$ui$viewer$interactions$get_fixed_ids$$=function($objects$jscomp$760$$){var $fixed_ids_parent_children_ids$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$common$files$helpers$fixed_scroll_QMARK_$$,$APP.$cljs$core$vals$$($objects$jscomp$760$$)),$fixed_children_ids$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__75550_SHARP_$$){return $APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$760$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__75550_SHARP_$$))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$fixed_ids_parent_children_ids$$])));$fixed_ids_parent_children_ids$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75552_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__75552_SHARP_$$,$APP.$app$common$uuid$zero$$)},$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__75551_SHARP_$$){return $APP.$cljs$core$cons$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__75551_SHARP_$$),
$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$760$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__75551_SHARP_$$)))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$fixed_ids_parent_children_ids$$])));return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($fixed_children_ids$$,$fixed_ids_parent_children_ids$$)};
$app$main$ui$viewer$interactions$interactions_menu_STAR_$$=function($interactions_mode_props_75625$$){$interactions_mode_props_75625$$=$interactions_mode_props_75625$$.interactionsMode;var $show_dropdown_QMARK_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$toggle_dropdown$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_dropdown_QMARK_$jscomp$3$$,$APP.$cljs$core$not$$)}),
$hide_dropdown$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_dropdown_QMARK_$jscomp$3$$,!1)}),$select_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$278$$){var $G__75626$jscomp$inline_8007_G__75626__$1$jscomp$inline_8008_mode$jscomp$46$$=$APP.$app$util$dom$get_current_target$$($event$jscomp$278$$);$G__75626$jscomp$inline_8007_G__75626__$1$jscomp$inline_8008_mode$jscomp$46$$=$G__75626$jscomp$inline_8007_G__75626__$1$jscomp$inline_8008_mode$jscomp$46$$==
null?null:$APP.$app$util$dom$get_data$$($G__75626$jscomp$inline_8007_G__75626__$1$jscomp$inline_8008_mode$jscomp$46$$,"mode");$G__75626$jscomp$inline_8007_G__75626__$1$jscomp$inline_8008_mode$jscomp$46$$=$G__75626$jscomp$inline_8007_G__75626__$1$jscomp$inline_8008_mode$jscomp$46$$==null?null:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__75626$jscomp$inline_8007_G__75626__$1$jscomp$inline_8008_mode$jscomp$46$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$278$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$set_interactions_mode$$($G__75626$jscomp$inline_8007_G__75626__$1$jscomp$inline_8008_mode$jscomp$46$$))});
return(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$toggle_dropdown$jscomp$2$$,className:"main_ui_viewer_interactions__view-options",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_interactions__dropdown-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("viewer.header.interactions")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_interactions__icon-dropdown",children:$APP.$app$main$ui$icons$arrow$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,
{show:$APP.$cljs$core$_deref$$($show_dropdown_QMARK_$jscomp$3$$),"on-close":$hide_dropdown$jscomp$2$$,children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_viewer_interactions__dropdown",children:[(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:$select_mode$$,"data-mode":"hide",className:"main_ui_viewer_interactions__dropdown-element "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode_props_75625$$,$APP.$cljs$cst$2345$hide$$)?"main_ui_viewer_interactions__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_viewer_interactions__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("viewer.header.dont-show-interactions")}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode_props_75625$$,$APP.$cljs$cst$2345$hide$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_interactions__icon",children:$APP.$app$main$ui$icons$tick$$}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:$select_mode$$,"data-mode":"show",className:"main_ui_viewer_interactions__dropdown-element "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode_props_75625$$,$cljs$cst$3471$show$$)?"main_ui_viewer_interactions__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_interactions__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("viewer.header.show-interactions")}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode_props_75625$$,$cljs$cst$3471$show$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_interactions__icon",
children:$APP.$app$main$ui$icons$tick$$}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:$select_mode$$,"data-mode":"show-on-click",className:"main_ui_viewer_interactions__dropdown-element "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode_props_75625$$,$APP.$cljs$cst$5234$show_on_click$$)?"main_ui_viewer_interactions__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_interactions__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("viewer.header.show-interactions-on-click")}),
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode_props_75625$$,$APP.$cljs$cst$5234$show_on_click$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_interactions__icon",children:$APP.$app$main$ui$icons$tick$$}):null]})]})})]})};$app$main$ui$viewer$header$open_login_dialog$$=function(){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5398$login_register$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$viewer$header$header_options$$=function($map__75680_props_75678_zoom$jscomp$63$$){$map__75680_props_75678_zoom$jscomp$63$$=$APP.$rumext$v2$util$wrap_props$$($map__75680_props_75678_zoom$jscomp$63$$);var $fullscreen_QMARK__map__75680__$1$$=$APP.$cljs$core$__destructure_map$$($map__75680_props_75678_zoom$jscomp$63$$),$section$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fullscreen_QMARK__map__75680__$1$$,$APP.$cljs$cst$1366$section$$);$map__75680_props_75678_zoom$jscomp$63$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fullscreen_QMARK__map__75680__$1$$,$APP.$cljs$cst$2196$zoom$$);var $page$jscomp$159$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fullscreen_QMARK__map__75680__$1$$,$APP.$cljs$cst$1624$page$$),$file$jscomp$155$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fullscreen_QMARK__map__75680__$1$$,$APP.$cljs$cst$208$file$$),$index$jscomp$406$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fullscreen_QMARK__map__75680__$1$$,
$APP.$cljs$cst$1795$index$$),$permissions$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fullscreen_QMARK__map__75680__$1$$,$APP.$cljs$cst$1722$permissions$$),$interactions_mode$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fullscreen_QMARK__map__75680__$1$$,$APP.$cljs$cst$5231$interactions_mode$$),$share$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fullscreen_QMARK__map__75680__$1$$,$APP.$cljs$cst$5399$share$$);$fullscreen_QMARK__map__75680__$1$$=
$APP.$rumext$v2$deref$$($APP.$app$main$ui$viewer$header$fullscreen_ref$$);var $toggle_fullscreen$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$toggle_fullscreen$$)}),$go_to_workspace$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page$jscomp$159$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$159$$)))}),
$open_share_dialog$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page$jscomp$159$$)],function(){$APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5400$share_link$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1624$page$$,$page$jscomp$159$$,$APP.$cljs$cst$208$file$$,$file$jscomp$155$$],null));return $APP.$app$main$data$modal$disallow_click_outside_BANG_$$()}),$handle_increase$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$increase_zoom$$)}),
$handle_decrease$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$decrease_zoom$$)}),$handle_zoom_reset$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$reset_zoom$$)}),$handle_zoom_fill$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$zoom_to_fill$$)}),
$handle_zoom_fit$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$zoom_to_fit$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($permissions$jscomp$30$$),$APP.$rumext$v2$adapt$$($share$$)],function(){var $JSCompiler_inline_result$jscomp$1474_and__5023__auto__$jscomp$inline_8010_and__5023__auto____$1$jscomp$inline_8011$$=$cljs$cst$5401$in_team$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$30$$);
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1474_and__5023__auto__$jscomp$inline_8010_and__5023__auto____$1$jscomp$inline_8011$$)&&($JSCompiler_inline_result$jscomp$1474_and__5023__auto__$jscomp$inline_8010_and__5023__auto____$1$jscomp$inline_8011$$=$APP.$cljs$cst$1597$is_admin$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$30$$),$JSCompiler_inline_result$jscomp$1474_and__5023__auto__$jscomp$inline_8010_and__5023__auto____$1$jscomp$inline_8011$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1474_and__5023__auto__$jscomp$inline_8010_and__5023__auto____$1$jscomp$inline_8011$$)?
$share$$:$JSCompiler_inline_result$jscomp$1474_and__5023__auto__$jscomp$inline_8010_and__5023__auto____$1$jscomp$inline_8011$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1474_and__5023__auto__$jscomp$inline_8010_and__5023__auto____$1$jscomp$inline_8011$$)?$open_share_dialog$$.$cljs$core$IFn$_invoke$arity$0$?$open_share_dialog$$.$cljs$core$IFn$_invoke$arity$0$():$open_share_dialog$$():null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_header__options-zone",
children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$exports$assets$progress_widget$$,{}),function(){switch($section$jscomp$22$$ instanceof $APP.$cljs$core$Keyword$$?$section$jscomp$22$$.$fqn$:null){case "interactions":return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($index$jscomp$406$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$interactions$flows_menu_STAR_$$,{page:$page$jscomp$159$$,index:$index$jscomp$406$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$interactions$interactions_menu_STAR_$$,
{interactionsMode:$interactions_mode$jscomp$1$$})]});case "comments":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$comments$comments_menu$$,{});default:return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_header__view-options"})}}(),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$header$zoom_widget$$,{zoom:$map__75680_props_75678_zoom$jscomp$63$$,"on-increase":$handle_increase$$,"on-decrease":$handle_decrease$$,"on-zoom-reset":$handle_zoom_reset$$,"on-zoom-fill":$handle_zoom_fill$$,
"on-zoom-fit":$handle_zoom_fit$$,"on-fullscreen":$toggle_fullscreen$$}),$APP.$cljs$core$truth_$$($cljs$cst$5401$in_team$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$30$$))?(0,$APP.$rumext$v2$jsx$$)("span",{onClick:$go_to_workspace$$,className:"main_ui_viewer_header__edit-btn",children:$APP.$app$main$ui$icons$curve$$}):null,(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("viewer.header.fullscreen"),onClick:$toggle_fullscreen$$,className:"main_ui_viewer_header__fullscreen-btn "+
($APP.$cljs$core$truth_$$($fullscreen_QMARK__map__75680__$1$$)?"main_ui_viewer_header__selected":""),children:$app$main$ui$icons$expand$$}),$APP.$cljs$core$truth_$$($cljs$cst$5401$in_team$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$30$$))?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$open_share_dialog$$,className:"main_ui_viewer_header__share-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.share")}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$5402$is_logged$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$30$$))?
null:(0,$APP.$rumext$v2$jsx$$)("span",{onClick:$app$main$ui$viewer$header$open_login_dialog$$,className:"main_ui_viewer_header__go-log-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.log-or-sign")})]})};
$app$main$ui$viewer$header$header_sitemap$$=function($map__75694_map__75694__$1_props_75693_toggle_thumbnails$$){$map__75694_map__75694__$1_props_75693_toggle_thumbnails$$=$APP.$rumext$v2$util$wrap_props$$($map__75694_map__75694__$1_props_75693_toggle_thumbnails$$);$map__75694_map__75694__$1_props_75693_toggle_thumbnails$$=$APP.$cljs$core$__destructure_map$$($map__75694_map__75694__$1_props_75693_toggle_thumbnails$$);var $project$jscomp$19_project_name$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75694_map__75694__$1_props_75693_toggle_thumbnails$$,
$APP.$cljs$cst$2230$project$$),$file$jscomp$156$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75694_map__75694__$1_props_75693_toggle_thumbnails$$,$APP.$cljs$cst$208$file$$),$frame_name$jscomp$4_page$jscomp$160$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75694_map__75694__$1_props_75693_toggle_thumbnails$$,$APP.$cljs$cst$1624$page$$),$frame$jscomp$64_open_dropdown$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75694_map__75694__$1_props_75693_toggle_thumbnails$$,
$APP.$cljs$cst$1606$frame$$);$map__75694_map__75694__$1_props_75693_toggle_thumbnails$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75694_map__75694__$1_props_75693_toggle_thumbnails$$,$cljs$cst$5403$toggle_thumbnails$$);$project$jscomp$19_project_name$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$19_project_name$$);var $file_name$jscomp$7$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$156$$),$page_name$jscomp$4$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame_name$jscomp$4_page$jscomp$160$$),
$page_id$jscomp$416$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame_name$jscomp$4_page$jscomp$160$$);$frame_name$jscomp$4_page$jscomp$160$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$64_open_dropdown$jscomp$2$$);var $show_dropdown_QMARK_$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$frame$jscomp$64_open_dropdown$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_dropdown_QMARK_$jscomp$4$$,
!0)});var $close_dropdown$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_dropdown_QMARK_$jscomp$4$$,!1)}),$navigate_to$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($page_id__$1$jscomp$24$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$go_to_page$$($page_id__$1$jscomp$24$$));return $APP.$cljs$core$reset_BANG_$$($show_dropdown_QMARK_$jscomp$4$$,!1)});return(0,$APP.$rumext$v2$jsxs$$)("div",
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("viewer.header.sitemap"),className:"main_ui_viewer_header__sitemap-zone",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_header__project-name",children:$project$jscomp$19_project_name$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_header__sitemap-text",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$frame$jscomp$64_open_dropdown$jscomp$2$$,className:"main_ui_viewer_header__breadcrumb",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_viewer_header__breadcrumb-text",children:""+($file_name$jscomp$7$$??"")+" / "+($page_name$jscomp$4$$??"")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_header__icon",children:$APP.$app$main$ui$icons$arrow$$}),(0,$APP.$rumext$v2$jsx$$)("span",{children:"/"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$_deref$$($show_dropdown_QMARK_$jscomp$4$$),"on-close":$close_dropdown$jscomp$2$$,children:(0,$APP.$rumext$v2$jsx$$)("ul",
{className:"main_ui_viewer_header__dropdown-sitemap",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$112$$,$id$jscomp$919$$){$out_arr__44124__auto__$jscomp$112$$.push((0,$APP.$rumext$v2$jsxs$$)("li",{id:""+($id$jscomp$919$$??""),onClick:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($navigate_to$$,$id$jscomp$919$$),className:"main_ui_viewer_header__dropdown-element "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$416$$,
$id$jscomp$919$$)?"main_ui_viewer_header__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_header__label",children:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$156$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$1630$pages_index$$,$id$jscomp$919$$,$APP.$cljs$cst$725$name$$],null))}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$416$$,
$id$jscomp$919$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_header__icon-check",children:$APP.$app$main$ui$icons$tick$$}):null]},""+($id$jscomp$919$$??"")));return $out_arr__44124__auto__$jscomp$112$$},[],$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$156$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2228$pages$$],null)))})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{id:"current-frame",
onClick:$map__75694_map__75694__$1_props_75693_toggle_thumbnails$$,className:"main_ui_viewer_header__current-frame",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_header__frame-name",children:$frame_name$jscomp$4_page$jscomp$160$$}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_header__icon",children:$APP.$app$main$ui$icons$arrow$$})]})]})]})};
$APP.$app$main$ui$viewer$header$header$$=function($map__75709_props_75707_zoom$jscomp$64$$){$map__75709_props_75707_zoom$jscomp$64$$=$APP.$rumext$v2$util$wrap_props$$($map__75709_props_75707_zoom$jscomp$64$$);var $map__75709__$1_share$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($map__75709_props_75707_zoom$jscomp$64$$);$map__75709_props_75707_zoom$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75709__$1_share$jscomp$1$$,$APP.$cljs$cst$2196$zoom$$);var $permissions$jscomp$31$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75709__$1_share$jscomp$1$$,$APP.$cljs$cst$1722$permissions$$),$frame$jscomp$65$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75709__$1_share$jscomp$1$$,$APP.$cljs$cst$1606$frame$$),$index$jscomp$407$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75709__$1_share$jscomp$1$$,$APP.$cljs$cst$1795$index$$),$file$jscomp$157$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75709__$1_share$jscomp$1$$,$APP.$cljs$cst$208$file$$),
$section$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75709__$1_share$jscomp$1$$,$APP.$cljs$cst$1366$section$$),$shown_thumbnails$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75709__$1_share$jscomp$1$$,$cljs$cst$5404$shown_thumbnails$$),$page$jscomp$161$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75709__$1_share$jscomp$1$$,$APP.$cljs$cst$1624$page$$),$interactions_mode$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75709__$1_share$jscomp$1$$,
$APP.$cljs$cst$5231$interactions_mode$$),$project$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75709__$1_share$jscomp$1$$,$APP.$cljs$cst$2230$project$$);$map__75709__$1_share$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75709__$1_share$jscomp$1$$,$APP.$cljs$cst$5399$share$$);var $go_to_dashboard$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$go_to_dashboard$$())}),
$go_to_inspect$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($permissions$jscomp$31$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5402$is_logged$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$31$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$viewer$close_thumbnails_panel$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$viewer$go_to_section$$($APP.$cljs$cst$2672$inspect$$)])):
$app$main$ui$viewer$header$open_login_dialog$$()}),$navigate$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($permissions$jscomp$31$$)],function($event$jscomp$283_section__$1$jscomp$1$$){$event$jscomp$283_section__$1$jscomp$1$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$283_section__$1$jscomp$1$$),"value"));var $JSCompiler_inline_result$jscomp$1475_or__5025__auto__$jscomp$inline_8013$$=
($JSCompiler_inline_result$jscomp$1475_or__5025__auto__$jscomp$inline_8013$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$283_section__$1$jscomp$1$$,$APP.$cljs$cst$2051$interactions$$))?$JSCompiler_inline_result$jscomp$1475_or__5025__auto__$jscomp$inline_8013$$:$APP.$cljs$cst$5402$is_logged$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$31$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1475_or__5025__auto__$jscomp$inline_8013$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$go_to_section$$($event$jscomp$283_section__$1$jscomp$1$$)):
$app$main$ui$viewer$header$open_login_dialog$$()}),$toggle_thumbnails$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$toggle_thumbnails_panel$$)}),$close_thumbnails$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shown_thumbnails$$)],function(){return $APP.$cljs$core$truth_$$($shown_thumbnails$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$close_thumbnails_panel$$):
null});return(0,$APP.$rumext$v2$jsxs$$)("header",{onClick:$close_thumbnails$$,className:"main_ui_viewer_header__viewer-header "+($APP.$cljs$core$truth_$$($APP.$rumext$v2$deref$$($APP.$app$main$ui$viewer$header$fullscreen_ref$$))?"main_ui_viewer_header__fullscreen":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_header__nav-zone",children:[(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$go_to_dashboard$$,"data-testid":"penpot-logo-link",style:{cursor:$APP.$cljs$core$truth_$$($cljs$cst$5401$in_team$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$31$$))?
null:"auto",pointerEvents:$APP.$cljs$core$truth_$$($cljs$cst$5401$in_team$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$31$$))?null:"none"},className:"main_ui_viewer_header__home-link",children:$app$main$ui$viewer$header$penpot_logo_icon$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$header$header_sitemap$$,{project:$project$jscomp$20$$,file:$file$jscomp$157$$,page:$page$jscomp$161$$,frame:$frame$jscomp$65$$,"toggle-thumbnails":$toggle_thumbnails$jscomp$1$$,index:$index$jscomp$407$$})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_header__mode-zone",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$navigate$$,"data-value":"interactions",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("viewer.header.interactions-section",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$viewer$shortcuts$get_tooltip$$($cljs$cst$5299$open_interactions$$)])),className:"main_ui_viewer_header__mode-zone-btn "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$23$$,
$APP.$cljs$cst$2051$interactions$$)?"main_ui_viewer_header__selected":""),children:$APP.$app$main$ui$icons$play$$}),$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1049$$=$cljs$cst$5401$in_team$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$31$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1049$$)?$or__5025__auto__$jscomp$1049$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5405$who_comment$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$31$$),
"all")}())?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$navigate$$,"data-value":"comments",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("viewer.header.comments-section",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$viewer$shortcuts$get_tooltip$$($cljs$cst$4799$open_comments$$)])),className:"main_ui_viewer_header__mode-zone-btn "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$23$$,$APP.$cljs$cst$3436$comments$$)?"main_ui_viewer_header__selected":
""),children:$APP.$app$main$ui$icons$comments$$}):null,$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1050$$=$cljs$cst$5401$in_team$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$31$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1050$$)?$or__5025__auto__$jscomp$1050$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$31$$),$APP.$cljs$cst$5400$share_link$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5406$who_inspect$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$31$$),
"all")}())?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$go_to_inspect$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("viewer.header.inspect-section",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$viewer$shortcuts$get_tooltip$$($cljs$cst$4817$open_inspect$$)])),className:"main_ui_viewer_header__mode-zone-btn "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$23$$,$APP.$cljs$cst$2672$inspect$$)?"main_ui_viewer_header__selected":
""),children:$app$main$ui$icons$code$$}):null]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$header$header_options$$,{section:$section$jscomp$23$$,permissions:$permissions$jscomp$31$$,page:$page$jscomp$161$$,file:$file$jscomp$157$$,index:$index$jscomp$407$$,zoom:$map__75709_props_75707_zoom$jscomp$64$$,"interactions-mode":$interactions_mode$jscomp$2$$,share:$map__75709__$1_share$jscomp$1$$})]})};
$APP.$app$main$ui$static$0$error_container_STAR_$$=function($children$jscomp$290_props_75730$$){$children$jscomp$290_props_75730$$=$children$jscomp$290_props_75730$$.children;var $profile_id$jscomp$17$$=$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$on_nav_root$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$router$nav_root$$())});
return(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_static__exception-layout",children:[(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_nav_root$$,className:"main_ui_static__exception-header",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$raw_svg$raw_svg_STAR_$$,{id:"penpot-logo-icon",className:"main_ui_static__penpot-logo"}),$APP.$cljs$core$truth_$$($profile_id$jscomp$17$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__go-back-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow",className:"main_ui_static__back-arrow"}),(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.go-dashboard")})]}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__deco-before",children:$app$main$ui$icons$logo_error_screen$$}),$APP.$cljs$core$truth_$$($profile_id$jscomp$17$$)?null:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_nav_root$$,className:"main_ui_static__login-header",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.login")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__exception-content",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__container",children:$children$jscomp$290_props_75730$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__deco-after2",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.copyright-period")}),$app$main$ui$icons$logo_error_screen$$,(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.made-with-love")})]})]})};
$$jscomp$defineProperty$$=typeof Object.defineProperties=="function"?Object.defineProperty:function($target$jscomp$92$$,$property$jscomp$16$$,$descriptor$jscomp$1$$){if($target$jscomp$92$$==Array.prototype||$target$jscomp$92$$==Object.prototype)return $target$jscomp$92$$;$target$jscomp$92$$[$property$jscomp$16$$]=$descriptor$jscomp$1$$.value;return $target$jscomp$92$$};$$jscomp$global$$=$$jscomp$getGlobal$$(this);
$$jscomp$polyfill$$("Symbol",function($orig$jscomp$1$$){function $symbolPolyfill$$($opt_description$jscomp$2$$){if(this instanceof $symbolPolyfill$$)throw new TypeError("Symbol is not a constructor");return new $SymbolClass$$($SYMBOL_PREFIX$$+($opt_description$jscomp$2$$||"")+"_"+$counter$$++,$opt_description$jscomp$2$$)}function $SymbolClass$$($id$jscomp$5$$,$opt_description$jscomp$1$$){this.$$jscomp$symbol$id_$=$id$jscomp$5$$;$$jscomp$defineProperty$$(this,"description",{configurable:!0,writable:!0,
value:$opt_description$jscomp$1$$})}if($orig$jscomp$1$$)return $orig$jscomp$1$$;$SymbolClass$$.prototype.toString=function(){return this.$$jscomp$symbol$id_$};var $SYMBOL_PREFIX$$="jscomp_symbol_"+(Math.random()*1E9>>>0)+"_",$counter$$=0;return $symbolPolyfill$$});
$$jscomp$polyfill$$("Symbol.iterator",function($orig$jscomp$2_symbolIterator$$){if($orig$jscomp$2_symbolIterator$$)return $orig$jscomp$2_symbolIterator$$;$orig$jscomp$2_symbolIterator$$=Symbol("Symbol.iterator");for(var $arrayLikes$$="Array Int8Array Uint8Array Uint8ClampedArray Int16Array Uint16Array Int32Array Uint32Array Float32Array Float64Array".split(" "),$i$jscomp$6$$=0;$i$jscomp$6$$<$arrayLikes$$.length;$i$jscomp$6$$++){var $ArrayLikeCtor$$=$$jscomp$global$$[$arrayLikes$$[$i$jscomp$6$$]];
typeof $ArrayLikeCtor$$==="function"&&typeof $ArrayLikeCtor$$.prototype[$orig$jscomp$2_symbolIterator$$]!="function"&&$$jscomp$defineProperty$$($ArrayLikeCtor$$.prototype,$orig$jscomp$2_symbolIterator$$,{configurable:!0,writable:!0,value:function(){return $$jscomp$iteratorPrototype$$($$jscomp$arrayIteratorImpl$$(this))}})}return $orig$jscomp$2_symbolIterator$$});$goog$$=$goog$$||{};$APP.$goog$global$$=globalThis;$goog$VALID_MODULE_RE_$$=/^[a-zA-Z_$][a-zA-Z0-9._$]*$/;$goog$module$$.get=function(){return null};
var $goog$moduleLoaderState_$$=null,$goog$UID_PROPERTY_$$="closure_uid_"+(Math.random()*1E9>>>0),$goog$uidCounter_$$=0;var $module$app$common$weak$impl_weak_value_map$$,$module$app$common$svg$path$parser$$,$module$app$render_wasm$api$shared$$,$module$app$util$clipboard$$;$APP.$goog$inherits$$($module$contents$goog$debug$Error_DebugError$$,Error);$module$contents$goog$debug$Error_DebugError$$.prototype.name="CustomError";$goog$reflect$sinkValue$$[" "]=function(){};var $module$contents$goog$math$Long_Long$$=class{constructor($low$$,$high$$){this.$low_$=$low$$|0;this.$high_$=$high$$|0}isSafeInteger(){var $top11Bits$$=this.$high_$>>21;return $top11Bits$$==0||$top11Bits$$==-1&&!(this.$low_$==0&&this.$high_$==-2097152)}toString($opt_radix$jscomp$1_radix$jscomp$2$$){$opt_radix$jscomp$1_radix$jscomp$2$$=$opt_radix$jscomp$1_radix$jscomp$2$$||10;if($opt_radix$jscomp$1_radix$jscomp$2$$<2||36<$opt_radix$jscomp$1_radix$jscomp$2$$)throw Error("radix out of range: "+$opt_radix$jscomp$1_radix$jscomp$2$$);
if(this.isSafeInteger()){var $asNumber_safeDigits$$=$JSCompiler_StaticMethods_toNumber$$(this);return $opt_radix$jscomp$1_radix$jscomp$2$$==10?""+$asNumber_safeDigits$$:$asNumber_safeDigits$$.toString($opt_radix$jscomp$1_radix$jscomp$2$$)}$asNumber_safeDigits$$=14-($opt_radix$jscomp$1_radix$jscomp$2$$>>2);var $radixPowSafeDigits_remDiv$$=Math.pow($opt_radix$jscomp$1_radix$jscomp$2$$,$asNumber_safeDigits$$),$JSCompiler_inline_result$jscomp$61_other$jscomp$inline_2292_radixToPower$$=$module$contents$goog$math$Long_Long$fromBits$$($radixPowSafeDigits_remDiv$$,
$radixPowSafeDigits_remDiv$$/4294967296);$radixPowSafeDigits_remDiv$$=$JSCompiler_StaticMethods_div$$(this,$JSCompiler_inline_result$jscomp$61_other$jscomp$inline_2292_radixToPower$$);var $JSCompiler_temp_const$jscomp$60_val$jscomp$10$$=Math,$JSCompiler_temp_const$jscomp$59_digits$$=$JSCompiler_temp_const$jscomp$60_val$jscomp$10$$.abs;$JSCompiler_inline_result$jscomp$61_other$jscomp$inline_2292_radixToPower$$=$radixPowSafeDigits_remDiv$$.multiply($JSCompiler_inline_result$jscomp$61_other$jscomp$inline_2292_radixToPower$$);
$JSCompiler_inline_result$jscomp$61_other$jscomp$inline_2292_radixToPower$$=this.add($JSCompiler_StaticMethods_negate$$($JSCompiler_inline_result$jscomp$61_other$jscomp$inline_2292_radixToPower$$));$JSCompiler_temp_const$jscomp$60_val$jscomp$10$$=$JSCompiler_temp_const$jscomp$59_digits$$.call($JSCompiler_temp_const$jscomp$60_val$jscomp$10$$,$JSCompiler_StaticMethods_toNumber$$($JSCompiler_inline_result$jscomp$61_other$jscomp$inline_2292_radixToPower$$));$JSCompiler_temp_const$jscomp$59_digits$$=$opt_radix$jscomp$1_radix$jscomp$2$$==
10?""+$JSCompiler_temp_const$jscomp$60_val$jscomp$10$$:$JSCompiler_temp_const$jscomp$60_val$jscomp$10$$.toString($opt_radix$jscomp$1_radix$jscomp$2$$);$JSCompiler_temp_const$jscomp$59_digits$$.length<$asNumber_safeDigits$$&&($JSCompiler_temp_const$jscomp$59_digits$$="0000000000000".slice($JSCompiler_temp_const$jscomp$59_digits$$.length-$asNumber_safeDigits$$)+$JSCompiler_temp_const$jscomp$59_digits$$);$JSCompiler_temp_const$jscomp$60_val$jscomp$10$$=$JSCompiler_StaticMethods_toNumber$$($radixPowSafeDigits_remDiv$$);
return($opt_radix$jscomp$1_radix$jscomp$2$$==10?$JSCompiler_temp_const$jscomp$60_val$jscomp$10$$:$JSCompiler_temp_const$jscomp$60_val$jscomp$10$$.toString($opt_radix$jscomp$1_radix$jscomp$2$$))+$JSCompiler_temp_const$jscomp$59_digits$$}$isZero$(){return this.$low_$==0&&this.$high_$==0}$hashCode$(){return this.$low_$^this.$high_$}equals($other$jscomp$11$$){return this.$low_$==$other$jscomp$11$$.$low_$&&this.$high_$==$other$jscomp$11$$.$high_$}compare($other$jscomp$17$$){return this.$high_$==$other$jscomp$17$$.$high_$?
this.$low_$==$other$jscomp$17$$.$low_$?0:this.$low_$>>>0>$other$jscomp$17$$.$low_$>>>0?1:-1:this.$high_$>$other$jscomp$17$$.$high_$?1:-1}add($c00_other$jscomp$18$$){var $a48_c48$$=this.$high_$>>>16,$a32$$=this.$high_$&65535,$a16_c32$$=this.$low_$>>>16,$b48$$=$c00_other$jscomp$18$$.$high_$>>>16,$b32$$=$c00_other$jscomp$18$$.$high_$&65535,$b16_c16$$=$c00_other$jscomp$18$$.$low_$>>>16;$c00_other$jscomp$18$$=(this.$low_$&65535)+($c00_other$jscomp$18$$.$low_$&65535);$b16_c16$$=($c00_other$jscomp$18$$>>>
16)+($a16_c32$$+$b16_c16$$);$a16_c32$$=$b16_c16$$>>>16;$a16_c32$$+=$a32$$+$b32$$;$a48_c48$$=($a16_c32$$>>>16)+($a48_c48$$+$b48$$)&65535;return $module$contents$goog$math$Long_Long$fromBits$$(($b16_c16$$&65535)<<16|$c00_other$jscomp$18$$&65535,$a48_c48$$<<16|$a16_c32$$&65535)}multiply($b00$jscomp$1_other$jscomp$20$$){if(this.$isZero$())return this;if($b00$jscomp$1_other$jscomp$20$$.$isZero$())return $b00$jscomp$1_other$jscomp$20$$;var $a48$jscomp$1$$=this.$high_$>>>16,$a32$jscomp$1$$=this.$high_$&
65535,$a16$jscomp$1$$=this.$low_$>>>16,$a00$jscomp$1$$=this.$low_$&65535,$b48$jscomp$1$$=$b00$jscomp$1_other$jscomp$20$$.$high_$>>>16,$b32$jscomp$1$$=$b00$jscomp$1_other$jscomp$20$$.$high_$&65535,$b16$jscomp$1$$=$b00$jscomp$1_other$jscomp$20$$.$low_$>>>16;$b00$jscomp$1_other$jscomp$20$$=$b00$jscomp$1_other$jscomp$20$$.$low_$&65535;var $c00$jscomp$1$$=$a00$jscomp$1$$*$b00$jscomp$1_other$jscomp$20$$;var $c16$jscomp$1$$=($c00$jscomp$1$$>>>16)+$a16$jscomp$1$$*$b00$jscomp$1_other$jscomp$20$$;var $c32$jscomp$1$$=
$c16$jscomp$1$$>>>16;$c16$jscomp$1$$=($c16$jscomp$1$$&65535)+$a00$jscomp$1$$*$b16$jscomp$1$$;$c32$jscomp$1$$+=$c16$jscomp$1$$>>>16;$c32$jscomp$1$$+=$a32$jscomp$1$$*$b00$jscomp$1_other$jscomp$20$$;var $c48$jscomp$1$$=$c32$jscomp$1$$>>>16;$c32$jscomp$1$$=($c32$jscomp$1$$&65535)+$a16$jscomp$1$$*$b16$jscomp$1$$;$c48$jscomp$1$$+=$c32$jscomp$1$$>>>16;$c32$jscomp$1$$=($c32$jscomp$1$$&65535)+$a00$jscomp$1$$*$b32$jscomp$1$$;$c48$jscomp$1$$=$c48$jscomp$1$$+($c32$jscomp$1$$>>>16)+($a48$jscomp$1$$*$b00$jscomp$1_other$jscomp$20$$+
$a32$jscomp$1$$*$b16$jscomp$1$$+$a16$jscomp$1$$*$b32$jscomp$1$$+$a00$jscomp$1$$*$b48$jscomp$1$$)&65535;return $module$contents$goog$math$Long_Long$fromBits$$(($c16$jscomp$1$$&65535)<<16|$c00$jscomp$1$$&65535,$c48$jscomp$1$$<<16|$c32$jscomp$1$$&65535)}and($other$jscomp$23$$){return $module$contents$goog$math$Long_Long$fromBits$$(this.$low_$&$other$jscomp$23$$.$low_$,this.$high_$&$other$jscomp$23$$.$high_$)}or($other$jscomp$24$$){return $module$contents$goog$math$Long_Long$fromBits$$(this.$low_$|$other$jscomp$24$$.$low_$,
this.$high_$|$other$jscomp$24$$.$high_$)}xor($other$jscomp$25$$){return $module$contents$goog$math$Long_Long$fromBits$$(this.$low_$^$other$jscomp$25$$.$low_$,this.$high_$^$other$jscomp$25$$.$high_$)}shiftLeft($numBits$$){$numBits$$&=63;if($numBits$$==0)return this;var $low$jscomp$1$$=this.$low_$;return $numBits$$<32?$module$contents$goog$math$Long_Long$fromBits$$($low$jscomp$1$$<<$numBits$$,this.$high_$<<$numBits$$|$low$jscomp$1$$>>>32-$numBits$$):$module$contents$goog$math$Long_Long$fromBits$$(0,
$low$jscomp$1$$<<$numBits$$-32)}},$module$contents$goog$math$Long_ZERO_$$=$module$contents$goog$math$Long_Long$fromBits$$(0,0),$module$contents$goog$math$Long_ONE_$$=$module$contents$goog$math$Long_Long$fromBits$$(1,0),$module$contents$goog$math$Long_NEG_ONE_$$=$module$contents$goog$math$Long_Long$fromBits$$(-1,-1),$module$contents$goog$math$Long_MAX_VALUE_$$=$module$contents$goog$math$Long_Long$fromBits$$(4294967295,2147483647),$module$contents$goog$math$Long_MIN_VALUE_$$=$module$contents$goog$math$Long_Long$fromBits$$(0,
2147483648);var $goog$html$trustedtypes$cachedPolicy_$$;var $module$contents$goog$html$SafeScript_CONSTRUCTOR_TOKEN_PRIVATE$$={},$module$contents$goog$html$SafeScript_SafeScript$$=class{constructor($value$jscomp$161$$){this.$privateDoNotAccessOrElseSafeScriptWrappedValue_$=$value$jscomp$161$$;this.$implementsGoogStringTypedString$=!0}toString(){return this.$privateDoNotAccessOrElseSafeScriptWrappedValue_$.toString()}$getTypedStringValue$(){return this.$privateDoNotAccessOrElseSafeScriptWrappedValue_$.toString()}};var $goog$html$TrustedResourceUrl$$=class{constructor($value$jscomp$162$$){this.$privateDoNotAccessOrElseTrustedResourceUrlWrappedValue_$=$value$jscomp$162$$}toString(){return this.$privateDoNotAccessOrElseTrustedResourceUrlWrappedValue_$+""}};$goog$html$TrustedResourceUrl$$.prototype.$implementsGoogStringTypedString$=!0;$goog$html$TrustedResourceUrl$$.prototype.$getTypedStringValue$=function(){return this.$privateDoNotAccessOrElseTrustedResourceUrlWrappedValue_$.toString()};var $goog$string$internal$trim$$=String.prototype.trim?function($str$jscomp$16$$){return $str$jscomp$16$$.trim()}:function($str$jscomp$17$$){return/^[\s\xa0]*([\s\S]*?)[\s\xa0]*$/.exec($str$jscomp$17$$)[1]};var $module$contents$goog$object_PROTOTYPE_FIELDS$$="constructor hasOwnProperty isPrototypeOf propertyIsEnumerable toLocaleString toString valueOf".split(" ");var $module$contents$goog$array_indexOf$$=Array.prototype.indexOf?function($arr$jscomp$10$$,$obj$jscomp$68$$){return Array.prototype.indexOf.call($arr$jscomp$10$$,$obj$jscomp$68$$,void 0)}:function($arr$jscomp$11$$,$obj$jscomp$69$$){if(typeof $arr$jscomp$11$$==="string")return typeof $obj$jscomp$69$$!=="string"||$obj$jscomp$69$$.length!=1?-1:$arr$jscomp$11$$.indexOf($obj$jscomp$69$$,0);for(let $i$jscomp$58$$=0;$i$jscomp$58$$<$arr$jscomp$11$$.length;$i$jscomp$58$$++)if($i$jscomp$58$$ in $arr$jscomp$11$$&&
$arr$jscomp$11$$[$i$jscomp$58$$]===$obj$jscomp$69$$)return $i$jscomp$58$$;return-1},$module$contents$goog$array_forEach$$=Array.prototype.forEach?function($arr$jscomp$14$$,$f$jscomp$16$$){Array.prototype.forEach.call($arr$jscomp$14$$,$f$jscomp$16$$,void 0)}:function($arr$jscomp$15$$,$f$jscomp$17$$){const $l$jscomp$2$$=$arr$jscomp$15$$.length,$arr2$$=typeof $arr$jscomp$15$$==="string"?$arr$jscomp$15$$.split(""):$arr$jscomp$15$$;for(let $i$jscomp$60$$=0;$i$jscomp$60$$<$l$jscomp$2$$;$i$jscomp$60$$++)$i$jscomp$60$$ in
$arr2$$&&$f$jscomp$17$$.call(void 0,$arr2$$[$i$jscomp$60$$],$i$jscomp$60$$,$arr$jscomp$15$$)},$module$contents$goog$array_some$$=Array.prototype.some?function($arr$jscomp$25$$,$f$jscomp$27$$){return Array.prototype.some.call($arr$jscomp$25$$,$f$jscomp$27$$,void 0)}:function($arr$jscomp$26$$,$f$jscomp$28$$){const $l$jscomp$6$$=$arr$jscomp$26$$.length,$arr2$jscomp$4$$=typeof $arr$jscomp$26$$==="string"?$arr$jscomp$26$$.split(""):$arr$jscomp$26$$;for(let $i$jscomp$64$$=0;$i$jscomp$64$$<$l$jscomp$6$$;$i$jscomp$64$$++)if($i$jscomp$64$$ in
$arr2$jscomp$4$$&&$f$jscomp$28$$.call(void 0,$arr2$jscomp$4$$[$i$jscomp$64$$],$i$jscomp$64$$,$arr$jscomp$26$$))return!0;return!1};var $goog$dom$safe$NONCE_PATTERN_$$=/^[\w+/_-]+[=]{0,2}$/;var $goog$string$repeat$$=String.prototype.repeat?function($string$jscomp$3$$,$length$jscomp$22$$){return $string$jscomp$3$$.repeat($length$jscomp$22$$)}:function($string$jscomp$4$$,$length$jscomp$23$$){return Array($length$jscomp$23$$+1).join($string$jscomp$4$$)};var $goog$uri$utils$splitRe_$$=RegExp("^(?:([^:/?#.]+):)?(?://(?:([^\\\\/?#]*)@)?([^\\\\/?#]*?)(?::([0-9]+))?(?\x3d[\\\\/?#]|$))?([^?#]+)?(?:\\?([^#]*))?(?:#([\\s\\S]*))?$");$APP.$JSCompiler_prototypeAlias$$=$goog$Uri$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.toString=function(){var $out$jscomp$3$$=[],$scheme$jscomp$4_userInfo$$=this.$scheme_$;$scheme$jscomp$4_userInfo$$&&$out$jscomp$3$$.push($goog$Uri$encodeSpecialChars_$$($scheme$jscomp$4_userInfo$$,$goog$Uri$reDisallowedInSchemeOrUserInfo_$$,!0),":");var $domain$jscomp$2_fragment$jscomp$1_path$jscomp$22_port_query$jscomp$12$$=this.$domain_$;if($domain$jscomp$2_fragment$jscomp$1_path$jscomp$22_port_query$jscomp$12$$||$scheme$jscomp$4_userInfo$$=="file")$out$jscomp$3$$.push("//"),
($scheme$jscomp$4_userInfo$$=this.$userInfo_$)&&$out$jscomp$3$$.push($goog$Uri$encodeSpecialChars_$$($scheme$jscomp$4_userInfo$$,$goog$Uri$reDisallowedInSchemeOrUserInfo_$$,!0),"@"),$out$jscomp$3$$.push($goog$Uri$removeDoubleEncoding_$$(encodeURIComponent(String($domain$jscomp$2_fragment$jscomp$1_path$jscomp$22_port_query$jscomp$12$$)))),$domain$jscomp$2_fragment$jscomp$1_path$jscomp$22_port_query$jscomp$12$$=this.$port_$,$domain$jscomp$2_fragment$jscomp$1_path$jscomp$22_port_query$jscomp$12$$!=null&&
$out$jscomp$3$$.push(":",String($domain$jscomp$2_fragment$jscomp$1_path$jscomp$22_port_query$jscomp$12$$));if($domain$jscomp$2_fragment$jscomp$1_path$jscomp$22_port_query$jscomp$12$$=this.$path_$)this.$domain_$&&$domain$jscomp$2_fragment$jscomp$1_path$jscomp$22_port_query$jscomp$12$$.charAt(0)!="/"&&$out$jscomp$3$$.push("/"),$out$jscomp$3$$.push($goog$Uri$encodeSpecialChars_$$($domain$jscomp$2_fragment$jscomp$1_path$jscomp$22_port_query$jscomp$12$$,$domain$jscomp$2_fragment$jscomp$1_path$jscomp$22_port_query$jscomp$12$$.charAt(0)==
"/"?$goog$Uri$reDisallowedInAbsolutePath_$$:$goog$Uri$reDisallowedInRelativePath_$$,!0));($domain$jscomp$2_fragment$jscomp$1_path$jscomp$22_port_query$jscomp$12$$=this.$queryData_$.toString())&&$out$jscomp$3$$.push("?",$domain$jscomp$2_fragment$jscomp$1_path$jscomp$22_port_query$jscomp$12$$);($domain$jscomp$2_fragment$jscomp$1_path$jscomp$22_port_query$jscomp$12$$=this.$fragment_$)&&$out$jscomp$3$$.push("#",$goog$Uri$encodeSpecialChars_$$($domain$jscomp$2_fragment$jscomp$1_path$jscomp$22_port_query$jscomp$12$$,
$goog$Uri$reDisallowedInFragment_$$));return $out$jscomp$3$$.join("")};
$APP.$JSCompiler_prototypeAlias$$.resolve=function($newFragment$jscomp$inline_11143_relativeUri$$){var $absoluteUri$$=this.clone(),$overridden$$=!!$newFragment$jscomp$inline_11143_relativeUri$$.$scheme_$;$overridden$$?$JSCompiler_StaticMethods_setScheme$$($absoluteUri$$,$newFragment$jscomp$inline_11143_relativeUri$$.$scheme_$):$overridden$$=!!$newFragment$jscomp$inline_11143_relativeUri$$.$userInfo_$;if($overridden$$){var $leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$=$newFragment$jscomp$inline_11143_relativeUri$$.$userInfo_$;
$JSCompiler_StaticMethods_enforceReadOnly$$($absoluteUri$$);$absoluteUri$$.$userInfo_$=$leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$}else $overridden$$=!!$newFragment$jscomp$inline_11143_relativeUri$$.$domain_$;$overridden$$?($leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$=$newFragment$jscomp$inline_11143_relativeUri$$.$domain_$,
$JSCompiler_StaticMethods_enforceReadOnly$$($absoluteUri$$),$absoluteUri$$.$domain_$=$leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$):$overridden$$=$newFragment$jscomp$inline_11143_relativeUri$$.$port_$!=null;$leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$=$newFragment$jscomp$inline_11143_relativeUri$$.$path_$;if($overridden$$)$JSCompiler_StaticMethods_setPort$$($absoluteUri$$,
$newFragment$jscomp$inline_11143_relativeUri$$.$port_$);else if($overridden$$=!!$newFragment$jscomp$inline_11143_relativeUri$$.$path_$){if($leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$.charAt(0)!="/")if(this.$domain_$&&!this.$path_$)$leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$="/"+$leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$;
else{var $lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$=$absoluteUri$$.$path_$.lastIndexOf("/");$lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$!=-1&&($leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$=$absoluteUri$$.$path_$.slice(0,$lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$+1)+$leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$)}$lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$=
$leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$;if($lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$==".."||$lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$==".")$leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$="";else if($lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$.indexOf("./")!=
-1||$lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$.indexOf("/.")!=-1){$leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$=$APP.$goog$string$internal$startsWith$$($lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$,"/");$lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$=$lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$.split("/");for(var $out$jscomp$inline_2313$$=
[],$pos$jscomp$inline_2314$$=0;$pos$jscomp$inline_2314$$<$lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$.length;){var $segment$jscomp$inline_2315$$=$lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$[$pos$jscomp$inline_2314$$++];$segment$jscomp$inline_2315$$=="."?$leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$&&$pos$jscomp$inline_2314$$==$lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$.length&&
$out$jscomp$inline_2313$$.push(""):$segment$jscomp$inline_2315$$==".."?(($out$jscomp$inline_2313$$.length>1||$out$jscomp$inline_2313$$.length==1&&$out$jscomp$inline_2313$$[0]!="")&&$out$jscomp$inline_2313$$.pop(),$leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$&&$pos$jscomp$inline_2314$$==$lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$.length&&$out$jscomp$inline_2313$$.push("")):($out$jscomp$inline_2313$$.push($segment$jscomp$inline_2315$$),
$leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$=!0)}$leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$=$out$jscomp$inline_2313$$.join("/")}else $leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$=$lastSlashIndex_path$jscomp$inline_2310_segments$jscomp$inline_2312$$}$overridden$$?
($JSCompiler_StaticMethods_enforceReadOnly$$($absoluteUri$$),$absoluteUri$$.$path_$=$leadingSlash$jscomp$inline_2311_newDomain$jscomp$inline_11135_newPath$jscomp$inline_11139_newUserInfo$jscomp$inline_11131_path$jscomp$23$$):$overridden$$=$newFragment$jscomp$inline_11143_relativeUri$$.$queryData_$.toString()!=="";$overridden$$?$JSCompiler_StaticMethods_setQueryData$$($absoluteUri$$,$newFragment$jscomp$inline_11143_relativeUri$$.$queryData_$.clone()):$overridden$$=!!$newFragment$jscomp$inline_11143_relativeUri$$.$fragment_$;
$overridden$$&&($newFragment$jscomp$inline_11143_relativeUri$$=$newFragment$jscomp$inline_11143_relativeUri$$.$fragment_$,$JSCompiler_StaticMethods_enforceReadOnly$$($absoluteUri$$),$absoluteUri$$.$fragment_$=$newFragment$jscomp$inline_11143_relativeUri$$);return $absoluteUri$$};$APP.$JSCompiler_prototypeAlias$$.clone=function(){return new $goog$Uri$$(this)};$APP.$JSCompiler_prototypeAlias$$.getQuery=function(){return this.$queryData_$.toString()};
$APP.$JSCompiler_prototypeAlias$$.removeParameter=function($key$jscomp$96$$){$JSCompiler_StaticMethods_enforceReadOnly$$(this);this.$queryData_$.remove($key$jscomp$96$$);return this};$APP.$JSCompiler_prototypeAlias$$.isReadOnly=function(){return this.$isReadOnly_$};$APP.$JSCompiler_prototypeAlias$$.$setIgnoreCase$=function($ignoreCase$$){this.$ignoreCase_$=$ignoreCase$$;this.$queryData_$&&this.$queryData_$.$setIgnoreCase$($ignoreCase$$)};
var $goog$Uri$reDisallowedInSchemeOrUserInfo_$$=/[#\/\?@]/g,$goog$Uri$reDisallowedInRelativePath_$$=/[#\?:]/g,$goog$Uri$reDisallowedInAbsolutePath_$$=/[#\?]/g,$goog$Uri$reDisallowedInQuery_$$=/[#\?@]/g,$goog$Uri$reDisallowedInFragment_$$=/#/g;$APP.$JSCompiler_prototypeAlias$$=$goog$Uri$QueryData$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.add=function($key$jscomp$98$$,$value$jscomp$196$$){$JSCompiler_StaticMethods_ensureKeyMapInitialized_$$(this);this.$encodedQuery_$=null;$key$jscomp$98$$=$JSCompiler_StaticMethods_getKeyName_$$(this,$key$jscomp$98$$);var $values$jscomp$20$$=this.$keyMap_$.get($key$jscomp$98$$);$values$jscomp$20$$||this.$keyMap_$.set($key$jscomp$98$$,$values$jscomp$20$$=[]);$values$jscomp$20$$.push($value$jscomp$196$$);this.$count_$+=1;return this};
$APP.$JSCompiler_prototypeAlias$$.remove=function($key$jscomp$99$$){$JSCompiler_StaticMethods_ensureKeyMapInitialized_$$(this);$key$jscomp$99$$=$JSCompiler_StaticMethods_getKeyName_$$(this,$key$jscomp$99$$);return this.$keyMap_$.has($key$jscomp$99$$)?(this.$encodedQuery_$=null,this.$count_$-=this.$keyMap_$.get($key$jscomp$99$$).length,this.$keyMap_$.delete($key$jscomp$99$$)):!1};$APP.$JSCompiler_prototypeAlias$$.clear=function(){this.$keyMap_$=this.$encodedQuery_$=null;this.$count_$=0};
$APP.$JSCompiler_prototypeAlias$$.isEmpty=function(){$JSCompiler_StaticMethods_ensureKeyMapInitialized_$$(this);return this.$count_$==0};
$APP.$JSCompiler_prototypeAlias$$.forEach=function($f$jscomp$44$$,$opt_scope$jscomp$3$$){$JSCompiler_StaticMethods_ensureKeyMapInitialized_$$(this);this.$keyMap_$.forEach(function($values$jscomp$21$$,$key$jscomp$101$$){$values$jscomp$21$$.forEach(function($value$jscomp$198$$){$f$jscomp$44$$.call($opt_scope$jscomp$3$$,$value$jscomp$198$$,$key$jscomp$101$$,this)},this)},this)};
$APP.$JSCompiler_prototypeAlias$$.$getKeys$=function(){$JSCompiler_StaticMethods_ensureKeyMapInitialized_$$(this);const $vals$jscomp$1$$=Array.from(this.$keyMap_$.values()),$keys$jscomp$9$$=Array.from(this.$keyMap_$.keys()),$rv$jscomp$12$$=[];for(let $i$jscomp$114$$=0;$i$jscomp$114$$<$keys$jscomp$9$$.length;$i$jscomp$114$$++){const $val$jscomp$39$$=$vals$jscomp$1$$[$i$jscomp$114$$];for(let $j$jscomp$8$$=0;$j$jscomp$8$$<$val$jscomp$39$$.length;$j$jscomp$8$$++)$rv$jscomp$12$$.push($keys$jscomp$9$$[$i$jscomp$114$$])}return $rv$jscomp$12$$};
$APP.$JSCompiler_prototypeAlias$$.$getValues$=function($opt_key$jscomp$2_values$jscomp$22$$){$JSCompiler_StaticMethods_ensureKeyMapInitialized_$$(this);let $rv$jscomp$13$$=[];if(typeof $opt_key$jscomp$2_values$jscomp$22$$==="string")$JSCompiler_StaticMethods_containsKey$$(this,$opt_key$jscomp$2_values$jscomp$22$$)&&($rv$jscomp$13$$=$rv$jscomp$13$$.concat(this.$keyMap_$.get($JSCompiler_StaticMethods_getKeyName_$$(this,$opt_key$jscomp$2_values$jscomp$22$$))));else{$opt_key$jscomp$2_values$jscomp$22$$=
Array.from(this.$keyMap_$.values());for(let $i$jscomp$115$$=0;$i$jscomp$115$$<$opt_key$jscomp$2_values$jscomp$22$$.length;$i$jscomp$115$$++)$rv$jscomp$13$$=$rv$jscomp$13$$.concat($opt_key$jscomp$2_values$jscomp$22$$[$i$jscomp$115$$])}return $rv$jscomp$13$$};
$APP.$JSCompiler_prototypeAlias$$.set=function($key$jscomp$102$$,$value$jscomp$199$$){$JSCompiler_StaticMethods_ensureKeyMapInitialized_$$(this);this.$encodedQuery_$=null;$key$jscomp$102$$=$JSCompiler_StaticMethods_getKeyName_$$(this,$key$jscomp$102$$);$JSCompiler_StaticMethods_containsKey$$(this,$key$jscomp$102$$)&&(this.$count_$-=this.$keyMap_$.get($key$jscomp$102$$).length);this.$keyMap_$.set($key$jscomp$102$$,[$value$jscomp$199$$]);this.$count_$+=1;return this};
$APP.$JSCompiler_prototypeAlias$$.get=function($key$jscomp$103_values$jscomp$23$$,$opt_default$$){if(!$key$jscomp$103_values$jscomp$23$$)return $opt_default$$;$key$jscomp$103_values$jscomp$23$$=this.$getValues$($key$jscomp$103_values$jscomp$23$$);return $key$jscomp$103_values$jscomp$23$$.length>0?String($key$jscomp$103_values$jscomp$23$$[0]):$opt_default$$};
$APP.$JSCompiler_prototypeAlias$$.toString=function(){if(this.$encodedQuery_$)return this.$encodedQuery_$;if(!this.$keyMap_$)return"";const $sb$jscomp$2$$=[],$keys$jscomp$10$$=Array.from(this.$keyMap_$.keys());for(var $i$jscomp$116$$=0;$i$jscomp$116$$<$keys$jscomp$10$$.length;$i$jscomp$116$$++){var $j$jscomp$9_key$jscomp$105$$=$keys$jscomp$10$$[$i$jscomp$116$$];const $encodedKey$$=encodeURIComponent(String($j$jscomp$9_key$jscomp$105$$)),$val$jscomp$40$$=this.$getValues$($j$jscomp$9_key$jscomp$105$$);
for($j$jscomp$9_key$jscomp$105$$=0;$j$jscomp$9_key$jscomp$105$$<$val$jscomp$40$$.length;$j$jscomp$9_key$jscomp$105$$++){var $param$jscomp$7$$=$encodedKey$$;$val$jscomp$40$$[$j$jscomp$9_key$jscomp$105$$]!==""&&($param$jscomp$7$$+="\x3d"+encodeURIComponent(String($val$jscomp$40$$[$j$jscomp$9_key$jscomp$105$$])));$sb$jscomp$2$$.push($param$jscomp$7$$)}}return this.$encodedQuery_$=$sb$jscomp$2$$.join("\x26")};
$APP.$JSCompiler_prototypeAlias$$.clone=function(){var $rv$jscomp$14$$=new $goog$Uri$QueryData$$;$rv$jscomp$14$$.$encodedQuery_$=this.$encodedQuery_$;this.$keyMap_$&&($rv$jscomp$14$$.$keyMap_$=new Map(this.$keyMap_$),$rv$jscomp$14$$.$count_$=this.$count_$);return $rv$jscomp$14$$};
$APP.$JSCompiler_prototypeAlias$$.$setIgnoreCase$=function($ignoreCase$jscomp$1$$){$ignoreCase$jscomp$1$$&&!this.$ignoreCase_$&&($JSCompiler_StaticMethods_ensureKeyMapInitialized_$$(this),this.$encodedQuery_$=null,this.$keyMap_$.forEach(function($value$jscomp$201$$,$key$jscomp$107$$){var $lowerCase$$=$key$jscomp$107$$.toLowerCase();$key$jscomp$107$$!=$lowerCase$$&&(this.remove($key$jscomp$107$$),this.remove($lowerCase$$),$value$jscomp$201$$.length>0&&(this.$encodedQuery_$=null,this.$keyMap_$.set($JSCompiler_StaticMethods_getKeyName_$$(this,
$lowerCase$$),$module$contents$goog$array_toArray$$($value$jscomp$201$$)),this.$count_$+=$value$jscomp$201$$.length))},this));this.$ignoreCase_$=$ignoreCase$jscomp$1$$};$APP.$JSCompiler_prototypeAlias$$.extend=function($var_args$jscomp$79$$){for(var $i$jscomp$117$$=0;$i$jscomp$117$$<arguments.length;$i$jscomp$117$$++)$goog$structs$forEach$$(arguments[$i$jscomp$117$$],function($value$jscomp$202$$,$key$jscomp$108$$){this.add($key$jscomp$108$$,$value$jscomp$202$$)},this)};$APP.$JSCompiler_prototypeAlias$$=$APP.$goog$string$StringBuffer$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$buffer_$="";$APP.$JSCompiler_prototypeAlias$$.set=function($s$jscomp$19$$){this.$buffer_$=""+$s$jscomp$19$$};$APP.$JSCompiler_prototypeAlias$$.append=function($a1$jscomp$2$$,$opt_a2$$,$var_args$jscomp$81$$){this.$buffer_$+=String($a1$jscomp$2$$);if($opt_a2$$!=null)for(let $i$jscomp$118$$=1;$i$jscomp$118$$<arguments.length;$i$jscomp$118$$++)this.$buffer_$+=arguments[$i$jscomp$118$$];return this};
$APP.$JSCompiler_prototypeAlias$$.clear=function(){this.$buffer_$=""};$APP.$JSCompiler_prototypeAlias$$.getLength=function(){return this.$buffer_$.length};$APP.$JSCompiler_prototypeAlias$$.toString=function(){return this.$buffer_$};var $cljs$$,$cljs$core$$,$cljs$core$_STAR_out_STAR_$$,$cljs$core$_STAR_print_readably_STAR_$$,$cljs$core$_STAR_print_dup_STAR_$$,$cljs$core$_STAR_print_length_STAR_$$,$cljs$core$_STAR_print_level_STAR_$$,$cljs$core$DEMUNGE_MAP$$,$cljs$core$DEMUNGE_PATTERN$$,$cljs$core$IIndexed$_nth$dyn_24458$$,$cljs$core$ILookup$_lookup$dyn_24466$$,$cljs$core$string_hash_cache$$,$cljs$core$string_hash_cache_count$$,$cljs$core$spread$$,$cljs$core$re_seq_STAR_$$,$cljs$core$char_escapes$$,$cljs$core$print_str$$;
$cljs$$={};$cljs$core$$={};$APP.$cljs$core$PROTOCOL_SENTINEL$$={};$cljs$core$_STAR_out_STAR_$$=null;$APP.$cljs$core$_STAR_assert_STAR_$$=!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=null;$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;$cljs$core$_STAR_print_readably_STAR_$$=!0;$cljs$core$_STAR_print_dup_STAR_$$=!1;$cljs$core$_STAR_print_length_STAR_$$=null;$cljs$core$_STAR_print_level_STAR_$$=null;
$APP.$cljs$core$ITER_SYMBOL$$=typeof Symbol!=="undefined"&&$APP.$goog$typeOf$$(Symbol)==="function"?Symbol.iterator:"@@iterator";$cljs$core$DEMUNGE_MAP$$={_RBRACE_:"}",_COLON_:":",_BANG_:"!",_QMARK_:"?",_BSLASH_:"\\\\",_SLASH_:"/",_PERCENT_:"%",_PLUS_:"+",_SHARP_:"#",_LBRACE_:"{",_BAR_:"|",_LBRACK_:"[",_EQ_:"\x3d",_:"-",_TILDE_:"~",_RBRACK_:"]",_GT_:"\x3e",_SINGLEQUOTE_:"'",_CIRCA_:"@",_AMPERSAND_:"\x26",_DOUBLEQUOTE_:'\\"',_CARET_:"^",_LT_:"\x3c",_STAR_:"*"};$cljs$core$DEMUNGE_PATTERN$$=null;
$cljs$core$IIndexed$_nth$dyn_24458$$=function(){function $G__24459__3$$($coll$jscomp$7$$,$n$jscomp$26$$,$not_found$$){var $m__5372__auto__$jscomp$27_m__5374__auto__$jscomp$27$$=$APP.$cljs$core$_nth$$[$APP.$goog$typeOf$$($coll$jscomp$7$$==null?null:$coll$jscomp$7$$)];if($m__5372__auto__$jscomp$27_m__5374__auto__$jscomp$27$$!=null)return $m__5372__auto__$jscomp$27_m__5374__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$27_m__5374__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$3$($coll$jscomp$7$$,
$n$jscomp$26$$,$not_found$$):$m__5372__auto__$jscomp$27_m__5374__auto__$jscomp$27$$($coll$jscomp$7$$,$n$jscomp$26$$,$not_found$$);$m__5372__auto__$jscomp$27_m__5374__auto__$jscomp$27$$=$APP.$cljs$core$_nth$$._;if($m__5372__auto__$jscomp$27_m__5374__auto__$jscomp$27$$!=null)return $m__5372__auto__$jscomp$27_m__5374__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$27_m__5374__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$3$($coll$jscomp$7$$,$n$jscomp$26$$,$not_found$$):
$m__5372__auto__$jscomp$27_m__5374__auto__$jscomp$27$$($coll$jscomp$7$$,$n$jscomp$26$$,$not_found$$);throw $APP.$cljs$core$missing_protocol$$("IIndexed.-nth",$coll$jscomp$7$$);}function $G__24459__2$$($coll$jscomp$6$$,$n$jscomp$25$$){var $m__5372__auto__$jscomp$26_m__5374__auto__$jscomp$26$$=$APP.$cljs$core$_nth$$[$APP.$goog$typeOf$$($coll$jscomp$6$$==null?null:$coll$jscomp$6$$)];if($m__5372__auto__$jscomp$26_m__5374__auto__$jscomp$26$$!=null)return $m__5372__auto__$jscomp$26_m__5374__auto__$jscomp$26$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$26_m__5374__auto__$jscomp$26$$.$cljs$core$IFn$_invoke$arity$2$($coll$jscomp$6$$,$n$jscomp$25$$):$m__5372__auto__$jscomp$26_m__5374__auto__$jscomp$26$$($coll$jscomp$6$$,$n$jscomp$25$$);$m__5372__auto__$jscomp$26_m__5374__auto__$jscomp$26$$=$APP.$cljs$core$_nth$$._;if($m__5372__auto__$jscomp$26_m__5374__auto__$jscomp$26$$!=null)return $m__5372__auto__$jscomp$26_m__5374__auto__$jscomp$26$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$26_m__5374__auto__$jscomp$26$$.$cljs$core$IFn$_invoke$arity$2$($coll$jscomp$6$$,
$n$jscomp$25$$):$m__5372__auto__$jscomp$26_m__5374__auto__$jscomp$26$$($coll$jscomp$6$$,$n$jscomp$25$$);throw $APP.$cljs$core$missing_protocol$$("IIndexed.-nth",$coll$jscomp$6$$);}var $G__24459$$=null;$G__24459$$=function($coll$jscomp$8$$,$n$jscomp$27$$,$not_found$jscomp$1$$){switch(arguments.length){case 2:return $G__24459__2$$.call(this,$coll$jscomp$8$$,$n$jscomp$27$$);case 3:return $G__24459__3$$.call(this,$coll$jscomp$8$$,$n$jscomp$27$$,$not_found$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);
};$G__24459$$.$cljs$core$IFn$_invoke$arity$2$=$G__24459__2$$;$G__24459$$.$cljs$core$IFn$_invoke$arity$3$=$G__24459__3$$;return $G__24459$$}();
$APP.$cljs$core$_nth$$=function $cljs$core$_nth$$($var_args$jscomp$93$$){switch(arguments.length){case 2:return $cljs$core$_nth$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$_nth$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cljs$core$_nth$$.$cljs$core$IFn$_invoke$arity$2$=function($coll$jscomp$9$$,$n$jscomp$28$$){return $coll$jscomp$9$$!=null&&$coll$jscomp$9$$.$cljs$core$IIndexed$_nth$arity$2$!=null?$coll$jscomp$9$$.$cljs$core$IIndexed$_nth$arity$2$($coll$jscomp$9$$,$n$jscomp$28$$):$cljs$core$IIndexed$_nth$dyn_24458$$($coll$jscomp$9$$,$n$jscomp$28$$)};
$APP.$cljs$core$_nth$$.$cljs$core$IFn$_invoke$arity$3$=function($coll$jscomp$10$$,$n$jscomp$29$$,$not_found$jscomp$2$$){return $coll$jscomp$10$$!=null&&$coll$jscomp$10$$.$cljs$core$IIndexed$_nth$arity$3$!=null?$coll$jscomp$10$$.$cljs$core$IIndexed$_nth$arity$3$($coll$jscomp$10$$,$n$jscomp$29$$,$not_found$jscomp$2$$):$cljs$core$IIndexed$_nth$dyn_24458$$($coll$jscomp$10$$,$n$jscomp$29$$,$not_found$jscomp$2$$)};$APP.$cljs$core$_nth$$.$cljs$lang$maxFixedArity$=3;
$cljs$core$ILookup$_lookup$dyn_24466$$=function(){function $G__24467__3$$($o$jscomp$20$$,$k$jscomp$27$$,$not_found$jscomp$3$$){var $m__5372__auto__$jscomp$32_m__5374__auto__$jscomp$32$$=$APP.$cljs$core$_lookup$$[$APP.$goog$typeOf$$($o$jscomp$20$$==null?null:$o$jscomp$20$$)];if($m__5372__auto__$jscomp$32_m__5374__auto__$jscomp$32$$!=null)return $m__5372__auto__$jscomp$32_m__5374__auto__$jscomp$32$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$32_m__5374__auto__$jscomp$32$$.$cljs$core$IFn$_invoke$arity$3$($o$jscomp$20$$,
$k$jscomp$27$$,$not_found$jscomp$3$$):$m__5372__auto__$jscomp$32_m__5374__auto__$jscomp$32$$($o$jscomp$20$$,$k$jscomp$27$$,$not_found$jscomp$3$$);$m__5372__auto__$jscomp$32_m__5374__auto__$jscomp$32$$=$APP.$cljs$core$_lookup$$._;if($m__5372__auto__$jscomp$32_m__5374__auto__$jscomp$32$$!=null)return $m__5372__auto__$jscomp$32_m__5374__auto__$jscomp$32$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$32_m__5374__auto__$jscomp$32$$.$cljs$core$IFn$_invoke$arity$3$($o$jscomp$20$$,$k$jscomp$27$$,
$not_found$jscomp$3$$):$m__5372__auto__$jscomp$32_m__5374__auto__$jscomp$32$$($o$jscomp$20$$,$k$jscomp$27$$,$not_found$jscomp$3$$);throw $APP.$cljs$core$missing_protocol$$("ILookup.-lookup",$o$jscomp$20$$);}function $G__24467__2$$($o$jscomp$19$$,$k$jscomp$26$$){var $m__5372__auto__$jscomp$31_m__5374__auto__$jscomp$31$$=$APP.$cljs$core$_lookup$$[$APP.$goog$typeOf$$($o$jscomp$19$$==null?null:$o$jscomp$19$$)];if($m__5372__auto__$jscomp$31_m__5374__auto__$jscomp$31$$!=null)return $m__5372__auto__$jscomp$31_m__5374__auto__$jscomp$31$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$31_m__5374__auto__$jscomp$31$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$19$$,$k$jscomp$26$$):$m__5372__auto__$jscomp$31_m__5374__auto__$jscomp$31$$($o$jscomp$19$$,$k$jscomp$26$$);$m__5372__auto__$jscomp$31_m__5374__auto__$jscomp$31$$=$APP.$cljs$core$_lookup$$._;if($m__5372__auto__$jscomp$31_m__5374__auto__$jscomp$31$$!=null)return $m__5372__auto__$jscomp$31_m__5374__auto__$jscomp$31$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$31_m__5374__auto__$jscomp$31$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$19$$,
$k$jscomp$26$$):$m__5372__auto__$jscomp$31_m__5374__auto__$jscomp$31$$($o$jscomp$19$$,$k$jscomp$26$$);throw $APP.$cljs$core$missing_protocol$$("ILookup.-lookup",$o$jscomp$19$$);}var $G__24467$$=null;$G__24467$$=function($o$jscomp$21$$,$k$jscomp$28$$,$not_found$jscomp$4$$){switch(arguments.length){case 2:return $G__24467__2$$.call(this,$o$jscomp$21$$,$k$jscomp$28$$);case 3:return $G__24467__3$$.call(this,$o$jscomp$21$$,$k$jscomp$28$$,$not_found$jscomp$4$$)}throw Error("Invalid arity: "+arguments.length);
};$G__24467$$.$cljs$core$IFn$_invoke$arity$2$=$G__24467__2$$;$G__24467$$.$cljs$core$IFn$_invoke$arity$3$=$G__24467__3$$;return $G__24467$$}();
$APP.$cljs$core$_lookup$$=function $cljs$core$_lookup$$($var_args$jscomp$94$$){switch(arguments.length){case 2:return $cljs$core$_lookup$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$_lookup$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cljs$core$_lookup$$.$cljs$core$IFn$_invoke$arity$2$=function($o$jscomp$22$$,$k$jscomp$29$$){return $o$jscomp$22$$!=null&&$o$jscomp$22$$.$cljs$core$ILookup$_lookup$arity$2$!=null?$o$jscomp$22$$.$cljs$core$ILookup$_lookup$arity$2$($o$jscomp$22$$,$k$jscomp$29$$):$cljs$core$ILookup$_lookup$dyn_24466$$($o$jscomp$22$$,$k$jscomp$29$$)};
$APP.$cljs$core$_lookup$$.$cljs$core$IFn$_invoke$arity$3$=function($o$jscomp$23$$,$k$jscomp$30$$,$not_found$jscomp$5$$){return $o$jscomp$23$$!=null&&$o$jscomp$23$$.$cljs$core$ILookup$_lookup$arity$3$!=null?$o$jscomp$23$$.$cljs$core$ILookup$_lookup$arity$3$($o$jscomp$23$$,$k$jscomp$30$$,$not_found$jscomp$5$$):$cljs$core$ILookup$_lookup$dyn_24466$$($o$jscomp$23$$,$k$jscomp$30$$,$not_found$jscomp$5$$)};$APP.$cljs$core$_lookup$$.$cljs$lang$maxFixedArity$=3;
var $cljs$core$IReduce$_reduce$dyn_24512$$=function(){function $G__24513__3$$($coll$jscomp$38$$,$f$jscomp$82$$,$start$jscomp$16$$){var $m__5372__auto__$jscomp$48_m__5374__auto__$jscomp$48$$=$cljs$core$_reduce$$[$APP.$goog$typeOf$$($coll$jscomp$38$$==null?null:$coll$jscomp$38$$)];if($m__5372__auto__$jscomp$48_m__5374__auto__$jscomp$48$$!=null)return $m__5372__auto__$jscomp$48_m__5374__auto__$jscomp$48$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$48_m__5374__auto__$jscomp$48$$.$cljs$core$IFn$_invoke$arity$3$($coll$jscomp$38$$,
$f$jscomp$82$$,$start$jscomp$16$$):$m__5372__auto__$jscomp$48_m__5374__auto__$jscomp$48$$($coll$jscomp$38$$,$f$jscomp$82$$,$start$jscomp$16$$);$m__5372__auto__$jscomp$48_m__5374__auto__$jscomp$48$$=$cljs$core$_reduce$$._;if($m__5372__auto__$jscomp$48_m__5374__auto__$jscomp$48$$!=null)return $m__5372__auto__$jscomp$48_m__5374__auto__$jscomp$48$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$48_m__5374__auto__$jscomp$48$$.$cljs$core$IFn$_invoke$arity$3$($coll$jscomp$38$$,$f$jscomp$82$$,$start$jscomp$16$$):
$m__5372__auto__$jscomp$48_m__5374__auto__$jscomp$48$$($coll$jscomp$38$$,$f$jscomp$82$$,$start$jscomp$16$$);throw $APP.$cljs$core$missing_protocol$$("IReduce.-reduce",$coll$jscomp$38$$);}function $G__24513__2$$($coll$jscomp$37$$,$f$jscomp$81$$){var $m__5372__auto__$jscomp$47_m__5374__auto__$jscomp$47$$=$cljs$core$_reduce$$[$APP.$goog$typeOf$$($coll$jscomp$37$$==null?null:$coll$jscomp$37$$)];if($m__5372__auto__$jscomp$47_m__5374__auto__$jscomp$47$$!=null)return $m__5372__auto__$jscomp$47_m__5374__auto__$jscomp$47$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$47_m__5374__auto__$jscomp$47$$.$cljs$core$IFn$_invoke$arity$2$($coll$jscomp$37$$,$f$jscomp$81$$):$m__5372__auto__$jscomp$47_m__5374__auto__$jscomp$47$$($coll$jscomp$37$$,$f$jscomp$81$$);$m__5372__auto__$jscomp$47_m__5374__auto__$jscomp$47$$=$cljs$core$_reduce$$._;if($m__5372__auto__$jscomp$47_m__5374__auto__$jscomp$47$$!=null)return $m__5372__auto__$jscomp$47_m__5374__auto__$jscomp$47$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$47_m__5374__auto__$jscomp$47$$.$cljs$core$IFn$_invoke$arity$2$($coll$jscomp$37$$,
$f$jscomp$81$$):$m__5372__auto__$jscomp$47_m__5374__auto__$jscomp$47$$($coll$jscomp$37$$,$f$jscomp$81$$);throw $APP.$cljs$core$missing_protocol$$("IReduce.-reduce",$coll$jscomp$37$$);}var $G__24513$$=null;$G__24513$$=function($coll$jscomp$39$$,$f$jscomp$83$$,$start$jscomp$17$$){switch(arguments.length){case 2:return $G__24513__2$$.call(this,$coll$jscomp$39$$,$f$jscomp$83$$);case 3:return $G__24513__3$$.call(this,$coll$jscomp$39$$,$f$jscomp$83$$,$start$jscomp$17$$)}throw Error("Invalid arity: "+arguments.length);
};$G__24513$$.$cljs$core$IFn$_invoke$arity$2$=$G__24513__2$$;$G__24513$$.$cljs$core$IFn$_invoke$arity$3$=$G__24513__3$$;return $G__24513$$}(),$cljs$core$_reduce$$=function $cljs$core$_reduce$$($var_args$jscomp$95$$){switch(arguments.length){case 2:return $cljs$core$_reduce$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$_reduce$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$cljs$core$_reduce$$.$cljs$core$IFn$_invoke$arity$2$=function($coll$jscomp$40$$,$f$jscomp$84$$){return $coll$jscomp$40$$!=null&&$coll$jscomp$40$$.$cljs$core$IReduce$_reduce$arity$2$!=null?$coll$jscomp$40$$.$cljs$core$IReduce$_reduce$arity$2$($coll$jscomp$40$$,$f$jscomp$84$$):$cljs$core$IReduce$_reduce$dyn_24512$$($coll$jscomp$40$$,$f$jscomp$84$$)};
$cljs$core$_reduce$$.$cljs$core$IFn$_invoke$arity$3$=function($coll$jscomp$41$$,$f$jscomp$85$$,$start$jscomp$18$$){return $coll$jscomp$41$$!=null&&$coll$jscomp$41$$.$cljs$core$IReduce$_reduce$arity$3$!=null?$coll$jscomp$41$$.$cljs$core$IReduce$_reduce$arity$3$($coll$jscomp$41$$,$f$jscomp$85$$,$start$jscomp$18$$):$cljs$core$IReduce$_reduce$dyn_24512$$($coll$jscomp$41$$,$f$jscomp$85$$,$start$jscomp$18$$)};$cljs$core$_reduce$$.$cljs$lang$maxFixedArity$=3;
var $cljs$core$ISwap$_swap_BANG_$dyn_24604$$=function(){function $G__24605__5$$($o$jscomp$45$$,$f$jscomp$93$$,$a$jscomp$58$$,$b$jscomp$52$$,$xs$jscomp$2$$){var $m__5372__auto__$jscomp$84_m__5374__auto__$jscomp$84$$=$cljs$core$_swap_BANG_$$[$APP.$goog$typeOf$$($o$jscomp$45$$==null?null:$o$jscomp$45$$)];if($m__5372__auto__$jscomp$84_m__5374__auto__$jscomp$84$$!=null)return $m__5372__auto__$jscomp$84_m__5374__auto__$jscomp$84$$.$cljs$core$IFn$_invoke$arity$5$?$m__5372__auto__$jscomp$84_m__5374__auto__$jscomp$84$$.$cljs$core$IFn$_invoke$arity$5$($o$jscomp$45$$,
$f$jscomp$93$$,$a$jscomp$58$$,$b$jscomp$52$$,$xs$jscomp$2$$):$m__5372__auto__$jscomp$84_m__5374__auto__$jscomp$84$$($o$jscomp$45$$,$f$jscomp$93$$,$a$jscomp$58$$,$b$jscomp$52$$,$xs$jscomp$2$$);$m__5372__auto__$jscomp$84_m__5374__auto__$jscomp$84$$=$cljs$core$_swap_BANG_$$._;if($m__5372__auto__$jscomp$84_m__5374__auto__$jscomp$84$$!=null)return $m__5372__auto__$jscomp$84_m__5374__auto__$jscomp$84$$.$cljs$core$IFn$_invoke$arity$5$?$m__5372__auto__$jscomp$84_m__5374__auto__$jscomp$84$$.$cljs$core$IFn$_invoke$arity$5$($o$jscomp$45$$,
$f$jscomp$93$$,$a$jscomp$58$$,$b$jscomp$52$$,$xs$jscomp$2$$):$m__5372__auto__$jscomp$84_m__5374__auto__$jscomp$84$$($o$jscomp$45$$,$f$jscomp$93$$,$a$jscomp$58$$,$b$jscomp$52$$,$xs$jscomp$2$$);throw $APP.$cljs$core$missing_protocol$$("ISwap.-swap!",$o$jscomp$45$$);}function $G__24605__4$$($o$jscomp$44$$,$f$jscomp$92$$,$a$jscomp$57$$,$b$jscomp$51$$){var $m__5372__auto__$jscomp$83_m__5374__auto__$jscomp$83$$=$cljs$core$_swap_BANG_$$[$APP.$goog$typeOf$$($o$jscomp$44$$==null?null:$o$jscomp$44$$)];if($m__5372__auto__$jscomp$83_m__5374__auto__$jscomp$83$$!=
null)return $m__5372__auto__$jscomp$83_m__5374__auto__$jscomp$83$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$83_m__5374__auto__$jscomp$83$$.$cljs$core$IFn$_invoke$arity$4$($o$jscomp$44$$,$f$jscomp$92$$,$a$jscomp$57$$,$b$jscomp$51$$):$m__5372__auto__$jscomp$83_m__5374__auto__$jscomp$83$$($o$jscomp$44$$,$f$jscomp$92$$,$a$jscomp$57$$,$b$jscomp$51$$);$m__5372__auto__$jscomp$83_m__5374__auto__$jscomp$83$$=$cljs$core$_swap_BANG_$$._;if($m__5372__auto__$jscomp$83_m__5374__auto__$jscomp$83$$!=
null)return $m__5372__auto__$jscomp$83_m__5374__auto__$jscomp$83$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$83_m__5374__auto__$jscomp$83$$.$cljs$core$IFn$_invoke$arity$4$($o$jscomp$44$$,$f$jscomp$92$$,$a$jscomp$57$$,$b$jscomp$51$$):$m__5372__auto__$jscomp$83_m__5374__auto__$jscomp$83$$($o$jscomp$44$$,$f$jscomp$92$$,$a$jscomp$57$$,$b$jscomp$51$$);throw $APP.$cljs$core$missing_protocol$$("ISwap.-swap!",$o$jscomp$44$$);}function $G__24605__3$$($o$jscomp$43$$,$f$jscomp$91$$,$a$jscomp$56$$){var $m__5372__auto__$jscomp$82_m__5374__auto__$jscomp$82$$=
$cljs$core$_swap_BANG_$$[$APP.$goog$typeOf$$($o$jscomp$43$$==null?null:$o$jscomp$43$$)];if($m__5372__auto__$jscomp$82_m__5374__auto__$jscomp$82$$!=null)return $m__5372__auto__$jscomp$82_m__5374__auto__$jscomp$82$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$82_m__5374__auto__$jscomp$82$$.$cljs$core$IFn$_invoke$arity$3$($o$jscomp$43$$,$f$jscomp$91$$,$a$jscomp$56$$):$m__5372__auto__$jscomp$82_m__5374__auto__$jscomp$82$$($o$jscomp$43$$,$f$jscomp$91$$,$a$jscomp$56$$);$m__5372__auto__$jscomp$82_m__5374__auto__$jscomp$82$$=
$cljs$core$_swap_BANG_$$._;if($m__5372__auto__$jscomp$82_m__5374__auto__$jscomp$82$$!=null)return $m__5372__auto__$jscomp$82_m__5374__auto__$jscomp$82$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$82_m__5374__auto__$jscomp$82$$.$cljs$core$IFn$_invoke$arity$3$($o$jscomp$43$$,$f$jscomp$91$$,$a$jscomp$56$$):$m__5372__auto__$jscomp$82_m__5374__auto__$jscomp$82$$($o$jscomp$43$$,$f$jscomp$91$$,$a$jscomp$56$$);throw $APP.$cljs$core$missing_protocol$$("ISwap.-swap!",$o$jscomp$43$$);}function $G__24605__2$$($o$jscomp$42$$,
$f$jscomp$90$$){var $m__5372__auto__$jscomp$81_m__5374__auto__$jscomp$81$$=$cljs$core$_swap_BANG_$$[$APP.$goog$typeOf$$($o$jscomp$42$$==null?null:$o$jscomp$42$$)];if($m__5372__auto__$jscomp$81_m__5374__auto__$jscomp$81$$!=null)return $m__5372__auto__$jscomp$81_m__5374__auto__$jscomp$81$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$81_m__5374__auto__$jscomp$81$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$42$$,$f$jscomp$90$$):$m__5372__auto__$jscomp$81_m__5374__auto__$jscomp$81$$($o$jscomp$42$$,
$f$jscomp$90$$);$m__5372__auto__$jscomp$81_m__5374__auto__$jscomp$81$$=$cljs$core$_swap_BANG_$$._;if($m__5372__auto__$jscomp$81_m__5374__auto__$jscomp$81$$!=null)return $m__5372__auto__$jscomp$81_m__5374__auto__$jscomp$81$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$81_m__5374__auto__$jscomp$81$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$42$$,$f$jscomp$90$$):$m__5372__auto__$jscomp$81_m__5374__auto__$jscomp$81$$($o$jscomp$42$$,$f$jscomp$90$$);throw $APP.$cljs$core$missing_protocol$$("ISwap.-swap!",
$o$jscomp$42$$);}var $G__24605$$=null;$G__24605$$=function($o$jscomp$46$$,$f$jscomp$94$$,$a$jscomp$59$$,$b$jscomp$53$$,$xs$jscomp$3$$){switch(arguments.length){case 2:return $G__24605__2$$.call(this,$o$jscomp$46$$,$f$jscomp$94$$);case 3:return $G__24605__3$$.call(this,$o$jscomp$46$$,$f$jscomp$94$$,$a$jscomp$59$$);case 4:return $G__24605__4$$.call(this,$o$jscomp$46$$,$f$jscomp$94$$,$a$jscomp$59$$,$b$jscomp$53$$);case 5:return $G__24605__5$$.call(this,$o$jscomp$46$$,$f$jscomp$94$$,$a$jscomp$59$$,$b$jscomp$53$$,
$xs$jscomp$3$$)}throw Error("Invalid arity: "+arguments.length);};$G__24605$$.$cljs$core$IFn$_invoke$arity$2$=$G__24605__2$$;$G__24605$$.$cljs$core$IFn$_invoke$arity$3$=$G__24605__3$$;$G__24605$$.$cljs$core$IFn$_invoke$arity$4$=$G__24605__4$$;$G__24605$$.$cljs$core$IFn$_invoke$arity$5$=$G__24605__5$$;return $G__24605$$}(),$cljs$core$_swap_BANG_$$=function $cljs$core$_swap_BANG_$$($var_args$jscomp$96$$){switch(arguments.length){case 2:return $cljs$core$_swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],
arguments[1]);case 3:return $cljs$core$_swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $cljs$core$_swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);case 5:return $cljs$core$_swap_BANG_$$.$cljs$core$IFn$_invoke$arity$5$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$cljs$core$_swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$=function($o$jscomp$47$$,$f$jscomp$95$$){return $o$jscomp$47$$!=null&&$o$jscomp$47$$.$cljs$core$ISwap$_swap_BANG_$arity$2$!=null?$o$jscomp$47$$.$cljs$core$ISwap$_swap_BANG_$arity$2$($o$jscomp$47$$,$f$jscomp$95$$):$cljs$core$ISwap$_swap_BANG_$dyn_24604$$($o$jscomp$47$$,$f$jscomp$95$$)};
$cljs$core$_swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$=function($o$jscomp$48$$,$f$jscomp$96$$,$a$jscomp$60$$){return $o$jscomp$48$$!=null&&$o$jscomp$48$$.$cljs$core$ISwap$_swap_BANG_$arity$3$!=null?$o$jscomp$48$$.$cljs$core$ISwap$_swap_BANG_$arity$3$($o$jscomp$48$$,$f$jscomp$96$$,$a$jscomp$60$$):$cljs$core$ISwap$_swap_BANG_$dyn_24604$$($o$jscomp$48$$,$f$jscomp$96$$,$a$jscomp$60$$)};
$cljs$core$_swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$=function($o$jscomp$49$$,$f$jscomp$97$$,$a$jscomp$61$$,$b$jscomp$54$$){return $o$jscomp$49$$!=null&&$o$jscomp$49$$.$cljs$core$ISwap$_swap_BANG_$arity$4$!=null?$o$jscomp$49$$.$cljs$core$ISwap$_swap_BANG_$arity$4$($o$jscomp$49$$,$f$jscomp$97$$,$a$jscomp$61$$,$b$jscomp$54$$):$cljs$core$ISwap$_swap_BANG_$dyn_24604$$($o$jscomp$49$$,$f$jscomp$97$$,$a$jscomp$61$$,$b$jscomp$54$$)};
$cljs$core$_swap_BANG_$$.$cljs$core$IFn$_invoke$arity$5$=function($o$jscomp$50$$,$f$jscomp$98$$,$a$jscomp$62$$,$b$jscomp$55$$,$xs$jscomp$4$$){return $o$jscomp$50$$!=null&&$o$jscomp$50$$.$cljs$core$ISwap$_swap_BANG_$arity$5$!=null?$o$jscomp$50$$.$cljs$core$ISwap$_swap_BANG_$arity$5$($o$jscomp$50$$,$f$jscomp$98$$,$a$jscomp$62$$,$b$jscomp$55$$,$xs$jscomp$4$$):$cljs$core$ISwap$_swap_BANG_$dyn_24604$$($o$jscomp$50$$,$f$jscomp$98$$,$a$jscomp$62$$,$b$jscomp$55$$,$xs$jscomp$4$$)};
$cljs$core$_swap_BANG_$$.$cljs$lang$maxFixedArity$=5;$cljs$core$StringBufferWriter$$.prototype.$cljs$core$IWriter$_write$arity$2$=function($_$$,$s$jscomp$31$$){return this.sb.append($s$jscomp$31$$)};$cljs$core$StringBufferWriter$$.prototype.$cljs$core$IWriter$_flush$arity$1$=function(){return null};
$APP.$cljs$core$imul$$=typeof Math!=="undefined"&&typeof Math.imul!=="undefined"?function($a$jscomp$63$$,$b$jscomp$56$$){return Math.imul($a$jscomp$63$$,$b$jscomp$56$$)}:function($a$jscomp$64$$,$b$jscomp$57$$){var $al$$=$a$jscomp$64$$&65535,$bl$$=$b$jscomp$57$$&65535;return $al$$*$bl$$+(($a$jscomp$64$$>>>16&65535)*$bl$$+$al$$*($b$jscomp$57$$>>>16&65535)<<16>>>0)|0};$cljs$core$string_hash_cache$$={};$cljs$core$string_hash_cache_count$$=0;$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$Symbol$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.toString=function(){return this.$str$};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$46$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$46$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($_$jscomp$3$$,$other$jscomp$47$$){return $other$jscomp$47$$ instanceof $APP.$cljs$core$Symbol$$?this.$str$===$other$jscomp$47$$.$str$:!1};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$6$$,$args22823$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args22823$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($coll$jscomp$68$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($coll$jscomp$68$$,this):$APP.$cljs$core$get$$($coll$jscomp$68$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($coll$jscomp$69$$,$not_found$jscomp$6$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($coll$jscomp$69$$,this,$not_found$jscomp$6$$):$APP.$cljs$core$get$$($coll$jscomp$69$$,this,$not_found$jscomp$6$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$_meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_$jscomp$5$$,$new_meta$$){return new $APP.$cljs$core$Symbol$$(this.ns,this.name,this.$str$,this.$_hash$,$new_meta$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto___h__5134__auto____$1$$=this.$_hash$;return $h__5134__auto___h__5134__auto____$1$$!=null?$h__5134__auto___h__5134__auto____$1$$:this.$_hash$=$h__5134__auto___h__5134__auto____$1$$=$cljs$core$hash_symbol$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INamed$_name$arity$1$=function(){return this.name};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INamed$_namespace$arity$1$=function(){return this.ns};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($o$jscomp$54$$,$writer$jscomp$7$$){return $APP.$cljs$core$_write$$($writer$jscomp$7$$,this.$str$)};
$APP.$cljs$core$symbol$$=function $cljs$core$symbol$$($var_args$jscomp$97$$){switch(arguments.length){case 1:return $cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$=function($name$jscomp$103$$){for(;;){if($name$jscomp$103$$ instanceof $APP.$cljs$core$Symbol$$)return $name$jscomp$103$$;if(typeof $name$jscomp$103$$==="string"){var $idx$jscomp$12$$=$name$jscomp$103$$.indexOf("/");return $idx$jscomp$12$$<1?$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$(null,$name$jscomp$103$$):$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$103$$.substring(0,$idx$jscomp$12$$),$name$jscomp$103$$.substring($idx$jscomp$12$$+
1,$name$jscomp$103$$.length))}if($name$jscomp$103$$ instanceof $APP.$cljs$core$Var$$)return $name$jscomp$103$$.$sym$;if($name$jscomp$103$$ instanceof $APP.$cljs$core$Keyword$$)$name$jscomp$103$$=$name$jscomp$103$$.$fqn$;else throw Error("no conversion to symbol");}};
$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$=function($ns$jscomp$3$$,$name$jscomp$104$$){var $sym_str$$=$ns$jscomp$3$$!=null?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ns$jscomp$3$$),"/",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$104$$)].join(""):$name$jscomp$104$$;return new $APP.$cljs$core$Symbol$$($ns$jscomp$3$$,$name$jscomp$104$$,$sym_str$$,null,null)};$APP.$cljs$core$symbol$$.$cljs$lang$maxFixedArity$=2;$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$Var$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.toString=function(){return["#'",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.$sym$)].join("")};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDeref$_deref$arity$1$=function(){return this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$()};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$_meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_$jscomp$13$$,$new_meta$jscomp$1$$){return new $APP.$cljs$core$Var$$(this.$val$,this.$sym$,$new_meta$jscomp$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($G__22828_this$$jscomp$52$$,$G__22829_other$jscomp$48$$){return $G__22829_other$jscomp$48$$ instanceof $APP.$cljs$core$Var$$?($G__22828_this$$jscomp$52$$=this.$sym$,$G__22829_other$jscomp$48$$=$G__22829_other$jscomp$48$$.$sym$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__22828_this$$jscomp$52$$,$G__22829_other$jscomp$48$$):$APP.$cljs$core$_EQ_$$($G__22828_this$$jscomp$52$$,
$G__22829_other$jscomp$48$$)):!1};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $cljs$core$hash_symbol$$(this.$sym$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$Fn$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$1$$){switch(arguments.length-1){case 0:return this.$cljs$core$IFn$_invoke$arity$0$();case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);case 3:return this.$cljs$core$IFn$_invoke$arity$3$(arguments[1],arguments[2],arguments[3]);case 4:return this.$cljs$core$IFn$_invoke$arity$4$(arguments[1],arguments[2],arguments[3],arguments[4]);
case 5:return this.$cljs$core$IFn$_invoke$arity$5$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5]);case 6:return this.$cljs$core$IFn$_invoke$arity$6$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6]);case 7:return this.$cljs$core$IFn$_invoke$arity$7$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7]);case 8:return this.$cljs$core$IFn$_invoke$arity$8$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],
arguments[6],arguments[7],arguments[8]);case 9:return this.$cljs$core$IFn$_invoke$arity$9$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9]);case 10:return this.$cljs$core$IFn$_invoke$arity$10$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10]);case 11:return this.$cljs$core$IFn$_invoke$arity$11$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],
arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11]);case 12:return this.$cljs$core$IFn$_invoke$arity$12$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12]);case 13:return this.$cljs$core$IFn$_invoke$arity$13$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],
arguments[13]);case 14:return this.$cljs$core$IFn$_invoke$arity$14$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14]);case 15:return this.$cljs$core$IFn$_invoke$arity$15$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15]);
case 16:return this.$cljs$core$IFn$_invoke$arity$16$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16]);case 17:return this.$cljs$core$IFn$_invoke$arity$17$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],
arguments[15],arguments[16],arguments[17]);case 18:return this.$cljs$core$IFn$_invoke$arity$18$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18]);case 19:return this.$cljs$core$IFn$_invoke$arity$19$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],
arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19]);case 20:return this.$cljs$core$IFn$_invoke$arity$20$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19],arguments[20]);case 21:return this.$cljs$core$IFn$_invoke$arity$21$(arguments[1],
arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19],arguments[20],arguments[21]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};
$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$23$$,$args22827$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args22827$$)))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$0$=function(){var $fexpr__22831$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22831$$.$cljs$core$IFn$_invoke$arity$0$?$fexpr__22831$$.$cljs$core$IFn$_invoke$arity$0$():$fexpr__22831$$()};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($a$jscomp$66$$){var $fexpr__22832$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22832$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__22832$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$66$$):$fexpr__22832$$($a$jscomp$66$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($a$jscomp$67$$,$b$jscomp$59$$){var $fexpr__22833$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22833$$.$cljs$core$IFn$_invoke$arity$2$?$fexpr__22833$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$67$$,$b$jscomp$59$$):$fexpr__22833$$($a$jscomp$67$$,$b$jscomp$59$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$3$=function($a$jscomp$68$$,$b$jscomp$60$$,$c$jscomp$44$$){var $fexpr__22834$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22834$$.$cljs$core$IFn$_invoke$arity$3$?$fexpr__22834$$.$cljs$core$IFn$_invoke$arity$3$($a$jscomp$68$$,$b$jscomp$60$$,$c$jscomp$44$$):$fexpr__22834$$($a$jscomp$68$$,$b$jscomp$60$$,$c$jscomp$44$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$4$=function($a$jscomp$69$$,$b$jscomp$61$$,$c$jscomp$45$$,$d$jscomp$37$$){var $fexpr__22835$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22835$$.$cljs$core$IFn$_invoke$arity$4$?$fexpr__22835$$.$cljs$core$IFn$_invoke$arity$4$($a$jscomp$69$$,$b$jscomp$61$$,$c$jscomp$45$$,$d$jscomp$37$$):$fexpr__22835$$($a$jscomp$69$$,$b$jscomp$61$$,$c$jscomp$45$$,$d$jscomp$37$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$5$=function($a$jscomp$70$$,$b$jscomp$62$$,$c$jscomp$46$$,$d$jscomp$38$$,$e$jscomp$51$$){var $fexpr__22836$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22836$$.$cljs$core$IFn$_invoke$arity$5$?$fexpr__22836$$.$cljs$core$IFn$_invoke$arity$5$($a$jscomp$70$$,$b$jscomp$62$$,$c$jscomp$46$$,$d$jscomp$38$$,$e$jscomp$51$$):$fexpr__22836$$($a$jscomp$70$$,$b$jscomp$62$$,$c$jscomp$46$$,
$d$jscomp$38$$,$e$jscomp$51$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$6$=function($a$jscomp$71$$,$b$jscomp$63$$,$c$jscomp$47$$,$d$jscomp$39$$,$e$jscomp$52$$,$f$jscomp$100$$){var $fexpr__22837$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22837$$.$cljs$core$IFn$_invoke$arity$6$?$fexpr__22837$$.$cljs$core$IFn$_invoke$arity$6$($a$jscomp$71$$,$b$jscomp$63$$,$c$jscomp$47$$,$d$jscomp$39$$,$e$jscomp$52$$,$f$jscomp$100$$):$fexpr__22837$$($a$jscomp$71$$,
$b$jscomp$63$$,$c$jscomp$47$$,$d$jscomp$39$$,$e$jscomp$52$$,$f$jscomp$100$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$7$=function($a$jscomp$72$$,$b$jscomp$64$$,$c$jscomp$48$$,$d$jscomp$40$$,$e$jscomp$53$$,$f$jscomp$101$$,$g$jscomp$31$$){var $fexpr__22838$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22838$$.$cljs$core$IFn$_invoke$arity$7$?$fexpr__22838$$.$cljs$core$IFn$_invoke$arity$7$($a$jscomp$72$$,$b$jscomp$64$$,$c$jscomp$48$$,$d$jscomp$40$$,$e$jscomp$53$$,$f$jscomp$101$$,$g$jscomp$31$$):
$fexpr__22838$$($a$jscomp$72$$,$b$jscomp$64$$,$c$jscomp$48$$,$d$jscomp$40$$,$e$jscomp$53$$,$f$jscomp$101$$,$g$jscomp$31$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$8$=function($a$jscomp$73$$,$b$jscomp$65$$,$c$jscomp$49$$,$d$jscomp$41$$,$e$jscomp$54$$,$f$jscomp$102$$,$g$jscomp$32$$,$h$jscomp$40$$){var $fexpr__22839$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22839$$.$cljs$core$IFn$_invoke$arity$8$?$fexpr__22839$$.$cljs$core$IFn$_invoke$arity$8$($a$jscomp$73$$,$b$jscomp$65$$,$c$jscomp$49$$,$d$jscomp$41$$,$e$jscomp$54$$,$f$jscomp$102$$,
$g$jscomp$32$$,$h$jscomp$40$$):$fexpr__22839$$($a$jscomp$73$$,$b$jscomp$65$$,$c$jscomp$49$$,$d$jscomp$41$$,$e$jscomp$54$$,$f$jscomp$102$$,$g$jscomp$32$$,$h$jscomp$40$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$9$=function($a$jscomp$74$$,$b$jscomp$66$$,$c$jscomp$50$$,$d$jscomp$42$$,$e$jscomp$55$$,$f$jscomp$103$$,$g$jscomp$33$$,$h$jscomp$41$$,$i$jscomp$149$$){var $fexpr__22840$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22840$$.$cljs$core$IFn$_invoke$arity$9$?$fexpr__22840$$.$cljs$core$IFn$_invoke$arity$9$($a$jscomp$74$$,$b$jscomp$66$$,$c$jscomp$50$$,$d$jscomp$42$$,$e$jscomp$55$$,
$f$jscomp$103$$,$g$jscomp$33$$,$h$jscomp$41$$,$i$jscomp$149$$):$fexpr__22840$$($a$jscomp$74$$,$b$jscomp$66$$,$c$jscomp$50$$,$d$jscomp$42$$,$e$jscomp$55$$,$f$jscomp$103$$,$g$jscomp$33$$,$h$jscomp$41$$,$i$jscomp$149$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$10$=function($a$jscomp$75$$,$b$jscomp$67$$,$c$jscomp$51$$,$d$jscomp$43$$,$e$jscomp$56$$,$f$jscomp$104$$,$g$jscomp$34$$,$h$jscomp$42$$,$i$jscomp$150$$,$j$jscomp$35$$){var $fexpr__22841$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22841$$.$cljs$core$IFn$_invoke$arity$10$?$fexpr__22841$$.$cljs$core$IFn$_invoke$arity$10$($a$jscomp$75$$,$b$jscomp$67$$,$c$jscomp$51$$,$d$jscomp$43$$,
$e$jscomp$56$$,$f$jscomp$104$$,$g$jscomp$34$$,$h$jscomp$42$$,$i$jscomp$150$$,$j$jscomp$35$$):$fexpr__22841$$($a$jscomp$75$$,$b$jscomp$67$$,$c$jscomp$51$$,$d$jscomp$43$$,$e$jscomp$56$$,$f$jscomp$104$$,$g$jscomp$34$$,$h$jscomp$42$$,$i$jscomp$150$$,$j$jscomp$35$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$11$=function($a$jscomp$76$$,$b$jscomp$68$$,$c$jscomp$52$$,$d$jscomp$44$$,$e$jscomp$57$$,$f$jscomp$105$$,$g$jscomp$35$$,$h$jscomp$43$$,$i$jscomp$151$$,$j$jscomp$36$$,$k$jscomp$43$$){var $fexpr__22842$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22842$$.$cljs$core$IFn$_invoke$arity$11$?$fexpr__22842$$.$cljs$core$IFn$_invoke$arity$11$($a$jscomp$76$$,$b$jscomp$68$$,$c$jscomp$52$$,
$d$jscomp$44$$,$e$jscomp$57$$,$f$jscomp$105$$,$g$jscomp$35$$,$h$jscomp$43$$,$i$jscomp$151$$,$j$jscomp$36$$,$k$jscomp$43$$):$fexpr__22842$$($a$jscomp$76$$,$b$jscomp$68$$,$c$jscomp$52$$,$d$jscomp$44$$,$e$jscomp$57$$,$f$jscomp$105$$,$g$jscomp$35$$,$h$jscomp$43$$,$i$jscomp$151$$,$j$jscomp$36$$,$k$jscomp$43$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$12$=function($a$jscomp$77$$,$b$jscomp$69$$,$c$jscomp$53$$,$d$jscomp$45$$,$e$jscomp$58$$,$f$jscomp$106$$,$g$jscomp$36$$,$h$jscomp$44$$,$i$jscomp$152$$,$j$jscomp$37$$,$k$jscomp$44$$,$l$jscomp$40$$){var $fexpr__22843$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22843$$.$cljs$core$IFn$_invoke$arity$12$?$fexpr__22843$$.$cljs$core$IFn$_invoke$arity$12$($a$jscomp$77$$,$b$jscomp$69$$,
$c$jscomp$53$$,$d$jscomp$45$$,$e$jscomp$58$$,$f$jscomp$106$$,$g$jscomp$36$$,$h$jscomp$44$$,$i$jscomp$152$$,$j$jscomp$37$$,$k$jscomp$44$$,$l$jscomp$40$$):$fexpr__22843$$($a$jscomp$77$$,$b$jscomp$69$$,$c$jscomp$53$$,$d$jscomp$45$$,$e$jscomp$58$$,$f$jscomp$106$$,$g$jscomp$36$$,$h$jscomp$44$$,$i$jscomp$152$$,$j$jscomp$37$$,$k$jscomp$44$$,$l$jscomp$40$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$13$=function($a$jscomp$78$$,$b$jscomp$70$$,$c$jscomp$54$$,$d$jscomp$46$$,$e$jscomp$59$$,$f$jscomp$107$$,$g$jscomp$37$$,$h$jscomp$45$$,$i$jscomp$153$$,$j$jscomp$38$$,$k$jscomp$45$$,$l$jscomp$41$$,$m$jscomp$20$$){var $fexpr__22844$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22844$$.$cljs$core$IFn$_invoke$arity$13$?$fexpr__22844$$.$cljs$core$IFn$_invoke$arity$13$($a$jscomp$78$$,
$b$jscomp$70$$,$c$jscomp$54$$,$d$jscomp$46$$,$e$jscomp$59$$,$f$jscomp$107$$,$g$jscomp$37$$,$h$jscomp$45$$,$i$jscomp$153$$,$j$jscomp$38$$,$k$jscomp$45$$,$l$jscomp$41$$,$m$jscomp$20$$):$fexpr__22844$$($a$jscomp$78$$,$b$jscomp$70$$,$c$jscomp$54$$,$d$jscomp$46$$,$e$jscomp$59$$,$f$jscomp$107$$,$g$jscomp$37$$,$h$jscomp$45$$,$i$jscomp$153$$,$j$jscomp$38$$,$k$jscomp$45$$,$l$jscomp$41$$,$m$jscomp$20$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$14$=function($a$jscomp$79$$,$b$jscomp$71$$,$c$jscomp$55$$,$d$jscomp$47$$,$e$jscomp$60$$,$f$jscomp$108$$,$g$jscomp$38$$,$h$jscomp$46$$,$i$jscomp$154$$,$j$jscomp$39$$,$k$jscomp$46$$,$l$jscomp$42$$,$m$jscomp$21$$,$n$jscomp$37$$){var $fexpr__22845$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22845$$.$cljs$core$IFn$_invoke$arity$14$?$fexpr__22845$$.$cljs$core$IFn$_invoke$arity$14$($a$jscomp$79$$,
$b$jscomp$71$$,$c$jscomp$55$$,$d$jscomp$47$$,$e$jscomp$60$$,$f$jscomp$108$$,$g$jscomp$38$$,$h$jscomp$46$$,$i$jscomp$154$$,$j$jscomp$39$$,$k$jscomp$46$$,$l$jscomp$42$$,$m$jscomp$21$$,$n$jscomp$37$$):$fexpr__22845$$($a$jscomp$79$$,$b$jscomp$71$$,$c$jscomp$55$$,$d$jscomp$47$$,$e$jscomp$60$$,$f$jscomp$108$$,$g$jscomp$38$$,$h$jscomp$46$$,$i$jscomp$154$$,$j$jscomp$39$$,$k$jscomp$46$$,$l$jscomp$42$$,$m$jscomp$21$$,$n$jscomp$37$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$15$=function($a$jscomp$80$$,$b$jscomp$72$$,$c$jscomp$56$$,$d$jscomp$48$$,$e$jscomp$61$$,$f$jscomp$109$$,$g$jscomp$39$$,$h$jscomp$47$$,$i$jscomp$155$$,$j$jscomp$40$$,$k$jscomp$47$$,$l$jscomp$43$$,$m$jscomp$22$$,$n$jscomp$38$$,$o$jscomp$55$$){var $fexpr__22846$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22846$$.$cljs$core$IFn$_invoke$arity$15$?$fexpr__22846$$.$cljs$core$IFn$_invoke$arity$15$($a$jscomp$80$$,
$b$jscomp$72$$,$c$jscomp$56$$,$d$jscomp$48$$,$e$jscomp$61$$,$f$jscomp$109$$,$g$jscomp$39$$,$h$jscomp$47$$,$i$jscomp$155$$,$j$jscomp$40$$,$k$jscomp$47$$,$l$jscomp$43$$,$m$jscomp$22$$,$n$jscomp$38$$,$o$jscomp$55$$):$fexpr__22846$$($a$jscomp$80$$,$b$jscomp$72$$,$c$jscomp$56$$,$d$jscomp$48$$,$e$jscomp$61$$,$f$jscomp$109$$,$g$jscomp$39$$,$h$jscomp$47$$,$i$jscomp$155$$,$j$jscomp$40$$,$k$jscomp$47$$,$l$jscomp$43$$,$m$jscomp$22$$,$n$jscomp$38$$,$o$jscomp$55$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$16$=function($a$jscomp$81$$,$b$jscomp$73$$,$c$jscomp$57$$,$d$jscomp$49$$,$e$jscomp$62$$,$f$jscomp$110$$,$g$jscomp$40$$,$h$jscomp$48$$,$i$jscomp$156$$,$j$jscomp$41$$,$k$jscomp$48$$,$l$jscomp$44$$,$m$jscomp$23$$,$n$jscomp$39$$,$o$jscomp$56$$,$p$jscomp$15$$){var $fexpr__22847$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22847$$.$cljs$core$IFn$_invoke$arity$16$?$fexpr__22847$$.$cljs$core$IFn$_invoke$arity$16$($a$jscomp$81$$,
$b$jscomp$73$$,$c$jscomp$57$$,$d$jscomp$49$$,$e$jscomp$62$$,$f$jscomp$110$$,$g$jscomp$40$$,$h$jscomp$48$$,$i$jscomp$156$$,$j$jscomp$41$$,$k$jscomp$48$$,$l$jscomp$44$$,$m$jscomp$23$$,$n$jscomp$39$$,$o$jscomp$56$$,$p$jscomp$15$$):$fexpr__22847$$($a$jscomp$81$$,$b$jscomp$73$$,$c$jscomp$57$$,$d$jscomp$49$$,$e$jscomp$62$$,$f$jscomp$110$$,$g$jscomp$40$$,$h$jscomp$48$$,$i$jscomp$156$$,$j$jscomp$41$$,$k$jscomp$48$$,$l$jscomp$44$$,$m$jscomp$23$$,$n$jscomp$39$$,$o$jscomp$56$$,$p$jscomp$15$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$17$=function($a$jscomp$82$$,$b$jscomp$74$$,$c$jscomp$58$$,$d$jscomp$50$$,$e$jscomp$63$$,$f$jscomp$111$$,$g$jscomp$41$$,$h$jscomp$49$$,$i$jscomp$157$$,$j$jscomp$42$$,$k$jscomp$49$$,$l$jscomp$45$$,$m$jscomp$24$$,$n$jscomp$40$$,$o$jscomp$57$$,$p$jscomp$16$$,$q$jscomp$11$$){var $fexpr__22848$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22848$$.$cljs$core$IFn$_invoke$arity$17$?
$fexpr__22848$$.$cljs$core$IFn$_invoke$arity$17$($a$jscomp$82$$,$b$jscomp$74$$,$c$jscomp$58$$,$d$jscomp$50$$,$e$jscomp$63$$,$f$jscomp$111$$,$g$jscomp$41$$,$h$jscomp$49$$,$i$jscomp$157$$,$j$jscomp$42$$,$k$jscomp$49$$,$l$jscomp$45$$,$m$jscomp$24$$,$n$jscomp$40$$,$o$jscomp$57$$,$p$jscomp$16$$,$q$jscomp$11$$):$fexpr__22848$$($a$jscomp$82$$,$b$jscomp$74$$,$c$jscomp$58$$,$d$jscomp$50$$,$e$jscomp$63$$,$f$jscomp$111$$,$g$jscomp$41$$,$h$jscomp$49$$,$i$jscomp$157$$,$j$jscomp$42$$,$k$jscomp$49$$,$l$jscomp$45$$,
$m$jscomp$24$$,$n$jscomp$40$$,$o$jscomp$57$$,$p$jscomp$16$$,$q$jscomp$11$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$18$=function($a$jscomp$83$$,$b$jscomp$75$$,$c$jscomp$59$$,$d$jscomp$51$$,$e$jscomp$64$$,$f$jscomp$112$$,$g$jscomp$42$$,$h$jscomp$50$$,$i$jscomp$158$$,$j$jscomp$43$$,$k$jscomp$50$$,$l$jscomp$46$$,$m$jscomp$25$$,$n$jscomp$41$$,$o$jscomp$58$$,$p$jscomp$17$$,$q$jscomp$12$$,$r$jscomp$11$$){var $fexpr__22849$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22849$$.$cljs$core$IFn$_invoke$arity$18$?
$fexpr__22849$$.$cljs$core$IFn$_invoke$arity$18$($a$jscomp$83$$,$b$jscomp$75$$,$c$jscomp$59$$,$d$jscomp$51$$,$e$jscomp$64$$,$f$jscomp$112$$,$g$jscomp$42$$,$h$jscomp$50$$,$i$jscomp$158$$,$j$jscomp$43$$,$k$jscomp$50$$,$l$jscomp$46$$,$m$jscomp$25$$,$n$jscomp$41$$,$o$jscomp$58$$,$p$jscomp$17$$,$q$jscomp$12$$,$r$jscomp$11$$):$fexpr__22849$$($a$jscomp$83$$,$b$jscomp$75$$,$c$jscomp$59$$,$d$jscomp$51$$,$e$jscomp$64$$,$f$jscomp$112$$,$g$jscomp$42$$,$h$jscomp$50$$,$i$jscomp$158$$,$j$jscomp$43$$,$k$jscomp$50$$,
$l$jscomp$46$$,$m$jscomp$25$$,$n$jscomp$41$$,$o$jscomp$58$$,$p$jscomp$17$$,$q$jscomp$12$$,$r$jscomp$11$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$19$=function($a$jscomp$84$$,$b$jscomp$76$$,$c$jscomp$60$$,$d$jscomp$52$$,$e$jscomp$65$$,$f$jscomp$113$$,$g$jscomp$43$$,$h$jscomp$51$$,$i$jscomp$159$$,$j$jscomp$44$$,$k$jscomp$51$$,$l$jscomp$47$$,$m$jscomp$26$$,$n$jscomp$42$$,$o$jscomp$59$$,$p$jscomp$18$$,$q$jscomp$13$$,$r$jscomp$12$$,$s$jscomp$33$$){var $fexpr__22850$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22850$$.$cljs$core$IFn$_invoke$arity$19$?
$fexpr__22850$$.$cljs$core$IFn$_invoke$arity$19$($a$jscomp$84$$,$b$jscomp$76$$,$c$jscomp$60$$,$d$jscomp$52$$,$e$jscomp$65$$,$f$jscomp$113$$,$g$jscomp$43$$,$h$jscomp$51$$,$i$jscomp$159$$,$j$jscomp$44$$,$k$jscomp$51$$,$l$jscomp$47$$,$m$jscomp$26$$,$n$jscomp$42$$,$o$jscomp$59$$,$p$jscomp$18$$,$q$jscomp$13$$,$r$jscomp$12$$,$s$jscomp$33$$):$fexpr__22850$$($a$jscomp$84$$,$b$jscomp$76$$,$c$jscomp$60$$,$d$jscomp$52$$,$e$jscomp$65$$,$f$jscomp$113$$,$g$jscomp$43$$,$h$jscomp$51$$,$i$jscomp$159$$,$j$jscomp$44$$,
$k$jscomp$51$$,$l$jscomp$47$$,$m$jscomp$26$$,$n$jscomp$42$$,$o$jscomp$59$$,$p$jscomp$18$$,$q$jscomp$13$$,$r$jscomp$12$$,$s$jscomp$33$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$20$=function($a$jscomp$85$$,$b$jscomp$77$$,$c$jscomp$61$$,$d$jscomp$53$$,$e$jscomp$66$$,$f$jscomp$114$$,$g$jscomp$44$$,$h$jscomp$52$$,$i$jscomp$160$$,$j$jscomp$45$$,$k$jscomp$52$$,$l$jscomp$48$$,$m$jscomp$27$$,$n$jscomp$43$$,$o$jscomp$60$$,$p$jscomp$19$$,$q$jscomp$14$$,$r$jscomp$13$$,$s$jscomp$34$$,$t$jscomp$6$$){var $fexpr__22851$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();return $fexpr__22851$$.$cljs$core$IFn$_invoke$arity$20$?
$fexpr__22851$$.$cljs$core$IFn$_invoke$arity$20$($a$jscomp$85$$,$b$jscomp$77$$,$c$jscomp$61$$,$d$jscomp$53$$,$e$jscomp$66$$,$f$jscomp$114$$,$g$jscomp$44$$,$h$jscomp$52$$,$i$jscomp$160$$,$j$jscomp$45$$,$k$jscomp$52$$,$l$jscomp$48$$,$m$jscomp$27$$,$n$jscomp$43$$,$o$jscomp$60$$,$p$jscomp$19$$,$q$jscomp$14$$,$r$jscomp$13$$,$s$jscomp$34$$,$t$jscomp$6$$):$fexpr__22851$$($a$jscomp$85$$,$b$jscomp$77$$,$c$jscomp$61$$,$d$jscomp$53$$,$e$jscomp$66$$,$f$jscomp$114$$,$g$jscomp$44$$,$h$jscomp$52$$,$i$jscomp$160$$,
$j$jscomp$45$$,$k$jscomp$52$$,$l$jscomp$48$$,$m$jscomp$27$$,$n$jscomp$43$$,$o$jscomp$60$$,$p$jscomp$19$$,$q$jscomp$14$$,$r$jscomp$13$$,$s$jscomp$34$$,$t$jscomp$6$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$21$=function($a$jscomp$86$$,$b$jscomp$78$$,$c$jscomp$62$$,$d$jscomp$54$$,$e$jscomp$67$$,$f$jscomp$115$$,$g$jscomp$45$$,$h$jscomp$53$$,$i$jscomp$161$$,$j$jscomp$46$$,$k$jscomp$53$$,$l$jscomp$49$$,$m$jscomp$28$$,$n$jscomp$44$$,$o$jscomp$61$$,$p$jscomp$20$$,$q$jscomp$15$$,$r$jscomp$14$$,$s$jscomp$35$$,$t$jscomp$7$$,$rest$jscomp$3$$){var $G__22852$$=this.$val$.$cljs$core$IFn$_invoke$arity$0$?this.$val$.$cljs$core$IFn$_invoke$arity$0$():this.$val$();
return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$21$?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$21$($G__22852$$,$a$jscomp$86$$,$b$jscomp$78$$,$c$jscomp$62$$,$d$jscomp$54$$,$e$jscomp$67$$,$f$jscomp$115$$,$g$jscomp$45$$,$h$jscomp$53$$,$i$jscomp$161$$,$j$jscomp$46$$,$k$jscomp$53$$,$l$jscomp$49$$,$m$jscomp$28$$,$n$jscomp$44$$,$o$jscomp$61$$,$p$jscomp$20$$,$q$jscomp$15$$,$r$jscomp$14$$,$s$jscomp$35$$,new $APP.$cljs$core$IndexedSeq$$([$t$jscomp$7$$,$rest$jscomp$3$$],0,null)):$APP.$cljs$core$apply$$($G__22852$$,
$a$jscomp$86$$,$b$jscomp$78$$,$c$jscomp$62$$,$d$jscomp$54$$,$e$jscomp$67$$,$f$jscomp$115$$,$g$jscomp$45$$,$h$jscomp$53$$,$i$jscomp$161$$,$j$jscomp$46$$,$k$jscomp$53$$,$l$jscomp$49$$,$m$jscomp$28$$,$n$jscomp$44$$,$o$jscomp$61$$,$p$jscomp$20$$,$q$jscomp$15$$,$r$jscomp$14$$,$s$jscomp$35$$,$t$jscomp$7$$,$rest$jscomp$3$$)};
$APP.$cljs$core$_EQ_$$=function $cljs$core$_EQ_$$($var_args$jscomp$98$$){switch(arguments.length){case 1:return $cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$7$$=[],$len__5749__auto___24760$$=arguments.length,$i__5750__auto___24761$$=0;;)if($i__5750__auto___24761$$<$len__5749__auto___24760$$)$args_arr__5774__auto__$jscomp$7$$.push(arguments[$i__5750__auto___24761$$]),
$i__5750__auto___24761$$+=1;else break;return $cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$7$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$7$$.slice(2),0,null):null)}};$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$1$=function(){return!0};
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$127$$,$y$jscomp$82$$){return $x$jscomp$127$$==null?$y$jscomp$82$$==null:$x$jscomp$127$$===$y$jscomp$82$$||$cljs$core$_equiv$$($x$jscomp$127$$,$y$jscomp$82$$)};
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__24767_x$jscomp$128$$,$G__24768_y$jscomp$83$$,$G__24769_more$$){for(;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__24767_x$jscomp$128$$,$G__24768_y$jscomp$83$$))if($APP.$cljs$core$next$$($G__24769_more$$)){$G__24767_x$jscomp$128$$=$G__24768_y$jscomp$83$$;$G__24768_y$jscomp$83$$=$APP.$cljs$core$first$$($G__24769_more$$);$G__24769_more$$=$APP.$cljs$core$next$$($G__24769_more$$);continue}else return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__24768_y$jscomp$83$$,
$APP.$cljs$core$first$$($G__24769_more$$));else return!1;break}};
$APP.$cljs$core$_EQ_$$.$cljs$lang$applyTo$=function($G__22884_seq22882$$){var $G__22883$$=$APP.$cljs$core$first$$($G__22884_seq22882$$),$seq22882__$1_seq22882__$2$$=$APP.$cljs$core$next$$($G__22884_seq22882$$);$G__22884_seq22882$$=$APP.$cljs$core$first$$($seq22882__$1_seq22882__$2$$);$seq22882__$1_seq22882__$2$$=$APP.$cljs$core$next$$($seq22882__$1_seq22882__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__22883$$,$G__22884_seq22882$$,$seq22882__$1_seq22882__$2$$)};
$APP.$cljs$core$_EQ_$$.$cljs$lang$maxFixedArity$=2;$cljs$core$ES6Iterator$$.prototype.next=function(){if(this.s!=null){var $x$jscomp$129$$=$APP.$cljs$core$first$$(this.s);this.s=$APP.$cljs$core$next$$(this.s);return{value:$x$jscomp$129$$,done:!1}}return{value:null,done:!0}};$cljs$core$ES6IteratorSeq$$.prototype.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};$cljs$core$ES6IteratorSeq$$.prototype.$cljs$core$ISeq$_first$arity$1$=function(){return this.value};
$cljs$core$ES6IteratorSeq$$.prototype.$cljs$core$ISeq$_rest$arity$1$=function(){this.$_rest$==null&&(this.$_rest$=$cljs$core$es6_iterator_seq$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$core$es6_iterator_seq$$.$cljs$core$IFn$_invoke$arity$1$(this.$iter$):$cljs$core$es6_iterator_seq$$(this.$iter$));return this.$_rest$};var $cljs$core$empty_ordered_hash$$=$APP.$cljs$core$mix_collection_hash$$(1,0),$cljs$core$empty_unordered_hash$$=$APP.$cljs$core$mix_collection_hash$$(0,0);
$cljs$core$ICounted$$["null"]=!0;$APP.$cljs$core$_count$$["null"]=function(){return 0};$APP.$JSCompiler_prototypeAlias$$=Date.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($o$jscomp$62$$,$other$jscomp$49$$){return $other$jscomp$49$$ instanceof Date&&this.valueOf()===$other$jscomp$49$$.valueOf()};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IComparable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IComparable$_compare$arity$2$=function($this$$jscomp$54$$,$other$jscomp$50$$){if($other$jscomp$50$$ instanceof Date)return $module$contents$goog$array_defaultCompare$$(this.valueOf(),$other$jscomp$50$$.valueOf());throw Error(["Cannot compare ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this)," to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$50$$)].join(""));};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$Inst$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$Inst$inst_ms_STAR_$arity$1$=function(){return this.getTime()};$cljs$core$_equiv$$.number=function($x$jscomp$131$$,$o$jscomp$63$$){return $x$jscomp$131$$===$o$jscomp$63$$};$cljs$core$Fn$$["function"]=!0;$APP.$cljs$core$IMeta$$["function"]=!0;$cljs$core$_meta$$["function"]=function(){return null};$APP.$cljs$core$_hash$$._=function($o$jscomp$64$$){return $goog$getUid$$($o$jscomp$64$$)};$APP.$cljs$core$_hash$$.symbol=function($o$jscomp$65$$){return $APP.$cljs$core$hash$$($o$jscomp$65$$.toString())};
$cljs$core$Reduced$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.$val$};$cljs$core$IndexedSeqIterator$$.prototype.hasNext=function(){return this.i<this.$arr$.length};$cljs$core$IndexedSeqIterator$$.prototype.next=function(){var $ret$jscomp$1$$=this.$arr$[this.i];this.i+=1;return $ret$jscomp$1$$};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$IndexedSeq$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$51$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$51$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__24855$$=null;$G__24855$$=function($x$jscomp$144$$,$start$jscomp$22$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$144$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$144$$,$start$jscomp$22$$)}throw Error("Invalid arity: "+arguments.length);};$G__24855$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$142$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$142$$,0)};$G__24855$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$143$$,$start$jscomp$21$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$143$$,$start$jscomp$21$$)};return $G__24855$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__24856__1$$($x$jscomp$145$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$145$$,$APP.$cljs$core$count$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$count$$.$cljs$core$IFn$_invoke$arity$1$(this):$APP.$cljs$core$count$$(this))}var $G__24856$$=null;$G__24856$$=function($x$jscomp$147$$,$start$jscomp$24$$){switch(arguments.length){case 1:return $G__24856__1$$.call(this,$x$jscomp$147$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$147$$,$start$jscomp$24$$)}throw Error("Invalid arity: "+arguments.length);};$G__24856$$.$cljs$core$IFn$_invoke$arity$1$=$G__24856__1$$;$G__24856$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$146$$,$start$jscomp$23$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$146$$,$start$jscomp$23$$)};return $G__24856$$}();
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($coll$jscomp$86_i__$1$$,$n$jscomp$52$$){$coll$jscomp$86_i__$1$$=$n$jscomp$52$$+this.i;if(0<=$coll$jscomp$86_i__$1$$&&$coll$jscomp$86_i__$1$$<this.$arr$.length)return this.$arr$[$coll$jscomp$86_i__$1$$];throw Error("Index out of bounds");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($coll$jscomp$87_i__$1$jscomp$1$$,$n$jscomp$53$$,$not_found$jscomp$7$$){$coll$jscomp$87_i__$1$jscomp$1$$=$n$jscomp$53$$+this.i;return 0<=$coll$jscomp$87_i__$1$jscomp$1$$&&$coll$jscomp$87_i__$1$jscomp$1$$<this.$arr$.length?this.$arr$[$coll$jscomp$87_i__$1$jscomp$1$$]:$not_found$jscomp$7$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $cljs$core$IndexedSeqIterator$$(this.$arr$,this.i)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$cljs$core$IndexedSeq$$(this.$arr$,this.i,this.$meta$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return this.i+1<this.$arr$.length?new $APP.$cljs$core$IndexedSeq$$(this.$arr$,this.i+1,null):null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){var $y__5111__auto__$jscomp$1$$=this.$arr$.length-this.i;return 0>$y__5111__auto__$jscomp$1$$?0:$y__5111__auto__$jscomp$1$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReversible$_rseq$arity$1$=function(){var $c$jscomp$63$$=this.$cljs$core$ICounted$_count$arity$1$(null);return $c$jscomp$63$$>0?new $APP.$cljs$core$RSeq$$(this,$c$jscomp$63$$-1,null):null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$92$$,$other$jscomp$52$$){return $cljs$core$equiv_sequential$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$core$equiv_sequential$$.$cljs$core$IFn$_invoke$arity$2$(this,$other$jscomp$52$$):$cljs$core$equiv_sequential$$(this,$other$jscomp$52$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$94$$,$f$jscomp$121$$){return $cljs$core$array_reduce$cljs$0core$0IFn$0_invoke$0arity$04$$(this.$arr$,$f$jscomp$121$$,this.$arr$[this.i],this.i+1)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$95$$,$f$jscomp$122$$,$start$jscomp$25$$){return $cljs$core$array_reduce$cljs$0core$0IFn$0_invoke$0arity$04$$(this.$arr$,$f$jscomp$122$$,$start$jscomp$25$$,this.i)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return this.$arr$[this.i]};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){return this.i+1<this.$arr$.length?new $APP.$cljs$core$IndexedSeq$$(this.$arr$,this.i+1,null):$APP.$cljs$core$List$EMPTY$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this.i<this.$arr$.length?this:null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$96$$,$new_meta$jscomp$2$$){return $new_meta$jscomp$2$$===this.$meta$?this:new $APP.$cljs$core$IndexedSeq$$(this.$arr$,this.i,$new_meta$jscomp$2$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$97$$,$o$jscomp$68$$){return $APP.$cljs$core$cons$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$cons$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$68$$,this):$APP.$cljs$core$cons$$($o$jscomp$68$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDrop$_drop$arity$2$=function($coll$jscomp$98$$,$n$jscomp$54$$){return $n$jscomp$54$$>0?this.i+$n$jscomp$54$$<this.$arr$.length?new $APP.$cljs$core$IndexedSeq$$(this.$arr$,this.i+$n$jscomp$54$$,null):null:this};$APP.$cljs$core$IndexedSeq$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$RSeq$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$53$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$53$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__24873$$=null;$G__24873$$=function($x$jscomp$150$$,$start$jscomp$27$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$150$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$150$$,$start$jscomp$27$$)}throw Error("Invalid arity: "+arguments.length);};$G__24873$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$148$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$148$$,0)};$G__24873$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$149$$,$start$jscomp$26$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$149$$,$start$jscomp$26$$)};return $G__24873$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__24874__1$$($x$jscomp$151$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$151$$,$APP.$cljs$core$count$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$count$$.$cljs$core$IFn$_invoke$arity$1$(this):$APP.$cljs$core$count$$(this))}var $G__24874$$=null;$G__24874$$=function($x$jscomp$153$$,$start$jscomp$29$$){switch(arguments.length){case 1:return $G__24874__1$$.call(this,$x$jscomp$153$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$153$$,$start$jscomp$29$$)}throw Error("Invalid arity: "+arguments.length);};$G__24874$$.$cljs$core$IFn$_invoke$arity$1$=$G__24874__1$$;$G__24874$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$152$$,$start$jscomp$28$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$152$$,$start$jscomp$28$$)};return $G__24874$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$cljs$core$RSeq$$(this.ci,this.i,this.$meta$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return this.i>0?new $APP.$cljs$core$RSeq$$(this.ci,this.i-1,null):null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.i+1};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$108$$,$other$jscomp$54$$){return $cljs$core$equiv_sequential$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$core$equiv_sequential$$.$cljs$core$IFn$_invoke$arity$2$(this,$other$jscomp$54$$):$cljs$core$equiv_sequential$$(this,$other$jscomp$54$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($col$jscomp$11$$,$f$jscomp$123$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$?$cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$123$$,this):$cljs$core$seq_reduce$$($f$jscomp$123$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($col$jscomp$12$$,$f$jscomp$124$$,$start$jscomp$30$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$?$cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$124$$,$start$jscomp$30$$,this):$cljs$core$seq_reduce$$($f$jscomp$124$$,$start$jscomp$30$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return $APP.$cljs$core$_nth$$(this.ci,this.i)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){return this.i>0?new $APP.$cljs$core$RSeq$$(this.ci,this.i-1,null):$APP.$cljs$core$List$EMPTY$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$113$$,$new_meta$jscomp$3$$){return $new_meta$jscomp$3$$===this.$meta$?this:new $APP.$cljs$core$RSeq$$(this.ci,this.i,$new_meta$jscomp$3$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$114$$,$o$jscomp$69$$){return $APP.$cljs$core$cons$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$cons$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$69$$,this):$APP.$cljs$core$cons$$($o$jscomp$69$$,this)};$APP.$cljs$core$RSeq$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
$cljs$core$_equiv$$._=function($x$jscomp$154$$,$o$jscomp$70$$){return $x$jscomp$154$$===$o$jscomp$70$$};
$APP.$cljs$core$conj$$=function $cljs$core$conj$$($var_args$jscomp$105$$){switch(arguments.length){case 0:return $cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$8$$=[],$len__5749__auto___24883$$=arguments.length,$i__5750__auto___24885$$=0;;)if($i__5750__auto___24885$$<$len__5749__auto___24883$$)$args_arr__5774__auto__$jscomp$8$$.push(arguments[$i__5750__auto___24885$$]),
$i__5750__auto___24885$$+=1;else break;return $cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$8$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$8$$.slice(2),0,null):null)}};$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$cljs$core$PersistentVector$EMPTY$$};$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$1$=function($coll$jscomp$120$$){return $coll$jscomp$120$$};
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$=function($coll$jscomp$121$$,$x$jscomp$155$$){return $coll$jscomp$121$$!=null?$APP.$cljs$core$_conj$$($coll$jscomp$121$$,$x$jscomp$155$$):new $APP.$cljs$core$List$$(null,$x$jscomp$155$$,null,1,null)};
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__24888_coll$jscomp$122$$,$G__24889_x$jscomp$156$$,$G__24890_xs$jscomp$5$$){for(;;)if($APP.$cljs$core$truth_$$($G__24890_xs$jscomp$5$$))$G__24888_coll$jscomp$122$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__24888_coll$jscomp$122$$,$G__24889_x$jscomp$156$$),$G__24889_x$jscomp$156$$=$APP.$cljs$core$first$$($G__24890_xs$jscomp$5$$),$G__24890_xs$jscomp$5$$=$APP.$cljs$core$next$$($G__24890_xs$jscomp$5$$);else return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__24888_coll$jscomp$122$$,
$G__24889_x$jscomp$156$$)};$APP.$cljs$core$conj$$.$cljs$lang$applyTo$=function($G__22914_seq22912$$){var $G__22913$$=$APP.$cljs$core$first$$($G__22914_seq22912$$),$seq22912__$1_seq22912__$2$$=$APP.$cljs$core$next$$($G__22914_seq22912$$);$G__22914_seq22912$$=$APP.$cljs$core$first$$($seq22912__$1_seq22912__$2$$);$seq22912__$1_seq22912__$2$$=$APP.$cljs$core$next$$($seq22912__$1_seq22912__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__22913$$,$G__22914_seq22912$$,$seq22912__$1_seq22912__$2$$)};
$APP.$cljs$core$conj$$.$cljs$lang$maxFixedArity$=2;$APP.$cljs$core$get$$=function $cljs$core$get$$($var_args$jscomp$108$$){switch(arguments.length){case 2:return $cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$=function($o$jscomp$71$$,$k$jscomp$54$$){return $o$jscomp$71$$==null?null:$o$jscomp$71$$!=null&&($o$jscomp$71$$.$cljs$lang$protocol_mask$partition0$$&256||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$o$jscomp$71$$.$cljs$core$ILookup$$)?$o$jscomp$71$$.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$54$$):$APP.$cljs$core$array_QMARK_$$($o$jscomp$71$$)?$k$jscomp$54$$!=null&&$k$jscomp$54$$<$o$jscomp$71$$.length?$o$jscomp$71$$[$k$jscomp$54$$|0]:null:typeof $o$jscomp$71$$===
"string"?$k$jscomp$54$$!=null&&-1<$k$jscomp$54$$&&$k$jscomp$54$$<$o$jscomp$71$$.length?$o$jscomp$71$$.charAt($k$jscomp$54$$|0):null:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ILookup$$,$o$jscomp$71$$)?$APP.$cljs$core$_lookup$$($o$jscomp$71$$,$k$jscomp$54$$):null};
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$=function($o$jscomp$72$$,$k$jscomp$55$$,$not_found$jscomp$10$$){return $o$jscomp$72$$!=null?$o$jscomp$72$$!=null&&($o$jscomp$72$$.$cljs$lang$protocol_mask$partition0$$&256||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$o$jscomp$72$$.$cljs$core$ILookup$$)?$o$jscomp$72$$.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$55$$,$not_found$jscomp$10$$):$APP.$cljs$core$array_QMARK_$$($o$jscomp$72$$)?$k$jscomp$55$$!=null&&-1<$k$jscomp$55$$&&$k$jscomp$55$$<$o$jscomp$72$$.length?
$o$jscomp$72$$[$k$jscomp$55$$|0]:$not_found$jscomp$10$$:typeof $o$jscomp$72$$==="string"?$k$jscomp$55$$!=null&&-1<$k$jscomp$55$$&&$k$jscomp$55$$<$o$jscomp$72$$.length?$o$jscomp$72$$.charAt($k$jscomp$55$$|0):$not_found$jscomp$10$$:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ILookup$$,$o$jscomp$72$$)?$APP.$cljs$core$_lookup$$($o$jscomp$72$$,$k$jscomp$55$$,$not_found$jscomp$10$$):$not_found$jscomp$10$$:$not_found$jscomp$10$$};$APP.$cljs$core$get$$.$cljs$lang$maxFixedArity$=3;
$APP.$cljs$core$assoc$$=function $cljs$core$assoc$$($var_args$jscomp$109$$){switch(arguments.length){case 3:return $cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:for(var $args_arr__5774__auto__$jscomp$9$$=[],$len__5749__auto___24914$$=arguments.length,$i__5750__auto___24915$$=0;;)if($i__5750__auto___24915$$<$len__5749__auto___24914$$)$args_arr__5774__auto__$jscomp$9$$.push(arguments[$i__5750__auto___24915$$]),$i__5750__auto___24915$$+=1;else break;
return $cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],3<$args_arr__5774__auto__$jscomp$9$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$9$$.slice(3),0,null):null)}};
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$=function($coll$jscomp$131$$,$k$jscomp$56$$,$v$jscomp$10$$){return $coll$jscomp$131$$!=null&&($coll$jscomp$131$$.$cljs$lang$protocol_mask$partition0$$&512||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$coll$jscomp$131$$.$cljs$core$IAssociative$$)?$coll$jscomp$131$$.$cljs$core$IAssociative$_assoc$arity$3$(null,$k$jscomp$56$$,$v$jscomp$10$$):$coll$jscomp$131$$!=null?$APP.$cljs$core$_assoc$$($coll$jscomp$131$$,$k$jscomp$56$$,$v$jscomp$10$$):$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$k$jscomp$56$$,
$v$jscomp$10$$])};
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__24920_coll$jscomp$132_ret$jscomp$2$$,$G__24921_k$jscomp$57$$,$G__24922_v$jscomp$11$$,$G__24923_kvs$$){for(;;)if($G__24920_coll$jscomp$132_ret$jscomp$2$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__24920_coll$jscomp$132_ret$jscomp$2$$,$G__24921_k$jscomp$57$$,$G__24922_v$jscomp$11$$),$APP.$cljs$core$truth_$$($G__24923_kvs$$))$G__24921_k$jscomp$57$$=$APP.$cljs$core$first$$($G__24923_kvs$$),$G__24922_v$jscomp$11$$=$APP.$cljs$core$second$$($G__24923_kvs$$),
$G__24923_kvs$$=$APP.$cljs$core$next$$($APP.$cljs$core$next$$($G__24923_kvs$$));else return $G__24920_coll$jscomp$132_ret$jscomp$2$$};
$APP.$cljs$core$assoc$$.$cljs$lang$applyTo$=function($G__22938_seq22936$$){var $G__22937$$=$APP.$cljs$core$first$$($G__22938_seq22936$$),$G__22939_seq22936__$1$$=$APP.$cljs$core$next$$($G__22938_seq22936$$);$G__22938_seq22936$$=$APP.$cljs$core$first$$($G__22939_seq22936__$1$$);var $seq22936__$2_seq22936__$3$$=$APP.$cljs$core$next$$($G__22939_seq22936__$1$$);$G__22939_seq22936__$1$$=$APP.$cljs$core$first$$($seq22936__$2_seq22936__$3$$);$seq22936__$2_seq22936__$3$$=$APP.$cljs$core$next$$($seq22936__$2_seq22936__$3$$);
return this.$cljs$core$IFn$_invoke$arity$variadic$($G__22937$$,$G__22938_seq22936$$,$G__22939_seq22936__$1$$,$seq22936__$2_seq22936__$3$$)};$APP.$cljs$core$assoc$$.$cljs$lang$maxFixedArity$=3;
$APP.$cljs$core$dissoc$$=function $cljs$core$dissoc$$($var_args$jscomp$110$$){switch(arguments.length){case 1:return $cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$10$$=[],$len__5749__auto___24925$$=arguments.length,$i__5750__auto___24926$$=0;;)if($i__5750__auto___24926$$<$len__5749__auto___24925$$)$args_arr__5774__auto__$jscomp$10$$.push(arguments[$i__5750__auto___24926$$]),
$i__5750__auto___24926$$+=1;else break;return $cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$10$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$10$$.slice(2),0,null):null)}};$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$1$=function($coll$jscomp$133$$){return $coll$jscomp$133$$};
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$=function($coll$jscomp$134$$,$k$jscomp$58$$){return $coll$jscomp$134$$==null?null:$APP.$cljs$core$_dissoc$$($coll$jscomp$134$$,$k$jscomp$58$$)};
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__24929_coll$jscomp$135_ret$jscomp$3$$,$G__24930_k$jscomp$59$$,$G__24931_ks$$){for(;;){if($G__24929_coll$jscomp$135_ret$jscomp$3$$==null)return null;$G__24929_coll$jscomp$135_ret$jscomp$3$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__24929_coll$jscomp$135_ret$jscomp$3$$,$G__24930_k$jscomp$59$$);if($APP.$cljs$core$truth_$$($G__24931_ks$$))$G__24930_k$jscomp$59$$=$APP.$cljs$core$first$$($G__24931_ks$$),$G__24931_ks$$=
$APP.$cljs$core$next$$($G__24931_ks$$);else return $G__24929_coll$jscomp$135_ret$jscomp$3$$}};
$APP.$cljs$core$dissoc$$.$cljs$lang$applyTo$=function($G__22945_seq22943$$){var $G__22944$$=$APP.$cljs$core$first$$($G__22945_seq22943$$),$seq22943__$1_seq22943__$2$$=$APP.$cljs$core$next$$($G__22945_seq22943$$);$G__22945_seq22943$$=$APP.$cljs$core$first$$($seq22943__$1_seq22943__$2$$);$seq22943__$1_seq22943__$2$$=$APP.$cljs$core$next$$($seq22943__$1_seq22943__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__22944$$,$G__22945_seq22943$$,$seq22943__$1_seq22943__$2$$)};
$APP.$cljs$core$dissoc$$.$cljs$lang$maxFixedArity$=2;$APP.$JSCompiler_prototypeAlias$$=$cljs$core$MetaFn$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_$jscomp$51$$,$new_meta$jscomp$4$$){return new $cljs$core$MetaFn$$(this.$afn$,$new_meta$jscomp$4$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$Fn$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$2$$){switch(arguments.length-1){case 0:return this.$cljs$core$IFn$_invoke$arity$0$();case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);case 3:return this.$cljs$core$IFn$_invoke$arity$3$(arguments[1],arguments[2],arguments[3]);case 4:return this.$cljs$core$IFn$_invoke$arity$4$(arguments[1],arguments[2],arguments[3],arguments[4]);
case 5:return this.$cljs$core$IFn$_invoke$arity$5$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5]);case 6:return this.$cljs$core$IFn$_invoke$arity$6$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6]);case 7:return this.$cljs$core$IFn$_invoke$arity$7$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7]);case 8:return this.$cljs$core$IFn$_invoke$arity$8$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],
arguments[6],arguments[7],arguments[8]);case 9:return this.$cljs$core$IFn$_invoke$arity$9$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9]);case 10:return this.$cljs$core$IFn$_invoke$arity$10$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10]);case 11:return this.$cljs$core$IFn$_invoke$arity$11$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],
arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11]);case 12:return this.$cljs$core$IFn$_invoke$arity$12$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12]);case 13:return this.$cljs$core$IFn$_invoke$arity$13$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],
arguments[13]);case 14:return this.$cljs$core$IFn$_invoke$arity$14$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14]);case 15:return this.$cljs$core$IFn$_invoke$arity$15$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15]);
case 16:return this.$cljs$core$IFn$_invoke$arity$16$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16]);case 17:return this.$cljs$core$IFn$_invoke$arity$17$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],
arguments[15],arguments[16],arguments[17]);case 18:return this.$cljs$core$IFn$_invoke$arity$18$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18]);case 19:return this.$cljs$core$IFn$_invoke$arity$19$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],
arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19]);case 20:return this.$cljs$core$IFn$_invoke$arity$20$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19],arguments[20]);case 21:return this.$cljs$core$IFn$_invoke$arity$21$(arguments[1],
arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19],arguments[20],arguments[21]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};
$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$101$$,$args22948$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args22948$$)))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$0$=function(){return this.$afn$.$cljs$core$IFn$_invoke$arity$0$?this.$afn$.$cljs$core$IFn$_invoke$arity$0$():this.$afn$()};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($a$jscomp$87$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$1$?this.$afn$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$87$$):this.$afn$($a$jscomp$87$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($a$jscomp$88$$,$b$jscomp$79$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$2$?this.$afn$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$88$$,$b$jscomp$79$$):this.$afn$($a$jscomp$88$$,$b$jscomp$79$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$3$=function($a$jscomp$89$$,$b$jscomp$80$$,$c$jscomp$64$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$3$?this.$afn$.$cljs$core$IFn$_invoke$arity$3$($a$jscomp$89$$,$b$jscomp$80$$,$c$jscomp$64$$):this.$afn$($a$jscomp$89$$,$b$jscomp$80$$,$c$jscomp$64$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$4$=function($a$jscomp$90$$,$b$jscomp$81$$,$c$jscomp$65$$,$d$jscomp$55$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$4$?this.$afn$.$cljs$core$IFn$_invoke$arity$4$($a$jscomp$90$$,$b$jscomp$81$$,$c$jscomp$65$$,$d$jscomp$55$$):this.$afn$($a$jscomp$90$$,$b$jscomp$81$$,$c$jscomp$65$$,$d$jscomp$55$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$5$=function($a$jscomp$91$$,$b$jscomp$82$$,$c$jscomp$66$$,$d$jscomp$56$$,$e$jscomp$68$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$5$?this.$afn$.$cljs$core$IFn$_invoke$arity$5$($a$jscomp$91$$,$b$jscomp$82$$,$c$jscomp$66$$,$d$jscomp$56$$,$e$jscomp$68$$):this.$afn$($a$jscomp$91$$,$b$jscomp$82$$,$c$jscomp$66$$,$d$jscomp$56$$,$e$jscomp$68$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$6$=function($a$jscomp$92$$,$b$jscomp$83$$,$c$jscomp$67$$,$d$jscomp$57$$,$e$jscomp$69$$,$f$jscomp$126$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$6$?this.$afn$.$cljs$core$IFn$_invoke$arity$6$($a$jscomp$92$$,$b$jscomp$83$$,$c$jscomp$67$$,$d$jscomp$57$$,$e$jscomp$69$$,$f$jscomp$126$$):this.$afn$($a$jscomp$92$$,$b$jscomp$83$$,$c$jscomp$67$$,$d$jscomp$57$$,$e$jscomp$69$$,$f$jscomp$126$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$7$=function($a$jscomp$93$$,$b$jscomp$84$$,$c$jscomp$68$$,$d$jscomp$58$$,$e$jscomp$70$$,$f$jscomp$127$$,$g$jscomp$46$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$7$?this.$afn$.$cljs$core$IFn$_invoke$arity$7$($a$jscomp$93$$,$b$jscomp$84$$,$c$jscomp$68$$,$d$jscomp$58$$,$e$jscomp$70$$,$f$jscomp$127$$,$g$jscomp$46$$):this.$afn$($a$jscomp$93$$,$b$jscomp$84$$,$c$jscomp$68$$,$d$jscomp$58$$,$e$jscomp$70$$,$f$jscomp$127$$,$g$jscomp$46$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$8$=function($a$jscomp$94$$,$b$jscomp$85$$,$c$jscomp$69$$,$d$jscomp$59$$,$e$jscomp$71$$,$f$jscomp$128$$,$g$jscomp$47$$,$h$jscomp$54$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$8$?this.$afn$.$cljs$core$IFn$_invoke$arity$8$($a$jscomp$94$$,$b$jscomp$85$$,$c$jscomp$69$$,$d$jscomp$59$$,$e$jscomp$71$$,$f$jscomp$128$$,$g$jscomp$47$$,$h$jscomp$54$$):this.$afn$($a$jscomp$94$$,$b$jscomp$85$$,$c$jscomp$69$$,$d$jscomp$59$$,$e$jscomp$71$$,$f$jscomp$128$$,
$g$jscomp$47$$,$h$jscomp$54$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$9$=function($a$jscomp$95$$,$b$jscomp$86$$,$c$jscomp$70$$,$d$jscomp$60$$,$e$jscomp$72$$,$f$jscomp$129$$,$g$jscomp$48$$,$h$jscomp$55$$,$i$jscomp$170$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$9$?this.$afn$.$cljs$core$IFn$_invoke$arity$9$($a$jscomp$95$$,$b$jscomp$86$$,$c$jscomp$70$$,$d$jscomp$60$$,$e$jscomp$72$$,$f$jscomp$129$$,$g$jscomp$48$$,$h$jscomp$55$$,$i$jscomp$170$$):this.$afn$($a$jscomp$95$$,$b$jscomp$86$$,$c$jscomp$70$$,$d$jscomp$60$$,
$e$jscomp$72$$,$f$jscomp$129$$,$g$jscomp$48$$,$h$jscomp$55$$,$i$jscomp$170$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$10$=function($a$jscomp$96$$,$b$jscomp$87$$,$c$jscomp$71$$,$d$jscomp$61$$,$e$jscomp$73$$,$f$jscomp$130$$,$g$jscomp$49$$,$h$jscomp$56$$,$i$jscomp$171$$,$j$jscomp$47$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$10$?this.$afn$.$cljs$core$IFn$_invoke$arity$10$($a$jscomp$96$$,$b$jscomp$87$$,$c$jscomp$71$$,$d$jscomp$61$$,$e$jscomp$73$$,$f$jscomp$130$$,$g$jscomp$49$$,$h$jscomp$56$$,$i$jscomp$171$$,$j$jscomp$47$$):this.$afn$($a$jscomp$96$$,
$b$jscomp$87$$,$c$jscomp$71$$,$d$jscomp$61$$,$e$jscomp$73$$,$f$jscomp$130$$,$g$jscomp$49$$,$h$jscomp$56$$,$i$jscomp$171$$,$j$jscomp$47$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$11$=function($a$jscomp$97$$,$b$jscomp$88$$,$c$jscomp$72$$,$d$jscomp$62$$,$e$jscomp$74$$,$f$jscomp$131$$,$g$jscomp$50$$,$h$jscomp$57$$,$i$jscomp$172$$,$j$jscomp$48$$,$k$jscomp$60$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$11$?this.$afn$.$cljs$core$IFn$_invoke$arity$11$($a$jscomp$97$$,$b$jscomp$88$$,$c$jscomp$72$$,$d$jscomp$62$$,$e$jscomp$74$$,$f$jscomp$131$$,$g$jscomp$50$$,$h$jscomp$57$$,$i$jscomp$172$$,$j$jscomp$48$$,$k$jscomp$60$$):
this.$afn$($a$jscomp$97$$,$b$jscomp$88$$,$c$jscomp$72$$,$d$jscomp$62$$,$e$jscomp$74$$,$f$jscomp$131$$,$g$jscomp$50$$,$h$jscomp$57$$,$i$jscomp$172$$,$j$jscomp$48$$,$k$jscomp$60$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$12$=function($a$jscomp$98$$,$b$jscomp$89$$,$c$jscomp$73$$,$d$jscomp$63$$,$e$jscomp$75$$,$f$jscomp$132$$,$g$jscomp$51$$,$h$jscomp$58$$,$i$jscomp$173$$,$j$jscomp$49$$,$k$jscomp$61$$,$l$jscomp$50$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$12$?this.$afn$.$cljs$core$IFn$_invoke$arity$12$($a$jscomp$98$$,$b$jscomp$89$$,$c$jscomp$73$$,$d$jscomp$63$$,$e$jscomp$75$$,$f$jscomp$132$$,$g$jscomp$51$$,$h$jscomp$58$$,$i$jscomp$173$$,$j$jscomp$49$$,
$k$jscomp$61$$,$l$jscomp$50$$):this.$afn$($a$jscomp$98$$,$b$jscomp$89$$,$c$jscomp$73$$,$d$jscomp$63$$,$e$jscomp$75$$,$f$jscomp$132$$,$g$jscomp$51$$,$h$jscomp$58$$,$i$jscomp$173$$,$j$jscomp$49$$,$k$jscomp$61$$,$l$jscomp$50$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$13$=function($a$jscomp$99$$,$b$jscomp$90$$,$c$jscomp$74$$,$d$jscomp$64$$,$e$jscomp$76$$,$f$jscomp$133$$,$g$jscomp$52$$,$h$jscomp$59$$,$i$jscomp$174$$,$j$jscomp$50$$,$k$jscomp$62$$,$l$jscomp$51$$,$m$jscomp$29$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$13$?this.$afn$.$cljs$core$IFn$_invoke$arity$13$($a$jscomp$99$$,$b$jscomp$90$$,$c$jscomp$74$$,$d$jscomp$64$$,$e$jscomp$76$$,$f$jscomp$133$$,$g$jscomp$52$$,$h$jscomp$59$$,$i$jscomp$174$$,
$j$jscomp$50$$,$k$jscomp$62$$,$l$jscomp$51$$,$m$jscomp$29$$):this.$afn$($a$jscomp$99$$,$b$jscomp$90$$,$c$jscomp$74$$,$d$jscomp$64$$,$e$jscomp$76$$,$f$jscomp$133$$,$g$jscomp$52$$,$h$jscomp$59$$,$i$jscomp$174$$,$j$jscomp$50$$,$k$jscomp$62$$,$l$jscomp$51$$,$m$jscomp$29$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$14$=function($a$jscomp$100$$,$b$jscomp$91$$,$c$jscomp$75$$,$d$jscomp$65$$,$e$jscomp$77$$,$f$jscomp$134$$,$g$jscomp$53$$,$h$jscomp$60$$,$i$jscomp$175$$,$j$jscomp$51$$,$k$jscomp$63$$,$l$jscomp$52$$,$m$jscomp$30$$,$n$jscomp$60$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$14$?this.$afn$.$cljs$core$IFn$_invoke$arity$14$($a$jscomp$100$$,$b$jscomp$91$$,$c$jscomp$75$$,$d$jscomp$65$$,$e$jscomp$77$$,$f$jscomp$134$$,$g$jscomp$53$$,$h$jscomp$60$$,
$i$jscomp$175$$,$j$jscomp$51$$,$k$jscomp$63$$,$l$jscomp$52$$,$m$jscomp$30$$,$n$jscomp$60$$):this.$afn$($a$jscomp$100$$,$b$jscomp$91$$,$c$jscomp$75$$,$d$jscomp$65$$,$e$jscomp$77$$,$f$jscomp$134$$,$g$jscomp$53$$,$h$jscomp$60$$,$i$jscomp$175$$,$j$jscomp$51$$,$k$jscomp$63$$,$l$jscomp$52$$,$m$jscomp$30$$,$n$jscomp$60$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$15$=function($a$jscomp$101$$,$b$jscomp$92$$,$c$jscomp$76$$,$d$jscomp$66$$,$e$jscomp$78$$,$f$jscomp$135$$,$g$jscomp$54$$,$h$jscomp$61$$,$i$jscomp$176$$,$j$jscomp$52$$,$k$jscomp$64$$,$l$jscomp$53$$,$m$jscomp$31$$,$n$jscomp$61$$,$o$jscomp$73$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$15$?this.$afn$.$cljs$core$IFn$_invoke$arity$15$($a$jscomp$101$$,$b$jscomp$92$$,$c$jscomp$76$$,$d$jscomp$66$$,$e$jscomp$78$$,$f$jscomp$135$$,$g$jscomp$54$$,
$h$jscomp$61$$,$i$jscomp$176$$,$j$jscomp$52$$,$k$jscomp$64$$,$l$jscomp$53$$,$m$jscomp$31$$,$n$jscomp$61$$,$o$jscomp$73$$):this.$afn$($a$jscomp$101$$,$b$jscomp$92$$,$c$jscomp$76$$,$d$jscomp$66$$,$e$jscomp$78$$,$f$jscomp$135$$,$g$jscomp$54$$,$h$jscomp$61$$,$i$jscomp$176$$,$j$jscomp$52$$,$k$jscomp$64$$,$l$jscomp$53$$,$m$jscomp$31$$,$n$jscomp$61$$,$o$jscomp$73$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$16$=function($a$jscomp$102$$,$b$jscomp$93$$,$c$jscomp$77$$,$d$jscomp$67$$,$e$jscomp$79$$,$f$jscomp$136$$,$g$jscomp$55$$,$h$jscomp$62$$,$i$jscomp$177$$,$j$jscomp$53$$,$k$jscomp$65$$,$l$jscomp$54$$,$m$jscomp$32$$,$n$jscomp$62$$,$o$jscomp$74$$,$p$jscomp$21$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$16$?this.$afn$.$cljs$core$IFn$_invoke$arity$16$($a$jscomp$102$$,$b$jscomp$93$$,$c$jscomp$77$$,$d$jscomp$67$$,$e$jscomp$79$$,$f$jscomp$136$$,
$g$jscomp$55$$,$h$jscomp$62$$,$i$jscomp$177$$,$j$jscomp$53$$,$k$jscomp$65$$,$l$jscomp$54$$,$m$jscomp$32$$,$n$jscomp$62$$,$o$jscomp$74$$,$p$jscomp$21$$):this.$afn$($a$jscomp$102$$,$b$jscomp$93$$,$c$jscomp$77$$,$d$jscomp$67$$,$e$jscomp$79$$,$f$jscomp$136$$,$g$jscomp$55$$,$h$jscomp$62$$,$i$jscomp$177$$,$j$jscomp$53$$,$k$jscomp$65$$,$l$jscomp$54$$,$m$jscomp$32$$,$n$jscomp$62$$,$o$jscomp$74$$,$p$jscomp$21$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$17$=function($a$jscomp$103$$,$b$jscomp$94$$,$c$jscomp$78$$,$d$jscomp$68$$,$e$jscomp$80$$,$f$jscomp$137$$,$g$jscomp$56$$,$h$jscomp$63$$,$i$jscomp$178$$,$j$jscomp$54$$,$k$jscomp$66$$,$l$jscomp$55$$,$m$jscomp$33$$,$n$jscomp$63$$,$o$jscomp$75$$,$p$jscomp$22$$,$q$jscomp$16$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$17$?this.$afn$.$cljs$core$IFn$_invoke$arity$17$($a$jscomp$103$$,$b$jscomp$94$$,$c$jscomp$78$$,$d$jscomp$68$$,$e$jscomp$80$$,
$f$jscomp$137$$,$g$jscomp$56$$,$h$jscomp$63$$,$i$jscomp$178$$,$j$jscomp$54$$,$k$jscomp$66$$,$l$jscomp$55$$,$m$jscomp$33$$,$n$jscomp$63$$,$o$jscomp$75$$,$p$jscomp$22$$,$q$jscomp$16$$):this.$afn$($a$jscomp$103$$,$b$jscomp$94$$,$c$jscomp$78$$,$d$jscomp$68$$,$e$jscomp$80$$,$f$jscomp$137$$,$g$jscomp$56$$,$h$jscomp$63$$,$i$jscomp$178$$,$j$jscomp$54$$,$k$jscomp$66$$,$l$jscomp$55$$,$m$jscomp$33$$,$n$jscomp$63$$,$o$jscomp$75$$,$p$jscomp$22$$,$q$jscomp$16$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$18$=function($a$jscomp$104$$,$b$jscomp$95$$,$c$jscomp$79$$,$d$jscomp$69$$,$e$jscomp$81$$,$f$jscomp$138$$,$g$jscomp$57$$,$h$jscomp$64$$,$i$jscomp$179$$,$j$jscomp$55$$,$k$jscomp$67$$,$l$jscomp$56$$,$m$jscomp$34$$,$n$jscomp$64$$,$o$jscomp$76$$,$p$jscomp$23$$,$q$jscomp$17$$,$r$jscomp$16$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$18$?this.$afn$.$cljs$core$IFn$_invoke$arity$18$($a$jscomp$104$$,$b$jscomp$95$$,$c$jscomp$79$$,$d$jscomp$69$$,
$e$jscomp$81$$,$f$jscomp$138$$,$g$jscomp$57$$,$h$jscomp$64$$,$i$jscomp$179$$,$j$jscomp$55$$,$k$jscomp$67$$,$l$jscomp$56$$,$m$jscomp$34$$,$n$jscomp$64$$,$o$jscomp$76$$,$p$jscomp$23$$,$q$jscomp$17$$,$r$jscomp$16$$):this.$afn$($a$jscomp$104$$,$b$jscomp$95$$,$c$jscomp$79$$,$d$jscomp$69$$,$e$jscomp$81$$,$f$jscomp$138$$,$g$jscomp$57$$,$h$jscomp$64$$,$i$jscomp$179$$,$j$jscomp$55$$,$k$jscomp$67$$,$l$jscomp$56$$,$m$jscomp$34$$,$n$jscomp$64$$,$o$jscomp$76$$,$p$jscomp$23$$,$q$jscomp$17$$,$r$jscomp$16$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$19$=function($a$jscomp$105$$,$b$jscomp$96$$,$c$jscomp$80$$,$d$jscomp$70$$,$e$jscomp$82$$,$f$jscomp$139$$,$g$jscomp$58$$,$h$jscomp$65$$,$i$jscomp$180$$,$j$jscomp$56$$,$k$jscomp$68$$,$l$jscomp$57$$,$m$jscomp$35$$,$n$jscomp$65$$,$o$jscomp$77$$,$p$jscomp$24$$,$q$jscomp$18$$,$r$jscomp$17$$,$s$jscomp$42$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$19$?this.$afn$.$cljs$core$IFn$_invoke$arity$19$($a$jscomp$105$$,$b$jscomp$96$$,$c$jscomp$80$$,
$d$jscomp$70$$,$e$jscomp$82$$,$f$jscomp$139$$,$g$jscomp$58$$,$h$jscomp$65$$,$i$jscomp$180$$,$j$jscomp$56$$,$k$jscomp$68$$,$l$jscomp$57$$,$m$jscomp$35$$,$n$jscomp$65$$,$o$jscomp$77$$,$p$jscomp$24$$,$q$jscomp$18$$,$r$jscomp$17$$,$s$jscomp$42$$):this.$afn$($a$jscomp$105$$,$b$jscomp$96$$,$c$jscomp$80$$,$d$jscomp$70$$,$e$jscomp$82$$,$f$jscomp$139$$,$g$jscomp$58$$,$h$jscomp$65$$,$i$jscomp$180$$,$j$jscomp$56$$,$k$jscomp$68$$,$l$jscomp$57$$,$m$jscomp$35$$,$n$jscomp$65$$,$o$jscomp$77$$,$p$jscomp$24$$,$q$jscomp$18$$,
$r$jscomp$17$$,$s$jscomp$42$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$20$=function($a$jscomp$106$$,$b$jscomp$97$$,$c$jscomp$81$$,$d$jscomp$71$$,$e$jscomp$83$$,$f$jscomp$140$$,$g$jscomp$59$$,$h$jscomp$66$$,$i$jscomp$181$$,$j$jscomp$57$$,$k$jscomp$69$$,$l$jscomp$58$$,$m$jscomp$36$$,$n$jscomp$66$$,$o$jscomp$78$$,$p$jscomp$25$$,$q$jscomp$19$$,$r$jscomp$18$$,$s$jscomp$43$$,$t$jscomp$8$$){return this.$afn$.$cljs$core$IFn$_invoke$arity$20$?this.$afn$.$cljs$core$IFn$_invoke$arity$20$($a$jscomp$106$$,$b$jscomp$97$$,
$c$jscomp$81$$,$d$jscomp$71$$,$e$jscomp$83$$,$f$jscomp$140$$,$g$jscomp$59$$,$h$jscomp$66$$,$i$jscomp$181$$,$j$jscomp$57$$,$k$jscomp$69$$,$l$jscomp$58$$,$m$jscomp$36$$,$n$jscomp$66$$,$o$jscomp$78$$,$p$jscomp$25$$,$q$jscomp$19$$,$r$jscomp$18$$,$s$jscomp$43$$,$t$jscomp$8$$):this.$afn$($a$jscomp$106$$,$b$jscomp$97$$,$c$jscomp$81$$,$d$jscomp$71$$,$e$jscomp$83$$,$f$jscomp$140$$,$g$jscomp$59$$,$h$jscomp$66$$,$i$jscomp$181$$,$j$jscomp$57$$,$k$jscomp$69$$,$l$jscomp$58$$,$m$jscomp$36$$,$n$jscomp$66$$,$o$jscomp$78$$,
$p$jscomp$25$$,$q$jscomp$19$$,$r$jscomp$18$$,$s$jscomp$43$$,$t$jscomp$8$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$21$=function($a$jscomp$107$$,$b$jscomp$98$$,$c$jscomp$82$$,$d$jscomp$72$$,$e$jscomp$84$$,$f$jscomp$141$$,$g$jscomp$60$$,$h$jscomp$67$$,$i$jscomp$182$$,$j$jscomp$58$$,$k$jscomp$70$$,$l$jscomp$59$$,$m$jscomp$37$$,$n$jscomp$67$$,$o$jscomp$79$$,$p$jscomp$26$$,$q$jscomp$20$$,$r$jscomp$19$$,$s$jscomp$44$$,$t$jscomp$9$$,$rest$jscomp$4$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$21$?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$21$(this.$afn$,
$a$jscomp$107$$,$b$jscomp$98$$,$c$jscomp$82$$,$d$jscomp$72$$,$e$jscomp$84$$,$f$jscomp$141$$,$g$jscomp$60$$,$h$jscomp$67$$,$i$jscomp$182$$,$j$jscomp$58$$,$k$jscomp$70$$,$l$jscomp$59$$,$m$jscomp$37$$,$n$jscomp$67$$,$o$jscomp$79$$,$p$jscomp$26$$,$q$jscomp$20$$,$r$jscomp$19$$,$s$jscomp$44$$,new $APP.$cljs$core$IndexedSeq$$([$t$jscomp$9$$,$rest$jscomp$4$$],0,null)):$APP.$cljs$core$apply$$(this.$afn$,$a$jscomp$107$$,$b$jscomp$98$$,$c$jscomp$82$$,$d$jscomp$72$$,$e$jscomp$84$$,$f$jscomp$141$$,$g$jscomp$60$$,
$h$jscomp$67$$,$i$jscomp$182$$,$j$jscomp$58$$,$k$jscomp$70$$,$l$jscomp$59$$,$m$jscomp$37$$,$n$jscomp$67$$,$o$jscomp$79$$,$p$jscomp$26$$,$q$jscomp$20$$,$r$jscomp$19$$,$s$jscomp$44$$,$t$jscomp$9$$,$rest$jscomp$4$$)};
$APP.$cljs$core$disj$$=function $cljs$core$disj$$($var_args$jscomp$111$$){switch(arguments.length){case 1:return $cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$11$$=[],$len__5749__auto___24984$$=arguments.length,$i__5750__auto___24985$$=0;;)if($i__5750__auto___24985$$<$len__5749__auto___24984$$)$args_arr__5774__auto__$jscomp$11$$.push(arguments[$i__5750__auto___24985$$]),
$i__5750__auto___24985$$+=1;else break;return $cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$11$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$11$$.slice(2),0,null):null)}};$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$1$=function($coll$jscomp$138$$){return $coll$jscomp$138$$};
$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$=function($coll$jscomp$139$$,$k$jscomp$71$$){return $coll$jscomp$139$$==null?null:$cljs$core$_disjoin$$($coll$jscomp$139$$,$k$jscomp$71$$)};
$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__24993_coll$jscomp$140_ret$jscomp$4$$,$G__24994_k$jscomp$72$$,$G__24995_ks$jscomp$1$$){for(;;){if($G__24993_coll$jscomp$140_ret$jscomp$4$$==null)return null;$G__24993_coll$jscomp$140_ret$jscomp$4$$=$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($G__24993_coll$jscomp$140_ret$jscomp$4$$,$G__24994_k$jscomp$72$$);if($APP.$cljs$core$truth_$$($G__24995_ks$jscomp$1$$))$G__24994_k$jscomp$72$$=$APP.$cljs$core$first$$($G__24995_ks$jscomp$1$$),
$G__24995_ks$jscomp$1$$=$APP.$cljs$core$next$$($G__24995_ks$jscomp$1$$);else return $G__24993_coll$jscomp$140_ret$jscomp$4$$}};
$APP.$cljs$core$disj$$.$cljs$lang$applyTo$=function($G__22954_seq22952$$){var $G__22953$$=$APP.$cljs$core$first$$($G__22954_seq22952$$),$seq22952__$1_seq22952__$2$$=$APP.$cljs$core$next$$($G__22954_seq22952$$);$G__22954_seq22952$$=$APP.$cljs$core$first$$($seq22952__$1_seq22952__$2$$);$seq22952__$1_seq22952__$2$$=$APP.$cljs$core$next$$($seq22952__$1_seq22952__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__22953$$,$G__22954_seq22952$$,$seq22952__$1_seq22952__$2$$)};
$APP.$cljs$core$disj$$.$cljs$lang$maxFixedArity$=2;
var $cljs$core$lookup_sentinel$$={},$cljs$core$distinct_QMARK_$$=function $cljs$core$distinct_QMARK_$$($var_args$jscomp$113$$){switch(arguments.length){case 1:return $cljs$core$distinct_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$distinct_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$13$$=[],$len__5749__auto___25128$$=arguments.length,$i__5750__auto___25129$$=0;;)if($i__5750__auto___25129$$<$len__5749__auto___25128$$)$args_arr__5774__auto__$jscomp$13$$.push(arguments[$i__5750__auto___25129$$]),
$i__5750__auto___25129$$+=1;else break;return $cljs$core$distinct_QMARK_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$13$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$13$$.slice(2),0,null):null)}};$cljs$core$distinct_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function(){return!0};
$cljs$core$distinct_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$181$$,$y$jscomp$84$$){return!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$181$$,$y$jscomp$84$$)};
$cljs$core$distinct_QMARK_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__25132_s$jscomp$47_x$jscomp$182$$,$xs$jscomp$7_y$jscomp$85$$,$G__25133_etc_more$jscomp$1$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__25132_s$jscomp$47_x$jscomp$182$$,$xs$jscomp$7_y$jscomp$85$$))return!1;$G__25132_s$jscomp$47_x$jscomp$182$$=$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$G__25132_s$jscomp$47_x$jscomp$182$$,$xs$jscomp$7_y$jscomp$85$$]);for($xs$jscomp$7_y$jscomp$85$$=$G__25133_etc_more$jscomp$1$$;;){var $x__$1$jscomp$1$$=
$APP.$cljs$core$first$$($xs$jscomp$7_y$jscomp$85$$);$G__25133_etc_more$jscomp$1$$=$APP.$cljs$core$next$$($xs$jscomp$7_y$jscomp$85$$);if($APP.$cljs$core$truth_$$($xs$jscomp$7_y$jscomp$85$$)){if($APP.$cljs$core$contains_QMARK_$$($G__25132_s$jscomp$47_x$jscomp$182$$,$x__$1$jscomp$1$$))return!1;$G__25132_s$jscomp$47_x$jscomp$182$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__25132_s$jscomp$47_x$jscomp$182$$,$x__$1$jscomp$1$$);$xs$jscomp$7_y$jscomp$85$$=$G__25133_etc_more$jscomp$1$$}else return!0}};
$cljs$core$distinct_QMARK_$$.$cljs$lang$applyTo$=function($G__22982_seq22980$$){var $G__22981$$=$APP.$cljs$core$first$$($G__22982_seq22980$$),$seq22980__$1_seq22980__$2$$=$APP.$cljs$core$next$$($G__22982_seq22980$$);$G__22982_seq22980$$=$APP.$cljs$core$first$$($seq22980__$1_seq22980__$2$$);$seq22980__$1_seq22980__$2$$=$APP.$cljs$core$next$$($seq22980__$1_seq22980__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__22981$$,$G__22982_seq22980$$,$seq22980__$1_seq22980__$2$$)};
$cljs$core$distinct_QMARK_$$.$cljs$lang$maxFixedArity$=2;$APP.$cljs$core$sort_by$$=function $cljs$core$sort_by$$($var_args$jscomp$116$$){switch(arguments.length){case 2:return $cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$=function($keyfn$$,$coll$jscomp$146$$){return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($keyfn$$,$APP.$cljs$core$compare$$,$coll$jscomp$146$$)};
$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$=function($keyfn$jscomp$1$$,$comp$jscomp$1$$,$coll$jscomp$147$$){return $APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$02$$(function($G__22992_x$jscomp$185$$,$G__22993_y$jscomp$88$$){$G__22992_x$jscomp$185$$=$keyfn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$keyfn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__22992_x$jscomp$185$$):$keyfn$jscomp$1$$($G__22992_x$jscomp$185$$);$G__22993_y$jscomp$88$$=$keyfn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$keyfn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__22993_y$jscomp$88$$):$keyfn$jscomp$1$$($G__22993_y$jscomp$88$$);var $fexpr__22991$$=$cljs$core$fn__GT_comparator$$($comp$jscomp$1$$);return $fexpr__22991$$.$cljs$core$IFn$_invoke$arity$2$?$fexpr__22991$$.$cljs$core$IFn$_invoke$arity$2$($G__22992_x$jscomp$185$$,$G__22993_y$jscomp$88$$):$fexpr__22991$$($G__22992_x$jscomp$185$$,$G__22993_y$jscomp$88$$)},$coll$jscomp$147$$)};$APP.$cljs$core$sort_by$$.$cljs$lang$maxFixedArity$=3;
$APP.$cljs$core$_PLUS_$$=function $cljs$core$_PLUS_$$($var_args$jscomp$122$$){switch(arguments.length){case 0:return $cljs$core$_PLUS_$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $cljs$core$_PLUS_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$_PLUS_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$14$$=[],$len__5749__auto___25221$$=arguments.length,$i__5750__auto___25222$$=0;;)if($i__5750__auto___25222$$<$len__5749__auto___25221$$)$args_arr__5774__auto__$jscomp$14$$.push(arguments[$i__5750__auto___25222$$]),
$i__5750__auto___25222$$+=1;else break;return $cljs$core$_PLUS_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$14$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$14$$.slice(2),0,null):null)}};$APP.$cljs$core$_PLUS_$$.$cljs$core$IFn$_invoke$arity$0$=function(){return 0};$APP.$cljs$core$_PLUS_$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$190$$){return $x$jscomp$190$$};
$APP.$cljs$core$_PLUS_$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$191$$,$y$jscomp$91$$){return $x$jscomp$191$$+$y$jscomp$91$$};$APP.$cljs$core$_PLUS_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($x$jscomp$192$$,$y$jscomp$92$$,$more$jscomp$2$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_PLUS_$$,$x$jscomp$192$$+$y$jscomp$92$$,$more$jscomp$2$$)};
$APP.$cljs$core$_PLUS_$$.$cljs$lang$applyTo$=function($G__23022_seq23020$$){var $G__23021$$=$APP.$cljs$core$first$$($G__23022_seq23020$$),$seq23020__$1_seq23020__$2$$=$APP.$cljs$core$next$$($G__23022_seq23020$$);$G__23022_seq23020$$=$APP.$cljs$core$first$$($seq23020__$1_seq23020__$2$$);$seq23020__$1_seq23020__$2$$=$APP.$cljs$core$next$$($seq23020__$1_seq23020__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23021$$,$G__23022_seq23020$$,$seq23020__$1_seq23020__$2$$)};
$APP.$cljs$core$_PLUS_$$.$cljs$lang$maxFixedArity$=2;
$APP.$cljs$core$_$$=function $cljs$core$_$$($var_args$jscomp$123$$){switch(arguments.length){case 1:return $cljs$core$_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$15$$=[],$len__5749__auto___25227$$=arguments.length,$i__5750__auto___25228$$=0;;)if($i__5750__auto___25228$$<$len__5749__auto___25227$$)$args_arr__5774__auto__$jscomp$15$$.push(arguments[$i__5750__auto___25228$$]),$i__5750__auto___25228$$+=
1;else break;return $cljs$core$_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$15$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$15$$.slice(2),0,null):null)}};$APP.$cljs$core$_$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$193$$){return-$x$jscomp$193$$};$APP.$cljs$core$_$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$194$$,$y$jscomp$93$$){return $x$jscomp$194$$-$y$jscomp$93$$};
$APP.$cljs$core$_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($x$jscomp$195$$,$y$jscomp$94$$,$more$jscomp$3$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_$$,$x$jscomp$195$$-$y$jscomp$94$$,$more$jscomp$3$$)};
$APP.$cljs$core$_$$.$cljs$lang$applyTo$=function($G__23027_seq23025$$){var $G__23026$$=$APP.$cljs$core$first$$($G__23027_seq23025$$),$seq23025__$1_seq23025__$2$$=$APP.$cljs$core$next$$($G__23027_seq23025$$);$G__23027_seq23025$$=$APP.$cljs$core$first$$($seq23025__$1_seq23025__$2$$);$seq23025__$1_seq23025__$2$$=$APP.$cljs$core$next$$($seq23025__$1_seq23025__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23026$$,$G__23027_seq23025$$,$seq23025__$1_seq23025__$2$$)};
$APP.$cljs$core$_$$.$cljs$lang$maxFixedArity$=2;
var $cljs$core$_STAR_$$=function $cljs$core$_STAR_$$($var_args$jscomp$124$$){switch(arguments.length){case 0:return $cljs$core$_STAR_$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $cljs$core$_STAR_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$_STAR_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$16$$=[],$len__5749__auto___25232$$=arguments.length,$i__5750__auto___25233$$=0;;)if($i__5750__auto___25233$$<$len__5749__auto___25232$$)$args_arr__5774__auto__$jscomp$16$$.push(arguments[$i__5750__auto___25233$$]),
$i__5750__auto___25233$$+=1;else break;return $cljs$core$_STAR_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$16$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$16$$.slice(2),0,null):null)}};$cljs$core$_STAR_$$.$cljs$core$IFn$_invoke$arity$0$=function(){return 1};$cljs$core$_STAR_$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$196$$){return $x$jscomp$196$$};
$cljs$core$_STAR_$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$197$$,$y$jscomp$95$$){return $x$jscomp$197$$*$y$jscomp$95$$};$cljs$core$_STAR_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($x$jscomp$198$$,$y$jscomp$96$$,$more$jscomp$4$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($cljs$core$_STAR_$$,$x$jscomp$198$$*$y$jscomp$96$$,$more$jscomp$4$$)};
$cljs$core$_STAR_$$.$cljs$lang$applyTo$=function($G__23032_seq23030$$){var $G__23031$$=$APP.$cljs$core$first$$($G__23032_seq23030$$),$seq23030__$1_seq23030__$2$$=$APP.$cljs$core$next$$($G__23032_seq23030$$);$G__23032_seq23030$$=$APP.$cljs$core$first$$($seq23030__$1_seq23030__$2$$);$seq23030__$1_seq23030__$2$$=$APP.$cljs$core$next$$($seq23030__$1_seq23030__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23031$$,$G__23032_seq23030$$,$seq23030__$1_seq23030__$2$$)};
$cljs$core$_STAR_$$.$cljs$lang$maxFixedArity$=2;
$APP.$cljs$core$_LT_$$=function $cljs$core$_LT_$$($var_args$jscomp$126$$){switch(arguments.length){case 1:return $cljs$core$_LT_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$_LT_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$18$$=[],$len__5749__auto___25257$$=arguments.length,$i__5750__auto___25258$$=0;;)if($i__5750__auto___25258$$<$len__5749__auto___25257$$)$args_arr__5774__auto__$jscomp$18$$.push(arguments[$i__5750__auto___25258$$]),$i__5750__auto___25258$$+=
1;else break;return $cljs$core$_LT_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$18$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$18$$.slice(2),0,null):null)}};$APP.$cljs$core$_LT_$$.$cljs$core$IFn$_invoke$arity$1$=function(){return!0};$APP.$cljs$core$_LT_$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$203$$,$y$jscomp$99$$){return $x$jscomp$203$$<$y$jscomp$99$$};
$APP.$cljs$core$_LT_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__25267_x$jscomp$204$$,$G__25268_y$jscomp$100$$,$G__25269_more$jscomp$6$$){for(;;){if($G__25267_x$jscomp$204$$<$G__25268_y$jscomp$100$$)if($APP.$cljs$core$next$$($G__25269_more$jscomp$6$$)){$G__25267_x$jscomp$204$$=$G__25268_y$jscomp$100$$;$G__25268_y$jscomp$100$$=$APP.$cljs$core$first$$($G__25269_more$jscomp$6$$);$G__25269_more$jscomp$6$$=$APP.$cljs$core$next$$($G__25269_more$jscomp$6$$);continue}else return $G__25268_y$jscomp$100$$<
$APP.$cljs$core$first$$($G__25269_more$jscomp$6$$);else return!1;break}};
$APP.$cljs$core$_LT_$$.$cljs$lang$applyTo$=function($G__23042_seq23040$$){var $G__23041$$=$APP.$cljs$core$first$$($G__23042_seq23040$$),$seq23040__$1_seq23040__$2$$=$APP.$cljs$core$next$$($G__23042_seq23040$$);$G__23042_seq23040$$=$APP.$cljs$core$first$$($seq23040__$1_seq23040__$2$$);$seq23040__$1_seq23040__$2$$=$APP.$cljs$core$next$$($seq23040__$1_seq23040__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23041$$,$G__23042_seq23040$$,$seq23040__$1_seq23040__$2$$)};
$APP.$cljs$core$_LT_$$.$cljs$lang$maxFixedArity$=2;
var $cljs$core$_LT__EQ_$$=function $cljs$core$_LT__EQ_$$($var_args$jscomp$127$$){switch(arguments.length){case 1:return $cljs$core$_LT__EQ_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$_LT__EQ_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$19$$=[],$len__5749__auto___25276$$=arguments.length,$i__5750__auto___25277$$=0;;)if($i__5750__auto___25277$$<$len__5749__auto___25276$$)$args_arr__5774__auto__$jscomp$19$$.push(arguments[$i__5750__auto___25277$$]),$i__5750__auto___25277$$+=
1;else break;return $cljs$core$_LT__EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$19$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$19$$.slice(2),0,null):null)}};$cljs$core$_LT__EQ_$$.$cljs$core$IFn$_invoke$arity$1$=function(){return!0};$cljs$core$_LT__EQ_$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$206$$,$y$jscomp$101$$){return $x$jscomp$206$$<=$y$jscomp$101$$};
$cljs$core$_LT__EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__25280_x$jscomp$207$$,$G__25281_y$jscomp$102$$,$G__25282_more$jscomp$7$$){for(;;){if($G__25280_x$jscomp$207$$<=$G__25281_y$jscomp$102$$)if($APP.$cljs$core$next$$($G__25282_more$jscomp$7$$)){$G__25280_x$jscomp$207$$=$G__25281_y$jscomp$102$$;$G__25281_y$jscomp$102$$=$APP.$cljs$core$first$$($G__25282_more$jscomp$7$$);$G__25282_more$jscomp$7$$=$APP.$cljs$core$next$$($G__25282_more$jscomp$7$$);continue}else return $G__25281_y$jscomp$102$$<=
$APP.$cljs$core$first$$($G__25282_more$jscomp$7$$);else return!1;break}};
$cljs$core$_LT__EQ_$$.$cljs$lang$applyTo$=function($G__23047_seq23045$$){var $G__23046$$=$APP.$cljs$core$first$$($G__23047_seq23045$$),$seq23045__$1_seq23045__$2$$=$APP.$cljs$core$next$$($G__23047_seq23045$$);$G__23047_seq23045$$=$APP.$cljs$core$first$$($seq23045__$1_seq23045__$2$$);$seq23045__$1_seq23045__$2$$=$APP.$cljs$core$next$$($seq23045__$1_seq23045__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23046$$,$G__23047_seq23045$$,$seq23045__$1_seq23045__$2$$)};
$cljs$core$_LT__EQ_$$.$cljs$lang$maxFixedArity$=2;
$APP.$cljs$core$_GT_$$=function $cljs$core$_GT_$$($var_args$jscomp$128$$){switch(arguments.length){case 1:return $cljs$core$_GT_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$_GT_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$20$$=[],$len__5749__auto___25285$$=arguments.length,$i__5750__auto___25286$$=0;;)if($i__5750__auto___25286$$<$len__5749__auto___25285$$)$args_arr__5774__auto__$jscomp$20$$.push(arguments[$i__5750__auto___25286$$]),$i__5750__auto___25286$$+=
1;else break;return $cljs$core$_GT_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$20$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$20$$.slice(2),0,null):null)}};$APP.$cljs$core$_GT_$$.$cljs$core$IFn$_invoke$arity$1$=function(){return!0};$APP.$cljs$core$_GT_$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$209$$,$y$jscomp$103$$){return $x$jscomp$209$$>$y$jscomp$103$$};
$APP.$cljs$core$_GT_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__25294_x$jscomp$210$$,$G__25295_y$jscomp$104$$,$G__25296_more$jscomp$8$$){for(;;){if($G__25294_x$jscomp$210$$>$G__25295_y$jscomp$104$$)if($APP.$cljs$core$next$$($G__25296_more$jscomp$8$$)){$G__25294_x$jscomp$210$$=$G__25295_y$jscomp$104$$;$G__25295_y$jscomp$104$$=$APP.$cljs$core$first$$($G__25296_more$jscomp$8$$);$G__25296_more$jscomp$8$$=$APP.$cljs$core$next$$($G__25296_more$jscomp$8$$);continue}else return $G__25295_y$jscomp$104$$>
$APP.$cljs$core$first$$($G__25296_more$jscomp$8$$);else return!1;break}};
$APP.$cljs$core$_GT_$$.$cljs$lang$applyTo$=function($G__23052_seq23050$$){var $G__23051$$=$APP.$cljs$core$first$$($G__23052_seq23050$$),$seq23050__$1_seq23050__$2$$=$APP.$cljs$core$next$$($G__23052_seq23050$$);$G__23052_seq23050$$=$APP.$cljs$core$first$$($seq23050__$1_seq23050__$2$$);$seq23050__$1_seq23050__$2$$=$APP.$cljs$core$next$$($seq23050__$1_seq23050__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23051$$,$G__23052_seq23050$$,$seq23050__$1_seq23050__$2$$)};
$APP.$cljs$core$_GT_$$.$cljs$lang$maxFixedArity$=2;
var $cljs$core$_GT__EQ_$$=function $cljs$core$_GT__EQ_$$($var_args$jscomp$129$$){switch(arguments.length){case 1:return $cljs$core$_GT__EQ_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$_GT__EQ_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$21$$=[],$len__5749__auto___25303$$=arguments.length,$i__5750__auto___25304$$=0;;)if($i__5750__auto___25304$$<$len__5749__auto___25303$$)$args_arr__5774__auto__$jscomp$21$$.push(arguments[$i__5750__auto___25304$$]),$i__5750__auto___25304$$+=
1;else break;return $cljs$core$_GT__EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$21$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$21$$.slice(2),0,null):null)}};$cljs$core$_GT__EQ_$$.$cljs$core$IFn$_invoke$arity$1$=function(){return!0};$cljs$core$_GT__EQ_$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$212$$,$y$jscomp$105$$){return $x$jscomp$212$$>=$y$jscomp$105$$};
$cljs$core$_GT__EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__25313_x$jscomp$213$$,$G__25314_y$jscomp$106$$,$G__25315_more$jscomp$9$$){for(;;){if($G__25313_x$jscomp$213$$>=$G__25314_y$jscomp$106$$)if($APP.$cljs$core$next$$($G__25315_more$jscomp$9$$)){$G__25313_x$jscomp$213$$=$G__25314_y$jscomp$106$$;$G__25314_y$jscomp$106$$=$APP.$cljs$core$first$$($G__25315_more$jscomp$9$$);$G__25315_more$jscomp$9$$=$APP.$cljs$core$next$$($G__25315_more$jscomp$9$$);continue}else return $G__25314_y$jscomp$106$$>=
$APP.$cljs$core$first$$($G__25315_more$jscomp$9$$);else return!1;break}};
$cljs$core$_GT__EQ_$$.$cljs$lang$applyTo$=function($G__23057_seq23055$$){var $G__23056$$=$APP.$cljs$core$first$$($G__23057_seq23055$$),$seq23055__$1_seq23055__$2$$=$APP.$cljs$core$next$$($G__23057_seq23055$$);$G__23057_seq23055$$=$APP.$cljs$core$first$$($seq23055__$1_seq23055__$2$$);$seq23055__$1_seq23055__$2$$=$APP.$cljs$core$next$$($seq23055__$1_seq23055__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23056$$,$G__23057_seq23055$$,$seq23055__$1_seq23055__$2$$)};
$cljs$core$_GT__EQ_$$.$cljs$lang$maxFixedArity$=2;
$APP.$cljs$core$max$$=function $cljs$core$max$$($var_args$jscomp$130$$){switch(arguments.length){case 1:return $cljs$core$max$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$max$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$22$$=[],$len__5749__auto___25324$$=arguments.length,$i__5750__auto___25325$$=0;;)if($i__5750__auto___25325$$<$len__5749__auto___25324$$)$args_arr__5774__auto__$jscomp$22$$.push(arguments[$i__5750__auto___25325$$]),$i__5750__auto___25325$$+=
1;else break;return $cljs$core$max$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$22$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$22$$.slice(2),0,null):null)}};$APP.$cljs$core$max$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$215$$){return $x$jscomp$215$$};$APP.$cljs$core$max$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$216$$,$y$jscomp$107$$){return $x$jscomp$216$$>$y$jscomp$107$$?$x$jscomp$216$$:$y$jscomp$107$$};
$APP.$cljs$core$max$$.$cljs$core$IFn$_invoke$arity$variadic$=function($x$jscomp$217$$,$y$jscomp$108$$,$more$jscomp$10$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$max$$,$x$jscomp$217$$>$y$jscomp$108$$?$x$jscomp$217$$:$y$jscomp$108$$,$more$jscomp$10$$)};
$APP.$cljs$core$max$$.$cljs$lang$applyTo$=function($G__23062_seq23060$$){var $G__23061$$=$APP.$cljs$core$first$$($G__23062_seq23060$$),$seq23060__$1_seq23060__$2$$=$APP.$cljs$core$next$$($G__23062_seq23060$$);$G__23062_seq23060$$=$APP.$cljs$core$first$$($seq23060__$1_seq23060__$2$$);$seq23060__$1_seq23060__$2$$=$APP.$cljs$core$next$$($seq23060__$1_seq23060__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23061$$,$G__23062_seq23060$$,$seq23060__$1_seq23060__$2$$)};
$APP.$cljs$core$max$$.$cljs$lang$maxFixedArity$=2;
$APP.$cljs$core$min$$=function $cljs$core$min$$($var_args$jscomp$131$$){switch(arguments.length){case 1:return $cljs$core$min$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$min$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$23$$=[],$len__5749__auto___25334$$=arguments.length,$i__5750__auto___25335$$=0;;)if($i__5750__auto___25335$$<$len__5749__auto___25334$$)$args_arr__5774__auto__$jscomp$23$$.push(arguments[$i__5750__auto___25335$$]),$i__5750__auto___25335$$+=
1;else break;return $cljs$core$min$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$23$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$23$$.slice(2),0,null):null)}};$APP.$cljs$core$min$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$218$$){return $x$jscomp$218$$};$APP.$cljs$core$min$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$219$$,$y$jscomp$109$$){return $x$jscomp$219$$<$y$jscomp$109$$?$x$jscomp$219$$:$y$jscomp$109$$};
$APP.$cljs$core$min$$.$cljs$core$IFn$_invoke$arity$variadic$=function($x$jscomp$220$$,$y$jscomp$110$$,$more$jscomp$11$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$min$$,$x$jscomp$220$$<$y$jscomp$110$$?$x$jscomp$220$$:$y$jscomp$110$$,$more$jscomp$11$$)};
$APP.$cljs$core$min$$.$cljs$lang$applyTo$=function($G__23067_seq23065$$){var $G__23066$$=$APP.$cljs$core$first$$($G__23067_seq23065$$),$seq23065__$1_seq23065__$2$$=$APP.$cljs$core$next$$($G__23067_seq23065$$);$G__23067_seq23065$$=$APP.$cljs$core$first$$($seq23065__$1_seq23065__$2$$);$seq23065__$1_seq23065__$2$$=$APP.$cljs$core$next$$($seq23065__$1_seq23065__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23066$$,$G__23067_seq23065$$,$seq23065__$1_seq23065__$2$$)};
$APP.$cljs$core$min$$.$cljs$lang$maxFixedArity$=2;
$APP.$cljs$core$str$$=function $cljs$core$str$$($var_args$jscomp$144$$){switch(arguments.length){case 0:return $cljs$core$str$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:for(var $args_arr__5774__auto__$jscomp$36$$=[],$len__5749__auto___25541$$=arguments.length,$i__5750__auto___25542$$=0;;)if($i__5750__auto___25542$$<$len__5749__auto___25541$$)$args_arr__5774__auto__$jscomp$36$$.push(arguments[$i__5750__auto___25542$$]),$i__5750__auto___25542$$+=
1;else break;return $cljs$core$str$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args_arr__5774__auto__$jscomp$36$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$36$$.slice(1),0,null):null)}};$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$0$=function(){return""};$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$294$$){return $x$jscomp$294$$==null?"":[$x$jscomp$294$$].join("")};
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__25545_sb$jscomp$6_x$jscomp$295$$,$G__25546_more$jscomp$24_ys$jscomp$2$$){for($G__25545_sb$jscomp$6_x$jscomp$295$$=new $APP.$goog$string$StringBuffer$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__25545_sb$jscomp$6_x$jscomp$295$$));;)if($APP.$cljs$core$truth_$$($G__25546_more$jscomp$24_ys$jscomp$2$$))$G__25545_sb$jscomp$6_x$jscomp$295$$=$G__25545_sb$jscomp$6_x$jscomp$295$$.append($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($G__25546_more$jscomp$24_ys$jscomp$2$$))),
$G__25546_more$jscomp$24_ys$jscomp$2$$=$APP.$cljs$core$next$$($G__25546_more$jscomp$24_ys$jscomp$2$$);else return $G__25545_sb$jscomp$6_x$jscomp$295$$.toString()};$APP.$cljs$core$str$$.$cljs$lang$applyTo$=function($seq23131_seq23131__$1$$){var $G__23132$$=$APP.$cljs$core$first$$($seq23131_seq23131__$1$$);$seq23131_seq23131__$1$$=$APP.$cljs$core$next$$($seq23131_seq23131__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23132$$,$seq23131_seq23131__$1$$)};
$APP.$cljs$core$str$$.$cljs$lang$maxFixedArity$=1;$APP.$cljs$core$subs$$=function $cljs$core$subs$$($var_args$jscomp$145$$){switch(arguments.length){case 2:return $cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$=function($s$jscomp$49$$,$start$jscomp$31$$){return $s$jscomp$49$$.substring($start$jscomp$31$$)};$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$=function($s$jscomp$50$$,$start$jscomp$32$$,$end$jscomp$12$$){return $s$jscomp$50$$.substring($start$jscomp$32$$,$end$jscomp$12$$)};$APP.$cljs$core$subs$$.$cljs$lang$maxFixedArity$=3;$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$List$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$55$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$55$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__25617$$=null;$G__25617$$=function($x$jscomp$299$$,$start$jscomp$34$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$299$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$299$$,$start$jscomp$34$$)}throw Error("Invalid arity: "+arguments.length);};$G__25617$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$297$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$297$$,0)};$G__25617$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$298$$,$start$jscomp$33$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$298$$,$start$jscomp$33$$)};return $G__25617$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__25624__1$$($x$jscomp$300$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$300$$,this.count)}var $G__25624$$=null;$G__25624$$=function($x$jscomp$302$$,$start$jscomp$36$$){switch(arguments.length){case 1:return $G__25624__1$$.call(this,$x$jscomp$302$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$302$$,$start$jscomp$36$$)}throw Error("Invalid arity: "+
arguments.length);};$G__25624$$.$cljs$core$IFn$_invoke$arity$1$=$G__25624__1$$;$G__25624$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$301$$,$start$jscomp$35$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$301$$,$start$jscomp$35$$)};return $G__25624$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$cljs$core$List$$(this.$meta$,this.first,this.$rest$,this.count,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return this.count===1?null:this.$rest$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.count};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_peek$arity$1$=function(){return this.first};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_pop$arity$1$=function(){return this.$cljs$core$ISeq$_rest$arity$1$(null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$1_h__5134__auto____$1$jscomp$1$$=this.$__hash$;return $h__5134__auto__$jscomp$1_h__5134__auto____$1$jscomp$1$$!=null?$h__5134__auto__$jscomp$1_h__5134__auto____$1$jscomp$1$$:this.$__hash$=$h__5134__auto__$jscomp$1_h__5134__auto____$1$jscomp$1$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$171$$,$other$jscomp$56$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$56$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$_with_meta$$($APP.$cljs$core$List$EMPTY$$,this.$meta$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$173$$,$f$jscomp$155$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$155$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$174$$,$f$jscomp$156$$,$start$jscomp$37$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$156$$,$start$jscomp$37$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return this.first};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){return this.count===1?$APP.$cljs$core$List$EMPTY$$:this.$rest$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$178$$,$new_meta$jscomp$5$$){return $new_meta$jscomp$5$$===this.$meta$?this:new $APP.$cljs$core$List$$($new_meta$jscomp$5$$,this.first,this.$rest$,this.count,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$179$$,$o$jscomp$82$$){return new $APP.$cljs$core$List$$(this.$meta$,$o$jscomp$82$$,this,this.count+1,null)};
$APP.$cljs$core$List$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$EmptyList$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$57$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$57$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__25645$$=null;$G__25645$$=function($x$jscomp$306$$,$start$jscomp$39$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$306$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$306$$,$start$jscomp$39$$)}throw Error("Invalid arity: "+arguments.length);};$G__25645$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$304$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$304$$,0)};$G__25645$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$305$$,$start$jscomp$38$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$305$$,$start$jscomp$38$$)};return $G__25645$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__25646__1$$($x$jscomp$307$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$307$$,$APP.$cljs$core$count$$(this))}var $G__25646$$=null;$G__25646$$=function($x$jscomp$309$$,$start$jscomp$41$$){switch(arguments.length){case 1:return $G__25646__1$$.call(this,$x$jscomp$309$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$309$$,$start$jscomp$41$$)}throw Error("Invalid arity: "+
arguments.length);};$G__25646$$.$cljs$core$IFn$_invoke$arity$1$=$G__25646__1$$;$G__25646$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$308$$,$start$jscomp$40$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$308$$,$start$jscomp$40$$)};return $G__25646$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$core$EmptyList$$(this.$meta$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 0};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_peek$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_pop$arity$1$=function(){throw Error("Can't pop empty list");};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $cljs$core$empty_ordered_hash$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$191$$,$other$jscomp$58$$){return $APP.$cljs$core$list_QMARK_$$($other$jscomp$58$$)||$APP.$cljs$core$sequential_QMARK_$$($other$jscomp$58$$)?$APP.$cljs$core$seq$$($other$jscomp$58$$)==null:!1};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return this};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$193$$,$f$jscomp$157$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$157$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$194$$,$f$jscomp$158$$,$start$jscomp$42$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$158$$,$start$jscomp$42$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$198$$,$new_meta$jscomp$6$$){return $new_meta$jscomp$6$$===this.$meta$?this:new $cljs$core$EmptyList$$($new_meta$jscomp$6$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$199$$,$o$jscomp$83$$){return new $APP.$cljs$core$List$$(this.$meta$,$o$jscomp$83$$,null,1,null)};$APP.$cljs$core$List$EMPTY$$=new $cljs$core$EmptyList$$(null);$cljs$core$EmptyList$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
$APP.$cljs$core$list$$=function $cljs$core$list$$($var_args$jscomp$146$$){for(var $args__5755__auto__$jscomp$1$$=[],$len__5749__auto___25654$$=arguments.length,$i__5750__auto___25656$$=0;;)if($i__5750__auto___25656$$<$len__5749__auto___25654$$)$args__5755__auto__$jscomp$1$$.push(arguments[$i__5750__auto___25656$$]),$i__5750__auto___25656$$+=1;else break;return $cljs$core$list$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$1$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$1$$.slice(0),
0,null):null)};
$APP.$cljs$core$list$$.$cljs$core$IFn$_invoke$arity$variadic$=function($i$jscomp$185_xs$jscomp$12_xs__$1$jscomp$inline_2634$$){if($i$jscomp$185_xs$jscomp$12_xs__$1$jscomp$inline_2634$$ instanceof $APP.$cljs$core$IndexedSeq$$&&$i$jscomp$185_xs$jscomp$12_xs__$1$jscomp$inline_2634$$.i===0)var $JSCompiler_temp$jscomp$143_arr$jscomp$73_arr$jscomp$inline_2633$$=$i$jscomp$185_xs$jscomp$12_xs__$1$jscomp$inline_2634$$.$arr$;else a:{for($JSCompiler_temp$jscomp$143_arr$jscomp$73_arr$jscomp$inline_2633$$=[];;)if($i$jscomp$185_xs$jscomp$12_xs__$1$jscomp$inline_2634$$!=
null)$JSCompiler_temp$jscomp$143_arr$jscomp$73_arr$jscomp$inline_2633$$.push($cljs$core$_first$$($i$jscomp$185_xs$jscomp$12_xs__$1$jscomp$inline_2634$$)),$i$jscomp$185_xs$jscomp$12_xs__$1$jscomp$inline_2634$$=$cljs$core$_next$$($i$jscomp$185_xs$jscomp$12_xs__$1$jscomp$inline_2634$$);else break a;$JSCompiler_temp$jscomp$143_arr$jscomp$73_arr$jscomp$inline_2633$$=void 0}$i$jscomp$185_xs$jscomp$12_xs__$1$jscomp$inline_2634$$=$JSCompiler_temp$jscomp$143_arr$jscomp$73_arr$jscomp$inline_2633$$.length;for(var $G__25661_r$jscomp$21$$=
$APP.$cljs$core$List$EMPTY$$;;)if($i$jscomp$185_xs$jscomp$12_xs__$1$jscomp$inline_2634$$>0){var $G__25660$$=$i$jscomp$185_xs$jscomp$12_xs__$1$jscomp$inline_2634$$-1;$G__25661_r$jscomp$21$$=$APP.$cljs$core$_conj$$($G__25661_r$jscomp$21$$,$JSCompiler_temp$jscomp$143_arr$jscomp$73_arr$jscomp$inline_2633$$[$i$jscomp$185_xs$jscomp$12_xs__$1$jscomp$inline_2634$$-1]);$i$jscomp$185_xs$jscomp$12_xs__$1$jscomp$inline_2634$$=$G__25660$$}else return $G__25661_r$jscomp$21$$};
$APP.$cljs$core$list$$.$cljs$lang$maxFixedArity$=0;$APP.$cljs$core$list$$.$cljs$lang$applyTo$=function($seq23154$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq23154$$))};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$Cons$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$59$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$59$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__25663$$=null;$G__25663$$=function($x$jscomp$312$$,$start$jscomp$44$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$312$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$312$$,$start$jscomp$44$$)}throw Error("Invalid arity: "+arguments.length);};$G__25663$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$310$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$310$$,0)};$G__25663$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$311$$,$start$jscomp$43$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$311$$,$start$jscomp$43$$)};return $G__25663$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__25666__1$$($x$jscomp$313$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$313$$,$APP.$cljs$core$count$$(this))}var $G__25666$$=null;$G__25666$$=function($x$jscomp$315$$,$start$jscomp$46$$){switch(arguments.length){case 1:return $G__25666__1$$.call(this,$x$jscomp$315$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$315$$,$start$jscomp$46$$)}throw Error("Invalid arity: "+
arguments.length);};$G__25666$$.$cljs$core$IFn$_invoke$arity$1$=$G__25666__1$$;$G__25666$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$314$$,$start$jscomp$45$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$314$$,$start$jscomp$45$$)};return $G__25666$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$cljs$core$Cons$$(this.$meta$,this.first,this.$rest$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return this.$rest$==null?null:$APP.$cljs$core$seq$$(this.$rest$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$2_h__5134__auto____$1$jscomp$2$$=this.$__hash$;return $h__5134__auto__$jscomp$2_h__5134__auto____$1$jscomp$2$$!=null?$h__5134__auto__$jscomp$2_h__5134__auto____$1$jscomp$2$$:this.$__hash$=$h__5134__auto__$jscomp$2_h__5134__auto____$1$jscomp$2$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$210$$,$other$jscomp$60$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$60$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$212$$,$f$jscomp$159$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$159$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$213$$,$f$jscomp$160$$,$start$jscomp$47$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$160$$,$start$jscomp$47$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return this.first};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){return this.$rest$==null?$APP.$cljs$core$List$EMPTY$$:this.$rest$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$217$$,$new_meta$jscomp$7$$){return $new_meta$jscomp$7$$===this.$meta$?this:new $APP.$cljs$core$Cons$$($new_meta$jscomp$7$$,this.first,this.$rest$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$218$$,$o$jscomp$84$$){return new $APP.$cljs$core$Cons$$(null,$o$jscomp$84$$,this,null)};
$APP.$cljs$core$Cons$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$Keyword$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return[":",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.$fqn$)].join("")};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$61$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$61$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($_$jscomp$78$$,$other$jscomp$62$$){return $other$jscomp$62$$ instanceof $APP.$cljs$core$Keyword$$?this.$fqn$===$other$jscomp$62$$.$fqn$:!1};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$3$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$191$$,$args23156$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23156$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($coll$jscomp$220$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($coll$jscomp$220$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($coll$jscomp$221$$,$not_found$jscomp$11$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($coll$jscomp$221$$,this,$not_found$jscomp$11$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$3_h__5134__auto____$1$jscomp$3$$=this.$_hash$;return $h__5134__auto__$jscomp$3_h__5134__auto____$1$jscomp$3$$!=null?$h__5134__auto__$jscomp$3_h__5134__auto____$1$jscomp$3$$:this.$_hash$=$h__5134__auto__$jscomp$3_h__5134__auto____$1$jscomp$3$$=$cljs$core$hash_symbol$$(this)+2654435769|0};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INamed$_name$arity$1$=function(){return this.name};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INamed$_namespace$arity$1$=function(){return this.ns};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($o$jscomp$85$$,$writer$jscomp$8$$){return $APP.$cljs$core$_write$$($writer$jscomp$8$$,[":",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.$fqn$)].join(""))};
$APP.$cljs$core$keyword$$=function $cljs$core$keyword$$($var_args$jscomp$147$$){switch(arguments.length){case 1:return $cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$=function($name$jscomp$107$$){if($name$jscomp$107$$ instanceof $APP.$cljs$core$Keyword$$)return $name$jscomp$107$$;if($name$jscomp$107$$ instanceof $APP.$cljs$core$Symbol$$)return new $APP.$cljs$core$Keyword$$($APP.$cljs$core$namespace$$($name$jscomp$107$$),$APP.$cljs$core$name$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$name$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$107$$):$APP.$cljs$core$name$$($name$jscomp$107$$),$name$jscomp$107$$.$str$,
null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("/",$name$jscomp$107$$))return new $APP.$cljs$core$Keyword$$(null,$name$jscomp$107$$,$name$jscomp$107$$,null);if(typeof $name$jscomp$107$$==="string"){var $parts$jscomp$12$$=$name$jscomp$107$$.split("/");return $parts$jscomp$12$$.length===2?new $APP.$cljs$core$Keyword$$($parts$jscomp$12$$[0],$parts$jscomp$12$$[1],$name$jscomp$107$$,null):new $APP.$cljs$core$Keyword$$(null,$parts$jscomp$12$$[0],$name$jscomp$107$$,null)}return null};
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$=function($ns$jscomp$6_ns__$1$$,$name$jscomp$108_name__$1$$){$ns$jscomp$6_ns__$1$$=$ns$jscomp$6_ns__$1$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$name$$.$cljs$core$IFn$_invoke$arity$1$($ns$jscomp$6_ns__$1$$):$APP.$cljs$core$name$$($ns$jscomp$6_ns__$1$$):$ns$jscomp$6_ns__$1$$ instanceof $APP.$cljs$core$Symbol$$?$APP.$cljs$core$name$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$name$$.$cljs$core$IFn$_invoke$arity$1$($ns$jscomp$6_ns__$1$$):
$APP.$cljs$core$name$$($ns$jscomp$6_ns__$1$$):$ns$jscomp$6_ns__$1$$;$name$jscomp$108_name__$1$$=$name$jscomp$108_name__$1$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$name$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$108_name__$1$$):$APP.$cljs$core$name$$($name$jscomp$108_name__$1$$):$name$jscomp$108_name__$1$$ instanceof $APP.$cljs$core$Symbol$$?$APP.$cljs$core$name$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$name$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$108_name__$1$$):
$APP.$cljs$core$name$$($name$jscomp$108_name__$1$$):$name$jscomp$108_name__$1$$;return new $APP.$cljs$core$Keyword$$($ns$jscomp$6_ns__$1$$,$name$jscomp$108_name__$1$$,[$APP.$cljs$core$truth_$$($ns$jscomp$6_ns__$1$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ns$jscomp$6_ns__$1$$),"/"].join(""):null,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$108_name__$1$$)].join(""),null)};$APP.$cljs$core$keyword$$.$cljs$lang$maxFixedArity$=2;
$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$LazySeq$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$63$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$63$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__25704$$=null;$G__25704$$=function($x$jscomp$330$$,$start$jscomp$49$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$330$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$330$$,$start$jscomp$49$$)}throw Error("Invalid arity: "+arguments.length);};$G__25704$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$328$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$328$$,0)};$G__25704$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$329$$,$start$jscomp$48$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$329$$,$start$jscomp$48$$)};return $G__25704$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__25709__1$$($x$jscomp$331$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$331$$,$APP.$cljs$core$count$$(this))}var $G__25709$$=null;$G__25709$$=function($x$jscomp$333$$,$start$jscomp$51$$){switch(arguments.length){case 1:return $G__25709__1$$.call(this,$x$jscomp$333$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$333$$,$start$jscomp$51$$)}throw Error("Invalid arity: "+
arguments.length);};$G__25709$$.$cljs$core$IFn$_invoke$arity$1$=$G__25709__1$$;$G__25709$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$332$$,$start$jscomp$50$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$332$$,$start$jscomp$50$$)};return $G__25709$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){this.$cljs$core$ISeqable$_seq$arity$1$(null);return this.s==null?null:$APP.$cljs$core$next$$(this.s)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$4_h__5134__auto____$1$jscomp$4$$=this.$__hash$;return $h__5134__auto__$jscomp$4_h__5134__auto____$1$jscomp$4$$!=null?$h__5134__auto__$jscomp$4_h__5134__auto____$1$jscomp$4$$:this.$__hash$=$h__5134__auto__$jscomp$4_h__5134__auto____$1$jscomp$4$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$231$$,$other$jscomp$64$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$64$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$_with_meta$$($APP.$cljs$core$List$EMPTY$$,this.$meta$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPending$_realized_QMARK_$arity$1$=function(){return $APP.$cljs$core$not$$(this.fn)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$234$$,$f$jscomp$161$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$161$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$235$$,$f$jscomp$162$$,$start$jscomp$52$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$162$$,$start$jscomp$52$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){this.$cljs$core$ISeqable$_seq$arity$1$(null);return this.s==null?null:$APP.$cljs$core$first$$(this.s)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){this.$cljs$core$ISeqable$_seq$arity$1$(null);return this.s!=null?$APP.$cljs$core$rest$$(this.s):$APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){$JSCompiler_StaticMethods_sval$$(this);if(this.s==null)return null;for(var $ls$$=this.s;;)if($ls$$ instanceof $APP.$cljs$core$LazySeq$$)$ls$$=$JSCompiler_StaticMethods_sval$$($ls$$);else return this.s=$ls$$,$APP.$cljs$core$seq$$(this.s)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$239$$,$new_meta$jscomp$8$$){var $coll__$1$jscomp$80$$=this;return $new_meta$jscomp$8$$===this.$meta$?$coll__$1$jscomp$80$$:new $APP.$cljs$core$LazySeq$$($new_meta$jscomp$8$$,function(){return $coll__$1$jscomp$80$$.$cljs$core$ISeqable$_seq$arity$1$(null)},null,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$240$$,$o$jscomp$86$$){return $APP.$cljs$core$cons$$($o$jscomp$86$$,this)};$APP.$cljs$core$LazySeq$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$cljs$core$ChunkBuffer$$.prototype.add=function($o$jscomp$87$$){this.$buf$[this.end]=$o$jscomp$87$$;return this.end+=1};
$cljs$core$ChunkBuffer$$.prototype.$chunk$=function(){var $ret$jscomp$7$$=new $cljs$core$ArrayChunk$$(this.$buf$,0,this.end);this.$buf$=null;return $ret$jscomp$7$$};$cljs$core$ChunkBuffer$$.prototype.$cljs$core$ICounted$_count$arity$1$=function(){return this.end};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$ArrayChunk$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.end-this.$off$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($coll$jscomp$241$$,$i$jscomp$186$$){return this.$arr$[this.$off$+$i$jscomp$186$$]};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($coll$jscomp$242$$,$i$jscomp$187$$,$not_found$jscomp$12$$){return $i$jscomp$187$$>=0&&$i$jscomp$187$$<this.end-this.$off$?this.$arr$[this.$off$+$i$jscomp$187$$]:$not_found$jscomp$12$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IChunk$_drop_first$arity$1$=function(){if(this.$off$===this.end)throw Error("-drop-first of empty chunk");return new $cljs$core$ArrayChunk$$(this.$arr$,this.$off$+1,this.end)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$244$$,$f$jscomp$163$$){return $cljs$core$array_reduce$cljs$0core$0IFn$0_invoke$0arity$04$$(this.$arr$,$f$jscomp$163$$,this.$arr$[this.$off$],this.$off$+1)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$245$$,$f$jscomp$164$$,$start$jscomp$53$$){return $cljs$core$array_reduce$cljs$0core$0IFn$0_invoke$0arity$04$$(this.$arr$,$f$jscomp$164$$,$start$jscomp$53$$,this.$off$)};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$ChunkedCons$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$65$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$65$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__25786$$=null;$G__25786$$=function($x$jscomp$336$$,$start$jscomp$55$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$336$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$336$$,$start$jscomp$55$$)}throw Error("Invalid arity: "+arguments.length);};$G__25786$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$334$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$334$$,0)};$G__25786$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$335$$,$start$jscomp$54$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$335$$,$start$jscomp$54$$)};return $G__25786$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__25787__1$$($x$jscomp$337$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$337$$,$APP.$cljs$core$count$$(this))}var $G__25787$$=null;$G__25787$$=function($x$jscomp$339$$,$start$jscomp$57$$){switch(arguments.length){case 1:return $G__25787__1$$.call(this,$x$jscomp$339$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$339$$,$start$jscomp$57$$)}throw Error("Invalid arity: "+
arguments.length);};$G__25787$$.$cljs$core$IFn$_invoke$arity$1$=$G__25787__1$$;$G__25787$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$338$$,$start$jscomp$56$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$338$$,$start$jscomp$56$$)};return $G__25787$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return $APP.$cljs$core$_count$$(this.$chunk$)>1?new $APP.$cljs$core$ChunkedCons$$($cljs$core$_drop_first$$(this.$chunk$),this.$more$,null,null):this.$more$==null?null:$cljs$core$_seq$$(this.$more$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$5_h__5134__auto____$1$jscomp$5$$=this.$__hash$;return $h__5134__auto__$jscomp$5_h__5134__auto____$1$jscomp$5$$!=null?$h__5134__auto__$jscomp$5_h__5134__auto____$1$jscomp$5$$:this.$__hash$=$h__5134__auto__$jscomp$5_h__5134__auto____$1$jscomp$5$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$254$$,$other$jscomp$66$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$66$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return $APP.$cljs$core$_nth$$(this.$chunk$,0)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){return $APP.$cljs$core$_count$$(this.$chunk$)>1?new $APP.$cljs$core$ChunkedCons$$($cljs$core$_drop_first$$(this.$chunk$),this.$more$,null,null):this.$more$==null?$APP.$cljs$core$List$EMPTY$$:this.$more$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IChunkedSeq$_chunked_first$arity$1$=function(){return this.$chunk$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IChunkedSeq$_chunked_rest$arity$1$=function(){return this.$more$==null?$APP.$cljs$core$List$EMPTY$$:this.$more$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$261$$,$new_meta$jscomp$9$$){return $new_meta$jscomp$9$$===this.$meta$?this:new $APP.$cljs$core$ChunkedCons$$(this.$chunk$,this.$more$,$new_meta$jscomp$9$$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this$$jscomp$65$$,$o$jscomp$88$$){return $APP.$cljs$core$cons$$($o$jscomp$88$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IChunkedNext$_chunked_next$arity$1$=function(){return this.$more$==null?null:this.$more$};$APP.$cljs$core$ChunkedCons$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
$cljs$core$spread$$=function $cljs$core$spread$$($arglist$$){if($arglist$$==null)return null;var $n$jscomp$85$$=$APP.$cljs$core$next$$($arglist$$);return $n$jscomp$85$$==null?$APP.$cljs$core$seq$$($APP.$cljs$core$first$$($arglist$$)):$APP.$cljs$core$cons$$($APP.$cljs$core$first$$($arglist$$),$cljs$core$spread$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$core$spread$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$85$$):$cljs$core$spread$$($n$jscomp$85$$))};
$APP.$cljs$core$concat$$=function $cljs$core$concat$$($var_args$jscomp$153$$){switch(arguments.length){case 0:return $cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$37$$=[],$len__5749__auto___25865$$=arguments.length,$i__5750__auto___25866$$=0;;)if($i__5750__auto___25866$$<$len__5749__auto___25865$$)$args_arr__5774__auto__$jscomp$37$$.push(arguments[$i__5750__auto___25866$$]),
$i__5750__auto___25866$$+=1;else break;return $cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$37$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$37$$.slice(2),0,null):null)}};$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$0$=function(){return new $APP.$cljs$core$LazySeq$$(null,function(){return null},null,null)};
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$341$$){return new $APP.$cljs$core$LazySeq$$(null,function(){return $x$jscomp$341$$},null,null)};
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$342$$,$y$jscomp$138$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $s$jscomp$65$$=$APP.$cljs$core$seq$$($x$jscomp$342$$);return $s$jscomp$65$$?$APP.$cljs$core$chunked_seq_QMARK_$$($s$jscomp$65$$)?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$_chunked_first$$($s$jscomp$65$$),$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_chunked_rest$$($s$jscomp$65$$),$y$jscomp$138$$)):$APP.$cljs$core$cons$$($APP.$cljs$core$first$$($s$jscomp$65$$),
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$rest$$($s$jscomp$65$$),$y$jscomp$138$$)):$y$jscomp$138$$},null,null)};
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$=function($x$jscomp$343$$,$y$jscomp$139$$,$zs$$){return function $cljs$core$cat$$($xys$$,$zs__$1$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $xys__$1$$=$APP.$cljs$core$seq$$($xys$$);return $xys__$1$$?$APP.$cljs$core$chunked_seq_QMARK_$$($xys__$1$$)?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$_chunked_first$$($xys__$1$$),$cljs$core$cat$$($APP.$cljs$core$_chunked_rest$$($xys__$1$$),$zs__$1$$)):$APP.$cljs$core$cons$$($APP.$cljs$core$first$$($xys__$1$$),
$cljs$core$cat$$($APP.$cljs$core$rest$$($xys__$1$$),$zs__$1$$)):$APP.$cljs$core$truth_$$($zs__$1$$)?$cljs$core$cat$$($APP.$cljs$core$first$$($zs__$1$$),$APP.$cljs$core$next$$($zs__$1$$)):null},null,null)}($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$343$$,$y$jscomp$139$$),$zs$$)};
$APP.$cljs$core$concat$$.$cljs$lang$applyTo$=function($G__23175_seq23173$$){var $G__23174$$=$APP.$cljs$core$first$$($G__23175_seq23173$$),$seq23173__$1_seq23173__$2$$=$APP.$cljs$core$next$$($G__23175_seq23173$$);$G__23175_seq23173$$=$APP.$cljs$core$first$$($seq23173__$1_seq23173__$2$$);$seq23173__$1_seq23173__$2$$=$APP.$cljs$core$next$$($seq23173__$1_seq23173__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23174$$,$G__23175_seq23173$$,$seq23173__$1_seq23173__$2$$)};
$APP.$cljs$core$concat$$.$cljs$lang$maxFixedArity$=2;
$APP.$cljs$core$conj_BANG_$$=function $cljs$core$conj_BANG_$$($var_args$jscomp$155$$){switch(arguments.length){case 0:return $cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$39$$=[],$len__5749__auto___25893$$=arguments.length,$i__5750__auto___25894$$=0;;)if($i__5750__auto___25894$$<
$len__5749__auto___25893$$)$args_arr__5774__auto__$jscomp$39$$.push(arguments[$i__5750__auto___25894$$]),$i__5750__auto___25894$$+=1;else break;return $cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$39$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$39$$.slice(2),0,null):null)}};$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$)};
$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$1$=function($tcoll$jscomp$15$$){return $tcoll$jscomp$15$$};$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$=function($tcoll$jscomp$16$$,$val$jscomp$63$$){return $cljs$core$_conj_BANG_$$($tcoll$jscomp$16$$,$val$jscomp$63$$)};
$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__25896_ntcoll_tcoll$jscomp$17$$,$G__25897_val$jscomp$64$$,$G__25898_vals$jscomp$2$$){for(;;)if($G__25896_ntcoll_tcoll$jscomp$17$$=$cljs$core$_conj_BANG_$$($G__25896_ntcoll_tcoll$jscomp$17$$,$G__25897_val$jscomp$64$$),$APP.$cljs$core$truth_$$($G__25898_vals$jscomp$2$$))$G__25897_val$jscomp$64$$=$APP.$cljs$core$first$$($G__25898_vals$jscomp$2$$),$G__25898_vals$jscomp$2$$=$APP.$cljs$core$next$$($G__25898_vals$jscomp$2$$);
else return $G__25896_ntcoll_tcoll$jscomp$17$$};
$APP.$cljs$core$conj_BANG_$$.$cljs$lang$applyTo$=function($G__23187_seq23185$$){var $G__23186$$=$APP.$cljs$core$first$$($G__23187_seq23185$$),$seq23185__$1_seq23185__$2$$=$APP.$cljs$core$next$$($G__23187_seq23185$$);$G__23187_seq23185$$=$APP.$cljs$core$first$$($seq23185__$1_seq23185__$2$$);$seq23185__$1_seq23185__$2$$=$APP.$cljs$core$next$$($seq23185__$1_seq23185__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23186$$,$G__23187_seq23185$$,$seq23185__$1_seq23185__$2$$)};
$APP.$cljs$core$conj_BANG_$$.$cljs$lang$maxFixedArity$=2;
$APP.$cljs$core$assoc_BANG_$$=function $cljs$core$assoc_BANG_$$($var_args$jscomp$156$$){switch(arguments.length){case 3:return $cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:for(var $args_arr__5774__auto__$jscomp$40$$=[],$len__5749__auto___25900$$=arguments.length,$i__5750__auto___25901$$=0;;)if($i__5750__auto___25901$$<$len__5749__auto___25900$$)$args_arr__5774__auto__$jscomp$40$$.push(arguments[$i__5750__auto___25901$$]),$i__5750__auto___25901$$+=
1;else break;return $cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],3<$args_arr__5774__auto__$jscomp$40$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$40$$.slice(3),0,null):null)}};$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$=function($tcoll$jscomp$18$$,$key$jscomp$118$$,$val$jscomp$65$$){return $cljs$core$_assoc_BANG_$$($tcoll$jscomp$18$$,$key$jscomp$118$$,$val$jscomp$65$$)};
$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__25903_ntcoll$jscomp$1_tcoll$jscomp$19$$,$G__25904_key$jscomp$119$$,$G__25905_val$jscomp$66$$,$G__25906_kvs$jscomp$1$$){for(;;)if($G__25903_ntcoll$jscomp$1_tcoll$jscomp$19$$=$cljs$core$_assoc_BANG_$$($G__25903_ntcoll$jscomp$1_tcoll$jscomp$19$$,$G__25904_key$jscomp$119$$,$G__25905_val$jscomp$66$$),$APP.$cljs$core$truth_$$($G__25906_kvs$jscomp$1$$))$G__25904_key$jscomp$119$$=$APP.$cljs$core$first$$($G__25906_kvs$jscomp$1$$),
$G__25905_val$jscomp$66$$=$APP.$cljs$core$second$$($G__25906_kvs$jscomp$1$$),$G__25906_kvs$jscomp$1$$=$APP.$cljs$core$next$$($APP.$cljs$core$next$$($G__25906_kvs$jscomp$1$$));else return $G__25903_ntcoll$jscomp$1_tcoll$jscomp$19$$};
$APP.$cljs$core$assoc_BANG_$$.$cljs$lang$applyTo$=function($G__23192_seq23190$$){var $G__23191$$=$APP.$cljs$core$first$$($G__23192_seq23190$$),$G__23193_seq23190__$1$$=$APP.$cljs$core$next$$($G__23192_seq23190$$);$G__23192_seq23190$$=$APP.$cljs$core$first$$($G__23193_seq23190__$1$$);var $seq23190__$2_seq23190__$3$$=$APP.$cljs$core$next$$($G__23193_seq23190__$1$$);$G__23193_seq23190__$1$$=$APP.$cljs$core$first$$($seq23190__$2_seq23190__$3$$);$seq23190__$2_seq23190__$3$$=$APP.$cljs$core$next$$($seq23190__$2_seq23190__$3$$);
return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23191$$,$G__23192_seq23190$$,$G__23193_seq23190__$1$$,$seq23190__$2_seq23190__$3$$)};$APP.$cljs$core$assoc_BANG_$$.$cljs$lang$maxFixedArity$=3;
var $cljs$core$dissoc_BANG_$$=function $cljs$core$dissoc_BANG_$$($var_args$jscomp$157$$){switch(arguments.length){case 2:return $cljs$core$dissoc_BANG_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$41$$=[],$len__5749__auto___25908$$=arguments.length,$i__5750__auto___25909$$=0;;)if($i__5750__auto___25909$$<$len__5749__auto___25908$$)$args_arr__5774__auto__$jscomp$41$$.push(arguments[$i__5750__auto___25909$$]),$i__5750__auto___25909$$+=1;
else break;return $cljs$core$dissoc_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$41$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$41$$.slice(2),0,null):null)}};$cljs$core$dissoc_BANG_$$.$cljs$core$IFn$_invoke$arity$2$=function($tcoll$jscomp$20$$,$key$jscomp$120$$){return $cljs$core$_dissoc_BANG_$$($tcoll$jscomp$20$$,$key$jscomp$120$$)};
$cljs$core$dissoc_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__25911_ntcoll$jscomp$2_tcoll$jscomp$21$$,$G__25912_key$jscomp$121$$,$G__25913_ks$jscomp$2$$){for(;;)if($G__25911_ntcoll$jscomp$2_tcoll$jscomp$21$$=$cljs$core$_dissoc_BANG_$$($G__25911_ntcoll$jscomp$2_tcoll$jscomp$21$$,$G__25912_key$jscomp$121$$),$APP.$cljs$core$truth_$$($G__25913_ks$jscomp$2$$))$G__25912_key$jscomp$121$$=$APP.$cljs$core$first$$($G__25913_ks$jscomp$2$$),$G__25913_ks$jscomp$2$$=$APP.$cljs$core$next$$($G__25913_ks$jscomp$2$$);
else return $G__25911_ntcoll$jscomp$2_tcoll$jscomp$21$$};
$cljs$core$dissoc_BANG_$$.$cljs$lang$applyTo$=function($G__23198_seq23196$$){var $G__23197$$=$APP.$cljs$core$first$$($G__23198_seq23196$$),$seq23196__$1_seq23196__$2$$=$APP.$cljs$core$next$$($G__23198_seq23196$$);$G__23198_seq23196$$=$APP.$cljs$core$first$$($seq23196__$1_seq23196__$2$$);$seq23196__$1_seq23196__$2$$=$APP.$cljs$core$next$$($seq23196__$1_seq23196__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23197$$,$G__23198_seq23196$$,$seq23196__$1_seq23196__$2$$)};
$cljs$core$dissoc_BANG_$$.$cljs$lang$maxFixedArity$=2;
$APP.$cljs$core$apply$$=function $cljs$core$apply$$($var_args$jscomp$160$$){switch(arguments.length){case 2:return $cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);case 5:return $cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$(arguments[0],arguments[1],
arguments[2],arguments[3],arguments[4]);default:for(var $args_arr__5774__auto__$jscomp$43$$=[],$len__5749__auto___25987$$=arguments.length,$i__5750__auto___25988$$=0;;)if($i__5750__auto___25988$$<$len__5749__auto___25987$$)$args_arr__5774__auto__$jscomp$43$$.push(arguments[$i__5750__auto___25988$$]),$i__5750__auto___25988$$+=1;else break;return $cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],5<$args_arr__5774__auto__$jscomp$43$$.length?
new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$43$$.slice(5),0,null):null)}};
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$=function($f$jscomp$171$$,$args$jscomp$22_args$jscomp$inline_2657$$){if($f$jscomp$171$$.$cljs$lang$applyTo$){var $fixed_arity$$=$f$jscomp$171$$.$cljs$lang$maxFixedArity$,$bc$$=$cljs$core$bounded_count$$($fixed_arity$$+1,$args$jscomp$22_args$jscomp$inline_2657$$);return $bc$$<=$fixed_arity$$?$cljs$core$apply_to$$($f$jscomp$171$$,$bc$$,$args$jscomp$22_args$jscomp$inline_2657$$):$f$jscomp$171$$.$cljs$lang$applyTo$($args$jscomp$22_args$jscomp$inline_2657$$)}$args$jscomp$22_args$jscomp$inline_2657$$=
$APP.$cljs$core$seq$$($args$jscomp$22_args$jscomp$inline_2657$$);return $args$jscomp$22_args$jscomp$inline_2657$$==null?$f$jscomp$171$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$171$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$171$$.call($f$jscomp$171$$):$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$171$$,$cljs$core$_first$$($args$jscomp$22_args$jscomp$inline_2657$$),$cljs$core$next_STAR_$$($args$jscomp$22_args$jscomp$inline_2657$$))};
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$=function($f$jscomp$172$$,$arglist$jscomp$1_x$jscomp$344$$,$args$jscomp$23_bc$jscomp$1$$){if($f$jscomp$172$$.$cljs$lang$applyTo$){$arglist$jscomp$1_x$jscomp$344$$=$APP.$cljs$core$cons$$($arglist$jscomp$1_x$jscomp$344$$,$args$jscomp$23_bc$jscomp$1$$);var $fixed_arity$jscomp$1$$=$f$jscomp$172$$.$cljs$lang$maxFixedArity$;$args$jscomp$23_bc$jscomp$1$$=$cljs$core$bounded_count$$($fixed_arity$jscomp$1$$,$args$jscomp$23_bc$jscomp$1$$)+1;return $args$jscomp$23_bc$jscomp$1$$<=
$fixed_arity$jscomp$1$$?$cljs$core$apply_to$$($f$jscomp$172$$,$args$jscomp$23_bc$jscomp$1$$,$arglist$jscomp$1_x$jscomp$344$$):$f$jscomp$172$$.$cljs$lang$applyTo$($arglist$jscomp$1_x$jscomp$344$$)}return $cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$172$$,$arglist$jscomp$1_x$jscomp$344$$,$APP.$cljs$core$seq$$($args$jscomp$23_bc$jscomp$1$$))};
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$4$=function($f$jscomp$173$$,$arglist$jscomp$2_x$jscomp$345$$,$fixed_arity$jscomp$2_y$jscomp$140$$,$args$jscomp$24_bc$jscomp$2$$){return $f$jscomp$173$$.$cljs$lang$applyTo$?($arglist$jscomp$2_x$jscomp$345$$=$APP.$cljs$core$cons$$($arglist$jscomp$2_x$jscomp$345$$,$APP.$cljs$core$cons$$($fixed_arity$jscomp$2_y$jscomp$140$$,$args$jscomp$24_bc$jscomp$2$$)),$fixed_arity$jscomp$2_y$jscomp$140$$=$f$jscomp$173$$.$cljs$lang$maxFixedArity$,$args$jscomp$24_bc$jscomp$2$$=
2+$cljs$core$bounded_count$$($fixed_arity$jscomp$2_y$jscomp$140$$-1,$args$jscomp$24_bc$jscomp$2$$),$args$jscomp$24_bc$jscomp$2$$<=$fixed_arity$jscomp$2_y$jscomp$140$$?$cljs$core$apply_to$$($f$jscomp$173$$,$args$jscomp$24_bc$jscomp$2$$,$arglist$jscomp$2_x$jscomp$345$$):$f$jscomp$173$$.$cljs$lang$applyTo$($arglist$jscomp$2_x$jscomp$345$$)):$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$04$$($f$jscomp$173$$,$arglist$jscomp$2_x$jscomp$345$$,$fixed_arity$jscomp$2_y$jscomp$140$$,$APP.$cljs$core$seq$$($args$jscomp$24_bc$jscomp$2$$))};
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$=function($f$jscomp$174$$,$arglist$jscomp$3_x$jscomp$346$$,$fixed_arity$jscomp$3_y$jscomp$141$$,$z$jscomp$17$$,$args$jscomp$25_bc$jscomp$3$$){return $f$jscomp$174$$.$cljs$lang$applyTo$?($arglist$jscomp$3_x$jscomp$346$$=$APP.$cljs$core$cons$$($arglist$jscomp$3_x$jscomp$346$$,$APP.$cljs$core$cons$$($fixed_arity$jscomp$3_y$jscomp$141$$,$APP.$cljs$core$cons$$($z$jscomp$17$$,$args$jscomp$25_bc$jscomp$3$$))),$fixed_arity$jscomp$3_y$jscomp$141$$=$f$jscomp$174$$.$cljs$lang$maxFixedArity$,
$args$jscomp$25_bc$jscomp$3$$=3+$cljs$core$bounded_count$$($fixed_arity$jscomp$3_y$jscomp$141$$-2,$args$jscomp$25_bc$jscomp$3$$),$args$jscomp$25_bc$jscomp$3$$<=$fixed_arity$jscomp$3_y$jscomp$141$$?$cljs$core$apply_to$$($f$jscomp$174$$,$args$jscomp$25_bc$jscomp$3$$,$arglist$jscomp$3_x$jscomp$346$$):$f$jscomp$174$$.$cljs$lang$applyTo$($arglist$jscomp$3_x$jscomp$346$$)):$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$05$$($f$jscomp$174$$,$arglist$jscomp$3_x$jscomp$346$$,$fixed_arity$jscomp$3_y$jscomp$141$$,
$z$jscomp$17$$,$APP.$cljs$core$seq$$($args$jscomp$25_bc$jscomp$3$$))};
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$=function($f$jscomp$175$$,$a$jscomp$120_arglist$jscomp$4$$,$b$jscomp$105_fixed_arity$jscomp$4$$,$c$jscomp$85$$,$d$jscomp$79$$,$args$jscomp$26_bc$jscomp$4_spread_args$$){return $f$jscomp$175$$.$cljs$lang$applyTo$?($args$jscomp$26_bc$jscomp$4_spread_args$$=$cljs$core$spread$$($args$jscomp$26_bc$jscomp$4_spread_args$$),$a$jscomp$120_arglist$jscomp$4$$=$APP.$cljs$core$cons$$($a$jscomp$120_arglist$jscomp$4$$,$APP.$cljs$core$cons$$($b$jscomp$105_fixed_arity$jscomp$4$$,
$APP.$cljs$core$cons$$($c$jscomp$85$$,$APP.$cljs$core$cons$$($d$jscomp$79$$,$args$jscomp$26_bc$jscomp$4_spread_args$$)))),$b$jscomp$105_fixed_arity$jscomp$4$$=$f$jscomp$175$$.$cljs$lang$maxFixedArity$,$args$jscomp$26_bc$jscomp$4_spread_args$$=4+$cljs$core$bounded_count$$($b$jscomp$105_fixed_arity$jscomp$4$$-3,$args$jscomp$26_bc$jscomp$4_spread_args$$),$args$jscomp$26_bc$jscomp$4_spread_args$$<=$b$jscomp$105_fixed_arity$jscomp$4$$?$cljs$core$apply_to$$($f$jscomp$175$$,$args$jscomp$26_bc$jscomp$4_spread_args$$,
$a$jscomp$120_arglist$jscomp$4$$):$f$jscomp$175$$.$cljs$lang$applyTo$($a$jscomp$120_arglist$jscomp$4$$)):$cljs$core$apply_to_simple$cljs$0core$0IFn$0_invoke$0arity$06$$($f$jscomp$175$$,$a$jscomp$120_arglist$jscomp$4$$,$b$jscomp$105_fixed_arity$jscomp$4$$,$c$jscomp$85$$,$d$jscomp$79$$,$cljs$core$spread$$($args$jscomp$26_bc$jscomp$4_spread_args$$))};
$APP.$cljs$core$apply$$.$cljs$lang$applyTo$=function($G__23211_seq23209$$){var $G__23210$$=$APP.$cljs$core$first$$($G__23211_seq23209$$),$G__23212_seq23209__$1$$=$APP.$cljs$core$next$$($G__23211_seq23209$$);$G__23211_seq23209$$=$APP.$cljs$core$first$$($G__23212_seq23209__$1$$);var $G__23213_seq23209__$2$$=$APP.$cljs$core$next$$($G__23212_seq23209__$1$$);$G__23212_seq23209__$1$$=$APP.$cljs$core$first$$($G__23213_seq23209__$2$$);var $G__23214_seq23209__$3$$=$APP.$cljs$core$next$$($G__23213_seq23209__$2$$);
$G__23213_seq23209__$2$$=$APP.$cljs$core$first$$($G__23214_seq23209__$3$$);var $seq23209__$4_seq23209__$5$$=$APP.$cljs$core$next$$($G__23214_seq23209__$3$$);$G__23214_seq23209__$3$$=$APP.$cljs$core$first$$($seq23209__$4_seq23209__$5$$);$seq23209__$4_seq23209__$5$$=$APP.$cljs$core$next$$($seq23209__$4_seq23209__$5$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23210$$,$G__23211_seq23209$$,$G__23212_seq23209__$1$$,$G__23213_seq23209__$2$$,$G__23214_seq23209__$3$$,$seq23209__$4_seq23209__$5$$)};
$APP.$cljs$core$apply$$.$cljs$lang$maxFixedArity$=5;
$APP.$cljs$core$not_EQ_$$=function $cljs$core$not_EQ_$$($var_args$jscomp$162$$){switch(arguments.length){case 1:return $cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$45$$=[],$len__5749__auto___26017$$=arguments.length,$i__5750__auto___26018$$=0;;)if($i__5750__auto___26018$$<$len__5749__auto___26017$$)$args_arr__5774__auto__$jscomp$45$$.push(arguments[$i__5750__auto___26018$$]),$i__5750__auto___26018$$+=
1;else break;return $cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$45$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$45$$.slice(2),0,null):null)}};$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$1$=function(){return!1};
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$348$$,$y$jscomp$142$$){return!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$348$$,$y$jscomp$142$$)};$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($x$jscomp$349$$,$y$jscomp$143$$,$more$jscomp$28$$){return $APP.$cljs$core$not$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_EQ_$$,$x$jscomp$349$$,$y$jscomp$143$$,$more$jscomp$28$$))};
$APP.$cljs$core$not_EQ_$$.$cljs$lang$applyTo$=function($G__23244_seq23242$$){var $G__23243$$=$APP.$cljs$core$first$$($G__23244_seq23242$$),$seq23242__$1_seq23242__$2$$=$APP.$cljs$core$next$$($G__23244_seq23242$$);$G__23244_seq23242$$=$APP.$cljs$core$first$$($seq23242__$1_seq23242__$2$$);$seq23242__$1_seq23242__$2$$=$APP.$cljs$core$next$$($seq23242__$1_seq23242__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23243$$,$G__23244_seq23242$$,$seq23242__$1_seq23242__$2$$)};
$APP.$cljs$core$not_EQ_$$.$cljs$lang$maxFixedArity$=2;$APP.$JSCompiler_prototypeAlias$$=$cljs$core$t_cljs$0core23246$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_23248$$,$meta23247__$1$$){return new $cljs$core$t_cljs$0core23246$$($meta23247__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta23247$};$APP.$JSCompiler_prototypeAlias$$.hasNext=function(){return!1};
$APP.$JSCompiler_prototypeAlias$$.next=function(){return Error("No such element")};$APP.$JSCompiler_prototypeAlias$$.remove=function(){return Error("Unsupported operation")};$cljs$core$StringIter$$.prototype.hasNext=function(){return this.i<this.s.length};$cljs$core$StringIter$$.prototype.next=function(){var $ret$jscomp$9$$=this.s.charAt(this.i);this.i+=1;return $ret$jscomp$9$$};$cljs$core$StringIter$$.prototype.remove=function(){return Error("Unsupported operation")};
$cljs$core$ArrayIter$$.prototype.hasNext=function(){return this.i<this.$arr$.length};$cljs$core$ArrayIter$$.prototype.next=function(){var $ret$jscomp$10$$=this.$arr$[this.i];this.i+=1;return $ret$jscomp$10$$};$cljs$core$ArrayIter$$.prototype.remove=function(){return Error("Unsupported operation")};var $cljs$core$INIT$$={},$cljs$core$START$$={};
$APP.$cljs$core$SeqIter$$.prototype.hasNext=function(){this.$_seq$===$cljs$core$INIT$$?(this.$_seq$=$cljs$core$START$$,this.$_next$=$APP.$cljs$core$seq$$(this.$_next$)):this.$_seq$===this.$_next$&&(this.$_next$=$APP.$cljs$core$next$$(this.$_seq$));return this.$_next$!=null};$APP.$cljs$core$SeqIter$$.prototype.next=function(){if(this.hasNext())return this.$_seq$=this.$_next$,$APP.$cljs$core$first$$(this.$_next$);throw Error("No such element");};$APP.$cljs$core$SeqIter$$.prototype.remove=function(){return Error("Unsupported operation")};
$cljs$core$Many$$.prototype.add=function($o$jscomp$89$$){this.$vals$.push($o$jscomp$89$$);return this};$cljs$core$Many$$.prototype.remove=function(){return this.$vals$.shift()};$cljs$core$Many$$.prototype.isEmpty=function(){return this.$vals$.length===0};$cljs$core$Many$$.prototype.toString=function(){return["Many: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.$vals$)].join("")};var $cljs$core$NONE$$={};
$cljs$core$Single$$.prototype.add=function($o$jscomp$90$$){return this.$val$===$cljs$core$NONE$$?(this.$val$=$o$jscomp$90$$,this):new $cljs$core$Many$$([this.$val$,$o$jscomp$90$$])};$cljs$core$Single$$.prototype.remove=function(){if(this.$val$===$cljs$core$NONE$$)throw Error("Removing object from empty buffer");var $ret$jscomp$11$$=this.$val$;this.$val$=$cljs$core$NONE$$;return $ret$jscomp$11$$};$cljs$core$Single$$.prototype.isEmpty=function(){return this.$val$===$cljs$core$NONE$$};
$cljs$core$Single$$.prototype.toString=function(){return["Single: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.$val$)].join("")};$cljs$core$Empty$$.prototype.add=function($o$jscomp$91$$){return new $cljs$core$Single$$($o$jscomp$91$$)};$cljs$core$Empty$$.prototype.remove=function(){throw Error("Removing object from empty buffer");};$cljs$core$Empty$$.prototype.isEmpty=function(){return!0};$cljs$core$Empty$$.prototype.toString=function(){return"Empty"};
var $cljs$core$EMPTY$$=new $cljs$core$Empty$$,$cljs$core$chunkIteratorSeq$$=function $cljs$core$chunkIteratorSeq$$($iter$jscomp$7$$){return new $APP.$cljs$core$LazySeq$$(null,function(){if($iter$jscomp$7$$.hasNext())for(var $arr$jscomp$82$$=[],$n$jscomp$86$$=0;;){var $and__5023__auto__$jscomp$inline_2663$$=$iter$jscomp$7$$.hasNext();if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_2663$$)?$n$jscomp$86$$<32:$and__5023__auto__$jscomp$inline_2663$$))$arr$jscomp$82$$[$n$jscomp$86$$]=
$iter$jscomp$7$$.next(),$n$jscomp$86$$+=1;else return $APP.$cljs$core$chunk_cons$$(new $cljs$core$ArrayChunk$$($arr$jscomp$82$$,0,$n$jscomp$86$$),$cljs$core$chunkIteratorSeq$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$core$chunkIteratorSeq$$.$cljs$core$IFn$_invoke$arity$1$($iter$jscomp$7$$):$cljs$core$chunkIteratorSeq$$($iter$jscomp$7$$))}else return null},null,null)};
$cljs$core$TransformerIterator$$.prototype.step=function(){if(this.$_next$!==$cljs$core$NONE$$)return!0;for(;;)if(this.$_next$===$cljs$core$NONE$$)if(this.buffer.isEmpty()){if(this.completed)return!1;if(this.$sourceIter$.hasNext()){if(this.$multi$)var $G__23250$jscomp$inline_2665_JSCompiler_temp$jscomp$154$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$(this.xf,$APP.$cljs$core$cons$$(null,this.$sourceIter$.next()));else $G__23250$jscomp$inline_2665_JSCompiler_temp$jscomp$154$$=this.$sourceIter$.next(),
$G__23250$jscomp$inline_2665_JSCompiler_temp$jscomp$154$$=this.xf.$cljs$core$IFn$_invoke$arity$2$?this.xf.$cljs$core$IFn$_invoke$arity$2$(null,$G__23250$jscomp$inline_2665_JSCompiler_temp$jscomp$154$$):this.xf(null,$G__23250$jscomp$inline_2665_JSCompiler_temp$jscomp$154$$);$cljs$core$reduced_QMARK_$$($G__23250$jscomp$inline_2665_JSCompiler_temp$jscomp$154$$)&&(this.xf.$cljs$core$IFn$_invoke$arity$1$?this.xf.$cljs$core$IFn$_invoke$arity$1$(null):this.xf(null),this.completed=!0)}else this.xf.$cljs$core$IFn$_invoke$arity$1$?
this.xf.$cljs$core$IFn$_invoke$arity$1$(null):this.xf(null),this.completed=!0}else this.$_next$=this.buffer.remove();else return!0};$cljs$core$TransformerIterator$$.prototype.hasNext=function(){return this.step()};$cljs$core$TransformerIterator$$.prototype.next=function(){if(this.hasNext()){var $ret$jscomp$12$$=this.$_next$;this.$_next$=$cljs$core$NONE$$;return $ret$jscomp$12$$}throw Error("No such element");};$cljs$core$TransformerIterator$$.prototype.remove=function(){return Error("Unsupported operation")};
$cljs$core$TransformerIterator$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
$APP.$cljs$core$comp$$=function $cljs$core$comp$$($var_args$jscomp$167$$){switch(arguments.length){case 0:return $cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:for(var $args_arr__5774__auto__$jscomp$47$$=[],$len__5749__auto___26158$$=
arguments.length,$i__5750__auto___26165$$=0;;)if($i__5750__auto___26165$$<$len__5749__auto___26158$$)$args_arr__5774__auto__$jscomp$47$$.push(arguments[$i__5750__auto___26165$$]),$i__5750__auto___26165$$+=1;else break;return $cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],3<$args_arr__5774__auto__$jscomp$47$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$47$$.slice(3),0,null):null)}};
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$cljs$core$identity$$};$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$1$=function($f$jscomp$183$$){return $f$jscomp$183$$};
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$=function($f$jscomp$184$$,$g$jscomp$61$$){return function(){function $G__26177__3$$($G__23270_x$jscomp$361$$,$y$jscomp$150$$,$z$jscomp$18$$){$G__23270_x$jscomp$361$$=$g$jscomp$61$$.$cljs$core$IFn$_invoke$arity$3$?$g$jscomp$61$$.$cljs$core$IFn$_invoke$arity$3$($G__23270_x$jscomp$361$$,$y$jscomp$150$$,$z$jscomp$18$$):$g$jscomp$61$$($G__23270_x$jscomp$361$$,$y$jscomp$150$$,$z$jscomp$18$$);return $f$jscomp$184$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$184$$.$cljs$core$IFn$_invoke$arity$1$($G__23270_x$jscomp$361$$):
$f$jscomp$184$$($G__23270_x$jscomp$361$$)}function $G__26177__2$$($G__23269_x$jscomp$360$$,$y$jscomp$149$$){$G__23269_x$jscomp$360$$=$g$jscomp$61$$.$cljs$core$IFn$_invoke$arity$2$?$g$jscomp$61$$.$cljs$core$IFn$_invoke$arity$2$($G__23269_x$jscomp$360$$,$y$jscomp$149$$):$g$jscomp$61$$($G__23269_x$jscomp$360$$,$y$jscomp$149$$);return $f$jscomp$184$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$184$$.$cljs$core$IFn$_invoke$arity$1$($G__23269_x$jscomp$360$$):$f$jscomp$184$$($G__23269_x$jscomp$360$$)}function $G__26177__1$$($G__23268_x$jscomp$359$$){$G__23268_x$jscomp$359$$=
$g$jscomp$61$$.$cljs$core$IFn$_invoke$arity$1$?$g$jscomp$61$$.$cljs$core$IFn$_invoke$arity$1$($G__23268_x$jscomp$359$$):$g$jscomp$61$$($G__23268_x$jscomp$359$$);return $f$jscomp$184$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$184$$.$cljs$core$IFn$_invoke$arity$1$($G__23268_x$jscomp$359$$):$f$jscomp$184$$($G__23268_x$jscomp$359$$)}function $G__26177__0$$(){var $G__23267$$=$g$jscomp$61$$.$cljs$core$IFn$_invoke$arity$0$?$g$jscomp$61$$.$cljs$core$IFn$_invoke$arity$0$():$g$jscomp$61$$();return $f$jscomp$184$$.$cljs$core$IFn$_invoke$arity$1$?
$f$jscomp$184$$.$cljs$core$IFn$_invoke$arity$1$($G__23267$$):$f$jscomp$184$$($G__23267$$)}var $G__26177$$=null,$G__26177__4$$=function(){function $G__26179$$($x$jscomp$363$$,$y$jscomp$152$$,$z$jscomp$20$$,$var_args$jscomp$168$$){var $G__26188__i_args$jscomp$32$$=null;if(arguments.length>3){$G__26188__i_args$jscomp$32$$=0;for(var $G__26188__a$$=Array(arguments.length-3);$G__26188__i_args$jscomp$32$$<$G__26188__a$$.length;)$G__26188__a$$[$G__26188__i_args$jscomp$32$$]=arguments[$G__26188__i_args$jscomp$32$$+
3],++$G__26188__i_args$jscomp$32$$;$G__26188__i_args$jscomp$32$$=new $APP.$cljs$core$IndexedSeq$$($G__26188__a$$,0,null)}return $G__26179__delegate$$.call(this,$x$jscomp$363$$,$y$jscomp$152$$,$z$jscomp$20$$,$G__26188__i_args$jscomp$32$$)}function $G__26179__delegate$$($G__23271_x$jscomp$362$$,$y$jscomp$151$$,$z$jscomp$19$$,$args$jscomp$31$$){$G__23271_x$jscomp$362$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($g$jscomp$61$$,$G__23271_x$jscomp$362$$,$y$jscomp$151$$,$z$jscomp$19$$,$args$jscomp$31$$);
return $f$jscomp$184$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$184$$.$cljs$core$IFn$_invoke$arity$1$($G__23271_x$jscomp$362$$):$f$jscomp$184$$($G__23271_x$jscomp$362$$)}$G__26179$$.$cljs$lang$maxFixedArity$=3;$G__26179$$.$cljs$lang$applyTo$=function($arglist__26190_args$jscomp$33$$){var $x$jscomp$364$$=$APP.$cljs$core$first$$($arglist__26190_args$jscomp$33$$);$arglist__26190_args$jscomp$33$$=$APP.$cljs$core$next$$($arglist__26190_args$jscomp$33$$);var $y$jscomp$153$$=$APP.$cljs$core$first$$($arglist__26190_args$jscomp$33$$);
$arglist__26190_args$jscomp$33$$=$APP.$cljs$core$next$$($arglist__26190_args$jscomp$33$$);var $z$jscomp$21$$=$APP.$cljs$core$first$$($arglist__26190_args$jscomp$33$$);$arglist__26190_args$jscomp$33$$=$APP.$cljs$core$rest$$($arglist__26190_args$jscomp$33$$);return $G__26179__delegate$$($x$jscomp$364$$,$y$jscomp$153$$,$z$jscomp$21$$,$arglist__26190_args$jscomp$33$$)};$G__26179$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26179__delegate$$;return $G__26179$$}();$G__26177$$=function($x$jscomp$365$$,$y$jscomp$154$$,
$z$jscomp$22$$,$var_args$jscomp$169$$){switch(arguments.length){case 0:return $G__26177__0$$.call(this);case 1:return $G__26177__1$$.call(this,$x$jscomp$365$$);case 2:return $G__26177__2$$.call(this,$x$jscomp$365$$,$y$jscomp$154$$);case 3:return $G__26177__3$$.call(this,$x$jscomp$365$$,$y$jscomp$154$$,$z$jscomp$22$$);default:var $G__26202_G__26203__i$$=null;if(arguments.length>3){$G__26202_G__26203__i$$=0;for(var $G__26203__a$$=Array(arguments.length-3);$G__26202_G__26203__i$$<$G__26203__a$$.length;)$G__26203__a$$[$G__26202_G__26203__i$$]=
arguments[$G__26202_G__26203__i$$+3],++$G__26202_G__26203__i$$;$G__26202_G__26203__i$$=new $APP.$cljs$core$IndexedSeq$$($G__26203__a$$,0,null)}return $G__26177__4$$.$cljs$core$IFn$_invoke$arity$variadic$($x$jscomp$365$$,$y$jscomp$154$$,$z$jscomp$22$$,$G__26202_G__26203__i$$)}throw Error("Invalid arity: "+arguments.length);};$G__26177$$.$cljs$lang$maxFixedArity$=3;$G__26177$$.$cljs$lang$applyTo$=$G__26177__4$$.$cljs$lang$applyTo$;$G__26177$$.$cljs$core$IFn$_invoke$arity$0$=$G__26177__0$$;$G__26177$$.$cljs$core$IFn$_invoke$arity$1$=
$G__26177__1$$;$G__26177$$.$cljs$core$IFn$_invoke$arity$2$=$G__26177__2$$;$G__26177$$.$cljs$core$IFn$_invoke$arity$3$=$G__26177__3$$;$G__26177$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26177__4$$.$cljs$core$IFn$_invoke$arity$variadic$;return $G__26177$$}()};
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$=function($f$jscomp$185$$,$g$jscomp$62$$,$h$jscomp$70$$){return function(){function $G__26205__3$$($G__23278_G__23279$jscomp$inline_2682_x$jscomp$368$$,$y$jscomp$156$$,$z$jscomp$23$$){$G__23278_G__23279$jscomp$inline_2682_x$jscomp$368$$=$h$jscomp$70$$.$cljs$core$IFn$_invoke$arity$3$?$h$jscomp$70$$.$cljs$core$IFn$_invoke$arity$3$($G__23278_G__23279$jscomp$inline_2682_x$jscomp$368$$,$y$jscomp$156$$,$z$jscomp$23$$):$h$jscomp$70$$($G__23278_G__23279$jscomp$inline_2682_x$jscomp$368$$,
$y$jscomp$156$$,$z$jscomp$23$$);$G__23278_G__23279$jscomp$inline_2682_x$jscomp$368$$=$g$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$?$g$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$($G__23278_G__23279$jscomp$inline_2682_x$jscomp$368$$):$g$jscomp$62$$($G__23278_G__23279$jscomp$inline_2682_x$jscomp$368$$);return $f$jscomp$185$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$185$$.$cljs$core$IFn$_invoke$arity$1$($G__23278_G__23279$jscomp$inline_2682_x$jscomp$368$$):$f$jscomp$185$$($G__23278_G__23279$jscomp$inline_2682_x$jscomp$368$$)}
function $G__26205__2$$($G__23276_G__23277$jscomp$inline_2680_x$jscomp$367$$,$y$jscomp$155$$){$G__23276_G__23277$jscomp$inline_2680_x$jscomp$367$$=$h$jscomp$70$$.$cljs$core$IFn$_invoke$arity$2$?$h$jscomp$70$$.$cljs$core$IFn$_invoke$arity$2$($G__23276_G__23277$jscomp$inline_2680_x$jscomp$367$$,$y$jscomp$155$$):$h$jscomp$70$$($G__23276_G__23277$jscomp$inline_2680_x$jscomp$367$$,$y$jscomp$155$$);$G__23276_G__23277$jscomp$inline_2680_x$jscomp$367$$=$g$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$?$g$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$($G__23276_G__23277$jscomp$inline_2680_x$jscomp$367$$):
$g$jscomp$62$$($G__23276_G__23277$jscomp$inline_2680_x$jscomp$367$$);return $f$jscomp$185$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$185$$.$cljs$core$IFn$_invoke$arity$1$($G__23276_G__23277$jscomp$inline_2680_x$jscomp$367$$):$f$jscomp$185$$($G__23276_G__23277$jscomp$inline_2680_x$jscomp$367$$)}function $G__26205__1$$($G__23274_G__23275$jscomp$inline_2678_x$jscomp$366$$){$G__23274_G__23275$jscomp$inline_2678_x$jscomp$366$$=$h$jscomp$70$$.$cljs$core$IFn$_invoke$arity$1$?$h$jscomp$70$$.$cljs$core$IFn$_invoke$arity$1$($G__23274_G__23275$jscomp$inline_2678_x$jscomp$366$$):
$h$jscomp$70$$($G__23274_G__23275$jscomp$inline_2678_x$jscomp$366$$);$G__23274_G__23275$jscomp$inline_2678_x$jscomp$366$$=$g$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$?$g$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$($G__23274_G__23275$jscomp$inline_2678_x$jscomp$366$$):$g$jscomp$62$$($G__23274_G__23275$jscomp$inline_2678_x$jscomp$366$$);return $f$jscomp$185$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$185$$.$cljs$core$IFn$_invoke$arity$1$($G__23274_G__23275$jscomp$inline_2678_x$jscomp$366$$):$f$jscomp$185$$($G__23274_G__23275$jscomp$inline_2678_x$jscomp$366$$)}
function $G__26205__0$$(){var $G__23272_G__23273$jscomp$inline_2676$$=$h$jscomp$70$$.$cljs$core$IFn$_invoke$arity$0$?$h$jscomp$70$$.$cljs$core$IFn$_invoke$arity$0$():$h$jscomp$70$$();$G__23272_G__23273$jscomp$inline_2676$$=$g$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$?$g$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$($G__23272_G__23273$jscomp$inline_2676$$):$g$jscomp$62$$($G__23272_G__23273$jscomp$inline_2676$$);return $f$jscomp$185$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$185$$.$cljs$core$IFn$_invoke$arity$1$($G__23272_G__23273$jscomp$inline_2676$$):
$f$jscomp$185$$($G__23272_G__23273$jscomp$inline_2676$$)}var $G__26205$$=null,$G__26205__4$$=function(){function $G__26208$$($x$jscomp$370$$,$y$jscomp$158$$,$z$jscomp$25$$,$var_args$jscomp$170$$){var $G__26217__i_args$jscomp$36$$=null;if(arguments.length>3){$G__26217__i_args$jscomp$36$$=0;for(var $G__26217__a$$=Array(arguments.length-3);$G__26217__i_args$jscomp$36$$<$G__26217__a$$.length;)$G__26217__a$$[$G__26217__i_args$jscomp$36$$]=arguments[$G__26217__i_args$jscomp$36$$+3],++$G__26217__i_args$jscomp$36$$;
$G__26217__i_args$jscomp$36$$=new $APP.$cljs$core$IndexedSeq$$($G__26217__a$$,0,null)}return $G__26208__delegate$$.call(this,$x$jscomp$370$$,$y$jscomp$158$$,$z$jscomp$25$$,$G__26217__i_args$jscomp$36$$)}function $G__26208__delegate$$($G__23280_G__23281$jscomp$inline_2684_x$jscomp$369$$,$y$jscomp$157$$,$z$jscomp$24$$,$args$jscomp$35$$){$G__23280_G__23281$jscomp$inline_2684_x$jscomp$369$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($h$jscomp$70$$,$G__23280_G__23281$jscomp$inline_2684_x$jscomp$369$$,
$y$jscomp$157$$,$z$jscomp$24$$,$args$jscomp$35$$);$G__23280_G__23281$jscomp$inline_2684_x$jscomp$369$$=$g$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$?$g$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$($G__23280_G__23281$jscomp$inline_2684_x$jscomp$369$$):$g$jscomp$62$$($G__23280_G__23281$jscomp$inline_2684_x$jscomp$369$$);return $f$jscomp$185$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$185$$.$cljs$core$IFn$_invoke$arity$1$($G__23280_G__23281$jscomp$inline_2684_x$jscomp$369$$):$f$jscomp$185$$($G__23280_G__23281$jscomp$inline_2684_x$jscomp$369$$)}
$G__26208$$.$cljs$lang$maxFixedArity$=3;$G__26208$$.$cljs$lang$applyTo$=function($arglist__26230_args$jscomp$37$$){var $x$jscomp$371$$=$APP.$cljs$core$first$$($arglist__26230_args$jscomp$37$$);$arglist__26230_args$jscomp$37$$=$APP.$cljs$core$next$$($arglist__26230_args$jscomp$37$$);var $y$jscomp$159$$=$APP.$cljs$core$first$$($arglist__26230_args$jscomp$37$$);$arglist__26230_args$jscomp$37$$=$APP.$cljs$core$next$$($arglist__26230_args$jscomp$37$$);var $z$jscomp$26$$=$APP.$cljs$core$first$$($arglist__26230_args$jscomp$37$$);
$arglist__26230_args$jscomp$37$$=$APP.$cljs$core$rest$$($arglist__26230_args$jscomp$37$$);return $G__26208__delegate$$($x$jscomp$371$$,$y$jscomp$159$$,$z$jscomp$26$$,$arglist__26230_args$jscomp$37$$)};$G__26208$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26208__delegate$$;return $G__26208$$}();$G__26205$$=function($x$jscomp$372$$,$y$jscomp$160$$,$z$jscomp$27$$,$var_args$jscomp$171$$){switch(arguments.length){case 0:return $G__26205__0$$.call(this);case 1:return $G__26205__1$$.call(this,$x$jscomp$372$$);
case 2:return $G__26205__2$$.call(this,$x$jscomp$372$$,$y$jscomp$160$$);case 3:return $G__26205__3$$.call(this,$x$jscomp$372$$,$y$jscomp$160$$,$z$jscomp$27$$);default:var $G__26231_G__26232__i$$=null;if(arguments.length>3){$G__26231_G__26232__i$$=0;for(var $G__26232__a$$=Array(arguments.length-3);$G__26231_G__26232__i$$<$G__26232__a$$.length;)$G__26232__a$$[$G__26231_G__26232__i$$]=arguments[$G__26231_G__26232__i$$+3],++$G__26231_G__26232__i$$;$G__26231_G__26232__i$$=new $APP.$cljs$core$IndexedSeq$$($G__26232__a$$,
0,null)}return $G__26205__4$$.$cljs$core$IFn$_invoke$arity$variadic$($x$jscomp$372$$,$y$jscomp$160$$,$z$jscomp$27$$,$G__26231_G__26232__i$$)}throw Error("Invalid arity: "+arguments.length);};$G__26205$$.$cljs$lang$maxFixedArity$=3;$G__26205$$.$cljs$lang$applyTo$=$G__26205__4$$.$cljs$lang$applyTo$;$G__26205$$.$cljs$core$IFn$_invoke$arity$0$=$G__26205__0$$;$G__26205$$.$cljs$core$IFn$_invoke$arity$1$=$G__26205__1$$;$G__26205$$.$cljs$core$IFn$_invoke$arity$2$=$G__26205__2$$;$G__26205$$.$cljs$core$IFn$_invoke$arity$3$=
$G__26205__3$$;$G__26205$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26205__4$$.$cljs$core$IFn$_invoke$arity$variadic$;return $G__26205$$}()};
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$variadic$=function($f1$$,$f2$$,$f3$$,$fs$$){var $fs__$1$$=$APP.$cljs$core$reverse$$($APP.$cljs$core$cons$$($f1$$,$APP.$cljs$core$cons$$($f2$$,$APP.$cljs$core$cons$$($f3$$,$fs$$))));return function(){function $G__26233$$($var_args$jscomp$172$$){var $G__26237__i_args$jscomp$40$$=null;if(arguments.length>0){$G__26237__i_args$jscomp$40$$=0;for(var $G__26237__a$$=Array(arguments.length-0);$G__26237__i_args$jscomp$40$$<$G__26237__a$$.length;)$G__26237__a$$[$G__26237__i_args$jscomp$40$$]=
arguments[$G__26237__i_args$jscomp$40$$+0],++$G__26237__i_args$jscomp$40$$;$G__26237__i_args$jscomp$40$$=new $APP.$cljs$core$IndexedSeq$$($G__26237__a$$,0,null)}return $G__26233__delegate$$.call(this,$G__26237__i_args$jscomp$40$$)}function $G__26233__delegate$$($G__26234_args$jscomp$39_ret$jscomp$13$$){$G__26234_args$jscomp$39_ret$jscomp$13$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($fs__$1$$),$G__26234_args$jscomp$39_ret$jscomp$13$$);for(var $G__26235_fs__$2$$=
$APP.$cljs$core$next$$($fs__$1$$);;)if($G__26235_fs__$2$$){var $fexpr__23282$jscomp$inline_2686$$=$APP.$cljs$core$first$$($G__26235_fs__$2$$);$G__26234_args$jscomp$39_ret$jscomp$13$$=$fexpr__23282$jscomp$inline_2686$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__23282$jscomp$inline_2686$$.$cljs$core$IFn$_invoke$arity$1$($G__26234_args$jscomp$39_ret$jscomp$13$$):$fexpr__23282$jscomp$inline_2686$$($G__26234_args$jscomp$39_ret$jscomp$13$$);$G__26235_fs__$2$$=$APP.$cljs$core$next$$($G__26235_fs__$2$$)}else return $G__26234_args$jscomp$39_ret$jscomp$13$$}
$G__26233$$.$cljs$lang$maxFixedArity$=0;$G__26233$$.$cljs$lang$applyTo$=function($arglist__26238_args$jscomp$41$$){$arglist__26238_args$jscomp$41$$=$APP.$cljs$core$seq$$($arglist__26238_args$jscomp$41$$);return $G__26233__delegate$$($arglist__26238_args$jscomp$41$$)};$G__26233$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26233__delegate$$;return $G__26233$$}()};
$APP.$cljs$core$comp$$.$cljs$lang$applyTo$=function($G__23264_seq23262$$){var $G__23263$$=$APP.$cljs$core$first$$($G__23264_seq23262$$),$G__23265_seq23262__$1$$=$APP.$cljs$core$next$$($G__23264_seq23262$$);$G__23264_seq23262$$=$APP.$cljs$core$first$$($G__23265_seq23262__$1$$);var $seq23262__$2_seq23262__$3$$=$APP.$cljs$core$next$$($G__23265_seq23262__$1$$);$G__23265_seq23262__$1$$=$APP.$cljs$core$first$$($seq23262__$2_seq23262__$3$$);$seq23262__$2_seq23262__$3$$=$APP.$cljs$core$next$$($seq23262__$2_seq23262__$3$$);
return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23263$$,$G__23264_seq23262$$,$G__23265_seq23262__$1$$,$seq23262__$2_seq23262__$3$$)};$APP.$cljs$core$comp$$.$cljs$lang$maxFixedArity$=3;$APP.$JSCompiler_prototypeAlias$$=$cljs$core$Atom$$.prototype;$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$67$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$67$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($o$jscomp$94$$,$other$jscomp$68$$){return this===$other$jscomp$68$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDeref$_deref$arity$1$=function(){return this.state};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWatchable$_notify_watches$arity$3$=function($G__26508_seq__23326_seq__23326__$1_temp__5825__auto__$jscomp$3_this$$jscomp$83$$,$oldval$jscomp$2$$,$newval$jscomp$2$$){$G__26508_seq__23326_seq__23326__$1_temp__5825__auto__$jscomp$3_this$$jscomp$83$$=$APP.$cljs$core$seq$$(this.$watches$);for(var $c__5548__auto___chunk__23327_vec__23339$$=null,$G__26510_count__23328$$=0,$i__23329$$=0;;)if($i__23329$$<$G__26510_count__23328$$){var $f$jscomp$198_vec__23336$$=
$c__5548__auto___chunk__23327_vec__23339$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__23329$$),$G__26509_key$jscomp$122$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$198_vec__23336$$,0,null);$f$jscomp$198_vec__23336$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$198_vec__23336$$,1,null);$f$jscomp$198_vec__23336$$.$cljs$core$IFn$_invoke$arity$4$?$f$jscomp$198_vec__23336$$.$cljs$core$IFn$_invoke$arity$4$($G__26509_key$jscomp$122$$,this,$oldval$jscomp$2$$,
$newval$jscomp$2$$):$f$jscomp$198_vec__23336$$($G__26509_key$jscomp$122$$,this,$oldval$jscomp$2$$,$newval$jscomp$2$$);$i__23329$$+=1}else if($G__26508_seq__23326_seq__23326__$1_temp__5825__auto__$jscomp$3_this$$jscomp$83$$=$APP.$cljs$core$seq$$($G__26508_seq__23326_seq__23326__$1_temp__5825__auto__$jscomp$3_this$$jscomp$83$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__26508_seq__23326_seq__23326__$1_temp__5825__auto__$jscomp$3_this$$jscomp$83$$)?($c__5548__auto___chunk__23327_vec__23339$$=$APP.$cljs$core$_chunked_first$$($G__26508_seq__23326_seq__23326__$1_temp__5825__auto__$jscomp$3_this$$jscomp$83$$),
$G__26508_seq__23326_seq__23326__$1_temp__5825__auto__$jscomp$3_this$$jscomp$83$$=$APP.$cljs$core$_chunked_rest$$($G__26508_seq__23326_seq__23326__$1_temp__5825__auto__$jscomp$3_this$$jscomp$83$$),$G__26509_key$jscomp$122$$=$c__5548__auto___chunk__23327_vec__23339$$,$G__26510_count__23328$$=$APP.$cljs$core$count$$($c__5548__auto___chunk__23327_vec__23339$$),$c__5548__auto___chunk__23327_vec__23339$$=$G__26509_key$jscomp$122$$):($c__5548__auto___chunk__23327_vec__23339$$=$APP.$cljs$core$first$$($G__26508_seq__23326_seq__23326__$1_temp__5825__auto__$jscomp$3_this$$jscomp$83$$),
$G__26509_key$jscomp$122$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto___chunk__23327_vec__23339$$,0,null),$f$jscomp$198_vec__23336$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto___chunk__23327_vec__23339$$,1,null),$f$jscomp$198_vec__23336$$.$cljs$core$IFn$_invoke$arity$4$?$f$jscomp$198_vec__23336$$.$cljs$core$IFn$_invoke$arity$4$($G__26509_key$jscomp$122$$,this,$oldval$jscomp$2$$,$newval$jscomp$2$$):$f$jscomp$198_vec__23336$$($G__26509_key$jscomp$122$$,
this,$oldval$jscomp$2$$,$newval$jscomp$2$$),$G__26508_seq__23326_seq__23326__$1_temp__5825__auto__$jscomp$3_this$$jscomp$83$$=$APP.$cljs$core$next$$($G__26508_seq__23326_seq__23326__$1_temp__5825__auto__$jscomp$3_this$$jscomp$83$$),$c__5548__auto___chunk__23327_vec__23339$$=null,$G__26510_count__23328$$=0),$i__23329$$=0;else return null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWatchable$_add_watch$arity$3$=function($this$$jscomp$84$$,$key$jscomp$123$$,$f$jscomp$199$$){this.$watches$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$watches$,$key$jscomp$123$$,$f$jscomp$199$$);return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWatchable$_remove_watch$arity$2$=function($this$$jscomp$85$$,$key$jscomp$124$$){return this.$watches$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$watches$,$key$jscomp$124$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $goog$getUid$$(this)};
$APP.$cljs$core$swap_BANG_$$=function $cljs$core$swap_BANG_$$($var_args$jscomp$191$$){switch(arguments.length){case 2:return $cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);default:for(var $args_arr__5774__auto__$jscomp$50$$=[],$len__5749__auto___26574$$=
arguments.length,$i__5750__auto___26575$$=0;;)if($i__5750__auto___26575$$<$len__5749__auto___26574$$)$args_arr__5774__auto__$jscomp$50$$.push(arguments[$i__5750__auto___26575$$]),$i__5750__auto___26575$$+=1;else break;return $cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],arguments[3],4<$args_arr__5774__auto__$jscomp$50$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$50$$.slice(4),0,null):null)}};
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$=function($JSCompiler_temp$jscomp$158_a$jscomp$147$$,$JSCompiler_inline_result$jscomp$159_f$jscomp$200$$){if($JSCompiler_temp$jscomp$158_a$jscomp$147$$ instanceof $cljs$core$Atom$$){var $G__23355$jscomp$inline_2690$$=$JSCompiler_temp$jscomp$158_a$jscomp$147$$.state;$JSCompiler_inline_result$jscomp$159_f$jscomp$200$$=$JSCompiler_inline_result$jscomp$159_f$jscomp$200$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$159_f$jscomp$200$$.$cljs$core$IFn$_invoke$arity$1$($G__23355$jscomp$inline_2690$$):
$JSCompiler_inline_result$jscomp$159_f$jscomp$200$$($G__23355$jscomp$inline_2690$$);$JSCompiler_temp$jscomp$158_a$jscomp$147$$=$APP.$cljs$core$reset_BANG_$$($JSCompiler_temp$jscomp$158_a$jscomp$147$$,$JSCompiler_inline_result$jscomp$159_f$jscomp$200$$)}else $JSCompiler_temp$jscomp$158_a$jscomp$147$$=$cljs$core$_swap_BANG_$$($JSCompiler_temp$jscomp$158_a$jscomp$147$$,$JSCompiler_inline_result$jscomp$159_f$jscomp$200$$);return $JSCompiler_temp$jscomp$158_a$jscomp$147$$};
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$=function($JSCompiler_temp$jscomp$160_a$jscomp$148$$,$JSCompiler_inline_result$jscomp$161_f$jscomp$201$$,$x$jscomp$400$$){if($JSCompiler_temp$jscomp$160_a$jscomp$148$$ instanceof $cljs$core$Atom$$){var $G__23356$jscomp$inline_2692$$=$JSCompiler_temp$jscomp$160_a$jscomp$148$$.state;$JSCompiler_inline_result$jscomp$161_f$jscomp$201$$=$JSCompiler_inline_result$jscomp$161_f$jscomp$201$$.$cljs$core$IFn$_invoke$arity$2$?$JSCompiler_inline_result$jscomp$161_f$jscomp$201$$.$cljs$core$IFn$_invoke$arity$2$($G__23356$jscomp$inline_2692$$,
$x$jscomp$400$$):$JSCompiler_inline_result$jscomp$161_f$jscomp$201$$($G__23356$jscomp$inline_2692$$,$x$jscomp$400$$);$JSCompiler_temp$jscomp$160_a$jscomp$148$$=$APP.$cljs$core$reset_BANG_$$($JSCompiler_temp$jscomp$160_a$jscomp$148$$,$JSCompiler_inline_result$jscomp$161_f$jscomp$201$$)}else $JSCompiler_temp$jscomp$160_a$jscomp$148$$=$cljs$core$_swap_BANG_$$($JSCompiler_temp$jscomp$160_a$jscomp$148$$,$JSCompiler_inline_result$jscomp$161_f$jscomp$201$$,$x$jscomp$400$$);return $JSCompiler_temp$jscomp$160_a$jscomp$148$$};
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$=function($JSCompiler_temp$jscomp$162_a$jscomp$149$$,$JSCompiler_inline_result$jscomp$163_f$jscomp$202$$,$x$jscomp$401$$,$y$jscomp$181$$){if($JSCompiler_temp$jscomp$162_a$jscomp$149$$ instanceof $cljs$core$Atom$$){var $G__23358$jscomp$inline_2694$$=$JSCompiler_temp$jscomp$162_a$jscomp$149$$.state;$JSCompiler_inline_result$jscomp$163_f$jscomp$202$$=$JSCompiler_inline_result$jscomp$163_f$jscomp$202$$.$cljs$core$IFn$_invoke$arity$3$?$JSCompiler_inline_result$jscomp$163_f$jscomp$202$$.$cljs$core$IFn$_invoke$arity$3$($G__23358$jscomp$inline_2694$$,
$x$jscomp$401$$,$y$jscomp$181$$):$JSCompiler_inline_result$jscomp$163_f$jscomp$202$$($G__23358$jscomp$inline_2694$$,$x$jscomp$401$$,$y$jscomp$181$$);$JSCompiler_temp$jscomp$162_a$jscomp$149$$=$APP.$cljs$core$reset_BANG_$$($JSCompiler_temp$jscomp$162_a$jscomp$149$$,$JSCompiler_inline_result$jscomp$163_f$jscomp$202$$)}else $JSCompiler_temp$jscomp$162_a$jscomp$149$$=$cljs$core$_swap_BANG_$$($JSCompiler_temp$jscomp$162_a$jscomp$149$$,$JSCompiler_inline_result$jscomp$163_f$jscomp$202$$,$x$jscomp$401$$,
$y$jscomp$181$$);return $JSCompiler_temp$jscomp$162_a$jscomp$149$$};
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($a$jscomp$150$$,$f$jscomp$203$$,$x$jscomp$402$$,$y$jscomp$182$$,$more$jscomp$30$$){return $a$jscomp$150$$ instanceof $cljs$core$Atom$$?$APP.$cljs$core$reset_BANG_$$($a$jscomp$150$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($f$jscomp$203$$,$a$jscomp$150$$.state,$x$jscomp$402$$,$y$jscomp$182$$,$more$jscomp$30$$)):$cljs$core$_swap_BANG_$$($a$jscomp$150$$,$f$jscomp$203$$,$x$jscomp$402$$,$y$jscomp$182$$,$more$jscomp$30$$)};
$APP.$cljs$core$swap_BANG_$$.$cljs$lang$applyTo$=function($G__23351_seq23349$$){var $G__23350$$=$APP.$cljs$core$first$$($G__23351_seq23349$$),$G__23352_seq23349__$1$$=$APP.$cljs$core$next$$($G__23351_seq23349$$);$G__23351_seq23349$$=$APP.$cljs$core$first$$($G__23352_seq23349__$1$$);var $G__23353_seq23349__$2$$=$APP.$cljs$core$next$$($G__23352_seq23349__$1$$);$G__23352_seq23349__$1$$=$APP.$cljs$core$first$$($G__23353_seq23349__$2$$);var $seq23349__$3_seq23349__$4$$=$APP.$cljs$core$next$$($G__23353_seq23349__$2$$);
$G__23353_seq23349__$2$$=$APP.$cljs$core$first$$($seq23349__$3_seq23349__$4$$);$seq23349__$3_seq23349__$4$$=$APP.$cljs$core$next$$($seq23349__$3_seq23349__$4$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23350$$,$G__23351_seq23349$$,$G__23352_seq23349__$1$$,$G__23353_seq23349__$2$$,$seq23349__$3_seq23349__$4$$)};$APP.$cljs$core$swap_BANG_$$.$cljs$lang$maxFixedArity$=4;
$cljs$core$Volatile$$.prototype.$cljs$core$IVolatile$_vreset_BANG_$arity$2$=function($_$jscomp$102$$,$new_state$$){return this.state=$new_state$$};$cljs$core$Volatile$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.state};
$APP.$cljs$core$map$$=function $cljs$core$map$$($var_args$jscomp$212$$){switch(arguments.length){case 1:return $cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $cljs$core$map$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);default:for(var $args_arr__5774__auto__$jscomp$54$$=
[],$len__5749__auto___26987$$=arguments.length,$i__5750__auto___26988$$=0;;)if($i__5750__auto___26988$$<$len__5749__auto___26987$$)$args_arr__5774__auto__$jscomp$54$$.push(arguments[$i__5750__auto___26988$$]),$i__5750__auto___26988$$+=1;else break;return $cljs$core$map$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],arguments[3],4<$args_arr__5774__auto__$jscomp$54$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$54$$.slice(4),0,null):null)}};
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$=function($f$jscomp$210$$){return function($rf$jscomp$3$$){return function(){function $G__26998__2$$($result$jscomp$32$$,$G__23418_input$jscomp$17$$){$G__23418_input$jscomp$17$$=$f$jscomp$210$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$210$$.$cljs$core$IFn$_invoke$arity$1$($G__23418_input$jscomp$17$$):$f$jscomp$210$$($G__23418_input$jscomp$17$$);return $rf$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$32$$,
$G__23418_input$jscomp$17$$):$rf$jscomp$3$$($result$jscomp$32$$,$G__23418_input$jscomp$17$$)}function $G__26998__1$$($result$jscomp$31$$){return $rf$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$31$$):$rf$jscomp$3$$($result$jscomp$31$$)}function $G__26998__0$$(){return $rf$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$rf$jscomp$3$$()}var $G__26998$$=null,$G__26998__3$$=function(){function $G__27003$$($result$jscomp$34$$,
$input$jscomp$19$$,$var_args$jscomp$213$$){var $G__27006__i_inputs$jscomp$2$$=null;if(arguments.length>2){$G__27006__i_inputs$jscomp$2$$=0;for(var $G__27006__a$$=Array(arguments.length-2);$G__27006__i_inputs$jscomp$2$$<$G__27006__a$$.length;)$G__27006__a$$[$G__27006__i_inputs$jscomp$2$$]=arguments[$G__27006__i_inputs$jscomp$2$$+2],++$G__27006__i_inputs$jscomp$2$$;$G__27006__i_inputs$jscomp$2$$=new $APP.$cljs$core$IndexedSeq$$($G__27006__a$$,0,null)}return $G__27003__delegate$$.call(this,$result$jscomp$34$$,
$input$jscomp$19$$,$G__27006__i_inputs$jscomp$2$$)}function $G__27003__delegate$$($result$jscomp$33$$,$G__23420_input$jscomp$18$$,$inputs$jscomp$1$$){$G__23420_input$jscomp$18$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($f$jscomp$210$$,$G__23420_input$jscomp$18$$,$inputs$jscomp$1$$);return $rf$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$33$$,$G__23420_input$jscomp$18$$):$rf$jscomp$3$$($result$jscomp$33$$,$G__23420_input$jscomp$18$$)}
$G__27003$$.$cljs$lang$maxFixedArity$=2;$G__27003$$.$cljs$lang$applyTo$=function($arglist__27008_inputs$jscomp$3$$){var $result$jscomp$35$$=$APP.$cljs$core$first$$($arglist__27008_inputs$jscomp$3$$);$arglist__27008_inputs$jscomp$3$$=$APP.$cljs$core$next$$($arglist__27008_inputs$jscomp$3$$);var $input$jscomp$20$$=$APP.$cljs$core$first$$($arglist__27008_inputs$jscomp$3$$);$arglist__27008_inputs$jscomp$3$$=$APP.$cljs$core$rest$$($arglist__27008_inputs$jscomp$3$$);return $G__27003__delegate$$($result$jscomp$35$$,
$input$jscomp$20$$,$arglist__27008_inputs$jscomp$3$$)};$G__27003$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__27003__delegate$$;return $G__27003$$}();$G__26998$$=function($result$jscomp$36$$,$input$jscomp$21$$,$var_args$jscomp$214$$){switch(arguments.length){case 0:return $G__26998__0$$.call(this);case 1:return $G__26998__1$$.call(this,$result$jscomp$36$$);case 2:return $G__26998__2$$.call(this,$result$jscomp$36$$,$input$jscomp$21$$);default:var $G__27012_G__27013__i$$=null;if(arguments.length>2){$G__27012_G__27013__i$$=
0;for(var $G__27013__a$$=Array(arguments.length-2);$G__27012_G__27013__i$$<$G__27013__a$$.length;)$G__27013__a$$[$G__27012_G__27013__i$$]=arguments[$G__27012_G__27013__i$$+2],++$G__27012_G__27013__i$$;$G__27012_G__27013__i$$=new $APP.$cljs$core$IndexedSeq$$($G__27013__a$$,0,null)}return $G__26998__3$$.$cljs$core$IFn$_invoke$arity$variadic$($result$jscomp$36$$,$input$jscomp$21$$,$G__27012_G__27013__i$$)}throw Error("Invalid arity: "+arguments.length);};$G__26998$$.$cljs$lang$maxFixedArity$=2;$G__26998$$.$cljs$lang$applyTo$=
$G__26998__3$$.$cljs$lang$applyTo$;$G__26998$$.$cljs$core$IFn$_invoke$arity$0$=$G__26998__0$$;$G__26998$$.$cljs$core$IFn$_invoke$arity$1$=$G__26998__1$$;$G__26998$$.$cljs$core$IFn$_invoke$arity$2$=$G__26998__2$$;$G__26998$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__26998__3$$.$cljs$core$IFn$_invoke$arity$variadic$;return $G__26998$$}()}};
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$=function($f$jscomp$211$$,$coll$jscomp$281$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $temp__5825__auto__$jscomp$5$$=$APP.$cljs$core$seq$$($coll$jscomp$281$$);if($temp__5825__auto__$jscomp$5$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($temp__5825__auto__$jscomp$5$$)){for(var $c$jscomp$107$$=$APP.$cljs$core$_chunked_first$$($temp__5825__auto__$jscomp$5$$),$size$jscomp$33$$=$APP.$cljs$core$count$$($c$jscomp$107$$),$b$jscomp$131$$=
$APP.$cljs$core$chunk_buffer$$($size$jscomp$33$$),$i_27021$$=0;;)if($i_27021$$<$size$jscomp$33$$)$APP.$cljs$core$chunk_append$$($b$jscomp$131$$,function(){var $G__23421$$=$APP.$cljs$core$_nth$$($c$jscomp$107$$,$i_27021$$);return $f$jscomp$211$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$211$$.$cljs$core$IFn$_invoke$arity$1$($G__23421$$):$f$jscomp$211$$($G__23421$$)}()),$i_27021$$+=1;else break;return $APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b$jscomp$131$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$211$$,
$APP.$cljs$core$_chunked_rest$$($temp__5825__auto__$jscomp$5$$)))}return $APP.$cljs$core$cons$$(function(){var $G__23422$$=$APP.$cljs$core$first$$($temp__5825__auto__$jscomp$5$$);return $f$jscomp$211$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$211$$.$cljs$core$IFn$_invoke$arity$1$($G__23422$$):$f$jscomp$211$$($G__23422$$)}(),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$211$$,$APP.$cljs$core$rest$$($temp__5825__auto__$jscomp$5$$)))}return null},null,null)};
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$=function($f$jscomp$212$$,$c1$jscomp$1$$,$c2$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $JSCompiler_temp$jscomp$165_s1$$=$APP.$cljs$core$seq$$($c1$jscomp$1$$),$s2$$=$APP.$cljs$core$seq$$($c2$$);if($JSCompiler_temp$jscomp$165_s1$$&&$s2$$){var $G__23423$jscomp$inline_2698_JSCompiler_inline_result$jscomp$166$$=$APP.$cljs$core$first$$($JSCompiler_temp$jscomp$165_s1$$);var $G__23424$jscomp$inline_2699$$=$APP.$cljs$core$first$$($s2$$);
$G__23423$jscomp$inline_2698_JSCompiler_inline_result$jscomp$166$$=$f$jscomp$212$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$212$$.$cljs$core$IFn$_invoke$arity$2$($G__23423$jscomp$inline_2698_JSCompiler_inline_result$jscomp$166$$,$G__23424$jscomp$inline_2699$$):$f$jscomp$212$$($G__23423$jscomp$inline_2698_JSCompiler_inline_result$jscomp$166$$,$G__23424$jscomp$inline_2699$$);$JSCompiler_temp$jscomp$165_s1$$=$APP.$cljs$core$cons$$($G__23423$jscomp$inline_2698_JSCompiler_inline_result$jscomp$166$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($f$jscomp$212$$,
$APP.$cljs$core$rest$$($JSCompiler_temp$jscomp$165_s1$$),$APP.$cljs$core$rest$$($s2$$)))}else $JSCompiler_temp$jscomp$165_s1$$=null;return $JSCompiler_temp$jscomp$165_s1$$},null,null)};
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$4$=function($f$jscomp$213$$,$c1$jscomp$2$$,$c2$jscomp$1$$,$c3$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $JSCompiler_temp$jscomp$167_s1$jscomp$1$$=$APP.$cljs$core$seq$$($c1$jscomp$2$$),$s2$jscomp$1$$=$APP.$cljs$core$seq$$($c2$jscomp$1$$),$s3$$=$APP.$cljs$core$seq$$($c3$$);if($JSCompiler_temp$jscomp$167_s1$jscomp$1$$&&$s2$jscomp$1$$&&$s3$$){var $G__23425$jscomp$inline_2701_JSCompiler_inline_result$jscomp$168$$=$APP.$cljs$core$first$$($JSCompiler_temp$jscomp$167_s1$jscomp$1$$);
var $G__23426$jscomp$inline_2702$$=$APP.$cljs$core$first$$($s2$jscomp$1$$),$G__23427$jscomp$inline_2703$$=$APP.$cljs$core$first$$($s3$$);$G__23425$jscomp$inline_2701_JSCompiler_inline_result$jscomp$168$$=$f$jscomp$213$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$213$$.$cljs$core$IFn$_invoke$arity$3$($G__23425$jscomp$inline_2701_JSCompiler_inline_result$jscomp$168$$,$G__23426$jscomp$inline_2702$$,$G__23427$jscomp$inline_2703$$):$f$jscomp$213$$($G__23425$jscomp$inline_2701_JSCompiler_inline_result$jscomp$168$$,
$G__23426$jscomp$inline_2702$$,$G__23427$jscomp$inline_2703$$);$JSCompiler_temp$jscomp$167_s1$jscomp$1$$=$APP.$cljs$core$cons$$($G__23425$jscomp$inline_2701_JSCompiler_inline_result$jscomp$168$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$4$($f$jscomp$213$$,$APP.$cljs$core$rest$$($JSCompiler_temp$jscomp$167_s1$jscomp$1$$),$APP.$cljs$core$rest$$($s2$jscomp$1$$),$APP.$cljs$core$rest$$($s3$$)))}else $JSCompiler_temp$jscomp$167_s1$jscomp$1$$=null;return $JSCompiler_temp$jscomp$167_s1$jscomp$1$$},
null,null)};
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$variadic$=function($f$jscomp$214$$,$c1$jscomp$3$$,$c2$jscomp$2$$,$c3$jscomp$1$$,$colls$jscomp$1$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__23409_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$214$$,$p1__23409_SHARP_$$)},function $cljs$core$step$$($cs$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $ss$jscomp$3$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$,$cs$$);
return $APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$identity$$,$ss$jscomp$3$$)?$APP.$cljs$core$cons$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$ss$jscomp$3$$),$cljs$core$step$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$rest$$,$ss$jscomp$3$$))):null},null,null)}($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($colls$jscomp$1$$,$c3$jscomp$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$c2$jscomp$2$$,
$c1$jscomp$3$$]))))};
$APP.$cljs$core$map$$.$cljs$lang$applyTo$=function($G__23413_seq23411$$){var $G__23412$$=$APP.$cljs$core$first$$($G__23413_seq23411$$),$G__23414_seq23411__$1$$=$APP.$cljs$core$next$$($G__23413_seq23411$$);$G__23413_seq23411$$=$APP.$cljs$core$first$$($G__23414_seq23411__$1$$);var $G__23415_seq23411__$2$$=$APP.$cljs$core$next$$($G__23414_seq23411__$1$$);$G__23414_seq23411__$1$$=$APP.$cljs$core$first$$($G__23415_seq23411__$2$$);var $seq23411__$3_seq23411__$4$$=$APP.$cljs$core$next$$($G__23415_seq23411__$2$$);$G__23415_seq23411__$2$$=
$APP.$cljs$core$first$$($seq23411__$3_seq23411__$4$$);$seq23411__$3_seq23411__$4$$=$APP.$cljs$core$next$$($seq23411__$3_seq23411__$4$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23412$$,$G__23413_seq23411$$,$G__23414_seq23411__$1$$,$G__23415_seq23411__$2$$,$seq23411__$3_seq23411__$4$$)};$APP.$cljs$core$map$$.$cljs$lang$maxFixedArity$=4;
$APP.$cljs$core$take$$=function $cljs$core$take$$($var_args$jscomp$215$$){switch(arguments.length){case 1:return $cljs$core$take$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$1$=function($n$jscomp$89$$){return function($rf$jscomp$4$$){var $na$$=$APP.$cljs$core$volatile_BANG_$$($n$jscomp$89$$);return function(){function $G__27042__2$$($result$jscomp$38_result__$1$$,$input$jscomp$22$$){var $n__$1$jscomp$2$$=$APP.$cljs$core$_deref$$($na$$),$nn$$=$na$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$na$$.$cljs$core$IDeref$_deref$arity$1$(null)-1);$result$jscomp$38_result__$1$$=$n__$1$jscomp$2$$>0?$rf$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?
$rf$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$38_result__$1$$,$input$jscomp$22$$):$rf$jscomp$4$$($result$jscomp$38_result__$1$$,$input$jscomp$22$$):$result$jscomp$38_result__$1$$;return $nn$$>0?$result$jscomp$38_result__$1$$:$cljs$core$reduced_QMARK_$$($result$jscomp$38_result__$1$$)?$result$jscomp$38_result__$1$$:$APP.$cljs$core$reduced$$($result$jscomp$38_result__$1$$)}function $G__27042__1$$($result$jscomp$37$$){return $rf$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$37$$):
$rf$jscomp$4$$($result$jscomp$37$$)}function $G__27042__0$$(){return $rf$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$rf$jscomp$4$$()}var $G__27042$$=null;$G__27042$$=function($result$jscomp$39$$,$input$jscomp$23$$){switch(arguments.length){case 0:return $G__27042__0$$.call(this);case 1:return $G__27042__1$$.call(this,$result$jscomp$39$$);case 2:return $G__27042__2$$.call(this,$result$jscomp$39$$,$input$jscomp$23$$)}throw Error("Invalid arity: "+arguments.length);
};$G__27042$$.$cljs$core$IFn$_invoke$arity$0$=$G__27042__0$$;$G__27042$$.$cljs$core$IFn$_invoke$arity$1$=$G__27042__1$$;$G__27042$$.$cljs$core$IFn$_invoke$arity$2$=$G__27042__2$$;return $G__27042$$}()}};
$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$=function($n$jscomp$90$$,$coll$jscomp$282$$){return new $APP.$cljs$core$LazySeq$$(null,function(){if($n$jscomp$90$$>0){var $temp__5825__auto__$jscomp$6$$=$APP.$cljs$core$seq$$($coll$jscomp$282$$);return $temp__5825__auto__$jscomp$6$$?$APP.$cljs$core$cons$$($APP.$cljs$core$first$$($temp__5825__auto__$jscomp$6$$),$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($n$jscomp$90$$-1,$APP.$cljs$core$rest$$($temp__5825__auto__$jscomp$6$$))):null}return null},
null,null)};$APP.$cljs$core$take$$.$cljs$lang$maxFixedArity$=2;$APP.$JSCompiler_prototypeAlias$$=$cljs$core$Repeat$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$69$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$69$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__27176$$=null;$G__27176$$=function($x$jscomp$467$$,$start$jscomp$60$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$467$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$467$$,$start$jscomp$60$$)}throw Error("Invalid arity: "+arguments.length);};$G__27176$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$465$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$465$$,0)};$G__27176$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$466$$,$start$jscomp$59$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$466$$,$start$jscomp$59$$)};return $G__27176$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__27185__1$$($x$jscomp$468$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$468$$,this.count)}var $G__27185$$=null;$G__27185$$=function($x$jscomp$470$$,$start$jscomp$62$$){switch(arguments.length){case 1:return $G__27185__1$$.call(this,$x$jscomp$470$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$470$$,$start$jscomp$62$$)}throw Error("Invalid arity: "+
arguments.length);};$G__27185$$.$cljs$core$IFn$_invoke$arity$1$=$G__27185__1$$;$G__27185$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$469$$,$start$jscomp$61$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$469$$,$start$jscomp$61$$)};return $G__27185$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return this.next==null?this.count>1?this.next=new $cljs$core$Repeat$$(null,this.count-1,this.$val$,null,null):-1===this.count?this:null:this.next};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$6_h__5134__auto____$1$jscomp$6$$=this.$__hash$;return $h__5134__auto__$jscomp$6_h__5134__auto____$1$jscomp$6$$!=null?$h__5134__auto__$jscomp$6_h__5134__auto____$1$jscomp$6$$:this.$__hash$=$h__5134__auto__$jscomp$6_h__5134__auto____$1$jscomp$6$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$309$$,$other$jscomp$70$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$70$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPending$_realized_QMARK_$arity$1$=function(){return!1};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$312_i$jscomp$199$$,$f$jscomp$217$$){if(this.count===-1)for(var $G__27222_ret$jscomp$16_ret__$1$jscomp$2$$=$f$jscomp$217$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$217$$.$cljs$core$IFn$_invoke$arity$2$(this.$val$,this.$val$):$f$jscomp$217$$(this.$val$,this.$val$);;){if($cljs$core$reduced_QMARK_$$($G__27222_ret$jscomp$16_ret__$1$jscomp$2$$))return $APP.$cljs$core$_deref$$($G__27222_ret$jscomp$16_ret__$1$jscomp$2$$);
$G__27222_ret$jscomp$16_ret__$1$jscomp$2$$=$f$jscomp$217$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$217$$.$cljs$core$IFn$_invoke$arity$2$($G__27222_ret$jscomp$16_ret__$1$jscomp$2$$,this.$val$):$f$jscomp$217$$($G__27222_ret$jscomp$16_ret__$1$jscomp$2$$,this.$val$)}else for($coll$jscomp$312_i$jscomp$199$$=1,$G__27222_ret$jscomp$16_ret__$1$jscomp$2$$=this.$val$;;)if($coll$jscomp$312_i$jscomp$199$$<this.count){$G__27222_ret$jscomp$16_ret__$1$jscomp$2$$=$f$jscomp$217$$.$cljs$core$IFn$_invoke$arity$2$?
$f$jscomp$217$$.$cljs$core$IFn$_invoke$arity$2$($G__27222_ret$jscomp$16_ret__$1$jscomp$2$$,this.$val$):$f$jscomp$217$$($G__27222_ret$jscomp$16_ret__$1$jscomp$2$$,this.$val$);if($cljs$core$reduced_QMARK_$$($G__27222_ret$jscomp$16_ret__$1$jscomp$2$$))return $APP.$cljs$core$_deref$$($G__27222_ret$jscomp$16_ret__$1$jscomp$2$$);$coll$jscomp$312_i$jscomp$199$$+=1}else return $G__27222_ret$jscomp$16_ret__$1$jscomp$2$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$313_i$jscomp$200$$,$f$jscomp$218$$,$G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$){if(this.count===-1)for($G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$=$f$jscomp$218$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$218$$.$cljs$core$IFn$_invoke$arity$2$($G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$,this.$val$):$f$jscomp$218$$($G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$,
this.$val$);;){if($cljs$core$reduced_QMARK_$$($G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$))return $APP.$cljs$core$_deref$$($G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$);$G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$=$f$jscomp$218$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$218$$.$cljs$core$IFn$_invoke$arity$2$($G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$,this.$val$):$f$jscomp$218$$($G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$,this.$val$)}else for($coll$jscomp$313_i$jscomp$200$$=
0;;)if($coll$jscomp$313_i$jscomp$200$$<this.count){$G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$=$f$jscomp$218$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$218$$.$cljs$core$IFn$_invoke$arity$2$($G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$,this.$val$):$f$jscomp$218$$($G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$,this.$val$);if($cljs$core$reduced_QMARK_$$($G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$))return $APP.$cljs$core$_deref$$($G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$);
$coll$jscomp$313_i$jscomp$200$$+=1}else return $G__27226_ret$jscomp$17_ret__$1$jscomp$3_start$jscomp$63$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return this.$val$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){return this.next==null?this.count>1?this.next=new $cljs$core$Repeat$$(null,this.count-1,this.$val$,null,null):-1===this.count?this:$APP.$cljs$core$List$EMPTY$$:this.next};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$317$$,$new_meta$jscomp$11$$){return $new_meta$jscomp$11$$===this.$meta$?this:new $cljs$core$Repeat$$($new_meta$jscomp$11$$,this.count,this.$val$,this.next,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$318$$,$o$jscomp$96$$){return $APP.$cljs$core$cons$$($o$jscomp$96$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDrop$_drop$arity$2$=function($coll$jscomp$319_dropped_count$$,$n$jscomp$96$$){if(this.count===-1)return this;$coll$jscomp$319_dropped_count$$=this.count-$n$jscomp$96$$;return $coll$jscomp$319_dropped_count$$>0?new $cljs$core$Repeat$$(null,$coll$jscomp$319_dropped_count$$,this.$val$,null,null):null};var $cljs$core$UNREALIZED_SEED$$={};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$Iterate$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return this.$cljs$core$ISeq$_rest$arity$1$(null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPending$_realized_QMARK_$arity$1$=function(){return this.seed!==$cljs$core$UNREALIZED_SEED$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($G__27261_coll$jscomp$325_first$jscomp$8_ret$jscomp$18$$,$rf$jscomp$7$$){$G__27261_coll$jscomp$325_first$jscomp$8_ret$jscomp$18$$=this.$cljs$core$ISeq$_first$arity$1$(null);var $G__27262_v$jscomp$16_v__$1$jscomp$1_v__$2$jscomp$1$$=this.f.$cljs$core$IFn$_invoke$arity$1$?this.f.$cljs$core$IFn$_invoke$arity$1$($G__27261_coll$jscomp$325_first$jscomp$8_ret$jscomp$18$$):this.f($G__27261_coll$jscomp$325_first$jscomp$8_ret$jscomp$18$$);
for($G__27261_coll$jscomp$325_first$jscomp$8_ret$jscomp$18$$=$rf$jscomp$7$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$7$$.$cljs$core$IFn$_invoke$arity$2$($G__27261_coll$jscomp$325_first$jscomp$8_ret$jscomp$18$$,$G__27262_v$jscomp$16_v__$1$jscomp$1_v__$2$jscomp$1$$):$rf$jscomp$7$$($G__27261_coll$jscomp$325_first$jscomp$8_ret$jscomp$18$$,$G__27262_v$jscomp$16_v__$1$jscomp$1_v__$2$jscomp$1$$);;){if($cljs$core$reduced_QMARK_$$($G__27261_coll$jscomp$325_first$jscomp$8_ret$jscomp$18$$))return $APP.$cljs$core$_deref$$($G__27261_coll$jscomp$325_first$jscomp$8_ret$jscomp$18$$);
$G__27262_v$jscomp$16_v__$1$jscomp$1_v__$2$jscomp$1$$=this.f.$cljs$core$IFn$_invoke$arity$1$?this.f.$cljs$core$IFn$_invoke$arity$1$($G__27262_v$jscomp$16_v__$1$jscomp$1_v__$2$jscomp$1$$):this.f($G__27262_v$jscomp$16_v__$1$jscomp$1_v__$2$jscomp$1$$);$G__27261_coll$jscomp$325_first$jscomp$8_ret$jscomp$18$$=$rf$jscomp$7$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$7$$.$cljs$core$IFn$_invoke$arity$2$($G__27261_coll$jscomp$325_first$jscomp$8_ret$jscomp$18$$,$G__27262_v$jscomp$16_v__$1$jscomp$1_v__$2$jscomp$1$$):
$rf$jscomp$7$$($G__27261_coll$jscomp$325_first$jscomp$8_ret$jscomp$18$$,$G__27262_v$jscomp$16_v__$1$jscomp$1_v__$2$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($G__27277_coll$jscomp$326_v$jscomp$17_v__$1$jscomp$2_v__$2$jscomp$2$$,$rf$jscomp$8$$,$G__27276_ret$jscomp$19_start$jscomp$64$$){$G__27277_coll$jscomp$326_v$jscomp$17_v__$1$jscomp$2_v__$2$jscomp$2$$=this.$cljs$core$ISeq$_first$arity$1$(null);for($G__27276_ret$jscomp$19_start$jscomp$64$$=$rf$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$($G__27276_ret$jscomp$19_start$jscomp$64$$,
$G__27277_coll$jscomp$326_v$jscomp$17_v__$1$jscomp$2_v__$2$jscomp$2$$):$rf$jscomp$8$$($G__27276_ret$jscomp$19_start$jscomp$64$$,$G__27277_coll$jscomp$326_v$jscomp$17_v__$1$jscomp$2_v__$2$jscomp$2$$);;){if($cljs$core$reduced_QMARK_$$($G__27276_ret$jscomp$19_start$jscomp$64$$))return $APP.$cljs$core$_deref$$($G__27276_ret$jscomp$19_start$jscomp$64$$);$G__27277_coll$jscomp$326_v$jscomp$17_v__$1$jscomp$2_v__$2$jscomp$2$$=this.f.$cljs$core$IFn$_invoke$arity$1$?this.f.$cljs$core$IFn$_invoke$arity$1$($G__27277_coll$jscomp$326_v$jscomp$17_v__$1$jscomp$2_v__$2$jscomp$2$$):
this.f($G__27277_coll$jscomp$326_v$jscomp$17_v__$1$jscomp$2_v__$2$jscomp$2$$);$G__27276_ret$jscomp$19_start$jscomp$64$$=$rf$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$($G__27276_ret$jscomp$19_start$jscomp$64$$,$G__27277_coll$jscomp$326_v$jscomp$17_v__$1$jscomp$2_v__$2$jscomp$2$$):$rf$jscomp$8$$($G__27276_ret$jscomp$19_start$jscomp$64$$,$G__27277_coll$jscomp$326_v$jscomp$17_v__$1$jscomp$2_v__$2$jscomp$2$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){$cljs$core$UNREALIZED_SEED$$===this.seed&&(this.seed=this.f.$cljs$core$IFn$_invoke$arity$1$?this.f.$cljs$core$IFn$_invoke$arity$1$(this.$prev_seed$):this.f(this.$prev_seed$));return this.seed};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){this.next==null&&(this.next=new $cljs$core$Iterate$$(null,this.f,this.$cljs$core$ISeq$_first$arity$1$(null),$cljs$core$UNREALIZED_SEED$$,null));return this.next};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$330$$,$new_meta$jscomp$12$$){return $new_meta$jscomp$12$$===this.$meta$?this:new $cljs$core$Iterate$$($new_meta$jscomp$12$$,this.f,this.$prev_seed$,this.seed,this.next)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$331$$,$o$jscomp$97$$){return $APP.$cljs$core$cons$$($o$jscomp$97$$,this)};
$APP.$cljs$core$interleave$$=function $cljs$core$interleave$$($var_args$jscomp$221$$){switch(arguments.length){case 0:return $cljs$core$interleave$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $cljs$core$interleave$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$interleave$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$55$$=[],$len__5749__auto___27325$$=arguments.length,$i__5750__auto___27326$$=0;;)if($i__5750__auto___27326$$<
$len__5749__auto___27325$$)$args_arr__5774__auto__$jscomp$55$$.push(arguments[$i__5750__auto___27326$$]),$i__5750__auto___27326$$+=1;else break;return $cljs$core$interleave$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$55$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$55$$.slice(2),0,null):null)}};$APP.$cljs$core$interleave$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$cljs$core$List$EMPTY$$};
$APP.$cljs$core$interleave$$.$cljs$core$IFn$_invoke$arity$1$=function($c1$jscomp$4$$){return new $APP.$cljs$core$LazySeq$$(null,function(){return $c1$jscomp$4$$},null,null)};
$APP.$cljs$core$interleave$$.$cljs$core$IFn$_invoke$arity$2$=function($c1$jscomp$5$$,$c2$jscomp$3$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $s1$jscomp$2$$=$APP.$cljs$core$seq$$($c1$jscomp$5$$),$s2$jscomp$2$$=$APP.$cljs$core$seq$$($c2$jscomp$3$$);return $s1$jscomp$2$$&&$s2$jscomp$2$$?$APP.$cljs$core$cons$$($APP.$cljs$core$first$$($s1$jscomp$2$$),$APP.$cljs$core$cons$$($APP.$cljs$core$first$$($s2$jscomp$2$$),$APP.$cljs$core$interleave$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$rest$$($s1$jscomp$2$$),
$APP.$cljs$core$rest$$($s2$jscomp$2$$)))):null},null,null)};
$APP.$cljs$core$interleave$$.$cljs$core$IFn$_invoke$arity$variadic$=function($c1$jscomp$6$$,$c2$jscomp$4$$,$colls$jscomp$2$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $ss$jscomp$4$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($colls$jscomp$2$$,$c2$jscomp$4$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$c1$jscomp$6$$])));return $APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$identity$$,
$ss$jscomp$4$$)?$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$ss$jscomp$4$$),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$interleave$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$rest$$,$ss$jscomp$4$$))):null},null,null)};
$APP.$cljs$core$interleave$$.$cljs$lang$applyTo$=function($G__23451_seq23449$$){var $G__23450$$=$APP.$cljs$core$first$$($G__23451_seq23449$$),$seq23449__$1_seq23449__$2$$=$APP.$cljs$core$next$$($G__23451_seq23449$$);$G__23451_seq23449$$=$APP.$cljs$core$first$$($seq23449__$1_seq23449__$2$$);$seq23449__$1_seq23449__$2$$=$APP.$cljs$core$next$$($seq23449__$1_seq23449__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23450$$,$G__23451_seq23449$$,$seq23449__$1_seq23449__$2$$)};
$APP.$cljs$core$interleave$$.$cljs$lang$maxFixedArity$=2;$APP.$cljs$core$filter$$=function $cljs$core$filter$$($var_args$jscomp$224$$){switch(arguments.length){case 1:return $cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$=function($pred$jscomp$6$$){return function($rf$jscomp$10$$){return function(){function $G__27358__2$$($result$jscomp$50$$,$input$jscomp$30$$){return $APP.$cljs$core$truth_$$($pred$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($input$jscomp$30$$):$pred$jscomp$6$$($input$jscomp$30$$))?$rf$jscomp$10$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$10$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$50$$,
$input$jscomp$30$$):$rf$jscomp$10$$($result$jscomp$50$$,$input$jscomp$30$$):$result$jscomp$50$$}function $G__27358__1$$($result$jscomp$49$$){return $rf$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$49$$):$rf$jscomp$10$$($result$jscomp$49$$)}function $G__27358__0$$(){return $rf$jscomp$10$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$10$$.$cljs$core$IFn$_invoke$arity$0$():$rf$jscomp$10$$()}var $G__27358$$=null;$G__27358$$=function($result$jscomp$51$$,
$input$jscomp$31$$){switch(arguments.length){case 0:return $G__27358__0$$.call(this);case 1:return $G__27358__1$$.call(this,$result$jscomp$51$$);case 2:return $G__27358__2$$.call(this,$result$jscomp$51$$,$input$jscomp$31$$)}throw Error("Invalid arity: "+arguments.length);};$G__27358$$.$cljs$core$IFn$_invoke$arity$0$=$G__27358__0$$;$G__27358$$.$cljs$core$IFn$_invoke$arity$1$=$G__27358__1$$;$G__27358$$.$cljs$core$IFn$_invoke$arity$2$=$G__27358__2$$;return $G__27358$$}()}};
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$=function($pred$jscomp$7$$,$coll$jscomp$334$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $r$jscomp$22_temp__5825__auto__$jscomp$7$$=$APP.$cljs$core$seq$$($coll$jscomp$334$$);if($r$jscomp$22_temp__5825__auto__$jscomp$7$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($r$jscomp$22_temp__5825__auto__$jscomp$7$$)){for(var $c$jscomp$108_f$jscomp$226$$=$APP.$cljs$core$_chunked_first$$($r$jscomp$22_temp__5825__auto__$jscomp$7$$),$size$jscomp$34$$=
$APP.$cljs$core$count$$($c$jscomp$108_f$jscomp$226$$),$b$jscomp$132$$=$APP.$cljs$core$chunk_buffer$$($size$jscomp$34$$),$i_27369$$=0;;)if($i_27369$$<$size$jscomp$34$$){var $G__23461$jscomp$inline_2714_JSCompiler_inline_result$jscomp$171_b$jscomp$inline_11201$$=$APP.$cljs$core$_nth$$($c$jscomp$108_f$jscomp$226$$,$i_27369$$);$G__23461$jscomp$inline_2714_JSCompiler_inline_result$jscomp$171_b$jscomp$inline_11201$$=$pred$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($G__23461$jscomp$inline_2714_JSCompiler_inline_result$jscomp$171_b$jscomp$inline_11201$$):
$pred$jscomp$7$$($G__23461$jscomp$inline_2714_JSCompiler_inline_result$jscomp$171_b$jscomp$inline_11201$$);if($APP.$cljs$core$truth_$$($G__23461$jscomp$inline_2714_JSCompiler_inline_result$jscomp$171_b$jscomp$inline_11201$$)){$G__23461$jscomp$inline_2714_JSCompiler_inline_result$jscomp$171_b$jscomp$inline_11201$$=$b$jscomp$132$$;var $x$jscomp$inline_11202$$=$APP.$cljs$core$_nth$$($c$jscomp$108_f$jscomp$226$$,$i_27369$$);$G__23461$jscomp$inline_2714_JSCompiler_inline_result$jscomp$171_b$jscomp$inline_11201$$.add($x$jscomp$inline_11202$$)}$i_27369$$+=
1}else break;return $APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b$jscomp$132$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($pred$jscomp$7$$,$APP.$cljs$core$_chunked_rest$$($r$jscomp$22_temp__5825__auto__$jscomp$7$$)))}$c$jscomp$108_f$jscomp$226$$=$APP.$cljs$core$first$$($r$jscomp$22_temp__5825__auto__$jscomp$7$$);$r$jscomp$22_temp__5825__auto__$jscomp$7$$=$APP.$cljs$core$rest$$($r$jscomp$22_temp__5825__auto__$jscomp$7$$);return $APP.$cljs$core$truth_$$($pred$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?
$pred$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$108_f$jscomp$226$$):$pred$jscomp$7$$($c$jscomp$108_f$jscomp$226$$))?$APP.$cljs$core$cons$$($c$jscomp$108_f$jscomp$226$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($pred$jscomp$7$$,$r$jscomp$22_temp__5825__auto__$jscomp$7$$)):$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($pred$jscomp$7$$,$r$jscomp$22_temp__5825__auto__$jscomp$7$$)}return null},null,null)};$APP.$cljs$core$filter$$.$cljs$lang$maxFixedArity$=2;
$APP.$cljs$core$remove$$=function $cljs$core$remove$$($var_args$jscomp$225$$){switch(arguments.length){case 1:return $cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$=function($pred$jscomp$8$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$complement$$($pred$jscomp$8$$))};
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$=function($pred$jscomp$9$$,$coll$jscomp$335$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$complement$$($pred$jscomp$9$$),$coll$jscomp$335$$)};$APP.$cljs$core$remove$$.$cljs$lang$maxFixedArity$=2;
$APP.$cljs$core$into$$=function $cljs$core$into$$($var_args$jscomp$226$$){switch(arguments.length){case 0:return $cljs$core$into$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $cljs$core$into$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$cljs$core$PersistentVector$EMPTY$$};$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$1$=function($to$jscomp$2$$){return $to$jscomp$2$$};
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$=function($to$jscomp$3$$,$from$jscomp$2$$){return $to$jscomp$3$$!=null?$to$jscomp$3$$!=null&&($to$jscomp$3$$.$cljs$lang$protocol_mask$partition1$$&4||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$to$jscomp$3$$.$cljs$core$IEditableCollection$$)?$APP.$cljs$core$_with_meta$$($APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($cljs$core$_conj_BANG_$$,$APP.$cljs$core$_as_transient$$($to$jscomp$3$$),$from$jscomp$2$$)),
$APP.$cljs$core$meta$$($to$jscomp$3$$)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,$to$jscomp$3$$,$from$jscomp$2$$):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$to$jscomp$3$$,$from$jscomp$2$$)};
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$=function($to$jscomp$4$$,$xform$jscomp$7$$,$from$jscomp$3$$){if($to$jscomp$4$$!=null&&($to$jscomp$4$$.$cljs$lang$protocol_mask$partition1$$&4||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$to$jscomp$4$$.$cljs$core$IEditableCollection$$)){var $tm$$=$APP.$cljs$core$meta$$($to$jscomp$4$$);return $cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$04$$($xform$jscomp$7$$,function(){function $G__27387__2$$($coll$jscomp$337$$,$v$jscomp$18$$){return $APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($coll$jscomp$337$$,
$v$jscomp$18$$)}function $G__27387__1$$($coll$jscomp$336$$){return $APP.$cljs$core$_with_meta$$($APP.$cljs$core$_persistent_BANG_$$($coll$jscomp$336$$),$tm$$)}var $G__27387$$=null;$G__27387$$=function($coll$jscomp$338$$,$v$jscomp$19$$){switch(arguments.length){case 1:return $G__27387__1$$.call(this,$coll$jscomp$338$$);case 2:return $G__27387__2$$.call(this,$coll$jscomp$338$$,$v$jscomp$19$$)}throw Error("Invalid arity: "+arguments.length);};$G__27387$$.$cljs$core$IFn$_invoke$arity$1$=$G__27387__1$$;
$G__27387$$.$cljs$core$IFn$_invoke$arity$2$=$G__27387__2$$;return $G__27387$$}(),$APP.$cljs$core$_as_transient$$($to$jscomp$4$$),$from$jscomp$3$$)}return $cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$04$$($xform$jscomp$7$$,$APP.$cljs$core$conj$$,$to$jscomp$4$$,$from$jscomp$3$$)};$APP.$cljs$core$into$$.$cljs$lang$maxFixedArity$=3;
$APP.$cljs$core$mapv$$=function $cljs$core$mapv$$($var_args$jscomp$227$$){switch(arguments.length){case 2:return $cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);default:for(var $args_arr__5774__auto__$jscomp$57$$=[],$len__5749__auto___27391$$=arguments.length,
$i__5750__auto___27392$$=0;;)if($i__5750__auto___27392$$<$len__5749__auto___27391$$)$args_arr__5774__auto__$jscomp$57$$.push(arguments[$i__5750__auto___27392$$]),$i__5750__auto___27392$$+=1;else break;return $cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],arguments[3],4<$args_arr__5774__auto__$jscomp$57$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$57$$.slice(4),0,null):null)}};
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$=function($f$jscomp$227$$,$coll$jscomp$339$$){return $APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($v$jscomp$20$$,$o$jscomp$98$$){return $APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$20$$,$f$jscomp$227$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$227$$.$cljs$core$IFn$_invoke$arity$1$($o$jscomp$98$$):$f$jscomp$227$$($o$jscomp$98$$))},$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),
$coll$jscomp$339$$))};$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$3$=function($f$jscomp$228$$,$c1$jscomp$7$$,$c2$jscomp$5$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($f$jscomp$228$$,$c1$jscomp$7$$,$c2$jscomp$5$$))};
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$4$=function($f$jscomp$229$$,$c1$jscomp$8$$,$c2$jscomp$6$$,$c3$jscomp$2$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$4$($f$jscomp$229$$,$c1$jscomp$8$$,$c2$jscomp$6$$,$c3$jscomp$2$$))};
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$variadic$=function($f$jscomp$230$$,$c1$jscomp$9$$,$c2$jscomp$7$$,$c3$jscomp$3$$,$colls$jscomp$5$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$map$$,$f$jscomp$230$$,$c1$jscomp$9$$,$c2$jscomp$7$$,$c3$jscomp$3$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$colls$jscomp$5$$])))};
$APP.$cljs$core$mapv$$.$cljs$lang$applyTo$=function($G__23472_seq23470$$){var $G__23471$$=$APP.$cljs$core$first$$($G__23472_seq23470$$),$G__23473_seq23470__$1$$=$APP.$cljs$core$next$$($G__23472_seq23470$$);$G__23472_seq23470$$=$APP.$cljs$core$first$$($G__23473_seq23470__$1$$);var $G__23474_seq23470__$2$$=$APP.$cljs$core$next$$($G__23473_seq23470__$1$$);$G__23473_seq23470__$1$$=$APP.$cljs$core$first$$($G__23474_seq23470__$2$$);var $seq23470__$3_seq23470__$4$$=$APP.$cljs$core$next$$($G__23474_seq23470__$2$$);
$G__23474_seq23470__$2$$=$APP.$cljs$core$first$$($seq23470__$3_seq23470__$4$$);$seq23470__$3_seq23470__$4$$=$APP.$cljs$core$next$$($seq23470__$3_seq23470__$4$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23471$$,$G__23472_seq23470$$,$G__23473_seq23470__$1$$,$G__23474_seq23470__$2$$,$seq23470__$3_seq23470__$4$$)};$APP.$cljs$core$mapv$$.$cljs$lang$maxFixedArity$=4;
$APP.$cljs$core$get_in$$=function $cljs$core$get_in$$($var_args$jscomp$229$$){switch(arguments.length){case 2:return $cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$=function($G__27411_m$jscomp$39_m__$1$$,$G__27412_ks$jscomp$3_ks__$1$$){for($G__27412_ks$jscomp$3_ks__$1$$=$APP.$cljs$core$seq$$($G__27412_ks$jscomp$3_ks__$1$$);;){if($G__27412_ks$jscomp$3_ks__$1$$==null)return $G__27411_m$jscomp$39_m__$1$$;$G__27411_m$jscomp$39_m__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__27411_m$jscomp$39_m__$1$$,$APP.$cljs$core$first$$($G__27412_ks$jscomp$3_ks__$1$$));$G__27412_ks$jscomp$3_ks__$1$$=$APP.$cljs$core$next$$($G__27412_ks$jscomp$3_ks__$1$$)}};
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$=function($G__27415_m$jscomp$40_m__$1$jscomp$1_m__$2$$,$G__27416_ks$jscomp$4_ks__$1$jscomp$1$$,$not_found$jscomp$13$$){var $G__27414_sentinel$$=$cljs$core$lookup_sentinel$$;for($G__27416_ks$jscomp$4_ks__$1$jscomp$1$$=$APP.$cljs$core$seq$$($G__27416_ks$jscomp$4_ks__$1$jscomp$1$$);;)if($G__27416_ks$jscomp$4_ks__$1$jscomp$1$$!=null){$G__27415_m$jscomp$40_m__$1$jscomp$1_m__$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($G__27415_m$jscomp$40_m__$1$jscomp$1_m__$2$$,
$APP.$cljs$core$first$$($G__27416_ks$jscomp$4_ks__$1$jscomp$1$$),$G__27414_sentinel$$);if($G__27414_sentinel$$===$G__27415_m$jscomp$40_m__$1$jscomp$1_m__$2$$)return $not_found$jscomp$13$$;$G__27416_ks$jscomp$4_ks__$1$jscomp$1$$=$APP.$cljs$core$next$$($G__27416_ks$jscomp$4_ks__$1$jscomp$1$$)}else return $G__27415_m$jscomp$40_m__$1$jscomp$1_m__$2$$};$APP.$cljs$core$get_in$$.$cljs$lang$maxFixedArity$=3;
$APP.$cljs$core$assoc_in$$=function $cljs$core$assoc_in$$($JSCompiler_temp$jscomp$172_m$jscomp$41$$,$first__23483_p__23480$$,$JSCompiler_inline_result$jscomp$175_v$jscomp$22$$){var $JSCompiler_temp_const$jscomp$173_seq__23482$$=$APP.$cljs$core$seq$$($first__23483_p__23480$$);$first__23483_p__23480$$=$APP.$cljs$core$first$$($JSCompiler_temp_const$jscomp$173_seq__23482$$);var $seq__23482__$1$$=$APP.$cljs$core$next$$($JSCompiler_temp_const$jscomp$173_seq__23482$$);if($seq__23482__$1$$){$JSCompiler_temp_const$jscomp$173_seq__23482$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;var $G__23484$jscomp$inline_2716$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$172_m$jscomp$41$$,$first__23483_p__23480$$);$JSCompiler_inline_result$jscomp$175_v$jscomp$22$$=$cljs$core$assoc_in$$.$cljs$core$IFn$_invoke$arity$3$?$cljs$core$assoc_in$$.$cljs$core$IFn$_invoke$arity$3$($G__23484$jscomp$inline_2716$$,$seq__23482__$1$$,$JSCompiler_inline_result$jscomp$175_v$jscomp$22$$):$cljs$core$assoc_in$$($G__23484$jscomp$inline_2716$$,
$seq__23482__$1$$,$JSCompiler_inline_result$jscomp$175_v$jscomp$22$$);$JSCompiler_temp$jscomp$172_m$jscomp$41$$=$JSCompiler_temp_const$jscomp$173_seq__23482$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp$jscomp$172_m$jscomp$41$$,$first__23483_p__23480$$,$JSCompiler_inline_result$jscomp$175_v$jscomp$22$$)}else $JSCompiler_temp$jscomp$172_m$jscomp$41$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$172_m$jscomp$41$$,$first__23483_p__23480$$,$JSCompiler_inline_result$jscomp$175_v$jscomp$22$$);
return $JSCompiler_temp$jscomp$172_m$jscomp$41$$};
$APP.$cljs$core$update_in$$=function $cljs$core$update_in$$($var_args$jscomp$230$$){switch(arguments.length){case 3:return $cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);case 5:return $cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4]);case 6:return $cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$6$(arguments[0],
arguments[1],arguments[2],arguments[3],arguments[4],arguments[5]);default:for(var $args_arr__5774__auto__$jscomp$58$$=[],$len__5749__auto___27423$$=arguments.length,$i__5750__auto___27424$$=0;;)if($i__5750__auto___27424$$<$len__5749__auto___27423$$)$args_arr__5774__auto__$jscomp$58$$.push(arguments[$i__5750__auto___27424$$]),$i__5750__auto___27424$$+=1;else break;return $cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],
6<$args_arr__5774__auto__$jscomp$58$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$58$$.slice(6),0,null):null)}};
$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$=function($JSCompiler_temp$jscomp$176_m$jscomp$42$$,$first__23499_p__23496$$,$JSCompiler_inline_result$jscomp$179_f$jscomp$231$$){var $JSCompiler_temp_const$jscomp$177_seq__23498_seq__23498__$1$$=$APP.$cljs$core$seq$$($first__23499_p__23496$$);$first__23499_p__23496$$=$APP.$cljs$core$first$$($JSCompiler_temp_const$jscomp$177_seq__23498_seq__23498__$1$$);if($JSCompiler_temp_const$jscomp$177_seq__23498_seq__23498__$1$$=$APP.$cljs$core$next$$($JSCompiler_temp_const$jscomp$177_seq__23498_seq__23498__$1$$))$JSCompiler_temp$jscomp$176_m$jscomp$42$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$176_m$jscomp$42$$,$first__23499_p__23496$$,$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$176_m$jscomp$42$$,$first__23499_p__23496$$),$JSCompiler_temp_const$jscomp$177_seq__23498_seq__23498__$1$$,$JSCompiler_inline_result$jscomp$179_f$jscomp$231$$));else{$JSCompiler_temp_const$jscomp$177_seq__23498_seq__23498__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;
var $G__23500$jscomp$inline_2718$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$176_m$jscomp$42$$,$first__23499_p__23496$$);$JSCompiler_inline_result$jscomp$179_f$jscomp$231$$=$JSCompiler_inline_result$jscomp$179_f$jscomp$231$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$179_f$jscomp$231$$.$cljs$core$IFn$_invoke$arity$1$($G__23500$jscomp$inline_2718$$):$JSCompiler_inline_result$jscomp$179_f$jscomp$231$$($G__23500$jscomp$inline_2718$$);$JSCompiler_temp$jscomp$176_m$jscomp$42$$=
$JSCompiler_temp_const$jscomp$177_seq__23498_seq__23498__$1$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp$jscomp$176_m$jscomp$42$$,$first__23499_p__23496$$,$JSCompiler_inline_result$jscomp$179_f$jscomp$231$$)}return $JSCompiler_temp$jscomp$176_m$jscomp$42$$};
$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$=function($JSCompiler_temp$jscomp$180_m$jscomp$43$$,$first__23504_p__23501$$,$JSCompiler_inline_result$jscomp$183_f$jscomp$232$$,$a$jscomp$156$$){var $JSCompiler_temp_const$jscomp$181_seq__23503_seq__23503__$1$$=$APP.$cljs$core$seq$$($first__23504_p__23501$$);$first__23504_p__23501$$=$APP.$cljs$core$first$$($JSCompiler_temp_const$jscomp$181_seq__23503_seq__23503__$1$$);if($JSCompiler_temp_const$jscomp$181_seq__23503_seq__23503__$1$$=$APP.$cljs$core$next$$($JSCompiler_temp_const$jscomp$181_seq__23503_seq__23503__$1$$))$JSCompiler_temp$jscomp$180_m$jscomp$43$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$180_m$jscomp$43$$,$first__23504_p__23501$$,$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$180_m$jscomp$43$$,$first__23504_p__23501$$),$JSCompiler_temp_const$jscomp$181_seq__23503_seq__23503__$1$$,$JSCompiler_inline_result$jscomp$183_f$jscomp$232$$,$a$jscomp$156$$));else{$JSCompiler_temp_const$jscomp$181_seq__23503_seq__23503__$1$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;var $G__23505$jscomp$inline_2720$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$180_m$jscomp$43$$,$first__23504_p__23501$$);$JSCompiler_inline_result$jscomp$183_f$jscomp$232$$=$JSCompiler_inline_result$jscomp$183_f$jscomp$232$$.$cljs$core$IFn$_invoke$arity$2$?$JSCompiler_inline_result$jscomp$183_f$jscomp$232$$.$cljs$core$IFn$_invoke$arity$2$($G__23505$jscomp$inline_2720$$,$a$jscomp$156$$):$JSCompiler_inline_result$jscomp$183_f$jscomp$232$$($G__23505$jscomp$inline_2720$$,
$a$jscomp$156$$);$JSCompiler_temp$jscomp$180_m$jscomp$43$$=$JSCompiler_temp_const$jscomp$181_seq__23503_seq__23503__$1$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp$jscomp$180_m$jscomp$43$$,$first__23504_p__23501$$,$JSCompiler_inline_result$jscomp$183_f$jscomp$232$$)}return $JSCompiler_temp$jscomp$180_m$jscomp$43$$};
$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$=function($JSCompiler_temp$jscomp$184_m$jscomp$44$$,$first__23510_p__23507$$,$JSCompiler_inline_result$jscomp$187_f$jscomp$233$$,$a$jscomp$157$$,$b$jscomp$133$$){var $JSCompiler_temp_const$jscomp$185_seq__23509_seq__23509__$1$$=$APP.$cljs$core$seq$$($first__23510_p__23507$$);$first__23510_p__23507$$=$APP.$cljs$core$first$$($JSCompiler_temp_const$jscomp$185_seq__23509_seq__23509__$1$$);if($JSCompiler_temp_const$jscomp$185_seq__23509_seq__23509__$1$$=
$APP.$cljs$core$next$$($JSCompiler_temp_const$jscomp$185_seq__23509_seq__23509__$1$$))$JSCompiler_temp$jscomp$184_m$jscomp$44$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$184_m$jscomp$44$$,$first__23510_p__23507$$,$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$184_m$jscomp$44$$,$first__23510_p__23507$$),$JSCompiler_temp_const$jscomp$185_seq__23509_seq__23509__$1$$,$JSCompiler_inline_result$jscomp$187_f$jscomp$233$$,
$a$jscomp$157$$,$b$jscomp$133$$));else{$JSCompiler_temp_const$jscomp$185_seq__23509_seq__23509__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;var $G__23511$jscomp$inline_2722$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$184_m$jscomp$44$$,$first__23510_p__23507$$);$JSCompiler_inline_result$jscomp$187_f$jscomp$233$$=$JSCompiler_inline_result$jscomp$187_f$jscomp$233$$.$cljs$core$IFn$_invoke$arity$3$?$JSCompiler_inline_result$jscomp$187_f$jscomp$233$$.$cljs$core$IFn$_invoke$arity$3$($G__23511$jscomp$inline_2722$$,
$a$jscomp$157$$,$b$jscomp$133$$):$JSCompiler_inline_result$jscomp$187_f$jscomp$233$$($G__23511$jscomp$inline_2722$$,$a$jscomp$157$$,$b$jscomp$133$$);$JSCompiler_temp$jscomp$184_m$jscomp$44$$=$JSCompiler_temp_const$jscomp$185_seq__23509_seq__23509__$1$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp$jscomp$184_m$jscomp$44$$,$first__23510_p__23507$$,$JSCompiler_inline_result$jscomp$187_f$jscomp$233$$)}return $JSCompiler_temp$jscomp$184_m$jscomp$44$$};
$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$6$=function($JSCompiler_temp$jscomp$188_m$jscomp$45$$,$first__23517_p__23514$$,$JSCompiler_inline_result$jscomp$191_f$jscomp$234$$,$a$jscomp$158$$,$b$jscomp$134$$,$c$jscomp$109$$){var $JSCompiler_temp_const$jscomp$189_seq__23516_seq__23516__$1$$=$APP.$cljs$core$seq$$($first__23517_p__23514$$);$first__23517_p__23514$$=$APP.$cljs$core$first$$($JSCompiler_temp_const$jscomp$189_seq__23516_seq__23516__$1$$);if($JSCompiler_temp_const$jscomp$189_seq__23516_seq__23516__$1$$=
$APP.$cljs$core$next$$($JSCompiler_temp_const$jscomp$189_seq__23516_seq__23516__$1$$))$JSCompiler_temp$jscomp$188_m$jscomp$45$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$188_m$jscomp$45$$,$first__23517_p__23514$$,$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$6$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$188_m$jscomp$45$$,$first__23517_p__23514$$),$JSCompiler_temp_const$jscomp$189_seq__23516_seq__23516__$1$$,$JSCompiler_inline_result$jscomp$191_f$jscomp$234$$,
$a$jscomp$158$$,$b$jscomp$134$$,$c$jscomp$109$$));else{$JSCompiler_temp_const$jscomp$189_seq__23516_seq__23516__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;var $G__23518$jscomp$inline_2724$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$188_m$jscomp$45$$,$first__23517_p__23514$$);$JSCompiler_inline_result$jscomp$191_f$jscomp$234$$=$JSCompiler_inline_result$jscomp$191_f$jscomp$234$$.$cljs$core$IFn$_invoke$arity$4$?$JSCompiler_inline_result$jscomp$191_f$jscomp$234$$.$cljs$core$IFn$_invoke$arity$4$($G__23518$jscomp$inline_2724$$,
$a$jscomp$158$$,$b$jscomp$134$$,$c$jscomp$109$$):$JSCompiler_inline_result$jscomp$191_f$jscomp$234$$($G__23518$jscomp$inline_2724$$,$a$jscomp$158$$,$b$jscomp$134$$,$c$jscomp$109$$);$JSCompiler_temp$jscomp$188_m$jscomp$45$$=$JSCompiler_temp_const$jscomp$189_seq__23516_seq__23516__$1$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp$jscomp$188_m$jscomp$45$$,$first__23517_p__23514$$,$JSCompiler_inline_result$jscomp$191_f$jscomp$234$$)}return $JSCompiler_temp$jscomp$188_m$jscomp$45$$};
$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$variadic$=function($m$jscomp$46$$,$first__23525_p__23522$$,$f$jscomp$235$$,$a$jscomp$159$$,$b$jscomp$135$$,$c$jscomp$110$$,$args$jscomp$89$$){var $seq__23524_seq__23524__$1$$=$APP.$cljs$core$seq$$($first__23525_p__23522$$);$first__23525_p__23522$$=$APP.$cljs$core$first$$($seq__23524_seq__23524__$1$$);return($seq__23524_seq__23524__$1$$=$APP.$cljs$core$next$$($seq__23524_seq__23524__$1$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$46$$,
$first__23525_p__23522$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$update_in$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$46$$,$first__23525_p__23522$$),$seq__23524_seq__23524__$1$$,$f$jscomp$235$$,$a$jscomp$159$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$b$jscomp$135$$,$c$jscomp$110$$,$args$jscomp$89$$]))):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$46$$,$first__23525_p__23522$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$($f$jscomp$235$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$46$$,$first__23525_p__23522$$),$a$jscomp$159$$,$b$jscomp$135$$,$c$jscomp$110$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$args$jscomp$89$$])))};
$APP.$cljs$core$update_in$$.$cljs$lang$applyTo$=function($G__23490_seq23488$$){var $G__23489$$=$APP.$cljs$core$first$$($G__23490_seq23488$$),$G__23491_seq23488__$1$$=$APP.$cljs$core$next$$($G__23490_seq23488$$);$G__23490_seq23488$$=$APP.$cljs$core$first$$($G__23491_seq23488__$1$$);var $G__23492_seq23488__$2$$=$APP.$cljs$core$next$$($G__23491_seq23488__$1$$);$G__23491_seq23488__$1$$=$APP.$cljs$core$first$$($G__23492_seq23488__$2$$);var $G__23493_seq23488__$3$$=$APP.$cljs$core$next$$($G__23492_seq23488__$2$$);
$G__23492_seq23488__$2$$=$APP.$cljs$core$first$$($G__23493_seq23488__$3$$);var $G__23494_seq23488__$4$$=$APP.$cljs$core$next$$($G__23493_seq23488__$3$$);$G__23493_seq23488__$3$$=$APP.$cljs$core$first$$($G__23494_seq23488__$4$$);var $seq23488__$5_seq23488__$6$$=$APP.$cljs$core$next$$($G__23494_seq23488__$4$$);$G__23494_seq23488__$4$$=$APP.$cljs$core$first$$($seq23488__$5_seq23488__$6$$);$seq23488__$5_seq23488__$6$$=$APP.$cljs$core$next$$($seq23488__$5_seq23488__$6$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23489$$,
$G__23490_seq23488$$,$G__23491_seq23488__$1$$,$G__23492_seq23488__$2$$,$G__23493_seq23488__$3$$,$G__23494_seq23488__$4$$,$seq23488__$5_seq23488__$6$$)};$APP.$cljs$core$update_in$$.$cljs$lang$maxFixedArity$=6;
$APP.$cljs$core$update$$=function $cljs$core$update$$($var_args$jscomp$231$$){switch(arguments.length){case 3:return $cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);case 5:return $cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4]);case 6:return $cljs$core$update$$.$cljs$core$IFn$_invoke$arity$6$(arguments[0],
arguments[1],arguments[2],arguments[3],arguments[4],arguments[5]);default:for(var $args_arr__5774__auto__$jscomp$59$$=[],$len__5749__auto___27446$$=arguments.length,$i__5750__auto___27447$$=0;;)if($i__5750__auto___27447$$<$len__5749__auto___27446$$)$args_arr__5774__auto__$jscomp$59$$.push(arguments[$i__5750__auto___27447$$]),$i__5750__auto___27447$$+=1;else break;return $cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],
6<$args_arr__5774__auto__$jscomp$59$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$59$$.slice(6),0,null):null)}};
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$=function($m$jscomp$47$$,$k$jscomp$81$$,$JSCompiler_inline_result$jscomp$194_f$jscomp$236$$){var $JSCompiler_temp_const$jscomp$192$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$G__23535$jscomp$inline_2726$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$47$$,$k$jscomp$81$$);$JSCompiler_inline_result$jscomp$194_f$jscomp$236$$=$JSCompiler_inline_result$jscomp$194_f$jscomp$236$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$194_f$jscomp$236$$.$cljs$core$IFn$_invoke$arity$1$($G__23535$jscomp$inline_2726$$):
$JSCompiler_inline_result$jscomp$194_f$jscomp$236$$($G__23535$jscomp$inline_2726$$);return $JSCompiler_temp_const$jscomp$192$$.call($APP.$cljs$core$assoc$$,$m$jscomp$47$$,$k$jscomp$81$$,$JSCompiler_inline_result$jscomp$194_f$jscomp$236$$)};
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$=function($m$jscomp$48$$,$k$jscomp$82$$,$JSCompiler_inline_result$jscomp$197_f$jscomp$237$$,$x$jscomp$476$$){var $JSCompiler_temp_const$jscomp$195$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$G__23536$jscomp$inline_2728$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$48$$,$k$jscomp$82$$);$JSCompiler_inline_result$jscomp$197_f$jscomp$237$$=$JSCompiler_inline_result$jscomp$197_f$jscomp$237$$.$cljs$core$IFn$_invoke$arity$2$?
$JSCompiler_inline_result$jscomp$197_f$jscomp$237$$.$cljs$core$IFn$_invoke$arity$2$($G__23536$jscomp$inline_2728$$,$x$jscomp$476$$):$JSCompiler_inline_result$jscomp$197_f$jscomp$237$$($G__23536$jscomp$inline_2728$$,$x$jscomp$476$$);return $JSCompiler_temp_const$jscomp$195$$.call($APP.$cljs$core$assoc$$,$m$jscomp$48$$,$k$jscomp$82$$,$JSCompiler_inline_result$jscomp$197_f$jscomp$237$$)};
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$=function($m$jscomp$49$$,$k$jscomp$83$$,$JSCompiler_inline_result$jscomp$200_f$jscomp$238$$,$x$jscomp$477$$,$y$jscomp$233$$){var $JSCompiler_temp_const$jscomp$198$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$G__23538$jscomp$inline_2730$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$49$$,$k$jscomp$83$$);$JSCompiler_inline_result$jscomp$200_f$jscomp$238$$=$JSCompiler_inline_result$jscomp$200_f$jscomp$238$$.$cljs$core$IFn$_invoke$arity$3$?
$JSCompiler_inline_result$jscomp$200_f$jscomp$238$$.$cljs$core$IFn$_invoke$arity$3$($G__23538$jscomp$inline_2730$$,$x$jscomp$477$$,$y$jscomp$233$$):$JSCompiler_inline_result$jscomp$200_f$jscomp$238$$($G__23538$jscomp$inline_2730$$,$x$jscomp$477$$,$y$jscomp$233$$);return $JSCompiler_temp_const$jscomp$198$$.call($APP.$cljs$core$assoc$$,$m$jscomp$49$$,$k$jscomp$83$$,$JSCompiler_inline_result$jscomp$200_f$jscomp$238$$)};
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$6$=function($m$jscomp$50$$,$k$jscomp$84$$,$JSCompiler_inline_result$jscomp$203_f$jscomp$239$$,$x$jscomp$478$$,$y$jscomp$234$$,$z$jscomp$84$$){var $JSCompiler_temp_const$jscomp$201$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$G__23541$jscomp$inline_2732$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$50$$,$k$jscomp$84$$);$JSCompiler_inline_result$jscomp$203_f$jscomp$239$$=$JSCompiler_inline_result$jscomp$203_f$jscomp$239$$.$cljs$core$IFn$_invoke$arity$4$?
$JSCompiler_inline_result$jscomp$203_f$jscomp$239$$.$cljs$core$IFn$_invoke$arity$4$($G__23541$jscomp$inline_2732$$,$x$jscomp$478$$,$y$jscomp$234$$,$z$jscomp$84$$):$JSCompiler_inline_result$jscomp$203_f$jscomp$239$$($G__23541$jscomp$inline_2732$$,$x$jscomp$478$$,$y$jscomp$234$$,$z$jscomp$84$$);return $JSCompiler_temp_const$jscomp$201$$.call($APP.$cljs$core$assoc$$,$m$jscomp$50$$,$k$jscomp$84$$,$JSCompiler_inline_result$jscomp$203_f$jscomp$239$$)};
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$=function($m$jscomp$51$$,$k$jscomp$85$$,$f$jscomp$240$$,$x$jscomp$479$$,$y$jscomp$235$$,$z$jscomp$85$$,$more$jscomp$32$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$51$$,$k$jscomp$85$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$($f$jscomp$240$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$51$$,$k$jscomp$85$$),$x$jscomp$479$$,$y$jscomp$235$$,$z$jscomp$85$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$more$jscomp$32$$])))};
$APP.$cljs$core$update$$.$cljs$lang$applyTo$=function($G__23529_seq23527$$){var $G__23528$$=$APP.$cljs$core$first$$($G__23529_seq23527$$),$G__23530_seq23527__$1$$=$APP.$cljs$core$next$$($G__23529_seq23527$$);$G__23529_seq23527$$=$APP.$cljs$core$first$$($G__23530_seq23527__$1$$);var $G__23531_seq23527__$2$$=$APP.$cljs$core$next$$($G__23530_seq23527__$1$$);$G__23530_seq23527__$1$$=$APP.$cljs$core$first$$($G__23531_seq23527__$2$$);var $G__23532_seq23527__$3$$=$APP.$cljs$core$next$$($G__23531_seq23527__$2$$);
$G__23531_seq23527__$2$$=$APP.$cljs$core$first$$($G__23532_seq23527__$3$$);var $G__23533_seq23527__$4$$=$APP.$cljs$core$next$$($G__23532_seq23527__$3$$);$G__23532_seq23527__$3$$=$APP.$cljs$core$first$$($G__23533_seq23527__$4$$);var $seq23527__$5_seq23527__$6$$=$APP.$cljs$core$next$$($G__23533_seq23527__$4$$);$G__23533_seq23527__$4$$=$APP.$cljs$core$first$$($seq23527__$5_seq23527__$6$$);$seq23527__$5_seq23527__$6$$=$APP.$cljs$core$next$$($seq23527__$5_seq23527__$6$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23528$$,
$G__23529_seq23527$$,$G__23530_seq23527__$1$$,$G__23531_seq23527__$2$$,$G__23532_seq23527__$3$$,$G__23533_seq23527__$4$$,$seq23527__$5_seq23527__$6$$)};$APP.$cljs$core$update$$.$cljs$lang$maxFixedArity$=6;
var $cljs$core$push_tail$$=function $cljs$core$push_tail$$($JSCompiler_temp$jscomp$204_pv$jscomp$1$$,$G__23546$jscomp$inline_2734_level$jscomp$20$$,$child_parent$jscomp$5$$,$tailnode$$){var $ret$jscomp$21$$=$cljs$core$pv_clone_node$$($child_parent$jscomp$5$$),$subidx$$=$JSCompiler_temp$jscomp$204_pv$jscomp$1$$.$cnt$-1>>>$G__23546$jscomp$inline_2734_level$jscomp$20$$&31;5===$G__23546$jscomp$inline_2734_level$jscomp$20$$?$ret$jscomp$21$$.$arr$[$subidx$$]=$tailnode$$:($child_parent$jscomp$5$$=$child_parent$jscomp$5$$.$arr$[$subidx$$],
$child_parent$jscomp$5$$!=null?($G__23546$jscomp$inline_2734_level$jscomp$20$$-=5,$JSCompiler_temp$jscomp$204_pv$jscomp$1$$=$cljs$core$push_tail$$.$cljs$core$IFn$_invoke$arity$4$?$cljs$core$push_tail$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$204_pv$jscomp$1$$,$G__23546$jscomp$inline_2734_level$jscomp$20$$,$child_parent$jscomp$5$$,$tailnode$$):$cljs$core$push_tail$$($JSCompiler_temp$jscomp$204_pv$jscomp$1$$,$G__23546$jscomp$inline_2734_level$jscomp$20$$,$child_parent$jscomp$5$$,$tailnode$$)):
$JSCompiler_temp$jscomp$204_pv$jscomp$1$$=$cljs$core$new_path$$(null,$G__23546$jscomp$inline_2734_level$jscomp$20$$-5,$tailnode$$),$ret$jscomp$21$$.$arr$[$subidx$$]=$JSCompiler_temp$jscomp$204_pv$jscomp$1$$);return $ret$jscomp$21$$},$cljs$core$do_assoc$$=function $cljs$core$do_assoc$$($JSCompiler_inline_result$jscomp$205_pv$jscomp$5$$,$G__23550$jscomp$inline_2736_level$jscomp$23$$,$G__23551$jscomp$inline_2737_node$jscomp$13$$,$i$jscomp$204$$,$val$jscomp$76$$){var $ret$jscomp$22$$=$cljs$core$pv_clone_node$$($G__23551$jscomp$inline_2737_node$jscomp$13$$);
if($G__23550$jscomp$inline_2736_level$jscomp$23$$===0)$ret$jscomp$22$$.$arr$[$i$jscomp$204$$&31]=$val$jscomp$76$$;else{var $subidx$jscomp$1$$=$i$jscomp$204$$>>>$G__23550$jscomp$inline_2736_level$jscomp$23$$&31;$G__23550$jscomp$inline_2736_level$jscomp$23$$-=5;$G__23551$jscomp$inline_2737_node$jscomp$13$$=$G__23551$jscomp$inline_2737_node$jscomp$13$$.$arr$[$subidx$jscomp$1$$];$JSCompiler_inline_result$jscomp$205_pv$jscomp$5$$=$cljs$core$do_assoc$$.$cljs$core$IFn$_invoke$arity$5$?$cljs$core$do_assoc$$.$cljs$core$IFn$_invoke$arity$5$($JSCompiler_inline_result$jscomp$205_pv$jscomp$5$$,
$G__23550$jscomp$inline_2736_level$jscomp$23$$,$G__23551$jscomp$inline_2737_node$jscomp$13$$,$i$jscomp$204$$,$val$jscomp$76$$):$cljs$core$do_assoc$$($JSCompiler_inline_result$jscomp$205_pv$jscomp$5$$,$G__23550$jscomp$inline_2736_level$jscomp$23$$,$G__23551$jscomp$inline_2737_node$jscomp$13$$,$i$jscomp$204$$,$val$jscomp$76$$);$ret$jscomp$22$$.$arr$[$subidx$jscomp$1$$]=$JSCompiler_inline_result$jscomp$205_pv$jscomp$5$$}return $ret$jscomp$22$$},$cljs$core$pop_tail$$=function $cljs$core$pop_tail$$($new_child_pv$jscomp$6$$,
$G__23555$jscomp$inline_2739_level$jscomp$24$$,$node$jscomp$14_ret$jscomp$23$$){var $subidx$jscomp$2$$=$new_child_pv$jscomp$6$$.$cnt$-2>>>$G__23555$jscomp$inline_2739_level$jscomp$24$$&31;if($G__23555$jscomp$inline_2739_level$jscomp$24$$>5){$G__23555$jscomp$inline_2739_level$jscomp$24$$-=5;var $G__23556$jscomp$inline_2740$$=$node$jscomp$14_ret$jscomp$23$$.$arr$[$subidx$jscomp$2$$];$new_child_pv$jscomp$6$$=$cljs$core$pop_tail$$.$cljs$core$IFn$_invoke$arity$3$?$cljs$core$pop_tail$$.$cljs$core$IFn$_invoke$arity$3$($new_child_pv$jscomp$6$$,
$G__23555$jscomp$inline_2739_level$jscomp$24$$,$G__23556$jscomp$inline_2740$$):$cljs$core$pop_tail$$($new_child_pv$jscomp$6$$,$G__23555$jscomp$inline_2739_level$jscomp$24$$,$G__23556$jscomp$inline_2740$$);if($new_child_pv$jscomp$6$$==null&&$subidx$jscomp$2$$===0)return null;$node$jscomp$14_ret$jscomp$23$$=$cljs$core$pv_clone_node$$($node$jscomp$14_ret$jscomp$23$$);$node$jscomp$14_ret$jscomp$23$$.$arr$[$subidx$jscomp$2$$]=$new_child_pv$jscomp$6$$;return $node$jscomp$14_ret$jscomp$23$$}if($subidx$jscomp$2$$===
0)return null;$node$jscomp$14_ret$jscomp$23$$=$cljs$core$pv_clone_node$$($node$jscomp$14_ret$jscomp$23$$);$node$jscomp$14_ret$jscomp$23$$.$arr$[$subidx$jscomp$2$$]=null;return $node$jscomp$14_ret$jscomp$23$$};$cljs$core$RangedIterator$$.prototype.hasNext=function(){return this.i<this.end};$cljs$core$RangedIterator$$.prototype.next=function(){this.i-this.$base$===32&&(this.$arr$=$cljs$core$unchecked_array_for$$(this.v,this.i),this.$base$+=32);var $ret$jscomp$24$$=this.$arr$[this.i&31];this.i+=1;return $ret$jscomp$24$$};
$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$PersistentVector$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$_find$arity$2$=function($coll$jscomp$344$$,$n$jscomp$103$$){return 0<=$n$jscomp$103$$&&$n$jscomp$103$$<this.$cnt$?new $APP.$cljs$core$MapEntry$$($n$jscomp$103$$,$cljs$core$unchecked_array_for$$(this,$n$jscomp$103$$)[$n$jscomp$103$$&31],null):null};
$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$71$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$71$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__27509$$=null;$G__27509$$=function($x$jscomp$482$$,$start$jscomp$71$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$482$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$482$$,$start$jscomp$71$$)}throw Error("Invalid arity: "+arguments.length);};$G__27509$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$480$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$480$$,0)};$G__27509$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$481$$,$start$jscomp$70$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$481$$,$start$jscomp$70$$)};return $G__27509$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__27511__1$$($x$jscomp$483$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$483$$,$APP.$cljs$core$count$$(this))}var $G__27511$$=null;$G__27511$$=function($x$jscomp$485$$,$start$jscomp$73$$){switch(arguments.length){case 1:return $G__27511__1$$.call(this,$x$jscomp$485$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$485$$,$start$jscomp$73$$)}throw Error("Invalid arity: "+
arguments.length);};$G__27511$$.$cljs$core$IFn$_invoke$arity$1$=$G__27511__1$$;$G__27511$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$484$$,$start$jscomp$72$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$484$$,$start$jscomp$72$$)};return $G__27511$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($coll$jscomp$350$$,$k$jscomp$86$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$86$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($coll$jscomp$351$$,$k$jscomp$87$$,$not_found$jscomp$14$$){return typeof $k$jscomp$87$$==="number"?this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$87$$,$not_found$jscomp$14$$):$not_found$jscomp$14$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($i$jscomp$209_v$jscomp$26$$,$f$jscomp$243$$,$init$jscomp$26_len$jscomp$17$$){$i$jscomp$209_v$jscomp$26$$=0;for(var $G__23562$jscomp$inline_11235_G__27519$jscomp$inline_11238_init__$1_init__$2$jscomp$inline_11233_init__$3$jscomp$inline_11234$$=$init$jscomp$26_len$jscomp$17$$;;)if($i$jscomp$209_v$jscomp$26$$<this.$cnt$){var $G__27522_arr$jscomp$88_init__$2$$=$cljs$core$unchecked_array_for$$(this,$i$jscomp$209_v$jscomp$26$$);
$init$jscomp$26_len$jscomp$17$$=$G__27522_arr$jscomp$88_init__$2$$.length;a:{for(var $j$jscomp$inline_11232$$=0;;)if($j$jscomp$inline_11232$$<$init$jscomp$26_len$jscomp$17$$){var $G__23563$jscomp$inline_11236$$=$j$jscomp$inline_11232$$+$i$jscomp$209_v$jscomp$26$$,$G__23564$jscomp$inline_11237$$=$G__27522_arr$jscomp$88_init__$2$$[$j$jscomp$inline_11232$$];$G__23562$jscomp$inline_11235_G__27519$jscomp$inline_11238_init__$1_init__$2$jscomp$inline_11233_init__$3$jscomp$inline_11234$$=$f$jscomp$243$$.$cljs$core$IFn$_invoke$arity$3$?
$f$jscomp$243$$.$cljs$core$IFn$_invoke$arity$3$($G__23562$jscomp$inline_11235_G__27519$jscomp$inline_11238_init__$1_init__$2$jscomp$inline_11233_init__$3$jscomp$inline_11234$$,$G__23563$jscomp$inline_11236$$,$G__23564$jscomp$inline_11237$$):$f$jscomp$243$$($G__23562$jscomp$inline_11235_G__27519$jscomp$inline_11238_init__$1_init__$2$jscomp$inline_11233_init__$3$jscomp$inline_11234$$,$G__23563$jscomp$inline_11236$$,$G__23564$jscomp$inline_11237$$);if($cljs$core$reduced_QMARK_$$($G__23562$jscomp$inline_11235_G__27519$jscomp$inline_11238_init__$1_init__$2$jscomp$inline_11233_init__$3$jscomp$inline_11234$$)){$G__27522_arr$jscomp$88_init__$2$$=
$G__23562$jscomp$inline_11235_G__27519$jscomp$inline_11238_init__$1_init__$2$jscomp$inline_11233_init__$3$jscomp$inline_11234$$;break a}$j$jscomp$inline_11232$$+=1}else{$G__27522_arr$jscomp$88_init__$2$$=$G__23562$jscomp$inline_11235_G__27519$jscomp$inline_11238_init__$1_init__$2$jscomp$inline_11233_init__$3$jscomp$inline_11234$$;break a}$G__27522_arr$jscomp$88_init__$2$$=void 0}if($cljs$core$reduced_QMARK_$$($G__27522_arr$jscomp$88_init__$2$$))return $APP.$cljs$core$_deref$$($G__27522_arr$jscomp$88_init__$2$$);
$i$jscomp$209_v$jscomp$26$$+=$init$jscomp$26_len$jscomp$17$$;$G__23562$jscomp$inline_11235_G__27519$jscomp$inline_11238_init__$1_init__$2$jscomp$inline_11233_init__$3$jscomp$inline_11234$$=$G__27522_arr$jscomp$88_init__$2$$}else return $G__23562$jscomp$inline_11235_G__27519$jscomp$inline_11238_init__$1_init__$2$jscomp$inline_11233_init__$3$jscomp$inline_11234$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$APersistentVector$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($coll$jscomp$352$$,$n$jscomp$104$$){return $cljs$core$array_for$$(this,$n$jscomp$104$$)[$n$jscomp$104$$&31]};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($coll$jscomp$353$$,$n$jscomp$105$$,$not_found$jscomp$15$$){return 0<=$n$jscomp$105$$&&$n$jscomp$105$$<this.$cnt$?$cljs$core$unchecked_array_for$$(this,$n$jscomp$105$$)[$n$jscomp$105$$&31]:$not_found$jscomp$15$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IVector$_assoc_n$arity$3$=function($coll$jscomp$354_new_tail$$,$n$jscomp$106$$,$val$jscomp$77$$){if(0<=$n$jscomp$106$$&&$n$jscomp$106$$<this.$cnt$)return $cljs$core$tail_off$$(this)<=$n$jscomp$106$$?($coll$jscomp$354_new_tail$$=$APP.$cljs$core$aclone$$(this.$tail$),$coll$jscomp$354_new_tail$$[$n$jscomp$106$$&31]=$val$jscomp$77$$,new $APP.$cljs$core$PersistentVector$$(this.$meta$,this.$cnt$,this.shift,this.root,$coll$jscomp$354_new_tail$$,null)):new $APP.$cljs$core$PersistentVector$$(this.$meta$,
this.$cnt$,this.shift,$cljs$core$do_assoc$$(this,this.shift,this.root,$n$jscomp$106$$,$val$jscomp$77$$),this.$tail$,null);if($n$jscomp$106$$===this.$cnt$)return this.$cljs$core$ICollection$_conj$arity$2$(null,$val$jscomp$77$$);throw Error(["Index ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$106$$)," out of bounds  [0,",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.$cnt$),"]"].join(""));};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return $cljs$core$ranged_iterator$$(this,0,this.$cnt$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$cljs$core$PersistentVector$$(this.$meta$,this.$cnt$,this.shift,this.root,this.$tail$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.$cnt$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_peek$arity$1$=function(){return this.$cnt$>0?this.$cljs$core$IIndexed$_nth$arity$2$(null,this.$cnt$-1):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_pop$arity$1$=function(){if(this.$cnt$===0)throw Error("Can't pop empty vector");if(1===this.$cnt$)return $APP.$cljs$core$_with_meta$$($APP.$cljs$core$PersistentVector$EMPTY$$,this.$meta$);if(1<this.$cnt$-$cljs$core$tail_off$$(this))return new $APP.$cljs$core$PersistentVector$$(this.$meta$,this.$cnt$-1,this.shift,this.root,this.$tail$.slice(0,-1),null);var $new_tail$jscomp$1$$=$cljs$core$unchecked_array_for$$(this,this.$cnt$-2),$new_root_nr$$=$cljs$core$pop_tail$$(this,
this.shift,this.root);$new_root_nr$$=$new_root_nr$$==null?$APP.$cljs$core$PersistentVector$EMPTY_NODE$$:$new_root_nr$$;var $cnt_1$$=this.$cnt$-1;return 5<this.shift&&$new_root_nr$$.$arr$[1]==null?new $APP.$cljs$core$PersistentVector$$(this.$meta$,$cnt_1$$,this.shift-5,$new_root_nr$$.$arr$[0],$new_tail$jscomp$1$$,null):new $APP.$cljs$core$PersistentVector$$(this.$meta$,$cnt_1$$,this.shift,$new_root_nr$$,$new_tail$jscomp$1$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReversible$_rseq$arity$1$=function(){return this.$cnt$>0?new $APP.$cljs$core$RSeq$$(this,this.$cnt$-1,null):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$7_h__5134__auto____$1$jscomp$7$$=this.$__hash$;return $h__5134__auto__$jscomp$7_h__5134__auto____$1$jscomp$7$$!=null?$h__5134__auto__$jscomp$7_h__5134__auto____$1$jscomp$7$$:this.$__hash$=$h__5134__auto__$jscomp$7_h__5134__auto____$1$jscomp$7$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$361_me_iter$$,$other$jscomp$72_you_iter$$){if($other$jscomp$72_you_iter$$ instanceof $APP.$cljs$core$PersistentVector$$)if(this.$cnt$===$APP.$cljs$core$count$$($other$jscomp$72_you_iter$$))for($coll$jscomp$361_me_iter$$=this.$cljs$core$IIterable$_iterator$arity$1$(null),$other$jscomp$72_you_iter$$=$other$jscomp$72_you_iter$$.$cljs$core$IIterable$_iterator$arity$1$(null);;){if($coll$jscomp$361_me_iter$$.hasNext()){var $x$jscomp$486$$=
$coll$jscomp$361_me_iter$$.next(),$y$jscomp$236$$=$other$jscomp$72_you_iter$$.next();if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$486$$,$y$jscomp$236$$))continue;else return!1}else return!0;break}else return!1;else return $cljs$core$equiv_sequential$$(this,$other$jscomp$72_you_iter$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEditableCollection$_as_transient$arity$1$=function(){return new $cljs$core$TransientVector$$(this.$cnt$,this.shift,$cljs$core$tv_editable_root$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$core$tv_editable_root$$.$cljs$core$IFn$_invoke$arity$1$(this.root):$cljs$core$tv_editable_root$$(this.root),$cljs$core$tv_editable_tail$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$core$tv_editable_tail$$.$cljs$core$IFn$_invoke$arity$1$(this.$tail$):$cljs$core$tv_editable_tail$$(this.$tail$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$_with_meta$$($APP.$cljs$core$PersistentVector$EMPTY$$,this.$meta$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($v$jscomp$27$$,$f$jscomp$244$$){return $cljs$core$pv_reduce$cljs$0core$0IFn$0_invoke$0arity$04$$(this,$f$jscomp$244$$,0,this.$cnt$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($i$jscomp$210_v$jscomp$28$$,$f$jscomp$245$$,$init$jscomp$27_len$jscomp$18$$){$i$jscomp$210_v$jscomp$28$$=0;for(var $G__23565$jscomp$inline_11243_G__27538$jscomp$inline_11245_init__$1$jscomp$1_init__$2$jscomp$inline_11241_init__$3$jscomp$inline_11242$$=$init$jscomp$27_len$jscomp$18$$;;)if($i$jscomp$210_v$jscomp$28$$<this.$cnt$){var $G__27540_arr$jscomp$89_init__$2$jscomp$2$$=$cljs$core$unchecked_array_for$$(this,$i$jscomp$210_v$jscomp$28$$);
$init$jscomp$27_len$jscomp$18$$=$G__27540_arr$jscomp$89_init__$2$jscomp$2$$.length;a:{for(var $j$jscomp$inline_11240$$=0;;)if($j$jscomp$inline_11240$$<$init$jscomp$27_len$jscomp$18$$){var $G__23566$jscomp$inline_11244$$=$G__27540_arr$jscomp$89_init__$2$jscomp$2$$[$j$jscomp$inline_11240$$];$G__23565$jscomp$inline_11243_G__27538$jscomp$inline_11245_init__$1$jscomp$1_init__$2$jscomp$inline_11241_init__$3$jscomp$inline_11242$$=$f$jscomp$245$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$245$$.$cljs$core$IFn$_invoke$arity$2$($G__23565$jscomp$inline_11243_G__27538$jscomp$inline_11245_init__$1$jscomp$1_init__$2$jscomp$inline_11241_init__$3$jscomp$inline_11242$$,
$G__23566$jscomp$inline_11244$$):$f$jscomp$245$$($G__23565$jscomp$inline_11243_G__27538$jscomp$inline_11245_init__$1$jscomp$1_init__$2$jscomp$inline_11241_init__$3$jscomp$inline_11242$$,$G__23566$jscomp$inline_11244$$);if($cljs$core$reduced_QMARK_$$($G__23565$jscomp$inline_11243_G__27538$jscomp$inline_11245_init__$1$jscomp$1_init__$2$jscomp$inline_11241_init__$3$jscomp$inline_11242$$)){$G__27540_arr$jscomp$89_init__$2$jscomp$2$$=$G__23565$jscomp$inline_11243_G__27538$jscomp$inline_11245_init__$1$jscomp$1_init__$2$jscomp$inline_11241_init__$3$jscomp$inline_11242$$;
break a}$j$jscomp$inline_11240$$+=1}else{$G__27540_arr$jscomp$89_init__$2$jscomp$2$$=$G__23565$jscomp$inline_11243_G__27538$jscomp$inline_11245_init__$1$jscomp$1_init__$2$jscomp$inline_11241_init__$3$jscomp$inline_11242$$;break a}$G__27540_arr$jscomp$89_init__$2$jscomp$2$$=void 0}if($cljs$core$reduced_QMARK_$$($G__27540_arr$jscomp$89_init__$2$jscomp$2$$))return $APP.$cljs$core$_deref$$($G__27540_arr$jscomp$89_init__$2$jscomp$2$$);$i$jscomp$210_v$jscomp$28$$+=$init$jscomp$27_len$jscomp$18$$;$G__23565$jscomp$inline_11243_G__27538$jscomp$inline_11245_init__$1$jscomp$1_init__$2$jscomp$inline_11241_init__$3$jscomp$inline_11242$$=
$G__27540_arr$jscomp$89_init__$2$jscomp$2$$}else return $G__23565$jscomp$inline_11243_G__27538$jscomp$inline_11245_init__$1$jscomp$1_init__$2$jscomp$inline_11241_init__$3$jscomp$inline_11242$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($coll$jscomp$364$$,$k$jscomp$88$$,$v$jscomp$29$$){if(typeof $k$jscomp$88$$==="number")return this.$cljs$core$IVector$_assoc_n$arity$3$(null,$k$jscomp$88$$,$v$jscomp$29$$);throw Error("Vector's key for assoc must be a number.");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($coll$jscomp$365$$,$k$jscomp$89$$){return $APP.$cljs$core$integer_QMARK_$$($k$jscomp$89$$)?0<=$k$jscomp$89$$&&$k$jscomp$89$$<this.$cnt$:!1};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){if(this.$cnt$===0)return null;if(this.$cnt$<=32)return new $APP.$cljs$core$IndexedSeq$$(this.$tail$,0,null);a:{var $G__23568_node$jscomp$inline_2753$$=this.root;for(var $G__27479$jscomp$inline_2755_level$jscomp$inline_2754$$=this.shift;;)if($G__27479$jscomp$inline_2755_level$jscomp$inline_2754$$>0)$G__27479$jscomp$inline_2755_level$jscomp$inline_2754$$-=5,$G__23568_node$jscomp$inline_2753$$=$G__23568_node$jscomp$inline_2753$$.$arr$[0];
else{$G__23568_node$jscomp$inline_2753$$=$G__23568_node$jscomp$inline_2753$$.$arr$;break a}$G__23568_node$jscomp$inline_2753$$=void 0}return $cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$?$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$(this,$G__23568_node$jscomp$inline_2753$$,0,0):$cljs$core$chunked_seq$$(this,$G__23568_node$jscomp$inline_2753$$,0,0)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$367$$,$new_meta$jscomp$13$$){return $new_meta$jscomp$13$$===this.$meta$?this:new $APP.$cljs$core$PersistentVector$$($new_meta$jscomp$13$$,this.$cnt$,this.shift,this.root,this.$tail$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$368_len$jscomp$19_new_shift$$,$o$jscomp$100$$){if(this.$cnt$-$cljs$core$tail_off$$(this)<32){$coll$jscomp$368_len$jscomp$19_new_shift$$=this.$tail$.length;for(var $JSCompiler_temp$jscomp$206_n_r$jscomp$inline_2757_new_tail$jscomp$2_root_overflow_QMARK_$$=Array($coll$jscomp$368_len$jscomp$19_new_shift$$+1),$i_27552_val$jscomp$inline_11253$$=0;;)if($i_27552_val$jscomp$inline_11253$$<$coll$jscomp$368_len$jscomp$19_new_shift$$)$JSCompiler_temp$jscomp$206_n_r$jscomp$inline_2757_new_tail$jscomp$2_root_overflow_QMARK_$$[$i_27552_val$jscomp$inline_11253$$]=
this.$tail$[$i_27552_val$jscomp$inline_11253$$],$i_27552_val$jscomp$inline_11253$$+=1;else break;$JSCompiler_temp$jscomp$206_n_r$jscomp$inline_2757_new_tail$jscomp$2_root_overflow_QMARK_$$[$coll$jscomp$368_len$jscomp$19_new_shift$$]=$o$jscomp$100$$;return new $APP.$cljs$core$PersistentVector$$(this.$meta$,this.$cnt$+1,this.shift,this.root,$JSCompiler_temp$jscomp$206_n_r$jscomp$inline_2757_new_tail$jscomp$2_root_overflow_QMARK_$$,null)}$coll$jscomp$368_len$jscomp$19_new_shift$$=($JSCompiler_temp$jscomp$206_n_r$jscomp$inline_2757_new_tail$jscomp$2_root_overflow_QMARK_$$=
this.$cnt$>>>5>1<<this.shift)?this.shift+5:this.shift;$JSCompiler_temp$jscomp$206_n_r$jscomp$inline_2757_new_tail$jscomp$2_root_overflow_QMARK_$$?($JSCompiler_temp$jscomp$206_n_r$jscomp$inline_2757_new_tail$jscomp$2_root_overflow_QMARK_$$=$cljs$core$pv_fresh_node$$(null),$JSCompiler_temp$jscomp$206_n_r$jscomp$inline_2757_new_tail$jscomp$2_root_overflow_QMARK_$$.$arr$[0]=this.root,$i_27552_val$jscomp$inline_11253$$=$cljs$core$new_path$$(null,this.shift,new $cljs$core$VectorNode$$(null,this.$tail$)),
$JSCompiler_temp$jscomp$206_n_r$jscomp$inline_2757_new_tail$jscomp$2_root_overflow_QMARK_$$.$arr$[1]=$i_27552_val$jscomp$inline_11253$$):$JSCompiler_temp$jscomp$206_n_r$jscomp$inline_2757_new_tail$jscomp$2_root_overflow_QMARK_$$=$cljs$core$push_tail$$(this,this.shift,this.root,new $cljs$core$VectorNode$$(null,this.$tail$));return new $APP.$cljs$core$PersistentVector$$(this.$meta$,this.$cnt$+1,$coll$jscomp$368_len$jscomp$19_new_shift$$,$JSCompiler_temp$jscomp$206_n_r$jscomp$inline_2757_new_tail$jscomp$2_root_overflow_QMARK_$$,
[$o$jscomp$100$$],null)};$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$4$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$367$$,$args23561$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23561$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$90$$){if(typeof $k$jscomp$90$$==="number")return this.$cljs$core$IIndexed$_nth$arity$2$(null,$k$jscomp$90$$);throw Error("Key must be integer");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDrop$_drop$arity$2$=function($coll$jscomp$370_offset$jscomp$26$$,$G__23574_n$jscomp$107$$){if($G__23574_n$jscomp$107$$<this.$cnt$){$coll$jscomp$370_offset$jscomp$26$$=$G__23574_n$jscomp$107$$%32;var $G__23573$$=$cljs$core$unchecked_array_for$$(this,$G__23574_n$jscomp$107$$);$G__23574_n$jscomp$107$$-=$coll$jscomp$370_offset$jscomp$26$$;return $cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$?$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$(this,
$G__23573$$,$G__23574_n$jscomp$107$$,$coll$jscomp$370_offset$jscomp$26$$):$cljs$core$chunked_seq$$(this,$G__23573$$,$G__23574_n$jscomp$107$$,$coll$jscomp$370_offset$jscomp$26$$)}return null};$APP.$cljs$core$PersistentVector$EMPTY_NODE$$=new $cljs$core$VectorNode$$(null,[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]);
$APP.$cljs$core$PersistentVector$EMPTY$$=new $APP.$cljs$core$PersistentVector$$(null,0,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[],$cljs$core$empty_ordered_hash$$);$APP.$cljs$core$PersistentVector$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
$APP.$cljs$core$vector$$=function $cljs$core$vector$$($var_args$jscomp$233$$){for(var $args__5755__auto__$jscomp$2$$=[],$len__5749__auto___27577$$=arguments.length,$i__5750__auto___27578$$=0;;)if($i__5750__auto___27578$$<$len__5749__auto___27577$$)$args__5755__auto__$jscomp$2$$.push(arguments[$i__5750__auto___27578$$]),$i__5750__auto___27578$$+=1;else break;return $cljs$core$vector$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$2$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$2$$.slice(0),
0,null):null)};$APP.$cljs$core$vector$$.$cljs$core$IFn$_invoke$arity$variadic$=function($args$jscomp$90$$){return $args$jscomp$90$$ instanceof $APP.$cljs$core$IndexedSeq$$&&$args$jscomp$90$$.i===0?$APP.$cljs$core$PersistentVector$fromArray$$($args$jscomp$90$$.$arr$,!$APP.$cljs$core$array_QMARK_$$($args$jscomp$90$$.$arr$)):$APP.$cljs$core$vec$$($args$jscomp$90$$)};$APP.$cljs$core$vector$$.$cljs$lang$maxFixedArity$=0;$APP.$cljs$core$vector$$.$cljs$lang$applyTo$=function($seq23576$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq23576$$))};
$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$ChunkedSeq$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$73$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$73$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__27582$$=null;$G__27582$$=function($x$jscomp$489$$,$start$jscomp$75$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$489$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$489$$,$start$jscomp$75$$)}throw Error("Invalid arity: "+arguments.length);};$G__27582$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$487$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$487$$,0)};$G__27582$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$488$$,$start$jscomp$74$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$488$$,$start$jscomp$74$$)};return $G__27582$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__27583__1$$($x$jscomp$490$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$490$$,$APP.$cljs$core$count$$(this))}var $G__27583$$=null;$G__27583$$=function($x$jscomp$492$$,$start$jscomp$77$$){switch(arguments.length){case 1:return $G__27583__1$$.call(this,$x$jscomp$492$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$492$$,$start$jscomp$77$$)}throw Error("Invalid arity: "+
arguments.length);};$G__27583$$.$cljs$core$IFn$_invoke$arity$1$=$G__27583__1$$;$G__27583$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$491$$,$start$jscomp$76$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$491$$,$start$jscomp$76$$)};return $G__27583$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){if(this.$off$+1<this.node.length){var $G__23577$jscomp$inline_2759_s$jscomp$84$$=this.$vec$;var $G__23578$jscomp$inline_2760$$=this.node,$G__23579$jscomp$inline_2761$$=this.i,$G__23580$jscomp$inline_2762$$=this.$off$+1;$G__23577$jscomp$inline_2759_s$jscomp$84$$=$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$?$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$($G__23577$jscomp$inline_2759_s$jscomp$84$$,
$G__23578$jscomp$inline_2760$$,$G__23579$jscomp$inline_2761$$,$G__23580$jscomp$inline_2762$$):$cljs$core$chunked_seq$$($G__23577$jscomp$inline_2759_s$jscomp$84$$,$G__23578$jscomp$inline_2760$$,$G__23579$jscomp$inline_2761$$,$G__23580$jscomp$inline_2762$$);return $G__23577$jscomp$inline_2759_s$jscomp$84$$==null?null:$G__23577$jscomp$inline_2759_s$jscomp$84$$}return this.$cljs$core$IChunkedNext$_chunked_next$arity$1$()};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$8_h__5134__auto____$1$jscomp$8$$=this.$__hash$;return $h__5134__auto__$jscomp$8_h__5134__auto____$1$jscomp$8$$!=null?$h__5134__auto__$jscomp$8_h__5134__auto____$1$jscomp$8$$:this.$__hash$=$h__5134__auto__$jscomp$8_h__5134__auto____$1$jscomp$8$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$380$$,$other$jscomp$74$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$74$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$382$$,$f$jscomp$246$$){return $cljs$core$pv_reduce$cljs$0core$0IFn$0_invoke$0arity$04$$(this.$vec$,$f$jscomp$246$$,this.i+this.$off$,$APP.$cljs$core$count$$(this.$vec$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$383$$,$f$jscomp$247$$,$start$jscomp$78$$){return $cljs$core$pv_reduce$cljs$0core$0IFn$0_invoke$0arity$05$$(this.$vec$,$f$jscomp$247$$,$start$jscomp$78$$,this.i+this.$off$,$APP.$cljs$core$count$$(this.$vec$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return this.node[this.$off$]};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){if(this.$off$+1<this.node.length){var $G__23581$jscomp$inline_2764_s$jscomp$85$$=this.$vec$;var $G__23582$jscomp$inline_2765$$=this.node,$G__23583$jscomp$inline_2766$$=this.i,$G__23584$jscomp$inline_2767$$=this.$off$+1;$G__23581$jscomp$inline_2764_s$jscomp$85$$=$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$?$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$($G__23581$jscomp$inline_2764_s$jscomp$85$$,
$G__23582$jscomp$inline_2765$$,$G__23583$jscomp$inline_2766$$,$G__23584$jscomp$inline_2767$$):$cljs$core$chunked_seq$$($G__23581$jscomp$inline_2764_s$jscomp$85$$,$G__23582$jscomp$inline_2765$$,$G__23583$jscomp$inline_2766$$,$G__23584$jscomp$inline_2767$$);return $G__23581$jscomp$inline_2764_s$jscomp$85$$==null?$APP.$cljs$core$List$EMPTY$$:$G__23581$jscomp$inline_2764_s$jscomp$85$$}return this.$cljs$core$IChunkedSeq$_chunked_rest$arity$1$(null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IChunkedSeq$_chunked_first$arity$1$=function(){var $arr$jscomp$inline_2769$$=this.node;return new $cljs$core$ArrayChunk$$($arr$jscomp$inline_2769$$,this.$off$,$arr$jscomp$inline_2769$$.length)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IChunkedSeq$_chunked_rest$arity$1$=function(){var $end$jscomp$23$$=this.i+this.node.length;if($end$jscomp$23$$<$APP.$cljs$core$_count$$(this.$vec$)){var $G__23585$$=this.$vec$,$G__23586$$=$cljs$core$unchecked_array_for$$(this.$vec$,$end$jscomp$23$$);return $cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$?$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$($G__23585$$,$G__23586$$,$end$jscomp$23$$,0):$cljs$core$chunked_seq$$($G__23585$$,
$G__23586$$,$end$jscomp$23$$,0)}return $APP.$cljs$core$List$EMPTY$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$389$$,$new_meta$jscomp$14$$){return $new_meta$jscomp$14$$===this.$meta$?this:$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$05$$(this.$vec$,this.node,this.i,this.$off$,$new_meta$jscomp$14$$):$cljs$core$chunked_seq$$(this.$vec$,this.node,this.i,this.$off$,$new_meta$jscomp$14$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$390$$,$o$jscomp$101$$){return $APP.$cljs$core$cons$$($o$jscomp$101$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDrop$_drop$arity$2$=function($coll$jscomp$391_new_offset_o$jscomp$102$$,$G__23589_n$jscomp$108$$){$coll$jscomp$391_new_offset_o$jscomp$102$$=this.$off$+$G__23589_n$jscomp$108$$;if($coll$jscomp$391_new_offset_o$jscomp$102$$<this.node.length)return $cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$?$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$(this.$vec$,this.node,this.i,$coll$jscomp$391_new_offset_o$jscomp$102$$):$cljs$core$chunked_seq$$(this.$vec$,
this.node,this.i,$coll$jscomp$391_new_offset_o$jscomp$102$$);var $G__23591_i__$1$jscomp$4$$=this.i+$coll$jscomp$391_new_offset_o$jscomp$102$$;if($G__23591_i__$1$jscomp$4$$<$APP.$cljs$core$_count$$(this.$vec$)){$coll$jscomp$391_new_offset_o$jscomp$102$$=$G__23591_i__$1$jscomp$4$$%32;$G__23589_n$jscomp$108$$=this.$vec$;var $G__23590$$=$cljs$core$unchecked_array_for$$(this.$vec$,$G__23591_i__$1$jscomp$4$$);$G__23591_i__$1$jscomp$4$$-=$coll$jscomp$391_new_offset_o$jscomp$102$$;return $cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$?
$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$($G__23589_n$jscomp$108$$,$G__23590$$,$G__23591_i__$1$jscomp$4$$,$coll$jscomp$391_new_offset_o$jscomp$102$$):$cljs$core$chunked_seq$$($G__23589_n$jscomp$108$$,$G__23590$$,$G__23591_i__$1$jscomp$4$$,$coll$jscomp$391_new_offset_o$jscomp$102$$)}return null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IChunkedNext$_chunked_next$arity$1$=function(){var $end$jscomp$24$$=this.i+this.node.length;if($end$jscomp$24$$<$APP.$cljs$core$_count$$(this.$vec$)){var $G__23593$$=this.$vec$,$G__23594$$=$cljs$core$unchecked_array_for$$(this.$vec$,$end$jscomp$24$$);return $cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$?$cljs$core$chunked_seq$cljs$0core$0IFn$0_invoke$0arity$04$$($G__23593$$,$G__23594$$,$end$jscomp$24$$,0):$cljs$core$chunked_seq$$($G__23593$$,
$G__23594$$,$end$jscomp$24$$,0)}return null};$APP.$cljs$core$ChunkedSeq$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$Subvec$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$_find$arity$2$=function($coll$jscomp$393_idx$jscomp$20$$,$n$jscomp$109$$){if($n$jscomp$109$$<0)return null;$coll$jscomp$393_idx$jscomp$20$$=this.start+$n$jscomp$109$$;return $coll$jscomp$393_idx$jscomp$20$$<this.end?new $APP.$cljs$core$MapEntry$$($n$jscomp$109$$,$APP.$cljs$core$_lookup$$(this.v,$coll$jscomp$393_idx$jscomp$20$$),null):null};$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$75$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$75$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__27604$$=null;$G__27604$$=function($x$jscomp$495$$,$start__$1$jscomp$1$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$495$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$495$$,$start__$1$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$G__27604$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$493$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$493$$,0)};$G__27604$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$494$$,$start__$1$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$494$$,$start__$1$$)};return $G__27604$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__27606__1$$($x$jscomp$496$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$496$$,$APP.$cljs$core$count$$(this))}var $G__27606$$=null;$G__27606$$=function($x$jscomp$498$$,$start__$1$jscomp$3$$){switch(arguments.length){case 1:return $G__27606__1$$.call(this,$x$jscomp$498$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$498$$,$start__$1$jscomp$3$$)}throw Error("Invalid arity: "+
arguments.length);};$G__27606$$.$cljs$core$IFn$_invoke$arity$1$=$G__27606__1$$;$G__27606$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$497$$,$start__$1$jscomp$2$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$497$$,$start__$1$jscomp$2$$)};return $G__27606$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($coll$jscomp$399$$,$k$jscomp$91$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$91$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($coll$jscomp$400$$,$k$jscomp$92$$,$not_found$jscomp$16$$){return typeof $k$jscomp$92$$==="number"?this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$92$$,$not_found$jscomp$16$$):$not_found$jscomp$16$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($coll$jscomp$401_i$jscomp$217$$,$f$jscomp$248$$,$G__23600$jscomp$inline_2776_G__27613_init$jscomp$28_init__$1$jscomp$2_init__$2$jscomp$4$$){$coll$jscomp$401_i$jscomp$217$$=this.start;for(var $G__27612_j$jscomp$64$$=0;;)if($coll$jscomp$401_i$jscomp$217$$<this.end){var $G__23601$jscomp$inline_2777$$=$G__27612_j$jscomp$64$$,$G__23602$jscomp$inline_2778$$=$APP.$cljs$core$_nth$$(this.v,$coll$jscomp$401_i$jscomp$217$$);
$G__23600$jscomp$inline_2776_G__27613_init$jscomp$28_init__$1$jscomp$2_init__$2$jscomp$4$$=$f$jscomp$248$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$248$$.$cljs$core$IFn$_invoke$arity$3$($G__23600$jscomp$inline_2776_G__27613_init$jscomp$28_init__$1$jscomp$2_init__$2$jscomp$4$$,$G__23601$jscomp$inline_2777$$,$G__23602$jscomp$inline_2778$$):$f$jscomp$248$$($G__23600$jscomp$inline_2776_G__27613_init$jscomp$28_init__$1$jscomp$2_init__$2$jscomp$4$$,$G__23601$jscomp$inline_2777$$,$G__23602$jscomp$inline_2778$$);
if($cljs$core$reduced_QMARK_$$($G__23600$jscomp$inline_2776_G__27613_init$jscomp$28_init__$1$jscomp$2_init__$2$jscomp$4$$))return $APP.$cljs$core$_deref$$($G__23600$jscomp$inline_2776_G__27613_init$jscomp$28_init__$1$jscomp$2_init__$2$jscomp$4$$);$G__27612_j$jscomp$64$$+=1;$coll$jscomp$401_i$jscomp$217$$+=1}else return $G__23600$jscomp$inline_2776_G__27613_init$jscomp$28_init__$1$jscomp$2_init__$2$jscomp$4$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($coll$jscomp$402$$,$n$jscomp$110$$){return $n$jscomp$110$$<0||this.end<=this.start+$n$jscomp$110$$?$cljs$core$vector_index_out_of_bounds$$($n$jscomp$110$$,this.end-this.start):$APP.$cljs$core$_nth$$(this.v,this.start+$n$jscomp$110$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($coll$jscomp$403$$,$n$jscomp$111$$,$not_found$jscomp$17$$){return $n$jscomp$111$$<0||this.end<=this.start+$n$jscomp$111$$?$not_found$jscomp$17$$:$APP.$cljs$core$_nth$$(this.v,this.start+$n$jscomp$111$$,$not_found$jscomp$17$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IVector$_assoc_n$arity$3$=function($G__23606_coll$jscomp$404_v_pos_y__5111__auto__$jscomp$inline_2781$$,$G__23603_n$jscomp$112$$,$G__23604_val$jscomp$78$$){$G__23606_coll$jscomp$404_v_pos_y__5111__auto__$jscomp$inline_2781$$=this.start+$G__23603_n$jscomp$112$$;if($G__23603_n$jscomp$112$$<0||this.end+1<=$G__23606_coll$jscomp$404_v_pos_y__5111__auto__$jscomp$inline_2781$$)throw Error(["Index ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__23603_n$jscomp$112$$),
" out of bounds [0,",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.$cljs$core$ICounted$_count$arity$1$(null)),"]"].join(""));$G__23603_n$jscomp$112$$=this.$meta$;$G__23604_val$jscomp$78$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.v,$G__23606_coll$jscomp$404_v_pos_y__5111__auto__$jscomp$inline_2781$$,$G__23604_val$jscomp$78$$);var $G__23605$$=this.start,$x__5110__auto__$jscomp$inline_2780$$=this.end;$G__23606_coll$jscomp$404_v_pos_y__5111__auto__$jscomp$inline_2781$$+=
1;$G__23606_coll$jscomp$404_v_pos_y__5111__auto__$jscomp$inline_2781$$=$x__5110__auto__$jscomp$inline_2780$$>$G__23606_coll$jscomp$404_v_pos_y__5111__auto__$jscomp$inline_2781$$?$x__5110__auto__$jscomp$inline_2780$$:$G__23606_coll$jscomp$404_v_pos_y__5111__auto__$jscomp$inline_2781$$;return $cljs$core$build_subvec$$.$cljs$core$IFn$_invoke$arity$5$?$cljs$core$build_subvec$$.$cljs$core$IFn$_invoke$arity$5$($G__23603_n$jscomp$112$$,$G__23604_val$jscomp$78$$,$G__23605$$,$G__23606_coll$jscomp$404_v_pos_y__5111__auto__$jscomp$inline_2781$$,
null):$cljs$core$build_subvec$$($G__23603_n$jscomp$112$$,$G__23604_val$jscomp$78$$,$G__23605$$,$G__23606_coll$jscomp$404_v_pos_y__5111__auto__$jscomp$inline_2781$$,null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return this.v!=null&&$APP.$cljs$core$PROTOCOL_SENTINEL$$===this.v.$cljs$core$APersistentVector$$?$cljs$core$ranged_iterator$$(this.v,this.start,this.end):new $APP.$cljs$core$SeqIter$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$cljs$core$Subvec$$(this.$meta$,this.v,this.start,this.end,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.end-this.start};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_peek$arity$1$=function(){return this.start===this.end?null:$APP.$cljs$core$_nth$$(this.v,this.end-1)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_pop$arity$1$=function(){if(this.start===this.end)throw Error("Can't pop empty vector");var $G__23609$$=this.$meta$,$G__23610$$=this.v,$G__23611$$=this.start,$G__23612$$=this.end-1;return $cljs$core$build_subvec$$.$cljs$core$IFn$_invoke$arity$5$?$cljs$core$build_subvec$$.$cljs$core$IFn$_invoke$arity$5$($G__23609$$,$G__23610$$,$G__23611$$,$G__23612$$,null):$cljs$core$build_subvec$$($G__23609$$,$G__23610$$,$G__23611$$,$G__23612$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReversible$_rseq$arity$1$=function(){return this.start!==this.end?new $APP.$cljs$core$RSeq$$(this,this.end-this.start-1,null):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$9_h__5134__auto____$1$jscomp$9$$=this.$__hash$;return $h__5134__auto__$jscomp$9_h__5134__auto____$1$jscomp$9$$!=null?$h__5134__auto__$jscomp$9_h__5134__auto____$1$jscomp$9$$:this.$__hash$=$h__5134__auto__$jscomp$9_h__5134__auto____$1$jscomp$9$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$412$$,$other$jscomp$76$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$76$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$_with_meta$$($APP.$cljs$core$PersistentVector$EMPTY$$,this.$meta$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$414$$,$f$jscomp$249$$){return this.v!=null&&$APP.$cljs$core$PROTOCOL_SENTINEL$$===this.v.$cljs$core$APersistentVector$$?$cljs$core$pv_reduce$cljs$0core$0IFn$0_invoke$0arity$04$$(this.v,$f$jscomp$249$$,this.start,this.end):$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$f$jscomp$249$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$415$$,$f$jscomp$250$$,$init$jscomp$29$$){return this.v!=null&&$APP.$cljs$core$PROTOCOL_SENTINEL$$===this.v.$cljs$core$APersistentVector$$?$cljs$core$pv_reduce$cljs$0core$0IFn$0_invoke$0arity$05$$(this.v,$f$jscomp$250$$,$init$jscomp$29$$,this.start,this.end):$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$f$jscomp$250$$,$init$jscomp$29$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($coll$jscomp$416$$,$key$jscomp$125$$,$val$jscomp$79$$){if(typeof $key$jscomp$125$$==="number")return this.$cljs$core$IVector$_assoc_n$arity$3$(null,$key$jscomp$125$$,$val$jscomp$79$$);throw Error("Subvec's key for assoc must be a number.");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($coll$jscomp$417$$,$key$jscomp$126$$){return $APP.$cljs$core$integer_QMARK_$$($key$jscomp$126$$)?0<=$key$jscomp$126$$&&$key$jscomp$126$$<this.end-this.start:!1};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){var $self__$jscomp$419$$=this;return function $cljs$core$subvec_seq$$($i$jscomp$218$$){return $i$jscomp$218$$===$self__$jscomp$419$$.end?null:$APP.$cljs$core$cons$$($APP.$cljs$core$_nth$$($self__$jscomp$419$$.v,$i$jscomp$218$$),new $APP.$cljs$core$LazySeq$$(null,function(){return $cljs$core$subvec_seq$$($i$jscomp$218$$+1)},null,null))}($self__$jscomp$419$$.start)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$419$$,$new_meta$jscomp$15$$){return $new_meta$jscomp$15$$===this.$meta$?this:$cljs$core$build_subvec$$.$cljs$core$IFn$_invoke$arity$5$?$cljs$core$build_subvec$$.$cljs$core$IFn$_invoke$arity$5$($new_meta$jscomp$15$$,this.v,this.start,this.end,this.$__hash$):$cljs$core$build_subvec$$($new_meta$jscomp$15$$,this.v,this.start,this.end,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($G__23616_coll$jscomp$420$$,$G__23617_o$jscomp$103$$){$G__23616_coll$jscomp$420$$=this.$meta$;$G__23617_o$jscomp$103$$=$cljs$core$_assoc_n$$(this.v,this.end,$G__23617_o$jscomp$103$$);var $G__23618$$=this.start,$G__23619$$=this.end+1;return $cljs$core$build_subvec$$.$cljs$core$IFn$_invoke$arity$5$?$cljs$core$build_subvec$$.$cljs$core$IFn$_invoke$arity$5$($G__23616_coll$jscomp$420$$,$G__23617_o$jscomp$103$$,$G__23618$$,
$G__23619$$,null):$cljs$core$build_subvec$$($G__23616_coll$jscomp$420$$,$G__23617_o$jscomp$103$$,$G__23618$$,$G__23619$$,null)};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$5$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$423$$,$args23599$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23599$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$93$$){return this.$cljs$core$IIndexed$_nth$arity$2$(null,$k$jscomp$93$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$94$$,$not_found$jscomp$18$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$94$$,$not_found$jscomp$18$$)};$APP.$cljs$core$Subvec$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
var $cljs$core$tv_push_tail$$=function $cljs$core$tv_push_tail$$($JSCompiler_temp$jscomp$208_tv$$,$G__23627$jscomp$inline_2784_level$jscomp$25$$,$parent$jscomp$6_ret$jscomp$26$$,$tail_node$$){$parent$jscomp$6_ret$jscomp$26$$=$cljs$core$tv_ensure_editable$$($JSCompiler_temp$jscomp$208_tv$$.root.$edit$,$parent$jscomp$6_ret$jscomp$26$$);var $subidx$jscomp$3$$=$JSCompiler_temp$jscomp$208_tv$$.$cnt$-1>>>$G__23627$jscomp$inline_2784_level$jscomp$25$$&31;if($G__23627$jscomp$inline_2784_level$jscomp$25$$===
5)$JSCompiler_temp$jscomp$208_tv$$=$tail_node$$;else{var $child$jscomp$inline_2783$$=$parent$jscomp$6_ret$jscomp$26$$.$arr$[$subidx$jscomp$3$$];$child$jscomp$inline_2783$$!=null?($G__23627$jscomp$inline_2784_level$jscomp$25$$-=5,$JSCompiler_temp$jscomp$208_tv$$=$cljs$core$tv_push_tail$$.$cljs$core$IFn$_invoke$arity$4$?$cljs$core$tv_push_tail$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$208_tv$$,$G__23627$jscomp$inline_2784_level$jscomp$25$$,$child$jscomp$inline_2783$$,$tail_node$$):$cljs$core$tv_push_tail$$($JSCompiler_temp$jscomp$208_tv$$,
$G__23627$jscomp$inline_2784_level$jscomp$25$$,$child$jscomp$inline_2783$$,$tail_node$$)):$JSCompiler_temp$jscomp$208_tv$$=$cljs$core$new_path$$($JSCompiler_temp$jscomp$208_tv$$.root.$edit$,$G__23627$jscomp$inline_2784_level$jscomp$25$$-5,$tail_node$$)}$parent$jscomp$6_ret$jscomp$26$$.$arr$[$subidx$jscomp$3$$]=$JSCompiler_temp$jscomp$208_tv$$;return $parent$jscomp$6_ret$jscomp$26$$};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$TransientVector$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientCollection$_conj_BANG_$arity$2$=function($tail_node$jscomp$1_tcoll$jscomp$25$$,$new_root_array_o$jscomp$104$$){if(this.root.$edit$){if(this.$cnt$-$cljs$core$tail_off$$(this)<32)this.$tail$[this.$cnt$&31]=$new_root_array_o$jscomp$104$$;else{$tail_node$jscomp$1_tcoll$jscomp$25$$=new $cljs$core$VectorNode$$(this.root.$edit$,this.$tail$);var $new_shift$jscomp$1_new_tail$jscomp$3$$=[null,null,null,null,null,null,null,null,null,null,null,null,null,
null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];$new_shift$jscomp$1_new_tail$jscomp$3$$[0]=$new_root_array_o$jscomp$104$$;this.$tail$=$new_shift$jscomp$1_new_tail$jscomp$3$$;this.$cnt$>>>5>1<<this.shift?($new_root_array_o$jscomp$104$$=[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],$new_shift$jscomp$1_new_tail$jscomp$3$$=this.shift+5,$new_root_array_o$jscomp$104$$[0]=
this.root,$new_root_array_o$jscomp$104$$[1]=$cljs$core$new_path$$(this.root.$edit$,this.shift,$tail_node$jscomp$1_tcoll$jscomp$25$$),this.root=new $cljs$core$VectorNode$$(this.root.$edit$,$new_root_array_o$jscomp$104$$),this.shift=$new_shift$jscomp$1_new_tail$jscomp$3$$):this.root=$cljs$core$tv_push_tail$$(this,this.shift,this.root,$tail_node$jscomp$1_tcoll$jscomp$25$$)}this.$cnt$+=1;return this}throw Error("conj! after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientCollection$_persistent_BANG_$arity$1$=function(){if(this.root.$edit$){this.root.$edit$=null;var $len$jscomp$20$$=this.$cnt$-$cljs$core$tail_off$$(this),$trimmed_tail$$=Array($len$jscomp$20$$);$cljs$core$array_copy$$(this.$tail$,0,$trimmed_tail$$,0,$len$jscomp$20$$);return new $APP.$cljs$core$PersistentVector$$(null,this.$cnt$,this.shift,this.root,$trimmed_tail$$,null)}throw Error("persistent! called twice");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$=function($tcoll$jscomp$27$$,$key$jscomp$127$$,$val$jscomp$80$$){if(typeof $key$jscomp$127$$==="number")return this.$cljs$core$ITransientVector$_assoc_n_BANG_$arity$3$(null,$key$jscomp$127$$,$val$jscomp$80$$);throw Error("TransientVector's key for assoc! must be a number.");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientVector$_assoc_n_BANG_$arity$3$=function($new_root$jscomp$3_tcoll$jscomp$28$$,$n$jscomp$113$$,$val$jscomp$81$$){var $self__$jscomp$429$$=this;if($self__$jscomp$429$$.root.$edit$){if(0<=$n$jscomp$113$$&&$n$jscomp$113$$<$self__$jscomp$429$$.$cnt$)return $cljs$core$tail_off$$(this)<=$n$jscomp$113$$?$self__$jscomp$429$$.$tail$[$n$jscomp$113$$&31]=$val$jscomp$81$$:($new_root$jscomp$3_tcoll$jscomp$28$$=function $cljs$core$go$$($level$jscomp$28_val$jscomp$inline_11265$$,
$node$jscomp$24_node__$1$jscomp$1$$){$node$jscomp$24_node__$1$jscomp$1$$=$cljs$core$tv_ensure_editable$$($self__$jscomp$429$$.root.$edit$,$node$jscomp$24_node__$1$jscomp$1$$);if($level$jscomp$28_val$jscomp$inline_11265$$===0)$node$jscomp$24_node__$1$jscomp$1$$.$arr$[$n$jscomp$113$$&31]=$val$jscomp$81$$;else{var $subidx$jscomp$5$$=$n$jscomp$113$$>>>$level$jscomp$28_val$jscomp$inline_11265$$&31;$level$jscomp$28_val$jscomp$inline_11265$$=$cljs$core$go$$($level$jscomp$28_val$jscomp$inline_11265$$-5,$node$jscomp$24_node__$1$jscomp$1$$.$arr$[$subidx$jscomp$5$$]);
$node$jscomp$24_node__$1$jscomp$1$$.$arr$[$subidx$jscomp$5$$]=$level$jscomp$28_val$jscomp$inline_11265$$}return $node$jscomp$24_node__$1$jscomp$1$$}($self__$jscomp$429$$.shift,$self__$jscomp$429$$.root),$self__$jscomp$429$$.root=$new_root$jscomp$3_tcoll$jscomp$28$$),this;if($n$jscomp$113$$===$self__$jscomp$429$$.$cnt$)return this.$cljs$core$ITransientCollection$_conj_BANG_$arity$2$(null,$val$jscomp$81$$);throw Error(["Index ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$113$$),
" out of bounds for TransientVector of length",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$429$$.$cnt$)].join(""));}throw Error("assoc! after persistent!");};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){if(this.root.$edit$)return this.$cnt$;throw Error("count after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($coll$jscomp$424$$,$n$jscomp$114$$){if(this.root.$edit$)return $cljs$core$array_for$$(this,$n$jscomp$114$$)[$n$jscomp$114$$&31];throw Error("nth after persistent!");};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($coll$jscomp$425$$,$n$jscomp$115$$,$not_found$jscomp$19$$){return 0<=$n$jscomp$115$$&&$n$jscomp$115$$<this.$cnt$?this.$cljs$core$IIndexed$_nth$arity$2$(null,$n$jscomp$115$$):$not_found$jscomp$19$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($coll$jscomp$426$$,$k$jscomp$95$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$95$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($coll$jscomp$427$$,$k$jscomp$96$$,$not_found$jscomp$20$$){if(this.root.$edit$)return typeof $k$jscomp$96$$==="number"?this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$96$$,$not_found$jscomp$20$$):$not_found$jscomp$20$$;throw Error("lookup after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$6$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$437$$,$args23633$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23633$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$97$$){return this.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$97$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$98$$,$not_found$jscomp$21$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$98$$,$not_found$jscomp$21$$)};
$cljs$core$PersistentQueueIter$$.prototype.hasNext=function(){var $and__5023__auto__$jscomp$25_or__5025__auto__$jscomp$28$$=this.$fseq$!=null&&$APP.$cljs$core$seq$$(this.$fseq$);return $and__5023__auto__$jscomp$25_or__5025__auto__$jscomp$28$$?$and__5023__auto__$jscomp$25_or__5025__auto__$jscomp$28$$:($and__5023__auto__$jscomp$25_or__5025__auto__$jscomp$28$$=this.$riter$!=null)?this.$riter$.hasNext():$and__5023__auto__$jscomp$25_or__5025__auto__$jscomp$28$$};
$cljs$core$PersistentQueueIter$$.prototype.next=function(){if(this.$fseq$!=null){var $ret$jscomp$27$$=$APP.$cljs$core$first$$(this.$fseq$);this.$fseq$=$APP.$cljs$core$next$$(this.$fseq$);return $ret$jscomp$27$$}if(this.$riter$!=null&&this.$riter$.hasNext())return this.$riter$.next();throw Error("No such element");};$cljs$core$PersistentQueueIter$$.prototype.remove=function(){return Error("Unsupported operation")};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$PersistentQueueSeq$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$77$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$77$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__27689$$=null;$G__27689$$=function($x$jscomp$501$$,$start$jscomp$85$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$501$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$501$$,$start$jscomp$85$$)}throw Error("Invalid arity: "+arguments.length);};$G__27689$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$499$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$499$$,0)};$G__27689$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$500$$,$start$jscomp$84$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$500$$,$start$jscomp$84$$)};return $G__27689$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__27692__1$$($x$jscomp$502$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$502$$,$APP.$cljs$core$count$$(this))}var $G__27692$$=null;$G__27692$$=function($x$jscomp$504$$,$start$jscomp$87$$){switch(arguments.length){case 1:return $G__27692__1$$.call(this,$x$jscomp$504$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$504$$,$start$jscomp$87$$)}throw Error("Invalid arity: "+
arguments.length);};$G__27692$$.$cljs$core$IFn$_invoke$arity$1$=$G__27692__1$$;$G__27692$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$503$$,$start$jscomp$86$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$503$$,$start$jscomp$86$$)};return $G__27692$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){var $temp__5823__auto__$jscomp$5$$=$APP.$cljs$core$next$$(this.$front$);return $temp__5823__auto__$jscomp$5$$?new $cljs$core$PersistentQueueSeq$$(this.$meta$,$temp__5823__auto__$jscomp$5$$,this.$rear$,null):this.$rear$!=null?new $cljs$core$PersistentQueueSeq$$(this.$meta$,this.$rear$,null,null):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$10_h__5134__auto____$1$jscomp$10$$=this.$__hash$;return $h__5134__auto__$jscomp$10_h__5134__auto____$1$jscomp$10$$!=null?$h__5134__auto__$jscomp$10_h__5134__auto____$1$jscomp$10$$:this.$__hash$=$h__5134__auto__$jscomp$10_h__5134__auto____$1$jscomp$10$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$438$$,$other$jscomp$78$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$78$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$_with_meta$$($APP.$cljs$core$List$EMPTY$$,this.$meta$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return $APP.$cljs$core$first$$(this.$front$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){var $temp__5823__auto__$jscomp$6$$=$APP.$cljs$core$next$$(this.$front$);return $temp__5823__auto__$jscomp$6$$?new $cljs$core$PersistentQueueSeq$$(this.$meta$,$temp__5823__auto__$jscomp$6$$,this.$rear$,null):this.$rear$==null?this.$cljs$core$IEmptyableCollection$_empty$arity$1$(null):new $cljs$core$PersistentQueueSeq$$(this.$meta$,this.$rear$,null,null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$443$$,$new_meta$jscomp$16$$){return $new_meta$jscomp$16$$===this.$meta$?this:new $cljs$core$PersistentQueueSeq$$($new_meta$jscomp$16$$,this.$front$,this.$rear$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$444$$,$o$jscomp$105$$){return $APP.$cljs$core$cons$$($o$jscomp$105$$,this)};
$cljs$core$PersistentQueueSeq$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$PersistentQueue$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$79$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$79$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__27703$$=null;$G__27703$$=function($x$jscomp$507$$,$start$jscomp$89$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$507$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$507$$,$start$jscomp$89$$)}throw Error("Invalid arity: "+arguments.length);};$G__27703$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$505$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$505$$,0)};$G__27703$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$506$$,$start$jscomp$88$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$506$$,$start$jscomp$88$$)};return $G__27703$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__27704__1$$($x$jscomp$508$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$508$$,this.count.$cljs$core$IFn$_invoke$arity$1$?this.count.$cljs$core$IFn$_invoke$arity$1$(this):this.count(this))}var $G__27704$$=null;$G__27704$$=function($x$jscomp$510$$,$start$jscomp$91$$){switch(arguments.length){case 1:return $G__27704__1$$.call(this,$x$jscomp$510$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$510$$,$start$jscomp$91$$)}throw Error("Invalid arity: "+arguments.length);};$G__27704$$.$cljs$core$IFn$_invoke$arity$1$=$G__27704__1$$;$G__27704$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$509$$,$start$jscomp$90$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$509$$,$start$jscomp$90$$)};return $G__27704$$}();
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $cljs$core$PersistentQueueIter$$(this.$front$,$APP.$cljs$core$_iterator$$(this.$rear$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$core$PersistentQueue$$(this.$meta$,this.count,this.$front$,this.$rear$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.count};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_peek$arity$1$=function(){return $APP.$cljs$core$first$$(this.$front$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_pop$arity$1$=function(){if($APP.$cljs$core$truth_$$(this.$front$)){var $temp__5823__auto__$jscomp$7$$=$APP.$cljs$core$next$$(this.$front$);return $temp__5823__auto__$jscomp$7$$?new $cljs$core$PersistentQueue$$(this.$meta$,this.count-1,$temp__5823__auto__$jscomp$7$$,this.$rear$,null):new $cljs$core$PersistentQueue$$(this.$meta$,this.count-1,$APP.$cljs$core$seq$$(this.$rear$),$APP.$cljs$core$PersistentVector$EMPTY$$,null)}return this};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$11_h__5134__auto____$1$jscomp$11$$=this.$__hash$;return $h__5134__auto__$jscomp$11_h__5134__auto____$1$jscomp$11$$!=null?$h__5134__auto__$jscomp$11_h__5134__auto____$1$jscomp$11$$:this.$__hash$=$h__5134__auto__$jscomp$11_h__5134__auto____$1$jscomp$11$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$457$$,$other$jscomp$80$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$80$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$_with_meta$$($APP.$cljs$core$PersistentQueue$EMPTY$$,this.$meta$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return $APP.$cljs$core$first$$(this.$front$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){return $APP.$cljs$core$rest$$($APP.$cljs$core$seq$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){var $rear__$1$$=$APP.$cljs$core$seq$$(this.$rear$),$or__5025__auto__$jscomp$inline_2786$$=this.$front$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_2786$$)?$or__5025__auto__$jscomp$inline_2786$$:$rear__$1$$)?new $cljs$core$PersistentQueueSeq$$(null,this.$front$,$APP.$cljs$core$seq$$($rear__$1$$),null):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$462$$,$new_meta$jscomp$17$$){return $new_meta$jscomp$17$$===this.$meta$?this:new $cljs$core$PersistentQueue$$($new_meta$jscomp$17$$,this.count,this.$front$,this.$rear$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$463_or__5025__auto__$jscomp$inline_2788$$,$JSCompiler_temp$jscomp$210_o$jscomp$106$$){$APP.$cljs$core$truth_$$(this.$front$)?($coll$jscomp$463_or__5025__auto__$jscomp$inline_2788$$=this.$rear$,$JSCompiler_temp$jscomp$210_o$jscomp$106$$=new $cljs$core$PersistentQueue$$(this.$meta$,this.count+1,this.$front$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($coll$jscomp$463_or__5025__auto__$jscomp$inline_2788$$)?
$coll$jscomp$463_or__5025__auto__$jscomp$inline_2788$$:$APP.$cljs$core$PersistentVector$EMPTY$$,$JSCompiler_temp$jscomp$210_o$jscomp$106$$),null)):$JSCompiler_temp$jscomp$210_o$jscomp$106$$=new $cljs$core$PersistentQueue$$(this.$meta$,this.count+1,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$(this.$front$,$JSCompiler_temp$jscomp$210_o$jscomp$106$$),$APP.$cljs$core$PersistentVector$EMPTY$$,null);return $JSCompiler_temp$jscomp$210_o$jscomp$106$$};
$APP.$cljs$core$PersistentQueue$EMPTY$$=new $cljs$core$PersistentQueue$$(null,0,null,$APP.$cljs$core$PersistentVector$EMPTY$$,$cljs$core$empty_ordered_hash$$);$cljs$core$PersistentQueue$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$cljs$core$NeverEquiv$$.prototype.equiv=function($other$jscomp$81$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$81$$)};$cljs$core$NeverEquiv$$.prototype.$cljs$core$IEquiv$_equiv$arity$2$=function(){return!1};
var $cljs$core$never_equiv$$=new $cljs$core$NeverEquiv$$;$APP.$cljs$core$RecordIter$$.prototype.hasNext=function(){var $or__5025__auto__$jscomp$31$$=this.i<this.$base_count$;return $or__5025__auto__$jscomp$31$$?$or__5025__auto__$jscomp$31$$:this.$ext_map_iter$.hasNext()};
$APP.$cljs$core$RecordIter$$.prototype.next=function(){if(this.i<this.$base_count$){var $k$jscomp$111$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$(this.$fields$,this.i);this.i+=1;return new $APP.$cljs$core$MapEntry$$($k$jscomp$111$$,$APP.$cljs$core$_lookup$$(this.$record$,$k$jscomp$111$$),null)}return this.$ext_map_iter$.next()};$APP.$cljs$core$RecordIter$$.prototype.remove=function(){return Error("Unsupported operation")};
$cljs$core$ES6EntriesIterator$$.prototype.next=function(){if(this.s!=null){var $v$jscomp$39_vec__23646$$=$APP.$cljs$core$first$$(this.s),$k$jscomp$112$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$39_vec__23646$$,0,null);$v$jscomp$39_vec__23646$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$39_vec__23646$$,1,null);this.s=$APP.$cljs$core$next$$(this.s);return{value:[$k$jscomp$112$$,$v$jscomp$39_vec__23646$$],done:!1}}return{value:null,done:!0}};
$cljs$core$ES6SetEntriesIterator$$.prototype.next=function(){if(this.s!=null){var $x$jscomp$512$$=$APP.$cljs$core$first$$(this.s);this.s=$APP.$cljs$core$next$$(this.s);return{value:[$x$jscomp$512$$,$x$jscomp$512$$],done:!1}}return{value:null,done:!0}};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$MapEntry$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$_find$arity$2$=function($node$jscomp$25$$,$k$jscomp$121$$){switch($k$jscomp$121$$){case 0:return new $APP.$cljs$core$MapEntry$$(0,this.key,null);case 1:return new $APP.$cljs$core$MapEntry$$(1,this.$val$,null);default:return null}};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__27791$$=null;$G__27791$$=function($x$jscomp$515$$,$start$jscomp$93$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$515$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$515$$,$start$jscomp$93$$)}throw Error("Invalid arity: "+arguments.length);};$G__27791$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$513$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$513$$,0)};$G__27791$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$514$$,$start$jscomp$92$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$514$$,$start$jscomp$92$$)};return $G__27791$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__27792__1$$($x$jscomp$516$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$516$$,$APP.$cljs$core$count$$(this))}var $G__27792$$=null;$G__27792$$=function($x$jscomp$518$$,$start$jscomp$95$$){switch(arguments.length){case 1:return $G__27792__1$$.call(this,$x$jscomp$518$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$518$$,$start$jscomp$95$$)}throw Error("Invalid arity: "+
arguments.length);};$G__27792$$.$cljs$core$IFn$_invoke$arity$1$=$G__27792__1$$;$G__27792$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$517$$,$start$jscomp$94$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$517$$,$start$jscomp$94$$)};return $G__27792$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($node$jscomp$26$$,$k$jscomp$122$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$122$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($node$jscomp$27$$,$k$jscomp$123$$,$not_found$jscomp$24$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$123$$,$not_found$jscomp$24$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($node$jscomp$28$$,$n$jscomp$116$$){if($n$jscomp$116$$===0)return this.key;if($n$jscomp$116$$===1)return this.$val$;throw Error("Index out of bounds");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($node$jscomp$29$$,$n$jscomp$117$$,$not_found$jscomp$25$$){return $n$jscomp$117$$===0?this.key:$n$jscomp$117$$===1?this.$val$:$not_found$jscomp$25$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IVector$_assoc_n$arity$3$=function($node$jscomp$30$$,$n$jscomp$118$$,$v$jscomp$42$$){return(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key,this.$val$],null)).$cljs$core$IVector$_assoc_n$arity$3$(null,$n$jscomp$118$$,$v$jscomp$42$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMapEntry$_key$arity$1$=function(){return this.key};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMapEntry$_val$arity$1$=function(){return this.$val$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_peek$arity$1$=function(){return this.$val$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_pop$arity$1$=function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key],null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReversible$_rseq$arity$1$=function(){return new $APP.$cljs$core$IndexedSeq$$([this.$val$,this.key],0,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$13_h__5134__auto____$1$jscomp$13$$=this.$__hash$;return $h__5134__auto__$jscomp$13_h__5134__auto____$1$jscomp$13$$!=null?$h__5134__auto__$jscomp$13_h__5134__auto____$1$jscomp$13$$:this.$__hash$=$h__5134__auto__$jscomp$13_h__5134__auto____$1$jscomp$13$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$490$$,$other$jscomp$85$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$85$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($node$jscomp$39$$,$f$jscomp$252$$){return $cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$f$jscomp$252$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($node$jscomp$40$$,$f$jscomp$253$$,$start$jscomp$96$$){return $cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$f$jscomp$253$$,$start$jscomp$96$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($node$jscomp$41$$,$k$jscomp$124$$,$v$jscomp$43$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key,this.$val$],null),$k$jscomp$124$$,$v$jscomp$43$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($node$jscomp$42$$,$k$jscomp$125$$){return $k$jscomp$125$$===0||$k$jscomp$125$$===1};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return new $APP.$cljs$core$IndexedSeq$$([this.key,this.$val$],0,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($node$jscomp$44$$,$meta$jscomp$42$$){return $APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key,this.$val$],null),$meta$jscomp$42$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($node$jscomp$45$$,$o$jscomp$108$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key,this.$val$,$o$jscomp$108$$],null)};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$8$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$536$$,$args23649$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23649$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$126$$){return this.$cljs$core$IIndexed$_nth$arity$2$(null,$k$jscomp$126$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$127$$,$not_found$jscomp$26$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$127$$,$not_found$jscomp$26$$)};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$PersistentArrayMapSeq$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$86$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$86$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__27805$$=null;$G__27805$$=function($x$jscomp$522$$,$start$jscomp$98$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$522$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$522$$,$start$jscomp$98$$)}throw Error("Invalid arity: "+arguments.length);};$G__27805$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$520$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$520$$,0)};$G__27805$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$521$$,$start$jscomp$97$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$521$$,$start$jscomp$97$$)};return $G__27805$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__27808__1$$($x$jscomp$523$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$523$$,$APP.$cljs$core$count$$(this))}var $G__27808$$=null;$G__27808$$=function($x$jscomp$525$$,$start$jscomp$100$$){switch(arguments.length){case 1:return $G__27808__1$$.call(this,$x$jscomp$525$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$525$$,$start$jscomp$100$$)}throw Error("Invalid arity: "+
arguments.length);};$G__27808$$.$cljs$core$IFn$_invoke$arity$1$=$G__27808__1$$;$G__27808$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$524$$,$start$jscomp$99$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$524$$,$start$jscomp$99$$)};return $G__27808$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$_meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return this.i<this.$arr$.length-2?new $APP.$cljs$core$PersistentArrayMapSeq$$(this.$arr$,this.i+2,null):null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return(this.$arr$.length-this.i)/2};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$500$$,$other$jscomp$87$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$87$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$502$$,$f$jscomp$254$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$254$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$503$$,$f$jscomp$255$$,$start$jscomp$101$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$255$$,$start$jscomp$101$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return new $APP.$cljs$core$MapEntry$$(this.$arr$[this.i],this.$arr$[this.i+1],null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){return this.i<this.$arr$.length-2?new $APP.$cljs$core$PersistentArrayMapSeq$$(this.$arr$,this.i+2,null):$APP.$cljs$core$List$EMPTY$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$507$$,$new_meta$jscomp$19$$){return $new_meta$jscomp$19$$===this.$_meta$?this:new $APP.$cljs$core$PersistentArrayMapSeq$$(this.$arr$,this.i,$new_meta$jscomp$19$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$508$$,$o$jscomp$109$$){return $APP.$cljs$core$cons$$($o$jscomp$109$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDrop$_drop$arity$2$=function($coll$jscomp$509$$,$n$jscomp$119$$){return $n$jscomp$119$$<this.$cljs$core$ICounted$_count$arity$1$(null)?new $APP.$cljs$core$PersistentArrayMapSeq$$(this.$arr$,this.i+2*$n$jscomp$119$$,null):null};$APP.$cljs$core$PersistentArrayMapSeq$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$cljs$core$PersistentArrayMapIterator$$.prototype.hasNext=function(){return this.i<this.$cnt$};
$cljs$core$PersistentArrayMapIterator$$.prototype.next=function(){var $ret$jscomp$28$$=new $APP.$cljs$core$MapEntry$$(this.$arr$[this.i],this.$arr$[this.i+1],null);this.i+=2;return $ret$jscomp$28$$};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$PersistentArrayMap$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$_find$arity$2$=function($coll$jscomp$510_idx$jscomp$21$$,$k$jscomp$128$$){$coll$jscomp$510_idx$jscomp$21$$=$cljs$core$array_index_of$$(this.$arr$,$k$jscomp$128$$);return $coll$jscomp$510_idx$jscomp$21$$===-1?null:new $APP.$cljs$core$MapEntry$$(this.$arr$[$coll$jscomp$510_idx$jscomp$21$$],this.$arr$[$coll$jscomp$510_idx$jscomp$21$$+1],null)};$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$88$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$88$$)};$APP.$JSCompiler_prototypeAlias$$.keys=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$keys$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$keys$$.$cljs$core$IFn$_invoke$arity$1$(this):$APP.$cljs$core$keys$$(this))};$APP.$JSCompiler_prototypeAlias$$.entries=function(){return $APP.$cljs$core$es6_entries_iterator$$($APP.$cljs$core$seq$$(this))};
$APP.$JSCompiler_prototypeAlias$$.values=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$vals$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$vals$$.$cljs$core$IFn$_invoke$arity$1$(this):$APP.$cljs$core$vals$$(this))};$APP.$JSCompiler_prototypeAlias$$.has=function($k$jscomp$129$$){return $APP.$cljs$core$contains_QMARK_$$(this,$k$jscomp$129$$)};
$APP.$JSCompiler_prototypeAlias$$.get=function($k$jscomp$130$$,$not_found$jscomp$27$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$130$$,$not_found$jscomp$27$$)};
$APP.$JSCompiler_prototypeAlias$$.forEach=function($f$jscomp$256$$){for(var $G__27829_seq__23654_seq__23654__$1_temp__5825__auto__$jscomp$10$$=$APP.$cljs$core$seq$$(this),$c__5548__auto__$jscomp$1_chunk__23655_vec__23667$$=null,$G__27831_count__23656$$=0,$i__23657$$=0;;)if($i__23657$$<$G__27831_count__23656$$){var $v$jscomp$44_vec__23664$$=$c__5548__auto__$jscomp$1_chunk__23655_vec__23667$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__23657$$),$G__27830_k$jscomp$131$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$44_vec__23664$$,
0,null);$v$jscomp$44_vec__23664$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$44_vec__23664$$,1,null);$f$jscomp$256$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$256$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$44_vec__23664$$,$G__27830_k$jscomp$131$$):$f$jscomp$256$$($v$jscomp$44_vec__23664$$,$G__27830_k$jscomp$131$$);$i__23657$$+=1}else if($G__27829_seq__23654_seq__23654__$1_temp__5825__auto__$jscomp$10$$=$APP.$cljs$core$seq$$($G__27829_seq__23654_seq__23654__$1_temp__5825__auto__$jscomp$10$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__27829_seq__23654_seq__23654__$1_temp__5825__auto__$jscomp$10$$)?
($c__5548__auto__$jscomp$1_chunk__23655_vec__23667$$=$APP.$cljs$core$_chunked_first$$($G__27829_seq__23654_seq__23654__$1_temp__5825__auto__$jscomp$10$$),$G__27829_seq__23654_seq__23654__$1_temp__5825__auto__$jscomp$10$$=$APP.$cljs$core$_chunked_rest$$($G__27829_seq__23654_seq__23654__$1_temp__5825__auto__$jscomp$10$$),$G__27830_k$jscomp$131$$=$c__5548__auto__$jscomp$1_chunk__23655_vec__23667$$,$G__27831_count__23656$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$1_chunk__23655_vec__23667$$),$c__5548__auto__$jscomp$1_chunk__23655_vec__23667$$=
$G__27830_k$jscomp$131$$):($c__5548__auto__$jscomp$1_chunk__23655_vec__23667$$=$APP.$cljs$core$first$$($G__27829_seq__23654_seq__23654__$1_temp__5825__auto__$jscomp$10$$),$G__27830_k$jscomp$131$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$1_chunk__23655_vec__23667$$,0,null),$v$jscomp$44_vec__23664$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$1_chunk__23655_vec__23667$$,1,null),$f$jscomp$256$$.$cljs$core$IFn$_invoke$arity$2$?
$f$jscomp$256$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$44_vec__23664$$,$G__27830_k$jscomp$131$$):$f$jscomp$256$$($v$jscomp$44_vec__23664$$,$G__27830_k$jscomp$131$$),$G__27829_seq__23654_seq__23654__$1_temp__5825__auto__$jscomp$10$$=$APP.$cljs$core$next$$($G__27829_seq__23654_seq__23654__$1_temp__5825__auto__$jscomp$10$$),$c__5548__auto__$jscomp$1_chunk__23655_vec__23667$$=null,$G__27831_count__23656$$=0),$i__23657$$=0;else return null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($coll$jscomp$518$$,$k$jscomp$132$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$132$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($coll$jscomp$519_idx$jscomp$22$$,$k$jscomp$133$$,$not_found$jscomp$28$$){$coll$jscomp$519_idx$jscomp$22$$=$cljs$core$array_index_of$$(this.$arr$,$k$jscomp$133$$);return $coll$jscomp$519_idx$jscomp$22$$===-1?$not_found$jscomp$28$$:this.$arr$[$coll$jscomp$519_idx$jscomp$22$$+1]};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($coll$jscomp$520_len$jscomp$29$$,$f$jscomp$257$$,$G__23670$jscomp$inline_2816_G__27841_init$jscomp$31_init__$1$jscomp$4_init__$2$jscomp$6$$){$coll$jscomp$520_len$jscomp$29$$=this.$arr$.length;for(var $i$jscomp$234$$=0;;)if($i$jscomp$234$$<$coll$jscomp$520_len$jscomp$29$$){var $G__23671$jscomp$inline_2817$$=this.$arr$[$i$jscomp$234$$],$G__23672$jscomp$inline_2818$$=this.$arr$[$i$jscomp$234$$+1];$G__23670$jscomp$inline_2816_G__27841_init$jscomp$31_init__$1$jscomp$4_init__$2$jscomp$6$$=
$f$jscomp$257$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$257$$.$cljs$core$IFn$_invoke$arity$3$($G__23670$jscomp$inline_2816_G__27841_init$jscomp$31_init__$1$jscomp$4_init__$2$jscomp$6$$,$G__23671$jscomp$inline_2817$$,$G__23672$jscomp$inline_2818$$):$f$jscomp$257$$($G__23670$jscomp$inline_2816_G__27841_init$jscomp$31_init__$1$jscomp$4_init__$2$jscomp$6$$,$G__23671$jscomp$inline_2817$$,$G__23672$jscomp$inline_2818$$);if($cljs$core$reduced_QMARK_$$($G__23670$jscomp$inline_2816_G__27841_init$jscomp$31_init__$1$jscomp$4_init__$2$jscomp$6$$))return $APP.$cljs$core$_deref$$($G__23670$jscomp$inline_2816_G__27841_init$jscomp$31_init__$1$jscomp$4_init__$2$jscomp$6$$);
$i$jscomp$234$$+=2}else return $G__23670$jscomp$inline_2816_G__27841_init$jscomp$31_init__$1$jscomp$4_init__$2$jscomp$6$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $cljs$core$PersistentArrayMapIterator$$(this.$arr$,this.$cnt$*2)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(this.$meta$,this.$cnt$,this.$arr$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.$cnt$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$14_h__5134__auto____$1$jscomp$14$$=this.$__hash$;return $h__5134__auto__$jscomp$14_h__5134__auto____$1$jscomp$14$$!=null?$h__5134__auto__$jscomp$14_h__5134__auto____$1$jscomp$14$$:this.$__hash$=$h__5134__auto__$jscomp$14_h__5134__auto____$1$jscomp$14$$=$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($alen_coll$jscomp$524$$,$other$jscomp$89$$){if($APP.$cljs$core$map_QMARK_$$($other$jscomp$89$$)&&!$APP.$cljs$core$record_QMARK_$$($other$jscomp$89$$))if($alen_coll$jscomp$524$$=this.$arr$.length,this.$cnt$===$other$jscomp$89$$.$cljs$core$ICounted$_count$arity$1$(null))for(var $i$jscomp$235$$=0;;){if($i$jscomp$235$$<$alen_coll$jscomp$524$$){var $v$jscomp$45$$=$other$jscomp$89$$.$cljs$core$ILookup$_lookup$arity$3$(null,this.$arr$[$i$jscomp$235$$],
$cljs$core$lookup_sentinel$$);if($v$jscomp$45$$!==$cljs$core$lookup_sentinel$$)if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$arr$[$i$jscomp$235$$+1],$v$jscomp$45$$)){$i$jscomp$235$$+=2;continue}else return!1;else return!1}else return!0;break}else return!1;else return!1};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEditableCollection$_as_transient$arity$1$=function(){return new $cljs$core$TransientArrayMap$$(this.$arr$.length,$APP.$cljs$core$aclone$$(this.$arr$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$_with_meta$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this.$meta$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$527$$,$f$jscomp$258$$){return $cljs$core$iter_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$f$jscomp$258$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$528$$,$f$jscomp$259$$,$start$jscomp$102$$){return $cljs$core$iter_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$f$jscomp$259$$,$start$jscomp$102$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($coll$jscomp$529_len$jscomp$30$$,$k$jscomp$134$$){if($cljs$core$array_index_of$$(this.$arr$,$k$jscomp$134$$)>=0){$coll$jscomp$529_len$jscomp$30$$=this.$arr$.length;var $new_arr$jscomp$1_new_len$$=$coll$jscomp$529_len$jscomp$30$$-2;if($new_arr$jscomp$1_new_len$$===0)return this.$cljs$core$IEmptyableCollection$_empty$arity$1$(null);$new_arr$jscomp$1_new_len$$=Array($new_arr$jscomp$1_new_len$$);for(var $s$jscomp$90$$=0,$G__27853_G__27855_d$jscomp$82$$=
0;;){if($s$jscomp$90$$>=$coll$jscomp$529_len$jscomp$30$$)return new $APP.$cljs$core$PersistentArrayMap$$(this.$meta$,this.$cnt$-1,$new_arr$jscomp$1_new_len$$,null);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$134$$,this.$arr$[$s$jscomp$90$$])?$s$jscomp$90$$+=2:($new_arr$jscomp$1_new_len$$[$G__27853_G__27855_d$jscomp$82$$]=this.$arr$[$s$jscomp$90$$],$new_arr$jscomp$1_new_len$$[$G__27853_G__27855_d$jscomp$82$$+1]=this.$arr$[$s$jscomp$90$$+1],$G__27853_G__27855_d$jscomp$82$$+=2,$s$jscomp$90$$+=
2)}}else return this};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($arr$jscomp$inline_11267_coll$jscomp$530_idx$jscomp$24$$,$G__23675$jscomp$inline_2820_k$jscomp$135$$,$v$jscomp$46$$){$arr$jscomp$inline_11267_coll$jscomp$530_idx$jscomp$24$$=$cljs$core$array_index_of$$(this.$arr$,$G__23675$jscomp$inline_2820_k$jscomp$135$$);if($arr$jscomp$inline_11267_coll$jscomp$530_idx$jscomp$24$$===-1){if(this.$cnt$<$APP.$cljs$core$PersistentArrayMap$HASHMAP_THRESHOLD$$){$arr$jscomp$inline_11267_coll$jscomp$530_idx$jscomp$24$$=this.$arr$;
for(var $l$jscomp$inline_11270$$=$arr$jscomp$inline_11267_coll$jscomp$530_idx$jscomp$24$$.length,$narr$jscomp$inline_11271$$=Array($l$jscomp$inline_11270$$+2),$i_27785$jscomp$inline_11272$$=0;;)if($i_27785$jscomp$inline_11272$$<$l$jscomp$inline_11270$$)$narr$jscomp$inline_11271$$[$i_27785$jscomp$inline_11272$$]=$arr$jscomp$inline_11267_coll$jscomp$530_idx$jscomp$24$$[$i_27785$jscomp$inline_11272$$],$i_27785$jscomp$inline_11272$$+=1;else break;$narr$jscomp$inline_11271$$[$l$jscomp$inline_11270$$]=
$G__23675$jscomp$inline_2820_k$jscomp$135$$;$narr$jscomp$inline_11271$$[$l$jscomp$inline_11270$$+1]=$v$jscomp$46$$;return new $APP.$cljs$core$PersistentArrayMap$$(this.$meta$,this.$cnt$+1,$narr$jscomp$inline_11271$$,null)}return $APP.$cljs$core$_with_meta$$($APP.$cljs$core$_assoc$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$PersistentHashMap$EMPTY$$,this),$G__23675$jscomp$inline_2820_k$jscomp$135$$,$v$jscomp$46$$),this.$meta$)}if($v$jscomp$46$$===this.$arr$[$arr$jscomp$inline_11267_coll$jscomp$530_idx$jscomp$24$$+
1])return this;$G__23675$jscomp$inline_2820_k$jscomp$135$$=$APP.$cljs$core$aclone$$(this.$arr$);$G__23675$jscomp$inline_2820_k$jscomp$135$$[$arr$jscomp$inline_11267_coll$jscomp$530_idx$jscomp$24$$+1]=$v$jscomp$46$$;return new $APP.$cljs$core$PersistentArrayMap$$(this.$meta$,this.$cnt$,$G__23675$jscomp$inline_2820_k$jscomp$135$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($coll$jscomp$531$$,$k$jscomp$136$$){return $cljs$core$array_index_of$$(this.$arr$,$k$jscomp$136$$)!==-1};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){var $arr$jscomp$inline_2822$$=this.$arr$;return 0<=$arr$jscomp$inline_2822$$.length-2?new $APP.$cljs$core$PersistentArrayMapSeq$$($arr$jscomp$inline_2822$$,0,null):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$533$$,$new_meta$jscomp$20$$){return $new_meta$jscomp$20$$===this.$meta$?this:new $APP.$cljs$core$PersistentArrayMap$$($new_meta$jscomp$20$$,this.$cnt$,this.$arr$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($G__27861_coll$jscomp$534_ret$jscomp$29$$,$G__27862_entry$jscomp$3_es$$){if($APP.$cljs$core$vector_QMARK_$$($G__27862_entry$jscomp$3_es$$))return this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($G__27862_entry$jscomp$3_es$$,0),$APP.$cljs$core$_nth$$($G__27862_entry$jscomp$3_es$$,1));$G__27861_coll$jscomp$534_ret$jscomp$29$$=this;for($G__27862_entry$jscomp$3_es$$=$APP.$cljs$core$seq$$($G__27862_entry$jscomp$3_es$$);;){if($G__27862_entry$jscomp$3_es$$==
null)return $G__27861_coll$jscomp$534_ret$jscomp$29$$;var $e$jscomp$87$$=$APP.$cljs$core$first$$($G__27862_entry$jscomp$3_es$$);if($APP.$cljs$core$vector_QMARK_$$($e$jscomp$87$$))$G__27861_coll$jscomp$534_ret$jscomp$29$$=$APP.$cljs$core$_assoc$$($G__27861_coll$jscomp$534_ret$jscomp$29$$,$APP.$cljs$core$_nth$$($e$jscomp$87$$,0),$APP.$cljs$core$_nth$$($e$jscomp$87$$,1)),$G__27862_entry$jscomp$3_es$$=$APP.$cljs$core$next$$($G__27862_entry$jscomp$3_es$$);else throw Error("conj on a map takes map entries or seqables of map entries");
}};$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$9$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$590$$,$args23653$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23653$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$137$$){return this.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$137$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$138$$,$not_found$jscomp$29$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$138$$,$not_found$jscomp$29$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDrop$_drop$arity$2$=function($coll$jscomp$537_temp__5829__auto__$$,$n$jscomp$120$$){$coll$jscomp$537_temp__5829__auto__$$=this.$cljs$core$ISeqable$_seq$arity$1$(null);return $coll$jscomp$537_temp__5829__auto__$$==null?null:$cljs$core$_drop$$($coll$jscomp$537_temp__5829__auto__$$,$n$jscomp$120$$)};$APP.$cljs$core$PersistentArrayMap$EMPTY$$=new $APP.$cljs$core$PersistentArrayMap$$(null,0,[],$cljs$core$empty_unordered_hash$$);
$APP.$cljs$core$PersistentArrayMap$HASHMAP_THRESHOLD$$=8;$APP.$cljs$core$PersistentArrayMap$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$TransientArrayMap$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){if(this.$editable_QMARK_$)return $APP.$cljs$core$quot$$(this.$len$,2);throw Error("count after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($tcoll$jscomp$31$$,$k$jscomp$139$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$139$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($idx$jscomp$25_tcoll$jscomp$32$$,$k$jscomp$140$$,$not_found$jscomp$30$$){if(this.$editable_QMARK_$)return $idx$jscomp$25_tcoll$jscomp$32$$=$cljs$core$array_index_of$$(this.$arr$,$k$jscomp$140$$),$idx$jscomp$25_tcoll$jscomp$32$$===-1?$not_found$jscomp$30$$:this.$arr$[$idx$jscomp$25_tcoll$jscomp$32$$+1];throw Error("lookup after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientCollection$_conj_BANG_$arity$2$=function($G__27909_es$jscomp$1_tcoll$jscomp$33$$,$G__27910_o$jscomp$110_tcoll__$2$$){if(this.$editable_QMARK_$){if($APP.$cljs$core$map_entry_QMARK_$$($G__27910_o$jscomp$110_tcoll__$2$$))return this.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$(null,$APP.$cljs$core$key$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$key$$.$cljs$core$IFn$_invoke$arity$1$($G__27910_o$jscomp$110_tcoll__$2$$):$APP.$cljs$core$_key$$($G__27910_o$jscomp$110_tcoll__$2$$),
$APP.$cljs$core$val$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$val$$.$cljs$core$IFn$_invoke$arity$1$($G__27910_o$jscomp$110_tcoll__$2$$):$APP.$cljs$core$_val$$($G__27910_o$jscomp$110_tcoll__$2$$));if($APP.$cljs$core$vector_QMARK_$$($G__27910_o$jscomp$110_tcoll__$2$$))return this.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$(null,$G__27910_o$jscomp$110_tcoll__$2$$.$cljs$core$IFn$_invoke$arity$1$?$G__27910_o$jscomp$110_tcoll__$2$$.$cljs$core$IFn$_invoke$arity$1$(0):$G__27910_o$jscomp$110_tcoll__$2$$(0),
$G__27910_o$jscomp$110_tcoll__$2$$.$cljs$core$IFn$_invoke$arity$1$?$G__27910_o$jscomp$110_tcoll__$2$$.$cljs$core$IFn$_invoke$arity$1$(1):$G__27910_o$jscomp$110_tcoll__$2$$(1));$G__27909_es$jscomp$1_tcoll$jscomp$33$$=$APP.$cljs$core$seq$$($G__27910_o$jscomp$110_tcoll__$2$$);for($G__27910_o$jscomp$110_tcoll__$2$$=this;;){var $e$jscomp$88_temp__5823__auto__$jscomp$8$$=$APP.$cljs$core$first$$($G__27909_es$jscomp$1_tcoll$jscomp$33$$);if($APP.$cljs$core$truth_$$($e$jscomp$88_temp__5823__auto__$jscomp$8$$))$G__27909_es$jscomp$1_tcoll$jscomp$33$$=
$APP.$cljs$core$next$$($G__27909_es$jscomp$1_tcoll$jscomp$33$$),$G__27910_o$jscomp$110_tcoll__$2$$=$cljs$core$_assoc_BANG_$$($G__27910_o$jscomp$110_tcoll__$2$$,$APP.$cljs$core$key$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$key$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$88_temp__5823__auto__$jscomp$8$$):$APP.$cljs$core$_key$$($e$jscomp$88_temp__5823__auto__$jscomp$8$$),$APP.$cljs$core$val$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$val$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$88_temp__5823__auto__$jscomp$8$$):
$APP.$cljs$core$_val$$($e$jscomp$88_temp__5823__auto__$jscomp$8$$));else return $G__27910_o$jscomp$110_tcoll__$2$$}}else throw Error("conj! after persistent!");};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientCollection$_persistent_BANG_$arity$1$=function(){if(this.$editable_QMARK_$)return this.$editable_QMARK_$=!1,new $APP.$cljs$core$PersistentArrayMap$$(null,$APP.$cljs$core$quot$$(this.$len$,2),this.$arr$,null);throw Error("persistent! called twice");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$=function($idx$jscomp$26_tcoll$jscomp$35$$,$key$jscomp$131$$,$val$jscomp$84$$){if(this.$editable_QMARK_$){$idx$jscomp$26_tcoll$jscomp$35$$=$cljs$core$array_index_of$$(this.$arr$,$key$jscomp$131$$);if($idx$jscomp$26_tcoll$jscomp$35$$===-1)return this.$len$+2<=2*$APP.$cljs$core$PersistentArrayMap$HASHMAP_THRESHOLD$$?(this.$len$+=2,this.$arr$.push($key$jscomp$131$$),this.$arr$.push($val$jscomp$84$$),this):$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($cljs$core$array__GT_transient_hash_map$$.$cljs$core$IFn$_invoke$arity$2$?
$cljs$core$array__GT_transient_hash_map$$.$cljs$core$IFn$_invoke$arity$2$(this.$len$,this.$arr$):$cljs$core$array__GT_transient_hash_map$$(this.$len$,this.$arr$),$key$jscomp$131$$,$val$jscomp$84$$);$val$jscomp$84$$!==this.$arr$[$idx$jscomp$26_tcoll$jscomp$35$$+1]&&(this.$arr$[$idx$jscomp$26_tcoll$jscomp$35$$+1]=$val$jscomp$84$$);return this}throw Error("assoc! after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientMap$_dissoc_BANG_$arity$2$=function($G__23679_27914_idx$jscomp$27_tcoll$jscomp$36$$,$key$jscomp$132$$){if(this.$editable_QMARK_$)return $G__23679_27914_idx$jscomp$27_tcoll$jscomp$36$$=$cljs$core$array_index_of$$(this.$arr$,$key$jscomp$132$$),$G__23679_27914_idx$jscomp$27_tcoll$jscomp$36$$>=0&&(this.$arr$[$G__23679_27914_idx$jscomp$27_tcoll$jscomp$36$$]=this.$arr$[this.$len$-2],this.$arr$[$G__23679_27914_idx$jscomp$27_tcoll$jscomp$36$$+1]=this.$arr$[this.$len$-
1],$G__23679_27914_idx$jscomp$27_tcoll$jscomp$36$$=this.$arr$,$G__23679_27914_idx$jscomp$27_tcoll$jscomp$36$$.pop(),$G__23679_27914_idx$jscomp$27_tcoll$jscomp$36$$.pop(),this.$len$-=2),this;throw Error("dissoc! after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$10$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$602$$,$args23678$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23678$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($key$jscomp$133$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$key$jscomp$133$$,null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($key$jscomp$134$$,$not_found$jscomp$31$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$key$jscomp$134$$,$not_found$jscomp$31$$)};
$cljs$core$NodeIterator$$.prototype.advance=function(){for(var $len$jscomp$37$$=this.$arr$.length;;)if(this.i<$len$jscomp$37$$){var $JSCompiler_temp$jscomp$219_JSCompiler_temp$jscomp$220_found$jscomp$1_key$jscomp$135_new_iter$jscomp$inline_2842$$=this.$arr$[this.i],$node_or_val$$=this.$arr$[this.i+1];$JSCompiler_temp$jscomp$219_JSCompiler_temp$jscomp$220_found$jscomp$1_key$jscomp$135_new_iter$jscomp$inline_2842$$!=null?$JSCompiler_temp$jscomp$219_JSCompiler_temp$jscomp$220_found$jscomp$1_key$jscomp$135_new_iter$jscomp$inline_2842$$=
this.$next_entry$=new $APP.$cljs$core$MapEntry$$($JSCompiler_temp$jscomp$219_JSCompiler_temp$jscomp$220_found$jscomp$1_key$jscomp$135_new_iter$jscomp$inline_2842$$,$node_or_val$$,null):$node_or_val$$!=null?($JSCompiler_temp$jscomp$219_JSCompiler_temp$jscomp$220_found$jscomp$1_key$jscomp$135_new_iter$jscomp$inline_2842$$=$APP.$cljs$core$_iterator$$($node_or_val$$),$JSCompiler_temp$jscomp$219_JSCompiler_temp$jscomp$220_found$jscomp$1_key$jscomp$135_new_iter$jscomp$inline_2842$$=$JSCompiler_temp$jscomp$219_JSCompiler_temp$jscomp$220_found$jscomp$1_key$jscomp$135_new_iter$jscomp$inline_2842$$.hasNext()?
this.$next_iter$=$JSCompiler_temp$jscomp$219_JSCompiler_temp$jscomp$220_found$jscomp$1_key$jscomp$135_new_iter$jscomp$inline_2842$$:!1):$JSCompiler_temp$jscomp$219_JSCompiler_temp$jscomp$220_found$jscomp$1_key$jscomp$135_new_iter$jscomp$inline_2842$$=!1;this.i+=2;if($JSCompiler_temp$jscomp$219_JSCompiler_temp$jscomp$220_found$jscomp$1_key$jscomp$135_new_iter$jscomp$inline_2842$$)return!0}else return!1};
$cljs$core$NodeIterator$$.prototype.hasNext=function(){var $or__5025__auto__$jscomp$36_or__5025__auto____$1$jscomp$10$$=this.$next_entry$!=null;return $or__5025__auto__$jscomp$36_or__5025__auto____$1$jscomp$10$$?$or__5025__auto__$jscomp$36_or__5025__auto____$1$jscomp$10$$:($or__5025__auto__$jscomp$36_or__5025__auto____$1$jscomp$10$$=this.$next_iter$!=null)?$or__5025__auto__$jscomp$36_or__5025__auto____$1$jscomp$10$$:this.advance()};
$cljs$core$NodeIterator$$.prototype.next=function(){if(this.$next_entry$!=null){var $ret$jscomp$33$$=this.$next_entry$;this.$next_entry$=null;return $ret$jscomp$33$$}if(this.$next_iter$!=null)return $ret$jscomp$33$$=this.$next_iter$.next(),this.$next_iter$.hasNext()||(this.$next_iter$=null),$ret$jscomp$33$$;if(this.advance())return this.next();throw Error("No such element");};$cljs$core$NodeIterator$$.prototype.remove=function(){return Error("Unsupported operation")};
$APP.$JSCompiler_prototypeAlias$$=$cljs$core$BitmapIndexedNode$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$ensure_editable$=function($e$jscomp$89$$){if($e$jscomp$89$$===this.$edit$)return this;var $n$jscomp$123$$=$cljs$core$bit_count$$(this.$bitmap$),$new_arr$jscomp$3$$=Array($n$jscomp$123$$<0?4:2*($n$jscomp$123$$+1));$cljs$core$array_copy$$(this.$arr$,0,$new_arr$jscomp$3$$,0,2*$n$jscomp$123$$);return new $cljs$core$BitmapIndexedNode$$($e$jscomp$89$$,this.$bitmap$,$new_arr$jscomp$3$$)};
$APP.$JSCompiler_prototypeAlias$$.$inode_without_BANG_$=function($edit__$1$$,$n$jscomp$124_shift$jscomp$6$$,$hash$jscomp$5$$,$key$jscomp$136$$,$removed_leaf_QMARK_$$){var $bit$jscomp$2$$=1<<($hash$jscomp$5$$>>>$n$jscomp$124_shift$jscomp$6$$&31);if((this.$bitmap$&$bit$jscomp$2$$)===0)return this;var $idx$jscomp$28$$=$cljs$core$bit_count$$(this.$bitmap$&$bit$jscomp$2$$-1),$key_or_nil$$=this.$arr$[2*$idx$jscomp$28$$],$val_or_node$$=this.$arr$[2*$idx$jscomp$28$$+1];return $key_or_nil$$==null?($n$jscomp$124_shift$jscomp$6$$=
$val_or_node$$.$inode_without_BANG_$($edit__$1$$,$n$jscomp$124_shift$jscomp$6$$+5,$hash$jscomp$5$$,$key$jscomp$136$$,$removed_leaf_QMARK_$$),$n$jscomp$124_shift$jscomp$6$$===$val_or_node$$?this:$n$jscomp$124_shift$jscomp$6$$!=null?$cljs$core$edit_and_set$cljs$0core$0IFn$0_invoke$0arity$04$$(this,$edit__$1$$,2*$idx$jscomp$28$$+1,$n$jscomp$124_shift$jscomp$6$$):this.$bitmap$===$bit$jscomp$2$$?null:$JSCompiler_StaticMethods_edit_and_remove_pair$$(this,$edit__$1$$,$bit$jscomp$2$$,$idx$jscomp$28$$)):$cljs$core$key_test$$($key$jscomp$136$$,
$key_or_nil$$)?($removed_leaf_QMARK_$$.$val$=!0,$JSCompiler_StaticMethods_edit_and_remove_pair$$(this,$edit__$1$$,$bit$jscomp$2$$,$idx$jscomp$28$$)):this};$APP.$JSCompiler_prototypeAlias$$.$inode_seq$=function(){return $cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$01$$?$cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$01$$(this.$arr$):$cljs$core$create_inode_seq$$(this.$arr$)};
$APP.$JSCompiler_prototypeAlias$$.$kv_reduce$=function($f$jscomp$261$$,$init$jscomp$35$$){return $cljs$core$inode_kv_reduce$$(this.$arr$,$f$jscomp$261$$,$init$jscomp$35$$)};
$APP.$JSCompiler_prototypeAlias$$.$inode_lookup$=function($shift$jscomp$7$$,$hash$jscomp$6$$,$key$jscomp$137$$,$not_found$jscomp$32$$){var $bit$jscomp$4_key_or_nil$jscomp$1$$=1<<($hash$jscomp$6$$>>>$shift$jscomp$7$$&31);if((this.$bitmap$&$bit$jscomp$4_key_or_nil$jscomp$1$$)===0)return $not_found$jscomp$32$$;var $idx$jscomp$29_val_or_node$jscomp$1$$=$cljs$core$bit_count$$(this.$bitmap$&$bit$jscomp$4_key_or_nil$jscomp$1$$-1);$bit$jscomp$4_key_or_nil$jscomp$1$$=this.$arr$[2*$idx$jscomp$29_val_or_node$jscomp$1$$];
$idx$jscomp$29_val_or_node$jscomp$1$$=this.$arr$[2*$idx$jscomp$29_val_or_node$jscomp$1$$+1];return $bit$jscomp$4_key_or_nil$jscomp$1$$==null?$idx$jscomp$29_val_or_node$jscomp$1$$.$inode_lookup$($shift$jscomp$7$$+5,$hash$jscomp$6$$,$key$jscomp$137$$,$not_found$jscomp$32$$):$cljs$core$key_test$$($key$jscomp$137$$,$bit$jscomp$4_key_or_nil$jscomp$1$$)?$idx$jscomp$29_val_or_node$jscomp$1$$:$not_found$jscomp$32$$};
$APP.$JSCompiler_prototypeAlias$$.$inode_assoc_BANG_$=function($edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$,$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$,$G__25072$jscomp$inline_11290_hash$jscomp$7_len$jscomp$inline_11285_len__$1$jscomp$inline_11288$$,$JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$,$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$,$G__23691$jscomp$inline_2844_added_leaf_QMARK__i__$1$jscomp$inline_11286$$){var $bit$jscomp$5_val_or_node$jscomp$2$$=
1<<($G__25072$jscomp$inline_11290_hash$jscomp$7_len$jscomp$inline_11285_len__$1$jscomp$inline_11288$$>>>$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$&31),$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$=$cljs$core$bit_count$$(this.$bitmap$&$bit$jscomp$5_val_or_node$jscomp$2$$-1);if((this.$bitmap$&$bit$jscomp$5_val_or_node$jscomp$2$$)===0){var $G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$=$cljs$core$bit_count$$(this.$bitmap$);if(2*$G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$<
this.$arr$.length){$edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$=this.$ensure_editable$($edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$);$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$=$edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$.$arr$;$G__23691$jscomp$inline_2844_added_leaf_QMARK__i__$1$jscomp$inline_11286$$.$val$=!0;$G__25072$jscomp$inline_11290_hash$jscomp$7_len$jscomp$inline_11285_len__$1$jscomp$inline_11288$$=2*($G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$-
$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$);$G__23691$jscomp$inline_2844_added_leaf_QMARK__i__$1$jscomp$inline_11286$$=2*$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$+($G__25072$jscomp$inline_11290_hash$jscomp$7_len$jscomp$inline_11285_len__$1$jscomp$inline_11288$$-1);for($G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$=2*($idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$+1)+($G__25072$jscomp$inline_11290_hash$jscomp$7_len$jscomp$inline_11285_len__$1$jscomp$inline_11288$$-
1);$G__25072$jscomp$inline_11290_hash$jscomp$7_len$jscomp$inline_11285_len__$1$jscomp$inline_11288$$!==0;)$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$[$G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$]=$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$[$G__23691$jscomp$inline_2844_added_leaf_QMARK__i__$1$jscomp$inline_11286$$],--$G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$,--$G__25072$jscomp$inline_11290_hash$jscomp$7_len$jscomp$inline_11285_len__$1$jscomp$inline_11288$$,
--$G__23691$jscomp$inline_2844_added_leaf_QMARK__i__$1$jscomp$inline_11286$$;$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$[2*$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$]=$JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$;$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$[2*$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$+1]=$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$;$edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$.$bitmap$|=$bit$jscomp$5_val_or_node$jscomp$2$$;
return $edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$}if($G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$>=16){$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$=[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$[$G__25072$jscomp$inline_11290_hash$jscomp$7_len$jscomp$inline_11285_len__$1$jscomp$inline_11288$$>>>
$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$&31]=$cljs$core$BitmapIndexedNode$EMPTY$$.$inode_assoc_BANG_$($edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$,$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$+5,$G__25072$jscomp$inline_11290_hash$jscomp$7_len$jscomp$inline_11285_len__$1$jscomp$inline_11288$$,$JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$,$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$,$G__23691$jscomp$inline_2844_added_leaf_QMARK__i__$1$jscomp$inline_11286$$);
for($G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$=$JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$=0;;)if($JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$<32)(this.$bitmap$>>>$JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$&1)===0?$JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$+=1:($idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$[$JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$]=this.$arr$[$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$]!=
null?$cljs$core$BitmapIndexedNode$EMPTY$$.$inode_assoc_BANG_$($edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$,$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$+5,$APP.$cljs$core$hash$$(this.$arr$[$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$]),this.$arr$[$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$],this.$arr$[$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$+1],$G__23691$jscomp$inline_2844_added_leaf_QMARK__i__$1$jscomp$inline_11286$$):
this.$arr$[$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$+1],$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$+=2,$JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$+=1);else break;return new $cljs$core$ArrayNode$$($edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$,$G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$+1,$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$)}$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$=
Array(2*($G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$+4));$cljs$core$array_copy$$(this.$arr$,0,$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$,0,2*$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$);$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$[2*$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$]=$JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$;$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$[2*$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$+
1]=$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$;$cljs$core$array_copy$$(this.$arr$,2*$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$,$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$,2*($idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$+1),2*($G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$-$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$));$G__23691$jscomp$inline_2844_added_leaf_QMARK__i__$1$jscomp$inline_11286$$.$val$=
!0;$edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$=this.$ensure_editable$($edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$);$edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$.$arr$=$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$;$edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$.$bitmap$|=$bit$jscomp$5_val_or_node$jscomp$2$$;return $edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$}$G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$=
this.$arr$[2*$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$];$bit$jscomp$5_val_or_node$jscomp$2$$=this.$arr$[2*$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$+1];if($G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$==null)return $G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$=$bit$jscomp$5_val_or_node$jscomp$2$$.$inode_assoc_BANG_$($edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$,$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$+
5,$G__25072$jscomp$inline_11290_hash$jscomp$7_len$jscomp$inline_11285_len__$1$jscomp$inline_11288$$,$JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$,$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$,$G__23691$jscomp$inline_2844_added_leaf_QMARK__i__$1$jscomp$inline_11286$$),$G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$===$bit$jscomp$5_val_or_node$jscomp$2$$?this:$cljs$core$edit_and_set$cljs$0core$0IFn$0_invoke$0arity$04$$(this,
$edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$,2*$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$+1,$G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$);if($cljs$core$key_test$$($JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$,$G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$))return $G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$===$bit$jscomp$5_val_or_node$jscomp$2$$?
this:$cljs$core$edit_and_set$cljs$0core$0IFn$0_invoke$0arity$04$$(this,$edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$,2*$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$+1,$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$);$G__23691$jscomp$inline_2844_added_leaf_QMARK__i__$1$jscomp$inline_11286$$.$val$=!0;$G__23691$jscomp$inline_2844_added_leaf_QMARK__i__$1$jscomp$inline_11286$$=$earr$jscomp$1_new_arr$jscomp$4_shift$jscomp$8$$+5;$JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$=
$cljs$core$create_node$cljs$0core$0IFn$0_invoke$0arity$07$$?$cljs$core$create_node$cljs$0core$0IFn$0_invoke$0arity$07$$($edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$,$G__23691$jscomp$inline_2844_added_leaf_QMARK__i__$1$jscomp$inline_11286$$,$G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$,$bit$jscomp$5_val_or_node$jscomp$2$$,$G__25072$jscomp$inline_11290_hash$jscomp$7_len$jscomp$inline_11285_len__$1$jscomp$inline_11288$$,$JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$,
$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$):$cljs$core$create_node$$($edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$,$G__23691$jscomp$inline_2844_added_leaf_QMARK__i__$1$jscomp$inline_11286$$,$G__25071$jscomp$inline_11289_j__$1$jscomp$inline_11287_key_or_nil$jscomp$2_n$jscomp$125$$,$bit$jscomp$5_val_or_node$jscomp$2$$,$G__25072$jscomp$inline_11290_hash$jscomp$7_len$jscomp$inline_11285_len__$1$jscomp$inline_11288$$,$JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$,
$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$);$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$=2*$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$;$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$=2*$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$+1;$edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$=this.$ensure_editable$($edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$);$edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$.$arr$[$G__27977_G__27979_i$jscomp$inline_11294_j_27974_val$jscomp$87$$]=
null;$edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$.$arr$[$idx$jscomp$30_j$jscomp$inline_11296_nodes$jscomp$18$$]=$JSCompiler_inline_result$jscomp$221_i_27973_key$jscomp$138$$;return $edit__$1$jscomp$1_editable$jscomp$3_editable$jscomp$inline_11298$$};
$APP.$JSCompiler_prototypeAlias$$.$inode_assoc$=function($G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$,$hash$jscomp$8$$,$i$jscomp$inline_11301_i_27982_key$jscomp$139$$,$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$,$JSCompiler_temp_const$jscomp$223_added_leaf_QMARK_$jscomp$1$$){var $bit$jscomp$6_val_or_node$jscomp$3$$=1<<($hash$jscomp$8$$>>>$G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$&
31),$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$=$cljs$core$bit_count$$(this.$bitmap$&$bit$jscomp$6_val_or_node$jscomp$3$$-1);if((this.$bitmap$&$bit$jscomp$6_val_or_node$jscomp$3$$)===0){var $JSCompiler_temp_const$jscomp$222_n$jscomp$126$$=$cljs$core$bit_count$$(this.$bitmap$);if($JSCompiler_temp_const$jscomp$222_n$jscomp$126$$>=16){$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$=[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,
null,null,null,null,null,null,null,null,null,null,null,null];$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$[$hash$jscomp$8$$>>>$G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$&31]=$cljs$core$BitmapIndexedNode$EMPTY$$.$inode_assoc$($G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$+5,$hash$jscomp$8$$,$i$jscomp$inline_11301_i_27982_key$jscomp$139$$,$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$,
$JSCompiler_temp_const$jscomp$223_added_leaf_QMARK_$jscomp$1$$);for($G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$=$i$jscomp$inline_11301_i_27982_key$jscomp$139$$=0;;)if($i$jscomp$inline_11301_i_27982_key$jscomp$139$$<32)(this.$bitmap$>>>$i$jscomp$inline_11301_i_27982_key$jscomp$139$$&1)===0?$i$jscomp$inline_11301_i_27982_key$jscomp$139$$+=1:($idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$[$i$jscomp$inline_11301_i_27982_key$jscomp$139$$]=this.$arr$[$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$]!=
null?$cljs$core$BitmapIndexedNode$EMPTY$$.$inode_assoc$($G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$+5,$APP.$cljs$core$hash$$(this.$arr$[$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$]),this.$arr$[$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$],this.$arr$[$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$+1],$JSCompiler_temp_const$jscomp$223_added_leaf_QMARK_$jscomp$1$$):this.$arr$[$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$+
1],$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$+=2,$i$jscomp$inline_11301_i_27982_key$jscomp$139$$+=1);else break;return new $cljs$core$ArrayNode$$(null,$JSCompiler_temp_const$jscomp$222_n$jscomp$126$$+1,$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$)}$G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$=Array(2*($JSCompiler_temp_const$jscomp$222_n$jscomp$126$$+1));$cljs$core$array_copy$$(this.$arr$,0,$G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$,
0,2*$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$);$G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$[2*$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$]=$i$jscomp$inline_11301_i_27982_key$jscomp$139$$;$G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$[2*$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$+1]=$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$;$cljs$core$array_copy$$(this.$arr$,
2*$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$,$G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$,2*($idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$+1),2*($JSCompiler_temp_const$jscomp$222_n$jscomp$126$$-$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$));$JSCompiler_temp_const$jscomp$223_added_leaf_QMARK_$jscomp$1$$.$val$=!0;return new $cljs$core$BitmapIndexedNode$$(null,this.$bitmap$|$bit$jscomp$6_val_or_node$jscomp$3$$,$G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$)}var $key_or_nil$jscomp$3$$=
this.$arr$[2*$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$];$bit$jscomp$6_val_or_node$jscomp$3$$=this.$arr$[2*$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$+1];if($key_or_nil$jscomp$3$$==null)return $JSCompiler_temp_const$jscomp$222_n$jscomp$126$$=$bit$jscomp$6_val_or_node$jscomp$3$$.$inode_assoc$($G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$+5,$hash$jscomp$8$$,$i$jscomp$inline_11301_i_27982_key$jscomp$139$$,$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$,
$JSCompiler_temp_const$jscomp$223_added_leaf_QMARK_$jscomp$1$$),$JSCompiler_temp_const$jscomp$222_n$jscomp$126$$===$bit$jscomp$6_val_or_node$jscomp$3$$?this:new $cljs$core$BitmapIndexedNode$$(null,this.$bitmap$,$cljs$core$clone_and_set$cljs$0core$0IFn$0_invoke$0arity$03$$(this.$arr$,2*$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$+1,$JSCompiler_temp_const$jscomp$222_n$jscomp$126$$));if($cljs$core$key_test$$($i$jscomp$inline_11301_i_27982_key$jscomp$139$$,$key_or_nil$jscomp$3$$))return $G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$===
$bit$jscomp$6_val_or_node$jscomp$3$$?this:new $cljs$core$BitmapIndexedNode$$(null,this.$bitmap$,$cljs$core$clone_and_set$cljs$0core$0IFn$0_invoke$0arity$03$$(this.$arr$,2*$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$+1,$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$));$JSCompiler_temp_const$jscomp$223_added_leaf_QMARK_$jscomp$1$$.$val$=!0;$JSCompiler_temp_const$jscomp$223_added_leaf_QMARK_$jscomp$1$$=this.$bitmap$;$JSCompiler_temp_const$jscomp$222_n$jscomp$126$$=this.$arr$;
$G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$+=5;$G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$=$cljs$core$create_node$cljs$0core$0IFn$0_invoke$0arity$06$$?$cljs$core$create_node$cljs$0core$0IFn$0_invoke$0arity$06$$($G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$,$key_or_nil$jscomp$3$$,$bit$jscomp$6_val_or_node$jscomp$3$$,$hash$jscomp$8$$,$i$jscomp$inline_11301_i_27982_key$jscomp$139$$,
$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$):$cljs$core$create_node$$($G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$,$key_or_nil$jscomp$3$$,$bit$jscomp$6_val_or_node$jscomp$3$$,$hash$jscomp$8$$,$i$jscomp$inline_11301_i_27982_key$jscomp$139$$,$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$);$i$jscomp$inline_11301_i_27982_key$jscomp$139$$=2*$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$;$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$=
2*$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$+1;$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$=$APP.$cljs$core$aclone$$($JSCompiler_temp_const$jscomp$222_n$jscomp$126$$);$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$[$i$jscomp$inline_11301_i_27982_key$jscomp$139$$]=null;$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$[$idx$jscomp$31_j$jscomp$inline_11302_nodes$jscomp$19$$]=$G__23697$jscomp$inline_2846_JSCompiler_inline_result$jscomp$224_new_arr$jscomp$5_shift$jscomp$9$$;
return new $cljs$core$BitmapIndexedNode$$(null,$JSCompiler_temp_const$jscomp$223_added_leaf_QMARK_$jscomp$1$$,$G__23684$jscomp$inline_11304_G__27985_G__27989_j_27983_val$jscomp$88$$)};
$APP.$JSCompiler_prototypeAlias$$.$inode_find$=function($shift$jscomp$10$$,$hash$jscomp$9$$,$key$jscomp$140$$,$not_found$jscomp$33$$){var $bit$jscomp$7_key_or_nil$jscomp$4$$=1<<($hash$jscomp$9$$>>>$shift$jscomp$10$$&31);if((this.$bitmap$&$bit$jscomp$7_key_or_nil$jscomp$4$$)===0)return $not_found$jscomp$33$$;var $idx$jscomp$32_val_or_node$jscomp$4$$=$cljs$core$bit_count$$(this.$bitmap$&$bit$jscomp$7_key_or_nil$jscomp$4$$-1);$bit$jscomp$7_key_or_nil$jscomp$4$$=this.$arr$[2*$idx$jscomp$32_val_or_node$jscomp$4$$];
$idx$jscomp$32_val_or_node$jscomp$4$$=this.$arr$[2*$idx$jscomp$32_val_or_node$jscomp$4$$+1];return $bit$jscomp$7_key_or_nil$jscomp$4$$==null?$idx$jscomp$32_val_or_node$jscomp$4$$.$inode_find$($shift$jscomp$10$$+5,$hash$jscomp$9$$,$key$jscomp$140$$,$not_found$jscomp$33$$):$cljs$core$key_test$$($key$jscomp$140$$,$bit$jscomp$7_key_or_nil$jscomp$4$$)?new $APP.$cljs$core$MapEntry$$($bit$jscomp$7_key_or_nil$jscomp$4$$,$idx$jscomp$32_val_or_node$jscomp$4$$,null):$not_found$jscomp$33$$};
$APP.$JSCompiler_prototypeAlias$$.$inode_without$=function($n$jscomp$127_shift$jscomp$11$$,$hash$jscomp$10$$,$key$jscomp$141$$){var $bit$jscomp$8$$=1<<($hash$jscomp$10$$>>>$n$jscomp$127_shift$jscomp$11$$&31);if((this.$bitmap$&$bit$jscomp$8$$)===0)return this;var $idx$jscomp$33$$=$cljs$core$bit_count$$(this.$bitmap$&$bit$jscomp$8$$-1),$key_or_nil$jscomp$5$$=this.$arr$[2*$idx$jscomp$33$$],$val_or_node$jscomp$5$$=this.$arr$[2*$idx$jscomp$33$$+1];return $key_or_nil$jscomp$5$$==null?($n$jscomp$127_shift$jscomp$11$$=
$val_or_node$jscomp$5$$.$inode_without$($n$jscomp$127_shift$jscomp$11$$+5,$hash$jscomp$10$$,$key$jscomp$141$$),$n$jscomp$127_shift$jscomp$11$$===$val_or_node$jscomp$5$$?this:$n$jscomp$127_shift$jscomp$11$$!=null?new $cljs$core$BitmapIndexedNode$$(null,this.$bitmap$,$cljs$core$clone_and_set$cljs$0core$0IFn$0_invoke$0arity$03$$(this.$arr$,2*$idx$jscomp$33$$+1,$n$jscomp$127_shift$jscomp$11$$)):this.$bitmap$===$bit$jscomp$8$$?null:new $cljs$core$BitmapIndexedNode$$(null,this.$bitmap$^$bit$jscomp$8$$,
$cljs$core$remove_pair$$(this.$arr$,$idx$jscomp$33$$))):$cljs$core$key_test$$($key$jscomp$141$$,$key_or_nil$jscomp$5$$)?this.$bitmap$===$bit$jscomp$8$$?null:new $cljs$core$BitmapIndexedNode$$(null,this.$bitmap$^$bit$jscomp$8$$,$cljs$core$remove_pair$$(this.$arr$,$idx$jscomp$33$$)):this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $cljs$core$NodeIterator$$(this.$arr$)};
var $cljs$core$BitmapIndexedNode$EMPTY$$=new $cljs$core$BitmapIndexedNode$$(null,0,[]);$cljs$core$ArrayNodeIterator$$.prototype.hasNext=function(){for(var $len$jscomp$40$$=this.$arr$.length;;){if(this.$next_iter$!=null&&this.$next_iter$.hasNext())return!0;if(this.i<$len$jscomp$40$$){var $node$jscomp$49$$=this.$arr$[this.i];this.i+=1;$node$jscomp$49$$!=null&&(this.$next_iter$=$APP.$cljs$core$_iterator$$($node$jscomp$49$$))}else return!1}};
$cljs$core$ArrayNodeIterator$$.prototype.next=function(){if(this.hasNext())return this.$next_iter$.next();throw Error("No such element");};$cljs$core$ArrayNodeIterator$$.prototype.remove=function(){return Error("Unsupported operation")};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$ArrayNode$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$ensure_editable$=function($e$jscomp$91$$){return $e$jscomp$91$$===this.$edit$?this:new $cljs$core$ArrayNode$$($e$jscomp$91$$,this.$cnt$,$APP.$cljs$core$aclone$$(this.$arr$))};
$APP.$JSCompiler_prototypeAlias$$.$inode_without_BANG_$=function($edit__$1$jscomp$2_editable$jscomp$4$$,$n$jscomp$128_shift$jscomp$12$$,$hash$jscomp$11$$,$key$jscomp$142$$,$removed_leaf_QMARK_$jscomp$1$$){var $idx$jscomp$35$$=$hash$jscomp$11$$>>>$n$jscomp$128_shift$jscomp$12$$&31,$node$jscomp$50$$=this.$arr$[$idx$jscomp$35$$];if($node$jscomp$50$$==null)return this;$n$jscomp$128_shift$jscomp$12$$=$node$jscomp$50$$.$inode_without_BANG_$($edit__$1$jscomp$2_editable$jscomp$4$$,$n$jscomp$128_shift$jscomp$12$$+
5,$hash$jscomp$11$$,$key$jscomp$142$$,$removed_leaf_QMARK_$jscomp$1$$);if($n$jscomp$128_shift$jscomp$12$$===$node$jscomp$50$$)return this;if($n$jscomp$128_shift$jscomp$12$$==null){if(this.$cnt$<=8)return $cljs$core$pack_array_node$$(this,$edit__$1$jscomp$2_editable$jscomp$4$$,$idx$jscomp$35$$);$edit__$1$jscomp$2_editable$jscomp$4$$=$cljs$core$edit_and_set$cljs$0core$0IFn$0_invoke$0arity$04$$(this,$edit__$1$jscomp$2_editable$jscomp$4$$,$idx$jscomp$35$$,$n$jscomp$128_shift$jscomp$12$$);--$edit__$1$jscomp$2_editable$jscomp$4$$.$cnt$;
return $edit__$1$jscomp$2_editable$jscomp$4$$}return $cljs$core$edit_and_set$cljs$0core$0IFn$0_invoke$0arity$04$$(this,$edit__$1$jscomp$2_editable$jscomp$4$$,$idx$jscomp$35$$,$n$jscomp$128_shift$jscomp$12$$)};$APP.$JSCompiler_prototypeAlias$$.$inode_seq$=function(){return $cljs$core$create_array_node_seq$cljs$0core$0IFn$0_invoke$0arity$01$$?$cljs$core$create_array_node_seq$cljs$0core$0IFn$0_invoke$0arity$01$$(this.$arr$):$cljs$core$create_array_node_seq$$(this.$arr$)};
$APP.$JSCompiler_prototypeAlias$$.$kv_reduce$=function($f$jscomp$262$$,$G__28019_G__28021_init$jscomp$36_init__$1$jscomp$7_init__$2$jscomp$8$$){for(var $len$jscomp$41$$=this.$arr$.length,$i$jscomp$252$$=0;;)if($i$jscomp$252$$<$len$jscomp$41$$){var $node$jscomp$51$$=this.$arr$[$i$jscomp$252$$];if($node$jscomp$51$$!=null){$G__28019_G__28021_init$jscomp$36_init__$1$jscomp$7_init__$2$jscomp$8$$=$node$jscomp$51$$.$kv_reduce$($f$jscomp$262$$,$G__28019_G__28021_init$jscomp$36_init__$1$jscomp$7_init__$2$jscomp$8$$);
if($cljs$core$reduced_QMARK_$$($G__28019_G__28021_init$jscomp$36_init__$1$jscomp$7_init__$2$jscomp$8$$))return $G__28019_G__28021_init$jscomp$36_init__$1$jscomp$7_init__$2$jscomp$8$$;$i$jscomp$252$$+=1}else $i$jscomp$252$$+=1}else return $G__28019_G__28021_init$jscomp$36_init__$1$jscomp$7_init__$2$jscomp$8$$};
$APP.$JSCompiler_prototypeAlias$$.$inode_lookup$=function($shift$jscomp$13$$,$hash$jscomp$12$$,$key$jscomp$143$$,$not_found$jscomp$34$$){var $node$jscomp$52$$=this.$arr$[$hash$jscomp$12$$>>>$shift$jscomp$13$$&31];return $node$jscomp$52$$!=null?$node$jscomp$52$$.$inode_lookup$($shift$jscomp$13$$+5,$hash$jscomp$12$$,$key$jscomp$143$$,$not_found$jscomp$34$$):$not_found$jscomp$34$$};
$APP.$JSCompiler_prototypeAlias$$.$inode_assoc_BANG_$=function($edit__$1$jscomp$3_editable$jscomp$5$$,$n$jscomp$129_shift$jscomp$14$$,$hash$jscomp$13$$,$key$jscomp$144$$,$val$jscomp$89$$,$added_leaf_QMARK_$jscomp$2$$){var $idx$jscomp$37$$=$hash$jscomp$13$$>>>$n$jscomp$129_shift$jscomp$14$$&31,$node$jscomp$53$$=this.$arr$[$idx$jscomp$37$$];if($node$jscomp$53$$==null)return $edit__$1$jscomp$3_editable$jscomp$5$$=$cljs$core$edit_and_set$cljs$0core$0IFn$0_invoke$0arity$04$$(this,$edit__$1$jscomp$3_editable$jscomp$5$$,
$idx$jscomp$37$$,$cljs$core$BitmapIndexedNode$EMPTY$$.$inode_assoc_BANG_$($edit__$1$jscomp$3_editable$jscomp$5$$,$n$jscomp$129_shift$jscomp$14$$+5,$hash$jscomp$13$$,$key$jscomp$144$$,$val$jscomp$89$$,$added_leaf_QMARK_$jscomp$2$$)),$edit__$1$jscomp$3_editable$jscomp$5$$.$cnt$+=1,$edit__$1$jscomp$3_editable$jscomp$5$$;$n$jscomp$129_shift$jscomp$14$$=$node$jscomp$53$$.$inode_assoc_BANG_$($edit__$1$jscomp$3_editable$jscomp$5$$,$n$jscomp$129_shift$jscomp$14$$+5,$hash$jscomp$13$$,$key$jscomp$144$$,$val$jscomp$89$$,
$added_leaf_QMARK_$jscomp$2$$);return $n$jscomp$129_shift$jscomp$14$$===$node$jscomp$53$$?this:$cljs$core$edit_and_set$cljs$0core$0IFn$0_invoke$0arity$04$$(this,$edit__$1$jscomp$3_editable$jscomp$5$$,$idx$jscomp$37$$,$n$jscomp$129_shift$jscomp$14$$)};
$APP.$JSCompiler_prototypeAlias$$.$inode_assoc$=function($n$jscomp$130_shift$jscomp$15$$,$hash$jscomp$14$$,$key$jscomp$145$$,$val$jscomp$90$$,$added_leaf_QMARK_$jscomp$3$$){var $idx$jscomp$38$$=$hash$jscomp$14$$>>>$n$jscomp$130_shift$jscomp$15$$&31,$node$jscomp$54$$=this.$arr$[$idx$jscomp$38$$];if($node$jscomp$54$$==null)return new $cljs$core$ArrayNode$$(null,this.$cnt$+1,$cljs$core$clone_and_set$cljs$0core$0IFn$0_invoke$0arity$03$$(this.$arr$,$idx$jscomp$38$$,$cljs$core$BitmapIndexedNode$EMPTY$$.$inode_assoc$($n$jscomp$130_shift$jscomp$15$$+
5,$hash$jscomp$14$$,$key$jscomp$145$$,$val$jscomp$90$$,$added_leaf_QMARK_$jscomp$3$$)));$n$jscomp$130_shift$jscomp$15$$=$node$jscomp$54$$.$inode_assoc$($n$jscomp$130_shift$jscomp$15$$+5,$hash$jscomp$14$$,$key$jscomp$145$$,$val$jscomp$90$$,$added_leaf_QMARK_$jscomp$3$$);return $n$jscomp$130_shift$jscomp$15$$===$node$jscomp$54$$?this:new $cljs$core$ArrayNode$$(null,this.$cnt$,$cljs$core$clone_and_set$cljs$0core$0IFn$0_invoke$0arity$03$$(this.$arr$,$idx$jscomp$38$$,$n$jscomp$130_shift$jscomp$15$$))};
$APP.$JSCompiler_prototypeAlias$$.$inode_find$=function($shift$jscomp$16$$,$hash$jscomp$15$$,$key$jscomp$146$$,$not_found$jscomp$35$$){var $node$jscomp$55$$=this.$arr$[$hash$jscomp$15$$>>>$shift$jscomp$16$$&31];return $node$jscomp$55$$!=null?$node$jscomp$55$$.$inode_find$($shift$jscomp$16$$+5,$hash$jscomp$15$$,$key$jscomp$146$$,$not_found$jscomp$35$$):$not_found$jscomp$35$$};
$APP.$JSCompiler_prototypeAlias$$.$inode_without$=function($n$jscomp$131_shift$jscomp$17$$,$hash$jscomp$16$$,$key$jscomp$147$$){var $idx$jscomp$40$$=$hash$jscomp$16$$>>>$n$jscomp$131_shift$jscomp$17$$&31,$node$jscomp$56$$=this.$arr$[$idx$jscomp$40$$];return $node$jscomp$56$$!=null?($n$jscomp$131_shift$jscomp$17$$=$node$jscomp$56$$.$inode_without$($n$jscomp$131_shift$jscomp$17$$+5,$hash$jscomp$16$$,$key$jscomp$147$$),$n$jscomp$131_shift$jscomp$17$$===$node$jscomp$56$$?this:$n$jscomp$131_shift$jscomp$17$$==
null?this.$cnt$<=8?$cljs$core$pack_array_node$$(this,null,$idx$jscomp$40$$):new $cljs$core$ArrayNode$$(null,this.$cnt$-1,$cljs$core$clone_and_set$cljs$0core$0IFn$0_invoke$0arity$03$$(this.$arr$,$idx$jscomp$40$$,$n$jscomp$131_shift$jscomp$17$$)):new $cljs$core$ArrayNode$$(null,this.$cnt$,$cljs$core$clone_and_set$cljs$0core$0IFn$0_invoke$0arity$03$$(this.$arr$,$idx$jscomp$40$$,$n$jscomp$131_shift$jscomp$17$$))):this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $cljs$core$ArrayNodeIterator$$(this.$arr$)};
$APP.$JSCompiler_prototypeAlias$$=$cljs$core$HashCollisionNode$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$ensure_editable$=function($e$jscomp$92$$){if($e$jscomp$92$$===this.$edit$)return this;var $new_arr$jscomp$7$$=Array(2*(this.$cnt$+1));$cljs$core$array_copy$$(this.$arr$,0,$new_arr$jscomp$7$$,0,2*this.$cnt$);return new $cljs$core$HashCollisionNode$$($e$jscomp$92$$,this.$collision_hash$,this.$cnt$,$new_arr$jscomp$7$$)};
$APP.$JSCompiler_prototypeAlias$$.$inode_without_BANG_$=function($edit__$1$jscomp$4_editable$jscomp$6$$,$idx$jscomp$41_shift$jscomp$18$$,$hash$jscomp$17$$,$key$jscomp$149$$,$earr$jscomp$2_removed_leaf_QMARK_$jscomp$2$$){$idx$jscomp$41_shift$jscomp$18$$=$cljs$core$hash_collision_node_find_index$$(this.$arr$,this.$cnt$,$key$jscomp$149$$);if($idx$jscomp$41_shift$jscomp$18$$===-1)return this;$earr$jscomp$2_removed_leaf_QMARK_$jscomp$2$$.$val$=!0;if(this.$cnt$===1)return null;$edit__$1$jscomp$4_editable$jscomp$6$$=
this.$ensure_editable$($edit__$1$jscomp$4_editable$jscomp$6$$);$earr$jscomp$2_removed_leaf_QMARK_$jscomp$2$$=$edit__$1$jscomp$4_editable$jscomp$6$$.$arr$;$earr$jscomp$2_removed_leaf_QMARK_$jscomp$2$$[$idx$jscomp$41_shift$jscomp$18$$]=$earr$jscomp$2_removed_leaf_QMARK_$jscomp$2$$[2*this.$cnt$-2];$earr$jscomp$2_removed_leaf_QMARK_$jscomp$2$$[$idx$jscomp$41_shift$jscomp$18$$+1]=$earr$jscomp$2_removed_leaf_QMARK_$jscomp$2$$[2*this.$cnt$-1];$earr$jscomp$2_removed_leaf_QMARK_$jscomp$2$$[2*this.$cnt$-1]=
null;$earr$jscomp$2_removed_leaf_QMARK_$jscomp$2$$[2*this.$cnt$-2]=null;--$edit__$1$jscomp$4_editable$jscomp$6$$.$cnt$;return $edit__$1$jscomp$4_editable$jscomp$6$$};$APP.$JSCompiler_prototypeAlias$$.$inode_seq$=function(){return $cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$01$$?$cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$01$$(this.$arr$):$cljs$core$create_inode_seq$$(this.$arr$)};
$APP.$JSCompiler_prototypeAlias$$.$kv_reduce$=function($f$jscomp$263$$,$init$jscomp$37$$){return $cljs$core$inode_kv_reduce$$(this.$arr$,$f$jscomp$263$$,$init$jscomp$37$$)};
$APP.$JSCompiler_prototypeAlias$$.$inode_lookup$=function($idx$jscomp$42_shift$jscomp$19$$,$hash$jscomp$18$$,$key$jscomp$150$$,$not_found$jscomp$36$$){$idx$jscomp$42_shift$jscomp$19$$=$cljs$core$hash_collision_node_find_index$$(this.$arr$,this.$cnt$,$key$jscomp$150$$);return $idx$jscomp$42_shift$jscomp$19$$<0?$not_found$jscomp$36$$:this.$arr$[$idx$jscomp$42_shift$jscomp$19$$+1]};
$APP.$JSCompiler_prototypeAlias$$.$inode_assoc_BANG_$=function($JSCompiler_inline_result$jscomp$225_edit__$1$jscomp$5_editable$jscomp$inline_11312$$,$i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$,$hash$jscomp$19_j$jscomp$inline_11310_len$jscomp$42$$,$count$jscomp$inline_2850_key$jscomp$151$$,$val$jscomp$91$$,$added_leaf_QMARK_$jscomp$4$$){if($hash$jscomp$19_j$jscomp$inline_11310_len$jscomp$42$$===this.$collision_hash$){$i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$=
$cljs$core$hash_collision_node_find_index$$(this.$arr$,this.$cnt$,$count$jscomp$inline_2850_key$jscomp$151$$);if($i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$===-1){if(this.$arr$.length>2*this.$cnt$)return $i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$=2*this.$cnt$,$hash$jscomp$19_j$jscomp$inline_11310_len$jscomp$42$$=2*this.$cnt$+1,$JSCompiler_inline_result$jscomp$225_edit__$1$jscomp$5_editable$jscomp$inline_11312$$=this.$ensure_editable$($JSCompiler_inline_result$jscomp$225_edit__$1$jscomp$5_editable$jscomp$inline_11312$$),
$JSCompiler_inline_result$jscomp$225_edit__$1$jscomp$5_editable$jscomp$inline_11312$$.$arr$[$i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$]=$count$jscomp$inline_2850_key$jscomp$151$$,$JSCompiler_inline_result$jscomp$225_edit__$1$jscomp$5_editable$jscomp$inline_11312$$.$arr$[$hash$jscomp$19_j$jscomp$inline_11310_len$jscomp$42$$]=$val$jscomp$91$$,$added_leaf_QMARK_$jscomp$4$$.$val$=!0,$JSCompiler_inline_result$jscomp$225_edit__$1$jscomp$5_editable$jscomp$inline_11312$$.$cnt$+=
1,$JSCompiler_inline_result$jscomp$225_edit__$1$jscomp$5_editable$jscomp$inline_11312$$;$hash$jscomp$19_j$jscomp$inline_11310_len$jscomp$42$$=this.$arr$.length;$i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$=Array($hash$jscomp$19_j$jscomp$inline_11310_len$jscomp$42$$+2);$cljs$core$array_copy$$(this.$arr$,0,$i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$,0,$hash$jscomp$19_j$jscomp$inline_11310_len$jscomp$42$$);$i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$[$hash$jscomp$19_j$jscomp$inline_11310_len$jscomp$42$$]=
$count$jscomp$inline_2850_key$jscomp$151$$;$i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$[$hash$jscomp$19_j$jscomp$inline_11310_len$jscomp$42$$+1]=$val$jscomp$91$$;$added_leaf_QMARK_$jscomp$4$$.$val$=!0;$count$jscomp$inline_2850_key$jscomp$151$$=this.$cnt$+1;$JSCompiler_inline_result$jscomp$225_edit__$1$jscomp$5_editable$jscomp$inline_11312$$===this.$edit$?(this.$arr$=$i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$,this.$cnt$=$count$jscomp$inline_2850_key$jscomp$151$$,
$JSCompiler_inline_result$jscomp$225_edit__$1$jscomp$5_editable$jscomp$inline_11312$$=this):$JSCompiler_inline_result$jscomp$225_edit__$1$jscomp$5_editable$jscomp$inline_11312$$=new $cljs$core$HashCollisionNode$$(this.$edit$,this.$collision_hash$,$count$jscomp$inline_2850_key$jscomp$151$$,$i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$);return $JSCompiler_inline_result$jscomp$225_edit__$1$jscomp$5_editable$jscomp$inline_11312$$}return this.$arr$[$i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$+
1]===$val$jscomp$91$$?this:$cljs$core$edit_and_set$cljs$0core$0IFn$0_invoke$0arity$04$$(this,$JSCompiler_inline_result$jscomp$225_edit__$1$jscomp$5_editable$jscomp$inline_11312$$,$i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$+1,$val$jscomp$91$$)}return(new $cljs$core$BitmapIndexedNode$$($JSCompiler_inline_result$jscomp$225_edit__$1$jscomp$5_editable$jscomp$inline_11312$$,1<<(this.$collision_hash$>>>$i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$&31),
[null,this,null,null])).$inode_assoc_BANG_$($JSCompiler_inline_result$jscomp$225_edit__$1$jscomp$5_editable$jscomp$inline_11312$$,$i$jscomp$inline_11308_idx$jscomp$43_new_arr$jscomp$8_shift$jscomp$20$$,$hash$jscomp$19_j$jscomp$inline_11310_len$jscomp$42$$,$count$jscomp$inline_2850_key$jscomp$151$$,$val$jscomp$91$$,$added_leaf_QMARK_$jscomp$4$$)};
$APP.$JSCompiler_prototypeAlias$$.$inode_assoc$=function($idx$jscomp$44_len$jscomp$43_shift$jscomp$21$$,$hash$jscomp$20_new_arr$jscomp$9$$,$key$jscomp$152$$,$val$jscomp$92$$,$added_leaf_QMARK_$jscomp$5$$){return $hash$jscomp$20_new_arr$jscomp$9$$===this.$collision_hash$?($idx$jscomp$44_len$jscomp$43_shift$jscomp$21$$=$cljs$core$hash_collision_node_find_index$$(this.$arr$,this.$cnt$,$key$jscomp$152$$),$idx$jscomp$44_len$jscomp$43_shift$jscomp$21$$===-1?($idx$jscomp$44_len$jscomp$43_shift$jscomp$21$$=
2*this.$cnt$,$hash$jscomp$20_new_arr$jscomp$9$$=Array($idx$jscomp$44_len$jscomp$43_shift$jscomp$21$$+2),$cljs$core$array_copy$$(this.$arr$,0,$hash$jscomp$20_new_arr$jscomp$9$$,0,$idx$jscomp$44_len$jscomp$43_shift$jscomp$21$$),$hash$jscomp$20_new_arr$jscomp$9$$[$idx$jscomp$44_len$jscomp$43_shift$jscomp$21$$]=$key$jscomp$152$$,$hash$jscomp$20_new_arr$jscomp$9$$[$idx$jscomp$44_len$jscomp$43_shift$jscomp$21$$+1]=$val$jscomp$92$$,$added_leaf_QMARK_$jscomp$5$$.$val$=!0,new $cljs$core$HashCollisionNode$$(null,
this.$collision_hash$,this.$cnt$+1,$hash$jscomp$20_new_arr$jscomp$9$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$arr$[$idx$jscomp$44_len$jscomp$43_shift$jscomp$21$$+1],$val$jscomp$92$$)?this:new $cljs$core$HashCollisionNode$$(null,this.$collision_hash$,this.$cnt$,$cljs$core$clone_and_set$cljs$0core$0IFn$0_invoke$0arity$03$$(this.$arr$,$idx$jscomp$44_len$jscomp$43_shift$jscomp$21$$+1,$val$jscomp$92$$))):(new $cljs$core$BitmapIndexedNode$$(null,1<<(this.$collision_hash$>>>$idx$jscomp$44_len$jscomp$43_shift$jscomp$21$$&
31),[null,this])).$inode_assoc$($idx$jscomp$44_len$jscomp$43_shift$jscomp$21$$,$hash$jscomp$20_new_arr$jscomp$9$$,$key$jscomp$152$$,$val$jscomp$92$$,$added_leaf_QMARK_$jscomp$5$$)};
$APP.$JSCompiler_prototypeAlias$$.$inode_find$=function($idx$jscomp$45_shift$jscomp$22$$,$hash$jscomp$21$$,$key$jscomp$153$$,$not_found$jscomp$37$$){$idx$jscomp$45_shift$jscomp$22$$=$cljs$core$hash_collision_node_find_index$$(this.$arr$,this.$cnt$,$key$jscomp$153$$);return $idx$jscomp$45_shift$jscomp$22$$<0?$not_found$jscomp$37$$:new $APP.$cljs$core$MapEntry$$(this.$arr$[$idx$jscomp$45_shift$jscomp$22$$],this.$arr$[$idx$jscomp$45_shift$jscomp$22$$+1],null)};
$APP.$JSCompiler_prototypeAlias$$.$inode_without$=function($idx$jscomp$46_shift$jscomp$23$$,$hash$jscomp$22$$,$key$jscomp$154$$){$idx$jscomp$46_shift$jscomp$23$$=$cljs$core$hash_collision_node_find_index$$(this.$arr$,this.$cnt$,$key$jscomp$154$$);return $idx$jscomp$46_shift$jscomp$23$$===-1?this:this.$cnt$===1?null:new $cljs$core$HashCollisionNode$$(null,this.$collision_hash$,this.$cnt$-1,$cljs$core$remove_pair$$(this.$arr$,$APP.$cljs$core$quot$$($idx$jscomp$46_shift$jscomp$23$$,2)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $cljs$core$NodeIterator$$(this.$arr$)};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$NodeSeq$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$91$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$91$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__28080$$=null;$G__28080$$=function($x$jscomp$528$$,$start$jscomp$104$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$528$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$528$$,$start$jscomp$104$$)}throw Error("Invalid arity: "+arguments.length);};$G__28080$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$526$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$526$$,0)};$G__28080$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$527$$,$start$jscomp$103$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$527$$,$start$jscomp$103$$)};return $G__28080$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__28084__1$$($x$jscomp$529$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$529$$,$APP.$cljs$core$count$$(this))}var $G__28084$$=null;$G__28084$$=function($x$jscomp$531$$,$start$jscomp$106$$){switch(arguments.length){case 1:return $G__28084__1$$.call(this,$x$jscomp$531$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$531$$,$start$jscomp$106$$)}throw Error("Invalid arity: "+
arguments.length);};$G__28084$$.$cljs$core$IFn$_invoke$arity$1$=$G__28084__1$$;$G__28084$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$530$$,$start$jscomp$105$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$530$$,$start$jscomp$105$$)};return $G__28084$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){if(this.s==null){var $G__23705_G__23708$$=this.$nodes$,$G__23706_G__23709$$=this.i+2;return $cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$03$$?$cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$03$$($G__23705_G__23708$$,$G__23706_G__23709$$,null):$cljs$core$create_inode_seq$$($G__23705_G__23708$$,$G__23706_G__23709$$,null)}$G__23705_G__23708$$=this.$nodes$;$G__23706_G__23709$$=this.i;var $G__23710$$=
$APP.$cljs$core$next$$(this.s);return $cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$03$$?$cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$03$$($G__23705_G__23708$$,$G__23706_G__23709$$,$G__23710$$):$cljs$core$create_inode_seq$$($G__23705_G__23708$$,$G__23706_G__23709$$,$G__23710$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$15_h__5134__auto____$1$jscomp$15$$=this.$__hash$;return $h__5134__auto__$jscomp$15_h__5134__auto____$1$jscomp$15$$!=null?$h__5134__auto__$jscomp$15_h__5134__auto____$1$jscomp$15$$:this.$__hash$=$h__5134__auto__$jscomp$15_h__5134__auto____$1$jscomp$15$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$549$$,$other$jscomp$92$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$92$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$551$$,$f$jscomp$264$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$264$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$552$$,$f$jscomp$265$$,$start$jscomp$107$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$265$$,$start$jscomp$107$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return this.s==null?new $APP.$cljs$core$MapEntry$$(this.$nodes$[this.i],this.$nodes$[this.i+1],null):$APP.$cljs$core$first$$(this.s)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){var $self__$jscomp$658$$=this,$ret$jscomp$34$$=$self__$jscomp$658$$.s==null?function(){var $G__23711$$=$self__$jscomp$658$$.$nodes$,$G__23712$$=$self__$jscomp$658$$.i+2;return $cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$03$$?$cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$03$$($G__23711$$,$G__23712$$,null):$cljs$core$create_inode_seq$$($G__23711$$,$G__23712$$,null)}():function(){var $G__23714$$=
$self__$jscomp$658$$.$nodes$,$G__23715$$=$self__$jscomp$658$$.i,$G__23716$$=$APP.$cljs$core$next$$($self__$jscomp$658$$.s);return $cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$03$$?$cljs$core$create_inode_seq$cljs$0core$0IFn$0_invoke$0arity$03$$($G__23714$$,$G__23715$$,$G__23716$$):$cljs$core$create_inode_seq$$($G__23714$$,$G__23715$$,$G__23716$$)}();return $ret$jscomp$34$$!=null?$ret$jscomp$34$$:$APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$555$$,$new_meta$jscomp$21$$){return $new_meta$jscomp$21$$===this.$meta$?this:new $APP.$cljs$core$NodeSeq$$($new_meta$jscomp$21$$,this.$nodes$,this.i,this.s,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$556$$,$o$jscomp$111$$){return $APP.$cljs$core$cons$$($o$jscomp$111$$,this)};$APP.$cljs$core$NodeSeq$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$ArrayNodeSeq$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$93$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$93$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__28131$$=null;$G__28131$$=function($x$jscomp$534$$,$start$jscomp$109$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$534$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$534$$,$start$jscomp$109$$)}throw Error("Invalid arity: "+arguments.length);};$G__28131$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$532$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$532$$,0)};$G__28131$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$533$$,$start$jscomp$108$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$533$$,$start$jscomp$108$$)};return $G__28131$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__28137__1$$($x$jscomp$535$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$535$$,$APP.$cljs$core$count$$(this))}var $G__28137$$=null;$G__28137$$=function($x$jscomp$537$$,$start$jscomp$111$$){switch(arguments.length){case 1:return $G__28137__1$$.call(this,$x$jscomp$537$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$537$$,$start$jscomp$111$$)}throw Error("Invalid arity: "+
arguments.length);};$G__28137$$.$cljs$core$IFn$_invoke$arity$1$=$G__28137__1$$;$G__28137$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$536$$,$start$jscomp$110$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$536$$,$start$jscomp$110$$)};return $G__28137$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){var $G__23719$$=this.$nodes$,$G__23720$$=this.i,$G__23721$$=$APP.$cljs$core$next$$(this.s);return $cljs$core$create_array_node_seq$cljs$0core$0IFn$0_invoke$0arity$03$$?$cljs$core$create_array_node_seq$cljs$0core$0IFn$0_invoke$0arity$03$$($G__23719$$,$G__23720$$,$G__23721$$):$cljs$core$create_array_node_seq$$($G__23719$$,$G__23720$$,$G__23721$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$16_h__5134__auto____$1$jscomp$16$$=this.$__hash$;return $h__5134__auto__$jscomp$16_h__5134__auto____$1$jscomp$16$$!=null?$h__5134__auto__$jscomp$16_h__5134__auto____$1$jscomp$16$$:this.$__hash$=$h__5134__auto__$jscomp$16_h__5134__auto____$1$jscomp$16$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$565$$,$other$jscomp$94$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$94$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$567$$,$f$jscomp$266$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$266$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$568$$,$f$jscomp$267$$,$start$jscomp$112$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$267$$,$start$jscomp$112$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return $APP.$cljs$core$first$$(this.s)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){var $G__23722$jscomp$inline_2853_ret$jscomp$35$$=this.$nodes$;var $G__23723$jscomp$inline_2854$$=this.i,$G__23724$jscomp$inline_2855$$=$APP.$cljs$core$next$$(this.s);$G__23722$jscomp$inline_2853_ret$jscomp$35$$=$cljs$core$create_array_node_seq$cljs$0core$0IFn$0_invoke$0arity$03$$?$cljs$core$create_array_node_seq$cljs$0core$0IFn$0_invoke$0arity$03$$($G__23722$jscomp$inline_2853_ret$jscomp$35$$,$G__23723$jscomp$inline_2854$$,
$G__23724$jscomp$inline_2855$$):$cljs$core$create_array_node_seq$$($G__23722$jscomp$inline_2853_ret$jscomp$35$$,$G__23723$jscomp$inline_2854$$,$G__23724$jscomp$inline_2855$$);return $G__23722$jscomp$inline_2853_ret$jscomp$35$$!=null?$G__23722$jscomp$inline_2853_ret$jscomp$35$$:$APP.$cljs$core$List$EMPTY$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$571$$,$new_meta$jscomp$22$$){return $new_meta$jscomp$22$$===this.$meta$?this:new $APP.$cljs$core$ArrayNodeSeq$$($new_meta$jscomp$22$$,this.$nodes$,this.i,this.s,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$572$$,$o$jscomp$112$$){return $APP.$cljs$core$cons$$($o$jscomp$112$$,this)};
$APP.$cljs$core$ArrayNodeSeq$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$cljs$core$HashMapIter$$.prototype.hasNext=function(){return!this.$seen$||this.$root_iter$.hasNext()};$cljs$core$HashMapIter$$.prototype.next=function(){if(this.$seen$)return this.$root_iter$.next();this.$seen$=!0;return new $APP.$cljs$core$MapEntry$$(null,this.$nil_val$,null)};$cljs$core$HashMapIter$$.prototype.remove=function(){return Error("Unsupported operation")};
$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$PersistentHashMap$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$_find$arity$2$=function($coll$jscomp$573$$,$k$jscomp$142$$){return $k$jscomp$142$$==null?this.$has_nil_QMARK_$?new $APP.$cljs$core$MapEntry$$(null,this.$nil_val$,null):null:this.root==null?null:this.root.$inode_find$(0,$APP.$cljs$core$hash$$($k$jscomp$142$$),$k$jscomp$142$$,null)};
$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$95$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$95$$)};$APP.$JSCompiler_prototypeAlias$$.keys=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$keys$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$keys$$.$cljs$core$IFn$_invoke$arity$1$(this):$APP.$cljs$core$keys$$(this))};
$APP.$JSCompiler_prototypeAlias$$.entries=function(){return $APP.$cljs$core$es6_entries_iterator$$($APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.values=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$vals$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$vals$$.$cljs$core$IFn$_invoke$arity$1$(this):$APP.$cljs$core$vals$$(this))};$APP.$JSCompiler_prototypeAlias$$.has=function($k$jscomp$143$$){return $APP.$cljs$core$contains_QMARK_$$(this,$k$jscomp$143$$)};
$APP.$JSCompiler_prototypeAlias$$.get=function($k$jscomp$144$$,$not_found$jscomp$38$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$144$$,$not_found$jscomp$38$$)};
$APP.$JSCompiler_prototypeAlias$$.forEach=function($f$jscomp$268$$){for(var $G__28196_seq__23728_seq__23728__$1_temp__5825__auto__$jscomp$11$$=$APP.$cljs$core$seq$$(this),$c__5548__auto__$jscomp$2_chunk__23729_vec__23741$$=null,$G__28198_count__23730$$=0,$i__23731$$=0;;)if($i__23731$$<$G__28198_count__23730$$){var $v$jscomp$47_vec__23738$$=$c__5548__auto__$jscomp$2_chunk__23729_vec__23741$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__23731$$),$G__28197_k$jscomp$145$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$47_vec__23738$$,
0,null);$v$jscomp$47_vec__23738$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$47_vec__23738$$,1,null);$f$jscomp$268$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$268$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$47_vec__23738$$,$G__28197_k$jscomp$145$$):$f$jscomp$268$$($v$jscomp$47_vec__23738$$,$G__28197_k$jscomp$145$$);$i__23731$$+=1}else if($G__28196_seq__23728_seq__23728__$1_temp__5825__auto__$jscomp$11$$=$APP.$cljs$core$seq$$($G__28196_seq__23728_seq__23728__$1_temp__5825__auto__$jscomp$11$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__28196_seq__23728_seq__23728__$1_temp__5825__auto__$jscomp$11$$)?
($c__5548__auto__$jscomp$2_chunk__23729_vec__23741$$=$APP.$cljs$core$_chunked_first$$($G__28196_seq__23728_seq__23728__$1_temp__5825__auto__$jscomp$11$$),$G__28196_seq__23728_seq__23728__$1_temp__5825__auto__$jscomp$11$$=$APP.$cljs$core$_chunked_rest$$($G__28196_seq__23728_seq__23728__$1_temp__5825__auto__$jscomp$11$$),$G__28197_k$jscomp$145$$=$c__5548__auto__$jscomp$2_chunk__23729_vec__23741$$,$G__28198_count__23730$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$2_chunk__23729_vec__23741$$),$c__5548__auto__$jscomp$2_chunk__23729_vec__23741$$=
$G__28197_k$jscomp$145$$):($c__5548__auto__$jscomp$2_chunk__23729_vec__23741$$=$APP.$cljs$core$first$$($G__28196_seq__23728_seq__23728__$1_temp__5825__auto__$jscomp$11$$),$G__28197_k$jscomp$145$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$2_chunk__23729_vec__23741$$,0,null),$v$jscomp$47_vec__23738$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$2_chunk__23729_vec__23741$$,1,null),$f$jscomp$268$$.$cljs$core$IFn$_invoke$arity$2$?
$f$jscomp$268$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$47_vec__23738$$,$G__28197_k$jscomp$145$$):$f$jscomp$268$$($v$jscomp$47_vec__23738$$,$G__28197_k$jscomp$145$$),$G__28196_seq__23728_seq__23728__$1_temp__5825__auto__$jscomp$11$$=$APP.$cljs$core$next$$($G__28196_seq__23728_seq__23728__$1_temp__5825__auto__$jscomp$11$$),$c__5548__auto__$jscomp$2_chunk__23729_vec__23741$$=null,$G__28198_count__23730$$=0),$i__23731$$=0;else return null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($coll$jscomp$581$$,$k$jscomp$146$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$146$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($coll$jscomp$582$$,$k$jscomp$147$$,$not_found$jscomp$39$$){return $k$jscomp$147$$==null?this.$has_nil_QMARK_$?this.$nil_val$:$not_found$jscomp$39$$:this.root==null?$not_found$jscomp$39$$:this.root.$inode_lookup$(0,$APP.$cljs$core$hash$$($k$jscomp$147$$),$k$jscomp$147$$,$not_found$jscomp$39$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($coll$jscomp$583_init__$1$jscomp$8$$,$f$jscomp$269$$,$init$jscomp$38$$){$coll$jscomp$583_init__$1$jscomp$8$$=this.$has_nil_QMARK_$?$f$jscomp$269$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$269$$.$cljs$core$IFn$_invoke$arity$3$($init$jscomp$38$$,null,this.$nil_val$):$f$jscomp$269$$($init$jscomp$38$$,null,this.$nil_val$):$init$jscomp$38$$;return $cljs$core$reduced_QMARK_$$($coll$jscomp$583_init__$1$jscomp$8$$)?$APP.$cljs$core$_deref$$($coll$jscomp$583_init__$1$jscomp$8$$):
this.root!=null?$cljs$core$unreduced$$(this.root.$kv_reduce$($f$jscomp$269$$,$coll$jscomp$583_init__$1$jscomp$8$$)):$coll$jscomp$583_init__$1$jscomp$8$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){var $root_iter$jscomp$2$$=this.root?$APP.$cljs$core$_iterator$$(this.root):$APP.$cljs$core$nil_iter$$();return this.$has_nil_QMARK_$?new $cljs$core$HashMapIter$$(this.$nil_val$,$root_iter$jscomp$2$$):$root_iter$jscomp$2$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$cljs$core$PersistentHashMap$$(this.$meta$,this.$cnt$,this.root,this.$has_nil_QMARK_$,this.$nil_val$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.$cnt$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$17_h__5134__auto____$1$jscomp$17$$=this.$__hash$;return $h__5134__auto__$jscomp$17_h__5134__auto____$1$jscomp$17$$!=null?$h__5134__auto__$jscomp$17_h__5134__auto____$1$jscomp$17$$:this.$__hash$=$h__5134__auto__$jscomp$17_h__5134__auto____$1$jscomp$17$$=$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$588$$,$other$jscomp$96$$){return $APP.$cljs$core$equiv_map$$(this,$other$jscomp$96$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEditableCollection$_as_transient$arity$1$=function(){return new $cljs$core$TransientHashMap$$(this.root,this.$cnt$,this.$has_nil_QMARK_$,this.$nil_val$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$_with_meta$$($cljs$core$PersistentHashMap$EMPTY$$,this.$meta$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($coll$jscomp$591_new_root$jscomp$5$$,$k$jscomp$148$$){if($k$jscomp$148$$==null)return this.$has_nil_QMARK_$?new $APP.$cljs$core$PersistentHashMap$$(this.$meta$,this.$cnt$-1,this.root,!1,null,null):this;if(this.root==null)return this;$coll$jscomp$591_new_root$jscomp$5$$=this.root.$inode_without$(0,$APP.$cljs$core$hash$$($k$jscomp$148$$),$k$jscomp$148$$);return $coll$jscomp$591_new_root$jscomp$5$$===this.root?this:new $APP.$cljs$core$PersistentHashMap$$(this.$meta$,
this.$cnt$-1,$coll$jscomp$591_new_root$jscomp$5$$,this.$has_nil_QMARK_$,this.$nil_val$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($added_leaf_QMARK_$jscomp$8_coll$jscomp$592$$,$k$jscomp$149_new_root$jscomp$6$$,$v$jscomp$48$$){if($k$jscomp$149_new_root$jscomp$6$$==null)return this.$has_nil_QMARK_$&&$v$jscomp$48$$===this.$nil_val$?this:new $APP.$cljs$core$PersistentHashMap$$(this.$meta$,this.$has_nil_QMARK_$?this.$cnt$:this.$cnt$+1,this.root,!0,$v$jscomp$48$$,null);$added_leaf_QMARK_$jscomp$8_coll$jscomp$592$$=new $cljs$core$Box$$;$k$jscomp$149_new_root$jscomp$6$$=
(this.root==null?$cljs$core$BitmapIndexedNode$EMPTY$$:this.root).$inode_assoc$(0,$APP.$cljs$core$hash$$($k$jscomp$149_new_root$jscomp$6$$),$k$jscomp$149_new_root$jscomp$6$$,$v$jscomp$48$$,$added_leaf_QMARK_$jscomp$8_coll$jscomp$592$$);return $k$jscomp$149_new_root$jscomp$6$$===this.root?this:new $APP.$cljs$core$PersistentHashMap$$(this.$meta$,$added_leaf_QMARK_$jscomp$8_coll$jscomp$592$$.$val$?this.$cnt$+1:this.$cnt$,$k$jscomp$149_new_root$jscomp$6$$,this.$has_nil_QMARK_$,this.$nil_val$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($coll$jscomp$593$$,$k$jscomp$150$$){return $k$jscomp$150$$==null?this.$has_nil_QMARK_$:this.root==null?!1:this.root.$inode_lookup$(0,$APP.$cljs$core$hash$$($k$jscomp$150$$),$k$jscomp$150$$,$cljs$core$lookup_sentinel$$)!==$cljs$core$lookup_sentinel$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){if(this.$cnt$>0){var $s$jscomp$98$$=this.root!=null?this.root.$inode_seq$():null;return this.$has_nil_QMARK_$?$APP.$cljs$core$cons$$(new $APP.$cljs$core$MapEntry$$(null,this.$nil_val$,null),$s$jscomp$98$$):$s$jscomp$98$$}return null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$595$$,$new_meta$jscomp$23$$){return $new_meta$jscomp$23$$===this.$meta$?this:new $APP.$cljs$core$PersistentHashMap$$($new_meta$jscomp$23$$,this.$cnt$,this.root,this.$has_nil_QMARK_$,this.$nil_val$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($G__28257_coll$jscomp$596_ret$jscomp$36$$,$G__28258_entry$jscomp$4_es$jscomp$2$$){if($APP.$cljs$core$vector_QMARK_$$($G__28258_entry$jscomp$4_es$jscomp$2$$))return this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($G__28258_entry$jscomp$4_es$jscomp$2$$,0),$APP.$cljs$core$_nth$$($G__28258_entry$jscomp$4_es$jscomp$2$$,1));$G__28257_coll$jscomp$596_ret$jscomp$36$$=this;for($G__28258_entry$jscomp$4_es$jscomp$2$$=
$APP.$cljs$core$seq$$($G__28258_entry$jscomp$4_es$jscomp$2$$);;){if($G__28258_entry$jscomp$4_es$jscomp$2$$==null)return $G__28257_coll$jscomp$596_ret$jscomp$36$$;var $e$jscomp$94$$=$APP.$cljs$core$first$$($G__28258_entry$jscomp$4_es$jscomp$2$$);if($APP.$cljs$core$vector_QMARK_$$($e$jscomp$94$$))$G__28257_coll$jscomp$596_ret$jscomp$36$$=$APP.$cljs$core$_assoc$$($G__28257_coll$jscomp$596_ret$jscomp$36$$,$APP.$cljs$core$_nth$$($e$jscomp$94$$,0),$APP.$cljs$core$_nth$$($e$jscomp$94$$,1)),$G__28258_entry$jscomp$4_es$jscomp$2$$=
$APP.$cljs$core$next$$($G__28258_entry$jscomp$4_es$jscomp$2$$);else throw Error("conj on a map takes map entries or seqables of map entries");}};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$11$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$710$$,$args23727$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23727$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$151$$){return this.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$151$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$152$$,$not_found$jscomp$40$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$152$$,$not_found$jscomp$40$$)};var $cljs$core$PersistentHashMap$EMPTY$$=new $APP.$cljs$core$PersistentHashMap$$(null,0,null,!1,null,$cljs$core$empty_unordered_hash$$);
$APP.$cljs$core$PersistentHashMap$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$TransientHashMap$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){if(this.$edit$)return this.count;throw Error("count after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($tcoll$jscomp$43$$,$k$jscomp$155$$){return $k$jscomp$155$$==null?this.$has_nil_QMARK_$?this.$nil_val$:null:this.root==null?null:this.root.$inode_lookup$(0,$APP.$cljs$core$hash$$($k$jscomp$155$$),$k$jscomp$155$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($tcoll$jscomp$44$$,$k$jscomp$156$$,$not_found$jscomp$41$$){return $k$jscomp$156$$==null?this.$has_nil_QMARK_$?this.$nil_val$:$not_found$jscomp$41$$:this.root==null?$not_found$jscomp$41$$:this.root.$inode_lookup$(0,$APP.$cljs$core$hash$$($k$jscomp$156$$),$k$jscomp$156$$,$not_found$jscomp$41$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientCollection$_conj_BANG_$arity$2$=function($G__28324$jscomp$inline_2863_JSCompiler_inline_result$jscomp$226_es$jscomp$inline_2859_tcoll$jscomp$45$$,$G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$){a:{if(this.$edit$){if($APP.$cljs$core$map_entry_QMARK_$$($G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$)){$G__28324$jscomp$inline_2863_JSCompiler_inline_result$jscomp$226_es$jscomp$inline_2859_tcoll$jscomp$45$$=
$JSCompiler_StaticMethods_assoc_BANG_$$(this,$APP.$cljs$core$key$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$key$$.$cljs$core$IFn$_invoke$arity$1$($G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$):$APP.$cljs$core$_key$$($G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$),$APP.$cljs$core$val$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$val$$.$cljs$core$IFn$_invoke$arity$1$($G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$):
$APP.$cljs$core$_val$$($G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$));break a}if($APP.$cljs$core$vector_QMARK_$$($G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$)){$G__28324$jscomp$inline_2863_JSCompiler_inline_result$jscomp$226_es$jscomp$inline_2859_tcoll$jscomp$45$$=$JSCompiler_StaticMethods_assoc_BANG_$$(this,$G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$.$cljs$core$IFn$_invoke$arity$1$?$G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$.$cljs$core$IFn$_invoke$arity$1$(0):
$G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$(0),$G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$.$cljs$core$IFn$_invoke$arity$1$?$G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$.$cljs$core$IFn$_invoke$arity$1$(1):$G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$(1));break a}$G__28324$jscomp$inline_2863_JSCompiler_inline_result$jscomp$226_es$jscomp$inline_2859_tcoll$jscomp$45$$=$APP.$cljs$core$seq$$($G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$);
for($G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$=this;;){var $e$jscomp$inline_2862_temp__5823__auto__$jscomp$inline_2861$$=$APP.$cljs$core$first$$($G__28324$jscomp$inline_2863_JSCompiler_inline_result$jscomp$226_es$jscomp$inline_2859_tcoll$jscomp$45$$);if($APP.$cljs$core$truth_$$($e$jscomp$inline_2862_temp__5823__auto__$jscomp$inline_2861$$))$G__28324$jscomp$inline_2863_JSCompiler_inline_result$jscomp$226_es$jscomp$inline_2859_tcoll$jscomp$45$$=$APP.$cljs$core$next$$($G__28324$jscomp$inline_2863_JSCompiler_inline_result$jscomp$226_es$jscomp$inline_2859_tcoll$jscomp$45$$),
$G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$=$JSCompiler_StaticMethods_assoc_BANG_$$($G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$,$APP.$cljs$core$key$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$key$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$inline_2862_temp__5823__auto__$jscomp$inline_2861$$):$APP.$cljs$core$_key$$($e$jscomp$inline_2862_temp__5823__auto__$jscomp$inline_2861$$),$APP.$cljs$core$val$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$val$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$inline_2862_temp__5823__auto__$jscomp$inline_2861$$):
$APP.$cljs$core$_val$$($e$jscomp$inline_2862_temp__5823__auto__$jscomp$inline_2861$$));else{$G__28324$jscomp$inline_2863_JSCompiler_inline_result$jscomp$226_es$jscomp$inline_2859_tcoll$jscomp$45$$=$G__28325$jscomp$inline_2864_tcoll__$1$jscomp$inline_2860_val$jscomp$93$$;break a}}}else throw Error("conj! after persistent");$G__28324$jscomp$inline_2863_JSCompiler_inline_result$jscomp$226_es$jscomp$inline_2859_tcoll$jscomp$45$$=void 0}return $G__28324$jscomp$inline_2863_JSCompiler_inline_result$jscomp$226_es$jscomp$inline_2859_tcoll$jscomp$45$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientCollection$_persistent_BANG_$arity$1$=function(){if(this.$edit$){this.$edit$=null;var $JSCompiler_inline_result$jscomp$228$$=new $APP.$cljs$core$PersistentHashMap$$(null,this.count,this.root,this.$has_nil_QMARK_$,this.$nil_val$,null)}else throw Error("persistent! called twice");return $JSCompiler_inline_result$jscomp$228$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$=function($tcoll$jscomp$47$$,$key$jscomp$155$$,$val$jscomp$94$$){return $JSCompiler_StaticMethods_assoc_BANG_$$(this,$key$jscomp$155$$,$val$jscomp$94$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientMap$_dissoc_BANG_$arity$2$=function($removed_leaf_QMARK_$jscomp$inline_2870_tcoll$jscomp$48$$,$key$jscomp$156_node$jscomp$inline_2871$$){if(this.$edit$)$key$jscomp$156_node$jscomp$inline_2871$$==null?this.$has_nil_QMARK_$&&(this.$has_nil_QMARK_$=!1,this.$nil_val$=null,--this.count):this.root!=null&&($removed_leaf_QMARK_$jscomp$inline_2870_tcoll$jscomp$48$$=new $cljs$core$Box$$,$key$jscomp$156_node$jscomp$inline_2871$$=this.root.$inode_without_BANG_$(this.$edit$,
0,$APP.$cljs$core$hash$$($key$jscomp$156_node$jscomp$inline_2871$$),$key$jscomp$156_node$jscomp$inline_2871$$,$removed_leaf_QMARK_$jscomp$inline_2870_tcoll$jscomp$48$$),$key$jscomp$156_node$jscomp$inline_2871$$!==this.root&&(this.root=$key$jscomp$156_node$jscomp$inline_2871$$),$removed_leaf_QMARK_$jscomp$inline_2870_tcoll$jscomp$48$$.$val$&&--this.count);else throw Error("dissoc! after persistent!");return this};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$12$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$725$$,$args23747$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23747$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($key$jscomp$157$$){return this.$cljs$core$ILookup$_lookup$arity$2$(null,$key$jscomp$157$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($key$jscomp$158$$,$not_found$jscomp$42$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$key$jscomp$158$$,$not_found$jscomp$42$$)};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$PersistentTreeMapSeq$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$97$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$97$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__28361$$=null;$G__28361$$=function($x$jscomp$540$$,$start$jscomp$114$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$540$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$540$$,$start$jscomp$114$$)}throw Error("Invalid arity: "+arguments.length);};$G__28361$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$538$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$538$$,0)};$G__28361$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$539$$,$start$jscomp$113$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$539$$,$start$jscomp$113$$)};return $G__28361$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__28362__1$$($x$jscomp$541$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$541$$,$APP.$cljs$core$count$$(this))}var $G__28362$$=null;$G__28362$$=function($x$jscomp$543$$,$start$jscomp$116$$){switch(arguments.length){case 1:return $G__28362__1$$.call(this,$x$jscomp$543$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$543$$,$start$jscomp$116$$)}throw Error("Invalid arity: "+
arguments.length);};$G__28362$$.$cljs$core$IFn$_invoke$arity$1$=$G__28362__1$$;$G__28362$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$542$$,$start$jscomp$115$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$542$$,$start$jscomp$115$$)};return $G__28362$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){var $next_stack_t$jscomp$11$$=$APP.$cljs$core$first$$(this.stack);$next_stack_t$jscomp$11$$=$cljs$core$tree_map_seq_push$$(this.$ascending_QMARK_$?$next_stack_t$jscomp$11$$.right:$next_stack_t$jscomp$11$$.left,$APP.$cljs$core$next$$(this.stack),this.$ascending_QMARK_$);return $next_stack_t$jscomp$11$$==null?null:new $cljs$core$PersistentTreeMapSeq$$(null,$next_stack_t$jscomp$11$$,this.$ascending_QMARK_$,this.$cnt$-1,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.$cnt$<0?$APP.$cljs$core$count$$($APP.$cljs$core$next$$(this))+1:this.$cnt$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$18_h__5134__auto____$1$jscomp$18$$=this.$__hash$;return $h__5134__auto__$jscomp$18_h__5134__auto____$1$jscomp$18$$!=null?$h__5134__auto__$jscomp$18_h__5134__auto____$1$jscomp$18$$:this.$__hash$=$h__5134__auto__$jscomp$18_h__5134__auto____$1$jscomp$18$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$608$$,$other$jscomp$98$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$98$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$610$$,$f$jscomp$270$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$270$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$611$$,$f$jscomp$271$$,$start$jscomp$117$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$271$$,$start$jscomp$117$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return $APP.$cljs$core$peek$$(this.stack)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){var $next_stack$jscomp$1_t$jscomp$12$$=$APP.$cljs$core$first$$(this.stack);$next_stack$jscomp$1_t$jscomp$12$$=$cljs$core$tree_map_seq_push$$(this.$ascending_QMARK_$?$next_stack$jscomp$1_t$jscomp$12$$.right:$next_stack$jscomp$1_t$jscomp$12$$.left,$APP.$cljs$core$next$$(this.stack),this.$ascending_QMARK_$);return $next_stack$jscomp$1_t$jscomp$12$$!=null?new $cljs$core$PersistentTreeMapSeq$$(null,$next_stack$jscomp$1_t$jscomp$12$$,
this.$ascending_QMARK_$,this.$cnt$-1,null):$APP.$cljs$core$List$EMPTY$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$612$$,$new_meta$jscomp$24$$){return $new_meta$jscomp$24$$===this.$meta$?this:new $cljs$core$PersistentTreeMapSeq$$($new_meta$jscomp$24$$,this.stack,this.$ascending_QMARK_$,this.$cnt$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$613$$,$o$jscomp$114$$){return $APP.$cljs$core$cons$$($o$jscomp$114$$,this)};$cljs$core$PersistentTreeMapSeq$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
var $cljs$core$tree_map_kv_reduce$$=function $cljs$core$tree_map_kv_reduce$$($node$jscomp$61$$,$f$jscomp$272$$,$init$jscomp$39$$){var $init__$1$jscomp$9$$=$node$jscomp$61$$.left!=null?function(){var $G__23749$$=$node$jscomp$61$$.left;return $cljs$core$tree_map_kv_reduce$$.$cljs$core$IFn$_invoke$arity$3$?$cljs$core$tree_map_kv_reduce$$.$cljs$core$IFn$_invoke$arity$3$($G__23749$$,$f$jscomp$272$$,$init$jscomp$39$$):$cljs$core$tree_map_kv_reduce$$($G__23749$$,$f$jscomp$272$$,$init$jscomp$39$$)}():$init$jscomp$39$$;
if($cljs$core$reduced_QMARK_$$($init__$1$jscomp$9$$))return $init__$1$jscomp$9$$;var $init__$2$jscomp$9$$=function(){var $G__23753$$=$node$jscomp$61$$.key,$G__23754$$=$node$jscomp$61$$.$val$;return $f$jscomp$272$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$272$$.$cljs$core$IFn$_invoke$arity$3$($init__$1$jscomp$9$$,$G__23753$$,$G__23754$$):$f$jscomp$272$$($init__$1$jscomp$9$$,$G__23753$$,$G__23754$$)}();if($cljs$core$reduced_QMARK_$$($init__$2$jscomp$9$$))return $init__$2$jscomp$9$$;if($node$jscomp$61$$.right!=
null){var $G__23755$$=$node$jscomp$61$$.right;return $cljs$core$tree_map_kv_reduce$$.$cljs$core$IFn$_invoke$arity$3$?$cljs$core$tree_map_kv_reduce$$.$cljs$core$IFn$_invoke$arity$3$($G__23755$$,$f$jscomp$272$$,$init__$2$jscomp$9$$):$cljs$core$tree_map_kv_reduce$$($G__23755$$,$f$jscomp$272$$,$init__$2$jscomp$9$$)}return $init__$2$jscomp$9$$};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$BlackNode$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$_find$arity$2$=function($node$jscomp$62$$,$k$jscomp$157$$){switch($k$jscomp$157$$){case 0:return new $APP.$cljs$core$MapEntry$$(0,this.key,null);case 1:return new $APP.$cljs$core$MapEntry$$(1,this.$val$,null);default:return null}};
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__28424__1$$($x$jscomp$544$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$544$$,$APP.$cljs$core$count$$(this))}var $G__28424$$=null;$G__28424$$=function($x$jscomp$546$$,$start$jscomp$119$$){switch(arguments.length){case 1:return $G__28424__1$$.call(this,$x$jscomp$546$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$546$$,$start$jscomp$119$$)}throw Error("Invalid arity: "+
arguments.length);};$G__28424$$.$cljs$core$IFn$_invoke$arity$1$=$G__28424__1$$;$G__28424$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$545$$,$start$jscomp$118$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$545$$,$start$jscomp$118$$)};return $G__28424$$}();
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__28427$$=null;$G__28427$$=function($x$jscomp$549$$,$start$jscomp$121$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$549$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$549$$,$start$jscomp$121$$)}throw Error("Invalid arity: "+arguments.length);};$G__28427$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$547$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$547$$,0)};$G__28427$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$548$$,$start$jscomp$120$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$548$$,$start$jscomp$120$$)};return $G__28427$$}();$APP.$JSCompiler_prototypeAlias$$.$add_right$=function($ins$jscomp$2$$){return $ins$jscomp$2$$.$balance_right$(this)};$APP.$JSCompiler_prototypeAlias$$.$redden$=function(){return new $APP.$cljs$core$RedNode$$(this.key,this.$val$,this.left,this.right,null)};
$APP.$JSCompiler_prototypeAlias$$.$blacken$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$add_left$=function($ins$jscomp$3$$){return $ins$jscomp$3$$.$balance_left$(this)};$APP.$JSCompiler_prototypeAlias$$.replace=function($key__$1$$,$val__$1$jscomp$4$$,$left__$1$$,$right__$1$$){return new $APP.$cljs$core$BlackNode$$($key__$1$$,$val__$1$jscomp$4$$,$left__$1$$,$right__$1$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$balance_left$=function($parent$jscomp$7$$){return new $APP.$cljs$core$BlackNode$$($parent$jscomp$7$$.key,$parent$jscomp$7$$.$val$,this,$parent$jscomp$7$$.right,null)};$APP.$JSCompiler_prototypeAlias$$.$balance_right$=function($parent$jscomp$8$$){return new $APP.$cljs$core$BlackNode$$($parent$jscomp$8$$.key,$parent$jscomp$8$$.$val$,$parent$jscomp$8$$.left,this,null)};
$APP.$JSCompiler_prototypeAlias$$.$kv_reduce$=function($f$jscomp$273$$,$init$jscomp$40$$){return $cljs$core$tree_map_kv_reduce$$(this,$f$jscomp$273$$,$init$jscomp$40$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($node$jscomp$73$$,$k$jscomp$158$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$158$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($node$jscomp$74$$,$k$jscomp$159$$,$not_found$jscomp$43$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$159$$,$not_found$jscomp$43$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($node$jscomp$75$$,$n$jscomp$132$$){if($n$jscomp$132$$===0)return this.key;if($n$jscomp$132$$===1)return this.$val$;throw Error("Index out of bounds");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($node$jscomp$76$$,$n$jscomp$133$$,$not_found$jscomp$44$$){return $n$jscomp$133$$===0?this.key:$n$jscomp$133$$===1?this.$val$:$not_found$jscomp$44$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IVector$_assoc_n$arity$3$=function($node$jscomp$77$$,$n$jscomp$134$$,$v$jscomp$50$$){return(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key,this.$val$],null)).$cljs$core$IVector$_assoc_n$arity$3$(null,$n$jscomp$134$$,$v$jscomp$50$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMapEntry$_key$arity$1$=function(){return this.key};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMapEntry$_val$arity$1$=function(){return this.$val$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_peek$arity$1$=function(){return this.$val$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_pop$arity$1$=function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key],null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReversible$_rseq$arity$1$=function(){return new $APP.$cljs$core$IndexedSeq$$([this.$val$,this.key],0,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$19_h__5134__auto____$1$jscomp$19$$=this.$__hash$;return $h__5134__auto__$jscomp$19_h__5134__auto____$1$jscomp$19$$!=null?$h__5134__auto__$jscomp$19_h__5134__auto____$1$jscomp$19$$:this.$__hash$=$h__5134__auto__$jscomp$19_h__5134__auto____$1$jscomp$19$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$619$$,$other$jscomp$99$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$99$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($node$jscomp$86$$,$f$jscomp$274$$){return $cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$f$jscomp$274$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($node$jscomp$87$$,$f$jscomp$275$$,$start$jscomp$122$$){return $cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$f$jscomp$275$$,$start$jscomp$122$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($node$jscomp$88$$,$k$jscomp$160$$,$v$jscomp$51$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key,this.$val$],null),$k$jscomp$160$$,$v$jscomp$51$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($node$jscomp$89$$,$k$jscomp$161$$){return $k$jscomp$161$$===0||$k$jscomp$161$$===1};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return new $APP.$cljs$core$IndexedSeq$$([this.key,this.$val$],0,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($node$jscomp$91$$,$meta$jscomp$53$$){return $APP.$cljs$core$_with_meta$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key,this.$val$],null),$meta$jscomp$53$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($node$jscomp$92$$,$o$jscomp$115$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key,this.$val$,$o$jscomp$115$$],null)};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$13$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$785$$,$args23758$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23758$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$162$$){return this.$cljs$core$IIndexed$_nth$arity$2$(null,$k$jscomp$162$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$163$$,$not_found$jscomp$45$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$163$$,$not_found$jscomp$45$$)};$APP.$cljs$core$BlackNode$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$RedNode$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$_find$arity$2$=function($node$jscomp$95$$,$k$jscomp$164$$){switch($k$jscomp$164$$){case 0:return new $APP.$cljs$core$MapEntry$$(0,this.key,null);case 1:return new $APP.$cljs$core$MapEntry$$(1,this.$val$,null);default:return null}};
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__28487__1$$($x$jscomp$550$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$550$$,$APP.$cljs$core$count$$(this))}var $G__28487$$=null;$G__28487$$=function($x$jscomp$552$$,$start$jscomp$124$$){switch(arguments.length){case 1:return $G__28487__1$$.call(this,$x$jscomp$552$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$552$$,$start$jscomp$124$$)}throw Error("Invalid arity: "+
arguments.length);};$G__28487$$.$cljs$core$IFn$_invoke$arity$1$=$G__28487__1$$;$G__28487$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$551$$,$start$jscomp$123$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$551$$,$start$jscomp$123$$)};return $G__28487$$}();
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__28490$$=null;$G__28490$$=function($x$jscomp$555$$,$start$jscomp$126$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$555$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$555$$,$start$jscomp$126$$)}throw Error("Invalid arity: "+arguments.length);};$G__28490$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$553$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$553$$,0)};$G__28490$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$554$$,$start$jscomp$125$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$554$$,$start$jscomp$125$$)};return $G__28490$$}();$APP.$JSCompiler_prototypeAlias$$.$add_right$=function($ins$jscomp$4$$){return new $APP.$cljs$core$RedNode$$(this.key,this.$val$,this.left,$ins$jscomp$4$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$redden$=function(){throw Error("red-black tree invariant violation");};$APP.$JSCompiler_prototypeAlias$$.$blacken$=function(){return new $APP.$cljs$core$BlackNode$$(this.key,this.$val$,this.left,this.right,null)};$APP.$JSCompiler_prototypeAlias$$.$add_left$=function($ins$jscomp$5$$){return new $APP.$cljs$core$RedNode$$(this.key,this.$val$,$ins$jscomp$5$$,this.right,null)};
$APP.$JSCompiler_prototypeAlias$$.replace=function($key__$1$jscomp$1$$,$val__$1$jscomp$5$$,$left__$1$jscomp$1$$,$right__$1$jscomp$1$$){return new $APP.$cljs$core$RedNode$$($key__$1$jscomp$1$$,$val__$1$jscomp$5$$,$left__$1$jscomp$1$$,$right__$1$jscomp$1$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$balance_left$=function($parent$jscomp$9$$){return this.left instanceof $APP.$cljs$core$RedNode$$?new $APP.$cljs$core$RedNode$$(this.key,this.$val$,this.left.$blacken$(),new $APP.$cljs$core$BlackNode$$($parent$jscomp$9$$.key,$parent$jscomp$9$$.$val$,this.right,$parent$jscomp$9$$.right,null),null):this.right instanceof $APP.$cljs$core$RedNode$$?new $APP.$cljs$core$RedNode$$(this.right.key,this.right.$val$,new $APP.$cljs$core$BlackNode$$(this.key,this.$val$,this.left,
this.right.left,null),new $APP.$cljs$core$BlackNode$$($parent$jscomp$9$$.key,$parent$jscomp$9$$.$val$,this.right.right,$parent$jscomp$9$$.right,null),null):new $APP.$cljs$core$BlackNode$$($parent$jscomp$9$$.key,$parent$jscomp$9$$.$val$,this,$parent$jscomp$9$$.right,null)};
$APP.$JSCompiler_prototypeAlias$$.$balance_right$=function($parent$jscomp$10$$){return this.right instanceof $APP.$cljs$core$RedNode$$?new $APP.$cljs$core$RedNode$$(this.key,this.$val$,new $APP.$cljs$core$BlackNode$$($parent$jscomp$10$$.key,$parent$jscomp$10$$.$val$,$parent$jscomp$10$$.left,this.left,null),this.right.$blacken$(),null):this.left instanceof $APP.$cljs$core$RedNode$$?new $APP.$cljs$core$RedNode$$(this.left.key,this.left.$val$,new $APP.$cljs$core$BlackNode$$($parent$jscomp$10$$.key,$parent$jscomp$10$$.$val$,
$parent$jscomp$10$$.left,this.left.left,null),new $APP.$cljs$core$BlackNode$$(this.key,this.$val$,this.left.right,this.right,null),null):new $APP.$cljs$core$BlackNode$$($parent$jscomp$10$$.key,$parent$jscomp$10$$.$val$,$parent$jscomp$10$$.left,this,null)};$APP.$JSCompiler_prototypeAlias$$.$kv_reduce$=function($f$jscomp$276$$,$init$jscomp$41$$){return $cljs$core$tree_map_kv_reduce$$(this,$f$jscomp$276$$,$init$jscomp$41$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($node$jscomp$106$$,$k$jscomp$165$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$165$$,null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($node$jscomp$107$$,$k$jscomp$166$$,$not_found$jscomp$46$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$166$$,$not_found$jscomp$46$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($node$jscomp$108$$,$n$jscomp$135$$){if($n$jscomp$135$$===0)return this.key;if($n$jscomp$135$$===1)return this.$val$;throw Error("Index out of bounds");};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($node$jscomp$109$$,$n$jscomp$136$$,$not_found$jscomp$47$$){return $n$jscomp$136$$===0?this.key:$n$jscomp$136$$===1?this.$val$:$not_found$jscomp$47$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IVector$_assoc_n$arity$3$=function($node$jscomp$110$$,$n$jscomp$137$$,$v$jscomp$52$$){return(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key,this.$val$],null)).$cljs$core$IVector$_assoc_n$arity$3$(null,$n$jscomp$137$$,$v$jscomp$52$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMapEntry$_key$arity$1$=function(){return this.key};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMapEntry$_val$arity$1$=function(){return this.$val$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_peek$arity$1$=function(){return this.$val$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_pop$arity$1$=function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key],null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReversible$_rseq$arity$1$=function(){return new $APP.$cljs$core$IndexedSeq$$([this.$val$,this.key],0,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$20_h__5134__auto____$1$jscomp$20$$=this.$__hash$;return $h__5134__auto__$jscomp$20_h__5134__auto____$1$jscomp$20$$!=null?$h__5134__auto__$jscomp$20_h__5134__auto____$1$jscomp$20$$:this.$__hash$=$h__5134__auto__$jscomp$20_h__5134__auto____$1$jscomp$20$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$625$$,$other$jscomp$100$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$100$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($node$jscomp$119$$,$f$jscomp$277$$){return $cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$f$jscomp$277$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($node$jscomp$120$$,$f$jscomp$278$$,$start$jscomp$127$$){return $cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$f$jscomp$278$$,$start$jscomp$127$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($node$jscomp$121$$,$k$jscomp$167$$,$v$jscomp$53$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key,this.$val$],null),$k$jscomp$167$$,$v$jscomp$53$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($node$jscomp$122$$,$k$jscomp$168$$){return $k$jscomp$168$$===0||$k$jscomp$168$$===1};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return new $APP.$cljs$core$IndexedSeq$$([this.key,this.$val$],0,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($node$jscomp$124$$,$meta$jscomp$54$$){return $APP.$cljs$core$_with_meta$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key,this.$val$],null),$meta$jscomp$54$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($node$jscomp$125$$,$o$jscomp$116$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.key,this.$val$,$o$jscomp$116$$],null)};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$14$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$826$$,$args23761$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23761$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$169$$){return this.$cljs$core$IIndexed$_nth$arity$2$(null,$k$jscomp$169$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$170$$,$not_found$jscomp$48$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$170$$,$not_found$jscomp$48$$)};$APP.$cljs$core$RedNode$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
var $cljs$core$tree_map_add$$=function $cljs$core$tree_map_add$$($comp$jscomp$2$$,$tree$jscomp$1$$,$k$jscomp$171$$,$v$jscomp$54$$,$found$jscomp$2$$){if($tree$jscomp$1$$==null)return new $APP.$cljs$core$RedNode$$($k$jscomp$171$$,$v$jscomp$54$$,null,null,null);var $c$jscomp$111_ins$jscomp$6$$=function(){var $G__23765$$=$tree$jscomp$1$$.key;return $comp$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$comp$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$171$$,$G__23765$$):$comp$jscomp$2$$($k$jscomp$171$$,
$G__23765$$)}();if($c$jscomp$111_ins$jscomp$6$$===0)return $found$jscomp$2$$[0]=$tree$jscomp$1$$,null;if($c$jscomp$111_ins$jscomp$6$$<0)return $c$jscomp$111_ins$jscomp$6$$=function(){var $G__23767$$=$tree$jscomp$1$$.left;return $cljs$core$tree_map_add$$.$cljs$core$IFn$_invoke$arity$5$?$cljs$core$tree_map_add$$.$cljs$core$IFn$_invoke$arity$5$($comp$jscomp$2$$,$G__23767$$,$k$jscomp$171$$,$v$jscomp$54$$,$found$jscomp$2$$):$cljs$core$tree_map_add$$($comp$jscomp$2$$,$G__23767$$,$k$jscomp$171$$,$v$jscomp$54$$,
$found$jscomp$2$$)}(),$c$jscomp$111_ins$jscomp$6$$!=null?$tree$jscomp$1$$.$add_left$($c$jscomp$111_ins$jscomp$6$$):null;$c$jscomp$111_ins$jscomp$6$$=function(){var $G__23772$$=$tree$jscomp$1$$.right;return $cljs$core$tree_map_add$$.$cljs$core$IFn$_invoke$arity$5$?$cljs$core$tree_map_add$$.$cljs$core$IFn$_invoke$arity$5$($comp$jscomp$2$$,$G__23772$$,$k$jscomp$171$$,$v$jscomp$54$$,$found$jscomp$2$$):$cljs$core$tree_map_add$$($comp$jscomp$2$$,$G__23772$$,$k$jscomp$171$$,$v$jscomp$54$$,$found$jscomp$2$$)}();
return $c$jscomp$111_ins$jscomp$6$$!=null?$tree$jscomp$1$$.$add_right$($c$jscomp$111_ins$jscomp$6$$):null},$cljs$core$tree_map_append$$=function $cljs$core$tree_map_append$$($left$jscomp$10$$,$right$jscomp$10$$){if($left$jscomp$10$$==null)return $right$jscomp$10$$;if($right$jscomp$10$$==null)return $left$jscomp$10$$;if($left$jscomp$10$$ instanceof $APP.$cljs$core$RedNode$$){if($right$jscomp$10$$ instanceof $APP.$cljs$core$RedNode$$){var $app__$1$$=function(){var $G__23776$$=$left$jscomp$10$$.right,
$G__23777$$=$right$jscomp$10$$.left;return $cljs$core$tree_map_append$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$core$tree_map_append$$.$cljs$core$IFn$_invoke$arity$2$($G__23776$$,$G__23777$$):$cljs$core$tree_map_append$$($G__23776$$,$G__23777$$)}();return $app__$1$$ instanceof $APP.$cljs$core$RedNode$$?new $APP.$cljs$core$RedNode$$($app__$1$$.key,$app__$1$$.$val$,new $APP.$cljs$core$RedNode$$($left$jscomp$10$$.key,$left$jscomp$10$$.$val$,$left$jscomp$10$$.left,$app__$1$$.left,null),new $APP.$cljs$core$RedNode$$($right$jscomp$10$$.key,
$right$jscomp$10$$.$val$,$app__$1$$.right,$right$jscomp$10$$.right,null),null):new $APP.$cljs$core$RedNode$$($left$jscomp$10$$.key,$left$jscomp$10$$.$val$,$left$jscomp$10$$.left,new $APP.$cljs$core$RedNode$$($right$jscomp$10$$.key,$right$jscomp$10$$.$val$,$app__$1$$,$right$jscomp$10$$.right,null),null)}return new $APP.$cljs$core$RedNode$$($left$jscomp$10$$.key,$left$jscomp$10$$.$val$,$left$jscomp$10$$.left,function(){var $G__23778$$=$left$jscomp$10$$.right;return $cljs$core$tree_map_append$$.$cljs$core$IFn$_invoke$arity$2$?
$cljs$core$tree_map_append$$.$cljs$core$IFn$_invoke$arity$2$($G__23778$$,$right$jscomp$10$$):$cljs$core$tree_map_append$$($G__23778$$,$right$jscomp$10$$)}(),null)}if($right$jscomp$10$$ instanceof $APP.$cljs$core$RedNode$$)return new $APP.$cljs$core$RedNode$$($right$jscomp$10$$.key,$right$jscomp$10$$.$val$,function(){var $G__23781$$=$right$jscomp$10$$.left;return $cljs$core$tree_map_append$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$core$tree_map_append$$.$cljs$core$IFn$_invoke$arity$2$($left$jscomp$10$$,
$G__23781$$):$cljs$core$tree_map_append$$($left$jscomp$10$$,$G__23781$$)}(),$right$jscomp$10$$.right,null);$app__$1$$=function(){var $G__23782$$=$left$jscomp$10$$.right,$G__23783$$=$right$jscomp$10$$.left;return $cljs$core$tree_map_append$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$core$tree_map_append$$.$cljs$core$IFn$_invoke$arity$2$($G__23782$$,$G__23783$$):$cljs$core$tree_map_append$$($G__23782$$,$G__23783$$)}();return $app__$1$$ instanceof $APP.$cljs$core$RedNode$$?new $APP.$cljs$core$RedNode$$($app__$1$$.key,
$app__$1$$.$val$,new $APP.$cljs$core$BlackNode$$($left$jscomp$10$$.key,$left$jscomp$10$$.$val$,$left$jscomp$10$$.left,$app__$1$$.left,null),new $APP.$cljs$core$BlackNode$$($right$jscomp$10$$.key,$right$jscomp$10$$.$val$,$app__$1$$.right,$right$jscomp$10$$.right,null),null):$cljs$core$balance_left_del$$($left$jscomp$10$$.key,$left$jscomp$10$$.$val$,$left$jscomp$10$$.left,new $APP.$cljs$core$BlackNode$$($right$jscomp$10$$.key,$right$jscomp$10$$.$val$,$app__$1$$,$right$jscomp$10$$.right,null))},$cljs$core$tree_map_remove$$=
function $cljs$core$tree_map_remove$$($comp$jscomp$3$$,$tree$jscomp$2$$,$k$jscomp$172$$,$found$jscomp$3$$){if($tree$jscomp$2$$!=null){var $c$jscomp$112_del$jscomp$6$$=function(){var $G__23785$$=$tree$jscomp$2$$.key;return $comp$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$?$comp$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$172$$,$G__23785$$):$comp$jscomp$3$$($k$jscomp$172$$,$G__23785$$)}();if($c$jscomp$112_del$jscomp$6$$===0)return $found$jscomp$3$$[0]=$tree$jscomp$2$$,$cljs$core$tree_map_append$$($tree$jscomp$2$$.left,
$tree$jscomp$2$$.right);if($c$jscomp$112_del$jscomp$6$$<0)return $c$jscomp$112_del$jscomp$6$$=function(){var $G__23787$$=$tree$jscomp$2$$.left;return $cljs$core$tree_map_remove$$.$cljs$core$IFn$_invoke$arity$4$?$cljs$core$tree_map_remove$$.$cljs$core$IFn$_invoke$arity$4$($comp$jscomp$3$$,$G__23787$$,$k$jscomp$172$$,$found$jscomp$3$$):$cljs$core$tree_map_remove$$($comp$jscomp$3$$,$G__23787$$,$k$jscomp$172$$,$found$jscomp$3$$)}(),$c$jscomp$112_del$jscomp$6$$!=null||$found$jscomp$3$$[0]!=null?$tree$jscomp$2$$.left instanceof
$APP.$cljs$core$BlackNode$$?$cljs$core$balance_left_del$$($tree$jscomp$2$$.key,$tree$jscomp$2$$.$val$,$c$jscomp$112_del$jscomp$6$$,$tree$jscomp$2$$.right):new $APP.$cljs$core$RedNode$$($tree$jscomp$2$$.key,$tree$jscomp$2$$.$val$,$c$jscomp$112_del$jscomp$6$$,$tree$jscomp$2$$.right,null):null;$c$jscomp$112_del$jscomp$6$$=function(){var $G__23791$$=$tree$jscomp$2$$.right;return $cljs$core$tree_map_remove$$.$cljs$core$IFn$_invoke$arity$4$?$cljs$core$tree_map_remove$$.$cljs$core$IFn$_invoke$arity$4$($comp$jscomp$3$$,
$G__23791$$,$k$jscomp$172$$,$found$jscomp$3$$):$cljs$core$tree_map_remove$$($comp$jscomp$3$$,$G__23791$$,$k$jscomp$172$$,$found$jscomp$3$$)}();return $c$jscomp$112_del$jscomp$6$$!=null||$found$jscomp$3$$[0]!=null?$tree$jscomp$2$$.right instanceof $APP.$cljs$core$BlackNode$$?$cljs$core$balance_right_del$$($tree$jscomp$2$$.key,$tree$jscomp$2$$.$val$,$tree$jscomp$2$$.left,$c$jscomp$112_del$jscomp$6$$):new $APP.$cljs$core$RedNode$$($tree$jscomp$2$$.key,$tree$jscomp$2$$.$val$,$tree$jscomp$2$$.left,$c$jscomp$112_del$jscomp$6$$,
null):null}return null},$cljs$core$tree_map_replace$$=function $cljs$core$tree_map_replace$$($comp$jscomp$4$$,$tree$jscomp$3$$,$k$jscomp$173$$,$v$jscomp$55$$){var $tk$$=$tree$jscomp$3$$.key,$c$jscomp$113$$=$comp$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$comp$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$173$$,$tk$$):$comp$jscomp$4$$($k$jscomp$173$$,$tk$$);return $c$jscomp$113$$===0?$tree$jscomp$3$$.replace($tk$$,$v$jscomp$55$$,$tree$jscomp$3$$.left,$tree$jscomp$3$$.right):$c$jscomp$113$$<
0?$tree$jscomp$3$$.replace($tk$$,$tree$jscomp$3$$.$val$,function(){var $G__23795$$=$tree$jscomp$3$$.left;return $cljs$core$tree_map_replace$$.$cljs$core$IFn$_invoke$arity$4$?$cljs$core$tree_map_replace$$.$cljs$core$IFn$_invoke$arity$4$($comp$jscomp$4$$,$G__23795$$,$k$jscomp$173$$,$v$jscomp$55$$):$cljs$core$tree_map_replace$$($comp$jscomp$4$$,$G__23795$$,$k$jscomp$173$$,$v$jscomp$55$$)}(),$tree$jscomp$3$$.right):$tree$jscomp$3$$.replace($tk$$,$tree$jscomp$3$$.$val$,$tree$jscomp$3$$.left,function(){var $G__23799$$=
$tree$jscomp$3$$.right;return $cljs$core$tree_map_replace$$.$cljs$core$IFn$_invoke$arity$4$?$cljs$core$tree_map_replace$$.$cljs$core$IFn$_invoke$arity$4$($comp$jscomp$4$$,$G__23799$$,$k$jscomp$173$$,$v$jscomp$55$$):$cljs$core$tree_map_replace$$($comp$jscomp$4$$,$G__23799$$,$k$jscomp$173$$,$v$jscomp$55$$)}())};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$PersistentTreeMap$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$_find$arity$2$=function($coll$jscomp$626$$,$k$jscomp$174$$){return $JSCompiler_StaticMethods_entry_at$$(this,$k$jscomp$174$$)};
$APP.$JSCompiler_prototypeAlias$$.forEach=function($f$jscomp$279$$){for(var $G__28619_seq__23803_seq__23803__$1_temp__5825__auto__$jscomp$12$$=$APP.$cljs$core$seq$$(this),$c__5548__auto__$jscomp$3_chunk__23804_vec__23816$$=null,$G__28621_count__23805$$=0,$i__23806$$=0;;)if($i__23806$$<$G__28621_count__23805$$){var $v$jscomp$56_vec__23813$$=$c__5548__auto__$jscomp$3_chunk__23804_vec__23816$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__23806$$),$G__28620_k$jscomp$175$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$56_vec__23813$$,
0,null);$v$jscomp$56_vec__23813$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$56_vec__23813$$,1,null);$f$jscomp$279$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$279$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$56_vec__23813$$,$G__28620_k$jscomp$175$$):$f$jscomp$279$$($v$jscomp$56_vec__23813$$,$G__28620_k$jscomp$175$$);$i__23806$$+=1}else if($G__28619_seq__23803_seq__23803__$1_temp__5825__auto__$jscomp$12$$=$APP.$cljs$core$seq$$($G__28619_seq__23803_seq__23803__$1_temp__5825__auto__$jscomp$12$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__28619_seq__23803_seq__23803__$1_temp__5825__auto__$jscomp$12$$)?
($c__5548__auto__$jscomp$3_chunk__23804_vec__23816$$=$APP.$cljs$core$_chunked_first$$($G__28619_seq__23803_seq__23803__$1_temp__5825__auto__$jscomp$12$$),$G__28619_seq__23803_seq__23803__$1_temp__5825__auto__$jscomp$12$$=$APP.$cljs$core$_chunked_rest$$($G__28619_seq__23803_seq__23803__$1_temp__5825__auto__$jscomp$12$$),$G__28620_k$jscomp$175$$=$c__5548__auto__$jscomp$3_chunk__23804_vec__23816$$,$G__28621_count__23805$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$3_chunk__23804_vec__23816$$),$c__5548__auto__$jscomp$3_chunk__23804_vec__23816$$=
$G__28620_k$jscomp$175$$):($c__5548__auto__$jscomp$3_chunk__23804_vec__23816$$=$APP.$cljs$core$first$$($G__28619_seq__23803_seq__23803__$1_temp__5825__auto__$jscomp$12$$),$G__28620_k$jscomp$175$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$3_chunk__23804_vec__23816$$,0,null),$v$jscomp$56_vec__23813$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$3_chunk__23804_vec__23816$$,1,null),$f$jscomp$279$$.$cljs$core$IFn$_invoke$arity$2$?
$f$jscomp$279$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$56_vec__23813$$,$G__28620_k$jscomp$175$$):$f$jscomp$279$$($v$jscomp$56_vec__23813$$,$G__28620_k$jscomp$175$$),$G__28619_seq__23803_seq__23803__$1_temp__5825__auto__$jscomp$12$$=$APP.$cljs$core$next$$($G__28619_seq__23803_seq__23803__$1_temp__5825__auto__$jscomp$12$$),$c__5548__auto__$jscomp$3_chunk__23804_vec__23816$$=null,$G__28621_count__23805$$=0),$i__23806$$=0;else return null};
$APP.$JSCompiler_prototypeAlias$$.get=function($k$jscomp$176$$,$not_found$jscomp$49$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$176$$,$not_found$jscomp$49$$)};$APP.$JSCompiler_prototypeAlias$$.entries=function(){return $APP.$cljs$core$es6_entries_iterator$$($APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.keys=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$keys$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$keys$$.$cljs$core$IFn$_invoke$arity$1$(this):$APP.$cljs$core$keys$$(this))};$APP.$JSCompiler_prototypeAlias$$.values=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$vals$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$vals$$.$cljs$core$IFn$_invoke$arity$1$(this):$APP.$cljs$core$vals$$(this))};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$101$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$101$$)};$APP.$JSCompiler_prototypeAlias$$.has=function($k$jscomp$178$$){return $APP.$cljs$core$contains_QMARK_$$(this,$k$jscomp$178$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($coll$jscomp$635$$,$k$jscomp$179$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$179$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($coll$jscomp$636_n$jscomp$138$$,$k$jscomp$180$$,$not_found$jscomp$50$$){$coll$jscomp$636_n$jscomp$138$$=$JSCompiler_StaticMethods_entry_at$$(this,$k$jscomp$180$$);return $coll$jscomp$636_n$jscomp$138$$!=null?$coll$jscomp$636_n$jscomp$138$$.$val$:$not_found$jscomp$50$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($coll$jscomp$637$$,$f$jscomp$280$$,$init$jscomp$42$$){return this.$tree$!=null?$cljs$core$unreduced$$($cljs$core$tree_map_kv_reduce$$(this.$tree$,$f$jscomp$280$$,$init$jscomp$42$$)):$init$jscomp$42$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$cljs$core$PersistentTreeMap$$(this.$comp$,this.$tree$,this.$cnt$,this.$meta$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.$cnt$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReversible$_rseq$arity$1$=function(){return this.$cnt$>0?$cljs$core$create_tree_map_seq$$(this.$tree$,!1,this.$cnt$):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$21_h__5134__auto____$1$jscomp$21$$=this.$__hash$;return $h__5134__auto__$jscomp$21_h__5134__auto____$1$jscomp$21$$!=null?$h__5134__auto__$jscomp$21_h__5134__auto____$1$jscomp$21$$:this.$__hash$=$h__5134__auto__$jscomp$21_h__5134__auto____$1$jscomp$21$$=$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$642$$,$other$jscomp$102$$){return $APP.$cljs$core$equiv_map$$(this,$other$jscomp$102$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return new $APP.$cljs$core$PersistentTreeMap$$(this.$comp$,null,0,this.$meta$,0)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($coll$jscomp$644_found$jscomp$4$$,$k$jscomp$181_t$jscomp$14$$){$coll$jscomp$644_found$jscomp$4$$=[null];$k$jscomp$181_t$jscomp$14$$=$cljs$core$tree_map_remove$$(this.$comp$,this.$tree$,$k$jscomp$181_t$jscomp$14$$,$coll$jscomp$644_found$jscomp$4$$);return $k$jscomp$181_t$jscomp$14$$==null?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($coll$jscomp$644_found$jscomp$4$$,0)==null?this:new $APP.$cljs$core$PersistentTreeMap$$(this.$comp$,
null,0,this.$meta$,null):new $APP.$cljs$core$PersistentTreeMap$$(this.$comp$,$k$jscomp$181_t$jscomp$14$$.$blacken$(),this.$cnt$-1,this.$meta$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($coll$jscomp$645_found$jscomp$5_found_node$$,$k$jscomp$182$$,$v$jscomp$57$$){$coll$jscomp$645_found$jscomp$5_found_node$$=[null];var $t$jscomp$15$$=$cljs$core$tree_map_add$$(this.$comp$,this.$tree$,$k$jscomp$182$$,$v$jscomp$57$$,$coll$jscomp$645_found$jscomp$5_found_node$$);return $t$jscomp$15$$==null?($coll$jscomp$645_found$jscomp$5_found_node$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($coll$jscomp$645_found$jscomp$5_found_node$$,
0),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$57$$,$coll$jscomp$645_found$jscomp$5_found_node$$.$val$)?this:new $APP.$cljs$core$PersistentTreeMap$$(this.$comp$,$cljs$core$tree_map_replace$$(this.$comp$,this.$tree$,$k$jscomp$182$$,$v$jscomp$57$$),this.$cnt$,this.$meta$,null)):new $APP.$cljs$core$PersistentTreeMap$$(this.$comp$,$t$jscomp$15$$.$blacken$(),this.$cnt$+1,this.$meta$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($coll$jscomp$646$$,$k$jscomp$183$$){return $JSCompiler_StaticMethods_entry_at$$(this,$k$jscomp$183$$)!=null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this.$cnt$>0?$cljs$core$create_tree_map_seq$$(this.$tree$,!0,this.$cnt$):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$648$$,$new_meta$jscomp$25$$){return $new_meta$jscomp$25$$===this.$meta$?this:new $APP.$cljs$core$PersistentTreeMap$$(this.$comp$,this.$tree$,this.$cnt$,$new_meta$jscomp$25$$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($G__28680_coll$jscomp$649_ret$jscomp$39$$,$G__28681_entry$jscomp$5_es$jscomp$4$$){if($APP.$cljs$core$vector_QMARK_$$($G__28681_entry$jscomp$5_es$jscomp$4$$))return this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($G__28681_entry$jscomp$5_es$jscomp$4$$,0),$APP.$cljs$core$_nth$$($G__28681_entry$jscomp$5_es$jscomp$4$$,1));$G__28680_coll$jscomp$649_ret$jscomp$39$$=this;for($G__28681_entry$jscomp$5_es$jscomp$4$$=
$APP.$cljs$core$seq$$($G__28681_entry$jscomp$5_es$jscomp$4$$);;){if($G__28681_entry$jscomp$5_es$jscomp$4$$==null)return $G__28680_coll$jscomp$649_ret$jscomp$39$$;var $e$jscomp$96$$=$APP.$cljs$core$first$$($G__28681_entry$jscomp$5_es$jscomp$4$$);if($APP.$cljs$core$vector_QMARK_$$($e$jscomp$96$$))$G__28680_coll$jscomp$649_ret$jscomp$39$$=$APP.$cljs$core$_assoc$$($G__28680_coll$jscomp$649_ret$jscomp$39$$,$APP.$cljs$core$_nth$$($e$jscomp$96$$,0),$APP.$cljs$core$_nth$$($e$jscomp$96$$,1)),$G__28681_entry$jscomp$5_es$jscomp$4$$=
$APP.$cljs$core$next$$($G__28681_entry$jscomp$5_es$jscomp$4$$);else throw Error("conj on a map takes map entries or seqables of map entries");}};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$15$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$856$$,$args23802$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23802$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$184$$){return this.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$184$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$185$$,$not_found$jscomp$51$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$185$$,$not_found$jscomp$51$$)};$APP.$cljs$core$PersistentTreeMap$EMPTY$$=new $APP.$cljs$core$PersistentTreeMap$$($APP.$cljs$core$compare$$,null,0,null,$cljs$core$empty_unordered_hash$$);
$APP.$cljs$core$PersistentTreeMap$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
$APP.$cljs$core$hash_map$$=function $cljs$core$hash_map$$($var_args$jscomp$241$$){for(var $args__5755__auto__$jscomp$3$$=[],$len__5749__auto___28738$$=arguments.length,$i__5750__auto___28739$$=0;;)if($i__5750__auto___28739$$<$len__5749__auto___28738$$)$args__5755__auto__$jscomp$3$$.push(arguments[$i__5750__auto___28739$$]),$i__5750__auto___28739$$+=1;else break;return $cljs$core$hash_map$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$3$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$3$$.slice(0),
0,null):null)};
$APP.$cljs$core$hash_map$$.$cljs$core$IFn$_invoke$arity$variadic$=function($in$$jscomp$2_keyvals$jscomp$1$$){$in$$jscomp$2_keyvals$jscomp$1$$=$APP.$cljs$core$seq$$($in$$jscomp$2_keyvals$jscomp$1$$);for(var $G__28744_out$jscomp$9$$=$APP.$cljs$core$_as_transient$$($cljs$core$PersistentHashMap$EMPTY$$);;)if($in$$jscomp$2_keyvals$jscomp$1$$){var $in_SINGLEQUOTE_$$=$APP.$cljs$core$next$$($in$$jscomp$2_keyvals$jscomp$1$$);if($in_SINGLEQUOTE_$$==null)throw Error(["No value supplied for key: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($in$$jscomp$2_keyvals$jscomp$1$$))].join(""));
var $G__28743$$=$APP.$cljs$core$next$$($in_SINGLEQUOTE_$$);$G__28744_out$jscomp$9$$=$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($G__28744_out$jscomp$9$$,$APP.$cljs$core$first$$($in$$jscomp$2_keyvals$jscomp$1$$),$APP.$cljs$core$first$$($in_SINGLEQUOTE_$$));$in$$jscomp$2_keyvals$jscomp$1$$=$G__28743$$}else return $APP.$cljs$core$_persistent_BANG_$$($G__28744_out$jscomp$9$$)};$APP.$cljs$core$hash_map$$.$cljs$lang$maxFixedArity$=0;$APP.$cljs$core$hash_map$$.$cljs$lang$applyTo$=function($seq23826$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq23826$$))};
var $cljs$core$array_map$$=function $cljs$core$array_map$$($var_args$jscomp$242$$){for(var $args__5755__auto__$jscomp$4$$=[],$len__5749__auto___28752$$=arguments.length,$i__5750__auto___28753$$=0;;)if($i__5750__auto___28753$$<$len__5749__auto___28752$$)$args__5755__auto__$jscomp$4$$.push(arguments[$i__5750__auto___28753$$]),$i__5750__auto___28753$$+=1;else break;return $cljs$core$array_map$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$4$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$4$$.slice(0),
0,null):null)};
$cljs$core$array_map$$.$cljs$core$IFn$_invoke$arity$variadic$=function($arr$jscomp$129_keyvals$jscomp$2$$){$arr$jscomp$129_keyvals$jscomp$2$$=$arr$jscomp$129_keyvals$jscomp$2$$ instanceof $APP.$cljs$core$IndexedSeq$$&&$arr$jscomp$129_keyvals$jscomp$2$$.i===0?$arr$jscomp$129_keyvals$jscomp$2$$.$arr$:$APP.$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$02$$($arr$jscomp$129_keyvals$jscomp$2$$);if(!$APP.$cljs$core$even_QMARK_$$($arr$jscomp$129_keyvals$jscomp$2$$.length))throw Error(["No value supplied for key: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($arr$jscomp$129_keyvals$jscomp$2$$))].join(""));
return $APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$($arr$jscomp$129_keyvals$jscomp$2$$)};$cljs$core$array_map$$.$cljs$lang$maxFixedArity$=0;$cljs$core$array_map$$.$cljs$lang$applyTo$=function($seq23827$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq23827$$))};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$KeySeq$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$103$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$103$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__28826$$=null;$G__28826$$=function($x$jscomp$558$$,$start$jscomp$129$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$558$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$558$$,$start$jscomp$129$$)}throw Error("Invalid arity: "+arguments.length);};$G__28826$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$556$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$556$$,0)};$G__28826$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$557$$,$start$jscomp$128$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$557$$,$start$jscomp$128$$)};return $G__28826$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__28829__1$$($x$jscomp$559$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$559$$,$APP.$cljs$core$count$$(this))}var $G__28829$$=null;$G__28829$$=function($x$jscomp$561$$,$start$jscomp$131$$){switch(arguments.length){case 1:return $G__28829__1$$.call(this,$x$jscomp$561$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$561$$,$start$jscomp$131$$)}throw Error("Invalid arity: "+
arguments.length);};$G__28829$$.$cljs$core$IFn$_invoke$arity$1$=$G__28829__1$$;$G__28829$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$560$$,$start$jscomp$130$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$560$$,$start$jscomp$130$$)};return $G__28829$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$_meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){var $nseq$$=(this.$mseq$!=null?this.$mseq$.$cljs$lang$protocol_mask$partition0$$&128||$APP.$cljs$core$PROTOCOL_SENTINEL$$===this.$mseq$.$cljs$core$INext$$||(this.$mseq$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$INext$$,this.$mseq$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$INext$$,this.$mseq$))?this.$mseq$.$cljs$core$INext$_next$arity$1$(null):$APP.$cljs$core$next$$(this.$mseq$);
return $nseq$$==null?null:new $cljs$core$KeySeq$$($nseq$$,null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $cljs$core$hash_ordered_coll$$(this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$664$$,$other$jscomp$104$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$104$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$666$$,$f$jscomp$281$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$281$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$667$$,$f$jscomp$282$$,$start$jscomp$132$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$282$$,$start$jscomp$132$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return this.$mseq$.$cljs$core$ISeq$_first$arity$1$(null).key};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){var $nseq$jscomp$1$$=(this.$mseq$!=null?this.$mseq$.$cljs$lang$protocol_mask$partition0$$&128||$APP.$cljs$core$PROTOCOL_SENTINEL$$===this.$mseq$.$cljs$core$INext$$||(this.$mseq$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$INext$$,this.$mseq$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$INext$$,this.$mseq$))?this.$mseq$.$cljs$core$INext$_next$arity$1$(null):$APP.$cljs$core$next$$(this.$mseq$);
return $nseq$jscomp$1$$!=null?new $cljs$core$KeySeq$$($nseq$jscomp$1$$,null):$APP.$cljs$core$List$EMPTY$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$671$$,$new_meta$jscomp$26$$){return $new_meta$jscomp$26$$===this.$_meta$?this:new $cljs$core$KeySeq$$(this.$mseq$,$new_meta$jscomp$26$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$672$$,$o$jscomp$117$$){return $APP.$cljs$core$cons$$($o$jscomp$117$$,this)};$cljs$core$KeySeq$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$ValSeq$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$105$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$105$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__28883$$=null;$G__28883$$=function($x$jscomp$564$$,$start$jscomp$134$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$564$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$564$$,$start$jscomp$134$$)}throw Error("Invalid arity: "+arguments.length);};$G__28883$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$562$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$562$$,0)};$G__28883$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$563$$,$start$jscomp$133$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$563$$,$start$jscomp$133$$)};return $G__28883$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__28888__1$$($x$jscomp$565$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$565$$,$APP.$cljs$core$count$$(this))}var $G__28888$$=null;$G__28888$$=function($x$jscomp$567$$,$start$jscomp$136$$){switch(arguments.length){case 1:return $G__28888__1$$.call(this,$x$jscomp$567$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$567$$,$start$jscomp$136$$)}throw Error("Invalid arity: "+
arguments.length);};$G__28888$$.$cljs$core$IFn$_invoke$arity$1$=$G__28888__1$$;$G__28888$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$566$$,$start$jscomp$135$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$566$$,$start$jscomp$135$$)};return $G__28888$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$_meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){var $nseq$jscomp$2$$=(this.$mseq$!=null?this.$mseq$.$cljs$lang$protocol_mask$partition0$$&128||$APP.$cljs$core$PROTOCOL_SENTINEL$$===this.$mseq$.$cljs$core$INext$$||(this.$mseq$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$INext$$,this.$mseq$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$INext$$,this.$mseq$))?this.$mseq$.$cljs$core$INext$_next$arity$1$(null):$APP.$cljs$core$next$$(this.$mseq$);
return $nseq$jscomp$2$$==null?null:new $cljs$core$ValSeq$$($nseq$jscomp$2$$,null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $cljs$core$hash_ordered_coll$$(this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$681$$,$other$jscomp$106$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$106$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$683$$,$f$jscomp$283$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$283$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$684$$,$f$jscomp$284$$,$start$jscomp$137$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$284$$,$start$jscomp$137$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return this.$mseq$.$cljs$core$ISeq$_first$arity$1$(null).$cljs$core$IMapEntry$_val$arity$1$(null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){var $nseq$jscomp$3$$=(this.$mseq$!=null?this.$mseq$.$cljs$lang$protocol_mask$partition0$$&128||$APP.$cljs$core$PROTOCOL_SENTINEL$$===this.$mseq$.$cljs$core$INext$$||(this.$mseq$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$INext$$,this.$mseq$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$INext$$,this.$mseq$))?this.$mseq$.$cljs$core$INext$_next$arity$1$(null):$APP.$cljs$core$next$$(this.$mseq$);
return $nseq$jscomp$3$$!=null?new $cljs$core$ValSeq$$($nseq$jscomp$3$$,null):$APP.$cljs$core$List$EMPTY$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$688$$,$new_meta$jscomp$27$$){return $new_meta$jscomp$27$$===this.$_meta$?this:new $cljs$core$ValSeq$$(this.$mseq$,$new_meta$jscomp$27$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$689$$,$o$jscomp$118$$){return $APP.$cljs$core$cons$$($o$jscomp$118$$,this)};$cljs$core$ValSeq$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
$APP.$cljs$core$merge$$=function $cljs$core$merge$$($var_args$jscomp$246$$){for(var $args__5755__auto__$jscomp$8$$=[],$len__5749__auto___28923$$=arguments.length,$i__5750__auto___28924$$=0;;)if($i__5750__auto___28924$$<$len__5749__auto___28923$$)$args__5755__auto__$jscomp$8$$.push(arguments[$i__5750__auto___28924$$]),$i__5750__auto___28924$$+=1;else break;return $cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$8$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$8$$.slice(0),
0,null):null)};$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$=function($maps$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($APP.$cljs$core$identity$$,$maps$$))?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__23838_SHARP_$$,$p2__23839_SHARP_$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($p1__23838_SHARP_$$)?$p1__23838_SHARP_$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$p2__23839_SHARP_$$)},$maps$$):null};
$APP.$cljs$core$merge$$.$cljs$lang$maxFixedArity$=0;$APP.$cljs$core$merge$$.$cljs$lang$applyTo$=function($seq23840$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq23840$$))};
$APP.$cljs$core$merge_with$$=function $cljs$core$merge_with$$($var_args$jscomp$247$$){for(var $args__5755__auto__$jscomp$9$$=[],$len__5749__auto___28928$$=arguments.length,$i__5750__auto___28929$$=0;;)if($i__5750__auto___28929$$<$len__5749__auto___28928$$)$args__5755__auto__$jscomp$9$$.push(arguments[$i__5750__auto___28929$$]),$i__5750__auto___28929$$+=1;else break;return $cljs$core$merge_with$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args__5755__auto__$jscomp$9$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$9$$.slice(1),
0,null):null)};
$APP.$cljs$core$merge_with$$.$cljs$core$IFn$_invoke$arity$variadic$=function($f$jscomp$285$$,$maps$jscomp$1$$){if($APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($APP.$cljs$core$identity$$,$maps$jscomp$1$$))){var $merge_entry$$=function($JSCompiler_temp$jscomp$230_m$jscomp$55$$,$JSCompiler_temp_const$jscomp$231_e$jscomp$97$$){var $k$jscomp$187$$=$APP.$cljs$core$_key$$($JSCompiler_temp_const$jscomp$231_e$jscomp$97$$),$JSCompiler_inline_result$jscomp$233_v$jscomp$58$$=$APP.$cljs$core$_val$$($JSCompiler_temp_const$jscomp$231_e$jscomp$97$$);if($APP.$cljs$core$contains_QMARK_$$($JSCompiler_temp$jscomp$230_m$jscomp$55$$,
$k$jscomp$187$$)){$JSCompiler_temp_const$jscomp$231_e$jscomp$97$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;var $G__23843$jscomp$inline_2882$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$230_m$jscomp$55$$,$k$jscomp$187$$);$JSCompiler_inline_result$jscomp$233_v$jscomp$58$$=$f$jscomp$285$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$285$$.$cljs$core$IFn$_invoke$arity$2$($G__23843$jscomp$inline_2882$$,$JSCompiler_inline_result$jscomp$233_v$jscomp$58$$):$f$jscomp$285$$($G__23843$jscomp$inline_2882$$,
$JSCompiler_inline_result$jscomp$233_v$jscomp$58$$);$JSCompiler_temp$jscomp$230_m$jscomp$55$$=$JSCompiler_temp_const$jscomp$231_e$jscomp$97$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp$jscomp$230_m$jscomp$55$$,$k$jscomp$187$$,$JSCompiler_inline_result$jscomp$233_v$jscomp$58$$)}else $JSCompiler_temp$jscomp$230_m$jscomp$55$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$230_m$jscomp$55$$,$k$jscomp$187$$,$JSCompiler_inline_result$jscomp$233_v$jscomp$58$$);return $JSCompiler_temp$jscomp$230_m$jscomp$55$$};
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(function($m1$$,$m2$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($merge_entry$$,$APP.$cljs$core$truth_$$($m1$$)?$m1$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$seq$$($m2$$))},$maps$jscomp$1$$)}return null};$APP.$cljs$core$merge_with$$.$cljs$lang$maxFixedArity$=1;
$APP.$cljs$core$merge_with$$.$cljs$lang$applyTo$=function($seq23841_seq23841__$1$$){var $G__23842$$=$APP.$cljs$core$first$$($seq23841_seq23841__$1$$);$seq23841_seq23841__$1$$=$APP.$cljs$core$next$$($seq23841_seq23841__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23842$$,$seq23841_seq23841__$1$$)};$cljs$core$HashSetIter$$.prototype.hasNext=function(){return this.$iter$.hasNext()};
$cljs$core$HashSetIter$$.prototype.next=function(){if(this.$iter$.hasNext())return this.$iter$.next().key;throw Error("No such element");};$cljs$core$HashSetIter$$.prototype.remove=function(){return Error("Unsupported operation")};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$PersistentHashSet$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$107$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$107$$)};$APP.$JSCompiler_prototypeAlias$$.keys=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.entries=function(){return $cljs$core$es6_set_entries_iterator$$($APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.values=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$seq$$(this))};
$APP.$JSCompiler_prototypeAlias$$.has=function($k$jscomp$188$$){return $APP.$cljs$core$contains_QMARK_$$(this,$k$jscomp$188$$)};
$APP.$JSCompiler_prototypeAlias$$.forEach=function($f$jscomp$286$$){for(var $G__28976_seq__23848_seq__23848__$1_temp__5825__auto__$jscomp$15$$=$APP.$cljs$core$seq$$(this),$c__5548__auto__$jscomp$4_chunk__23849_vec__23861$$=null,$G__28978_count__23850$$=0,$i__23851$$=0;;)if($i__23851$$<$G__28978_count__23850$$){var $v$jscomp$59_vec__23858$$=$c__5548__auto__$jscomp$4_chunk__23849_vec__23861$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__23851$$),$G__28977_k$jscomp$189$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$59_vec__23858$$,
0,null);$v$jscomp$59_vec__23858$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$59_vec__23858$$,1,null);$f$jscomp$286$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$286$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$59_vec__23858$$,$G__28977_k$jscomp$189$$):$f$jscomp$286$$($v$jscomp$59_vec__23858$$,$G__28977_k$jscomp$189$$);$i__23851$$+=1}else if($G__28976_seq__23848_seq__23848__$1_temp__5825__auto__$jscomp$15$$=$APP.$cljs$core$seq$$($G__28976_seq__23848_seq__23848__$1_temp__5825__auto__$jscomp$15$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__28976_seq__23848_seq__23848__$1_temp__5825__auto__$jscomp$15$$)?
($c__5548__auto__$jscomp$4_chunk__23849_vec__23861$$=$APP.$cljs$core$_chunked_first$$($G__28976_seq__23848_seq__23848__$1_temp__5825__auto__$jscomp$15$$),$G__28976_seq__23848_seq__23848__$1_temp__5825__auto__$jscomp$15$$=$APP.$cljs$core$_chunked_rest$$($G__28976_seq__23848_seq__23848__$1_temp__5825__auto__$jscomp$15$$),$G__28977_k$jscomp$189$$=$c__5548__auto__$jscomp$4_chunk__23849_vec__23861$$,$G__28978_count__23850$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$4_chunk__23849_vec__23861$$),$c__5548__auto__$jscomp$4_chunk__23849_vec__23861$$=
$G__28977_k$jscomp$189$$):($c__5548__auto__$jscomp$4_chunk__23849_vec__23861$$=$APP.$cljs$core$first$$($G__28976_seq__23848_seq__23848__$1_temp__5825__auto__$jscomp$15$$),$G__28977_k$jscomp$189$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$4_chunk__23849_vec__23861$$,0,null),$v$jscomp$59_vec__23858$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$4_chunk__23849_vec__23861$$,1,null),$f$jscomp$286$$.$cljs$core$IFn$_invoke$arity$2$?
$f$jscomp$286$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$59_vec__23858$$,$G__28977_k$jscomp$189$$):$f$jscomp$286$$($v$jscomp$59_vec__23858$$,$G__28977_k$jscomp$189$$),$G__28976_seq__23848_seq__23848__$1_temp__5825__auto__$jscomp$15$$=$APP.$cljs$core$next$$($G__28976_seq__23848_seq__23848__$1_temp__5825__auto__$jscomp$15$$),$c__5548__auto__$jscomp$4_chunk__23849_vec__23861$$=null,$G__28978_count__23850$$=0),$i__23851$$=0;else return null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($coll$jscomp$696$$,$v$jscomp$60$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$v$jscomp$60$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($coll$jscomp$697_temp__5823__auto__$jscomp$12$$,$v$jscomp$61$$,$not_found$jscomp$52$$){$coll$jscomp$697_temp__5823__auto__$jscomp$12$$=$cljs$core$_find$$(this.$hash_map$,$v$jscomp$61$$);return $APP.$cljs$core$truth_$$($coll$jscomp$697_temp__5823__auto__$jscomp$12$$)?$APP.$cljs$core$_key$$($coll$jscomp$697_temp__5823__auto__$jscomp$12$$):$not_found$jscomp$52$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $cljs$core$HashSetIter$$($APP.$cljs$core$_iterator$$(this.$hash_map$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$cljs$core$PersistentHashSet$$(this.$meta$,this.$hash_map$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return $APP.$cljs$core$_count$$(this.$hash_map$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$22_h__5134__auto____$1$jscomp$22$$=this.$__hash$;return $h__5134__auto__$jscomp$22_h__5134__auto____$1$jscomp$22$$!=null?$h__5134__auto__$jscomp$22_h__5134__auto____$1$jscomp$22$$:this.$__hash$=$h__5134__auto__$jscomp$22_h__5134__auto____$1$jscomp$22$$=$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($and__5023__auto__$jscomp$26_and__5023__auto____$1$jscomp$12_coll$jscomp$702$$,$other$jscomp$108$$){if($and__5023__auto__$jscomp$26_and__5023__auto____$1$jscomp$12_coll$jscomp$702$$=$APP.$cljs$core$set_QMARK_$$($other$jscomp$108$$))if($and__5023__auto__$jscomp$26_and__5023__auto____$1$jscomp$12_coll$jscomp$702$$=$APP.$cljs$core$count$$(this)===$APP.$cljs$core$count$$($other$jscomp$108$$))try{return $APP.$cljs$core$reduce_kv$$(function($or__5025__auto__$jscomp$39_p1__23846_SHARP_$$,
$p2__23845_SHARP_$$){return($or__5025__auto__$jscomp$39_p1__23846_SHARP_$$=$APP.$cljs$core$contains_QMARK_$$($other$jscomp$108$$,$p2__23845_SHARP_$$))?$or__5025__auto__$jscomp$39_p1__23846_SHARP_$$:$APP.$cljs$core$reduced$$(!1)},!0,this.$hash_map$)}catch($e23864$$){if($e23864$$ instanceof Error)return!1;throw $e23864$$;}else return $and__5023__auto__$jscomp$26_and__5023__auto____$1$jscomp$12_coll$jscomp$702$$;else return $and__5023__auto__$jscomp$26_and__5023__auto____$1$jscomp$12_coll$jscomp$702$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEditableCollection$_as_transient$arity$1$=function(){return new $cljs$core$TransientHashSet$$($APP.$cljs$core$_as_transient$$(this.$hash_map$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$_with_meta$$($APP.$cljs$core$PersistentHashSet$EMPTY$$,this.$meta$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISet$_disjoin$arity$2$=function($coll$jscomp$705$$,$v$jscomp$62$$){return new $APP.$cljs$core$PersistentHashSet$$(this.$meta$,$APP.$cljs$core$_dissoc$$(this.$hash_map$,$v$jscomp$62$$),null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$keys$$(this.$hash_map$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$707$$,$new_meta$jscomp$28$$){return $new_meta$jscomp$28$$===this.$meta$?this:new $APP.$cljs$core$PersistentHashSet$$($new_meta$jscomp$28$$,this.$hash_map$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$708$$,$o$jscomp$119$$){return new $APP.$cljs$core$PersistentHashSet$$(this.$meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$hash_map$,$o$jscomp$119$$,null),null)};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$16$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$924$$,$args23847$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23847$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$190$$){return this.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$190$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$191$$,$not_found$jscomp$53$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$191$$,$not_found$jscomp$53$$)};
$APP.$cljs$core$PersistentHashSet$EMPTY$$=new $APP.$cljs$core$PersistentHashSet$$(null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$core$empty_unordered_hash$$);$APP.$cljs$core$PersistentHashSet$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$TransientHashSet$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientCollection$_conj_BANG_$arity$2$=function($tcoll$jscomp$51$$,$o$jscomp$120$$){this.$transient_map$=$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$(this.$transient_map$,$o$jscomp$120$$,null);return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientCollection$_persistent_BANG_$arity$1$=function(){return new $APP.$cljs$core$PersistentHashSet$$(null,$APP.$cljs$core$_persistent_BANG_$$(this.$transient_map$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return $APP.$cljs$core$count$$(this.$transient_map$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($tcoll$jscomp$55$$,$v$jscomp$64$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$v$jscomp$64$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($tcoll$jscomp$56$$,$v$jscomp$65$$,$not_found$jscomp$54$$){return $APP.$cljs$core$_lookup$$(this.$transient_map$,$v$jscomp$65$$,$cljs$core$lookup_sentinel$$)===$cljs$core$lookup_sentinel$$?$not_found$jscomp$54$$:$v$jscomp$65$$};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$17$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$934$$,$args23866$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23866$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$192$$){return $APP.$cljs$core$_lookup$$(this.$transient_map$,$k$jscomp$192$$,$cljs$core$lookup_sentinel$$)===$cljs$core$lookup_sentinel$$?null:$k$jscomp$192$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$193$$,$not_found$jscomp$55$$){return $APP.$cljs$core$_lookup$$(this.$transient_map$,$k$jscomp$193$$,$cljs$core$lookup_sentinel$$)===$cljs$core$lookup_sentinel$$?$not_found$jscomp$55$$:$k$jscomp$193$$};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$PersistentTreeSet$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$109$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$109$$)};$APP.$JSCompiler_prototypeAlias$$.keys=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.entries=function(){return $cljs$core$es6_set_entries_iterator$$($APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.values=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$seq$$(this))};
$APP.$JSCompiler_prototypeAlias$$.has=function($k$jscomp$194$$){return $APP.$cljs$core$contains_QMARK_$$(this,$k$jscomp$194$$)};
$APP.$JSCompiler_prototypeAlias$$.forEach=function($f$jscomp$287$$){for(var $G__29078_seq__23871_seq__23871__$1_temp__5825__auto__$jscomp$16$$=$APP.$cljs$core$seq$$(this),$c__5548__auto__$jscomp$5_chunk__23872_vec__23884$$=null,$G__29080_count__23873$$=0,$i__23874$$=0;;)if($i__23874$$<$G__29080_count__23873$$){var $v$jscomp$66_vec__23881$$=$c__5548__auto__$jscomp$5_chunk__23872_vec__23884$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__23874$$),$G__29079_k$jscomp$195$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$66_vec__23881$$,
0,null);$v$jscomp$66_vec__23881$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$66_vec__23881$$,1,null);$f$jscomp$287$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$287$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$66_vec__23881$$,$G__29079_k$jscomp$195$$):$f$jscomp$287$$($v$jscomp$66_vec__23881$$,$G__29079_k$jscomp$195$$);$i__23874$$+=1}else if($G__29078_seq__23871_seq__23871__$1_temp__5825__auto__$jscomp$16$$=$APP.$cljs$core$seq$$($G__29078_seq__23871_seq__23871__$1_temp__5825__auto__$jscomp$16$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__29078_seq__23871_seq__23871__$1_temp__5825__auto__$jscomp$16$$)?
($c__5548__auto__$jscomp$5_chunk__23872_vec__23884$$=$APP.$cljs$core$_chunked_first$$($G__29078_seq__23871_seq__23871__$1_temp__5825__auto__$jscomp$16$$),$G__29078_seq__23871_seq__23871__$1_temp__5825__auto__$jscomp$16$$=$APP.$cljs$core$_chunked_rest$$($G__29078_seq__23871_seq__23871__$1_temp__5825__auto__$jscomp$16$$),$G__29079_k$jscomp$195$$=$c__5548__auto__$jscomp$5_chunk__23872_vec__23884$$,$G__29080_count__23873$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$5_chunk__23872_vec__23884$$),$c__5548__auto__$jscomp$5_chunk__23872_vec__23884$$=
$G__29079_k$jscomp$195$$):($c__5548__auto__$jscomp$5_chunk__23872_vec__23884$$=$APP.$cljs$core$first$$($G__29078_seq__23871_seq__23871__$1_temp__5825__auto__$jscomp$16$$),$G__29079_k$jscomp$195$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$5_chunk__23872_vec__23884$$,0,null),$v$jscomp$66_vec__23881$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$5_chunk__23872_vec__23884$$,1,null),$f$jscomp$287$$.$cljs$core$IFn$_invoke$arity$2$?
$f$jscomp$287$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$66_vec__23881$$,$G__29079_k$jscomp$195$$):$f$jscomp$287$$($v$jscomp$66_vec__23881$$,$G__29079_k$jscomp$195$$),$G__29078_seq__23871_seq__23871__$1_temp__5825__auto__$jscomp$16$$=$APP.$cljs$core$next$$($G__29078_seq__23871_seq__23871__$1_temp__5825__auto__$jscomp$16$$),$c__5548__auto__$jscomp$5_chunk__23872_vec__23884$$=null,$G__29080_count__23873$$=0),$i__23874$$=0;else return null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($coll$jscomp$717$$,$v$jscomp$67$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$v$jscomp$67$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($coll$jscomp$718_n$jscomp$139$$,$v$jscomp$68$$,$not_found$jscomp$56$$){$coll$jscomp$718_n$jscomp$139$$=$JSCompiler_StaticMethods_entry_at$$(this.$tree_map$,$v$jscomp$68$$);return $coll$jscomp$718_n$jscomp$139$$!=null?$coll$jscomp$718_n$jscomp$139$$.key:$not_found$jscomp$56$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$core$PersistentTreeSet$$(this.$meta$,this.$tree_map$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return $APP.$cljs$core$count$$(this.$tree_map$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReversible$_rseq$arity$1$=function(){return $APP.$cljs$core$count$$(this.$tree_map$)>0?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$key$$,$APP.$cljs$core$_rseq$$(this.$tree_map$)):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$23_h__5134__auto____$1$jscomp$23$$=this.$__hash$;return $h__5134__auto__$jscomp$23_h__5134__auto____$1$jscomp$23$$!=null?$h__5134__auto__$jscomp$23_h__5134__auto____$1$jscomp$23$$:this.$__hash$=$h__5134__auto__$jscomp$23_h__5134__auto____$1$jscomp$23$$=$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($and__5023__auto__$jscomp$27_and__5023__auto____$1$jscomp$13_coll$jscomp$723$$,$other$jscomp$110$$){if($and__5023__auto__$jscomp$27_and__5023__auto____$1$jscomp$13_coll$jscomp$723$$=$APP.$cljs$core$set_QMARK_$$($other$jscomp$110$$))if($and__5023__auto__$jscomp$27_and__5023__auto____$1$jscomp$13_coll$jscomp$723$$=$APP.$cljs$core$count$$(this)===$APP.$cljs$core$count$$($other$jscomp$110$$))try{return $APP.$cljs$core$reduce_kv$$(function($or__5025__auto__$jscomp$40_p1__23869_SHARP_$$,
$p2__23868_SHARP_$$){return($or__5025__auto__$jscomp$40_p1__23869_SHARP_$$=$APP.$cljs$core$contains_QMARK_$$($other$jscomp$110$$,$p2__23868_SHARP_$$))?$or__5025__auto__$jscomp$40_p1__23869_SHARP_$$:$APP.$cljs$core$reduced$$(!1)},!0,this.$tree_map$)}catch($e23887$$){if($e23887$$ instanceof Error)return!1;throw $e23887$$;}else return $and__5023__auto__$jscomp$27_and__5023__auto____$1$jscomp$13_coll$jscomp$723$$;else return $and__5023__auto__$jscomp$27_and__5023__auto____$1$jscomp$13_coll$jscomp$723$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return new $cljs$core$PersistentTreeSet$$(this.$meta$,$cljs$core$_empty$$(this.$tree_map$),0)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISet$_disjoin$arity$2$=function($coll$jscomp$725$$,$v$jscomp$69$$){return new $cljs$core$PersistentTreeSet$$(this.$meta$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$tree_map$,$v$jscomp$69$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$keys$$(this.$tree_map$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$727$$,$new_meta$jscomp$29$$){return $new_meta$jscomp$29$$===this.$meta$?this:new $cljs$core$PersistentTreeSet$$($new_meta$jscomp$29$$,this.$tree_map$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$728$$,$o$jscomp$121$$){return new $cljs$core$PersistentTreeSet$$(this.$meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$tree_map$,$o$jscomp$121$$,null),null)};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$18$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$958$$,$args23870$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args23870$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$196$$){return this.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$196$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$197$$,$not_found$jscomp$57$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$197$$,$not_found$jscomp$57$$)};var $cljs$core$PersistentTreeSet$EMPTY$$=new $cljs$core$PersistentTreeSet$$(null,$APP.$cljs$core$PersistentTreeMap$EMPTY$$,$cljs$core$empty_unordered_hash$$);
$cljs$core$PersistentTreeSet$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
$APP.$cljs$core$distinct$$=function $cljs$core$distinct$$($var_args$jscomp$252$$){switch(arguments.length){case 0:return $cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$0$=function(){return function($rf$jscomp$12$$){var $seen$jscomp$4$$=$APP.$cljs$core$volatile_BANG_$$($APP.$cljs$core$PersistentHashSet$EMPTY$$);return function(){function $G__29147__2$$($result$jscomp$53$$,$input$jscomp$32$$){if($APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($seen$jscomp$4$$),$input$jscomp$32$$))return $result$jscomp$53$$;$seen$jscomp$4$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($seen$jscomp$4$$.$cljs$core$IDeref$_deref$arity$1$(null),
$input$jscomp$32$$));return $rf$jscomp$12$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$12$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$53$$,$input$jscomp$32$$):$rf$jscomp$12$$($result$jscomp$53$$,$input$jscomp$32$$)}function $G__29147__1$$($result$jscomp$52$$){return $rf$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$52$$):$rf$jscomp$12$$($result$jscomp$52$$)}function $G__29147__0$$(){return $rf$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$?
$rf$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$():$rf$jscomp$12$$()}var $G__29147$$=null;$G__29147$$=function($result$jscomp$54$$,$input$jscomp$33$$){switch(arguments.length){case 0:return $G__29147__0$$.call(this);case 1:return $G__29147__1$$.call(this,$result$jscomp$54$$);case 2:return $G__29147__2$$.call(this,$result$jscomp$54$$,$input$jscomp$33$$)}throw Error("Invalid arity: "+arguments.length);};$G__29147$$.$cljs$core$IFn$_invoke$arity$0$=$G__29147__0$$;$G__29147$$.$cljs$core$IFn$_invoke$arity$1$=
$G__29147__1$$;$G__29147$$.$cljs$core$IFn$_invoke$arity$2$=$G__29147__2$$;return $G__29147$$}()}};
$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$=function($coll$jscomp$737$$){return function $cljs$core$step$jscomp$1$$($xs$jscomp$14$$,$seen$jscomp$5$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $G__29149$jscomp$inline_2894_JSCompiler_inline_result$jscomp$235_seen__$1$jscomp$inline_2888$$;a:{var $G__29148$jscomp$inline_2893_f$jscomp$inline_2890_p__23901$jscomp$inline_2887$$=$xs$jscomp$14$$;for($G__29149$jscomp$inline_2894_JSCompiler_inline_result$jscomp$235_seen__$1$jscomp$inline_2888$$=
$seen$jscomp$5$$;;){var $s$jscomp$inline_2892_temp__5825__auto__$jscomp$inline_2891_vec__23902$jscomp$inline_2889$$=$G__29148$jscomp$inline_2893_f$jscomp$inline_2890_p__23901$jscomp$inline_2887$$;$G__29148$jscomp$inline_2893_f$jscomp$inline_2890_p__23901$jscomp$inline_2887$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$inline_2892_temp__5825__auto__$jscomp$inline_2891_vec__23902$jscomp$inline_2889$$,0,null);if($s$jscomp$inline_2892_temp__5825__auto__$jscomp$inline_2891_vec__23902$jscomp$inline_2889$$=
$APP.$cljs$core$seq$$($s$jscomp$inline_2892_temp__5825__auto__$jscomp$inline_2891_vec__23902$jscomp$inline_2889$$))if($APP.$cljs$core$contains_QMARK_$$($G__29149$jscomp$inline_2894_JSCompiler_inline_result$jscomp$235_seen__$1$jscomp$inline_2888$$,$G__29148$jscomp$inline_2893_f$jscomp$inline_2890_p__23901$jscomp$inline_2887$$)){$G__29148$jscomp$inline_2893_f$jscomp$inline_2890_p__23901$jscomp$inline_2887$$=$APP.$cljs$core$rest$$($s$jscomp$inline_2892_temp__5825__auto__$jscomp$inline_2891_vec__23902$jscomp$inline_2889$$);
continue}else{$G__29149$jscomp$inline_2894_JSCompiler_inline_result$jscomp$235_seen__$1$jscomp$inline_2888$$=$APP.$cljs$core$cons$$($G__29148$jscomp$inline_2893_f$jscomp$inline_2890_p__23901$jscomp$inline_2887$$,$cljs$core$step$jscomp$1$$($APP.$cljs$core$rest$$($s$jscomp$inline_2892_temp__5825__auto__$jscomp$inline_2891_vec__23902$jscomp$inline_2889$$),$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__29149$jscomp$inline_2894_JSCompiler_inline_result$jscomp$235_seen__$1$jscomp$inline_2888$$,
$G__29148$jscomp$inline_2893_f$jscomp$inline_2890_p__23901$jscomp$inline_2887$$)));break a}else{$G__29149$jscomp$inline_2894_JSCompiler_inline_result$jscomp$235_seen__$1$jscomp$inline_2888$$=null;break a}break}$G__29149$jscomp$inline_2894_JSCompiler_inline_result$jscomp$235_seen__$1$jscomp$inline_2888$$=void 0}return $G__29149$jscomp$inline_2894_JSCompiler_inline_result$jscomp$235_seen__$1$jscomp$inline_2888$$},null,null)}($coll$jscomp$737$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$)};
$APP.$cljs$core$distinct$$.$cljs$lang$maxFixedArity$=1;
$APP.$cljs$core$max_key$$=function $cljs$core$max_key$$($var_args$jscomp$253$$){switch(arguments.length){case 2:return $cljs$core$max_key$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$max_key$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:for(var $args_arr__5774__auto__$jscomp$61$$=[],$len__5749__auto___29160$$=arguments.length,$i__5750__auto___29161$$=0;;)if($i__5750__auto___29161$$<$len__5749__auto___29160$$)$args_arr__5774__auto__$jscomp$61$$.push(arguments[$i__5750__auto___29161$$]),
$i__5750__auto___29161$$+=1;else break;return $cljs$core$max_key$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],3<$args_arr__5774__auto__$jscomp$61$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$61$$.slice(3),0,null):null)}};$APP.$cljs$core$max_key$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$199$$,$x$jscomp$569$$){return $x$jscomp$569$$};
$APP.$cljs$core$max_key$$.$cljs$core$IFn$_invoke$arity$3$=function($k$jscomp$200$$,$x$jscomp$570$$,$y$jscomp$238$$){return($k$jscomp$200$$.$cljs$core$IFn$_invoke$arity$1$?$k$jscomp$200$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$570$$):$k$jscomp$200$$($x$jscomp$570$$))>($k$jscomp$200$$.$cljs$core$IFn$_invoke$arity$1$?$k$jscomp$200$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$238$$):$k$jscomp$200$$($y$jscomp$238$$))?$x$jscomp$570$$:$y$jscomp$238$$};
$APP.$cljs$core$max_key$$.$cljs$core$IFn$_invoke$arity$variadic$=function($k$jscomp$201$$,$x$jscomp$571$$,$y$jscomp$239$$,$more$jscomp$33$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__23906_SHARP_$$,$p2__23907_SHARP_$$){return $APP.$cljs$core$max_key$$.$cljs$core$IFn$_invoke$arity$3$($k$jscomp$201$$,$p1__23906_SHARP_$$,$p2__23907_SHARP_$$)},$APP.$cljs$core$max_key$$.$cljs$core$IFn$_invoke$arity$3$($k$jscomp$201$$,$x$jscomp$571$$,$y$jscomp$239$$),$more$jscomp$33$$)};
$APP.$cljs$core$max_key$$.$cljs$lang$applyTo$=function($G__23911_seq23909$$){var $G__23910$$=$APP.$cljs$core$first$$($G__23911_seq23909$$),$G__23912_seq23909__$1$$=$APP.$cljs$core$next$$($G__23911_seq23909$$);$G__23911_seq23909$$=$APP.$cljs$core$first$$($G__23912_seq23909__$1$$);var $seq23909__$2_seq23909__$3$$=$APP.$cljs$core$next$$($G__23912_seq23909__$1$$);$G__23912_seq23909__$1$$=$APP.$cljs$core$first$$($seq23909__$2_seq23909__$3$$);$seq23909__$2_seq23909__$3$$=$APP.$cljs$core$next$$($seq23909__$2_seq23909__$3$$);
return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23910$$,$G__23911_seq23909$$,$G__23912_seq23909__$1$$,$seq23909__$2_seq23909__$3$$)};$APP.$cljs$core$max_key$$.$cljs$lang$maxFixedArity$=3;
$APP.$cljs$core$min_key$$=function $cljs$core$min_key$$($var_args$jscomp$254$$){switch(arguments.length){case 2:return $cljs$core$min_key$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$min_key$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:for(var $args_arr__5774__auto__$jscomp$62$$=[],$len__5749__auto___29169$$=arguments.length,$i__5750__auto___29170$$=0;;)if($i__5750__auto___29170$$<$len__5749__auto___29169$$)$args_arr__5774__auto__$jscomp$62$$.push(arguments[$i__5750__auto___29170$$]),
$i__5750__auto___29170$$+=1;else break;return $cljs$core$min_key$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],3<$args_arr__5774__auto__$jscomp$62$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$62$$.slice(3),0,null):null)}};$APP.$cljs$core$min_key$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$202$$,$x$jscomp$572$$){return $x$jscomp$572$$};
$APP.$cljs$core$min_key$$.$cljs$core$IFn$_invoke$arity$3$=function($k$jscomp$203$$,$x$jscomp$573$$,$y$jscomp$240$$){return($k$jscomp$203$$.$cljs$core$IFn$_invoke$arity$1$?$k$jscomp$203$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$573$$):$k$jscomp$203$$($x$jscomp$573$$))<($k$jscomp$203$$.$cljs$core$IFn$_invoke$arity$1$?$k$jscomp$203$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$240$$):$k$jscomp$203$$($y$jscomp$240$$))?$x$jscomp$573$$:$y$jscomp$240$$};
$APP.$cljs$core$min_key$$.$cljs$core$IFn$_invoke$arity$variadic$=function($k$jscomp$204$$,$x$jscomp$574$$,$y$jscomp$241$$,$more$jscomp$34$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__23914_SHARP_$$,$p2__23915_SHARP_$$){return $APP.$cljs$core$min_key$$.$cljs$core$IFn$_invoke$arity$3$($k$jscomp$204$$,$p1__23914_SHARP_$$,$p2__23915_SHARP_$$)},$APP.$cljs$core$min_key$$.$cljs$core$IFn$_invoke$arity$3$($k$jscomp$204$$,$x$jscomp$574$$,$y$jscomp$241$$),$more$jscomp$34$$)};
$APP.$cljs$core$min_key$$.$cljs$lang$applyTo$=function($G__23919_seq23917$$){var $G__23918$$=$APP.$cljs$core$first$$($G__23919_seq23917$$),$G__23920_seq23917__$1$$=$APP.$cljs$core$next$$($G__23919_seq23917$$);$G__23919_seq23917$$=$APP.$cljs$core$first$$($G__23920_seq23917__$1$$);var $seq23917__$2_seq23917__$3$$=$APP.$cljs$core$next$$($G__23920_seq23917__$1$$);$G__23920_seq23917__$1$$=$APP.$cljs$core$first$$($seq23917__$2_seq23917__$3$$);$seq23917__$2_seq23917__$3$$=$APP.$cljs$core$next$$($seq23917__$2_seq23917__$3$$);
return this.$cljs$core$IFn$_invoke$arity$variadic$($G__23918$$,$G__23919_seq23917$$,$G__23920_seq23917__$1$$,$seq23917__$2_seq23917__$3$$)};$APP.$cljs$core$min_key$$.$cljs$lang$maxFixedArity$=3;$cljs$core$ArrayList$$.prototype.add=function($x$jscomp$575$$){return this.$arr$.push($x$jscomp$575$$)};$cljs$core$ArrayList$$.prototype.size=function(){return this.$arr$.length};$cljs$core$ArrayList$$.prototype.clear=function(){return this.$arr$=[]};
$cljs$core$ArrayList$$.prototype.isEmpty=function(){return this.$arr$.length===0};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$IntegerRangeChunk$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.count};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return this.start};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($coll$jscomp$749$$,$i$jscomp$265$$){return this.start+$i$jscomp$265$$*this.step};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($coll$jscomp$750$$,$i$jscomp$266$$,$not_found$jscomp$58$$){return $i$jscomp$266$$>=0&&$i$jscomp$266$$<this.count?this.start+$i$jscomp$266$$*this.step:$not_found$jscomp$58$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IChunk$_drop_first$arity$1$=function(){if(this.count<=1)throw Error("-drop-first of empty chunk");return new $cljs$core$IntegerRangeChunk$$(this.start+this.step,this.step,this.count-1)};
$cljs$core$RangeIterator$$.prototype.hasNext=function(){return this.step>0?this.i<this.end:this.i>this.end};$cljs$core$RangeIterator$$.prototype.next=function(){var $ret$jscomp$43$$=this.i;this.i+=this.step;return $ret$jscomp$43$$};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$IntegerRange$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$111$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$111$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__29221$$=null;$G__29221$$=function($x$jscomp$578$$,$start__$1$jscomp$5$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$578$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$578$$,$start__$1$jscomp$5$$)}throw Error("Invalid arity: "+arguments.length);};$G__29221$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$576$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$576$$,0)};$G__29221$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$577$$,$start__$1$jscomp$4$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$577$$,$start__$1$jscomp$4$$)};return $G__29221$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__29224__1$$($x$jscomp$579$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$579$$,$APP.$cljs$core$count$$(this))}var $G__29224$$=null;$G__29224$$=function($x$jscomp$581$$,$start__$1$jscomp$7$$){switch(arguments.length){case 1:return $G__29224__1$$.call(this,$x$jscomp$581$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$581$$,$start__$1$jscomp$7$$)}throw Error("Invalid arity: "+
arguments.length);};$G__29224$$.$cljs$core$IFn$_invoke$arity$1$=$G__29224__1$$;$G__29224$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$580$$,$start__$1$jscomp$6$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$580$$,$start__$1$jscomp$6$$)};return $G__29224$$}();
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($rng$$,$n$jscomp$151$$){if(0<=$n$jscomp$151$$&&$n$jscomp$151$$<this.$cljs$core$ICounted$_count$arity$1$(null))return this.start+$n$jscomp$151$$*this.step;if(0<=$n$jscomp$151$$&&this.start>this.end&&this.step===0)return this.start;throw Error("Index out of bounds");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($rng$jscomp$1$$,$n$jscomp$152$$,$not_found$jscomp$59$$){return 0<=$n$jscomp$152$$&&$n$jscomp$152$$<this.$cljs$core$ICounted$_count$arity$1$(null)?this.start+$n$jscomp$152$$*this.step:0<=$n$jscomp$152$$&&this.start>this.end&&this.step===0?this.start:$not_found$jscomp$59$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $cljs$core$RangeIterator$$(this.start,this.end,this.step)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$core$IntegerRange$$(this.$meta$,this.start,this.end,this.step,this.$cnt$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return this.step>0?this.start+this.step<this.end?new $cljs$core$IntegerRange$$(null,this.start+this.step,this.end,this.step,Math.ceil((this.end-(this.start+this.step))/this.step),null):null:this.start+this.step>this.end?new $cljs$core$IntegerRange$$(null,this.start+this.step,this.end,this.step,Math.ceil((this.end-(this.start+this.step))/this.step),null):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.$cnt$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$24_h__5134__auto____$1$jscomp$24$$=this.$__hash$;return $h__5134__auto__$jscomp$24_h__5134__auto____$1$jscomp$24$$!=null?$h__5134__auto__$jscomp$24_h__5134__auto____$1$jscomp$24$$:this.$__hash$=$h__5134__auto__$jscomp$24_h__5134__auto____$1$jscomp$24$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($rng$jscomp$6$$,$other$jscomp$112$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$112$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($rng$jscomp$8$$,$f$jscomp$289$$){return $cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$f$jscomp$289$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($i$jscomp$269_rng$jscomp$9$$,$f$jscomp$290$$,$G__29239_init$jscomp$43_ret$jscomp$44_ret__$1$jscomp$5$$){for($i$jscomp$269_rng$jscomp$9$$=this.start;;)if(this.step>0?$i$jscomp$269_rng$jscomp$9$$<this.end:$i$jscomp$269_rng$jscomp$9$$>this.end){$G__29239_init$jscomp$43_ret$jscomp$44_ret__$1$jscomp$5$$=$f$jscomp$290$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$290$$.$cljs$core$IFn$_invoke$arity$2$($G__29239_init$jscomp$43_ret$jscomp$44_ret__$1$jscomp$5$$,
$i$jscomp$269_rng$jscomp$9$$):$f$jscomp$290$$($G__29239_init$jscomp$43_ret$jscomp$44_ret__$1$jscomp$5$$,$i$jscomp$269_rng$jscomp$9$$);if($cljs$core$reduced_QMARK_$$($G__29239_init$jscomp$43_ret$jscomp$44_ret__$1$jscomp$5$$))return $APP.$cljs$core$_deref$$($G__29239_init$jscomp$43_ret$jscomp$44_ret__$1$jscomp$5$$);$i$jscomp$269_rng$jscomp$9$$+=this.step}else return $G__29239_init$jscomp$43_ret$jscomp$44_ret__$1$jscomp$5$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return this.start};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){var $s$jscomp$111$$=this.$cljs$core$INext$_next$arity$1$(null);return $s$jscomp$111$$==null?$APP.$cljs$core$List$EMPTY$$:$s$jscomp$111$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IChunkedSeq$_chunked_first$arity$1$=function(){var $x__5113__auto__$jscomp$inline_2898$$=this.$cnt$;return new $cljs$core$IntegerRangeChunk$$(this.start,this.step,$x__5113__auto__$jscomp$inline_2898$$<32?$x__5113__auto__$jscomp$inline_2898$$:32)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IChunkedSeq$_chunked_rest$arity$1$=function(){if(this.$cnt$<=32)return $APP.$cljs$core$List$EMPTY$$;var $start__$1$jscomp$8$$=this.start+this.step*32;return this.step>0?this.end<=$start__$1$jscomp$8$$?$APP.$cljs$core$List$EMPTY$$:new $cljs$core$IntegerRange$$(null,$start__$1$jscomp$8$$,this.end,this.step,Math.ceil((this.end-$start__$1$jscomp$8$$)/this.step),null):this.step<0?this.end>=$start__$1$jscomp$8$$?$APP.$cljs$core$List$EMPTY$$:new $cljs$core$IntegerRange$$(null,
$start__$1$jscomp$8$$,this.end,this.step,Math.ceil((this.end-$start__$1$jscomp$8$$)/this.step),null):this.end===$start__$1$jscomp$8$$?$APP.$cljs$core$List$EMPTY$$:$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$($start__$1$jscomp$8$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($rng$jscomp$15$$,$new_meta$jscomp$30$$){return $new_meta$jscomp$30$$===this.$meta$?this:new $cljs$core$IntegerRange$$($new_meta$jscomp$30$$,this.start,this.end,this.step,this.$cnt$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($rng$jscomp$16$$,$o$jscomp$122$$){return $APP.$cljs$core$cons$$($o$jscomp$122$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDrop$_drop$arity$2$=function($rng$jscomp$17$$,$n$jscomp$153$$){return $n$jscomp$153$$>0?$n$jscomp$153$$<this.$cnt$?new $cljs$core$IntegerRange$$(null,this.start+this.step*$n$jscomp$153$$,this.end,this.step,this.$cnt$-$n$jscomp$153$$,null):null:this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IChunkedNext$_chunked_next$arity$1$=function(){return $APP.$cljs$core$seq$$(this.$cljs$core$IChunkedSeq$_chunked_rest$arity$1$(null))};
$cljs$core$IntegerRange$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$Range$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$113$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$113$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__29249$$=null;$G__29249$$=function($x$jscomp$584$$,$start__$1$jscomp$10$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$584$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$584$$,$start__$1$jscomp$10$$)}throw Error("Invalid arity: "+arguments.length);};$G__29249$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$582$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$582$$,0)};$G__29249$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$583$$,$start__$1$jscomp$9$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$583$$,$start__$1$jscomp$9$$)};return $G__29249$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__29250__1$$($x$jscomp$585$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$585$$,$APP.$cljs$core$count$$(this))}var $G__29250$$=null;$G__29250$$=function($x$jscomp$587$$,$start__$1$jscomp$12$$){switch(arguments.length){case 1:return $G__29250__1$$.call(this,$x$jscomp$587$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$587$$,$start__$1$jscomp$12$$)}throw Error("Invalid arity: "+
arguments.length);};$G__29250$$.$cljs$core$IFn$_invoke$arity$1$=$G__29250__1$$;$G__29250$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$586$$,$start__$1$jscomp$11$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$586$$,$start__$1$jscomp$11$$)};return $G__29250$$}();$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $cljs$core$RangeIterator$$(this.start,this.end,this.step)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$core$Range$$(this.$meta$,this.start,this.end,this.step,this.$chunk$,this.$chunk_next$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return this.step>0?this.start+this.step<this.end?new $cljs$core$Range$$(null,this.start+this.step,this.end,this.step,null,null,null):null:this.start+this.step>this.end?new $cljs$core$Range$$(null,this.start+this.step,this.end,this.step,null,null,null):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$25_h__5134__auto____$1$jscomp$25$$=this.$__hash$;return $h__5134__auto__$jscomp$25_h__5134__auto____$1$jscomp$25$$!=null?$h__5134__auto__$jscomp$25_h__5134__auto____$1$jscomp$25$$:this.$__hash$=$h__5134__auto__$jscomp$25_h__5134__auto____$1$jscomp$25$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($rng$jscomp$22$$,$other$jscomp$114$$){return $cljs$core$equiv_sequential$$(this,$other$jscomp$114$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($rng$jscomp$24$$,$f$jscomp$291$$){return $cljs$core$seq_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$291$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($i$jscomp$270_rng$jscomp$25$$,$f$jscomp$292$$,$G__29279_init$jscomp$44_ret$jscomp$45_ret__$1$jscomp$6$$){for($i$jscomp$270_rng$jscomp$25$$=this.start;;)if(this.step>0?$i$jscomp$270_rng$jscomp$25$$<this.end:$i$jscomp$270_rng$jscomp$25$$>this.end){$G__29279_init$jscomp$44_ret$jscomp$45_ret__$1$jscomp$6$$=$f$jscomp$292$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$292$$.$cljs$core$IFn$_invoke$arity$2$($G__29279_init$jscomp$44_ret$jscomp$45_ret__$1$jscomp$6$$,
$i$jscomp$270_rng$jscomp$25$$):$f$jscomp$292$$($G__29279_init$jscomp$44_ret$jscomp$45_ret__$1$jscomp$6$$,$i$jscomp$270_rng$jscomp$25$$);if($cljs$core$reduced_QMARK_$$($G__29279_init$jscomp$44_ret$jscomp$45_ret__$1$jscomp$6$$))return $APP.$cljs$core$_deref$$($G__29279_init$jscomp$44_ret$jscomp$45_ret__$1$jscomp$6$$);$i$jscomp$270_rng$jscomp$25$$+=this.step}else return $G__29279_init$jscomp$44_ret$jscomp$45_ret__$1$jscomp$6$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return this.start};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){var $s$jscomp$112$$=this.$cljs$core$INext$_next$arity$1$(null);return $s$jscomp$112$$==null?$APP.$cljs$core$List$EMPTY$$:$s$jscomp$112$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IChunkedSeq$_chunked_first$arity$1$=function(){$JSCompiler_StaticMethods_forceChunk$$(this);return this.$chunk$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IChunkedSeq$_chunked_rest$arity$1$=function(){$JSCompiler_StaticMethods_forceChunk$$(this);return this.$chunk_next$==null?$APP.$cljs$core$List$EMPTY$$:this.$chunk_next$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($rng$jscomp$31$$,$new_meta$jscomp$31$$){return $new_meta$jscomp$31$$===this.$meta$?this:new $cljs$core$Range$$($new_meta$jscomp$31$$,this.start,this.end,this.step,this.$chunk$,this.$chunk_next$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($rng$jscomp$32$$,$o$jscomp$123$$){return $APP.$cljs$core$cons$$($o$jscomp$123$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IChunkedNext$_chunked_next$arity$1$=function(){return $APP.$cljs$core$seq$$(this.$cljs$core$IChunkedSeq$_chunked_rest$arity$1$(null))};$cljs$core$Range$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
$cljs$core$re_seq_STAR_$$=function $cljs$core$re_seq_STAR_$$($re$jscomp$4$$,$s$jscomp$120$$){var $temp__5829__auto__$jscomp$1$$=$re$jscomp$4$$.exec($s$jscomp$120$$);if($temp__5829__auto__$jscomp$1$$==null)return null;var $match_str$$=$temp__5829__auto__$jscomp$1$$[0],$match_vals$$=$temp__5829__auto__$jscomp$1$$.length===1?$match_str$$:$APP.$cljs$core$vec$$($temp__5829__auto__$jscomp$1$$);return $APP.$cljs$core$cons$$($match_vals$$,new $APP.$cljs$core$LazySeq$$(null,function(){var $G__23985_post_idx_y__5111__auto__$jscomp$inline_2908$$=
$match_str$$.length;$G__23985_post_idx_y__5111__auto__$jscomp$inline_2908$$=$temp__5829__auto__$jscomp$1$$.index+(1>$G__23985_post_idx_y__5111__auto__$jscomp$inline_2908$$?1:$G__23985_post_idx_y__5111__auto__$jscomp$inline_2908$$);return $G__23985_post_idx_y__5111__auto__$jscomp$inline_2908$$<=$s$jscomp$120$$.length?($G__23985_post_idx_y__5111__auto__$jscomp$inline_2908$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$120$$,$G__23985_post_idx_y__5111__auto__$jscomp$inline_2908$$),
$cljs$core$re_seq_STAR_$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$core$re_seq_STAR_$$.$cljs$core$IFn$_invoke$arity$2$($re$jscomp$4$$,$G__23985_post_idx_y__5111__auto__$jscomp$inline_2908$$):$cljs$core$re_seq_STAR_$$($re$jscomp$4$$,$G__23985_post_idx_y__5111__auto__$jscomp$inline_2908$$)):null},null,null))};$cljs$core$char_escapes$$={'"':'\\"',"\\":"\\\\","\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","\t":"\\t"};
$APP.$cljs$core$pr_str$$=function $cljs$core$pr_str$$($var_args$jscomp$278$$){for(var $args__5755__auto__$jscomp$13$$=[],$len__5749__auto___29462$$=arguments.length,$i__5750__auto___29463$$=0;;)if($i__5750__auto___29463$$<$len__5749__auto___29462$$)$args__5755__auto__$jscomp$13$$.push(arguments[$i__5750__auto___29463$$]),$i__5750__auto___29463$$+=1;else break;return $cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$13$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$13$$.slice(0),
0,null):null)};$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$=function($objs$jscomp$5$$){return $cljs$core$pr_str_with_opts$$($objs$jscomp$5$$,$cljs$core$pr_opts$$())};$APP.$cljs$core$pr_str$$.$cljs$lang$maxFixedArity$=0;$APP.$cljs$core$pr_str$$.$cljs$lang$applyTo$=function($seq24026$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq24026$$))};
$APP.$cljs$core$print$$=function(){function $cljs$core$cljs_core_print$$($var_args$jscomp$281$$){var $G__29479__i_objs$jscomp$9$$=null;if(arguments.length>0){$G__29479__i_objs$jscomp$9$$=0;for(var $G__29479__a$$=Array(arguments.length-0);$G__29479__i_objs$jscomp$9$$<$G__29479__a$$.length;)$G__29479__a$$[$G__29479__i_objs$jscomp$9$$]=arguments[$G__29479__i_objs$jscomp$9$$+0],++$G__29479__i_objs$jscomp$9$$;$G__29479__i_objs$jscomp$9$$=new $APP.$cljs$core$IndexedSeq$$($G__29479__a$$,0,null)}return $cljs$core$cljs_core_print__delegate$$.call(this,
$G__29479__i_objs$jscomp$9$$)}function $cljs$core$cljs_core_print__delegate$$($objs$jscomp$8$$){var $opts$jscomp$inline_2926$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cljs$core$pr_opts$$(),$cljs$cst$1$readably$$,!1);return $cljs$core$string_print$$($cljs$core$pr_str_with_opts$$($objs$jscomp$8$$,$opts$jscomp$inline_2926$$))}$cljs$core$cljs_core_print$$.$cljs$lang$maxFixedArity$=0;$cljs$core$cljs_core_print$$.$cljs$lang$applyTo$=function($arglist__29480_objs$jscomp$10$$){$arglist__29480_objs$jscomp$10$$=
$APP.$cljs$core$seq$$($arglist__29480_objs$jscomp$10$$);return $cljs$core$cljs_core_print__delegate$$($arglist__29480_objs$jscomp$10$$)};$cljs$core$cljs_core_print$$.$cljs$core$IFn$_invoke$arity$variadic$=$cljs$core$cljs_core_print__delegate$$;return $cljs$core$cljs_core_print$$}();
$cljs$core$print_str$$=function $cljs$core$print_str$$($var_args$jscomp$282$$){for(var $args__5755__auto__$jscomp$16$$=[],$len__5749__auto___29481$$=arguments.length,$i__5750__auto___29482$$=0;;)if($i__5750__auto___29482$$<$len__5749__auto___29481$$)$args__5755__auto__$jscomp$16$$.push(arguments[$i__5750__auto___29482$$]),$i__5750__auto___29482$$+=1;else break;return $cljs$core$print_str$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$16$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$16$$.slice(0),
0,null):null)};$cljs$core$print_str$$.$cljs$core$IFn$_invoke$arity$variadic$=function($objs$jscomp$11$$){return $cljs$core$pr_str_with_opts$$($objs$jscomp$11$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cljs$core$pr_opts$$(),$cljs$cst$1$readably$$,!1))};$cljs$core$print_str$$.$cljs$lang$maxFixedArity$=0;$cljs$core$print_str$$.$cljs$lang$applyTo$=function($seq24029$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq24029$$))};
$cljs$core$Volatile$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$Volatile$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($a$jscomp$167$$,$writer$jscomp$17$$,$opts$jscomp$14$$){$APP.$cljs$core$_write$$($writer$jscomp$17$$,"#object[cljs.core.Volatile ");$APP.$cljs$core$pr_writer$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$108$val$$,this.state],null),$writer$jscomp$17$$,$opts$jscomp$14$$);return $APP.$cljs$core$_write$$($writer$jscomp$17$$,"]")};$APP.$cljs$core$Var$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$Var$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($a$jscomp$168$$,$writer$jscomp$18$$,$opts$jscomp$15$$){$APP.$cljs$core$_write$$($writer$jscomp$18$$,"#'");return $APP.$cljs$core$pr_writer$$(this.$sym$,$writer$jscomp$18$$,$opts$jscomp$15$$)};$APP.$cljs$core$IndexedSeq$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$IndexedSeq$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$774$$,$writer$jscomp$19$$,$opts$jscomp$16$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$19$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$16$$,this)};$APP.$cljs$core$LazySeq$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$LazySeq$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$775$$,$writer$jscomp$20$$,$opts$jscomp$17$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$20$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$17$$,this)};$APP.$cljs$core$MapEntry$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$MapEntry$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$776$$,$writer$jscomp$21$$,$opts$jscomp$18$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$21$$,$APP.$cljs$core$pr_writer$$,"["," ","]",$opts$jscomp$18$$,this)};$cljs$core$PersistentTreeMapSeq$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$PersistentTreeMapSeq$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$777$$,$writer$jscomp$22$$,$opts$jscomp$19$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$22$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$19$$,this)};$APP.$cljs$core$NodeSeq$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$NodeSeq$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$778$$,$writer$jscomp$23$$,$opts$jscomp$20$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$23$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$20$$,this)};$APP.$cljs$core$BlackNode$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$BlackNode$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$779$$,$writer$jscomp$24$$,$opts$jscomp$21$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$24$$,$APP.$cljs$core$pr_writer$$,"["," ","]",$opts$jscomp$21$$,this)};$APP.$cljs$core$PersistentArrayMapSeq$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$PersistentArrayMapSeq$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$780$$,$writer$jscomp$25$$,$opts$jscomp$22$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$25$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$22$$,this)};$cljs$core$ES6IteratorSeq$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$ES6IteratorSeq$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$781$$,$writer$jscomp$26$$,$opts$jscomp$23$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$26$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$23$$,this)};$cljs$core$PersistentTreeSet$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$PersistentTreeSet$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$782$$,$writer$jscomp$27$$,$opts$jscomp$24$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$27$$,$APP.$cljs$core$pr_writer$$,"#{"," ","}",$opts$jscomp$24$$,this)};$APP.$cljs$core$ChunkedSeq$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$ChunkedSeq$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$783$$,$writer$jscomp$28$$,$opts$jscomp$25$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$28$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$25$$,this)};$APP.$cljs$core$Cons$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$Cons$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$785$$,$writer$jscomp$30$$,$opts$jscomp$27$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$30$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$27$$,this)};$cljs$core$Iterate$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$Iterate$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$786$$,$writer$jscomp$31$$,$opts$jscomp$28$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$31$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$28$$,this)};$APP.$cljs$core$RSeq$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$RSeq$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$787$$,$writer$jscomp$32$$,$opts$jscomp$29$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$32$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$29$$,this)};$cljs$core$IntegerRange$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$IntegerRange$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$788$$,$writer$jscomp$33$$,$opts$jscomp$30$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$33$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$30$$,this)};$APP.$cljs$core$PersistentHashMap$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$PersistentHashMap$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$789$$,$writer$jscomp$34$$,$opts$jscomp$31$$){return $cljs$core$print_map$$(this,$APP.$cljs$core$pr_writer$$,$writer$jscomp$34$$,$opts$jscomp$31$$)};$APP.$cljs$core$ArrayNodeSeq$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$ArrayNodeSeq$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$790$$,$writer$jscomp$35$$,$opts$jscomp$32$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$35$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$32$$,this)};$APP.$cljs$core$Subvec$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$Subvec$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$791$$,$writer$jscomp$36$$,$opts$jscomp$33$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$36$$,$APP.$cljs$core$pr_writer$$,"["," ","]",$opts$jscomp$33$$,this)};$APP.$cljs$core$PersistentTreeMap$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$PersistentTreeMap$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$793$$,$writer$jscomp$38$$,$opts$jscomp$35$$){return $cljs$core$print_map$$(this,$APP.$cljs$core$pr_writer$$,$writer$jscomp$38$$,$opts$jscomp$35$$)};$APP.$cljs$core$PersistentHashSet$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$PersistentHashSet$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$794$$,$writer$jscomp$39$$,$opts$jscomp$36$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$39$$,$APP.$cljs$core$pr_writer$$,"#{"," ","}",$opts$jscomp$36$$,this)};$APP.$cljs$core$ChunkedCons$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$ChunkedCons$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$795$$,$writer$jscomp$40$$,$opts$jscomp$37$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$40$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$37$$,this)};$cljs$core$Atom$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$Atom$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($a$jscomp$169$$,$writer$jscomp$41$$,$opts$jscomp$38$$){$APP.$cljs$core$_write$$($writer$jscomp$41$$,"#object[cljs.core.Atom ");$APP.$cljs$core$pr_writer$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$108$val$$,this.state],null),$writer$jscomp$41$$,$opts$jscomp$38$$);return $APP.$cljs$core$_write$$($writer$jscomp$41$$,"]")};$cljs$core$ValSeq$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$ValSeq$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$796$$,$writer$jscomp$42$$,$opts$jscomp$39$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$42$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$39$$,this)};$APP.$cljs$core$RedNode$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$RedNode$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$797$$,$writer$jscomp$43$$,$opts$jscomp$40$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$43$$,$APP.$cljs$core$pr_writer$$,"["," ","]",$opts$jscomp$40$$,this)};$cljs$core$Repeat$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$Repeat$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$798$$,$writer$jscomp$44$$,$opts$jscomp$41$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$44$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$41$$,this)};$APP.$cljs$core$PersistentVector$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$PersistentVector$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$799$$,$writer$jscomp$45$$,$opts$jscomp$42$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$45$$,$APP.$cljs$core$pr_writer$$,"["," ","]",$opts$jscomp$42$$,this)};$cljs$core$PersistentQueueSeq$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$PersistentQueueSeq$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$800$$,$writer$jscomp$46$$,$opts$jscomp$43$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$46$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$43$$,this)};$cljs$core$EmptyList$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$EmptyList$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$801$$,$writer$jscomp$47$$){return $APP.$cljs$core$_write$$($writer$jscomp$47$$,"()")};$cljs$core$PersistentQueue$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$PersistentQueue$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$802$$,$writer$jscomp$48$$,$opts$jscomp$45$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$48$$,$APP.$cljs$core$pr_writer$$,"#queue ["," ","]",$opts$jscomp$45$$,$APP.$cljs$core$seq$$(this))};$APP.$cljs$core$PersistentArrayMap$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$PersistentArrayMap$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$803$$,$writer$jscomp$49$$,$opts$jscomp$46$$){return $cljs$core$print_map$$(this,$APP.$cljs$core$pr_writer$$,$writer$jscomp$49$$,$opts$jscomp$46$$)};$cljs$core$Range$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$Range$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$804$$,$writer$jscomp$50$$,$opts$jscomp$47$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$50$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$47$$,this)};$cljs$core$TransformerIterator$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$TransformerIterator$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$805$$,$writer$jscomp$51$$,$opts$jscomp$48$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$51$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$48$$,this)};$cljs$core$KeySeq$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$KeySeq$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$806$$,$writer$jscomp$52$$,$opts$jscomp$49$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$52$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$49$$,this)};$APP.$cljs$core$List$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$List$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$807$$,$writer$jscomp$53$$,$opts$jscomp$50$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$53$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$50$$,this)};$APP.$cljs$core$Symbol$$.prototype.$cljs$core$IComparable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$Symbol$$.prototype.$cljs$core$IComparable$_compare$arity$2$=function($x$jscomp$619$$,$y$jscomp$266$$){if($y$jscomp$266$$ instanceof $APP.$cljs$core$Symbol$$)return $cljs$core$compare_symbols$$(this,$y$jscomp$266$$);throw Error(["Cannot compare ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this)," to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$266$$)].join(""));};$APP.$cljs$core$Keyword$$.prototype.$cljs$core$IComparable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$Keyword$$.prototype.$cljs$core$IComparable$_compare$arity$2$=function($x$jscomp$620$$,$y$jscomp$267$$){if($y$jscomp$267$$ instanceof $APP.$cljs$core$Keyword$$)return $cljs$core$compare_keywords$$(this,$y$jscomp$267$$);throw Error(["Cannot compare ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this)," to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$267$$)].join(""));};$APP.$cljs$core$Subvec$$.prototype.$cljs$core$IComparable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$Subvec$$.prototype.$cljs$core$IComparable$_compare$arity$2$=function($x$jscomp$621$$,$y$jscomp$268$$){if($APP.$cljs$core$vector_QMARK_$$($y$jscomp$268$$))return $cljs$core$compare_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$y$jscomp$268$$);throw Error(["Cannot compare ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this)," to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$268$$)].join(""));};
$APP.$cljs$core$PersistentVector$$.prototype.$cljs$core$IComparable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$PersistentVector$$.prototype.$cljs$core$IComparable$_compare$arity$2$=function($x$jscomp$622$$,$y$jscomp$269$$){if($APP.$cljs$core$vector_QMARK_$$($y$jscomp$269$$))return $cljs$core$compare_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$y$jscomp$269$$);throw Error(["Cannot compare ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this)," to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$269$$)].join(""));};
$APP.$cljs$core$MapEntry$$.prototype.$cljs$core$IComparable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$MapEntry$$.prototype.$cljs$core$IComparable$_compare$arity$2$=function($x$jscomp$623$$,$y$jscomp$270$$){if($APP.$cljs$core$vector_QMARK_$$($y$jscomp$270$$))return $cljs$core$compare_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$y$jscomp$270$$);throw Error(["Cannot compare ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this)," to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$270$$)].join(""));};
$APP.$cljs$core$BlackNode$$.prototype.$cljs$core$IComparable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$BlackNode$$.prototype.$cljs$core$IComparable$_compare$arity$2$=function($x$jscomp$624$$,$y$jscomp$271$$){if($APP.$cljs$core$vector_QMARK_$$($y$jscomp$271$$))return $cljs$core$compare_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$y$jscomp$271$$);throw Error(["Cannot compare ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this)," to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$271$$)].join(""));};
$APP.$cljs$core$RedNode$$.prototype.$cljs$core$IComparable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$RedNode$$.prototype.$cljs$core$IComparable$_compare$arity$2$=function($x$jscomp$625$$,$y$jscomp$272$$){if($APP.$cljs$core$vector_QMARK_$$($y$jscomp$272$$))return $cljs$core$compare_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$y$jscomp$272$$);throw Error(["Cannot compare ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this)," to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$272$$)].join(""));};var $cljs$core$gensym_counter$$=null;
$APP.$cljs$core$Delay$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){$APP.$cljs$core$truth_$$(this.f)&&(this.value=this.f.$cljs$core$IFn$_invoke$arity$0$?this.f.$cljs$core$IFn$_invoke$arity$0$():this.f(),this.f=null);return this.value};$APP.$cljs$core$Delay$$.prototype.$cljs$core$IPending$_realized_QMARK_$arity$1$=function(){return $APP.$cljs$core$not$$(this.f)};
$APP.$cljs$core$Delay$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($x$jscomp$627$$,$writer$jscomp$54$$,$opts$jscomp$51$$){$APP.$cljs$core$_write$$($writer$jscomp$54$$,"#object[cljs.core.Delay ");$APP.$cljs$core$pr_writer$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$109$status$$,this.f==null?$cljs$cst$110$ready$$:$APP.$cljs$cst$111$pending$$,$APP.$cljs$cst$108$val$$,this.value],null),$writer$jscomp$54$$,$opts$jscomp$51$$);return $APP.$cljs$core$_write$$($writer$jscomp$54$$,
"]")};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$Eduction$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__29660$$=null;$G__29660$$=function($x$jscomp$633$$,$start$jscomp$148$$){switch(arguments.length){case 1:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$633$$,0);case 2:return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$633$$,$start$jscomp$148$$)}throw Error("Invalid arity: "+arguments.length);};$G__29660$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$631$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$631$$,0)};$G__29660$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$632$$,$start$jscomp$147$$){return $cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$632$$,$start$jscomp$147$$)};return $G__29660$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__29661__1$$($x$jscomp$634$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$634$$,$APP.$cljs$core$count$$(this))}var $G__29661$$=null;$G__29661$$=function($x$jscomp$636$$,$start$jscomp$150$$){switch(arguments.length){case 1:return $G__29661__1$$.call(this,$x$jscomp$636$$);case 2:return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$636$$,$start$jscomp$150$$)}throw Error("Invalid arity: "+
arguments.length);};$G__29661$$.$cljs$core$IFn$_invoke$arity$1$=$G__29661__1$$;$G__29661$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$635$$,$start$jscomp$149$$){return $cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$635$$,$start$jscomp$149$$)};return $G__29661$$}();
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){var $xform$jscomp$inline_2933$$=this.$xform$,$source$jscomp$inline_2934$$=$cljs$core$iter$$(this.$coll$);return $cljs$core$transformer_iterator$$($xform$jscomp$inline_2933$$,$source$jscomp$inline_2934$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$(this.$xform$,this.$coll$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($_$jscomp$148$$,$f$jscomp$305$$){return $cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$03$$(this.$xform$,$cljs$core$completing$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$305$$),this.$coll$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($_$jscomp$149$$,$f$jscomp$306$$,$init$jscomp$46$$){return $cljs$core$transduce$cljs$0core$0IFn$0_invoke$0arity$04$$(this.$xform$,$cljs$core$completing$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$306$$),$init$jscomp$46$$,this.$coll$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll__$1$jscomp$452$$,$writer$jscomp$55$$,$opts$jscomp$52$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$55$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$52$$,this)};$cljs$core$Eduction$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
var $cljs$core$eduction$$=function $cljs$core$eduction$$($var_args$jscomp$291$$){for(var $args__5755__auto__$jscomp$21$$=[],$len__5749__auto___29679$$=arguments.length,$i__5750__auto___29680$$=0;;)if($i__5750__auto___29680$$<$len__5749__auto___29679$$)$args__5755__auto__$jscomp$21$$.push(arguments[$i__5750__auto___29680$$]),$i__5750__auto___29680$$+=1;else break;return $cljs$core$eduction$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$21$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$21$$.slice(0),
0,null):null)};$cljs$core$eduction$$.$cljs$core$IFn$_invoke$arity$variadic$=function($xforms$$){return new $cljs$core$Eduction$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$,$APP.$cljs$core$butlast$$($xforms$$)),$APP.$cljs$core$last$$($xforms$$))};$cljs$core$eduction$$.$cljs$lang$maxFixedArity$=0;$cljs$core$eduction$$.$cljs$lang$applyTo$=function($seq24082$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq24082$$))};
$APP.$cljs$core$clj__GT_js$$=function $cljs$core$clj__GT_js$$($var_args$jscomp$294$$){for(var $args__5755__auto__$jscomp$23$$=[],$len__5749__auto___29724$$=arguments.length,$i__5750__auto___29725$$=0;;)if($i__5750__auto___29725$$<$len__5749__auto___29724$$)$args__5755__auto__$jscomp$23$$.push(arguments[$i__5750__auto___29725$$]),$i__5750__auto___29725$$+=1;else break;return $cljs$core$clj__GT_js$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args__5755__auto__$jscomp$23$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$23$$.slice(1),
0,null):null)};
$APP.$cljs$core$clj__GT_js$$.$cljs$core$IFn$_invoke$arity$variadic$=function($x$jscomp$641$$,$map__24100__$1_p__24099$$){$map__24100__$1_p__24099$$=$APP.$cljs$core$__destructure_map$$($map__24100__$1_p__24099$$);var $keyword_fn$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__24100__$1_p__24099$$,$cljs$cst$126$keyword_fn$$,$APP.$cljs$core$name$$),$thisfn$$=function $cljs$core$thisfn$$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$){if($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$==null)return null;
if($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$.$cljs$core$IEncodeJS$$||($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$.$cljs$lang$protocol_mask$partition$$?
0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IEncodeJS$$,$G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IEncodeJS$$,$G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$))return $cljs$core$_clj__GT_js$$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$);
if($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$ instanceof $APP.$cljs$core$Keyword$$)return $keyword_fn$$.$cljs$core$IFn$_invoke$arity$1$?$keyword_fn$$.$cljs$core$IFn$_invoke$arity$1$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$):$keyword_fn$$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$);
if($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$ instanceof $APP.$cljs$core$Symbol$$)return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$);if($APP.$cljs$core$map_QMARK_$$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$)){var $arr$jscomp$135_m$jscomp$60$$=
{};$G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$=$APP.$cljs$core$seq$$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$);for(var $G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$=null,$G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$=
0,$G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$=0;;)if($G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$<$G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$){var $obj$jscomp$inline_2940_vec__24137_29736_x_29767__$2$$=$G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$),
$k_29737_key$jscomp$inline_2941$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($obj$jscomp$inline_2940_vec__24137_29736_x_29767__$2$$,0,null),$v_29738_value$jscomp$inline_2942$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($obj$jscomp$inline_2940_vec__24137_29736_x_29767__$2$$,1,null);$obj$jscomp$inline_2940_vec__24137_29736_x_29767__$2$$=$arr$jscomp$135_m$jscomp$60$$;$k_29737_key$jscomp$inline_2941$$=$cljs$core$key__GT_js$cljs$0core$0IFn$0_invoke$0arity$02$$($k_29737_key$jscomp$inline_2941$$,
$thisfn$$);$v_29738_value$jscomp$inline_2942$$=$cljs$core$thisfn$$($v_29738_value$jscomp$inline_2942$$);$obj$jscomp$inline_2940_vec__24137_29736_x_29767__$2$$[$k_29737_key$jscomp$inline_2941$$]=$v_29738_value$jscomp$inline_2942$$;$G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$+=1}else if($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$=$APP.$cljs$core$seq$$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$)?
($G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$=$APP.$cljs$core$_chunked_first$$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$),$G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$=$APP.$cljs$core$_chunked_rest$$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$),
$G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$=$G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$,$G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$=$APP.$cljs$core$count$$($G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$)):($G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$=
$APP.$cljs$core$first$$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$),$G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$,0,null),$G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$,1,null),$G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$=$arr$jscomp$135_m$jscomp$60$$,$G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$=$cljs$core$key__GT_js$cljs$0core$0IFn$0_invoke$0arity$02$$($G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$,
$thisfn$$),$G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$=$cljs$core$thisfn$$($G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$),$G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$[$G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$]=$G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$,$G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$=
$APP.$cljs$core$next$$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$),$G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$=null,$G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$=0),$G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$=
0;else break;return $arr$jscomp$135_m$jscomp$60$$}if($APP.$cljs$core$coll_QMARK_$$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$)){$arr$jscomp$135_m$jscomp$60$$=[];$G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$=$APP.$cljs$core$seq$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$thisfn$$,
$G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$));$G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$=null;for($G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$=$G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$=0;;)if($G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$<
$G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$)$obj$jscomp$inline_2940_vec__24137_29736_x_29767__$2$$=$G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$),$arr$jscomp$135_m$jscomp$60$$.push($obj$jscomp$inline_2940_vec__24137_29736_x_29767__$2$$),$G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$+=
1;else if($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$=$APP.$cljs$core$seq$$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$))$G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$=$G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$,
$APP.$cljs$core$chunked_seq_QMARK_$$($G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$)?($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$=$APP.$cljs$core$_chunked_first$$($G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$),$G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$=
$APP.$cljs$core$_chunked_rest$$($G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$),$G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$=$G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$,$G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$=
$APP.$cljs$core$count$$($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$),$G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$=$G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$):($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$=
$APP.$cljs$core$first$$($G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$),$arr$jscomp$135_m$jscomp$60$$.push($G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$),$G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$=
$APP.$cljs$core$next$$($G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$),$G__29749_G__29779_chunk__24128_29733_chunk__24144_29763_obj$jscomp$inline_2944_seq__24143_29776__$1_vec__24140_29754$$=null,$G__29750_G__29780_c__5548__auto___29746_count__24129_29734_count__24145_29764_k_29755_key$jscomp$inline_2945$$=0),$G__29778_i__24130_29735_i__24146_29765_v_29756_value$jscomp$inline_2946$$=0;else break;return $arr$jscomp$135_m$jscomp$60$$}return $G__29748_c__5548__auto___29777_seq__24127_29732_seq__24127_29745__$1_seq__24143_29762_temp__5825__auto___29744_temp__5825__auto___29773_x_29782__$2_x__$1$jscomp$11$$};
return $thisfn$$($x$jscomp$641$$)};$APP.$cljs$core$clj__GT_js$$.$cljs$lang$maxFixedArity$=1;$APP.$cljs$core$clj__GT_js$$.$cljs$lang$applyTo$=function($seq24097_seq24097__$1$$){var $G__24098$$=$APP.$cljs$core$first$$($seq24097_seq24097__$1$$);$seq24097_seq24097__$1$$=$APP.$cljs$core$next$$($seq24097_seq24097__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__24098$$,$seq24097_seq24097__$1$$)};
var $cljs$core$_global_hierarchy$$=null,$cljs$core$derive$$=function $cljs$core$derive$$($var_args$jscomp$304$$){switch(arguments.length){case 2:return $cljs$core$derive$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $cljs$core$derive$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$cljs$core$derive$$.$cljs$core$IFn$_invoke$arity$2$=function($args$jscomp$inline_2958_tag$jscomp$9$$,$parent$jscomp$13$$){$args$jscomp$inline_2958_tag$jscomp$9$$=$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$args$jscomp$inline_2958_tag$jscomp$9$$,$parent$jscomp$13$$]);$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$swap_BANG_$$,$APP.$cljs$core$get_global_hierarchy$$(),$cljs$core$derive$$,$args$jscomp$inline_2958_tag$jscomp$9$$);return null};
$cljs$core$derive$$.$cljs$core$IFn$_invoke$arity$3$=function($h$jscomp$77$$,$JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$,$parent$jscomp$14$$){function $tf$jscomp$3$$($m$jscomp$61$$,$source$jscomp$20$$,$sources$jscomp$1$$,$target$jscomp$103$$,$targets$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret$jscomp$54$$,$k$jscomp$214$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($ret$jscomp$54$$,$k$jscomp$214$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($targets$$,$k$jscomp$214$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$APP.$cljs$core$cons$$($target$jscomp$103$$,$targets$$.$cljs$core$IFn$_invoke$arity$1$?$targets$$.$cljs$core$IFn$_invoke$arity$1$($target$jscomp$103$$):$targets$$($target$jscomp$103$$))))},$m$jscomp$61$$,$APP.$cljs$core$cons$$($source$jscomp$20$$,$sources$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$sources$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($source$jscomp$20$$):$sources$jscomp$1$$($source$jscomp$20$$)))}
var $tp$$=$cljs$cst$128$parents$$.$cljs$core$IFn$_invoke$arity$1$($h$jscomp$77$$),$td$$=$cljs$cst$129$descendants$$.$cljs$core$IFn$_invoke$arity$1$($h$jscomp$77$$),$ta$$=$cljs$cst$130$ancestors$$.$cljs$core$IFn$_invoke$arity$1$($h$jscomp$77$$);if($APP.$cljs$core$contains_QMARK_$$($tp$$.$cljs$core$IFn$_invoke$arity$1$?$tp$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$):$tp$$($JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$),
$parent$jscomp$14$$))$JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$=null;else{if($APP.$cljs$core$contains_QMARK_$$($ta$$.$cljs$core$IFn$_invoke$arity$1$?$ta$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$):$ta$$($JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$),$parent$jscomp$14$$))throw Error([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$),
"already has",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$14$$),"as ancestor"].join(""));if($APP.$cljs$core$contains_QMARK_$$($ta$$.$cljs$core$IFn$_invoke$arity$1$?$ta$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$14$$):$ta$$($parent$jscomp$14$$),$JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$))throw Error(["Cyclic derivation:",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$14$$),"has",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$),
"as ancestor"].join(""));$JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$128$parents$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cljs$cst$128$parents$$.$cljs$core$IFn$_invoke$arity$1$($h$jscomp$77$$),$JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($tp$$,$JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$,
$APP.$cljs$core$PersistentHashSet$EMPTY$$),$parent$jscomp$14$$)),$cljs$cst$130$ancestors$$,$tf$jscomp$3$$($cljs$cst$130$ancestors$$.$cljs$core$IFn$_invoke$arity$1$($h$jscomp$77$$),$JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$,$td$$,$parent$jscomp$14$$,$ta$$),$cljs$cst$129$descendants$$,$tf$jscomp$3$$($cljs$cst$129$descendants$$.$cljs$core$IFn$_invoke$arity$1$($h$jscomp$77$$),$parent$jscomp$14$$,$ta$$,$JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$,$td$$)],
null)}return $APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$)?$JSCompiler_temp$jscomp$251_or__5025__auto__$jscomp$47_tag$jscomp$10$$:$h$jscomp$77$$};$cljs$core$derive$$.$cljs$lang$maxFixedArity$=3;
var $cljs$core$prefers_STAR_$$=function $cljs$core$prefers_STAR_$$($x$jscomp$647$$,$y$jscomp$273$$,$prefer_table$$){var $or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$=function(){var $fexpr__24179$$=$APP.$cljs$core$_deref$$($prefer_table$$);return $fexpr__24179$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__24179$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$647$$):$fexpr__24179$$($x$jscomp$647$$)}();$or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$=
$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$)?$or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$.$cljs$core$IFn$_invoke$arity$1$?$or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$273$$):$or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$($y$jscomp$273$$):
$or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$)?!0:null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$))return $or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$;$or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$=function(){for(var $ps$jscomp$2$$=$cljs$core$parents$cljs$0core$0IFn$0_invoke$0arity$01$$($y$jscomp$273$$);;)if($APP.$cljs$core$count$$($ps$jscomp$2$$)>
0){var $G__24181$jscomp$inline_2962$$=$APP.$cljs$core$first$$($ps$jscomp$2$$);$cljs$core$prefers_STAR_$$.$cljs$core$IFn$_invoke$arity$3$?$cljs$core$prefers_STAR_$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$647$$,$G__24181$jscomp$inline_2962$$,$prefer_table$$):$cljs$core$prefers_STAR_$$($x$jscomp$647$$,$G__24181$jscomp$inline_2962$$,$prefer_table$$);$ps$jscomp$2$$=$APP.$cljs$core$rest$$($ps$jscomp$2$$)}else return null}();if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$))return $or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$;
$or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$=function(){for(var $ps$jscomp$3$$=$cljs$core$parents$cljs$0core$0IFn$0_invoke$0arity$01$$($x$jscomp$647$$);;)if($APP.$cljs$core$count$$($ps$jscomp$3$$)>0){var $G__24183$jscomp$inline_2964$$=$APP.$cljs$core$first$$($ps$jscomp$3$$);$cljs$core$prefers_STAR_$$.$cljs$core$IFn$_invoke$arity$3$?$cljs$core$prefers_STAR_$$.$cljs$core$IFn$_invoke$arity$3$($G__24183$jscomp$inline_2964$$,$y$jscomp$273$$,$prefer_table$$):
$cljs$core$prefers_STAR_$$($G__24183$jscomp$inline_2964$$,$y$jscomp$273$$,$prefer_table$$);$ps$jscomp$3$$=$APP.$cljs$core$rest$$($ps$jscomp$3$$)}else return null}();return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$)?$or__5025__auto__$jscomp$48_or__5025__auto____$1$jscomp$12_or__5025__auto____$2$jscomp$5_xprefs$$:!1},$cljs$core$find_and_cache_best_method$$=function $cljs$core$find_and_cache_best_method$$($name$jscomp$110$$,
$dispatch_val$$,$hierarchy$jscomp$2$$,$method_table$jscomp$1$$,$prefer_table$jscomp$2$$,$method_cache$jscomp$1$$,$cached_hierarchy$jscomp$1$$,$default_dispatch_val$$){var $best_entry$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($be_be2$$,$p__24186$$){var $k$jscomp$215$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__24186$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__24186$$,1,null);if($cljs$core$isa_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_deref$$($hierarchy$jscomp$2$$),
$dispatch_val$$,$k$jscomp$215$$)){$be_be2$$=$be_be2$$==null||$cljs$core$dominates$$($k$jscomp$215$$,$APP.$cljs$core$first$$($be_be2$$),$prefer_table$jscomp$2$$,$APP.$cljs$core$_deref$$($hierarchy$jscomp$2$$))?$p__24186$$:$be_be2$$;if(!$cljs$core$dominates$$($APP.$cljs$core$first$$($be_be2$$),$k$jscomp$215$$,$prefer_table$jscomp$2$$,$APP.$cljs$core$_deref$$($hierarchy$jscomp$2$$)))throw Error(["Multiple methods in multimethod '",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$110$$),
"' match dispatch value: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($dispatch_val$$)," -\x3e ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$215$$)," and ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($be_be2$$)),", and neither is preferred"].join(""));return $be_be2$$}return $be_be2$$},null,$APP.$cljs$core$_deref$$($method_table$jscomp$1$$)),$best_entry__$1$$=function(){var $and__5023__auto__$jscomp$inline_2966_fexpr__24190$jscomp$inline_2967_temp__5823__auto__$jscomp$18$$;
if($and__5023__auto__$jscomp$inline_2966_fexpr__24190$jscomp$inline_2967_temp__5823__auto__$jscomp$18$$=$best_entry$$==null)$and__5023__auto__$jscomp$inline_2966_fexpr__24190$jscomp$inline_2967_temp__5823__auto__$jscomp$18$$=$APP.$cljs$core$_deref$$($method_table$jscomp$1$$),$and__5023__auto__$jscomp$inline_2966_fexpr__24190$jscomp$inline_2967_temp__5823__auto__$jscomp$18$$=$and__5023__auto__$jscomp$inline_2966_fexpr__24190$jscomp$inline_2967_temp__5823__auto__$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$?
$and__5023__auto__$jscomp$inline_2966_fexpr__24190$jscomp$inline_2967_temp__5823__auto__$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$($default_dispatch_val$$):$and__5023__auto__$jscomp$inline_2966_fexpr__24190$jscomp$inline_2967_temp__5823__auto__$jscomp$18$$($default_dispatch_val$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_2966_fexpr__24190$jscomp$inline_2967_temp__5823__auto__$jscomp$18$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$default_dispatch_val$$,$and__5023__auto__$jscomp$inline_2966_fexpr__24190$jscomp$inline_2967_temp__5823__auto__$jscomp$18$$],null):$best_entry$$}();if($APP.$cljs$core$truth_$$($best_entry__$1$$)){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($cached_hierarchy$jscomp$1$$),$APP.$cljs$core$_deref$$($hierarchy$jscomp$2$$)))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($method_cache$jscomp$1$$,$APP.$cljs$core$assoc$$,$dispatch_val$$,$APP.$cljs$core$second$$($best_entry__$1$$)),
$APP.$cljs$core$second$$($best_entry__$1$$);$cljs$core$reset_cache$$($method_cache$jscomp$1$$,$method_table$jscomp$1$$,$cached_hierarchy$jscomp$1$$,$hierarchy$jscomp$2$$);return $cljs$core$find_and_cache_best_method$$.$cljs$core$IFn$_invoke$arity$8$?$cljs$core$find_and_cache_best_method$$.$cljs$core$IFn$_invoke$arity$8$($name$jscomp$110$$,$dispatch_val$$,$hierarchy$jscomp$2$$,$method_table$jscomp$1$$,$prefer_table$jscomp$2$$,$method_cache$jscomp$1$$,$cached_hierarchy$jscomp$1$$,$default_dispatch_val$$):
$cljs$core$find_and_cache_best_method$$($name$jscomp$110$$,$dispatch_val$$,$hierarchy$jscomp$2$$,$method_table$jscomp$1$$,$prefer_table$jscomp$2$$,$method_cache$jscomp$1$$,$cached_hierarchy$jscomp$1$$,$default_dispatch_val$$)}return null};$APP.$JSCompiler_prototypeAlias$$=$APP.$cljs$core$MultiFn$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$19$$){switch(arguments.length-1){case 0:return this.$cljs$core$IFn$_invoke$arity$0$();case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);case 3:return this.$cljs$core$IFn$_invoke$arity$3$(arguments[1],arguments[2],arguments[3]);case 4:return this.$cljs$core$IFn$_invoke$arity$4$(arguments[1],arguments[2],arguments[3],arguments[4]);
case 5:return this.$cljs$core$IFn$_invoke$arity$5$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5]);case 6:return this.$cljs$core$IFn$_invoke$arity$6$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6]);case 7:return this.$cljs$core$IFn$_invoke$arity$7$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7]);case 8:return this.$cljs$core$IFn$_invoke$arity$8$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],
arguments[6],arguments[7],arguments[8]);case 9:return this.$cljs$core$IFn$_invoke$arity$9$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9]);case 10:return this.$cljs$core$IFn$_invoke$arity$10$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10]);case 11:return this.$cljs$core$IFn$_invoke$arity$11$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],
arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11]);case 12:return this.$cljs$core$IFn$_invoke$arity$12$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12]);case 13:return this.$cljs$core$IFn$_invoke$arity$13$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],
arguments[13]);case 14:return this.$cljs$core$IFn$_invoke$arity$14$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14]);case 15:return this.$cljs$core$IFn$_invoke$arity$15$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15]);
case 16:return this.$cljs$core$IFn$_invoke$arity$16$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16]);case 17:return this.$cljs$core$IFn$_invoke$arity$17$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],
arguments[15],arguments[16],arguments[17]);case 18:return this.$cljs$core$IFn$_invoke$arity$18$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18]);case 19:return this.$cljs$core$IFn$_invoke$arity$19$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],
arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19]);case 20:return this.$cljs$core$IFn$_invoke$arity$20$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19],arguments[20]);case 21:return this.$cljs$core$IFn$_invoke$arity$21$(arguments[1],
arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19],arguments[20],arguments[21]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};
$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$1045$$,$args24191$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args24191$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$0$=function(){var $dispatch_val$jscomp$10$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$0$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$0$():this.$dispatch_fn$(),$target_fn$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$10$$);$APP.$cljs$core$truth_$$($target_fn$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$10$$);return $target_fn$$.$cljs$core$IFn$_invoke$arity$0$?
$target_fn$$.$cljs$core$IFn$_invoke$arity$0$():$target_fn$$()};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($a$jscomp$170$$){var $dispatch_val$jscomp$11$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$1$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$170$$):this.$dispatch_fn$($a$jscomp$170$$),$target_fn$jscomp$1$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$11$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$1$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$11$$);
return $target_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$target_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$170$$):$target_fn$jscomp$1$$($a$jscomp$170$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($a$jscomp$171$$,$b$jscomp$139$$){var $dispatch_val$jscomp$12$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$2$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$171$$,$b$jscomp$139$$):this.$dispatch_fn$($a$jscomp$171$$,$b$jscomp$139$$),$target_fn$jscomp$2$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$12$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$2$$)||$cljs$core$throw_no_method_error$$(this.name,
$dispatch_val$jscomp$12$$);return $target_fn$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$target_fn$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$171$$,$b$jscomp$139$$):$target_fn$jscomp$2$$($a$jscomp$171$$,$b$jscomp$139$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$3$=function($a$jscomp$172$$,$b$jscomp$140$$,$c$jscomp$116$$){var $dispatch_val$jscomp$13$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$3$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$3$($a$jscomp$172$$,$b$jscomp$140$$,$c$jscomp$116$$):this.$dispatch_fn$($a$jscomp$172$$,$b$jscomp$140$$,$c$jscomp$116$$),$target_fn$jscomp$3$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$13$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$3$$)||
$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$13$$);return $target_fn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$3$?$target_fn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$3$($a$jscomp$172$$,$b$jscomp$140$$,$c$jscomp$116$$):$target_fn$jscomp$3$$($a$jscomp$172$$,$b$jscomp$140$$,$c$jscomp$116$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$4$=function($a$jscomp$173$$,$b$jscomp$141$$,$c$jscomp$117$$,$d$jscomp$83$$){var $dispatch_val$jscomp$14$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$4$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$4$($a$jscomp$173$$,$b$jscomp$141$$,$c$jscomp$117$$,$d$jscomp$83$$):this.$dispatch_fn$($a$jscomp$173$$,$b$jscomp$141$$,$c$jscomp$117$$,$d$jscomp$83$$),$target_fn$jscomp$4$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,
$dispatch_val$jscomp$14$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$4$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$14$$);return $target_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$4$?$target_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$4$($a$jscomp$173$$,$b$jscomp$141$$,$c$jscomp$117$$,$d$jscomp$83$$):$target_fn$jscomp$4$$($a$jscomp$173$$,$b$jscomp$141$$,$c$jscomp$117$$,$d$jscomp$83$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$5$=function($a$jscomp$174$$,$b$jscomp$142$$,$c$jscomp$118$$,$d$jscomp$84$$,$e$jscomp$108$$){var $dispatch_val$jscomp$15$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$5$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$5$($a$jscomp$174$$,$b$jscomp$142$$,$c$jscomp$118$$,$d$jscomp$84$$,$e$jscomp$108$$):this.$dispatch_fn$($a$jscomp$174$$,$b$jscomp$142$$,$c$jscomp$118$$,$d$jscomp$84$$,$e$jscomp$108$$),$target_fn$jscomp$5$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,
$dispatch_val$jscomp$15$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$5$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$15$$);return $target_fn$jscomp$5$$.$cljs$core$IFn$_invoke$arity$5$?$target_fn$jscomp$5$$.$cljs$core$IFn$_invoke$arity$5$($a$jscomp$174$$,$b$jscomp$142$$,$c$jscomp$118$$,$d$jscomp$84$$,$e$jscomp$108$$):$target_fn$jscomp$5$$($a$jscomp$174$$,$b$jscomp$142$$,$c$jscomp$118$$,$d$jscomp$84$$,$e$jscomp$108$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$6$=function($a$jscomp$175$$,$b$jscomp$143$$,$c$jscomp$119$$,$d$jscomp$85$$,$e$jscomp$109$$,$f$jscomp$313$$){var $dispatch_val$jscomp$16$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$6$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$6$($a$jscomp$175$$,$b$jscomp$143$$,$c$jscomp$119$$,$d$jscomp$85$$,$e$jscomp$109$$,$f$jscomp$313$$):this.$dispatch_fn$($a$jscomp$175$$,$b$jscomp$143$$,$c$jscomp$119$$,$d$jscomp$85$$,$e$jscomp$109$$,$f$jscomp$313$$),
$target_fn$jscomp$6$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$16$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$6$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$16$$);return $target_fn$jscomp$6$$.$cljs$core$IFn$_invoke$arity$6$?$target_fn$jscomp$6$$.$cljs$core$IFn$_invoke$arity$6$($a$jscomp$175$$,$b$jscomp$143$$,$c$jscomp$119$$,$d$jscomp$85$$,$e$jscomp$109$$,$f$jscomp$313$$):$target_fn$jscomp$6$$($a$jscomp$175$$,$b$jscomp$143$$,
$c$jscomp$119$$,$d$jscomp$85$$,$e$jscomp$109$$,$f$jscomp$313$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$7$=function($a$jscomp$176$$,$b$jscomp$144$$,$c$jscomp$120$$,$d$jscomp$86$$,$e$jscomp$110$$,$f$jscomp$314$$,$g$jscomp$66$$){var $dispatch_val$jscomp$17$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$7$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$7$($a$jscomp$176$$,$b$jscomp$144$$,$c$jscomp$120$$,$d$jscomp$86$$,$e$jscomp$110$$,$f$jscomp$314$$,$g$jscomp$66$$):this.$dispatch_fn$($a$jscomp$176$$,$b$jscomp$144$$,$c$jscomp$120$$,$d$jscomp$86$$,
$e$jscomp$110$$,$f$jscomp$314$$,$g$jscomp$66$$),$target_fn$jscomp$7$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$17$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$7$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$17$$);return $target_fn$jscomp$7$$.$cljs$core$IFn$_invoke$arity$7$?$target_fn$jscomp$7$$.$cljs$core$IFn$_invoke$arity$7$($a$jscomp$176$$,$b$jscomp$144$$,$c$jscomp$120$$,$d$jscomp$86$$,$e$jscomp$110$$,$f$jscomp$314$$,$g$jscomp$66$$):
$target_fn$jscomp$7$$($a$jscomp$176$$,$b$jscomp$144$$,$c$jscomp$120$$,$d$jscomp$86$$,$e$jscomp$110$$,$f$jscomp$314$$,$g$jscomp$66$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$8$=function($a$jscomp$177$$,$b$jscomp$145$$,$c$jscomp$121$$,$d$jscomp$87$$,$e$jscomp$111$$,$f$jscomp$315$$,$g$jscomp$67$$,$h$jscomp$79$$){var $dispatch_val$jscomp$18$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$8$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$8$($a$jscomp$177$$,$b$jscomp$145$$,$c$jscomp$121$$,$d$jscomp$87$$,$e$jscomp$111$$,$f$jscomp$315$$,$g$jscomp$67$$,$h$jscomp$79$$):this.$dispatch_fn$($a$jscomp$177$$,$b$jscomp$145$$,
$c$jscomp$121$$,$d$jscomp$87$$,$e$jscomp$111$$,$f$jscomp$315$$,$g$jscomp$67$$,$h$jscomp$79$$),$target_fn$jscomp$8$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$18$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$8$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$18$$);return $target_fn$jscomp$8$$.$cljs$core$IFn$_invoke$arity$8$?$target_fn$jscomp$8$$.$cljs$core$IFn$_invoke$arity$8$($a$jscomp$177$$,$b$jscomp$145$$,$c$jscomp$121$$,$d$jscomp$87$$,
$e$jscomp$111$$,$f$jscomp$315$$,$g$jscomp$67$$,$h$jscomp$79$$):$target_fn$jscomp$8$$($a$jscomp$177$$,$b$jscomp$145$$,$c$jscomp$121$$,$d$jscomp$87$$,$e$jscomp$111$$,$f$jscomp$315$$,$g$jscomp$67$$,$h$jscomp$79$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$9$=function($a$jscomp$178$$,$b$jscomp$146$$,$c$jscomp$122$$,$d$jscomp$88$$,$e$jscomp$112$$,$f$jscomp$316$$,$g$jscomp$68$$,$h$jscomp$80$$,$i$jscomp$273$$){var $dispatch_val$jscomp$19$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$9$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$9$($a$jscomp$178$$,$b$jscomp$146$$,$c$jscomp$122$$,$d$jscomp$88$$,$e$jscomp$112$$,$f$jscomp$316$$,$g$jscomp$68$$,$h$jscomp$80$$,$i$jscomp$273$$):this.$dispatch_fn$($a$jscomp$178$$,
$b$jscomp$146$$,$c$jscomp$122$$,$d$jscomp$88$$,$e$jscomp$112$$,$f$jscomp$316$$,$g$jscomp$68$$,$h$jscomp$80$$,$i$jscomp$273$$),$target_fn$jscomp$9$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$19$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$9$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$19$$);return $target_fn$jscomp$9$$.$cljs$core$IFn$_invoke$arity$9$?$target_fn$jscomp$9$$.$cljs$core$IFn$_invoke$arity$9$($a$jscomp$178$$,$b$jscomp$146$$,
$c$jscomp$122$$,$d$jscomp$88$$,$e$jscomp$112$$,$f$jscomp$316$$,$g$jscomp$68$$,$h$jscomp$80$$,$i$jscomp$273$$):$target_fn$jscomp$9$$($a$jscomp$178$$,$b$jscomp$146$$,$c$jscomp$122$$,$d$jscomp$88$$,$e$jscomp$112$$,$f$jscomp$316$$,$g$jscomp$68$$,$h$jscomp$80$$,$i$jscomp$273$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$10$=function($a$jscomp$179$$,$b$jscomp$147$$,$c$jscomp$123$$,$d$jscomp$89$$,$e$jscomp$113$$,$f$jscomp$317$$,$g$jscomp$69$$,$h$jscomp$81$$,$i$jscomp$274$$,$j$jscomp$73$$){var $dispatch_val$jscomp$20$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$10$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$10$($a$jscomp$179$$,$b$jscomp$147$$,$c$jscomp$123$$,$d$jscomp$89$$,$e$jscomp$113$$,$f$jscomp$317$$,$g$jscomp$69$$,$h$jscomp$81$$,$i$jscomp$274$$,
$j$jscomp$73$$):this.$dispatch_fn$($a$jscomp$179$$,$b$jscomp$147$$,$c$jscomp$123$$,$d$jscomp$89$$,$e$jscomp$113$$,$f$jscomp$317$$,$g$jscomp$69$$,$h$jscomp$81$$,$i$jscomp$274$$,$j$jscomp$73$$),$target_fn$jscomp$10$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$20$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$10$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$20$$);return $target_fn$jscomp$10$$.$cljs$core$IFn$_invoke$arity$10$?$target_fn$jscomp$10$$.$cljs$core$IFn$_invoke$arity$10$($a$jscomp$179$$,
$b$jscomp$147$$,$c$jscomp$123$$,$d$jscomp$89$$,$e$jscomp$113$$,$f$jscomp$317$$,$g$jscomp$69$$,$h$jscomp$81$$,$i$jscomp$274$$,$j$jscomp$73$$):$target_fn$jscomp$10$$($a$jscomp$179$$,$b$jscomp$147$$,$c$jscomp$123$$,$d$jscomp$89$$,$e$jscomp$113$$,$f$jscomp$317$$,$g$jscomp$69$$,$h$jscomp$81$$,$i$jscomp$274$$,$j$jscomp$73$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$11$=function($a$jscomp$180$$,$b$jscomp$148$$,$c$jscomp$124$$,$d$jscomp$90$$,$e$jscomp$114$$,$f$jscomp$318$$,$g$jscomp$70$$,$h$jscomp$82$$,$i$jscomp$275$$,$j$jscomp$74$$,$k$jscomp$216$$){var $dispatch_val$jscomp$21$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$11$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$11$($a$jscomp$180$$,$b$jscomp$148$$,$c$jscomp$124$$,$d$jscomp$90$$,$e$jscomp$114$$,$f$jscomp$318$$,$g$jscomp$70$$,$h$jscomp$82$$,
$i$jscomp$275$$,$j$jscomp$74$$,$k$jscomp$216$$):this.$dispatch_fn$($a$jscomp$180$$,$b$jscomp$148$$,$c$jscomp$124$$,$d$jscomp$90$$,$e$jscomp$114$$,$f$jscomp$318$$,$g$jscomp$70$$,$h$jscomp$82$$,$i$jscomp$275$$,$j$jscomp$74$$,$k$jscomp$216$$),$target_fn$jscomp$11$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$21$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$11$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$21$$);return $target_fn$jscomp$11$$.$cljs$core$IFn$_invoke$arity$11$?
$target_fn$jscomp$11$$.$cljs$core$IFn$_invoke$arity$11$($a$jscomp$180$$,$b$jscomp$148$$,$c$jscomp$124$$,$d$jscomp$90$$,$e$jscomp$114$$,$f$jscomp$318$$,$g$jscomp$70$$,$h$jscomp$82$$,$i$jscomp$275$$,$j$jscomp$74$$,$k$jscomp$216$$):$target_fn$jscomp$11$$($a$jscomp$180$$,$b$jscomp$148$$,$c$jscomp$124$$,$d$jscomp$90$$,$e$jscomp$114$$,$f$jscomp$318$$,$g$jscomp$70$$,$h$jscomp$82$$,$i$jscomp$275$$,$j$jscomp$74$$,$k$jscomp$216$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$12$=function($a$jscomp$181$$,$b$jscomp$149$$,$c$jscomp$125$$,$d$jscomp$91$$,$e$jscomp$115$$,$f$jscomp$319$$,$g$jscomp$71$$,$h$jscomp$83$$,$i$jscomp$276$$,$j$jscomp$75$$,$k$jscomp$217$$,$l$jscomp$63$$){var $dispatch_val$jscomp$22$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$12$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$12$($a$jscomp$181$$,$b$jscomp$149$$,$c$jscomp$125$$,$d$jscomp$91$$,$e$jscomp$115$$,$f$jscomp$319$$,$g$jscomp$71$$,
$h$jscomp$83$$,$i$jscomp$276$$,$j$jscomp$75$$,$k$jscomp$217$$,$l$jscomp$63$$):this.$dispatch_fn$($a$jscomp$181$$,$b$jscomp$149$$,$c$jscomp$125$$,$d$jscomp$91$$,$e$jscomp$115$$,$f$jscomp$319$$,$g$jscomp$71$$,$h$jscomp$83$$,$i$jscomp$276$$,$j$jscomp$75$$,$k$jscomp$217$$,$l$jscomp$63$$),$target_fn$jscomp$12$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$22$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$12$$)||$cljs$core$throw_no_method_error$$(this.name,
$dispatch_val$jscomp$22$$);return $target_fn$jscomp$12$$.$cljs$core$IFn$_invoke$arity$12$?$target_fn$jscomp$12$$.$cljs$core$IFn$_invoke$arity$12$($a$jscomp$181$$,$b$jscomp$149$$,$c$jscomp$125$$,$d$jscomp$91$$,$e$jscomp$115$$,$f$jscomp$319$$,$g$jscomp$71$$,$h$jscomp$83$$,$i$jscomp$276$$,$j$jscomp$75$$,$k$jscomp$217$$,$l$jscomp$63$$):$target_fn$jscomp$12$$($a$jscomp$181$$,$b$jscomp$149$$,$c$jscomp$125$$,$d$jscomp$91$$,$e$jscomp$115$$,$f$jscomp$319$$,$g$jscomp$71$$,$h$jscomp$83$$,$i$jscomp$276$$,$j$jscomp$75$$,
$k$jscomp$217$$,$l$jscomp$63$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$13$=function($a$jscomp$182$$,$b$jscomp$150$$,$c$jscomp$126$$,$d$jscomp$92$$,$e$jscomp$116$$,$f$jscomp$320$$,$g$jscomp$72$$,$h$jscomp$84$$,$i$jscomp$277$$,$j$jscomp$76$$,$k$jscomp$218$$,$l$jscomp$64$$,$m$jscomp$62$$){var $dispatch_val$jscomp$23$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$13$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$13$($a$jscomp$182$$,$b$jscomp$150$$,$c$jscomp$126$$,$d$jscomp$92$$,$e$jscomp$116$$,$f$jscomp$320$$,
$g$jscomp$72$$,$h$jscomp$84$$,$i$jscomp$277$$,$j$jscomp$76$$,$k$jscomp$218$$,$l$jscomp$64$$,$m$jscomp$62$$):this.$dispatch_fn$($a$jscomp$182$$,$b$jscomp$150$$,$c$jscomp$126$$,$d$jscomp$92$$,$e$jscomp$116$$,$f$jscomp$320$$,$g$jscomp$72$$,$h$jscomp$84$$,$i$jscomp$277$$,$j$jscomp$76$$,$k$jscomp$218$$,$l$jscomp$64$$,$m$jscomp$62$$),$target_fn$jscomp$13$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$23$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$13$$)||
$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$23$$);return $target_fn$jscomp$13$$.$cljs$core$IFn$_invoke$arity$13$?$target_fn$jscomp$13$$.$cljs$core$IFn$_invoke$arity$13$($a$jscomp$182$$,$b$jscomp$150$$,$c$jscomp$126$$,$d$jscomp$92$$,$e$jscomp$116$$,$f$jscomp$320$$,$g$jscomp$72$$,$h$jscomp$84$$,$i$jscomp$277$$,$j$jscomp$76$$,$k$jscomp$218$$,$l$jscomp$64$$,$m$jscomp$62$$):$target_fn$jscomp$13$$($a$jscomp$182$$,$b$jscomp$150$$,$c$jscomp$126$$,$d$jscomp$92$$,$e$jscomp$116$$,$f$jscomp$320$$,
$g$jscomp$72$$,$h$jscomp$84$$,$i$jscomp$277$$,$j$jscomp$76$$,$k$jscomp$218$$,$l$jscomp$64$$,$m$jscomp$62$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$14$=function($a$jscomp$183$$,$b$jscomp$151$$,$c$jscomp$127$$,$d$jscomp$93$$,$e$jscomp$117$$,$f$jscomp$321$$,$g$jscomp$73$$,$h$jscomp$85$$,$i$jscomp$278$$,$j$jscomp$77$$,$k$jscomp$219$$,$l$jscomp$65$$,$m$jscomp$63$$,$n$jscomp$162$$){var $dispatch_val$jscomp$24$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$14$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$14$($a$jscomp$183$$,$b$jscomp$151$$,$c$jscomp$127$$,$d$jscomp$93$$,$e$jscomp$117$$,
$f$jscomp$321$$,$g$jscomp$73$$,$h$jscomp$85$$,$i$jscomp$278$$,$j$jscomp$77$$,$k$jscomp$219$$,$l$jscomp$65$$,$m$jscomp$63$$,$n$jscomp$162$$):this.$dispatch_fn$($a$jscomp$183$$,$b$jscomp$151$$,$c$jscomp$127$$,$d$jscomp$93$$,$e$jscomp$117$$,$f$jscomp$321$$,$g$jscomp$73$$,$h$jscomp$85$$,$i$jscomp$278$$,$j$jscomp$77$$,$k$jscomp$219$$,$l$jscomp$65$$,$m$jscomp$63$$,$n$jscomp$162$$),$target_fn$jscomp$14$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$24$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$14$$)||
$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$24$$);return $target_fn$jscomp$14$$.$cljs$core$IFn$_invoke$arity$14$?$target_fn$jscomp$14$$.$cljs$core$IFn$_invoke$arity$14$($a$jscomp$183$$,$b$jscomp$151$$,$c$jscomp$127$$,$d$jscomp$93$$,$e$jscomp$117$$,$f$jscomp$321$$,$g$jscomp$73$$,$h$jscomp$85$$,$i$jscomp$278$$,$j$jscomp$77$$,$k$jscomp$219$$,$l$jscomp$65$$,$m$jscomp$63$$,$n$jscomp$162$$):$target_fn$jscomp$14$$($a$jscomp$183$$,$b$jscomp$151$$,$c$jscomp$127$$,$d$jscomp$93$$,$e$jscomp$117$$,
$f$jscomp$321$$,$g$jscomp$73$$,$h$jscomp$85$$,$i$jscomp$278$$,$j$jscomp$77$$,$k$jscomp$219$$,$l$jscomp$65$$,$m$jscomp$63$$,$n$jscomp$162$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$15$=function($a$jscomp$184$$,$b$jscomp$152$$,$c$jscomp$128$$,$d$jscomp$94$$,$e$jscomp$118$$,$f$jscomp$322$$,$g$jscomp$74$$,$h$jscomp$86$$,$i$jscomp$279$$,$j$jscomp$78$$,$k$jscomp$220$$,$l$jscomp$66$$,$m$jscomp$64$$,$n$jscomp$163$$,$o$jscomp$124$$){var $dispatch_val$jscomp$25$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$15$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$15$($a$jscomp$184$$,$b$jscomp$152$$,$c$jscomp$128$$,$d$jscomp$94$$,
$e$jscomp$118$$,$f$jscomp$322$$,$g$jscomp$74$$,$h$jscomp$86$$,$i$jscomp$279$$,$j$jscomp$78$$,$k$jscomp$220$$,$l$jscomp$66$$,$m$jscomp$64$$,$n$jscomp$163$$,$o$jscomp$124$$):this.$dispatch_fn$($a$jscomp$184$$,$b$jscomp$152$$,$c$jscomp$128$$,$d$jscomp$94$$,$e$jscomp$118$$,$f$jscomp$322$$,$g$jscomp$74$$,$h$jscomp$86$$,$i$jscomp$279$$,$j$jscomp$78$$,$k$jscomp$220$$,$l$jscomp$66$$,$m$jscomp$64$$,$n$jscomp$163$$,$o$jscomp$124$$),$target_fn$jscomp$15$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,
$dispatch_val$jscomp$25$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$15$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$25$$);return $target_fn$jscomp$15$$.$cljs$core$IFn$_invoke$arity$15$?$target_fn$jscomp$15$$.$cljs$core$IFn$_invoke$arity$15$($a$jscomp$184$$,$b$jscomp$152$$,$c$jscomp$128$$,$d$jscomp$94$$,$e$jscomp$118$$,$f$jscomp$322$$,$g$jscomp$74$$,$h$jscomp$86$$,$i$jscomp$279$$,$j$jscomp$78$$,$k$jscomp$220$$,$l$jscomp$66$$,$m$jscomp$64$$,$n$jscomp$163$$,$o$jscomp$124$$):
$target_fn$jscomp$15$$($a$jscomp$184$$,$b$jscomp$152$$,$c$jscomp$128$$,$d$jscomp$94$$,$e$jscomp$118$$,$f$jscomp$322$$,$g$jscomp$74$$,$h$jscomp$86$$,$i$jscomp$279$$,$j$jscomp$78$$,$k$jscomp$220$$,$l$jscomp$66$$,$m$jscomp$64$$,$n$jscomp$163$$,$o$jscomp$124$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$16$=function($a$jscomp$185$$,$b$jscomp$153$$,$c$jscomp$129$$,$d$jscomp$95$$,$e$jscomp$119$$,$f$jscomp$323$$,$g$jscomp$75$$,$h$jscomp$87$$,$i$jscomp$280$$,$j$jscomp$79$$,$k$jscomp$221$$,$l$jscomp$67$$,$m$jscomp$65$$,$n$jscomp$164$$,$o$jscomp$125$$,$p$jscomp$33$$){var $dispatch_val$jscomp$26$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$16$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$16$($a$jscomp$185$$,$b$jscomp$153$$,$c$jscomp$129$$,
$d$jscomp$95$$,$e$jscomp$119$$,$f$jscomp$323$$,$g$jscomp$75$$,$h$jscomp$87$$,$i$jscomp$280$$,$j$jscomp$79$$,$k$jscomp$221$$,$l$jscomp$67$$,$m$jscomp$65$$,$n$jscomp$164$$,$o$jscomp$125$$,$p$jscomp$33$$):this.$dispatch_fn$($a$jscomp$185$$,$b$jscomp$153$$,$c$jscomp$129$$,$d$jscomp$95$$,$e$jscomp$119$$,$f$jscomp$323$$,$g$jscomp$75$$,$h$jscomp$87$$,$i$jscomp$280$$,$j$jscomp$79$$,$k$jscomp$221$$,$l$jscomp$67$$,$m$jscomp$65$$,$n$jscomp$164$$,$o$jscomp$125$$,$p$jscomp$33$$),$target_fn$jscomp$16$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,
$dispatch_val$jscomp$26$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$16$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$26$$);return $target_fn$jscomp$16$$.$cljs$core$IFn$_invoke$arity$16$?$target_fn$jscomp$16$$.$cljs$core$IFn$_invoke$arity$16$($a$jscomp$185$$,$b$jscomp$153$$,$c$jscomp$129$$,$d$jscomp$95$$,$e$jscomp$119$$,$f$jscomp$323$$,$g$jscomp$75$$,$h$jscomp$87$$,$i$jscomp$280$$,$j$jscomp$79$$,$k$jscomp$221$$,$l$jscomp$67$$,$m$jscomp$65$$,$n$jscomp$164$$,$o$jscomp$125$$,
$p$jscomp$33$$):$target_fn$jscomp$16$$($a$jscomp$185$$,$b$jscomp$153$$,$c$jscomp$129$$,$d$jscomp$95$$,$e$jscomp$119$$,$f$jscomp$323$$,$g$jscomp$75$$,$h$jscomp$87$$,$i$jscomp$280$$,$j$jscomp$79$$,$k$jscomp$221$$,$l$jscomp$67$$,$m$jscomp$65$$,$n$jscomp$164$$,$o$jscomp$125$$,$p$jscomp$33$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$17$=function($a$jscomp$186$$,$b$jscomp$154$$,$c$jscomp$130$$,$d$jscomp$96$$,$e$jscomp$120$$,$f$jscomp$324$$,$g$jscomp$76$$,$h$jscomp$88$$,$i$jscomp$281$$,$j$jscomp$80$$,$k$jscomp$222$$,$l$jscomp$68$$,$m$jscomp$66$$,$n$jscomp$165$$,$o$jscomp$126$$,$p$jscomp$34$$,$q$jscomp$23$$){var $dispatch_val$jscomp$27$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$17$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$17$($a$jscomp$186$$,$b$jscomp$154$$,
$c$jscomp$130$$,$d$jscomp$96$$,$e$jscomp$120$$,$f$jscomp$324$$,$g$jscomp$76$$,$h$jscomp$88$$,$i$jscomp$281$$,$j$jscomp$80$$,$k$jscomp$222$$,$l$jscomp$68$$,$m$jscomp$66$$,$n$jscomp$165$$,$o$jscomp$126$$,$p$jscomp$34$$,$q$jscomp$23$$):this.$dispatch_fn$($a$jscomp$186$$,$b$jscomp$154$$,$c$jscomp$130$$,$d$jscomp$96$$,$e$jscomp$120$$,$f$jscomp$324$$,$g$jscomp$76$$,$h$jscomp$88$$,$i$jscomp$281$$,$j$jscomp$80$$,$k$jscomp$222$$,$l$jscomp$68$$,$m$jscomp$66$$,$n$jscomp$165$$,$o$jscomp$126$$,$p$jscomp$34$$,
$q$jscomp$23$$),$target_fn$jscomp$17$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$27$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$17$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$27$$);return $target_fn$jscomp$17$$.$cljs$core$IFn$_invoke$arity$17$?$target_fn$jscomp$17$$.$cljs$core$IFn$_invoke$arity$17$($a$jscomp$186$$,$b$jscomp$154$$,$c$jscomp$130$$,$d$jscomp$96$$,$e$jscomp$120$$,$f$jscomp$324$$,$g$jscomp$76$$,$h$jscomp$88$$,
$i$jscomp$281$$,$j$jscomp$80$$,$k$jscomp$222$$,$l$jscomp$68$$,$m$jscomp$66$$,$n$jscomp$165$$,$o$jscomp$126$$,$p$jscomp$34$$,$q$jscomp$23$$):$target_fn$jscomp$17$$($a$jscomp$186$$,$b$jscomp$154$$,$c$jscomp$130$$,$d$jscomp$96$$,$e$jscomp$120$$,$f$jscomp$324$$,$g$jscomp$76$$,$h$jscomp$88$$,$i$jscomp$281$$,$j$jscomp$80$$,$k$jscomp$222$$,$l$jscomp$68$$,$m$jscomp$66$$,$n$jscomp$165$$,$o$jscomp$126$$,$p$jscomp$34$$,$q$jscomp$23$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$18$=function($a$jscomp$187$$,$b$jscomp$155$$,$c$jscomp$131$$,$d$jscomp$97$$,$e$jscomp$121$$,$f$jscomp$325$$,$g$jscomp$77$$,$h$jscomp$89$$,$i$jscomp$282$$,$j$jscomp$81$$,$k$jscomp$223$$,$l$jscomp$69$$,$m$jscomp$67$$,$n$jscomp$166$$,$o$jscomp$127$$,$p$jscomp$35$$,$q$jscomp$24$$,$r$jscomp$25$$){var $dispatch_val$jscomp$28$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$18$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$18$($a$jscomp$187$$,
$b$jscomp$155$$,$c$jscomp$131$$,$d$jscomp$97$$,$e$jscomp$121$$,$f$jscomp$325$$,$g$jscomp$77$$,$h$jscomp$89$$,$i$jscomp$282$$,$j$jscomp$81$$,$k$jscomp$223$$,$l$jscomp$69$$,$m$jscomp$67$$,$n$jscomp$166$$,$o$jscomp$127$$,$p$jscomp$35$$,$q$jscomp$24$$,$r$jscomp$25$$):this.$dispatch_fn$($a$jscomp$187$$,$b$jscomp$155$$,$c$jscomp$131$$,$d$jscomp$97$$,$e$jscomp$121$$,$f$jscomp$325$$,$g$jscomp$77$$,$h$jscomp$89$$,$i$jscomp$282$$,$j$jscomp$81$$,$k$jscomp$223$$,$l$jscomp$69$$,$m$jscomp$67$$,$n$jscomp$166$$,
$o$jscomp$127$$,$p$jscomp$35$$,$q$jscomp$24$$,$r$jscomp$25$$),$target_fn$jscomp$18$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$28$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$18$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$28$$);return $target_fn$jscomp$18$$.$cljs$core$IFn$_invoke$arity$18$?$target_fn$jscomp$18$$.$cljs$core$IFn$_invoke$arity$18$($a$jscomp$187$$,$b$jscomp$155$$,$c$jscomp$131$$,$d$jscomp$97$$,$e$jscomp$121$$,
$f$jscomp$325$$,$g$jscomp$77$$,$h$jscomp$89$$,$i$jscomp$282$$,$j$jscomp$81$$,$k$jscomp$223$$,$l$jscomp$69$$,$m$jscomp$67$$,$n$jscomp$166$$,$o$jscomp$127$$,$p$jscomp$35$$,$q$jscomp$24$$,$r$jscomp$25$$):$target_fn$jscomp$18$$($a$jscomp$187$$,$b$jscomp$155$$,$c$jscomp$131$$,$d$jscomp$97$$,$e$jscomp$121$$,$f$jscomp$325$$,$g$jscomp$77$$,$h$jscomp$89$$,$i$jscomp$282$$,$j$jscomp$81$$,$k$jscomp$223$$,$l$jscomp$69$$,$m$jscomp$67$$,$n$jscomp$166$$,$o$jscomp$127$$,$p$jscomp$35$$,$q$jscomp$24$$,$r$jscomp$25$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$19$=function($a$jscomp$188$$,$b$jscomp$156$$,$c$jscomp$132$$,$d$jscomp$98$$,$e$jscomp$122$$,$f$jscomp$326$$,$g$jscomp$78$$,$h$jscomp$90$$,$i$jscomp$283$$,$j$jscomp$82$$,$k$jscomp$224$$,$l$jscomp$70$$,$m$jscomp$68$$,$n$jscomp$167$$,$o$jscomp$128$$,$p$jscomp$36$$,$q$jscomp$25$$,$r$jscomp$26$$,$s$jscomp$125$$){var $dispatch_val$jscomp$29$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$19$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$19$($a$jscomp$188$$,
$b$jscomp$156$$,$c$jscomp$132$$,$d$jscomp$98$$,$e$jscomp$122$$,$f$jscomp$326$$,$g$jscomp$78$$,$h$jscomp$90$$,$i$jscomp$283$$,$j$jscomp$82$$,$k$jscomp$224$$,$l$jscomp$70$$,$m$jscomp$68$$,$n$jscomp$167$$,$o$jscomp$128$$,$p$jscomp$36$$,$q$jscomp$25$$,$r$jscomp$26$$,$s$jscomp$125$$):this.$dispatch_fn$($a$jscomp$188$$,$b$jscomp$156$$,$c$jscomp$132$$,$d$jscomp$98$$,$e$jscomp$122$$,$f$jscomp$326$$,$g$jscomp$78$$,$h$jscomp$90$$,$i$jscomp$283$$,$j$jscomp$82$$,$k$jscomp$224$$,$l$jscomp$70$$,$m$jscomp$68$$,
$n$jscomp$167$$,$o$jscomp$128$$,$p$jscomp$36$$,$q$jscomp$25$$,$r$jscomp$26$$,$s$jscomp$125$$),$target_fn$jscomp$19$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$29$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$19$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$29$$);return $target_fn$jscomp$19$$.$cljs$core$IFn$_invoke$arity$19$?$target_fn$jscomp$19$$.$cljs$core$IFn$_invoke$arity$19$($a$jscomp$188$$,$b$jscomp$156$$,$c$jscomp$132$$,
$d$jscomp$98$$,$e$jscomp$122$$,$f$jscomp$326$$,$g$jscomp$78$$,$h$jscomp$90$$,$i$jscomp$283$$,$j$jscomp$82$$,$k$jscomp$224$$,$l$jscomp$70$$,$m$jscomp$68$$,$n$jscomp$167$$,$o$jscomp$128$$,$p$jscomp$36$$,$q$jscomp$25$$,$r$jscomp$26$$,$s$jscomp$125$$):$target_fn$jscomp$19$$($a$jscomp$188$$,$b$jscomp$156$$,$c$jscomp$132$$,$d$jscomp$98$$,$e$jscomp$122$$,$f$jscomp$326$$,$g$jscomp$78$$,$h$jscomp$90$$,$i$jscomp$283$$,$j$jscomp$82$$,$k$jscomp$224$$,$l$jscomp$70$$,$m$jscomp$68$$,$n$jscomp$167$$,$o$jscomp$128$$,
$p$jscomp$36$$,$q$jscomp$25$$,$r$jscomp$26$$,$s$jscomp$125$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$20$=function($a$jscomp$189$$,$b$jscomp$157$$,$c$jscomp$133$$,$d$jscomp$99$$,$e$jscomp$123$$,$f$jscomp$327$$,$g$jscomp$79$$,$h$jscomp$91$$,$i$jscomp$284$$,$j$jscomp$83$$,$k$jscomp$225$$,$l$jscomp$71$$,$m$jscomp$69$$,$n$jscomp$168$$,$o$jscomp$129$$,$p$jscomp$37$$,$q$jscomp$26$$,$r$jscomp$27$$,$s$jscomp$126$$,$t$jscomp$19$$){var $dispatch_val$jscomp$30$$=this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$20$?this.$dispatch_fn$.$cljs$core$IFn$_invoke$arity$20$($a$jscomp$189$$,
$b$jscomp$157$$,$c$jscomp$133$$,$d$jscomp$99$$,$e$jscomp$123$$,$f$jscomp$327$$,$g$jscomp$79$$,$h$jscomp$91$$,$i$jscomp$284$$,$j$jscomp$83$$,$k$jscomp$225$$,$l$jscomp$71$$,$m$jscomp$69$$,$n$jscomp$168$$,$o$jscomp$129$$,$p$jscomp$37$$,$q$jscomp$26$$,$r$jscomp$27$$,$s$jscomp$126$$,$t$jscomp$19$$):this.$dispatch_fn$($a$jscomp$189$$,$b$jscomp$157$$,$c$jscomp$133$$,$d$jscomp$99$$,$e$jscomp$123$$,$f$jscomp$327$$,$g$jscomp$79$$,$h$jscomp$91$$,$i$jscomp$284$$,$j$jscomp$83$$,$k$jscomp$225$$,$l$jscomp$71$$,
$m$jscomp$69$$,$n$jscomp$168$$,$o$jscomp$129$$,$p$jscomp$37$$,$q$jscomp$26$$,$r$jscomp$27$$,$s$jscomp$126$$,$t$jscomp$19$$),$target_fn$jscomp$20$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$30$$);$APP.$cljs$core$truth_$$($target_fn$jscomp$20$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$30$$);return $target_fn$jscomp$20$$.$cljs$core$IFn$_invoke$arity$20$?$target_fn$jscomp$20$$.$cljs$core$IFn$_invoke$arity$20$($a$jscomp$189$$,
$b$jscomp$157$$,$c$jscomp$133$$,$d$jscomp$99$$,$e$jscomp$123$$,$f$jscomp$327$$,$g$jscomp$79$$,$h$jscomp$91$$,$i$jscomp$284$$,$j$jscomp$83$$,$k$jscomp$225$$,$l$jscomp$71$$,$m$jscomp$69$$,$n$jscomp$168$$,$o$jscomp$129$$,$p$jscomp$37$$,$q$jscomp$26$$,$r$jscomp$27$$,$s$jscomp$126$$,$t$jscomp$19$$):$target_fn$jscomp$20$$($a$jscomp$189$$,$b$jscomp$157$$,$c$jscomp$133$$,$d$jscomp$99$$,$e$jscomp$123$$,$f$jscomp$327$$,$g$jscomp$79$$,$h$jscomp$91$$,$i$jscomp$284$$,$j$jscomp$83$$,$k$jscomp$225$$,$l$jscomp$71$$,
$m$jscomp$69$$,$n$jscomp$168$$,$o$jscomp$129$$,$p$jscomp$37$$,$q$jscomp$26$$,$r$jscomp$27$$,$s$jscomp$126$$,$t$jscomp$19$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$21$=function($a$jscomp$190$$,$b$jscomp$158$$,$c$jscomp$134$$,$d$jscomp$100$$,$e$jscomp$124$$,$f$jscomp$328$$,$g$jscomp$80$$,$h$jscomp$92$$,$i$jscomp$285$$,$j$jscomp$84$$,$k$jscomp$226$$,$l$jscomp$72$$,$m$jscomp$70$$,$n$jscomp$169$$,$o$jscomp$130$$,$p$jscomp$38$$,$q$jscomp$27$$,$r$jscomp$28$$,$s$jscomp$127$$,$t$jscomp$20$$,$rest$jscomp$10$$){var $dispatch_val$jscomp$31$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$(this.$dispatch_fn$,
$a$jscomp$190$$,$b$jscomp$158$$,$c$jscomp$134$$,$d$jscomp$100$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$e$jscomp$124$$,$f$jscomp$328$$,$g$jscomp$80$$,$h$jscomp$92$$,$i$jscomp$285$$,$j$jscomp$84$$,$k$jscomp$226$$,$l$jscomp$72$$,$m$jscomp$70$$,$n$jscomp$169$$,$o$jscomp$130$$,$p$jscomp$38$$,$q$jscomp$27$$,$r$jscomp$28$$,$s$jscomp$127$$,$t$jscomp$20$$,$rest$jscomp$10$$])),$target_fn$jscomp$21$$=$JSCompiler_StaticMethods_cljs$core$IMultiFn$_get_method$arity$2$$(this,$dispatch_val$jscomp$31$$);
$APP.$cljs$core$truth_$$($target_fn$jscomp$21$$)||$cljs$core$throw_no_method_error$$(this.name,$dispatch_val$jscomp$31$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$($target_fn$jscomp$21$$,$a$jscomp$190$$,$b$jscomp$158$$,$c$jscomp$134$$,$d$jscomp$100$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$e$jscomp$124$$,$f$jscomp$328$$,$g$jscomp$80$$,$h$jscomp$92$$,$i$jscomp$285$$,$j$jscomp$84$$,$k$jscomp$226$$,$l$jscomp$72$$,$m$jscomp$70$$,$n$jscomp$169$$,$o$jscomp$130$$,
$p$jscomp$38$$,$q$jscomp$27$$,$r$jscomp$28$$,$s$jscomp$127$$,$t$jscomp$20$$,$rest$jscomp$10$$]))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMultiFn$_methods$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.$method_table$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMultiFn$_add_method$arity$3$=function($mf$jscomp$46$$,$dispatch_val$jscomp$33$$,$method$jscomp$3$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$(this.$method_table$,$APP.$cljs$core$assoc$$,$dispatch_val$jscomp$33$$,$method$jscomp$3$$);$cljs$core$reset_cache$$(this.$method_cache$,this.$method_table$,this.$cached_hierarchy$,this.$hierarchy$);return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INamed$_name$arity$1$=function(){return $cljs$core$_name$$(this.name)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INamed$_namespace$arity$1$=function(){return $cljs$core$_namespace$$(this.name)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $goog$getUid$$(this)};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$UUID$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IUUID$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return this.uuid};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$115$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$115$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($_$jscomp$156_and__5023__auto__$jscomp$32$$,$other$jscomp$116$$){return($_$jscomp$156_and__5023__auto__$jscomp$32$$=$other$jscomp$116$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$other$jscomp$116$$.$cljs$core$IUUID$$?!0:!1:!1)?this.uuid===$other$jscomp$116$$.uuid:$_$jscomp$156_and__5023__auto__$jscomp$32$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($_$jscomp$157$$,$writer$jscomp$56$$){return $APP.$cljs$core$_write$$($writer$jscomp$56$$,['#uuid "',$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.uuid),'"'].join(""))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){this.$__hash$==null&&(this.$__hash$=$APP.$cljs$core$hash$$(this.uuid));return this.$__hash$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IComparable$_compare$arity$2$=function($this$$jscomp$128$$,$other$jscomp$117$$){if($other$jscomp$117$$ instanceof $cljs$core$UUID$$)return $module$contents$goog$array_defaultCompare$$(this.uuid,$other$jscomp$117$$.uuid);throw Error(["Cannot compare ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this)," to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$117$$)].join(""));};
$APP.$cljs$core$ExceptionInfo$$.prototype.__proto__=Error.prototype;$APP.$cljs$core$ExceptionInfo$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$cljs$core$ExceptionInfo$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($obj$jscomp$101$$,$writer$jscomp$58$$,$opts$jscomp$55$$){$APP.$cljs$core$_write$$($writer$jscomp$58$$,"#error {:message ");$APP.$cljs$core$pr_writer$$(this.message,$writer$jscomp$58$$,$opts$jscomp$55$$);$APP.$cljs$core$truth_$$(this.data)&&($APP.$cljs$core$_write$$($writer$jscomp$58$$,", :data "),$APP.$cljs$core$pr_writer$$(this.data,$writer$jscomp$58$$,$opts$jscomp$55$$));$APP.$cljs$core$truth_$$(this.cause)&&
($APP.$cljs$core$_write$$($writer$jscomp$58$$,", :cause "),$APP.$cljs$core$pr_writer$$(this.cause,$writer$jscomp$58$$,$opts$jscomp$55$$));return $APP.$cljs$core$_write$$($writer$jscomp$58$$,"}")};$APP.$cljs$core$ExceptionInfo$$.prototype.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};var $cljs$core$uuid_regex$$=/^[0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F]-[0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F]-[0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F]-[0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F]-[0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F]$/;
typeof console!=="undefined"&&$cljs$core$enable_console_print_BANG_$$();$cljs$core$enable_console_print_BANG_$$();var $cljs$cst$2459$app_DOT_main_DOT_router_SLASH_nav_back$$,$cljs$cst$5196$non_deleted_component_cannot_have_objects$$,$cljs$cst$2796$spreadMethod$$,$cljs$cst$5210$variant_component_bad_name$$,$cljs$cst$4405$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_remove_layout_track$$,$cljs$cst$4399$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_remove_shape_layout$$,$cljs$cst$1369$intra_block_nl$$,$cljs$cst$1450$exponentchar$$,$cljs$cst$4613$platforms$$,$cljs$cst$1992$sided_margins$$,
$cljs$cst$3339$app_DOT_main_DOT_data_DOT_websocket_SLASH_opened$$,$cljs$cst$3062$events_times$$,$cljs$cst$1317$with_meta$$,$cljs$cst$3652$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_toggle_visibility_selected$$,$cljs$cst$3631$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_start$$,$cljs$cst$697$nil_QMARK_$$,$cljs$cst$796$clojure_DOT_test_DOT_check_DOT_generators_SLASH_one_of$$,$cljs$cst$4351$unsubscribe_file$$,$cljs$cst$2075$radius_group$$,$cljs$cst$3368$invalid_paste_data$$,
$cljs$cst$3247$app_DOT_main_DOT_data_DOT_profile_SLASH_fetch_access_tokens$$,$cljs$cst$336$sci_DOT_core_SLASH_init$$,$cljs$cst$3235$file_comments_users$$,$cljs$cst$293$recursive$$,$cljs$cst$3818$child_width$$,$cljs$cst$2260$export_binfile$$,$cljs$cst$4990$on_remove_plugin$$,$cljs$cst$359$malli_DOT_core_SLASH_find$$,$cljs$cst$3472$app_DOT_main_DOT_data_DOT_comments_SLASH_update_filters$$,$cljs$cst$4836$move_unit_up$$,$cljs$cst$2575$components_v2$$,$cljs$cst$5190$nested_copy_not_allowed$$,$cljs$cst$2552$all_main_QMARK_$$,
$cljs$cst$3835$selection_rect_cache$$,$cljs$cst$2878$unicode$$,$cljs$cst$2979$is_fallback$$,$cljs$cst$4854$select_parent_layer$$,$cljs$cst$3085$thumbnail_QMARK_$$,$cljs$cst$3551$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_expand_subtree$$,$cljs$cst$906$float$$,$cljs$cst$1211$v2_migration$$,$cljs$cst$1507$if_let$$,$cljs$cst$5285$app_DOT_main_DOT_data_DOT_viewer_SLASH_open_overlay$$,$cljs$cst$976$cljs_DOT_spec_DOT_alpha_SLASH_name$$,$cljs$cst$3979$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_libraries_fetched$$,
$cljs$cst$3298$leave_team$$,$cljs$cst$4714$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_create_token_and_set$$,$cljs$cst$4397$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_create_layout_from_id$$,$cljs$cst$4629$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_fill$$,$cljs$cst$2784$repeatDur$$,$cljs$cst$3596$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_prev_shape$$,$cljs$cst$671$pos_QMARK_$$,$cljs$cst$1287$prop__GT_key$$,
$cljs$cst$3300$app_DOT_main_DOT_data_DOT_team_SLASH_create_invitations$$,$cljs$cst$4521$app_DOT_main_DOT_data_DOT_workspace_SLASH_fix_orphan_shapes$$,$cljs$cst$1435$remaining_arg_count$$,$cljs$cst$2987$ol_chiki$$,$cljs$cst$3063$wasm_viewbox$$,$cljs$cst$2967$non_blocking$$,$cljs$cst$4054$border_end_start_radius$$,$cljs$cst$3510$app_DOT_main_DOT_data_DOT_project_SLASH_fetch_project$$,$cljs$cst$770$returned$$,$cljs$cst$2866$specularConstant$$,$cljs$cst$3549$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_expand_collapse$$,
$cljs$cst$5096$valid_item_fn$$,$cljs$cst$3597$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_next_shape$$,$cljs$cst$645$explainer$$,$cljs$cst$4989$on_open_plugin$$,$cljs$cst$3493$otf_file_id$$,$cljs$cst$2917$stroke_linecap$$,$cljs$cst$2926$flood_color$$,$cljs$cst$2891$keySplines$$,$cljs$cst$110$ready$$,$cljs$cst$2608$set_comment_thread_position$$,$cljs$cst$1154$app_DOT_common_DOT_logging_SLASH_sync_QMARK_$$,$cljs$cst$2723$missing_glyph$$,$cljs$cst$385$malli_DOT_core_SLASH_nil$$,$cljs$cst$2816$underline_thickness$$,
$cljs$cst$4094$grid_auto_flow$$,$cljs$cst$2068$fill_group$$,$cljs$cst$3926$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_delete_component$$,$cljs$cst$4946$app_DOT_main_DOT_data_DOT_dashboard_SLASH_rename_project$$,$cljs$cst$3963$synced_at$$,$cljs$cst$3517$fill_values_QMARK_$$,$cljs$cst$3832$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_temporary_modifiers$$,$cljs$cst$1893$svg_viewbox$$,$cljs$cst$1801$add_children$$,$cljs$cst$344$int$$,$cljs$cst$2853$xlink_COLON_href$$,$cljs$cst$4190$click_draw_QMARK_$$,
$cljs$cst$2937$className$$,$cljs$cst$5181$ref_shape_is_not_head$$,$cljs$cst$5349$analyze_error$$,$cljs$cst$2786$kernelUnitLength$$,$cljs$cst$5321$skip_validate$$,$cljs$cst$181$param_tags$$,$cljs$cst$4885$modify_layers$$,$cljs$cst$4682$observable$$,$cljs$cst$3205$app_DOT_main_DOT_data_DOT_profile_SLASH_refresh_profile$$,$cljs$cst$3813$child_min_height$$,$cljs$cst$212$illegal_argument$$,$cljs$cst$2829$in2$$,$cljs$cst$1372$logical_block_callback$$,$cljs$cst$3530$force_frame_QMARK_$$,$cljs$cst$878$negated$$,
$cljs$cst$2989$osmanya$$,$cljs$cst$4145$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_stroke_color$$,$cljs$cst$865$malli_DOT_generator_SLASH_rec_gen$$,$cljs$cst$4226$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_setup_frame$$,$cljs$cst$3870$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_start_move_duplicate$$,$cljs$cst$4776$num_shapes$$,$cljs$cst$5197$invalid_text_touched$$,$cljs$cst$3934$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_detach_component$$,
$cljs$cst$3165$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_changes$$,$cljs$cst$3008$cherokee$$,$cljs$cst$1104$cljs_DOT_spec_DOT_alpha_SLASH_alt$$,$cljs$cst$3016$korean$$,$cljs$cst$2664$conflict$$,$cljs$cst$3469$app_DOT_main_DOT_data_DOT_comments_SLASH_open_comment_thread$$,$cljs$cst$5180$ref_shape_not_found$$,$cljs$cst$3543$saved_component_root_QMARK_$$,$cljs$cst$4375$cljs_DOT_core_SLASH_contains_QMARK_$$,$cljs$cst$3653$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_toggle_lock_selected$$,
$cljs$cst$2078$stroke_group$$,$cljs$cst$5177$component_main$$,$cljs$cst$4615$preprocessors$$,$cljs$cst$2717$glyphRef$$,$cljs$cst$779$NaN_QMARK_$$,$cljs$cst$2731$feImage$$,$cljs$cst$3274$member_id$$,$cljs$cst$3323$slug$$,$cljs$cst$3489$app_DOT_main_DOT_fonts_SLASH_woff2_file_id$$,$cljs$cst$2510$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_files$$,$cljs$cst$3565$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_append_undo$$,$cljs$cst$1892$no_flip$$,$cljs$cst$211$reader_error$$,$cljs$cst$3399$app_DOT_main_DOT_data_DOT_plugins_SLASH_remove_current_plugin$$,
$cljs$cst$4998$filter_mentions$$,$cljs$cst$642$keep$$,$cljs$cst$5380$account_without_password$$,$cljs$cst$3014$georgian$$,$cljs$cst$2760$x_height$$,$cljs$cst$2939$units$$,$cljs$cst$3836$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_wasm_modifiers$$,$cljs$cst$2147$app_DOT_main_DOT_data_DOT_changes_SLASH_commit$$,$cljs$cst$2130$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_value$$,$cljs$cst$563$input$$,$cljs$cst$3760$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_ungroup_selected$$,
$cljs$cst$1493$doseq$$,$cljs$cst$3746$selected_palette_colorpicker$$,$cljs$cst$5362$activation_code$$,$cljs$cst$4699$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_theme_active$$,$cljs$cst$4060$backdrop_filter$$,$cljs$cst$3199$app_DOT_main_DOT_data_DOT_profile_SLASH_profile_fetched$$,$cljs$cst$169$throw$$,$cljs$cst$5164$child_not_in_parent$$,$cljs$cst$690$indexed_QMARK_$$,$cljs$cst$3261$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_teams$$,$cljs$cst$1442$char_format$$,
$cljs$cst$1800$remove_children$$,$cljs$cst$953$app_DOT_common_DOT_schema_SLASH_set_of_keywords$$,$cljs$cst$3897$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_all$$,$cljs$cst$917$default_decoder$$,$cljs$cst$4442$number_of_combined$$,$cljs$cst$2595$show_modified$$,$cljs$cst$3619$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_duplicate_shapes$$,$cljs$cst$4347$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_initialize$$,$cljs$cst$3786$object_ids$$,$cljs$cst$3370$app_DOT_main_DOT_data_DOT_workspace_SLASH_reload_current_file$$,
$cljs$cst$3187$app_DOT_main_DOT_data_DOT_media_SLASH_blob_QMARK_$$,$cljs$cst$2933$visibility$$,$cljs$cst$523$malli_DOT_core_SLASH_invalid_dispatch_value$$,$cljs$cst$2837$units_per_em$$,$cljs$cst$1826$app_DOT_common_DOT_schema_DOT_openapi_SLASH_default$$,$cljs$cst$3542$saved_component_root$$,$cljs$cst$4801$zoom_lense_decrease$$,$cljs$cst$750$user$$,$cljs$cst$3070$bool_shapes$$,$cljs$cst$2567$team_feature_mismatch$$,$cljs$cst$815$clojure_DOT_test_DOT_check_DOT_generators_SLASH_keyword_ns$$,$cljs$cst$2890$v_alphabetic$$,
$cljs$cst$3479$yours$$,$cljs$cst$531$multi$$,$cljs$cst$654$preset$$,$cljs$cst$5168$invalid_parent$$,$cljs$cst$4266$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_select_for_drawing$$,$cljs$cst$4758$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_show_viewer_export_dialog$$,$cljs$cst$4583$error_DOT_token_SLASH_invalid_color$$,$cljs$cst$299$malli_DOT_core_SLASH_end_of_input$$,$cljs$cst$5387$accept_terms_and_privacy$$,$cljs$cst$2706$marker$$,$cljs$cst$2759$startOffset$$,$cljs$cst$3032$xlinkhref$$,
$cljs$cst$3837$undo_transation_QMARK_$$,$cljs$cst$1235$audit_log_logger$$,$cljs$cst$4400$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_create_shape_layout$$,$cljs$cst$5306$general_viewer$$,$cljs$cst$3045$anchor_offset$$,$cljs$cst$3529$new_variant_id$$,$cljs$cst$4844$select_prev$$,$cljs$cst$1074$gen_max$$,$cljs$cst$3046$focus_para$$,$cljs$cst$5271$app_DOT_main_DOT_data_DOT_viewer_SLASH_flash_done$$,$cljs$cst$3620$alt_duplication$$,$cljs$cst$632$re_unparser$$,$cljs$cst$4118$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_html_text$$,
$cljs$cst$3335$app_DOT_main_DOT_data_DOT_websocket_SLASH_initialize$$,$cljs$cst$2615$fix_obj$$,$cljs$cst$3012$hebrew$$,$cljs$cst$923$json$$,$cljs$cst$5369$only_owner_can_delete_team$$,$cljs$cst$2670$pre_context_lost_read_only_QMARK_$$,$cljs$cst$1101$cljs_DOT_spec_DOT_alpha_SLASH_cat$$,$cljs$cst$4369$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_update_page_root$$,$cljs$cst$4852$move_fast_right$$,$cljs$cst$1157$app_DOT_common_DOT_logging_SLASH_id$$,$cljs$cst$1995$italic_QMARK_$$,$cljs$cst$4187$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_common_SLASH_clear_drawing$$,
$cljs$cst$4596$error_DOT_style_dictionary_SLASH_invalid_token_value_stroke_width$$,$cljs$cst$2894$xlink_COLON_role$$,$cljs$cst$4491$app_DOT_main_DOT_data_DOT_workspace_SLASH_toggle_proportion_lock$$,$cljs$cst$4116$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_transit_props$$,$cljs$cst$4957$app_DOT_main_DOT_data_DOT_dashboard_SLASH_file_created$$,$cljs$cst$4768$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_update_export_status$$,$cljs$cst$2841$viewTarget$$,$cljs$cst$3068$selection_center$$,
$cljs$cst$2751$foreignObject$$,$cljs$cst$2852$slope$$,$cljs$cst$3337$ws_conn$$,$cljs$cst$593$malli_DOT_core_SLASH_function_checker$$,$cljs$cst$4479$app_DOT_main_DOT_data_DOT_workspace_SLASH_delete_selected$$,$cljs$cst$2600$set_touched$$,$cljs$cst$2893$xml_COLON_base$$,$cljs$cst$2648$set_active_token_themes$$,$cljs$cst$5250$app_DOT_main_DOT_data_DOT_viewer_SLASH_update_zoom_querystring$$,$cljs$cst$5353$analyze$$,$cljs$cst$1846$maxLength$$,$cljs$cst$4$print_length$$,$cljs$cst$2932$color_interpolation$$,
$cljs$cst$391$keys$$,$cljs$cst$3019$mongolian$$,$cljs$cst$858$gen_SLASH_NaN_QMARK_$$,$cljs$cst$2646$set_token_set$$,$cljs$cst$3688$lowercase$$,$cljs$cst$4898$levels$$,$cljs$cst$1103$cljs_DOT_spec_DOT_alpha_SLASH__QMARK_$$,$cljs$cst$1099$cljs_DOT_spec_DOT_alpha_SLASH__AMPERSAND_$$,$cljs$cst$3965$update_file_library_sync_status$$,$cljs$cst$3371$snapshot_is_locked$$,$cljs$cst$1345$edge$$,$cljs$cst$1094$cljs_DOT_spec_DOT_alpha_SLASH__STAR_$$,$cljs$cst$1100$cljs_DOT_spec_DOT_alpha_SLASH__PLUS_$$,$cljs$cst$5228$go_to_search$$,
$cljs$cst$2562$feature_not_supported$$,$cljs$cst$4334$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_update_mcp_status$$,$cljs$cst$346$arity$$,$cljs$cst$1420$radix$$,$cljs$cst$674$double_QMARK_$$,$cljs$cst$1320$first$$,$cljs$cst$2167$up_mouse_QMARK_$$,$cljs$cst$5333$markup$$,$cljs$cst$4079$root_shapes$$,$cljs$cst$1226$backend_worker$$,$cljs$cst$4201$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_streams_SLASH_empty$$,$cljs$cst$146$clojure_DOT_error_SLASH_phase$$,$cljs$cst$3321$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_shared_files$$,
$cljs$cst$1184$smtp$$,$cljs$cst$2565$file_in_components_v1$$,$cljs$cst$2302$device_arch$$,$cljs$cst$3806$margin_y$$,$cljs$cst$3805$margin_x$$,$cljs$cst$3358$logout$$,$cljs$cst$1220$inspect_styles$$,$cljs$cst$3027$armenian$$,$cljs$cst$3583$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_zoom_to_fit_all$$,$cljs$cst$2805$strikethrough_position$$,$cljs$cst$2920$alignment_baseline$$,$cljs$cst$3100$lose_browser_context_QMARK_$$,$cljs$cst$5005$insert_at_symbol$$,$cljs$cst$2818$maskUnits$$,$cljs$cst$2621$mod_page$$,
$cljs$cst$4040$new_shape_QMARK_$$,$cljs$cst$742$sub_delims$$,$cljs$cst$2927$unicode_bidi$$,$cljs$cst$163$recur$$,$cljs$cst$4620$font_size_value$$,$cljs$cst$4230$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_start_draw_mode_STAR_$$,$cljs$cst$688$inst_QMARK_$$,$cljs$cst$4763$resource_id$$,$cljs$cst$2895$stemh$$,$cljs$cst$4268$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_start_drawing$$,$cljs$cst$2787$stemv$$,$cljs$cst$4683$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_propagation_SLASH_propagate_workspace_tokens$$,
$cljs$cst$283$cljs_DOT_core_SLASH_unquote$$,$cljs$cst$2701$feTurbulence$$,$cljs$cst$1504$defn_$$,$cljs$cst$3679$mixBlendMode$$,$cljs$cst$2769$textLength$$,$cljs$cst$3041$gradient_transform$$,$cljs$cst$5272$app_DOT_main_DOT_data_DOT_viewer_SLASH_set_nav_scroll$$,$cljs$cst$3690$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_image_uploaded$$,$cljs$cst$2990$shavian$$,$cljs$cst$3084$base_objects$$,$cljs$cst$112$cljs_DOT_core_SLASH_halt$$,$cljs$cst$4945$update_project_pin$$,$cljs$cst$4358$disconnect$$,
$cljs$cst$2153$native_event$$,$cljs$cst$4702$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_update_token_set$$,$cljs$cst$2519$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_fonts$$,$cljs$cst$5208$variant_bad_name$$,$cljs$cst$2351$bottom_actions$$,$cljs$cst$937$decode_SLASH_string$$,$cljs$cst$152$ns_STAR_$$,$cljs$cst$3920$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_component2$$,$cljs$cst$3473$app_DOT_main_DOT_data_DOT_comments_SLASH_update_options$$,$cljs$cst$2295$device_type$$,
$cljs$cst$693$list_QMARK_$$,$cljs$cst$4555$data_testid$$,$cljs$cst$2673$app_DOT_main_DOT_data_DOT_render_wasm_SLASH_context_restored$$,$cljs$cst$980$cljs_DOT_spec_DOT_alpha_SLASH_gfn$$,$cljs$cst$1232$nrepl_server$$,$cljs$cst$3037$stopOpacity$$,$cljs$cst$1456$else_params$$,$cljs$cst$4250$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_apply_content_modifiers$$,$cljs$cst$2859$filterRes$$,$cljs$cst$1217$audit_log_archive$$,$cljs$cst$5192$not_head_copy_not_allowed$$,$cljs$cst$3369$vern_conflict$$,
$cljs$cst$694$seq_QMARK_$$,$cljs$cst$1878$radius_4$$,$cljs$cst$1877$radius_1$$,$cljs$cst$1358$webworker$$,$cljs$cst$149$case_STAR_$$,$cljs$cst$4770$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_request_simple_export$$,$cljs$cst$400$properties$$,$cljs$cst$2737$feSpecularLighting$$,$cljs$cst$3015$tifinagh$$,$cljs$cst$2597$only$$,$cljs$cst$3918$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_delete_typography$$,$cljs$cst$4217$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_drag_handler$$,
$cljs$cst$3275$app_DOT_main_DOT_data_DOT_team_SLASH_update_member_role$$,$cljs$cst$3463$app_DOT_main_DOT_data_DOT_comments_SLASH_retrieve_unread_comment_threads$$,$cljs$cst$5138$owner_cant_leave_team$$,$cljs$cst$3013$lao$$,$cljs$cst$3894$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_event$$,$cljs$cst$2718$feFlood$$,$cljs$cst$3968$ignore_file_library_sync_status$$,$cljs$cst$2973$family_id_buffer$$,$cljs$cst$4294$app_DOT_main_DOT_data_DOT_workspace_DOT_highlight_SLASH_highlight_shape$$,
$cljs$cst$199$strable$$,$cljs$cst$384$decode$$,$cljs$cst$3403$close_only_edition_plugins_QMARK_$$,$cljs$cst$1126$p1__34846_SHARP_$$,$cljs$cst$4085$grid_column$$,$cljs$cst$5354$analyze_import$$,$cljs$cst$4278$update_comment_thread_position$$,$cljs$cst$4260$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_start_path_edit$$,$cljs$cst$696$set_QMARK_$$,$cljs$cst$1843$additionalItems$$,$cljs$cst$1437$mincol$$,$cljs$cst$5057$app_DOT_main_DOT_data_DOT_nitrate_SLASH_show_nitrate_popup$$,$cljs$cst$3176$ignore_geometry_QMARK_$$,
$cljs$cst$5205$invalid_variant_properties$$,$cljs$cst$164$set_BANG_$$,$cljs$cst$2148$app_DOT_main_DOT_store_SLASH_ongoing_tasks$$,$cljs$cst$2728$glyph$$,$cljs$cst$2951$app_DOT_main_DOT_data_DOT_shortcuts_SLASH_pop_shortcuts$$,$cljs$cst$3632$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer$$,$cljs$cst$3017$myanmar$$,$cljs$cst$2858$operator$$,$cljs$cst$5001$insert_next_mention$$,$cljs$cst$1560$scroll_top$$,$cljs$cst$4827$move_fast_down$$,$cljs$cst$420$float$$,$cljs$cst$3741$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_textpalette_QMARK_$$,
$cljs$cst$741$unreserved$$,$cljs$cst$2911$stroke_linejoin$$,$cljs$cst$3576$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_assure_valid_current_page$$,$cljs$cst$1121$p1__34845_SHARP_$$,$cljs$cst$4018$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_start_edit_if_selected$$,$cljs$cst$4422$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_update_properties_names_and_values$$,$cljs$cst$720$sequential$$,$cljs$cst$5301$toggle_fullscreen$$,$cljs$cst$2257$app_DOT_util_DOT_sse_SLASH_clone_template$$,
$cljs$cst$872$malli_DOT_generator_SLASH_no_generator$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$,$cljs$cst$4336$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_disconnect$$,$cljs$cst$1253$enable_backend_api_doc$$,$cljs$cst$3761$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_mask_group$$,$cljs$cst$2699$feConvolveMatrix$$,$cljs$cst$731$merge_required$$,$cljs$cst$2292$engine_version$$,$cljs$cst$1988$min_height$$,$cljs$cst$3320$app_DOT_main_DOT_data_DOT_team_SLASH_shared_files_fetched$$,
$cljs$cst$3052$disable_thumbnail_cache$$,$cljs$cst$2862$xChannelSelector$$,$cljs$cst$1302$map_builder$$,$cljs$cst$3242$app_DOT_main_DOT_data_DOT_profile_SLASH_request_profile_recovery$$,$cljs$cst$2897$text_rendering$$,$cljs$cst$4362$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_file_restored$$,$cljs$cst$5325$rgba$$,$cljs$cst$814$clojure_DOT_test_DOT_check_DOT_generators_SLASH_keyword$$,$cljs$cst$3004$vietnamese$$,$cljs$cst$3887$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_flip_vertical_selected$$,
$cljs$cst$2256$unable_to_process_repository_response$$,$cljs$cst$2578$has_media_trimmed$$,$cljs$cst$4769$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_request_simple_export_wasm$$,$cljs$cst$2660$media_refs$$,$cljs$cst$3374$snapshot_already_locked$$,$cljs$cst$1827$exclusiveMinimum$$,$cljs$cst$833$max_size$$,$cljs$cst$1046$distinct_QMARK_$$,$cljs$cst$1171$login_with_custom_sso$$,$cljs$cst$5162$invalid_geometry$$,$cljs$cst$4562$data_direction$$,$cljs$cst$3611$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_clear_memorize_duplicated$$,
$cljs$cst$2521$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_recent$$,$cljs$cst$1554$on_event$$,$cljs$cst$5216$copy_nested$$,$cljs$cst$4717$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_update_token$$,$cljs$cst$2791$edgeMode$$,$cljs$cst$3738$app_DOT_main_DOT_data_DOT_workspace_SLASH_hide_palettes_QMARK_$$,$cljs$cst$1855$next_p$$,$cljs$cst$4368$index_SLASH_initialize$$,$cljs$cst$1274$patch$$,$cljs$cst$3476$app_DOT_main_DOT_data_DOT_comments_SLASH_toggle_comment_options$$,
$cljs$cst$1831$allOf$$,$cljs$cst$3791$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_clear_thumbnail$$,$cljs$cst$3745$app_DOT_main_DOT_data_DOT_workspace_SLASH_selected_palette$$,$cljs$cst$2944$wrapper_styles$$,$cljs$cst$3967$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_ignore_sync$$,$cljs$cst$4096$paragraph_set$$,$cljs$cst$367$malli_DOT_core_SLASH_invalid_entry$$,$cljs$cst$4104$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_from_clipboard$$,$cljs$cst$719$seqable$$,
$cljs$cst$1820$prev$$,$cljs$cst$1455$right_params$$,$cljs$cst$2857$additive$$,$cljs$cst$2140$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_pointer_update$$,$cljs$cst$1258$enable_onboarding$$,$cljs$cst$1830$maximum$$,$cljs$cst$3675$strokeWidth$$,$cljs$cst$5397$app_DOT_main_DOT_ui_DOT_viewer_DOT_interactions_SLASH_fixed$$,$cljs$cst$2834$azimuth$$,$cljs$cst$2738$font_face_format$$,$cljs$cst$1428$func$$,$cljs$cst$4480$app_DOT_main_DOT_data_DOT_workspace_SLASH_start_rename_selected$$,
$cljs$cst$2879$bias$$,$cljs$cst$1580$headers$$,$cljs$cst$1202$backend_api_doc$$,$cljs$cst$4948$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_project$$,$cljs$cst$1238$tiered_file_data_storage$$,$cljs$cst$825$clojure_DOT_test_DOT_check_DOT_generators_SLASH_uuid$$,$cljs$cst$1859$next_i$$,$cljs$cst$1860$next_c$$,$cljs$cst$3883$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_move_shapes_to_frame$$,$cljs$cst$4697$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_update_token_theme$$,
$cljs$cst$4742$max_length$$,$cljs$cst$2636$restore_component$$,$cljs$cst$3676$strokeColor$$,$cljs$cst$4370$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_create_page$$,$cljs$cst$407$type$$,$cljs$cst$3891$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_commit$$,$cljs$cst$4339$mcp_SLASH_force_disconect$$,$cljs$cst$969$app_DOT_common_DOT_schema_SLASH_word_string$$,$cljs$cst$1228$rpc_climit$$,$cljs$cst$2905$clip$$,$cljs$cst$1031$cljs_DOT_core_SLASH_vector_QMARK_$$,
$cljs$cst$1847$app_DOT_common_DOT_schema_DOT_openapi_SLASH_definitions_path$$,$cljs$cst$1889$invalid_path_content$$,$cljs$cst$4076$string_or_size_array$$,$cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$,$cljs$cst$1391$logical_block$$,$cljs$cst$3980$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_load_library_file$$,$cljs$cst$2460$app_DOT_main_DOT_router_SLASH_nav_root$$,$cljs$cst$4475$app_DOT_main_DOT_data_DOT_workspace_SLASH_start_rename_shape$$,$cljs$cst$5259$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_fullscreen$$,
$cljs$cst$2881$v_ideographic$$,$cljs$cst$786$clojure_DOT_test_DOT_check_DOT_generators_SLASH_list$$,$cljs$cst$4448$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_update_viewport_position_center$$,$cljs$cst$2695$feBlend$$,$cljs$cst$5358$on_hide_comments$$,$cljs$cst$5003$mention_filter$$,$cljs$cst$3572$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_restore_selection$$,$cljs$cst$2616$mov_objects$$,$cljs$cst$5403$toggle_thumbnails$$,$cljs$cst$4890$zoom_workspace$$,$cljs$cst$2166$blur_QMARK_$$,
$cljs$cst$1965$app_DOT_common_DOT_types_DOT_shape_DOT_interactions_SLASH_animation$$,$cljs$cst$2877$xlink_COLON_title$$,$cljs$cst$2079$visibility_group$$,$cljs$cst$2725$tspan$$,$cljs$cst$3642$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_add_shape$$,$cljs$cst$1304$prefer_strings$$,$cljs$cst$1148$parallelism$$,$cljs$cst$4650$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_spacing_token_separated$$,$cljs$cst$698$false_QMARK_$$,$cljs$cst$2525$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_invitations$$,
$cljs$cst$3704$unable_to_optimize$$,$cljs$cst$5031$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_initialize_version$$,$cljs$cst$2639$mod_typography$$,$cljs$cst$1779$structure_parent$$,$cljs$cst$3997$entityRanges$$,$cljs$cst$1229$auto_file_snapshot$$,$cljs$cst$250$readers$$,$cljs$cst$168$catch$$,$cljs$cst$701$coll_QMARK_$$,$cljs$cst$3398$open_plugins$$,$cljs$cst$2734$font_face_src$$,$cljs$cst$3882$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_position_shapes$$,$cljs$cst$3494$app_DOT_main_DOT_data_DOT_fonts_SLASH_fonts_loaded$$,
$cljs$cst$1072$max_count$$,$cljs$cst$1862$close$$,$cljs$cst$3703$media_max_file_size_reached$$,$cljs$cst$2980$emoji_QMARK_$$,$cljs$cst$2712$font_face$$,$cljs$cst$2093$dest_objects$$,$cljs$cst$2254$authorization$$,$cljs$cst$1361$data_uri$$,$cljs$cst$615$__GT_$$,$cljs$cst$1382$start_pos$$,$cljs$cst$4213$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_start_path_undo$$,$cljs$cst$1319$trailing$$,$cljs$cst$565$guard$$,$cljs$cst$949$app_DOT_common_DOT_schema_DOT_openapi_SLASH_items$$,$cljs$cst$4063$border_start_end_radius$$,
$cljs$cst$3768$shape_name$$,$cljs$cst$2810$orientation$$,$cljs$cst$4110$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_props$$,$cljs$cst$2554$descendants_variant_ids_set$$,$cljs$cst$363$entries$$,$cljs$cst$1248$enable_login_with_password$$,$cljs$cst$1469$generator_fn$$,$cljs$cst$866$malli_DOT_generator_SLASH_default$$,$cljs$cst$1589$json_verbose$$,$cljs$cst$2095$clojure_DOT_core_DOT_protocols_SLASH_datafy$$,$cljs$cst$5322$debug_SLASH_set_shape_ref$$,$cljs$cst$3975$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_watch_component_changes$$,
$cljs$cst$773$max_tries$$,$cljs$cst$2682$custom$$,$cljs$cst$4435$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_add_new_variant$$,$cljs$cst$740$pchar$$,$cljs$cst$2144$app_DOT_main_DOT_data_DOT_workspace_DOT_persistence_SLASH_update_persistence_status$$,$cljs$cst$4800$toggle_layers$$,$cljs$cst$1354$macos$$,$cljs$cst$2814$yChannelSelector$$,$cljs$cst$2592$container_id$$,$cljs$cst$1151$app_DOT_common_DOT_logging_SLASH_body$$,$cljs$cst$4766$resource_uri$$,$cljs$cst$2783$amplitude$$,$cljs$cst$1448$overflowchar$$,
$cljs$cst$1457$min_remaining$$,$cljs$cst$3202$get_subscription_usage$$,$cljs$cst$4425$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_update_property_name$$,$cljs$cst$3238$get_profiles_for_file_comments$$,$cljs$cst$3797$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_watch_state_changes$$,$cljs$cst$2865$mathematical$$,$cljs$cst$2861$keyPoints$$,$cljs$cst$2836$xmlns_COLON_xlink$$,$cljs$cst$764$into$$,$cljs$cst$3258$organization_slug$$,$cljs$cst$664$some_QMARK_$$,$cljs$cst$3956$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_component_thumbnail$$,
$cljs$cst$379$malli_DOT_core_SLASH_default$$,$cljs$cst$2982$oriya$$,$cljs$cst$3541$inst$$,$cljs$cst$4279$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_set_zoom_to_separate_grouped_bubbles$$,$cljs$cst$4098$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_images$$,$cljs$cst$3024$brahmi$$,$cljs$cst$552$malli_DOT_core_SLASH_walk_schema_refs$$,$cljs$cst$2667$operation_not_implemented$$,$cljs$cst$3681$sodipodi_COLON_label$$,$cljs$cst$2617$after_shape$$,$cljs$cst$490$parse$$,$cljs$cst$2668$_component_id$$,
$cljs$cst$415$type_properties$$,$cljs$cst$265$linked_SLASH_set$$,$cljs$cst$823$clojure_DOT_test_DOT_check_DOT_generators_SLASH_symbol$$,$cljs$cst$1849$app_DOT_common_DOT_openapi$$,$cljs$cst$2631$add_component$$,$cljs$cst$666$integer_QMARK_$$,$cljs$cst$737$select_keys$$,$cljs$cst$562$_EQ__GT_$$,$cljs$cst$2288$app_DOT_util_DOT_i18n_SLASH_locale$$,$cljs$cst$708$_GT__EQ_$$,$cljs$cst$3365$app_DOT_main_DOT_errors_SLASH_trace$$,$cljs$cst$826$complete$$,$cljs$cst$3792$delete_file_object_thumbnail$$,$cljs$cst$3800$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_wasm_SLASH_persist_thumbnail$$,
$cljs$cst$3468$threads$$,$cljs$cst$4322$app_DOT_main_DOT_data_DOT_workspace_DOT_layers_SLASH_pressed_opacity$$,$cljs$cst$1195$google_fonts_provider$$,$cljs$cst$710$_LT__EQ_$$,$cljs$cst$1146$same_thread$$,$cljs$cst$2915$stop_opacity$$,$cljs$cst$3066$wasm_gl_context_init_error$$,$cljs$cst$3921$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_component$$,$cljs$cst$2693$radialGradient$$,$cljs$cst$2123$active_themes$$,$cljs$cst$4066$max_inline_size$$,$cljs$cst$4328$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_connect$$,
$cljs$cst$564$output$$,$cljs$cst$393$malli_DOT_core_SLASH_coll_check_limit$$,$cljs$cst$4588$error_DOT_style_dictionary_SLASH_composite_line_height_needs_font_size$$,$cljs$cst$3457$app_DOT_main_DOT_data_DOT_comments_SLASH_refresh_comment_thread$$,$cljs$cst$2746$font_face_name$$,$cljs$cst$4121$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_image$$,$cljs$cst$197$nil$$,$cljs$cst$4458$app_DOT_main_DOT_data_DOT_workspace_SLASH_library_resolved$$,$cljs$cst$4606$warning_DOT_style_dictionary_SLASH_invalid_referenced_token_value_opacity$$,
$cljs$cst$4434$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_resposition_and_resize_variant$$,$cljs$cst$4099$images$$,$cljs$cst$2771$elevation$$,$cljs$cst$3916$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_typography$$,$cljs$cst$1194$soft_file_schema_validation$$,$cljs$cst$1844$pattern$$,$cljs$cst$677$ident_QMARK_$$,$cljs$cst$1384$trailing_white_space$$,$cljs$cst$5377$ldap_not_initialized$$,$cljs$cst$4100$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected$$,
$cljs$cst$2804$contentScriptType$$,$cljs$cst$5340$panel$$,$cljs$cst$4886$tools$$,$cljs$cst$5318$path_editor$$,$cljs$cst$704$ifn_QMARK_$$,$cljs$cst$2570$paste_feature_not_enabled$$,$cljs$cst$685$qualified_symbol_QMARK_$$,$cljs$cst$1401$current$$,$cljs$cst$1506$__GT_$$,$cljs$cst$752$port$$,$cljs$cst$1488$_DOT__DOT_$$,$cljs$cst$361$children$$,$cljs$cst$4069$margin_inline_start$$,$cljs$cst$207$ex_kind$$,$cljs$cst$4147$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_shadow$$,$cljs$cst$5156$error_code$$,
$cljs$cst$4364$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_select_frame_tool$$,$cljs$cst$2968$panic$$,$cljs$cst$5058$app_DOT_main_DOT_data_DOT_nitrate_SLASH_get_nitrate_connectivity$$,$cljs$cst$5104$default_member_id$$,$cljs$cst$4807$toggle_lock_size$$,$cljs$cst$596$malli_DOT_core_SLASH_invalid_input_schema$$,$cljs$cst$1079$cljs_DOT_spec_DOT_alpha_SLASH_kfn$$,$cljs$cst$2892$overline_thickness$$,$cljs$cst$1306$prefer_buffers$$,$cljs$cst$2251$attempt$$,$cljs$cst$1370$per_line_prefix$$,$cljs$cst$4607$warning_SLASH_code$$,
$cljs$cst$1107$cljs_DOT_core_SLASH_nil_QMARK_$$,$cljs$cst$5185$cycles_ids$$,$cljs$cst$3297$app_DOT_main_DOT_data_DOT_team_SLASH_leave_current_team$$,$cljs$cst$1837$maxProperties$$,$cljs$cst$1234$render_wasm_dpr$$,$cljs$cst$672$neg_QMARK_$$,$cljs$cst$3940$update_layout_QMARK_$$,$cljs$cst$5095$select_class$$,$cljs$cst$3562$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_materialize_undo$$,$cljs$cst$3343$auth_backend$$,$cljs$cst$2082$shadow_group$$,$cljs$cst$3193$media_type_not_allowed$$,$cljs$cst$2935$marker_end$$,
$cljs$cst$3348$provider$$,$cljs$cst$341$properties$$,$cljs$cst$3614$id_original$$,$cljs$cst$3561$selected_after$$,$cljs$cst$5097$caution_item_fn$$,$cljs$cst$4538$app_DOT_main_DOT_data_DOT_workspace_SLASH_close_layers_search$$,$cljs$cst$2560$app_DOT_common_DOT_features_SLASH_features$$,$cljs$cst$3423$owner_email$$,$cljs$cst$3599$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_shift_select_shapes$$,$cljs$cst$3213$cancel_email_change$$,$cljs$cst$1153$app_DOT_common_DOT_logging_SLASH_context$$,
$cljs$cst$950$app_DOT_common_DOT_schema_DOT_openapi_SLASH_unique_items$$,$cljs$cst$3020$syriac$$,$cljs$cst$4681$atom$$,$cljs$cst$3396$app_DOT_main_DOT_data_DOT_plugins_SLASH_save_plugin_permissions_peek$$,$cljs$cst$4207$undo_stack$$,$cljs$cst$147$phase$$,$cljs$cst$1486$when_first$$,$cljs$cst$3923$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_rename_component$$,$cljs$cst$765$lambdaisland_SLASH_uri$$,$cljs$cst$4803$toggle_assets$$,$cljs$cst$3601$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_all$$,
$cljs$cst$3826$wasm_props$$,$cljs$cst$1264$enable_token_shadow$$,$cljs$cst$1073$cljs_DOT_spec_DOT_alpha_SLASH_kind_form$$,$cljs$cst$4283$comment_id$$,$cljs$cst$2961$subscr$$,$cljs$cst$4211$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_end_path_undo$$,$cljs$cst$4200$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_clear_edition_mode$$,$cljs$cst$861$vector_min$$,$cljs$cst$4536$app_DOT_main_DOT_data_DOT_workspace_SLASH_open_layers_search$$,$cljs$cst$4103$replace_QMARK_$$,$cljs$cst$4888$navigation_workspace$$,
$cljs$cst$1468$bracket_info$$,$cljs$cst$4193$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_insert_point$$,$cljs$cst$4138$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_fill$$,$cljs$cst$4592$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_type$$,$cljs$cst$3735$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_toggle_layout_flag$$,$cljs$cst$3637$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_event$$,$cljs$cst$1078$distinct$$,$cljs$cst$3144$selected_before$$,
$cljs$cst$691$map_QMARK_$$,$cljs$cst$2690$clipPath$$,$cljs$cst$1555$validate_fn$$,$cljs$cst$1492$struct$$,$cljs$cst$3908$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_rename_color$$,$cljs$cst$5257$app_DOT_main_DOT_data_DOT_viewer_SLASH_zoom_to_fill$$,$cljs$cst$2781$refY$$,$cljs$cst$4463$app_DOT_main_DOT_data_DOT_workspace_SLASH_zoom_to_frame$$,$cljs$cst$2886$refX$$,$cljs$cst$1771$text_cb$$,$cljs$cst$3243$request_profile_recovery$$,$cljs$cst$4045$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_v2_update_text_shape_content$$,
$cljs$cst$5336$hover_shape$$,$cljs$cst$4516$app_DOT_main_DOT_data_DOT_workspace_SLASH_change_canvas_color$$,$cljs$cst$772$ex_fn$$,$cljs$cst$2802$clipPathUnits$$,$cljs$cst$4349$subscribe_file$$,$cljs$cst$1137$integrant_DOT_core_SLASH_build_failed_spec$$,$cljs$cst$3471$show$$,$cljs$cst$4402$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_layout$$,$cljs$cst$4643$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_spacing_token$$,$cljs$cst$3028$meroitic$$,$cljs$cst$2151$mod$$,
$cljs$cst$5169$frame_not_found$$,$cljs$cst$4329$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_handle_pong$$,$cljs$cst$286$reserve_chars$$,$cljs$cst$1491$loop$$,$cljs$cst$3188$app_DOT_main_DOT_data_DOT_media_SLASH_blobs$$,$cljs$cst$5160$_type$$,$cljs$cst$2635$skip_undelete_QMARK_$$,$cljs$cst$1622$remove_blocked$$,$cljs$cst$451$malli_DOT_core_SLASH_missing_key$$,$cljs$cst$1458$max_columns$$,$cljs$cst$3944$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_library_thumbnails_fetched$$,$cljs$cst$2856$keyTimes$$,
$cljs$cst$5378$admin_only_profile$$,$cljs$cst$3687$normalize$$,$cljs$cst$365$order$$,$cljs$cst$648$encode$$,$cljs$cst$952$app_DOT_common_DOT_schema_SLASH_set_of_strings$$,$cljs$cst$3942$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_go_to_local_component$$,$cljs$cst$777$max_elements$$,$cljs$cst$3566$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_start_undo_transaction$$,$cljs$cst$1465$colnum$$,$cljs$cst$4059$grid_template_rows$$,$cljs$cst$734$malli_DOT_util_SLASH_reducing_children_must_be_non_empty$$,
$cljs$cst$3961$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_set_updating_library$$,$cljs$cst$2745$altGlyphItem$$,$cljs$cst$368$entry$$,$cljs$cst$1825$geom$$,$cljs$cst$2953$timer$$,$cljs$cst$1088$rep_PLUS_$$,$cljs$cst$3342$app_DOT_main_DOT_data_DOT_auth_SLASH_logged_in$$,$cljs$cst$700$zero_QMARK_$$,$cljs$cst$4426$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_update_property_value$$,$cljs$cst$5381$get_sso_provider$$,$cljs$cst$5304$open_workspace$$,$cljs$cst$2580$app_DOT_common_DOT_types_DOT_file_SLASH_data$$,
$cljs$cst$2977$style_name$$,$cljs$cst$4325$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_set_mcp_active$$,$cljs$cst$1848$app_DOT_common_DOT_schema_DOT_openapi_SLASH_embed$$,$cljs$cst$4195$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_finish_drawing$$,$cljs$cst$5328$viewer_libraries$$,$cljs$cst$3464$current_team_comments_users$$,$cljs$cst$2523$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_members$$,$cljs$cst$3871$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_set_ghost_displacement$$,
$cljs$cst$5170$invalid_frame$$,$cljs$cst$3702$invalid_image$$,$cljs$cst$4940$app_DOT_main_DOT_data_DOT_dashboard_SLASH_duplicate_project$$,$cljs$cst$2072$layer_effects_group$$,$cljs$cst$3654$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_toggle_file_thumbnail_selected$$,$cljs$cst$4343$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_init$$,$cljs$cst$1426$rest$$,$cljs$cst$3352$resp$$,$cljs$cst$2888$attributeName$$,$cljs$cst$4308$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_update_interaction$$,
$cljs$cst$3444$update_comment_thread_status$$,$cljs$cst$3099$viewport_interest_area_threshold$$,$cljs$cst$3845$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_delta_rotation_modifiers$$,$cljs$cst$4218$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_finish_drag$$,$cljs$cst$3492$app_DOT_main_DOT_fonts_SLASH_otf_file_id$$,$cljs$cst$4988$user_can_edit$$,$cljs$cst$5103$field_name$$,$cljs$cst$5006$h_dir$$,$cljs$cst$4558$on_pointer_leave_option$$,$cljs$cst$4858$move_fast_left$$,
$cljs$cst$4256$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_finish_move_selected$$,$cljs$cst$2798$preserveAspectRatio$$,$cljs$cst$628$child_bounds$$,$cljs$cst$824$clojure_DOT_test_DOT_check_DOT_generators_SLASH_symbol_ns$$,$cljs$cst$5226$navigation_dashboard$$,$cljs$cst$4013$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_root_attrs$$,$cljs$cst$3135$ignore_wasm_QMARK_$$,$cljs$cst$3810$line_max_height$$,$cljs$cst$5376$profile_blocked$$,$cljs$cst$3645$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_delete_shapes$$,
$cljs$cst$2680$app_DOT_main_DOT_fonts_SLASH_on_loaded$$,$cljs$cst$161$js_STAR_$$,$cljs$cst$1774$text_content_text$$,$cljs$cst$4050$padding_inline_end$$,$cljs$cst$3955$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_launch_component_sync$$,$cljs$cst$1393$nl_t$$,$cljs$cst$347$varargs$$,$cljs$cst$2851$v_mathematical$$,$cljs$cst$3602$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_deselect_all$$,$cljs$cst$4366$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_initialize_page_STAR_$$,
$cljs$cst$1269$enable_render_switch$$,$cljs$cst$3349$app_DOT_main_DOT_data_DOT_auth_SLASH_login_with_sso$$,$cljs$cst$2531$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_workspace$$,$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$,$cljs$cst$4330$connected_tab$$,$cljs$cst$680$keyword_QMARK_$$,$cljs$cst$4122$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_link_to_clipboard$$,$cljs$cst$3316$app_DOT_main_DOT_data_DOT_team_SLASH_update_webhook$$,$cljs$cst$3759$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_ungroup_shapes$$,
$cljs$cst$702$associative_QMARK_$$,$cljs$cst$1368$done_nl$$,$cljs$cst$4777$app_DOT_main_DOT_data_DOT_preview_SLASH_update_preview$$,$cljs$cst$4257$current_move$$,$cljs$cst$4477$app_DOT_main_DOT_data_DOT_workspace_SLASH_rename_shape_or_variant$$,$cljs$cst$2678$builtin$$,$cljs$cst$4552$label_class$$,$cljs$cst$1271$commit_hash$$,$cljs$cst$1772$attribute_cb$$,$cljs$cst$2533$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_viewer$$,$cljs$cst$5251$app_DOT_main_DOT_data_DOT_viewer_SLASH_increase_zoom$$,$cljs$cst$2991$bengali$$,
$cljs$cst$3526$ignore_parents_QMARK_$$,$cljs$cst$3121$many_QMARK_$$,$cljs$cst$5105$leave_and_reassign_org$$,$cljs$cst$3340$login_redirect$$,$cljs$cst$2564$file_feature_mismatch$$,$cljs$cst$4115$hibt$$,$cljs$cst$3345$app_DOT_main_DOT_data_DOT_auth_SLASH_login$$,$cljs$cst$352$registry$$,$cljs$cst$5202$swap_slot$$,$cljs$cst$4809$open_dashboard$$,$cljs$cst$165$_DOT_$$,$cljs$cst$1044$cljs_DOT_core_SLASH_coll_QMARK_$$,$cljs$cst$5092$default_checked$$,$cljs$cst$5270$app_DOT_main_DOT_data_DOT_viewer_SLASH_flash_interactions$$,
$cljs$cst$1119$cljs_DOT_spec_DOT_alpha_SLASH_kvs__GT_map$$,$cljs$cst$5355$import_files$$,$cljs$cst$852$malli_DOT_generator_SLASH_unsatisfiable_schema$$,$cljs$cst$4120$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_svg_text$$,$cljs$cst$355$k$$,$cljs$cst$316$m$$,$cljs$cst$57$v$$,$cljs$cst$5296$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_page$$,$cljs$cst$3737$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_set_options_mode$$,$cljs$cst$3674$strokeOpacity$$,$cljs$cst$3689$strict_entities$$,
$cljs$cst$1196$exporter_svgo$$,$cljs$cst$605$function$$,$cljs$cst$4061$border_width$$,$cljs$cst$371$naked_keys$$,$cljs$cst$918$encoders$$,$cljs$cst$806$clojure_DOT_test_DOT_check_DOT_generators_SLASH_any_printable$$,$cljs$cst$1593$admin$$,$cljs$cst$3742$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_rulers_QMARK_$$,$cljs$cst$3263$app_DOT_main_DOT_data_DOT_team_SLASH_members_fetched$$,$cljs$cst$1263$enable_token_color$$,$cljs$cst$5214$copy_top$$,$cljs$cst$3178$uops$$,$cljs$cst$4611$warning_SLASH_message$$,
$cljs$cst$5305$navigation_viewer$$,$cljs$cst$2923$baseline_shift$$,$cljs$cst$5281$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_section$$,$cljs$cst$5233$comments_show$$,$cljs$cst$5330$geometry$$,$cljs$cst$576$malli_DOT_core_SLASH_invalid_arity$$,$cljs$cst$4081$column_row$$,$cljs$cst$4377$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_shapes_to_path_SLASH_convert_selected_to_path$$,$cljs$cst$2129$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_simple_value$$,$cljs$cst$2974$font_loaded$$,$cljs$cst$4987$manifest$$,
$cljs$cst$444$not$$,$cljs$cst$2486$has_file_libraries$$,$cljs$cst$2243$updating_library$$,$cljs$cst$5171$component_not_main$$,$cljs$cst$3567$transactions_pending$$,$cljs$cst$3627$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_toggle_focus_mode$$,$cljs$cst$5174$invalid_main_instance_id$$,$cljs$cst$745$reserved$$,$cljs$cst$4342$get_current_mcp_token$$,$cljs$cst$1989$sided_paddings$$,$cljs$cst$2970$ttf_file_id$$,$cljs$cst$5200$component_duplicate_slot$$,$cljs$cst$5136$no_enough_members_for_leave$$,
$cljs$cst$3387$server_error$$,$cljs$cst$464$malli_DOT_core_SLASH_limits$$,$cljs$cst$105$more_marker$$,$cljs$cst$1218$client_header_check_middleware$$,$cljs$cst$3647$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_create_and_add_shape$$,$cljs$cst$5351$import_success$$,$cljs$cst$5191$not_head_main_not_allowed$$,$cljs$cst$2280$blob_QMARK_$$,$cljs$cst$870$gen_SLASH_schema$$,$cljs$cst$4635$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_layout_sizing_limits$$,$cljs$cst$1725$app_DOT_common_DOT_types_DOT_color_SLASH_hex_color$$,
$cljs$cst$3796$requester$$,$cljs$cst$761$multikeys$$,$cljs$cst$2901$color_rendering$$,$cljs$cst$2755$baseProfile$$,$cljs$cst$3905$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_clear_color_for_rename$$,$cljs$cst$3461$app_DOT_main_DOT_data_DOT_comments_SLASH_retrieve_comments$$,$cljs$cst$2807$horiz_origin_y$$,$cljs$cst$3312$delete_team$$,$cljs$cst$2799$horiz_origin_x$$,$cljs$cst$4296$app_DOT_main_DOT_data_DOT_workspace_DOT_highlight_SLASH_dehighlight_shape$$,$cljs$cst$5111$render_fn$$,$cljs$cst$1249$enable_export_file_v3$$,
$cljs$cst$4531$app_DOT_main_DOT_data_DOT_workspace_SLASH_find_components_norefs$$,$cljs$cst$263$linked_SLASH_map$$,$cljs$cst$650$explain$$,$cljs$cst$1$readably$$,$cljs$cst$2273$rename_to$$,$cljs$cst$4696$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_create_token_theme$$,$cljs$cst$812$clojure_DOT_test_DOT_check_DOT_generators_SLASH_double$$,$cljs$cst$2775$kernelMatrix$$,$cljs$cst$5268$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_first_frame$$,$cljs$cst$2942$clipUnits$$,$cljs$cst$2981$fallback_QMARK_$$,
$cljs$cst$634$re_min_max$$,$cljs$cst$1356$linux$$,$cljs$cst$4576$error_DOT_style_dictionary_SLASH_invalid_token_value_font_weight$$,$cljs$cst$4198$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_changes_SLASH_save_path_content$$,$cljs$cst$3655$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_relocate_shapes$$,$cljs$cst$2160$movement$$,$cljs$cst$1145$virtual$$,$cljs$cst$3034$stopcolor$$,$cljs$cst$4363$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_library_change$$,$cljs$cst$3483$app_DOT_main_DOT_data_DOT_comments_SLASH_fetch_profiles$$,
$cljs$cst$4789$italic$$,$cljs$cst$4067$border_color$$,$cljs$cst$1618$ignore_children_fn$$,$cljs$cst$5212$main_top$$,$cljs$cst$2064$bool_content$$,$cljs$cst$1585$average$$,$cljs$cst$2299$screen_height$$,$cljs$cst$2754$xml_COLON_lang$$,$cljs$cst$2985$runic$$,$cljs$cst$4857$move_unit_right$$,$cljs$cst$1714$remove_empty_QMARK_$$,$cljs$cst$4445$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_variants_switch$$,$cljs$cst$4597$error_DOT_style_dictionary_SLASH_invalid_token_value_text_case$$,$cljs$cst$1934$pdf$$,
$cljs$cst$1155$app_DOT_common_DOT_logging_SLASH_logger$$,$cljs$cst$578$args$$,$cljs$cst$5388$email_does_not_match_invitation$$,$cljs$cst$5087$auto_focus_QMARK_$$,$cljs$cst$1805$precise_QMARK_$$,$cljs$cst$493$malli_DOT_core_SLASH_cannot_provide_empty_and_bounded_props$$,$cljs$cst$158$new$$,$cljs$cst$1176$log_invitation_tokens$$,$cljs$cst$2471$app_DOT_main_DOT_data_DOT_common_SLASH_show_shared_dialog$$,$cljs$cst$1482$lift_ns$$,$cljs$cst$3825$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_clear_local_transform$$,
$cljs$cst$1473$arg1$$,$cljs$cst$2914$word_spacing$$,$cljs$cst$1475$arg3$$,$cljs$cst$5215$library_exists$$,$cljs$cst$1474$arg2$$,$cljs$cst$5195$component_nil_objects_not_allowed$$,$cljs$cst$1192$perf_logs$$,$cljs$cst$2740$animateMotion$$,$cljs$cst$3757$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_group_shapes$$,$cljs$cst$2993$latin_ext$$,$cljs$cst$5299$open_interactions$$,$cljs$cst$657$clojure_DOT_string$$,$cljs$cst$4401$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_toggle_shape_layout$$,
$cljs$cst$2267$retrieve_list_of_builtin_templates$$,$cljs$cst$551$malli_DOT_core_SLASH_invalid_ref$$,$cljs$cst$1166$app_DOT_common_DOT_logging_SLASH_trace$$,$cljs$cst$3206$app_DOT_main_DOT_data_DOT_profile_SLASH_persist_profile$$,$cljs$cst$2868$limitingConeAngle$$,$cljs$cst$2581$app_DOT_common_DOT_types_DOT_file_SLASH_file$$,$cljs$cst$3808$line_min_height$$,$cljs$cst$3584$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_zoom_to_selected_shape$$,$cljs$cst$867$gen_SLASH_return$$,$cljs$cst$2835$alphabetic$$,
$cljs$cst$1421$right_margin$$,$cljs$cst$1219$redis_cache$$,$cljs$cst$1049$cljs_DOT_core_SLASH_set_QMARK_$$,$cljs$cst$3314$delete_webhook$$,$cljs$cst$5370$not_valid_teams$$,$cljs$cst$4630$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_fill_stroke$$,$cljs$cst$3820$reverse_QMARK_$$,$cljs$cst$2278$elapsed$$,$cljs$cst$5391$email_as_password$$,$cljs$cst$4757$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_show_workspace_export_dialog$$,$cljs$cst$1497$with_open$$,$cljs$cst$4992$error_manifest$$,
$cljs$cst$3778$aspect_ratio$$,$cljs$cst$1257$enable_email_verification$$,$cljs$cst$517$malli_DOT_core_SLASH_index_out_of_bounds$$,$cljs$cst$3906$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_color$$,$cljs$cst$2875$v_hanging$$,$cljs$cst$2470$app_DOT_main_DOT_data_DOT_common_SLASH_show_notification$$,$cljs$cst$2941$ratio$$,$cljs$cst$4284$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_navigate_to_comment_id$$,$cljs$cst$2619$reorder_children$$,$cljs$cst$1418$lines$$,$cljs$cst$3481$update_comment_thread_frame$$,
$cljs$cst$948$ordered$$,$cljs$cst$1399$indent_t$$,$cljs$cst$1141$cached$$,$cljs$cst$3593$last_selected$$,$cljs$cst$4640$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_shape_dimensions$$,$cljs$cst$3817$to_bound_width$$,$cljs$cst$5401$in_team$$,$cljs$cst$1350$firefox$$,$cljs$cst$340$malli_DOT_core_SLASH_child_error$$,$cljs$cst$1164$app_DOT_common_DOT_logging_SLASH_message$$,$cljs$cst$579$malli_DOT_core_SLASH_invalid_input$$,$cljs$cst$4694$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_path$$,
$cljs$cst$1075$cljs_DOT_spec_DOT_alpha_SLASH_cpred$$,$cljs$cst$4035$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_apply_typography$$,$cljs$cst$1955$out$$,$cljs$cst$3780$root_shape$$,$cljs$cst$2793$pointsAtY$$,$cljs$cst$3021$greek$$,$cljs$cst$2871$pointsAtX$$,$cljs$cst$2768$pointsAtZ$$,$cljs$cst$4326$active$$,$cljs$cst$378$malli_DOT_core_SLASH_lazy_entries$$,$cljs$cst$2827$unicode_range$$,$cljs$cst$4799$open_comments$$,$cljs$cst$3030$paragraph$$,$cljs$cst$2143$app_DOT_main_DOT_data_DOT_websocket_SLASH_send_message$$,
$cljs$cst$452$malli_DOT_core_SLASH_extra_key$$,$cljs$cst$1778$geometry_child$$,$cljs$cst$4381$updated_ids$$,$cljs$cst$382$leave$$,$cljs$cst$4337$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_update_mcp_plugin_connection$$,$cljs$cst$2686$transparent$$,$cljs$cst$3840$transforms$$,$cljs$cst$2268$stream_QMARK_$$,$cljs$cst$5224$general_dashboard$$,$cljs$cst$1494$if_not$$,$cljs$cst$3782$is_hidden$$,$cljs$cst$2080$modifiable_group$$,$cljs$cst$567$malli_DOT_core_SLASH_explain_output$$,$cljs$cst$3873$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_reorder_layout_child$$,
$cljs$cst$5206$variant_not_main$$,$cljs$cst$3407$app_DOT_main_DOT_data_DOT_plugins_SLASH_check_open_plugin$$,$cljs$cst$3621$is_external_library$$,$cljs$cst$2925$stroke_miterlimit$$,$cljs$cst$5007$v_dir$$,$cljs$cst$2934$enable_background$$,$cljs$cst$3787$time$$,$cljs$cst$4476$app_DOT_main_DOT_data_DOT_workspace_SLASH_end_rename_shape$$,$cljs$cst$2778$maskContentUnits$$,$cljs$cst$967$strict$$,$cljs$cst$2049$locked$$,$cljs$cst$4488$app_DOT_main_DOT_data_DOT_workspace_SLASH_align_objects$$,$cljs$cst$438$orn$$,
$cljs$cst$4113$prev_id$$,$cljs$cst$4968$app_DOT_main_DOT_data_DOT_dashboard_SLASH_create_element$$,$cljs$cst$1471$last$$,$cljs$cst$4083$grid_row$$,$cljs$cst$695$char_QMARK_$$,$cljs$cst$4064$min_block_size$$,$cljs$cst$2290$browser_version$$,$cljs$cst$343$lazy$$,$cljs$cst$1267$enable_feature_render_wasm$$,$cljs$cst$1485$deref$$,$cljs$cst$3042$fillOpacity$$,$cljs$cst$1454$max_iterations$$,$cljs$cst$3579$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_increase_zoom$$,$cljs$cst$3509$app_DOT_main_DOT_data_DOT_project_SLASH_project_fetched$$,
$cljs$cst$2906$glyph_orientation_horizontal$$,$cljs$cst$2864$systemLanguage$$,$cljs$cst$4210$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_add_undo_entry$$,$cljs$cst$2081$grids_group$$,$cljs$cst$1216$rpc_rlimit$$,$cljs$cst$5110$avatar$$,$cljs$cst$1568$max_age$$,$cljs$cst$2640$del_typography$$,$cljs$cst$663$any_QMARK_$$,$cljs$cst$3736$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_remove_layout_flag$$,$cljs$cst$2065$geometry_group$$,$cljs$cst$1181$log_emails$$,$cljs$cst$4359$leave_file$$,
$cljs$cst$2806$markerHeight$$,$cljs$cst$3051$end_offset$$,$cljs$cst$1098$cljs_DOT_spec_DOT_alpha_SLASH_nil$$,$cljs$cst$3174$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_index$$,$cljs$cst$295$malli_DOT_core_SLASH_invalid$$,$cljs$cst$4361$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_file_deleted$$,$cljs$cst$3400$allow_background$$,$cljs$cst$3269$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_invitations$$,$cljs$cst$1165$app_DOT_common_DOT_logging_SLASH_cause$$,$cljs$cst$4277$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_update_comment_thread_position$$,
$cljs$cst$159$deftype_STAR_$$,$cljs$cst$4761$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_initialize_export_status$$,$cljs$cst$4715$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_create_token$$,$cljs$cst$2247$service_unavailable$$,$cljs$cst$2831$markerUnits$$,$cljs$cst$2938$htmlFor$$,$cljs$cst$676$string_QMARK_$$,$cljs$cst$1188$backend_openapi_doc$$,$cljs$cst$851$malli_DOT_generator_SLASH_original_generator_schema$$,$cljs$cst$4647$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_token$$,
$cljs$cst$3684$app_DOT_main_DOT_data_DOT_workspace_DOT_svg_upload_SLASH_add_svg_shapes$$,$cljs$cst$2902$fill_rule$$,$cljs$cst$1168$login_with_password$$,$cljs$cst$2815$orient$$,$cljs$cst$5099$caution$$,$cljs$cst$3641$skip_edition_QMARK_$$,$cljs$cst$4209$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_merge_head$$,$cljs$cst$916$decoders$$,$cljs$cst$3678$strokeCapEnd$$,$cljs$cst$4609$warning_DOT_style_dictionary_SLASH_invalid_referenced_token_value_stroke_width$$,$cljs$cst$3855$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_finish_transform$$,
$cljs$cst$995$opt_un$$,$cljs$cst$991$cljs_DOT_spec_DOT_alpha_SLASH_keys$$,$cljs$cst$1839$uniqueItems$$,$cljs$cst$2142$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_pointer_send$$,$cljs$cst$5203$not_a_variant$$,$cljs$cst$2529$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_settings$$,$cljs$cst$3571$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_check_open_transactions$$,$cljs$cst$3651$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shape_flags$$,$cljs$cst$2583$app_DOT_common_DOT_types_DOT_file_SLASH_typographies$$,
$cljs$cst$3833$ignore_snap_pixel$$,$cljs$cst$535$malli_DOT_core_SLASH_walked_refs$$,$cljs$cst$2823$contentStyleType$$,$cljs$cst$3470$app_DOT_main_DOT_data_DOT_comments_SLASH_close_comment_thread$$,$cljs$cst$1412$buffer_block$$,$cljs$cst$1167$app_DOT_common_DOT_logging_SLASH_default$$,$cljs$cst$2097$clojure_DOT_datafy_SLASH_obj$$,$cljs$cst$3988$get_library_usage$$,$cljs$cst$5350$import_progress$$,$cljs$cst$5379$wrong_credentials$$,$cljs$cst$252$queue$$,$cljs$cst$4353$connect$$,$cljs$cst$5331$app_DOT_util_DOT_code_highlight_SLASH_highlight_BANG_$$,
$cljs$cst$3431$mentions$$,$cljs$cst$1242$prepl_server$$,$cljs$cst$2568$missing_features_in_paste_content$$,$cljs$cst$5155$webhook_validation$$,$cljs$cst$1367$start_col$$,$cljs$cst$5165$duplicated_children$$,$cljs$cst$2$meta$$,$cljs$cst$856$malli_DOT_generator_SLASH_invalid_property$$,$cljs$cst$2662$fix_not_implemented$$,$cljs$cst$3852$index_SLASH_query_snap_xy$$,$cljs$cst$2186$render_state$$,$cljs$cst$3964$sync_dialog$$,$cljs$cst$1182$email_whitelist$$,$cljs$cst$3248$get_access_tokens$$,$cljs$cst$4780$font_size_dec$$,
$cljs$cst$3785$exact$$,$cljs$cst$2275$raw_transit_QMARK_$$,$cljs$cst$4786$text_editor$$,$cljs$cst$2839$glyph_name$$,$cljs$cst$2722$feDiffuseLighting$$,$cljs$cst$150$defrecord_STAR_$$,$cljs$cst$491$unparse$$,$cljs$cst$1019$opt_specs$$,$cljs$cst$3007$gujarati$$,$cljs$cst$577$arities$$,$cljs$cst$1441$commachar$$,$cljs$cst$4074$size_array$$,$cljs$cst$1252$enable_backend_svgo$$,$cljs$cst$3318$app_DOT_main_DOT_data_DOT_team_SLASH_create_webhook$$,$cljs$cst$3381$file_version_not_supported$$,$cljs$cst$787$clojure_DOT_test_DOT_check_DOT_generators_SLASH_map$$,
$cljs$cst$4356$text_color$$,$cljs$cst$1266$enable_feature_fdata_objects_map$$,$cljs$cst$4649$applied_to_variant$$,$cljs$cst$4373$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_id$$,$cljs$cst$1419$pretty$$,$cljs$cst$3854$y_ranges$$,$cljs$cst$790$clojure_DOT_test_DOT_check_DOT_generators_SLASH_vector$$,$cljs$cst$3344$is_muted$$,$cljs$cst$4578$error_DOT_style_dictionary_SLASH_invalid_token_value_font_family$$,$cljs$cst$1247$enable_registration$$,$cljs$cst$1503$let$$,$cljs$cst$1819$curve_to$$,$cljs$cst$3022$old_italic$$,
$cljs$cst$4554$on_selected$$,$cljs$cst$2264$get_raw_file$$,$cljs$cst$2495$app_DOT_main_DOT_data_DOT_common_SLASH_team_membership_change$$,$cljs$cst$2976$wasm_id$$,$cljs$cst$2713$feMergeNode$$,$cljs$cst$5060$teams_to_leave$$,$cljs$cst$1087$forms$$,$cljs$cst$2704$fePointLight$$,$cljs$cst$5175$invalid_main_instance_page$$,$cljs$cst$3373$only_creator_can_unlock$$,$cljs$cst$5009$is_grabbing$$,$cljs$cst$5167$child_id$$,$cljs$cst$2258$app_DOT_util_DOT_sse_SLASH_import_binfile$$,$cljs$cst$659$namespaces$$,
$cljs$cst$1499$defonce$$,$cljs$cst$5267$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_next_frame$$,$cljs$cst$2579$migrations$$,$cljs$cst$857$gen_SLASH_infinite_QMARK_$$,$cljs$cst$5137$member_does_not_exist$$,$cljs$cst$1355$windows$$,$cljs$cst$3487$total_chunks$$,$cljs$cst$3447$update_comment_thread$$,$cljs$cst$3376$svg_parser$$,$cljs$cst$4964$milliseconds$$,$cljs$cst$4281$app_DOT_main_DOT_data_DOT_workspace_SLASH_workspace_initialized$$,$cljs$cst$3519$property_name$$,$cljs$cst$4276$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_center_to_comment_thread$$,
$cljs$cst$2558$app_DOT_common_DOT_types_DOT_container_SLASH_touched$$,$cljs$cst$3305$get_team_invitation_token$$,$cljs$cst$1858$prev_c$$,$cljs$cst$2291$engine$$,$cljs$cst$4154$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_picker_for_selected_shape$$,$cljs$cst$1857$prev_i$$,$cljs$cst$5218$copy_any$$,$cljs$cst$3649$converted_from$$,$cljs$cst$5000$insert_selected_mention$$,$cljs$cst$345$double$$,$cljs$cst$2553$any_variant_container_descendant$$,$cljs$cst$3025$kannada$$,$cljs$cst$2598$assign$$,
$cljs$cst$1203$audit_log_gc$$,$cljs$cst$2943$svg_defs$$,$cljs$cst$4755$widget_visible$$,$cljs$cst$1122$cljs_DOT_core_SLASH_zipmap$$,$cljs$cst$5033$restore_file_snapshot$$,$cljs$cst$4485$app_DOT_main_DOT_data_DOT_workspace_SLASH_start_editing_selected$$,$cljs$cst$1856$prev_p$$,$cljs$cst$3633$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_stop$$,$cljs$cst$4360$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_file_change$$,$cljs$cst$2721$stop$$,$cljs$cst$3795$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_update_thumbnail$$,
$cljs$cst$5319$app$$,$cljs$cst$2779$tableValues$$,$cljs$cst$749$digit$$,$cljs$cst$3259$organization_owner_id$$,$cljs$cst$3265$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_members$$,$cljs$cst$1246$transit_readable_response$$,$cljs$cst$943$encode_SLASH_string$$,$cljs$cst$4559$default_value$$,$cljs$cst$3341$welcome_file_id$$,$cljs$cst$2792$repeatCount$$,$cljs$cst$2248$bad_gateway$$,$cljs$cst$2855$primitiveUnits$$,$cljs$cst$5334$html$$,$cljs$cst$1481$cljs_DOT_core$$,$cljs$cst$288$miser$$,$cljs$cst$2741$hkern$$,
$cljs$cst$1096$amp$$,$cljs$cst$1832$anyOf$$,$cljs$cst$3325$avatar_bg_url$$,$cljs$cst$4231$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_change_edit_mode$$,$cljs$cst$2904$stop_color$$,$cljs$cst$3303$app_DOT_main_DOT_data_DOT_team_SLASH_copy_invitation_link$$,$cljs$cst$1288$key__GT_prop$$,$cljs$cst$5302$next_frame$$,$cljs$cst$807$clojure_DOT_test_DOT_check_DOT_generators_SLASH_boolean$$,$cljs$cst$289$indentation$$,$cljs$cst$2764$stdDeviation$$,$cljs$cst$3098$node_batch_threshold$$,
$cljs$cst$686$uuid_QMARK_$$,$cljs$cst$1244$frontend_svgo$$,$cljs$cst$4700$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_delete_token_theme$$,$cljs$cst$597$_scope$$,$cljs$cst$2929$pointer_events$$,$cljs$cst$3450$app_DOT_main_DOT_data_DOT_comments_SLASH_update_comment$$,$cljs$cst$1381$end_pos$$,$cljs$cst$369$malli_DOT_core_SLASH_duplicate_keys$$,$cljs$cst$3924$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_rename_component_and_main_instance$$,$cljs$cst$358$malli_DOT_core_SLASH_invalid_schema$$,
$cljs$cst$2128$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_tokens_lib$$,$cljs$cst$2105$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_node$$,$cljs$cst$5217$main_any$$,$cljs$cst$2296$device_vendor$$,$cljs$cst$966$app_DOT_common_DOT_schema_SLASH_contains_any$$,$cljs$cst$3705$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_process_media_objects$$,$cljs$cst$1279$branch$$,$cljs$cst$4802$start_measure$$,$cljs$cst$4947$rename_project$$,$cljs$cst$3458$app_DOT_main_DOT_data_DOT_comments_SLASH_comment_threads_fetched$$,
$cljs$cst$2898$image_rendering$$,$cljs$cst$2076$exports_group$$,$cljs$cst$3132$index_SLASH_update$$,$cljs$cst$3350$provider_not_configured$$,$cljs$cst$3747$app_DOT_main_DOT_data_DOT_workspace_SLASH_selected_palette_colorpicker$$,$cljs$cst$5061$app_DOT_main_DOT_data_DOT_nitrate_SLASH_leave_org$$,$cljs$cst$156$letfn_STAR_$$,$cljs$cst$3993$penpot_selection$$,$cljs$cst$533$malli_DOT_core_SLASH_missing_property$$,$cljs$cst$2146$hint_origin$$,$cljs$cst$550$ref$$,$cljs$cst$3078$removed_mixed$$,$cljs$cst$3580$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_decrease_zoom$$,
$cljs$cst$1084$ret$$,$cljs$cst$992$req$$,$cljs$cst$2994$chinese$$,$cljs$cst$1489$defmacro$$,$cljs$cst$4188$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_common_SLASH_handle_finish_drawing$$,$cljs$cst$871$gen_SLASH_fmap$$,$cljs$cst$5102$num_teams_to_delete$$,$cljs$cst$422$qualified_keyword$$,$cljs$cst$2246$offline$$,$cljs$cst$931$data_validation$$,$cljs$cst$3807$line_min_width$$,$cljs$cst$2752$divisor$$,$cljs$cst$2517$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_libraries$$,$cljs$cst$3650$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_create_artboard_from_selection$$,
$cljs$cst$2761$exponent$$,$cljs$cst$3448$app_DOT_main_DOT_data_DOT_comments_SLASH_create_comment$$,$cljs$cst$1508$binding$$,$cljs$cst$3295$app_DOT_main_DOT_data_DOT_team_SLASH_team_leaved$$,$cljs$cst$1241$soft_quotes$$,$cljs$cst$2647$set_token_theme$$,$cljs$cst$4939$app_DOT_main_DOT_data_DOT_dashboard_SLASH_project_duplicated$$,$cljs$cst$3879$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_update_position$$,$cljs$cst$5179$should_not_be_component_root$$,$cljs$cst$5269$app_DOT_main_DOT_data_DOT_viewer_SLASH_set_interactions_mode$$,
$cljs$cst$4486$app_DOT_main_DOT_data_DOT_workspace_SLASH_select_parent_layer$$,$cljs$cst$5163$parent_not_found$$,$cljs$cst$629$re_validator$$,$cljs$cst$300$malli_DOT_core_SLASH_input_remaining$$,$cljs$cst$1584$network$$,$cljs$cst$2609$comment_thread_id$$,$cljs$cst$970$app_DOT_common_DOT_schema_SLASH_uri$$,$cljs$cst$1434$parameter_from_args$$,$cljs$cst$1108$cljs_DOT_core_SLASH_sequential_QMARK_$$,$cljs$cst$2625$add_color$$,$cljs$cst$776$min_elements$$,$cljs$cst$3573$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_undo_to_index$$,
$cljs$cst$3170$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_applied_changes_count$$,$cljs$cst$706$empty_QMARK_$$,$cljs$cst$4321$app_DOT_main_DOT_data_DOT_workspace_DOT_layers_SLASH_set_opacity$$,$cljs$cst$2692$linearGradient$$,$cljs$cst$2762$bbox$$,$cljs$cst$129$descendants$$,$cljs$cst$3773$data_old_width$$,$cljs$cst$449$malli_DOT_core_SLASH_val$$,$cljs$cst$880$malli_DOT_error_SLASH_unknown$$,$cljs$cst$3947$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_ext_library_changed$$,$cljs$cst$5227$go_to_libs$$,
$cljs$cst$661$malli_DOT_core_SLASH_disable_sci$$,$cljs$cst$1835$oneOf$$,$cljs$cst$3429$count_comments$$,$cljs$cst$3454$app_DOT_main_DOT_data_DOT_comments_SLASH_delete_comment_thread_on_viewer$$,$cljs$cst$5371$org_owner_cannot_leave$$,$cljs$cst$4411$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_layout_child$$,$cljs$cst$4073$padding_inline_start$$,$cljs$cst$3466$app_DOT_main_DOT_data_DOT_comments_SLASH_mark_all_threads_as_read$$,$cljs$cst$4357$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_presence$$,
$cljs$cst$1603$app_DOT_common_DOT_geom_DOT_matrix_SLASH_matrix$$,$cljs$cst$2719$feMorphology$$,$cljs$cst$3443$app_DOT_main_DOT_data_DOT_comments_SLASH_update_comment_thread_status$$,$cljs$cst$1276$commit$$,$cljs$cst$3701$unable_to_access_to_url$$,$cljs$cst$4756$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_clear_export_state$$,$cljs$cst$2870$vert_adv_y$$,$cljs$cst$581$malli_DOT_core_SLASH_invalid_guard$$,$cljs$cst$1201$sec_fetch_metadata_middleware$$,$cljs$cst$2661$broken_children$$,$cljs$cst$3285$get_webhooks$$,
$cljs$cst$2797$ideographic$$,$cljs$cst$2067$text_font_group$$,$cljs$cst$3639$no_select_QMARK_$$,$cljs$cst$2785$preserveAlpha$$,$cljs$cst$2830$begin$$,$cljs$cst$2860$lengthAdjust$$,$cljs$cst$5265$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_prev_frame$$,$cljs$cst$689$seqable_QMARK_$$,$cljs$cst$1092$splice$$,$cljs$cst$3168$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_component_id$$,$cljs$cst$4378$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_shapes_to_path_SLASH_convert_selected_strokes_to_path$$,
$cljs$cst$4225$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_end_edition$$,$cljs$cst$2671$pre_context_lost_options_mode$$,$cljs$cst$3680$inkscape_COLON_label$$,$cljs$cst$763$keywordize_QMARK_$$,$cljs$cst$4441$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_combine_as_variants$$,$cljs$cst$5300$prev_frame$$,$cljs$cst$3892$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_ids$$,$cljs$cst$1259$enable_dashboard_templates_section$$,$cljs$cst$4287$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_update_guides$$,
$cljs$cst$392$child$$,$cljs$cst$705$fn_QMARK_$$,$cljs$cst$532$dispatch$$,$cljs$cst$2936$paint_order$$,$cljs$cst$3336$app_DOT_main_DOT_data_DOT_websocket_SLASH_finalize$$,$cljs$cst$3096$blur_downscale_threshold$$,$cljs$cst$2908$writing_mode$$,$cljs$cst$4783$selected_shapes_data$$,$cljs$cst$3537$shapes_group$$,$cljs$cst$4393$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_initialize_shape_layout$$,$cljs$cst$5264$app_DOT_main_DOT_data_DOT_viewer_SLASH_close_thumbnails_panel$$,$cljs$cst$1802$reflow$$,
$cljs$cst$3677$strokeCapStart$$,$cljs$cst$3306$app_DOT_main_DOT_data_DOT_team_SLASH_update_invitation_role$$,$cljs$cst$3983$link_file_to_library$$,$cljs$cst$2223$workspace_v2_editor_state$$,$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$,$cljs$cst$951$app_DOT_common_DOT_schema_SLASH_vec$$,$cljs$cst$4233$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_check_changed_content$$,$cljs$cst$1163$fatal$$,$cljs$cst$4159$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_color_in_selected$$,
$cljs$cst$2700$feDisplacementMap$$,$cljs$cst$3357$app_DOT_main_DOT_data_DOT_auth_SLASH_logout$$,$cljs$cst$2463$app_DOT_main_DOT_router_SLASH_nav_raw$$,$cljs$cst$4372$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_rename_page$$,$cljs$cst$4119$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_text$$,$cljs$cst$5385$go_back_callback$$,$cljs$cst$3869$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_start_move_selected$$,$cljs$cst$4651$frame_children$$,$cljs$cst$4484$app_DOT_main_DOT_data_DOT_workspace_SLASH_relocate_selected_shapes$$,
$cljs$cst$2984$japanese$$,$cljs$cst$1466$directive$$,$cljs$cst$4631$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_layout_item_margin$$,$cljs$cst$3380$feature_mismatch$$,$cljs$cst$3101$image_resources$$,$cljs$cst$3893$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_inner$$,$cljs$cst$4590$error_DOT_style_dictionary_SLASH_invalid_token_value_opacity$$,$cljs$cst$1402$mandatory$$,$cljs$cst$2957$on_hold$$,$cljs$cst$4764$healthy_QMARK_$$,$cljs$cst$3691$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_svg_uploaded$$,
$cljs$cst$3640$no_update_layout_QMARK_$$,$cljs$cst$3886$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_flip_horizontal_selected$$,$cljs$cst$1318$leading$$,$cljs$cst$4817$open_inspect$$,$cljs$cst$4507$disable_flatten_QMARK_$$,$cljs$cst$2618$allow_altering_copies$$,$cljs$cst$3287$app_DOT_main_DOT_data_DOT_team_SLASH_team_created$$,$cljs$cst$423$qualified_symbol$$,$cljs$cst$3945$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_fetch_library_thumbnails$$,$cljs$cst$1256$enable_secure_session_cookies$$,
$cljs$cst$4752$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_toggle_detail_visibililty$$,$cljs$cst$3783$thumbnail_uri$$,$cljs$cst$4773$force_multiple$$,$cljs$cst$2774$intercept$$,$cljs$cst$3644$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_move_shapes_into_frame$$,$cljs$cst$225$else$$,$cljs$cst$416$from_ast$$,$cljs$cst$1425$seq$$,$cljs$cst$254$sep$$,$cljs$cst$1490$defn$$,$cljs$cst$4585$error_DOT_token_SLASH_number_too_large$$,$cljs$cst$4055$max_block_size$$,$cljs$cst$3962$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_sync_file$$,
$cljs$cst$1275$major$$,$cljs$cst$1518$app_DOT_common_DOT_geom_DOT_point_SLASH_point$$,$cljs$cst$4778$app_DOT_main_DOT_data_DOT_preview_SLASH_open_preview_selected$$,$cljs$cst$3814$child_max_width$$,$cljs$cst$3212$app_DOT_main_DOT_data_DOT_profile_SLASH_cancel_email_change$$,$cljs$cst$5084$on_change_value$$,$cljs$cst$1438$colinc$$,$cljs$cst$1324$sch$$,$cljs$cst$3594$board_id$$,$cljs$cst$3545$alt_duplication_QMARK_$$,$cljs$cst$721$every$$,$cljs$cst$3207$update_profile$$,$cljs$cst$5008$is_hover$$,$cljs$cst$1338$app_DOT_util_DOT_storage_SLASH_last_refresh$$,
$cljs$cst$3453$delete_comment_thread$$,$cljs$cst$4049$border_style$$,$cljs$cst$4037$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_v2_update_text_editor_styles$$,$cljs$cst$5211$variant_component_bad_id$$,$cljs$cst$2889$gradientTransform$$,$cljs$cst$2633$del_component$$,$cljs$cst$2996$ethiopic$$,$cljs$cst$566$malli_DOT_core_SLASH_explain_input$$,$cljs$cst$3006$thai$$,$cljs$cst$1301$arrayBuilder$$,$cljs$cst$801$clojure_DOT_test_DOT_check_DOT_generators_SLASH_large_integer_STAR_$$,$cljs$cst$3864$no_wasm_QMARK_$$,
$cljs$cst$1903$image_fix$$,$cljs$cst$1174$oidc_registration$$,$cljs$cst$4481$app_DOT_main_DOT_data_DOT_workspace_SLASH_vertical_order_selected$$,$cljs$cst$2715$feSpotLight$$,$cljs$cst$768$seed$$,$cljs$cst$4577$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow$$,$cljs$cst$1303$mapBuilder$$,$cljs$cst$2637$purge_component$$,$cljs$cst$2681$app_DOT_main_DOT_fonts_SLASH_woff1_file_id$$,$cljs$cst$606$malli_DOT_core_SLASH_non_function_childs$$,$cljs$cst$1305$preferStrings$$,$cljs$cst$902$malli_DOT_transform_SLASH_compiled$$,
$cljs$cst$2582$app_DOT_common_DOT_types_DOT_file_SLASH_colors$$,$cljs$cst$4216$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_add_node$$,$cljs$cst$1183$smtp_debug$$,$cljs$cst$3000$telugu$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,$cljs$cst$3527$new_component_file$$,$cljs$cst$1081$min_count$$,$cljs$cst$3672$xmlns$$,$cljs$cst$2876$requiredFeatures$$,$cljs$cst$3811$children_data$$,$cljs$cst$3941$retries$$,$cljs$cst$4192$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_setup_frame$$,
$cljs$cst$1595$owner$$,$cljs$cst$4403$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_add_layout_track$$,$cljs$cst$3598$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_deselect_shape$$,$cljs$cst$1260$enable_google_fonts_provider$$,$cljs$cst$4004$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_editor_state$$,$cljs$cst$414$to_ast$$,$cljs$cst$989$cljs_DOT_core_SLASH_map_QMARK_$$,$cljs$cst$2669$app_DOT_main_DOT_data_DOT_render_wasm_SLASH_context_lost$$,$cljs$cst$3010$tibetan$$,
$cljs$cst$350$malli_DOT_core_SLASH_duplicate_arities$$,$cljs$cst$2770$requiredExtensions$$,$cljs$cst$4269$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_handle_drawing$$,$cljs$cst$2874$rendering_intent$$,$cljs$cst$658$malli_DOT_core$$,$cljs$cst$5235$unresolved$$,$cljs$cst$4046$prev_content$$,$cljs$cst$1170$login_with_gitlab$$,$cljs$cst$904$this$$,$cljs$cst$1143$vthread$$,$cljs$cst$2840$cap_height$$,$cljs$cst$2539$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_level$$,$cljs$cst$4261$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_stop_path_edit$$,
$cljs$cst$1906$blend_filters$$,$cljs$cst$2104$tokens_tree$$,$cljs$cst$372$lazy_refs$$,$cljs$cst$1156$app_DOT_common_DOT_logging_SLASH_level$$,$cljs$cst$370$arr$$,$cljs$cst$3090$next_index$$,$cljs$cst$692$vector_QMARK_$$,$cljs$cst$1976$rtl$$,$cljs$cst$4350$subscribe_team$$,$cljs$cst$4999$hide_mentions$$,$cljs$cst$2337$app_DOT_main_DOT_data_DOT_modal_SLASH_show_modal$$,$cljs$cst$2360$app_DOT_main_DOT_data_DOT_notifications_SLASH_hide$$,$cljs$cst$145$cause$$,$cljs$cst$4380$new_shape$$,$cljs$cst$3890$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text$$,
$cljs$cst$5213$main_nested$$,$cljs$cst$956$app_DOT_common_DOT_schema_SLASH_coll_of_uuid$$,$cljs$cst$2709$animateColor$$,$cljs$cst$3884$element_type$$,$cljs$cst$4302$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_remove_flow$$,$cljs$cst$4338$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_connect_mcp$$,$cljs$cst$253$js$$,$cljs$cst$5199$duplicate_slot$$,$cljs$cst$5332$css$$,$cljs$cst$3834$subtree_ids_by_id$$,$cljs$cst$4599$error_DOT_style_dictionary_SLASH_invalid_token_value_typography$$,
$cljs$cst$3474$app_DOT_main_DOT_data_DOT_comments_SLASH_create_draft$$,$cljs$cst$3998$entityMap$$,$cljs$cst$5342$grid_element$$,$cljs$cst$3284$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_webhooks$$,$cljs$cst$6$ns$$,$cljs$cst$3700$invalid_svg_file$$,$cljs$cst$3173$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_undefined$$,$cljs$cst$4949$delete_project$$,$cljs$cst$5188$nested_main_not_allowed$$,$cljs$cst$210$col$$,$cljs$cst$2726$vkern$$,$cljs$cst$3110$app_DOT_main_DOT_features_SLASH_recompute_features$$,
$cljs$cst$4388$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_clean_selection$$,$cljs$cst$2995$gurmukhi$$,$cljs$cst$4628$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_shape_rotation$$,$cljs$cst$766$value_fn$$,$cljs$cst$4228$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_handle_new_shape$$,$cljs$cst$4573$paragraph_spacing$$,$cljs$cst$1483$not_delivered$$,$cljs$cst$908$transformers$$,$cljs$cst$1411$miser_width$$,$cljs$cst$3668$shape_cells$$,
$cljs$cst$4080$reverse_row$$,$cljs$cst$3615$id_duplicated$$,$cljs$cst$574$malli_DOT_core_SLASH_missing_function$$,$cljs$cst$3294$update_team$$,$cljs$cst$3177$rops$$,$cljs$cst$4636$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_generate_text_shape_update$$,$cljs$cst$3425$file_name$$,$cljs$cst$3283$app_DOT_main_DOT_data_DOT_team_SLASH_webhooks_fetched$$,$cljs$cst$1617$root$$,$cljs$cst$1498$with_local_vars$$,$cljs$cst$961$app_DOT_common_DOT_schema_SLASH_safe_int$$,$cljs$cst$5324$on_change_format$$,
$cljs$cst$4258$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_move_selected$$,$cljs$cst$670$nat_int_QMARK_$$,$cljs$cst$4191$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_box_SLASH_handle_drawing$$,$cljs$cst$3749$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_set_workspace_visited$$,$cljs$cst$2978$is_emoji$$,$cljs$cst$5133$email_domain_is_not_allowed$$,$cljs$cst$2514$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_search$$,$cljs$cst$4889$panels$$,$cljs$cst$3569$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_commit_undo_transaction$$,
$cljs$cst$5219$not_component$$,$cljs$cst$1470$allows_separator$$,$cljs$cst$4541$app_DOT_main_DOT_ui_DOT_hooks_DOT_resize_SLASH_state$$,$cljs$cst$3192$app_DOT_main_DOT_data_DOT_media_SLASH_files$$,$cljs$cst$3909$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_delete_color$$,$cljs$cst$3433$app_DOT_main_DOT_data_DOT_comments_SLASH_created_thread_on_workspace$$,$cljs$cst$633$re_transformer$$,$cljs$cst$5207$parent_not_variant$$,$cljs$cst$2887$attributeType$$,$cljs$cst$681$simple_keyword_QMARK_$$,
$cljs$cst$5178$should_be_component_root$$,$cljs$cst$3195$media_type_mismatch$$,$cljs$cst$3189$cljs_DOT_spec_DOT_alpha_SLASH_coll_of$$,$cljs$cst$4374$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_name$$,$cljs$cst$2767$accent_height$$,$cljs$cst$3581$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_set_zoom$$,$cljs$cst$2538$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_simplified$$,$cljs$cst$1050$cljs_DOT_core_SLASH_list_QMARK_$$,$cljs$cst$1390$buffer_blob$$,$cljs$cst$4790$app_DOT_main_DOT_data_DOT_workspace_DOT_shortcuts_SLASH_esc_pressed$$,
$cljs$cst$3011$bamum$$,$cljs$cst$5292$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_all$$,$cljs$cst$3378$app_DOT_main_DOT_errors_SLASH_exceptional_state$$,$cljs$cst$3043$selected_colors$$,$cljs$cst$2708$color_profile$$,$cljs$cst$4779$font_size_inc$$,$cljs$cst$3548$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_toggle_collapse$$,$cljs$cst$868$gen_SLASH_elements$$,$cljs$cst$5004$insert_mention$$,$cljs$cst$2999$khmer$$,$cljs$cst$1179$login_with_ldap$$,$cljs$cst$3815$child_max_height$$,$cljs$cst$2776$patternUnits$$,
$cljs$cst$4489$app_DOT_main_DOT_data_DOT_workspace_SLASH_distribute_objects$$,$cljs$cst$4560$dropdown_class$$,$cljs$cst$5389$registration_disabled$$,$cljs$cst$679$qualified_ident_QMARK_$$,$cljs$cst$2849$xlink_COLON_actuate$$,$cljs$cst$2674$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_v3_SLASH_v3_update_text_editor_styles$$,$cljs$cst$4935$app_DOT_main_DOT_data_DOT_dashboard_SLASH_project_created$$,$cljs$cst$2724$feComposite$$,$cljs$cst$2150$ctrl$$,$cljs$cst$3039$gradient_units$$,$cljs$cst$154$loop_STAR_$$,
$cljs$cst$4410$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_change_layout_track$$,$cljs$cst$808$clojure_DOT_test_DOT_check_DOT_generators_SLASH_char$$,$cljs$cst$3841$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_move_frame_comment_threads$$,$cljs$cst$3002$javanese$$,$cljs$cst$3885$moved$$,$cljs$cst$1752$internal$$,$cljs$cst$98$cljs_DOT_core_SLASH_not_found$$,$cljs$cst$5286$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_overlay$$,$cljs$cst$2965$svg_transform$$,$cljs$cst$2880$viewBox$$,
$cljs$cst$1144$thread$$,$cljs$cst$3827$prev_wasm_props$$,$cljs$cst$2711$animate$$,$cljs$cst$3816$to_bound_height$$,$cljs$cst$2825$arabic_form$$,$cljs$cst$4941$duplicate_project$$,$cljs$cst$2910$clip_rule$$,$cljs$cst$4222$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_start_edition$$,$cljs$cst$4143$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_all_fills$$,$cljs$cst$4229$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_start_draw_mode$$,$cljs$cst$3246$app_DOT_main_DOT_data_DOT_profile_SLASH_access_tokens_fetched$$,
$cljs$cst$155$do$$,$cljs$cst$2824$specularExponent$$,$cljs$cst$1349$other$$,$cljs$cst$4095$grid_area$$,$cljs$cst$2838$overline_position$$,$cljs$cst$682$qualified_keyword_QMARK_$$,$cljs$cst$3828$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_current_move_selected$$,$cljs$cst$4265$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_tools_SLASH_toggle_snap$$,$cljs$cst$3424$page_name$$,$cljs$cst$1208$file_schema_validation$$,$cljs$cst$2697$feDistantLight$$,$cljs$cst$1501$dotimes$$,$cljs$cst$4323$press_opacity_id$$,
$cljs$cst$3706$media_loading$$,$cljs$cst$3623$is_variant$$,$cljs$cst$669$neg_int_QMARK_$$,$cljs$cst$1502$cond$$,$cljs$cst$3743$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_none$$,$cljs$cst$5201$missing_slot$$,$cljs$cst$1565$ascent$$,$cljs$cst$4290$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_remove_guides$$,$cljs$cst$1221$soft_rpc_rlimit$$,$cljs$cst$157$if$$,$cljs$cst$3050$end_para$$,$cljs$cst$3974$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_component_changed$$,$cljs$cst$3771$data_old_x$$,
$cljs$cst$3772$data_old_y$$,$cljs$cst$3234$delete_profile_photo$$,$cljs$cst$138$uuid$$,$cljs$cst$3558$app_DOT_main_DOT_data_DOT_workspace_DOT_edition_SLASH_start_edition_mode$$,$cljs$cst$2844$dur$$,$cljs$cst$3$dup$$,$cljs$cst$855$gen_SLASH_max$$,$cljs$cst$5088$auto_focus$$,$cljs$cst$494$malli_DOT_core_SLASH_tuple_size$$,$cljs$cst$1124$cljs_DOT_spec_DOT_alpha_SLASH_k$$,$cljs$cst$4824$select_next$$,$cljs$cst$4196$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_handle_drawing$$,$cljs$cst$5326$hsla$$,
$cljs$cst$1509$struct_map$$,$cljs$cst$1395$end_block_t$$,$cljs$cst$1125$cljs_DOT_spec_DOT_alpha_SLASH_v$$,$cljs$cst$1142$current_thread$$,$cljs$cst$3089$strokeLinejoin$$,$cljs$cst$2854$baseFrequency$$,$cljs$cst$3847$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_apply_modifiers$$,$cljs$cst$3943$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_initialize_page$$,$cljs$cst$4344$mcp_SLASH_ping$$,$cljs$cst$3313$app_DOT_main_DOT_data_DOT_team_SLASH_delete_webhook$$,$cljs$cst$2551$top_children$$,
$cljs$cst$3048$start_para$$,$cljs$cst$4033$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_attrs$$,$cljs$cst$3003$malayalam$$,$cljs$cst$3130$app_DOT_main_DOT_data_DOT_changes_SLASH_update_indexes$$,$cljs$cst$2594$show_touched$$,$cljs$cst$3233$app_DOT_main_DOT_data_DOT_profile_SLASH_delete_photo$$,$cljs$cst$5100$leave_and_reassign$$,$cljs$cst$2703$use$$,$cljs$cst$2720$feGaussianBlur$$,$cljs$cst$5303$toggle_zoom_style$$,$cljs$cst$903$malli_DOT_transform_SLASH_too_deep_compilation$$,$cljs$cst$662$malli_DOT_core_SLASH_sci_options$$,
$cljs$cst$862$generator$$,$cljs$cst$3097$max_blocking_time_ms$$,$cljs$cst$3366$handled$$,$cljs$cst$3094$force_sync$$,$cljs$cst$3367$unhandled$$,$cljs$cst$4264$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_tools_SLASH_process_path_tool$$,$cljs$cst$1851$app_DOT_common_DOT_types_DOT_path_SLASH_content$$,$cljs$cst$474$malli_DOT_core_SLASH_in$$,$cljs$cst$4392$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_layout_positions$$,$cljs$cst$4811$open_color_picker$$,$cljs$cst$3198$app_DOT_main_DOT_data_DOT_profile_SLASH_set_profile$$,
$cljs$cst$3522$ignore_tree$$,$cljs$cst$854$gen_SLASH_min$$,$cljs$cst$4644$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_sizing_token$$,$cljs$cst$4355$pointer_update$$,$cljs$cst$4227$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_handle_drawing_end$$,$cljs$cst$3946$get_file_object_thumbnails$$,$cljs$cst$335$sci_DOT_core_SLASH_eval_string_STAR_$$,$cljs$cst$2846$surfaceScale$$,$cljs$cst$1077$cljs_DOT_spec_DOT_alpha_SLASH_describe$$,$cljs$cst$748$scheme$$,
$cljs$cst$3856$duplicate_move_started_QMARK_$$,$cljs$cst$1095$cljs_DOT_spec_DOT_alpha_SLASH_amp$$,$cljs$cst$4584$error_DOT_style_dictionary_SLASH_value_with_units$$,$cljs$cst$3047$focus_offset$$,$cljs$cst$4214$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_shortcuts_SLASH_esc_pressed$$,$cljs$cst$1097$cljs_DOT_spec_DOT_alpha_SLASH_alt$$,$cljs$cst$445$malli_DOT_core_SLASH_walk_entry_vals$$,$cljs$cst$4580$error_DOT_style_dictionary_SLASH_value_with_percent$$,$cljs$cst$1015$keys_pred$$,$cljs$cst$3209$app_DOT_main_DOT_data_DOT_profile_SLASH_toggle_theme$$,
$cljs$cst$2593$show_ids$$,$cljs$cst$5320$debug_SLASH_repair_current_file$$,$cljs$cst$3781$show_grids_QMARK_$$,$cljs$cst$4962$app_DOT_main_DOT_data_DOT_dashboard_SLASH_move_files$$,$cljs$cst$3560$lock$$,$cljs$cst$353$malli_DOT_core_SLASH_allow_invalid_refs$$,$cljs$cst$1845$minLength$$,$cljs$cst$2913$stroke_dashoffset$$,$cljs$cst$3372$only_creator_can_lock$$,$cljs$cst$2141$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_change_hover_state$$,$cljs$cst$2817$horiz_adv_x$$,$cljs$cst$3289$create_team$$,
$cljs$cst$2626$mod_color$$,$cljs$cst$4051$box_shadow$$,$cljs$cst$3981$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_attach_library$$,$cljs$cst$130$ancestors$$,$cljs$cst$4208$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_redo_path$$,$cljs$cst$1429$def$$,$cljs$cst$4117$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_shapes$$,$cljs$cst$2629$mod_media$$,$cljs$cst$3225$app_DOT_main_DOT_data_DOT_profile_SLASH_update_profile_props$$,$cljs$cst$1018$req_keys$$,$cljs$cst$2795$targetY$$,
$cljs$cst$2812$targetX$$,$cljs$cst$4704$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_duplicate_token_set$$,$cljs$cst$3035$stopColor$$,$cljs$cst$285$map_entry_separator$$,$cljs$cst$3550$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_collapse_all$$,$cljs$cst$673$float_QMARK_$$,$cljs$cst$3038$gradientunits$$,$cljs$cst$2765$font_stretch$$,$cljs$cst$5232$show_interactions$$,$cljs$cst$3203$app_DOT_main_DOT_data_DOT_profile_SLASH_fetch_profile$$,$cljs$cst$3347$app_DOT_main_DOT_data_DOT_auth_SLASH_login_with_ldap$$,
$cljs$cst$3102$wasm_reload_context_failure$$,$cljs$cst$2566$migration_in_progress$$,$cljs$cst$3276$update_team_member_role$$,$cljs$cst$5329$layout_element$$,$cljs$cst$4014$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_paragraph_attrs$$,$cljs$cst$2300$screen_color_depth$$,$cljs$cst$126$keyword_fn$$,$cljs$cst$4084$z_index$$,$cljs$cst$5189$root_copy_not_allowed$$,$cljs$cst$2585$ignore_sync_until$$,$cljs$cst$1270$enable_render_wasm_info$$,$cljs$cst$1090$cljs_DOT_spec_DOT_alpha_SLASH_rep$$,
$cljs$cst$5352$import_error$$,$cljs$cst$5002$insert_prev_mention$$,$cljs$cst$1919$omit_blocked_QMARK_$$,$cljs$cst$5183$ref_shape_is_head$$,$cljs$cst$5396$prepare_register_profile$$,$cljs$cst$4340$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_user_disconnect_mcp$$,$cljs$cst$292$val_fn$$,$cljs$cst$47$validator$$,$cljs$cst$5375$callback_url$$,$cljs$cst$3446$app_DOT_main_DOT_data_DOT_comments_SLASH_update_comment_thread$$,$cljs$cst$4457$app_DOT_main_DOT_data_DOT_workspace_SLASH_check_libraries_synchronization$$,
$cljs$cst$1300$array_builder$$,$cljs$cst$3088$strokeLinecap$$,$cljs$cst$614$childs$$,$cljs$cst$3744$selected_palette$$,$cljs$cst$1045$cljs_DOT_core_SLASH__LT__EQ_$$,$cljs$cst$2070$content_group$$,$cljs$cst$2826$widths$$,$cljs$cst$1251$enable_exporter_svgo$$,$cljs$cst$2596$root_id$$,$cljs$cst$4819$paste_replace$$,$cljs$cst$1254$enable_backend_openapi_doc$$,$cljs$cst$2634$delta$$,$cljs$cst$2102$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_token_set$$,$cljs$cst$4639$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_generate_font_weight_text_shape_update$$,
$cljs$cst$2666$not_implemented$$,$cljs$cst$4553$input_id$$,$cljs$cst$1383$type_tag$$,$cljs$cst$1842$nullable$$,$cljs$cst$819$clojure_DOT_test_DOT_check_DOT_generators_SLASH_simple_type_printable$$,$cljs$cst$3478$owner_photo_id$$,$cljs$cst$1551$potok_DOT_v2_DOT_core_SLASH_undefined$$,$cljs$cst$4753$detail_visible$$,$cljs$cst$660$malli_DOT_core_SLASH_sci_not_available$$,$cljs$cst$3559$app_DOT_main_DOT_data_DOT_workspace_DOT_edition_SLASH_clear_edition_mode$$,$cljs$cst$3081$feature_text_editor_wasm$$,
$cljs$cst$4413$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_change_cells_mode$$,$cljs$cst$3354$app_DOT_main_DOT_data_DOT_auth_SLASH_login_from_register$$,$cljs$cst$5258$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_zoom_style$$,$cljs$cst$1422$suppress_namespaces$$,$cljs$cst$2772$xlink_COLON_show$$,$cljs$cst$2187$lost$$,$cljs$cst$3452$app_DOT_main_DOT_data_DOT_comments_SLASH_delete_comment_thread_on_workspace$$,$cljs$cst$1362$cur$$,$cljs$cst$2757$strikethrough_thickness$$,$cljs$cst$5327$background_image$$,
$cljs$cst$2924$color_interpolation_filters$$,$cljs$cst$1158$app_DOT_common_DOT_logging_SLASH_props$$,$cljs$cst$383$malli_DOT_core_SLASH_invalid_transformer$$,$cljs$cst$348$malli_DOT_core_SLASH_multiple_varargs$$,$cljs$cst$4041$content_has_text_QMARK_$$,$cljs$cst$2649$theme_paths$$,$cljs$cst$3302$create_team_invitations$$,$cljs$cst$5348$import_ready$$,$cljs$cst$3692$assemble_file_media_object$$,$cljs$cst$2461$app_DOT_main_DOT_router_SLASH_reload$$,$cljs$cst$5252$app_DOT_main_DOT_data_DOT_viewer_SLASH_decrease_zoom$$,
$cljs$cst$1017$req_specs$$,$cljs$cst$3755$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_set_workspace_read_only$$,$cljs$cst$5011$new_position_y$$,$cljs$cst$1123$cljs_DOT_core_SLASH_map$$,$cljs$cst$1500$when_let$$,$cljs$cst$863$malli_DOT_generator_SLASH_distinct_generator_failure$$,$cljs$cst$4056$padding_block_end$$,$cljs$cst$5010$new_position_x$$,$cljs$cst$3317$update_webhook$$,$cljs$cst$4706$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_set$$,$cljs$cst$3638$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes$$,
$cljs$cst$687$uri_QMARK_$$,$cljs$cst$4070$grid_template_columns$$,$cljs$cst$3793$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_assoc_thumbnail$$,$cljs$cst$4594$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_blur$$,$cljs$cst$492$bounded$$,$cljs$cst$4189$initialized_QMARK_$$,$cljs$cst$4772$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_request_multiple_export$$,$cljs$cst$4967$app_DOT_main_DOT_data_DOT_dashboard_SLASH_clone_template$$,$cljs$cst$4093$grid_template_areas$$,
$cljs$cst$3404$app_DOT_main_DOT_data_DOT_plugins_SLASH_close_current_plugin$$,$cljs$cst$1205$render_wasm_info$$,$cljs$cst$2819$calcMode$$,$cljs$cst$2847$underline_position$$,$cljs$cst$630$re_explainer$$,$cljs$cst$2729$feTile$$,$cljs$cst$213$eof$$,$cljs$cst$3351$redirect_uri$$,$cljs$cst$5085$show_success_QMARK_$$,$cljs$cst$3865$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_update_dimensions$$,$cljs$cst$739$authority$$,$cljs$cst$994$req_un$$,$cljs$cst$2297$device_model$$,$cljs$cst$1753$invalid_fill$$,
$cljs$cst$4598$error_DOT_style_dictionary_SLASH_invalid_token_value_text_decoration$$,$cljs$cst$2907$kerning$$,$cljs$cst$3544$variant_props$$,$cljs$cst$3970$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_notify_sync_file$$,$cljs$cst$5193$not_component_not_allowed$$,$cljs$cst$128$parents$$,$cljs$cst$3310$app_DOT_main_DOT_data_DOT_team_SLASH_team_deleted$$,$cljs$cst$4252$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_set_modifiers$$,$cljs$cst$1404$logical_blocks$$,$cljs$cst$3630$mod_QMARK_$$,
$cljs$cst$2638$add_typography$$,$cljs$cst$3397$app_DOT_main_DOT_data_DOT_plugins_SLASH_save_current_plugin$$,$cljs$cst$3319$create_webhook$$,$cljs$cst$3739$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_colorpalette_QMARK_$$,$cljs$cst$3086$image_id$$,$cljs$cst$683$symbol_QMARK_$$,$cljs$cst$4514$app_DOT_main_DOT_data_DOT_workspace_SLASH_hide_context_menu$$,$cljs$cst$4429$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_remove_empty_properties$$,$cljs$cst$2918$flood_opacity$$,$cljs$cst$2537$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_default$$,
$cljs$cst$3033$xlink_href$$,$cljs$cst$5173$component_not_found$$,$cljs$cst$4618$brokenReferences$$,$cljs$cst$4286$app_DOT_main_DOT_data_DOT_workspace_DOT_fix_deleted_fonts_SLASH_fix_deleted_fonts_for_page$$,$cljs$cst$4082$flex_shrink$$,$cljs$cst$2949$app_DOT_main_DOT_data_DOT_shortcuts_SLASH_push_shortcuts$$,$cljs$cst$4459$app_DOT_main_DOT_data_DOT_workspace_SLASH_fetch_libries$$,$cljs$cst$5187$root_main_not_allowed$$,$cljs$cst$4439$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_rename_variant$$,
$cljs$cst$2077$blur_group$$,$cljs$cst$1394$start_block_t$$,$cljs$cst$2822$xlink_COLON_type$$,$cljs$cst$869$gen_SLASH_gen$$,$cljs$cst$534$malli_DOT_core_SLASH_potentially_recursive_seqex$$,$cljs$cst$2694$altGlyph$$,$cljs$cst$4212$undo_lock$$,$cljs$cst$4608$warning_SLASH_fn$$,$cljs$cst$4551$label_text$$,$cljs$cst$5176$invalid_main_instance$$,$cljs$cst$665$number_QMARK_$$,$cljs$cst$728$malli_DOT_core_SLASH_instrument_requires_function_schema$$,$cljs$cst$2106$is_source$$,$cljs$cst$2559$app_DOT_common_DOT_schema_DOT_desc_js_like_SLASH_inline$$,
$cljs$cst$3018$modi$$,$cljs$cst$3191$app_DOT_main_DOT_data_DOT_media_SLASH_file_QMARK_$$,$cljs$cst$107$fallback_impl$$,$cljs$cst$4788$bold$$,$cljs$cst$3728$element_options$$,$cljs$cst$1829$exclusiveMaximum$$,$cljs$cst$5142$selected_id$$,$cljs$cst$1089$cljs_DOT_spec_DOT_alpha_SLASH_pcat$$,$cljs$cst$3903$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_color$$,$cljs$cst$1407$writing$$,$cljs$cst$3122$ignore_response_QMARK_$$,$cljs$cst$3657$app_DOT_main_DOT_data_DOT_workspace_DOT_bool_SLASH_create_bool_union$$,
$cljs$cst$251$inst$$,$cljs$cst$667$int_QMARK_$$,$cljs$cst$2279$unexpected_response$$,$cljs$cst$1834$additionalProperties$$,$cljs$cst$3914$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_typography$$,$cljs$cst$3575$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_redo$$,$cljs$cst$4092$flex_grow$$,$cljs$cst$1016$opt_keys$$,$cljs$cst$4727$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_set_selected_token_set_id$$,$cljs$cst$2758$accumulate$$,$cljs$cst$8$str$$,$cljs$cst$5014$detach$$,
$cljs$cst$3414$app_DOT_common_DOT_attrs_SLASH_unset$$,$cljs$cst$1020$pred_forms$$,$cljs$cst$1262$enable_render_wasm_dpr$$,$cljs$cst$3932$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_instantiate_component$$,$cljs$cst$1210$urepl_server$$,$cljs$cst$3001$vai$$,$cljs$cst$3327$organization_custom_photo$$,$cljs$cst$0$flush_on_newline$$,$cljs$cst$4300$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_add_flow$$,$cljs$cst$793$clojure_DOT_test_DOT_check_DOT_generators_SLASH_elements$$,$cljs$cst$3288$app_DOT_main_DOT_data_DOT_team_SLASH_create_team$$,
$cljs$cst$2966$is_mask_QMARK_$$,$cljs$cst$774$max_tries_or_opts$$,$cljs$cst$4474$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_shape$$,$cljs$cst$2749$view$$,$cljs$cst$2710$altGlyphDef$$,$cljs$cst$2919$lighting_color$$,$cljs$cst$3326$custom_photo$$,$cljs$cst$4062$margin_block_start$$,$cljs$cst$4465$app_DOT_main_DOT_data_DOT_workspace_SLASH_initialize_file$$,$cljs$cst$941$encode_SLASH_json$$,$cljs$cst$4997$display_mentions$$,$cljs$cst$4634$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_layout_gap$$,
$cljs$cst$3874$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_nudge_selected_shapes$$,$cljs$cst$259$both$$,$cljs$cst$3625$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_duplicate_selected$$,$cljs$cst$2707$feComponentTransfer$$,$cljs$cst$2930$font_size_adjust$$,$cljs$cst$4068$border_end_end_radius$$,$cljs$cst$5083$show_error$$,$cljs$cst$2736$feOffset$$,$cljs$cst$3145$translation_QMARK_$$,$cljs$cst$1185$email_verification$$,$cljs$cst$1316$handlerForForeign$$,$cljs$cst$3699$force_media$$,
$cljs$cst$5059$teams_to_delete$$,$cljs$cst$595$catn$$,$cljs$cst$2342$app_DOT_main_DOT_data_DOT_modal_SLASH_update_modal$$,$cljs$cst$3574$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_undo$$,$cljs$cst$2928$marker_mid$$,$cljs$cst$5367$edition_QMARK_$$,$cljs$cst$4412$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_grid_cells$$,$cljs$cst$5277$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_frame$$,$cljs$cst$1277$minor$$,$cljs$cst$1225$quotes$$,$cljs$cst$1887$relative$$,$cljs$cst$2773$restart$$,
$cljs$cst$2811$panose_1$$,$cljs$cst$800$clojure_DOT_test_DOT_check_DOT_generators_SLASH_return$$,$cljs$cst$569$check$$,$cljs$cst$3480$app_DOT_main_DOT_data_DOT_comments_SLASH_update_comment_thread_frame$$,$cljs$cst$3603$selected_frame$$,$cljs$cst$2869$fy$$,$cljs$cst$2882$fx$$,$cljs$cst$4610$warning_SLASH_unknown$$,$cljs$cst$3044$anchor_para$$,$cljs$cst$2083$skip_components_QMARK_$$,$cljs$cst$718$altn$$,$cljs$cst$2547$allow_main_QMARK_$$,$cljs$cst$1937$mouse_over$$,$cljs$cst$4432$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_set_variant_id$$,
$cljs$cst$2808$dy$$,$cljs$cst$2777$dx$$,$cljs$cst$4058$margin_block_end$$,$cljs$cst$4438$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_duplicate_or_add_variant$$,$cljs$cst$3077$watcher$$,$cljs$cst$2800$xml_COLON_space$$,$cljs$cst$1444$colon_up_arrow$$,$cljs$cst$4333$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_notify_other_tabs_disconnect$$,$cljs$cst$4354$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_change_team_role$$,$cljs$cst$3634$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_commit$$,
$cljs$cst$1033$cljs_DOT_core_SLASH_count$$,$cljs$cst$2809$g2$$,$cljs$cst$2832$g1$$,$cljs$cst$2546$app_DOT_common_DOT_types_DOT_container_SLASH_container$$,$cljs$cst$1105$cljs_DOT_core_SLASH_fn$$,$cljs$cst$2922$marker_start$$,$cljs$cst$2494$change$$,$cljs$cst$2867$by$$,$cljs$cst$4821$move_unit_down$$,$cljs$cst$2632$mod_component$$,$cljs$cst$5230$comments_mode$$,$cljs$cst$3277$app_DOT_main_DOT_data_DOT_team_SLASH_delete_member$$,$cljs$cst$3985$variants_count$$,$cljs$cst$1836$minProperties$$,$cljs$cst$4101$copied_shapes$$,
$cljs$cst$3987$used_in$$,$cljs$cst$315$malli_DOT_core_SLASH_invalid_type$$,$cljs$cst$1822$c2$$,$cljs$cst$3495$app_DOT_main_DOT_data_DOT_fonts_SLASH_fetch_fonts$$,$cljs$cst$4440$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_rename_comp_or_variant_and_main$$,$cljs$cst$2688$map_to$$,$cljs$cst$1433$at$$,$cljs$cst$2255$challenge_required$$,$cljs$cst$1180$email_blacklist$$,$cljs$cst$2992$cyrillic$$,$cljs$cst$5172$component_main_external$$,$cljs$cst$853$malli_DOT_generator_SLASH_never_gen$$,$cljs$cst$860$op$$,
$cljs$cst$2727$defs$$,$cljs$cst$3296$reassign_to$$,$cljs$cst$3488$woff1_file_id$$,$cljs$cst$2293$os$$,$cljs$cst$2780$zoomAndPan$$,$cljs$cst$4206$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_undo_path$$,$cljs$cst$2748$switch$$,$cljs$cst$1415$buffer_level$$,$cljs$cst$1085$ps$$,$cljs$cst$4614$transformGroup$$,$cljs$cst$3134$app_DOT_main_DOT_data_DOT_changes_SLASH_sync_wasm_structural_changes$$,$cljs$cst$1106$cljs_DOT_core_SLASH_or$$,$cljs$cst$463$map_of$$,$cljs$cst$2986$tamil$$,$cljs$cst$1413$pretty_writer$$,
$cljs$cst$2702$font_face_uri$$,$cljs$cst$2497$removed$$,$cljs$cst$2069$mask_group$$,$cljs$cst$2714$mpath$$,$cljs$cst$1086$ks$$,$cljs$cst$4701$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_create_token_set$$,$cljs$cst$1487$condp$$,$cljs$cst$4057$min_inline_size$$,$cljs$cst$2249$max_retries$$,$cljs$cst$3769$filter_in$$,$cljs$cst$5184$shape_ref_cycle$$,$cljs$cst$3770$filter_id$$,$cljs$cst$4043$workspace_text_session_geom$$,$cljs$cst$3917$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_rename_typography$$,
$cljs$cst$3278$delete_team_member$$,$cljs$cst$4652$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_unapply_token$$,$cljs$cst$366$malli_DOT_core_SLASH_key_missing$$,$cljs$cst$3853$x_ranges$$,$cljs$cst$2885$k2$$,$cljs$cst$1841$maxItems$$,$cljs$cst$2884$k1$$,$cljs$cst$2848$k4$$,$cljs$cst$2845$k3$$,$cljs$cst$4072$border_start_start_radius$$,$cljs$cst$3123$completed$$,$cljs$cst$1586$app_DOT_util_DOT_http_SLASH_response$$,$cljs$cst$730$merge_default$$,$cljs$cst$3438$app_DOT_main_DOT_data_DOT_comments_SLASH_create_thread_on_workspace$$,
$cljs$cst$4053$margin_inline_end$$,$cljs$cst$1152$js$$,$cljs$cst$4943$move_project$$,$cljs$cst$1261$enable_component_thumbnails$$,$cljs$cst$5256$fit$$,$cljs$cst$3459$app_DOT_main_DOT_data_DOT_comments_SLASH_retrieve_comment_threads$$,$cljs$cst$5384$on_success_callback$$,$cljs$cst$4332$mcp_SLASH_pong$$,$cljs$cst$357$malli_DOT_core_SLASH_infinitely_expanding_schema$$,$cljs$cst$1443$up_arrow$$,$cljs$cst$675$boolean_QMARK_$$,$cljs$cst$2782$patternContentUnits$$,$cljs$cst$1533$app_DOT_common_DOT_geom_DOT_rect_SLASH_rect$$,
$cljs$cst$2572$media_id$$,$cljs$cst$3422$owner_fullname$$,$cljs$cst$1476$right_bracket$$,$cljs$cst$2677$ttf_url$$,$cljs$cst$2341$app_DOT_main_DOT_data_DOT_modal_SLASH_hide_modal$$,$cljs$cst$3896$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce$$,$cljs$cst$1307$preferBuffers$$,$cljs$cst$2555$any_main_descendant$$,$cljs$cst$4781$app_DOT_main_DOT_refs_SLASH_selected_shapes_data$$,$cljs$cst$3957$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_component_swap$$,
$cljs$cst$4415$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_grid_cell_position$$,$cljs$cst$2788$font_variant$$,$cljs$cst$2843$u2$$,$cljs$cst$2794$u1$$,$cljs$cst$2739$feFuncA$$,$cljs$cst$2705$feFuncB$$,$cljs$cst$2747$feFuncG$$,$cljs$cst$3307$update_team_invitation_role$$,$cljs$cst$4427$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_update_error$$,$cljs$cst$962$app_DOT_common_DOT_schema_SLASH_safe_double$$,$cljs$cst$2744$feFuncR$$,$cljs$cst$2801$markerWidth$$,$cljs$cst$4612$warning_SLASH_value$$,
$cljs$cst$5229$create_new_project$$,$cljs$cst$1414$sections$$,$cljs$cst$4965$move_files$$,$cljs$cst$2601$set_remote_synced$$,$cljs$cst$655$termination_safe$$,$cljs$cst$3824$snap_ignore_axis$$,$cljs$cst$3799$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_wasm_SLASH_render_thumbnail$$,$cljs$cst$3293$app_DOT_main_DOT_data_DOT_team_SLASH_update_team$$,$cljs$cst$268$app_DOT_common_DOT_data_SLASH_close_BANG_$$,$cljs$cst$512$re$$,$cljs$cst$1824$t2$$,$cljs$cst$3091$background_opacity$$,$cljs$cst$1823$t1$$,
$cljs$cst$1250$enable_frontend_svgo$$,$cljs$cst$4505$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_shape_context_menu$$,$cljs$cst$5386$accept_newsletter_updates$$,$cljs$cst$3125$dropped$$,$cljs$cst$3831$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_temporary_selrect$$,$cljs$cst$4077$tracks$$,$cljs$cst$2679$google$$,$cljs$cst$4944$app_DOT_main_DOT_data_DOT_dashboard_SLASH_toggle_project_pin$$,$cljs$cst$959$app_DOT_common_DOT_schema_SLASH_double$$,$cljs$cst$933$app_DOT_common_DOT_schema_SLASH_id$$,
$cljs$cst$4633$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_shape_position$$,$cljs$cst$5107$team_form$$,$cljs$cst$3777$include_metadata$$,$cljs$cst$4102$in_viewport$$,$cljs$cst$2605$set_flow$$,$cljs$cst$5254$app_DOT_main_DOT_data_DOT_viewer_SLASH_zoom_to_fit$$,$cljs$cst$5198$misplaced_slot$$,$cljs$cst$4637$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_generate_font_family_text_shape_update$$,$cljs$cst$3635$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_changes$$,
$cljs$cst$3147$app_DOT_main_DOT_data_DOT_changes_SLASH_commit_changes$$,$cljs$cst$2732$animateTransform$$,$cljs$cst$1268$enable_token_import_from_library$$,$cljs$cst$3301$resend$$,$cljs$cst$3838$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_apply_wasm_modifiesr$$,$cljs$cst$3648$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_create_artboard_from_shapes$$,$cljs$cst$3172$apply_to_library_QMARK_$$,$cljs$cst$3582$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_reset_zoom$$,$cljs$cst$282$cljs_DOT_core_SLASH_deref$$,
$cljs$cst$1775$text_content_attribute$$,$cljs$cst$3901$obj_id$$,$cljs$cst$1496$when$$,$cljs$cst$3868$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_increase_rotation$$,$cljs$cst$2735$feMerge$$,$cljs$cst$3009$symbols_2$$,$cljs$cst$895$unknown$$,$cljs$cst$2899$stroke_dasharray$$,$cljs$cst$4444$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_variant_switch$$,$cljs$cst$789$clojure_DOT_test_DOT_check_DOT_generators_SLASH_set$$,$cljs$cst$413$property_pred$$,$cljs$cst$3260$organization_avatar_bg_url$$,
$cljs$cst$3774$data_old_height$$,$cljs$cst$5297$overlays$$,$cljs$cst$3534$reset_QMARK_$$,$cljs$cst$3266$get_team_members$$,$cljs$cst$1082$cljs_DOT_spec_DOT_alpha_SLASH_conform_all$$,$cljs$cst$968$app_DOT_common_DOT_schema_SLASH_fn$$,$cljs$cst$5166$child_not_found$$,$cljs$cst$2663$syncing$$,$cljs$cst$2803$vert_origin_y$$,$cljs$cst$3839$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_move_frame_guides$$,$cljs$cst$2642$set_token$$,$cljs$cst$1209$backend_svgo$$,$cljs$cst$4506$disable_booleans_QMARK_$$,
$cljs$cst$3996$app_DOT_common_DOT_text_SLASH_novalue$$,$cljs$cst$816$clojure_DOT_test_DOT_check_DOT_generators_SLASH_large_integer$$,$cljs$cst$2962$once_QMARK_$$,$cljs$cst$2983$coptic$$,$cljs$cst$3878$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_move_selected$$,$cljs$cst$2916$clip_path$$,$cljs$cst$4557$on_pointer_enter_option$$,$cljs$cst$712$not_EQ_$$,$cljs$cst$4600$error_DOT_import_SLASH_style_dictionary_reference_errors$$,$cljs$cst$699$true_QMARK_$$,$cljs$cst$349$infos$$,$cljs$cst$955$app_DOT_common_DOT_schema_SLASH_set_of_uuid$$,
$cljs$cst$4288$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_remove_guide$$,$cljs$cst$3969$date$$,$cljs$cst$1272$modifier$$,$cljs$cst$2527$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_webhooks$$,$cljs$cst$2294$os_version$$,$cljs$cst$337$sci_DOT_core_SLASH_fork$$,$cljs$cst$907$double$$,$cljs$cst$4247$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_update_selection$$,$cljs$cst$1495$when_not$$,$cljs$cst$1439$padchar$$,$cljs$cst$703$sequential_QMARK_$$,$cljs$cst$536$malli_DOT_core_SLASH_walk_refs$$,
$cljs$cst$3533$shape_inst$$,$cljs$cst$3973$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_touch_component$$,$cljs$cst$5225$go_to_drafts$$,$cljs$cst$1076$conform_keys$$,$cljs$cst$4331$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_handle_ping$$,$cljs$cst$919$default_encoder$$,$cljs$cst$879$malli_DOT_error_SLASH_misspelled_value$$,$cljs$cst$3986$library_used_in$$,$cljs$cst$3524$ignore_flows_for$$,$cljs$cst$3881$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_update_positions$$,
$cljs$cst$4341$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_manage_mcp_notification$$,$cljs$cst$580$malli_DOT_core_SLASH_invalid_output$$,$cljs$cst$4877$move_unit_left$$,$cljs$cst$4632$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_layout_padding$$,$cljs$cst$3798$persist_QMARK_$$,$cljs$cst$3758$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_group_selected$$,$cljs$cst$4449$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_update_viewport_position$$,$cljs$cst$1206$soft_file_validation$$,
$cljs$cst$3058$bounding_boxes$$,$cljs$cst$2358$app_DOT_main_DOT_data_DOT_notifications_SLASH_show$$,$cljs$cst$4016$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_with_function$$,$cljs$cst$4285$app_DOT_main_DOT_data_DOT_workspace_DOT_fix_deleted_fonts_SLASH_fix_deleted_fonts_for_local_library$$,$cljs$cst$2756$stitchTiles$$,$cljs$cst$5356$on_end$$,$cljs$cst$4796$clear_undo$$,$cljs$cst$568$malli_DOT_core_SLASH_explain_guard$$,$cljs$cst$3578$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_auto$$,
$cljs$cst$4774$export_update$$,$cljs$cst$3311$app_DOT_main_DOT_data_DOT_team_SLASH_delete_team$$,$cljs$cst$3809$line_max_width$$,$cljs$cst$3789$max_time$$,$cljs$cst$2074$constraints_group$$,$cljs$cst$1405$buffering$$,$cljs$cst$1147$platform$$,$cljs$cst$1445$base_args$$,$cljs$cst$1773$text_content_structure$$,$cljs$cst$2873$patternTransform$$,$cljs$cst$3475$app_DOT_main_DOT_data_DOT_comments_SLASH_update_draft_thread$$,$cljs$cst$1556$event$$,$cljs$cst$1440$commainterval$$,$cljs$cst$1169$login_with_google$$,
$cljs$cst$2997$sinhala$$,$cljs$cst$4433$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_focus_property$$,$cljs$cst$881$malli_DOT_error_SLASH_misspelled_key$$,$cljs$cst$5361$app_DOT_main_DOT_ui_DOT_nitrate_DOT_nitrate_code_activation_modal_SLASH_redeem_nitrate_activation_code$$,$cljs$cst$2945$app_DOT_main_DOT_broadcast_SLASH_event$$,$cljs$cst$934$app_DOT_common_DOT_schema_SLASH_type$$,$cljs$cst$2145$app_DOT_main_DOT_router_SLASH_assign_exception$$,$cljs$cst$678$simple_ident_QMARK_$$,$cljs$cst$3592$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_shape$$,
$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$,$cljs$cst$2763$xlink_COLON_arcrole$$,$cljs$cst$5276$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_frame_by_index$$,$cljs$cst$3788$calc_time$$,$cljs$cst$3049$start_offset$$,$cljs$cst$4462$app_DOT_main_DOT_data_DOT_workspace_SLASH_bundle_fetched$$,$cljs$cst$4991$error_url$$,$cljs$cst$5253$app_DOT_main_DOT_data_DOT_viewer_SLASH_reset_zoom$$,$cljs$cst$2963$xml$$,$cljs$cst$5298$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_workspace$$,$cljs$cst$2094$app_DOT_common_DOT_types_DOT_shape_tree_SLASH_old_id$$,
$cljs$cst$1240$file_validation$$,$cljs$cst$1175$login_with_oidc$$,$cljs$cst$3523$ignore_mask$$,$cljs$cst$2271$form_data_QMARK_$$,$cljs$cst$3467$mark_all_threads_as_read$$,$cljs$cst$4461$workspace_ready$$,$cljs$cst$2604$set_guide$$,$cljs$cst$2284$upload_chunk$$,$cljs$cst$4582$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_spread$$,$cljs$cst$5404$shown_thumbnails$$,$cljs$cst$1120$cljs_DOT_spec_DOT_alpha_SLASH_conformer$$,$cljs$cst$4863$zoom_lense_increase$$,$cljs$cst$2066$text_display_group$$,
$cljs$cst$1477$cljs_DOT_core_SLASH_lift_ns$$,$cljs$cst$2298$screen_width$$,$cljs$cst$2627$del_color$$,$cljs$cst$3477$app_DOT_main_DOT_data_DOT_comments_SLASH_hide_comment_options$$,$cljs$cst$1558$scroll_height$$,$cljs$cst$4398$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_create_layout_from_selection$$,$cljs$cst$5159$masking_child_QMARK_$$,$cljs$cst$2262$create_file_object_thumbnail$$,$cljs$cst$1173$login_with_github$$,$cljs$cst$5262$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_thumbnails_panel$$,
$cljs$cst$4436$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_transform_in_variant$$,$cljs$cst$1633$metadata$$,$cljs$cst$3819$child_height$$,$cljs$cst$990$gfn$$,$cljs$cst$3872$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_start_move$$,$cljs$cst$3490$woff2_file_id$$,$cljs$cst$4280$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_navigate_to_comment_from_dashboard$$,$cljs$cst$1907$inner_shadow$$,$cljs$cst$2896$text_anchor$$,$cljs$cst$2912$shape_rendering$$,$cljs$cst$573$gen$$,
$cljs$cst$3491$app_DOT_main_DOT_fonts_SLASH_ttf_file_id$$,$cljs$cst$5307$zoom_viewer$$,$cljs$cst$3036$stopopacity$$,$cljs$cst$3375$worker_error$$,$cljs$cst$3756$shape_path$$,$cljs$cst$827$property$$,$cljs$cst$656$aliases$$,$cljs$cst$2250$base_delay_ms$$,$cljs$cst$792$clojure_DOT_test_DOT_check_DOT_generators_SLASH_fmap$$,$cljs$cst$4996$mention$$,$cljs$cst$4267$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_clear_drawing$$,$cljs$cst$668$pos_int_QMARK_$$,$cljs$cst$3613$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_memorize_duplicated$$,
$cljs$cst$3355$app_DOT_main_DOT_data_DOT_auth_SLASH_logged_out$$,$cljs$cst$4782$app_DOT_main_DOT_refs$$,$cljs$cst$684$simple_symbol_QMARK_$$,$cljs$cst$885$malli_DOT_error_SLASH_likely_misspelling_of$$,$cljs$cst$631$re_parser$$,$cljs$cst$4709$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_delete_token_set$$,$cljs$cst$5343$flex_element$$,$cljs$cst$4895$preview_frame$$,$cljs$cst$2733$feColorMatrix$$,$cljs$cst$743$gen_delims$$,$cljs$cst$1083$cljs_DOT_spec_DOT_alpha_SLASH_accept$$,
$cljs$cst$1567$app_DOT_util_DOT_dom_SLASH_focus_element$$,$cljs$cst$4504$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_context_menu$$,$cljs$cst$153$finally$$,$cljs$cst$4617$warnings$$,$cljs$cst$4719$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_delete_token$$,$cljs$cst$3486$create_upload_session$$,$cljs$cst$140$cljs_DOT_core_SLASH_ExceptionInfo$$,$cljs$cst$3186$app_DOT_main_DOT_data_DOT_media_SLASH_blob$$,$cljs$cst$462$closed$$,$cljs$cst$3546$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_expand_all_parents$$,
$cljs$cst$5209$variant_bad_variant_name$$,$cljs$cst$1224$token_tokenscript$$,$cljs$cst$4428$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_remove_property$$,$cljs$cst$3095$aa_threshold$$,$cljs$cst$3775$use_thumbnails$$,$cljs$cst$1940$mouse_press$$,$cljs$cst$3528$new_shape_id$$,$cljs$cst$106$alt_impl$$,$cljs$cst$1840$minItems$$,$cljs$cst$1436$minpad$$,$cljs$cst$1828$minimum$$,$cljs$cst$2931$glyph_orientation_vertical$$,$cljs$cst$3900$raw_change$$,$cljs$cst$3863$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_trigger_bounding_box_cloaking$$,
$cljs$cst$3671$view_box$$,$cljs$cst$1204$secure_session_cookies$$,$cljs$cst$1014$pred_exprs$$,$cljs$cst$4904$total_count$$,$cljs$cst$2821$diffuseConstant$$,$cljs$cst$2091$force_id$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$,$cljs$cst$424$uuid$$,$cljs$cst$4437$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_add_component_or_variant$$,$cljs$cst$4648$applied_to$$,$cljs$cst$2742$tref$$,$cljs$cst$4619$references$$,$cljs$cst$3830$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_modifiers$$,
$cljs$cst$3334$opened$$,$cljs$cst$4303$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_update_flow$$,$cljs$cst$395$malli_DOT_core_SLASH_non_associative_schema$$,$cljs$cst$3628$workspace_pre_focus$$,$cljs$cst$3823$snap_precision$$,$cljs$cst$905$malli_DOT_transform_SLASH_invalid_transformer$$,$cljs$cst$2900$mask_type$$,$cljs$cst$4515$app_DOT_main_DOT_data_DOT_workspace_SLASH_toggle_distances_display$$,$cljs$cst$5101$teams_to_transfer$$,$cljs$cst$170$def$$,$cljs$cst$3401$plugin_permissions_update$$,
$cljs$cst$4642$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_dimensions_token$$,$cljs$cst$3616$move_delta_QMARK_$$,$cljs$cst$3564$transaction$$,$cljs$cst$4430$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_add_new_property$$,$cljs$cst$1159$app_DOT_common_DOT_logging_SLASH_timestamp$$,$cljs$cst$3026$symbols$$,$cljs$cst$419$some$$,$cljs$cst$4215$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_preview_next_point$$,$cljs$cst$3482$app_DOT_main_DOT_data_DOT_comments_SLASH_detach_comment_thread$$,
$cljs$cst$2921$dominant_baseline$$,$cljs$cst$822$clojure_DOT_test_DOT_check_DOT_generators_SLASH_string_alphanumeric$$,$cljs$cst$5194$instance_head_not_frame$$,$cljs$cst$2998$sora_sompeng$$,$cljs$cst$2086$app_DOT_common_DOT_types_DOT_shape_tree_SLASH_index_frames$$,$cljs$cst$3812$child_min_width$$,$cljs$cst$3092$on_render$$,$cljs$cst$5287$app_DOT_main_DOT_data_DOT_viewer_SLASH_close_overlay$$,$cljs$cst$2842$numOctaves$$,$cljs$cst$3065$gl_context$$,$cljs$cst$4112$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_selected_props$$,
$cljs$cst$797$clojure_DOT_test_DOT_check_DOT_generators_SLASH_such_that$$,$cljs$cst$2005$used_pos$$,$cljs$cst$4654$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_on_toggle_token$$,$cljs$cst$859$malli_DOT_generator_SLASH_generator_ast$$,$cljs$cst$2988$music$$,$cljs$cst$3190$app_DOT_main_DOT_data_DOT_media_SLASH_file$$,$cljs$cst$1200$strict_session_cookies$$,$cljs$cst$3392$app_DOT_plugins_DOT_flags_SLASH_reset$$,$cljs$cst$775$num_elements$$,$cljs$cst$4149$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_add_stroke$$,
$cljs$cst$5204$invalid_variant_id$$,$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,$cljs$cst$5295$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_dashboard$$,$cljs$cst$3512$app_DOT_main_DOT_data_DOT_project_SLASH_initialize_project$$,$cljs$cst$4873$move_fast_up$$,$cljs$cst$1566$descent$$,$cljs$cst$3087$fillRule$$,$cljs$cst$3999$$id$$,$cljs$cst$5091$tab_index$$,$cljs$cst$4942$app_DOT_main_DOT_data_DOT_dashboard_SLASH_move_project$$,$cljs$cst$3040$gradienttransform$$,$cljs$cst$778$infinite_QMARK_$$,
$cljs$cst$2833$z$$,$cljs$cst$1446$w$$,$cljs$cst$4626$interactive_QMARK_$$,$cljs$cst$1451$n$$,$cljs$cst$3790$min_time$$,$cljs$cst$733$k$$,$cljs$cst$598$f$$,$cljs$cst$1521$c$$,$cljs$cst$3136$app_DOT_main_DOT_data_DOT_changes_SLASH_apply_changes_localy$$,$cljs$cst$1449$e$$,$cljs$cst$1447$d$$,$cljs$cst$1804$change_property$$,$cljs$cst$711$_EQ_$$,$cljs$cst$709$_LT_$$,$cljs$cst$4879$stop_measure$$,$cljs$cst$715$_QMARK_$$,$cljs$cst$160$let_STAR_$$,$cljs$cst$707$_GT_$$,$cljs$cst$151$try$$,$cljs$cst$5323$copy_data$$,
$cljs$cst$713$_PLUS_$$,$cljs$cst$714$_STAR_$$,$cljs$cst$3846$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_apply_modifiers_STAR_$$,$cljs$cst$4194$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_points$$,$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$,$cljs$cst$5098$on_submit$$,$cljs$cst$4464$app_DOT_main_DOT_data_DOT_workspace_SLASH_fetch_bundle$$,$cljs$cst$5182$component_id_mismatch$$,$cljs$cst$2168$interrupt_QMARK_$$,$cljs$cst$2975$font_url$$,$cljs$cst$3194$app_DOT_main_DOT_data_DOT_media_SLASH_media_upload$$,
$cljs$cst$3056$simple_selection$$,$cljs$cst$3600$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_shapes$$,$cljs$cst$4466$app_DOT_main_DOT_data_DOT_workspace_SLASH_initialize_workspace$$,$cljs$cst$4052$padding_block_start$$,$cljs$cst$3465$get_unread_comment_threads$$,$cljs$cst$3557$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_common_SLASH_finish_path$$,$cljs$cst$2548$main_instance_QMARK_$$,$cljs$cst$2850$externalResourcesRequired$$,$cljs$cst$3455$app_DOT_main_DOT_data_DOT_comments_SLASH_delete_comment$$,
$cljs$cst$1453$clauses$$,$cljs$cst$2301$screen_orientation$$,$cljs$cst$3936$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_detach_selected_components$$,$cljs$cst$4114$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_transit_shapes$$,$cljs$cst$4282$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_navigate_to_comment$$,$cljs$cst$3570$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_reset_undo$$,$cljs$cst$2591$with_context_QMARK_$$,$cljs$cst$762$duplicates$$,$cljs$cst$4775$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_retry_last_export$$,
$cljs$cst$1032$cljs_DOT_core_SLASH__EQ_$$,$cljs$cst$3626$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_update_focus_shapes$$,$cljs$cst$2753$gradientUnits$$,$cljs$cst$3762$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_unmask_group$$,$cljs$cst$3753$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_show_toolbar$$,$cljs$cst$977$cljs_DOT_spec_DOT_alpha_SLASH_unknown$$,$cljs$cst$1505$locking$$,$cljs$cst$4015$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_attrs$$,$cljs$cst$3267$app_DOT_main_DOT_data_DOT_team_SLASH_invitations_fetched$$,
$cljs$cst$3270$get_team_invitations$$,$cljs$cst$3023$arabic$$,$cljs$cst$2253$request_body_too_large$$,$cljs$cst$4307$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_remove_interaction$$,$cljs$cst$2789$filterUnits$$,$cljs$cst$2569$paste_feature_not_supported$$,$cljs$cst$5186$shape_ref_in_main$$,$cljs$cst$3031$span$$,$cljs$cst$2790$pathLength$$,$cljs$cst$1265$enable_inspect_styles$$,$cljs$cst$3005$devanagari$$,$cljs$cst$1255$enable_backend_worker$$,$cljs$cst$2283$app_DOT_main_DOT_repo_SLASH_multipart_upload$$,
$cljs$cst$864$malli_DOT_generator_SLASH_such_that_failure$$,$cljs$cst$2491$app_DOT_main_DOT_data_DOT_common_SLASH_change_team_role$$,$cljs$cst$2766$hanging$$,$cljs$cst$2813$vert_origin_x$$;$APP.$cljs$cst$5056$app_DOT_main_DOT_data_DOT_nitrate_SLASH_nitrate_entry_pending_popup$$=new $APP.$cljs$core$Keyword$$("app.main.data.nitrate","nitrate-entry-pending-popup","app.main.data.nitrate/nitrate-entry-pending-popup",1850797186);
$cljs$cst$2459$app_DOT_main_DOT_router_SLASH_nav_back$$=new $APP.$cljs$core$Keyword$$("app.main.router","nav-back","app.main.router/nav-back",1728663407);$cljs$cst$5196$non_deleted_component_cannot_have_objects$$=new $APP.$cljs$core$Keyword$$(null,"non-deleted-component-cannot-have-objects","non-deleted-component-cannot-have-objects",511800600);$cljs$cst$2796$spreadMethod$$=new $APP.$cljs$core$Keyword$$(null,"spreadMethod","spreadMethod",223383336);
$cljs$cst$5210$variant_component_bad_name$$=new $APP.$cljs$core$Keyword$$(null,"variant-component-bad-name","variant-component-bad-name",550703572);$APP.$cljs$cst$2040$dotted$$=new $APP.$cljs$core$Keyword$$(null,"dotted","dotted",-1504510307);$APP.$cljs$cst$4153$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_reorder_strokes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","reorder-strokes","app.main.data.workspace.colors/reorder-strokes",1056676007);
$APP.$cljs$cst$5124$dashboard_team_settings$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-team-settings","dashboard-team-settings",-1522044016);$cljs$cst$4405$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_remove_layout_track$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","remove-layout-track","app.main.data.workspace.shape-layout/remove-layout-track",535512799);
$cljs$cst$4399$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_remove_shape_layout$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","remove-shape-layout","app.main.data.workspace.shape-layout/remove-shape-layout",1271415407);$APP.$cljs$cst$5293$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_collapse$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","toggle-collapse","app.main.data.viewer/toggle-collapse",1666263275);
$cljs$cst$1369$intra_block_nl$$=new $APP.$cljs$core$Keyword$$(null,"intra-block-nl","intra-block-nl",1808826875);$cljs$cst$1450$exponentchar$$=new $APP.$cljs$core$Keyword$$(null,"exponentchar","exponentchar",1986664222);$APP.$cljs$cst$1978$number$$=new $APP.$cljs$core$Keyword$$(null,"number","number",1570378438);$APP.$cljs$cst$4621$typography_key$$=new $APP.$cljs$core$Keyword$$(null,"typography-key","typography-key",64987307);
$cljs$cst$4613$platforms$$=new $APP.$cljs$core$Keyword$$(null,"platforms","platforms",1418350461);$cljs$cst$1992$sided_margins$$=new $APP.$cljs$core$Keyword$$(null,"sided-margins","sided-margins",-355961218);$APP.$cljs$cst$3695$on_image$$=new $APP.$cljs$core$Keyword$$(null,"on-image","on-image",1794160201);$cljs$cst$3339$app_DOT_main_DOT_data_DOT_websocket_SLASH_opened$$=new $APP.$cljs$core$Keyword$$("app.main.data.websocket","opened","app.main.data.websocket/opened",1251993736);
$cljs$cst$3062$events_times$$=new $APP.$cljs$core$Keyword$$(null,"events-times","events-times",420818190);$cljs$cst$1317$with_meta$$=new $APP.$cljs$core$Keyword$$(null,"with-meta","with-meta",-1566856820);$cljs$cst$3652$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_toggle_visibility_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","toggle-visibility-selected","app.main.data.workspace.shapes/toggle-visibility-selected",-1946017969);
$APP.$cljs$cst$2054$axis$$=new $APP.$cljs$core$Keyword$$(null,"axis","axis",-1215390822);$cljs$cst$3631$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_start$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","update-shapes-buffer-start","app.main.data.workspace.shapes/update-shapes-buffer-start",-1950154985);$APP.$cljs$cst$4813$draw_text$$=new $APP.$cljs$core$Keyword$$(null,"draw-text","draw-text",2017889925);
$APP.$cljs$cst$3694$uris$$=new $APP.$cljs$core$Keyword$$(null,"uris","uris",-253706916);$APP.$cljs$cst$1686$layout_padding$$=new $APP.$cljs$core$Keyword$$(null,"layout-padding","layout-padding",1903395747);$cljs$cst$697$nil_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"nil?","nil?",1612038930,null);$APP.$cljs$cst$2000$variant_id$$=new $APP.$cljs$core$Keyword$$(null,"variant-id","variant-id",1171818270);
$APP.$cljs$cst$4414$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_merge_cells$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","merge-cells","app.main.data.workspace.shape-layout/merge-cells",-300475520);$APP.$cljs$cst$4932$app_DOT_main_DOT_data_DOT_dashboard_SLASH_hide_file_menu$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","hide-file-menu","app.main.data.dashboard/hide-file-menu",1101642004);
$cljs$cst$796$clojure_DOT_test_DOT_check_DOT_generators_SLASH_one_of$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","one-of","clojure.test.check.generators/one-of",-183339191,null);$APP.$cljs$cst$4270$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_change_orientation$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.drawing","change-orientation","app.main.data.workspace.drawing/change-orientation",1702793855);
$cljs$cst$4351$unsubscribe_file$$=new $APP.$cljs$core$Keyword$$(null,"unsubscribe-file","unsubscribe-file",-130369757);$APP.$cljs$cst$4469$workspace_versions$$=new $APP.$cljs$core$Keyword$$(null,"workspace-versions","workspace-versions",-347907449);$cljs$cst$2075$radius_group$$=new $APP.$cljs$core$Keyword$$(null,"radius-group","radius-group",-848842979);$cljs$cst$3368$invalid_paste_data$$=new $APP.$cljs$core$Keyword$$(null,"invalid-paste-data","invalid-paste-data",1058482108);
$APP.$cljs$cst$5373$release_notes$$=new $APP.$cljs$core$Keyword$$(null,"release-notes","release-notes",1238210686);$cljs$cst$3247$app_DOT_main_DOT_data_DOT_profile_SLASH_fetch_access_tokens$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","fetch-access-tokens","app.main.data.profile/fetch-access-tokens",-1393543345);$cljs$cst$336$sci_DOT_core_SLASH_init$$=new $APP.$cljs$core$Symbol$$("sci.core","init","sci.core/init",-622666095,null);
$cljs$cst$3235$file_comments_users$$=new $APP.$cljs$core$Keyword$$(null,"file-comments-users","file-comments-users",1002954415);$cljs$cst$293$recursive$$=new $APP.$cljs$core$Keyword$$(null,"recursive","recursive",718885872);$cljs$cst$3818$child_width$$=new $APP.$cljs$core$Keyword$$(null,"child-width","child-width",-597845627);$APP.$cljs$cst$4203$shift_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"shift?","shift?",-1034734696);
$APP.$cljs$cst$2022$lighten$$=new $APP.$cljs$core$Keyword$$(null,"lighten","lighten",-234464980);$cljs$cst$2260$export_binfile$$=new $APP.$cljs$core$Keyword$$(null,"export-binfile","export-binfile",-1093144052);$cljs$cst$4990$on_remove_plugin$$=new $APP.$cljs$core$Keyword$$(null,"on-remove-plugin","on-remove-plugin",-58459040);$APP.$cljs$cst$450$optional$$=new $APP.$cljs$core$Keyword$$(null,"optional","optional",2053951509);
$APP.$cljs$cst$5064$app_DOT_main_DOT_data_DOT_nitrate_SLASH_add_team_to_organization$$=new $APP.$cljs$core$Keyword$$("app.main.data.nitrate","add-team-to-organization","app.main.data.nitrate/add-team-to-organization",-1006660543);$APP.$cljs$cst$1239$token_combobox$$=new $APP.$cljs$core$Keyword$$(null,"token-combobox","token-combobox",-2136397862);$cljs$cst$359$malli_DOT_core_SLASH_find$$=new $APP.$cljs$core$Keyword$$("malli.core","find","malli.core/find",163301512);
$APP.$cljs$cst$2229$thumbnails$$=new $APP.$cljs$core$Keyword$$(null,"thumbnails","thumbnails",-529239572);$APP.$cljs$cst$3075$shape_panel$$=new $APP.$cljs$core$Keyword$$(null,"shape-panel","shape-panel",-2139910340);$cljs$cst$3472$app_DOT_main_DOT_data_DOT_comments_SLASH_update_filters$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","update-filters","app.main.data.comments/update-filters",-380440015);$APP.$cljs$cst$4420$grid_id$$=new $APP.$cljs$core$Keyword$$(null,"grid-id","grid-id",1007140206);
$cljs$cst$4836$move_unit_up$$=new $APP.$cljs$core$Keyword$$(null,"move-unit-up","move-unit-up",-87570067);$APP.$cljs$cst$4130$picking_color_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"picking-color?","picking-color?",-819672832);$APP.$cljs$cst$4311$editing_interaction_index$$=new $APP.$cljs$core$Keyword$$(null,"editing-interaction-index","editing-interaction-index",1202734402);$cljs$cst$2575$components_v2$$=new $APP.$cljs$core$Keyword$$(null,"components-v2","components-v2",-708922978);
$cljs$cst$5190$nested_copy_not_allowed$$=new $APP.$cljs$core$Keyword$$(null,"nested-copy-not-allowed","nested-copy-not-allowed",-425843986);$APP.$cljs$cst$4718$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_bulk_update_tokens$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","bulk-update-tokens","app.main.data.workspace.tokens.library-edit/bulk-update-tokens",1820570607);
$cljs$cst$2552$all_main_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"all-main?","all-main?",410878230);$cljs$cst$3835$selection_rect_cache$$=new $APP.$cljs$core$Keyword$$(null,"selection-rect-cache","selection-rect-cache",1846080478);$APP.$cljs$cst$2209$workspace_layout$$=new $APP.$cljs$core$Keyword$$(null,"workspace-layout","workspace-layout",420938173);$cljs$cst$2878$unicode$$=new $APP.$cljs$core$Keyword$$(null,"unicode","unicode",-542572710);
$APP.$cljs$cst$5408$register_validate$$=new $APP.$cljs$core$Keyword$$(null,"register-validate","register-validate",425170720);$cljs$cst$2979$is_fallback$$=new $APP.$cljs$core$Keyword$$(null,"is-fallback","is-fallback",-2080537356);$APP.$cljs$cst$1691$layout_align_content$$=new $APP.$cljs$core$Keyword$$(null,"layout-align-content","layout-align-content",-1511926473);$cljs$cst$4854$select_parent_layer$$=new $APP.$cljs$core$Keyword$$(null,"select-parent-layer","select-parent-layer",-2143444363);
$cljs$cst$3085$thumbnail_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"thumbnail?","thumbnail?",1872474018);$cljs$cst$3551$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_expand_subtree$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.collapse","expand-subtree","app.main.data.workspace.collapse/expand-subtree",-2019176692);$cljs$cst$906$float$$=new $APP.$cljs$core$Symbol$$(null,"float","float",-91857841,null);
$APP.$cljs$cst$5366$licenses$$=new $APP.$cljs$core$Keyword$$(null,"licenses","licenses",521774891);$APP.$cljs$cst$747$query$$=new $APP.$cljs$core$Keyword$$(null,"query","query",-1288509510);$cljs$cst$1211$v2_migration$$=new $APP.$cljs$core$Keyword$$(null,"v2-migration","v2-migration",-647211158);$APP.$cljs$cst$1484$queue$$=new $APP.$cljs$core$Keyword$$(null,"queue","queue",1455835879);$cljs$cst$1507$if_let$$=new $APP.$cljs$core$Symbol$$(null,"if-let","if-let",1803593690,null);
$cljs$cst$5285$app_DOT_main_DOT_data_DOT_viewer_SLASH_open_overlay$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","open-overlay","app.main.data.viewer/open-overlay",-456952813);$cljs$cst$976$cljs_DOT_spec_DOT_alpha_SLASH_name$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","name","cljs.spec.alpha/name",205233570);
$cljs$cst$3979$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_libraries_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","libraries-fetched","app.main.data.workspace.libraries/libraries-fetched",626857502);$APP.$cljs$cst$5035$delete_file_snapshot$$=new $APP.$cljs$core$Keyword$$(null,"delete-file-snapshot","delete-file-snapshot",-364018056);$cljs$cst$3298$leave_team$$=new $APP.$cljs$core$Keyword$$(null,"leave-team","leave-team",-1470569524);
$cljs$cst$4714$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_create_token_and_set$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","create-token-and-set","app.main.data.workspace.tokens.library-edit/create-token-and-set",811480295);
$APP.$cljs$cst$4144$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_hide_fill_on_export$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","change-hide-fill-on-export","app.main.data.workspace.colors/change-hide-fill-on-export",479858268);
$cljs$cst$4397$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_create_layout_from_id$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","create-layout-from-id","app.main.data.workspace.shape-layout/create-layout-from-id",282302992);
$cljs$cst$4629$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_fill$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","update-fill","app.main.data.workspace.tokens.application/update-fill",-364177809);$APP.$cljs$cst$2659$set_base_font_size$$=new $APP.$cljs$core$Keyword$$(null,"set-base-font-size","set-base-font-size",-1438596312);$APP.$cljs$cst$5406$who_inspect$$=new $APP.$cljs$core$Keyword$$(null,"who-inspect","who-inspect",525863768);
$cljs$cst$2784$repeatDur$$=new $APP.$cljs$core$Keyword$$(null,"repeatDur","repeatDur",963760998);$APP.$cljs$cst$3420$vcenter$$=new $APP.$cljs$core$Keyword$$(null,"vcenter","vcenter",564475646);$cljs$cst$3596$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_prev_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","select-prev-shape","app.main.data.workspace.selection/select-prev-shape",-47001125);
$cljs$cst$671$pos_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"pos?","pos?",-244377722,null);$cljs$cst$1287$prop__GT_key$$=new $APP.$cljs$core$Keyword$$(null,"prop-\x3ekey","prop-\x3ekey",-1297715246);$cljs$cst$3300$app_DOT_main_DOT_data_DOT_team_SLASH_create_invitations$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","create-invitations","app.main.data.team/create-invitations",207317748);
$APP.$cljs$cst$2378$reitit_DOT_trie_SLASH_following_parameters$$=new $APP.$cljs$core$Keyword$$("reitit.trie","following-parameters","reitit.trie/following-parameters",-1072685800);$APP.$cljs$cst$3249$app_DOT_main_DOT_data_DOT_profile_SLASH_access_token_created$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","access-token-created","app.main.data.profile/access-token-created",-1371452256);
$cljs$cst$4521$app_DOT_main_DOT_data_DOT_workspace_SLASH_fix_orphan_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","fix-orphan-shapes","app.main.data.workspace/fix-orphan-shapes",-1593553661);$cljs$cst$1435$remaining_arg_count$$=new $APP.$cljs$core$Keyword$$(null,"remaining-arg-count","remaining-arg-count",-1216589335);
$APP.$cljs$cst$2261$app_DOT_util_DOT_sse_SLASH_restore_deleted_team_files$$=new $APP.$cljs$core$Keyword$$("app.util.sse","restore-deleted-team-files","app.util.sse/restore-deleted-team-files",-2130814225);$cljs$cst$2987$ol_chiki$$=new $APP.$cljs$core$Keyword$$(null,"ol-chiki","ol-chiki",-1012768220);$cljs$cst$3063$wasm_viewbox$$=new $APP.$cljs$core$Keyword$$(null,"wasm-viewbox","wasm-viewbox",-1694070386);
$cljs$cst$2967$non_blocking$$=new $APP.$cljs$core$Keyword$$(null,"non-blocking","non-blocking",-1539350067);$cljs$cst$4054$border_end_start_radius$$=new $APP.$cljs$core$Keyword$$(null,"border-end-start-radius","border-end-start-radius",-251560249);$APP.$cljs$cst$222$NaN$$=new $APP.$cljs$core$Symbol$$(null,"NaN","NaN",666918153,null);
$cljs$cst$3510$app_DOT_main_DOT_data_DOT_project_SLASH_fetch_project$$=new $APP.$cljs$core$Keyword$$("app.main.data.project","fetch-project","app.main.data.project/fetch-project",2128789384);$cljs$cst$770$returned$$=new $APP.$cljs$core$Keyword$$(null,"returned","returned",-2020439163);$cljs$cst$2866$specularConstant$$=new $APP.$cljs$core$Keyword$$(null,"specularConstant","specularConstant",-1556454024);
$cljs$cst$3549$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_expand_collapse$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.collapse","expand-collapse","app.main.data.workspace.collapse/expand-collapse",1532499910);$APP.$cljs$cst$1138$iso$$=new $APP.$cljs$core$Keyword$$(null,"iso","iso",-1366207543);$cljs$cst$5096$valid_item_fn$$=new $APP.$cljs$core$Keyword$$(null,"valid-item-fn","valid-item-fn",-2057807375);
$APP.$cljs$cst$3167$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page$$=new $APP.$cljs$core$Keyword$$("app.common.files.changes-builder","page","app.common.files.changes-builder/page",-623448303);$cljs$cst$3597$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_next_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","select-next-shape","app.main.data.workspace.selection/select-next-shape",661431164);
$cljs$cst$645$explainer$$=new $APP.$cljs$core$Keyword$$(null,"explainer","explainer",-2002221924);$cljs$cst$4989$on_open_plugin$$=new $APP.$cljs$core$Keyword$$(null,"on-open-plugin","on-open-plugin",-1345349261);$cljs$cst$3493$otf_file_id$$=new $APP.$cljs$core$Keyword$$(null,"otf-file-id","otf-file-id",-108616880);$APP.$cljs$cst$2644$token_id$$=new $APP.$cljs$core$Keyword$$(null,"token-id","token-id",-764089526);
$cljs$cst$2917$stroke_linecap$$=new $APP.$cljs$core$Keyword$$(null,"stroke-linecap","stroke-linecap",-1201103248);$APP.$cljs$cst$1614$shapes$$=new $APP.$cljs$core$Keyword$$(null,"shapes","shapes",1897594879);$cljs$cst$2926$flood_color$$=new $APP.$cljs$core$Keyword$$(null,"flood-color","flood-color",1622703322);
$APP.$cljs$cst$4976$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_files_immediately$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","delete-files-immediately","app.main.data.dashboard/delete-files-immediately",-1239559697);$APP.$cljs$cst$3727$layers$$=new $APP.$cljs$core$Keyword$$(null,"layers","layers",1944875032);$cljs$cst$2891$keySplines$$=new $APP.$cljs$core$Keyword$$(null,"keySplines","keySplines",-1138000833);
$APP.$cljs$cst$2347$floating$$=new $APP.$cljs$core$Keyword$$(null,"floating","floating",-1978091029);$APP.$cljs$cst$3664$column_total_size$$=new $APP.$cljs$core$Keyword$$(null,"column-total-size","column-total-size",1061541632);$cljs$cst$110$ready$$=new $APP.$cljs$core$Keyword$$(null,"ready","ready",1086465795);
$APP.$cljs$cst$5036$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_pin_version$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","pin-version","app.main.data.workspace.versions/pin-version",-1713491836);$APP.$cljs$cst$2184$selected_project$$=new $APP.$cljs$core$Keyword$$(null,"selected-project","selected-project",993223033);$cljs$cst$2608$set_comment_thread_position$$=new $APP.$cljs$core$Keyword$$(null,"set-comment-thread-position","set-comment-thread-position",1716614827);
$cljs$cst$1154$app_DOT_common_DOT_logging_SLASH_sync_QMARK_$$=new $APP.$cljs$core$Keyword$$("app.common.logging","sync?","app.common.logging/sync?",-1206954327);$APP.$cljs$cst$5368$dragging_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"dragging?","dragging?",-995941410);$APP.$cljs$cst$5113$resolved$$=new $APP.$cljs$core$Keyword$$(null,"resolved","resolved",968763567);$cljs$cst$2723$missing_glyph$$=new $APP.$cljs$core$Keyword$$(null,"missing-glyph","missing-glyph",1334509298);
$APP.$cljs$cst$3803$layout_gap_row$$=new $APP.$cljs$core$Keyword$$(null,"layout-gap-row","layout-gap-row",609410826);$cljs$cst$385$malli_DOT_core_SLASH_nil$$=new $APP.$cljs$core$Keyword$$("malli.core","nil","malli.core/nil",296405773);$APP.$cljs$cst$4406$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_duplicate_layout_track$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","duplicate-layout-track","app.main.data.workspace.shape-layout/duplicate-layout-track",260016686);
$cljs$cst$2816$underline_thickness$$=new $APP.$cljs$core$Keyword$$(null,"underline-thickness","underline-thickness",1528492621);$APP.$cljs$cst$1479$arglists$$=new $APP.$cljs$core$Keyword$$(null,"arglists","arglists",1661989754);$APP.$cljs$cst$218$end_column$$=new $APP.$cljs$core$Keyword$$(null,"end-column","end-column",1425389514);$APP.$cljs$cst$2557$ignore_geometry$$=new $APP.$cljs$core$Keyword$$(null,"ignore-geometry","ignore-geometry",1630780695);
$cljs$cst$4094$grid_auto_flow$$=new $APP.$cljs$core$Keyword$$(null,"grid-auto-flow","grid-auto-flow",-1754873684);$APP.$cljs$cst$5416$error_href$$=new $APP.$cljs$core$Keyword$$(null,"error-href","error-href",-1882436137);$APP.$cljs$cst$4160$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_apply_color_from_palette$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","apply-color-from-palette","app.main.data.workspace.colors/apply-color-from-palette",1499511946);
$cljs$cst$2068$fill_group$$=new $APP.$cljs$core$Keyword$$(null,"fill-group","fill-group",1027726676);$cljs$cst$3926$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_delete_component$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","delete-component","app.main.data.workspace.libraries/delete-component",1399838040);$APP.$cljs$cst$3505$delete_font$$=new $APP.$cljs$core$Keyword$$(null,"delete-font","delete-font",1742044319);
$APP.$cljs$cst$4251$moving_nodes$$=new $APP.$cljs$core$Keyword$$(null,"moving-nodes","moving-nodes",-1718310036);$cljs$cst$4946$app_DOT_main_DOT_data_DOT_dashboard_SLASH_rename_project$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","rename-project","app.main.data.dashboard/rename-project",-1207543221);$APP.$cljs$cst$271$backward$$=new $APP.$cljs$core$Keyword$$(null,"backward","backward",554036364);
$APP.$cljs$cst$3363$app_DOT_main_DOT_data_DOT_auth_SLASH_show_redirect_error$$=new $APP.$cljs$core$Keyword$$("app.main.data.auth","show-redirect-error","app.main.data.auth/show-redirect-error",-1078266261);$cljs$cst$3963$synced_at$$=new $APP.$cljs$core$Keyword$$(null,"synced-at","synced-at",98622459);$APP.$cljs$cst$2505$slow$$=new $APP.$cljs$core$Keyword$$(null,"slow","slow",120317203);$cljs$cst$3517$fill_values_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"fill-values?","fill-values?",-1457713069);
$cljs$cst$3832$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_temporary_modifiers$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.modifiers","set-temporary-modifiers","app.main.data.workspace.modifiers/set-temporary-modifiers",1171692928);$APP.$cljs$cst$5069$settings_subscription$$=new $APP.$cljs$core$Keyword$$(null,"settings-subscription","settings-subscription",11670706);$cljs$cst$1893$svg_viewbox$$=new $APP.$cljs$core$Keyword$$(null,"svg-viewbox","svg-viewbox",-255575146);
$cljs$cst$1801$add_children$$=new $APP.$cljs$core$Keyword$$(null,"add-children","add-children",705239943);$cljs$cst$344$int$$=new $APP.$cljs$core$Keyword$$(null,"int","int",-1741416922);$cljs$cst$2853$xlink_COLON_href$$=new $APP.$cljs$core$Keyword$$(null,"xlink:href","xlink:href",828777205);$cljs$cst$4190$click_draw_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"click-draw?","click-draw?",-1784736640);$cljs$cst$2937$className$$=new $APP.$cljs$core$Keyword$$(null,"className","className",-1983287057);
$cljs$cst$5181$ref_shape_is_not_head$$=new $APP.$cljs$core$Keyword$$(null,"ref-shape-is-not-head","ref-shape-is-not-head",1548958917);$APP.$cljs$cst$4471$rename_file$$=new $APP.$cljs$core$Keyword$$(null,"rename-file","rename-file",-1507579634);$APP.$cljs$cst$4979$app_DOT_main_DOT_data_DOT_dashboard_SLASH_restore_files_immediately$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","restore-files-immediately","app.main.data.dashboard/restore-files-immediately",155671388);
$cljs$cst$5349$analyze_error$$=new $APP.$cljs$core$Keyword$$(null,"analyze-error","analyze-error",-2139543576);$APP.$cljs$cst$4730$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_start_token_set_creation$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","start-token-set-creation","app.main.data.workspace.tokens.library-edit/start-token-set-creation",-2023312002);
$APP.$cljs$cst$1197$background_blur$$=new $APP.$cljs$core$Keyword$$(null,"background-blur","background-blur",-526014557);$cljs$cst$2786$kernelUnitLength$$=new $APP.$cljs$core$Keyword$$(null,"kernelUnitLength","kernelUnitLength",-2070848249);$APP.$cljs$cst$2179$shared_files$$=new $APP.$cljs$core$Keyword$$(null,"shared-files","shared-files",-929120284);$APP.$cljs$cst$3719$document_history$$=new $APP.$cljs$core$Keyword$$(null,"document-history","document-history",1908608999);
$cljs$cst$5321$skip_validate$$=new $APP.$cljs$core$Keyword$$(null,"skip-validate","skip-validate",1937218253);$APP.$cljs$cst$5116$align$$=new $APP.$cljs$core$Keyword$$(null,"align","align",1964212802);$APP.$cljs$cst$3500$names$$=new $APP.$cljs$core$Keyword$$(null,"names","names",-1943074658);$APP.$cljs$cst$2691$filter$$=new $APP.$cljs$core$Keyword$$(null,"filter","filter",-948537934);$APP.$cljs$cst$3073$display_touched$$=new $APP.$cljs$core$Keyword$$(null,"display-touched","display-touched",-1742826950);
$APP.$cljs$cst$1885$bottom_right$$=new $APP.$cljs$core$Keyword$$(null,"bottom-right","bottom-right",956401646);$APP.$cljs$cst$2197$tool$$=new $APP.$cljs$core$Keyword$$(null,"tool","tool",-1298696470);$cljs$cst$181$param_tags$$=new $APP.$cljs$core$Keyword$$(null,"param-tags","param-tags",250134169);$cljs$cst$4885$modify_layers$$=new $APP.$cljs$core$Keyword$$(null,"modify-layers","modify-layers",-454509783);$cljs$cst$4682$observable$$=new $APP.$cljs$core$Keyword$$(null,"observable","observable",-1538858614);
$cljs$cst$3205$app_DOT_main_DOT_data_DOT_profile_SLASH_refresh_profile$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","refresh-profile","app.main.data.profile/refresh-profile",364238237);$APP.$cljs$cst$3362$create_demo_profile$$=new $APP.$cljs$core$Keyword$$(null,"create-demo-profile","create-demo-profile",1091998858);$cljs$cst$3813$child_min_height$$=new $APP.$cljs$core$Keyword$$(null,"child-min-height","child-min-height",1967236206);
$cljs$cst$212$illegal_argument$$=new $APP.$cljs$core$Keyword$$(null,"illegal-argument","illegal-argument",-1845493170);$APP.$cljs$cst$925$types$$=new $APP.$cljs$core$Keyword$$(null,"types","types",590030639);$APP.$cljs$cst$2331$session$$=new $APP.$cljs$core$Keyword$$(null,"session","session",1008279103);$cljs$cst$2829$in2$$=new $APP.$cljs$core$Keyword$$(null,"in2","in2",782506768);
$APP.$cljs$cst$4707$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_set_group$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","toggle-token-set-group","app.main.data.workspace.tokens.library-edit/toggle-token-set-group",132799458);$APP.$cljs$cst$1604$points$$=new $APP.$cljs$core$Keyword$$(null,"points","points",-1486596883);$APP.$cljs$cst$4678$collapsed_paths$$=new $APP.$cljs$core$Keyword$$(null,"collapsed-paths","collapsed-paths",-841392049);
$cljs$cst$1372$logical_block_callback$$=new $APP.$cljs$core$Keyword$$(null,"logical-block-callback","logical-block-callback",1612691194);$cljs$cst$3530$force_frame_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"force-frame?","force-frame?",174727086);$cljs$cst$878$negated$$=new $APP.$cljs$core$Keyword$$(null,"negated","negated",-273117033);$cljs$cst$2989$osmanya$$=new $APP.$cljs$core$Keyword$$(null,"osmanya","osmanya",-223695996);
$cljs$cst$4145$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_stroke_color$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","change-stroke-color","app.main.data.workspace.colors/change-stroke-color",692335748);$APP.$cljs$cst$2285$update_profile_photo$$=new $APP.$cljs$core$Keyword$$(null,"update-profile-photo","update-profile-photo",1847991804);
$APP.$cljs$cst$2282$upload_file_media_object$$=new $APP.$cljs$core$Keyword$$(null,"upload-file-media-object","upload-file-media-object",-350555764);$cljs$cst$865$malli_DOT_generator_SLASH_rec_gen$$=new $APP.$cljs$core$Keyword$$("malli.generator","rec-gen","malli.generator/rec-gen",65631558);
$cljs$cst$4226$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_setup_frame$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","setup-frame","app.main.data.workspace.path.drawing/setup-frame",1408910788);$cljs$cst$3870$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_start_move_duplicate$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","start-move-duplicate","app.main.data.workspace.transforms/start-move-duplicate",-1788098437);
$APP.$cljs$cst$2320$total_colors$$=new $APP.$cljs$core$Keyword$$(null,"total-colors","total-colors",-891553408);$cljs$cst$4776$num_shapes$$=new $APP.$cljs$core$Keyword$$(null,"num-shapes","num-shapes",597955393);$APP.$cljs$cst$2506$app_DOT_main_DOT_data_DOT_common_SLASH_toggle_progress_visibility$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","toggle-progress-visibility","app.main.data.common/toggle-progress-visibility",581576293);
$cljs$cst$5197$invalid_text_touched$$=new $APP.$cljs$core$Keyword$$(null,"invalid-text-touched","invalid-text-touched",-603175216);$cljs$cst$3934$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_detach_component$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","detach-component","app.main.data.workspace.libraries/detach-component",-292547169);$APP.$cljs$cst$20$meta$$=new $APP.$cljs$core$Symbol$$(null,"meta","meta",-1154898805,null);
$APP.$cljs$cst$3232$app_DOT_main_DOT_data_DOT_profile_SLASH_update_photo$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","update-photo","app.main.data.profile/update-photo",37896275);$cljs$cst$3165$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_changes$$=new $APP.$cljs$core$Keyword$$("app.common.files.changes-builder","changes","app.common.files.changes-builder/changes",-1192369556);
$APP.$cljs$cst$4317$move_overlay_to$$=new $APP.$cljs$core$Keyword$$(null,"move-overlay-to","move-overlay-to",1237478707);$cljs$cst$3008$cherokee$$=new $APP.$cljs$core$Keyword$$(null,"cherokee","cherokee",1112096818);$APP.$cljs$cst$5043$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_exit_preview$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","exit-preview","app.main.data.workspace.versions/exit-preview",1083121217);
$cljs$cst$1104$cljs_DOT_spec_DOT_alpha_SLASH_alt$$=new $APP.$cljs$core$Symbol$$("cljs.spec.alpha","alt","cljs.spec.alpha/alt",-2130750332,null);$cljs$cst$3016$korean$$=new $APP.$cljs$core$Keyword$$(null,"korean","korean",1402655801);$cljs$cst$2664$conflict$$=new $APP.$cljs$core$Keyword$$(null,"conflict","conflict",1978796605);$APP.$cljs$cst$2652$set_group_fname$$=new $APP.$cljs$core$Keyword$$(null,"set-group-fname","set-group-fname",1422836316);
$cljs$cst$3469$app_DOT_main_DOT_data_DOT_comments_SLASH_open_comment_thread$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","open-comment-thread","app.main.data.comments/open-comment-thread",1097012576);$cljs$cst$5180$ref_shape_not_found$$=new $APP.$cljs$core$Keyword$$(null,"ref-shape-not-found","ref-shape-not-found",1014790633);$APP.$cljs$cst$1233$nitrate$$=new $APP.$cljs$core$Keyword$$(null,"nitrate","nitrate",1567206870);
$cljs$cst$3543$saved_component_root_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"saved-component-root?","saved-component-root?",-1355561726);$APP.$cljs$cst$3660$app_DOT_main_DOT_data_DOT_workspace_DOT_bool_SLASH_change_bool_type$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.bool","change-bool-type","app.main.data.workspace.bool/change-bool-type",424899887);
$cljs$cst$4375$cljs_DOT_core_SLASH_contains_QMARK_$$=new $APP.$cljs$core$Symbol$$("cljs.core","contains?","cljs.core/contains?",-976526835,null);$cljs$cst$3653$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_toggle_lock_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","toggle-lock-selected","app.main.data.workspace.shapes/toggle-lock-selected",458405573);$APP.$cljs$cst$5146$placeholder_key$$=new $APP.$cljs$core$Keyword$$(null,"placeholder-key","placeholder-key",968681483);
$APP.$cljs$cst$1299$handlers$$=new $APP.$cljs$core$Keyword$$(null,"handlers","handlers",79528781);$cljs$cst$2078$stroke_group$$=new $APP.$cljs$core$Keyword$$(null,"stroke-group","stroke-group",-1369020464);$cljs$cst$5177$component_main$$=new $APP.$cljs$core$Keyword$$(null,"component-main","component-main",-462144619);
$APP.$cljs$cst$4312$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_move_edit_interaction$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","move-edit-interaction","app.main.data.workspace.interactions/move-edit-interaction",1984185751);$cljs$cst$4615$preprocessors$$=new $APP.$cljs$core$Keyword$$(null,"preprocessors","preprocessors",109643103);$APP.$cljs$cst$1522$height$$=new $APP.$cljs$core$Keyword$$(null,"height","height",1025178622);
$cljs$cst$2717$glyphRef$$=new $APP.$cljs$core$Keyword$$(null,"glyphRef","glyphRef",1945816336);$cljs$cst$779$NaN_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"NaN?","NaN?",-1917767651);$cljs$cst$2731$feImage$$=new $APP.$cljs$core$Keyword$$(null,"feImage","feImage",-1553580330);$cljs$cst$3274$member_id$$=new $APP.$cljs$core$Keyword$$(null,"member-id","member-id",606659713);$cljs$cst$3323$slug$$=new $APP.$cljs$core$Keyword$$(null,"slug","slug",2029314850);
$APP.$cljs$cst$2396$path_parts$$=new $APP.$cljs$core$Keyword$$(null,"path-parts","path-parts",945822894);$cljs$cst$3489$app_DOT_main_DOT_fonts_SLASH_woff2_file_id$$=new $APP.$cljs$core$Keyword$$("app.main.fonts","woff2-file-id","app.main.fonts/woff2-file-id",-49144145);$APP.$cljs$cst$1723$ids$$=new $APP.$cljs$core$Keyword$$(null,"ids","ids",-998535796);
$cljs$cst$2510$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_files$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","go-to-dashboard-files","app.main.data.common/go-to-dashboard-files",1138202340);$cljs$cst$3565$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_append_undo$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.undo","append-undo","app.main.data.workspace.undo/append-undo",2071819251);
$cljs$cst$1892$no_flip$$=new $APP.$cljs$core$Keyword$$(null,"no-flip","no-flip",-318174213);$APP.$cljs$cst$5582$lightness$$=new $APP.$cljs$core$Keyword$$(null,"lightness","lightness",-2040901930);$APP.$cljs$cst$736$union$$=new $APP.$cljs$core$Keyword$$(null,"union","union",2142937499);$cljs$cst$211$reader_error$$=new $APP.$cljs$core$Keyword$$(null,"reader-error","reader-error",1610253121);
$cljs$cst$3399$app_DOT_main_DOT_data_DOT_plugins_SLASH_remove_current_plugin$$=new $APP.$cljs$core$Keyword$$("app.main.data.plugins","remove-current-plugin","app.main.data.plugins/remove-current-plugin",-488575711);$cljs$cst$4998$filter_mentions$$=new $APP.$cljs$core$Keyword$$(null,"filter-mentions","filter-mentions",-1571090553);$APP.$cljs$cst$1695$layout_grid_columns$$=new $APP.$cljs$core$Keyword$$(null,"layout-grid-columns","layout-grid-columns",-295096864);
$cljs$cst$642$keep$$=new $APP.$cljs$core$Keyword$$(null,"keep","keep",-2133338530);$cljs$cst$5380$account_without_password$$=new $APP.$cljs$core$Keyword$$(null,"account-without-password","account-without-password",-96930553);$APP.$cljs$cst$1952$ease_out$$=new $APP.$cljs$core$Keyword$$(null,"ease-out","ease-out",1760664474);$cljs$cst$3014$georgian$$=new $APP.$cljs$core$Keyword$$(null,"georgian","georgian",1734823735);
$APP.$cljs$cst$1677$align_self$$=new $APP.$cljs$core$Keyword$$(null,"align-self","align-self",1475936794);$cljs$cst$2760$x_height$$=new $APP.$cljs$core$Keyword$$(null,"x-height","x-height",1735436609);$cljs$cst$2939$units$$=new $APP.$cljs$core$Keyword$$(null,"units","units",-533089095);
$cljs$cst$3836$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_wasm_modifiers$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.modifiers","set-wasm-modifiers","app.main.data.workspace.modifiers/set-wasm-modifiers",2017937478);$cljs$cst$2147$app_DOT_main_DOT_data_DOT_changes_SLASH_commit$$=new $APP.$cljs$core$Keyword$$("app.main.data.changes","commit","app.main.data.changes/commit",-1518621522);
$cljs$cst$2130$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_value$$=new $APP.$cljs$core$Keyword$$("app.common.types.tokens-lib","value","app.common.types.tokens-lib/value",-1272173908);$cljs$cst$563$input$$=new $APP.$cljs$core$Keyword$$(null,"input","input",556931961);$cljs$cst$3760$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_ungroup_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.groups","ungroup-selected","app.main.data.workspace.groups/ungroup-selected",-980266808);
$APP.$cljs$cst$4712$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_drop_token_set_group$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","drop-token-set-group","app.main.data.workspace.tokens.library-edit/drop-token-set-group",1403859113);$cljs$cst$1493$doseq$$=new $APP.$cljs$core$Symbol$$(null,"doseq","doseq",221164135,null);
$cljs$cst$3746$selected_palette_colorpicker$$=new $APP.$cljs$core$Keyword$$(null,"selected-palette-colorpicker","selected-palette-colorpicker",1737136573);$cljs$cst$5362$activation_code$$=new $APP.$cljs$core$Keyword$$(null,"activation-code","activation-code",-8800947);$APP.$cljs$cst$3237$share_id$$=new $APP.$cljs$core$Keyword$$(null,"share-id","share-id",795821204);$APP.$cljs$cst$4760$export_frames$$=new $APP.$cljs$core$Keyword$$(null,"export-frames","export-frames",-511225256);
$APP.$cljs$cst$1189$dashboard_templates_section$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-templates-section","dashboard-templates-section",-474074368);$cljs$cst$4699$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_theme_active$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","toggle-token-theme-active","app.main.data.workspace.tokens.library-edit/toggle-token-theme-active",-57455161);
$cljs$cst$4060$backdrop_filter$$=new $APP.$cljs$core$Keyword$$(null,"backdrop-filter","backdrop-filter",-735928241);$APP.$cljs$cst$3958$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_component_multi_swap$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","component-multi-swap","app.main.data.workspace.libraries/component-multi-swap",-63161346);
$APP.$cljs$cst$4126$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_colorpicker_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","colorpicker-selected","app.main.data.workspace.colors/colorpicker-selected",284549186);$cljs$cst$3199$app_DOT_main_DOT_data_DOT_profile_SLASH_profile_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","profile-fetched","app.main.data.profile/profile-fetched",1641970658);
$cljs$cst$169$throw$$=new $APP.$cljs$core$Symbol$$(null,"throw","throw",595905694,null);$cljs$cst$5164$child_not_in_parent$$=new $APP.$cljs$core$Keyword$$(null,"child-not-in-parent","child-not-in-parent",969396311);$cljs$cst$690$indexed_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"indexed?","indexed?",1234610384,null);$cljs$cst$3261$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_teams$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","fetch-teams","app.main.data.team/fetch-teams",-2041250742);
$cljs$cst$1442$char_format$$=new $APP.$cljs$core$Keyword$$(null,"char-format","char-format",-1016499218);$APP.$cljs$cst$2107$external_id$$=new $APP.$cljs$core$Keyword$$(null,"external-id","external-id",-456527727);$cljs$cst$1800$remove_children$$=new $APP.$cljs$core$Keyword$$(null,"remove-children","remove-children",1296934069);$cljs$cst$953$app_DOT_common_DOT_schema_SLASH_set_of_keywords$$=new $APP.$cljs$core$Keyword$$("app.common.schema","set-of-keywords","app.common.schema/set-of-keywords",2102430849);
$cljs$cst$3897$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_all$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.wasm-text","resize-wasm-text-all","app.main.data.workspace.wasm-text/resize-wasm-text-all",100967986);$cljs$cst$917$default_decoder$$=new $APP.$cljs$core$Keyword$$(null,"default-decoder","default-decoder",808357161);
$APP.$cljs$cst$4170$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_initialize_colorpicker$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","initialize-colorpicker","app.main.data.workspace.colors/initialize-colorpicker",1173363953);$APP.$cljs$cst$5034$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_delete_version$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","delete-version","app.main.data.workspace.versions/delete-version",-947424824);
$cljs$cst$4442$number_of_combined$$=new $APP.$cljs$core$Keyword$$(null,"number-of-combined","number-of-combined",366676508);$APP.$cljs$cst$1642$typography_ref_file$$=new $APP.$cljs$core$Keyword$$(null,"typography-ref-file","typography-ref-file",2114311688);$APP.$cljs$cst$3064$history_overlay$$=new $APP.$cljs$core$Keyword$$(null,"history-overlay","history-overlay",1725695055);$cljs$cst$2595$show_modified$$=new $APP.$cljs$core$Keyword$$(null,"show-modified","show-modified",-1388936404);
$APP.$cljs$cst$2036$auto_width$$=new $APP.$cljs$core$Keyword$$(null,"auto-width","auto-width",-992925188);$cljs$cst$3619$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_duplicate_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","duplicate-shapes","app.main.data.workspace.selection/duplicate-shapes",757495841);
$cljs$cst$4347$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_initialize$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.notifications","initialize","app.main.data.workspace.notifications/initialize",-1561873434);$cljs$cst$3786$object_ids$$=new $APP.$cljs$core$Keyword$$(null,"object-ids","object-ids",1559034327);
$cljs$cst$3370$app_DOT_main_DOT_data_DOT_workspace_SLASH_reload_current_file$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","reload-current-file","app.main.data.workspace/reload-current-file",-807745136);$APP.$cljs$cst$4490$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_shape_proportion_lock$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","set-shape-proportion-lock","app.main.data.workspace/set-shape-proportion-lock",1359513115);
$APP.$cljs$cst$2034$intersection$$=new $APP.$cljs$core$Keyword$$(null,"intersection","intersection",2003891010);$cljs$cst$3187$app_DOT_main_DOT_data_DOT_media_SLASH_blob_QMARK_$$=new $APP.$cljs$core$Symbol$$("app.main.data.media","blob?","app.main.data.media/blob?",-950868156,null);$APP.$cljs$cst$2349$toast$$=new $APP.$cljs$core$Keyword$$(null,"toast","toast",68598129);$cljs$cst$2933$visibility$$=new $APP.$cljs$core$Keyword$$(null,"visibility","visibility",1338380893);
$cljs$cst$523$malli_DOT_core_SLASH_invalid_dispatch_value$$=new $APP.$cljs$core$Keyword$$("malli.core","invalid-dispatch-value","malli.core/invalid-dispatch-value",516707675);$cljs$cst$2837$units_per_em$$=new $APP.$cljs$core$Keyword$$(null,"units-per-em","units-per-em",1845580082);$APP.$cljs$cst$1613$svg_raw$$=new $APP.$cljs$core$Keyword$$(null,"svg-raw","svg-raw",-594329202);
$cljs$cst$1826$app_DOT_common_DOT_schema_DOT_openapi_SLASH_default$$=new $APP.$cljs$core$Keyword$$("app.common.schema.openapi","default","app.common.schema.openapi/default",-1057013151);$APP.$cljs$cst$3939$additional_ids$$=new $APP.$cljs$core$Keyword$$(null,"additional-ids","additional-ids",1987201277);$cljs$cst$3542$saved_component_root$$=new $APP.$cljs$core$Keyword$$(null,"saved-component-root","saved-component-root",1854874793);
$cljs$cst$4801$zoom_lense_decrease$$=new $APP.$cljs$core$Keyword$$(null,"zoom-lense-decrease","zoom-lense-decrease",1789059043);$cljs$cst$750$user$$=new $APP.$cljs$core$Keyword$$(null,"user","user",1532431356);$APP.$cljs$cst$3054$disable_frame_thumbnails$$=new $APP.$cljs$core$Keyword$$(null,"disable-frame-thumbnails","disable-frame-thumbnails",-1073907006);$cljs$cst$3070$bool_shapes$$=new $APP.$cljs$core$Keyword$$(null,"bool-shapes","bool-shapes",-1080624236);
$APP.$cljs$cst$2113$skip_children_pred$$=new $APP.$cljs$core$Keyword$$(null,"skip-children-pred","skip-children-pred",663146554);$APP.$cljs$cst$141$message$$=new $APP.$cljs$core$Keyword$$(null,"message","message",-406056002);$cljs$cst$2567$team_feature_mismatch$$=new $APP.$cljs$core$Keyword$$(null,"team-feature-mismatch","team-feature-mismatch",-1423359773);
$cljs$cst$815$clojure_DOT_test_DOT_check_DOT_generators_SLASH_keyword_ns$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","keyword-ns","clojure.test.check.generators/keyword-ns",-1492628482,null);$cljs$cst$2890$v_alphabetic$$=new $APP.$cljs$core$Keyword$$(null,"v-alphabetic","v-alphabetic",-552236578);$APP.$cljs$cst$2048$collapsed$$=new $APP.$cljs$core$Keyword$$(null,"collapsed","collapsed",-628494523);$cljs$cst$3479$yours$$=new $APP.$cljs$core$Keyword$$(null,"yours","yours",289099402);
$cljs$cst$531$multi$$=new $APP.$cljs$core$Keyword$$(null,"multi","multi",-190293005);$APP.$cljs$cst$4977$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_project_immediately$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","delete-project-immediately","app.main.data.dashboard/delete-project-immediately",-1785355806);$cljs$cst$654$preset$$=new $APP.$cljs$core$Keyword$$(null,"preset","preset",777387345);
$APP.$cljs$cst$3279$app_DOT_main_DOT_data_DOT_team_SLASH_stats_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","stats-fetched","app.main.data.team/stats-fetched",-807692414);$cljs$cst$5168$invalid_parent$$=new $APP.$cljs$core$Keyword$$(null,"invalid-parent","invalid-parent",-882875239);$APP.$cljs$cst$2685$show_text_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"show-text?","show-text?",1934354679);
$cljs$cst$4266$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_select_for_drawing$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.drawing","select-for-drawing","app.main.data.workspace.drawing/select-for-drawing",-937062938);$cljs$cst$4758$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_show_viewer_export_dialog$$=new $APP.$cljs$core$Keyword$$("app.main.data.exports.assets","show-viewer-export-dialog","app.main.data.exports.assets/show-viewer-export-dialog",1881460878);
$cljs$cst$4583$error_DOT_token_SLASH_invalid_color$$=new $APP.$cljs$core$Keyword$$("error.token","invalid-color","error.token/invalid-color",-1523551318);$cljs$cst$299$malli_DOT_core_SLASH_end_of_input$$=new $APP.$cljs$core$Keyword$$("malli.core","end-of-input","malli.core/end-of-input",-491237771);$cljs$cst$5387$accept_terms_and_privacy$$=new $APP.$cljs$core$Keyword$$(null,"accept-terms-and-privacy","accept-terms-and-privacy",420542438);
$APP.$cljs$cst$2863$rotate$$=new $APP.$cljs$core$Keyword$$(null,"rotate","rotate",152705015);$APP.$cljs$cst$3138$undo_group$$=new $APP.$cljs$core$Keyword$$(null,"undo-group","undo-group",-1765279846);$APP.$cljs$cst$5093$focus$$=new $APP.$cljs$core$Keyword$$(null,"focus","focus",234677911);$cljs$cst$2706$marker$$=new $APP.$cljs$core$Keyword$$(null,"marker","marker",865118313);
$APP.$cljs$cst$5243$app_DOT_main_DOT_data_DOT_viewer_SLASH_update_page_position_data$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","update-page-position-data","app.main.data.viewer/update-page-position-data",1313123413);$cljs$cst$2759$startOffset$$=new $APP.$cljs$core$Keyword$$(null,"startOffset","startOffset",-590231263);$cljs$cst$3032$xlinkhref$$=new $APP.$cljs$core$Keyword$$(null,"xlinkhref","xlinkhref",1985487126);
$cljs$cst$3837$undo_transation_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"undo-transation?","undo-transation?",-1838368123);$cljs$cst$1235$audit_log_logger$$=new $APP.$cljs$core$Keyword$$(null,"audit-log-logger","audit-log-logger",-1783756745);$APP.$cljs$cst$3281$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_stats$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","fetch-stats","app.main.data.team/fetch-stats",1035659502);
$cljs$cst$4400$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_create_shape_layout$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","create-shape-layout","app.main.data.workspace.shape-layout/create-shape-layout",-937143778);$cljs$cst$5306$general_viewer$$=new $APP.$cljs$core$Keyword$$(null,"general-viewer","general-viewer",-748214774);$APP.$cljs$cst$4155$disable_opacity$$=new $APP.$cljs$core$Keyword$$(null,"disable-opacity","disable-opacity",1547998851);
$cljs$cst$3045$anchor_offset$$=new $APP.$cljs$core$Keyword$$(null,"anchor-offset","anchor-offset",175135585);$APP.$cljs$cst$4335$mcp_enabled$$=new $APP.$cljs$core$Keyword$$(null,"mcp-enabled","mcp-enabled",-2146653267);$APP.$cljs$cst$4834$delete$$=new $APP.$cljs$core$Keyword$$(null,"delete","delete",-1768633620);$APP.$cljs$cst$3253$delete_access_token$$=new $APP.$cljs$core$Keyword$$(null,"delete-access-token","delete-access-token",-110686384);
$cljs$cst$3529$new_variant_id$$=new $APP.$cljs$core$Keyword$$(null,"new-variant-id","new-variant-id",683771380);$cljs$cst$4844$select_prev$$=new $APP.$cljs$core$Keyword$$(null,"select-prev","select-prev",457778960);$cljs$cst$1074$gen_max$$=new $APP.$cljs$core$Keyword$$(null,"gen-max","gen-max",-793680445);$cljs$cst$3046$focus_para$$=new $APP.$cljs$core$Keyword$$(null,"focus-para","focus-para",-292469673);
$cljs$cst$5271$app_DOT_main_DOT_data_DOT_viewer_SLASH_flash_done$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","flash-done","app.main.data.viewer/flash-done",-1842223531);$APP.$cljs$cst$3588$zooming$$=new $APP.$cljs$core$Keyword$$(null,"zooming","zooming",719822603);$cljs$cst$3620$alt_duplication$$=new $APP.$cljs$core$Keyword$$(null,"alt-duplication","alt-duplication",774015793);$APP.$cljs$cst$2909$overflow$$=new $APP.$cljs$core$Keyword$$(null,"overflow","overflow",2058931880);
$APP.$cljs$cst$5383$auth_register$$=new $APP.$cljs$core$Keyword$$(null,"auth-register","auth-register",826284239);$cljs$cst$632$re_unparser$$=new $APP.$cljs$core$Keyword$$(null,"re-unparser","re-unparser",1432943079);$APP.$cljs$cst$3991$get_file_libraries$$=new $APP.$cljs$core$Keyword$$(null,"get-file-libraries","get-file-libraries",-1759425876);
$cljs$cst$4118$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_html_text$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","paste-html-text","app.main.data.workspace.clipboard/paste-html-text",4281609);$cljs$cst$3335$app_DOT_main_DOT_data_DOT_websocket_SLASH_initialize$$=new $APP.$cljs$core$Keyword$$("app.main.data.websocket","initialize","app.main.data.websocket/initialize",-1086102386);
$cljs$cst$2615$fix_obj$$=new $APP.$cljs$core$Keyword$$(null,"fix-obj","fix-obj",1131095112);$cljs$cst$3012$hebrew$$=new $APP.$cljs$core$Keyword$$(null,"hebrew","hebrew",-1789946506);$cljs$cst$923$json$$=new $APP.$cljs$core$Keyword$$(null,"json","json",1279968570);$cljs$cst$5369$only_owner_can_delete_team$$=new $APP.$cljs$core$Keyword$$(null,"only-owner-can-delete-team","only-owner-can-delete-team",340374263);
$APP.$cljs$cst$1689$layout_justify_content$$=new $APP.$cljs$core$Keyword$$(null,"layout-justify-content","layout-justify-content",-416357134);$cljs$cst$2670$pre_context_lost_read_only_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"pre-context-lost-read-only?","pre-context-lost-read-only?",947331693);$cljs$cst$1101$cljs_DOT_spec_DOT_alpha_SLASH_cat$$=new $APP.$cljs$core$Symbol$$("cljs.spec.alpha","cat","cljs.spec.alpha/cat",-1471398329,null);
$APP.$cljs$cst$4842$open_viewer$$=new $APP.$cljs$core$Keyword$$(null,"open-viewer","open-viewer",-29795505);$APP.$cljs$cst$1917$current_file_id$$=new $APP.$cljs$core$Keyword$$(null,"current-file-id","current-file-id",1601348404);$APP.$cljs$cst$2139$tokens_lib$$=new $APP.$cljs$core$Keyword$$(null,"tokens-lib","tokens-lib",1725671991);$APP.$cljs$cst$2027$exclusion$$=new $APP.$cljs$core$Keyword$$(null,"exclusion","exclusion",531897910);
$APP.$cljs$cst$1756$typography_ref_id$$=new $APP.$cljs$core$Keyword$$(null,"typography-ref-id","typography-ref-id",-993695356);$cljs$cst$4369$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_update_page_root$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.pages","update-page-root","app.main.data.workspace.pages/update-page-root",-1237648848);$cljs$cst$4852$move_fast_right$$=new $APP.$cljs$core$Keyword$$(null,"move-fast-right","move-fast-right",-1380819692);
$APP.$cljs$cst$3393$app_DOT_plugins_DOT_flags_SLASH_set_flag$$=new $APP.$cljs$core$Keyword$$("app.plugins.flags","set-flag","app.plugins.flags/set-flag",-2024665901);$APP.$cljs$cst$3877$small$$=new $APP.$cljs$core$Keyword$$(null,"small","small",2133478704);$cljs$cst$1157$app_DOT_common_DOT_logging_SLASH_id$$=new $APP.$cljs$core$Keyword$$("app.common.logging","id","app.common.logging/id",1339267211);$cljs$cst$1995$italic_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"italic?","italic?",1143640731);
$APP.$cljs$cst$3608$full_frame_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"full-frame?","full-frame?",763988721);$cljs$cst$4187$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_common_SLASH_clear_drawing$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.drawing.common","clear-drawing","app.main.data.workspace.drawing.common/clear-drawing",-2106156961);$APP.$cljs$cst$3898$get_file_fragment$$=new $APP.$cljs$core$Keyword$$(null,"get-file-fragment","get-file-fragment",-1236282386);
$APP.$cljs$cst$4029$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_remove_text_modifier$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","remove-text-modifier","app.main.data.workspace.texts/remove-text-modifier",-1971036133);$APP.$cljs$cst$3127$config$$=new $APP.$cljs$core$Keyword$$(null,"config","config",994861415);
$cljs$cst$4596$error_DOT_style_dictionary_SLASH_invalid_token_value_stroke_width$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","invalid-token-value-stroke-width","error.style-dictionary/invalid-token-value-stroke-width",-601889002);$cljs$cst$2894$xlink_COLON_role$$=new $APP.$cljs$core$Keyword$$(null,"xlink:role","xlink:role",-556206369);
$cljs$cst$4491$app_DOT_main_DOT_data_DOT_workspace_SLASH_toggle_proportion_lock$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","toggle-proportion-lock","app.main.data.workspace/toggle-proportion-lock",2079914676);$cljs$cst$4116$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_transit_props$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","paste-transit-props","app.main.data.workspace.clipboard/paste-transit-props",-1093057052);
$APP.$cljs$cst$4365$workspace_cache$$=new $APP.$cljs$core$Keyword$$(null,"workspace-cache","workspace-cache",773600470);$APP.$cljs$cst$5365$monthly$$=new $APP.$cljs$core$Keyword$$(null,"monthly","monthly",1596693261);$APP.$cljs$cst$4141$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_detach_fill$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","detach-fill","app.main.data.workspace.colors/detach-fill",1504712239);
$APP.$cljs$cst$5294$app_DOT_main_DOT_data_DOT_viewer_SLASH_hover_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","hover-shape","app.main.data.viewer/hover-shape",84002923);$APP.$cljs$cst$193$source$$=new $APP.$cljs$core$Keyword$$(null,"source","source",-433931539);$cljs$cst$4957$app_DOT_main_DOT_data_DOT_dashboard_SLASH_file_created$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","file-created","app.main.data.dashboard/file-created",758247287);
$APP.$cljs$cst$4732$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_clear_token_set_edition$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","clear-token-set-edition","app.main.data.workspace.tokens.library-edit/clear-token-set-edition",-1445403962);
$cljs$cst$4768$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_update_export_status$$=new $APP.$cljs$core$Keyword$$("app.main.data.exports.assets","update-export-status","app.main.data.exports.assets/update-export-status",-1565666338);$APP.$cljs$cst$221$keyword$$=new $APP.$cljs$core$Keyword$$(null,"keyword","keyword",811389747);$cljs$cst$2841$viewTarget$$=new $APP.$cljs$core$Keyword$$(null,"viewTarget","viewTarget",-494135597);
$APP.$cljs$cst$2214$recent_fonts$$=new $APP.$cljs$core$Keyword$$(null,"recent-fonts","recent-fonts",1734170898);$APP.$cljs$cst$1763$text_align$$=new $APP.$cljs$core$Keyword$$(null,"text-align","text-align",1786091845);$cljs$cst$3068$selection_center$$=new $APP.$cljs$core$Keyword$$(null,"selection-center","selection-center",-521638829);
$APP.$cljs$cst$4152$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_reorder_shadow$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","reorder-shadow","app.main.data.workspace.colors/reorder-shadow",1099393324);$cljs$cst$2751$foreignObject$$=new $APP.$cljs$core$Keyword$$(null,"foreignObject","foreignObject",25502111);$cljs$cst$2852$slope$$=new $APP.$cljs$core$Keyword$$(null,"slope","slope",-1227938123);
$cljs$cst$3337$ws_conn$$=new $APP.$cljs$core$Keyword$$(null,"ws-conn","ws-conn",1536795552);$cljs$cst$593$malli_DOT_core_SLASH_function_checker$$=new $APP.$cljs$core$Keyword$$("malli.core","function-checker","malli.core/function-checker",-792030936);$APP.$cljs$cst$1160$debug$$=new $APP.$cljs$core$Keyword$$(null,"debug","debug",-1608172596);
$cljs$cst$4479$app_DOT_main_DOT_data_DOT_workspace_SLASH_delete_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","delete-selected","app.main.data.workspace/delete-selected",-1780665429);$APP.$cljs$cst$4176$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_gradient_opacity$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","update-colorpicker-gradient-opacity","app.main.data.workspace.colors/update-colorpicker-gradient-opacity",1818184102);
$APP.$cljs$cst$4224$draw$$=new $APP.$cljs$core$Keyword$$(null,"draw","draw",1358331674);$APP.$cljs$cst$4497$app_DOT_main_DOT_data_DOT_workspace_SLASH_clear_assets_section_open$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","clear-assets-section-open","app.main.data.workspace/clear-assets-section-open",-1852940833);$APP.$cljs$cst$2089$update_new_shape$$=new $APP.$cljs$core$Keyword$$(null,"update-new-shape","update-new-shape",1958657165);
$APP.$cljs$cst$3734$force_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"force?","force?",1839038675);$cljs$cst$2600$set_touched$$=new $APP.$cljs$core$Keyword$$(null,"set-touched","set-touched",-443889429);$APP.$cljs$cst$4543$on_lost_pointer_capture$$=new $APP.$cljs$core$Keyword$$(null,"on-lost-pointer-capture","on-lost-pointer-capture",-1554883134);$cljs$cst$2893$xml_COLON_base$$=new $APP.$cljs$core$Keyword$$(null,"xml:base","xml:base",1209393887);
$APP.$cljs$cst$1746$fill_color$$=new $APP.$cljs$core$Keyword$$(null,"fill-color","fill-color",-1156875903);$cljs$cst$2648$set_active_token_themes$$=new $APP.$cljs$core$Keyword$$(null,"set-active-token-themes","set-active-token-themes",-1825247552);$APP.$cljs$cst$2577$vern$$=new $APP.$cljs$core$Keyword$$(null,"vern","vern",2071435888);
$APP.$cljs$cst$4315$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_finish_edit_interaction$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","finish-edit-interaction","app.main.data.workspace.interactions/finish-edit-interaction",1799182220);$APP.$cljs$cst$1814$line_to$$=new $APP.$cljs$core$Keyword$$(null,"line-to","line-to",1332939595);
$APP.$cljs$cst$3441$app_DOT_main_DOT_data_DOT_comments_SLASH_created_thread_on_viewer$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","created-thread-on-viewer","app.main.data.comments/created-thread-on-viewer",-1700234781);$APP.$cljs$cst$2493$team_name$$=new $APP.$cljs$core$Keyword$$(null,"team-name","team-name",1475836072);$APP.$cljs$cst$2163$point$$=new $APP.$cljs$core$Keyword$$(null,"point","point",1813198264);
$cljs$cst$5250$app_DOT_main_DOT_data_DOT_viewer_SLASH_update_zoom_querystring$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","update-zoom-querystring","app.main.data.viewer/update-zoom-querystring",-567729030);$APP.$cljs$cst$4689$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_close_token_type$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","close-token-type","app.main.data.workspace.tokens.library-edit/close-token-type",1978661553);
$APP.$cljs$cst$4248$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_modify_handler$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.edition","modify-handler","app.main.data.workspace.path.edition/modify-handler",1743833054);$cljs$cst$5353$analyze$$=new $APP.$cljs$core$Keyword$$(null,"analyze","analyze",-766389120);$APP.$cljs$cst$2488$on_success$$=new $APP.$cljs$core$Keyword$$(null,"on-success","on-success",1786904109);
$cljs$cst$1846$maxLength$$=new $APP.$cljs$core$Keyword$$(null,"maxLength","maxLength",-1633020073);$APP.$cljs$cst$3766$node$$=new $APP.$cljs$core$Keyword$$(null,"node","node",581201198);$APP.$cljs$cst$4884$edit$$=new $APP.$cljs$core$Keyword$$(null,"edit","edit",-1641834166);$cljs$cst$4$print_length$$=new $APP.$cljs$core$Keyword$$(null,"print-length","print-length",1931866356);$cljs$cst$2932$color_interpolation$$=new $APP.$cljs$core$Keyword$$(null,"color-interpolation","color-interpolation",-1276247587);
$cljs$cst$391$keys$$=new $APP.$cljs$core$Keyword$$(null,"keys","keys",1068423698);$cljs$cst$3019$mongolian$$=new $APP.$cljs$core$Keyword$$(null,"mongolian","mongolian",-233794022);$APP.$cljs$cst$5261$app_DOT_main_DOT_data_DOT_viewer_SLASH_set_viewport_size$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","set-viewport-size","app.main.data.viewer/set-viewport-size",-2131805670);$APP.$cljs$cst$273$code$$=new $APP.$cljs$core$Keyword$$(null,"code","code",1586293142);
$cljs$cst$858$gen_SLASH_NaN_QMARK_$$=new $APP.$cljs$core$Keyword$$("gen","NaN?","gen/NaN?",-1917993267);$cljs$cst$2646$set_token_set$$=new $APP.$cljs$core$Keyword$$(null,"set-token-set","set-token-set",-1146185413);$APP.$cljs$cst$1670$percent$$=new $APP.$cljs$core$Keyword$$(null,"percent","percent",2031453817);$cljs$cst$3688$lowercase$$=new $APP.$cljs$core$Keyword$$(null,"lowercase","lowercase",41029539);$cljs$cst$4898$levels$$=new $APP.$cljs$core$Keyword$$(null,"levels","levels",-950747887);
$cljs$cst$1103$cljs_DOT_spec_DOT_alpha_SLASH__QMARK_$$=new $APP.$cljs$core$Symbol$$("cljs.spec.alpha","?","cljs.spec.alpha/?",1605136319,null);$cljs$cst$1099$cljs_DOT_spec_DOT_alpha_SLASH__AMPERSAND_$$=new $APP.$cljs$core$Symbol$$("cljs.spec.alpha","\x26","cljs.spec.alpha/\x26",1635809823,null);$cljs$cst$3965$update_file_library_sync_status$$=new $APP.$cljs$core$Keyword$$(null,"update-file-library-sync-status","update-file-library-sync-status",-1000632019);
$APP.$cljs$cst$873$options$$=new $APP.$cljs$core$Keyword$$(null,"options","options",99638489);$APP.$cljs$cst$1326$emit_current_value_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"emit-current-value?","emit-current-value?",56289147);$cljs$cst$3371$snapshot_is_locked$$=new $APP.$cljs$core$Keyword$$(null,"snapshot-is-locked","snapshot-is-locked",904526286);$cljs$cst$1345$edge$$=new $APP.$cljs$core$Keyword$$(null,"edge","edge",919909153);
$cljs$cst$1094$cljs_DOT_spec_DOT_alpha_SLASH__STAR_$$=new $APP.$cljs$core$Symbol$$("cljs.spec.alpha","*","cljs.spec.alpha/*",-1238084288,null);$cljs$cst$1100$cljs_DOT_spec_DOT_alpha_SLASH__PLUS_$$=new $APP.$cljs$core$Symbol$$("cljs.spec.alpha","+","cljs.spec.alpha/+",2101263265,null);$cljs$cst$5228$go_to_search$$=new $APP.$cljs$core$Keyword$$(null,"go-to-search","go-to-search",1620800181);
$cljs$cst$2562$feature_not_supported$$=new $APP.$cljs$core$Keyword$$(null,"feature-not-supported","feature-not-supported",1036203378);$cljs$cst$4334$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_update_mcp_status$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.mcp","update-mcp-status","app.main.data.workspace.mcp/update-mcp-status",-1025242204);$cljs$cst$346$arity$$=new $APP.$cljs$core$Keyword$$(null,"arity","arity",-1808556135);
$APP.$cljs$cst$3157$authentication$$=new $APP.$cljs$core$Keyword$$(null,"authentication","authentication",1746273042);$APP.$cljs$cst$4417$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_copy_grid_tracks$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","copy-grid-tracks","app.main.data.workspace.shape-layout/copy-grid-tracks",-727009663);$cljs$cst$1420$radix$$=new $APP.$cljs$core$Keyword$$(null,"radix","radix",857016463);
$APP.$cljs$cst$4897$dashboard_projects$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-projects","dashboard-projects",-425944382);$cljs$cst$674$double_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"double?","double?",-2146564276,null);$cljs$cst$1320$first$$=new $APP.$cljs$core$Keyword$$(null,"first","first",-644103046);$cljs$cst$2167$up_mouse_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"up-mouse?","up-mouse?",-2106647044);$cljs$cst$5333$markup$$=new $APP.$cljs$core$Keyword$$(null,"markup","markup",2143234544);
$APP.$cljs$cst$2241$workspace_preview_blend$$=new $APP.$cljs$core$Keyword$$(null,"workspace-preview-blend","workspace-preview-blend",-1720937040);$cljs$cst$4079$root_shapes$$=new $APP.$cljs$core$Keyword$$(null,"root-shapes","root-shapes",2046683285);$cljs$cst$1226$backend_worker$$=new $APP.$cljs$core$Keyword$$(null,"backend-worker","backend-worker",1214587666);
$cljs$cst$4201$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_streams_SLASH_empty$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.streams","empty","app.main.data.workspace.path.streams/empty",1775930509);$cljs$cst$146$clojure_DOT_error_SLASH_phase$$=new $APP.$cljs$core$Keyword$$("clojure.error","phase","clojure.error/phase",275140358);
$cljs$cst$3321$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_shared_files$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","fetch-shared-files","app.main.data.team/fetch-shared-files",426251101);$cljs$cst$1184$smtp$$=new $APP.$cljs$core$Keyword$$(null,"smtp","smtp",1393366583);$APP.$cljs$cst$3460$get_comment_threads$$=new $APP.$cljs$core$Keyword$$(null,"get-comment-threads","get-comment-threads",-138542175);
$APP.$cljs$cst$5048$preview_dialog$$=new $APP.$cljs$core$Keyword$$(null,"preview-dialog","preview-dialog",1880879054);$APP.$cljs$cst$1765$line_height$$=new $APP.$cljs$core$Keyword$$(null,"line-height","line-height",1870784992);$APP.$cljs$cst$1222$onboarding$$=new $APP.$cljs$core$Keyword$$(null,"onboarding","onboarding",-1622662800);$cljs$cst$2565$file_in_components_v1$$=new $APP.$cljs$core$Keyword$$(null,"file-in-components-v1","file-in-components-v1",-1067825588);
$cljs$cst$2302$device_arch$$=new $APP.$cljs$core$Keyword$$(null,"device-arch","device-arch",-313234416);$cljs$cst$3806$margin_y$$=new $APP.$cljs$core$Keyword$$(null,"margin-y","margin-y",-371718288);$cljs$cst$3805$margin_x$$=new $APP.$cljs$core$Keyword$$(null,"margin-x","margin-x",1660588286);$APP.$cljs$cst$4087$align_content$$=new $APP.$cljs$core$Keyword$$(null,"align-content","align-content",-990200349);$cljs$cst$3358$logout$$=new $APP.$cljs$core$Keyword$$(null,"logout","logout",1418564329);
$cljs$cst$1220$inspect_styles$$=new $APP.$cljs$core$Keyword$$(null,"inspect-styles","inspect-styles",1359737423);$cljs$cst$3027$armenian$$=new $APP.$cljs$core$Keyword$$(null,"armenian","armenian",610189759);$APP.$cljs$cst$2044$component_root$$=new $APP.$cljs$core$Keyword$$(null,"component-root","component-root",-485271026);$APP.$cljs$cst$1990$vertical_margin$$=new $APP.$cljs$core$Keyword$$(null,"vertical-margin","vertical-margin",629210288);
$cljs$cst$3583$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_zoom_to_fit_all$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.zoom","zoom-to-fit-all","app.main.data.workspace.zoom/zoom-to-fit-all",906260964);$cljs$cst$2805$strikethrough_position$$=new $APP.$cljs$core$Keyword$$(null,"strikethrough-position","strikethrough-position",402256746);$cljs$cst$2920$alignment_baseline$$=new $APP.$cljs$core$Keyword$$(null,"alignment-baseline","alignment-baseline",-311060879);
$APP.$cljs$cst$5260$app_DOT_main_DOT_data_DOT_viewer_SLASH_exit_fullscreen$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","exit-fullscreen","app.main.data.viewer/exit-fullscreen",2035238371);$APP.$cljs$cst$1895$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_counter_clockwise$$=new $APP.$cljs$core$Keyword$$("app.common.geom.shapes.intersect","counter-clockwise","app.common.geom.shapes.intersect/counter-clockwise",1531989207);
$cljs$cst$3100$lose_browser_context_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"lose-browser-context?","lose-browser-context?",1325749437);$cljs$cst$5005$insert_at_symbol$$=new $APP.$cljs$core$Keyword$$(null,"insert-at-symbol","insert-at-symbol",974397941);$APP.$cljs$cst$4186$token_name$$=new $APP.$cljs$core$Keyword$$(null,"token-name","token-name",1766556933);
$APP.$cljs$cst$2366$reitit_DOT_impl_SLASH_merge_data$$=new $APP.$cljs$core$Keyword$$("reitit.impl","merge-data","reitit.impl/merge-data",-588218417);$cljs$cst$2818$maskUnits$$=new $APP.$cljs$core$Keyword$$(null,"maskUnits","maskUnits",1842176270);$cljs$cst$2621$mod_page$$=new $APP.$cljs$core$Keyword$$(null,"mod-page","mod-page",1847006799);$cljs$cst$4040$new_shape_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"new-shape?","new-shape?",178861361);
$cljs$cst$742$sub_delims$$=new $APP.$cljs$core$Keyword$$(null,"sub-delims","sub-delims",1571683437);$APP.$cljs$cst$2971$wasm_critical$$=new $APP.$cljs$core$Keyword$$(null,"wasm-critical","wasm-critical",-12740140);$APP.$cljs$cst$1715$first_row$$=new $APP.$cljs$core$Keyword$$(null,"first-row","first-row",-111793911);$cljs$cst$2927$unicode_bidi$$=new $APP.$cljs$core$Keyword$$(null,"unicode-bidi","unicode-bidi",310629754);
$cljs$cst$163$recur$$=new $APP.$cljs$core$Symbol$$(null,"recur","recur",1202958259,null);$APP.$cljs$cst$3067$force_frame_thumbnails$$=new $APP.$cljs$core$Keyword$$(null,"force-frame-thumbnails","force-frame-thumbnails",-717831919);$cljs$cst$4620$font_size_value$$=new $APP.$cljs$core$Keyword$$(null,"font-size-value","font-size-value",-1463858424);$APP.$cljs$cst$1776$last_order$$=new $APP.$cljs$core$Keyword$$(null,"last-order","last-order",203806992);
$cljs$cst$4230$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_start_draw_mode_STAR_$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","start-draw-mode*","app.main.data.workspace.path.drawing/start-draw-mode*",-328303341);$cljs$cst$688$inst_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"inst?","inst?",1614698981,null);$APP.$cljs$cst$4828$bring_forward$$=new $APP.$cljs$core$Keyword$$(null,"bring-forward","bring-forward",-672639798);
$APP.$cljs$cst$3080$saved_font_size$$=new $APP.$cljs$core$Keyword$$(null,"saved-font-size","saved-font-size",-1079596543);$cljs$cst$4763$resource_id$$=new $APP.$cljs$core$Keyword$$(null,"resource-id","resource-id",-1308422582);$cljs$cst$2895$stemh$$=new $APP.$cljs$core$Keyword$$(null,"stemh","stemh",1705215871);
$cljs$cst$4268$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_start_drawing$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.drawing","start-drawing","app.main.data.workspace.drawing/start-drawing",-1115834775);$cljs$cst$2787$stemv$$=new $APP.$cljs$core$Keyword$$(null,"stemv","stemv",-157426393);
$cljs$cst$4683$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_propagation_SLASH_propagate_workspace_tokens$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.propagation","propagate-workspace-tokens","app.main.data.workspace.tokens.propagation/propagate-workspace-tokens",-508121292);$cljs$cst$283$cljs_DOT_core_SLASH_unquote$$=new $APP.$cljs$core$Symbol$$("cljs.core","unquote","cljs.core/unquote",1013085760,null);
$APP.$cljs$cst$244$cljs_DOT_core_SLASH_hash_set$$=new $APP.$cljs$core$Symbol$$("cljs.core","hash-set","cljs.core/hash-set",1130426749,null);$APP.$cljs$cst$1135$old_password$$=new $APP.$cljs$core$Keyword$$(null,"old-password","old-password",1136552804);$cljs$cst$2701$feTurbulence$$=new $APP.$cljs$core$Keyword$$(null,"feTurbulence","feTurbulence",2079450215);$cljs$cst$1504$defn_$$=new $APP.$cljs$core$Symbol$$(null,"defn-","defn-",1097765044,null);
$cljs$cst$3679$mixBlendMode$$=new $APP.$cljs$core$Keyword$$(null,"mixBlendMode","mixBlendMode",362779252);$cljs$cst$2769$textLength$$=new $APP.$cljs$core$Keyword$$(null,"textLength","textLength",2037311011);$cljs$cst$3041$gradient_transform$$=new $APP.$cljs$core$Keyword$$(null,"gradient-transform","gradient-transform",-1737815870);
$cljs$cst$5272$app_DOT_main_DOT_data_DOT_viewer_SLASH_set_nav_scroll$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","set-nav-scroll","app.main.data.viewer/set-nav-scroll",1095276888);$cljs$cst$3690$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_image_uploaded$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.media","image-uploaded","app.main.data.workspace.media/image-uploaded",-1620704432);$cljs$cst$2990$shavian$$=new $APP.$cljs$core$Keyword$$(null,"shavian","shavian",1437298405);
$cljs$cst$3084$base_objects$$=new $APP.$cljs$core$Keyword$$(null,"base-objects","base-objects",1173855083);$cljs$cst$112$cljs_DOT_core_SLASH_halt$$=new $APP.$cljs$core$Keyword$$("cljs.core","halt","cljs.core/halt",-1049036715);$cljs$cst$4945$update_project_pin$$=new $APP.$cljs$core$Keyword$$(null,"update-project-pin","update-project-pin",-1855624591);$cljs$cst$4358$disconnect$$=new $APP.$cljs$core$Keyword$$(null,"disconnect","disconnect",-132009289);
$APP.$cljs$cst$4542$on_pointer_down$$=new $APP.$cljs$core$Keyword$$(null,"on-pointer-down","on-pointer-down",573334138);$APP.$cljs$cst$4798$copy$$=new $APP.$cljs$core$Keyword$$(null,"copy","copy",-1077617309);$cljs$cst$2153$native_event$$=new $APP.$cljs$core$Keyword$$(null,"native-event","native-event",-387122796);
$APP.$cljs$cst$4391$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_select_track_cells$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid-layout.editor","select-track-cells","app.main.data.workspace.grid-layout.editor/select-track-cells",-1790760885);$APP.$cljs$cst$4724$token_node_context_menu$$=new $APP.$cljs$core$Keyword$$(null,"token-node-context-menu","token-node-context-menu",-107694707);
$cljs$cst$4702$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_update_token_set$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","update-token-set","app.main.data.workspace.tokens.library-edit/update-token-set",-854753157);$APP.$cljs$cst$2676$variants$$=new $APP.$cljs$core$Keyword$$(null,"variants","variants",-176391100);
$APP.$cljs$cst$5236$app_DOT_main_DOT_data_DOT_viewer_SLASH_initialize$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","initialize","app.main.data.viewer/initialize",-1196715997);$cljs$cst$2519$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_fonts$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","go-to-dashboard-fonts","app.main.data.common/go-to-dashboard-fonts",-1567195956);
$APP.$cljs$cst$5234$show_on_click$$=new $APP.$cljs$core$Keyword$$(null,"show-on-click","show-on-click",1549930356);$APP.$cljs$cst$4910$app_DOT_main_DOT_data_DOT_dashboard_SLASH_search$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","search","app.main.data.dashboard/search",-944445674);$APP.$cljs$cst$5017$embed_assets$$=new $APP.$cljs$core$Keyword$$(null,"embed-assets","embed-assets",76615105);
$APP.$cljs$cst$2480$get_file_summary$$=new $APP.$cljs$core$Keyword$$(null,"get-file-summary","get-file-summary",-845116685);$cljs$cst$5208$variant_bad_name$$=new $APP.$cljs$core$Keyword$$(null,"variant-bad-name","variant-bad-name",1075263625);$cljs$cst$2351$bottom_actions$$=new $APP.$cljs$core$Keyword$$(null,"bottom-actions","bottom-actions",-2121294335);$cljs$cst$937$decode_SLASH_string$$=new $APP.$cljs$core$Keyword$$("decode","string","decode/string",-108229948);
$cljs$cst$152$ns_STAR_$$=new $APP.$cljs$core$Symbol$$(null,"ns*","ns*",1840949383,null);$APP.$cljs$cst$4404$with_shapes_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"with-shapes?","with-shapes?",-2137257409);$cljs$cst$3920$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_component2$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","add-component2","app.main.data.workspace.libraries/add-component2",405951852);
$cljs$cst$3473$app_DOT_main_DOT_data_DOT_comments_SLASH_update_options$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","update-options","app.main.data.comments/update-options",1747043275);$cljs$cst$2295$device_type$$=new $APP.$cljs$core$Keyword$$(null,"device-type","device-type",-1461223759);$cljs$cst$693$list_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"list?","list?",-1494629,null);$APP.$cljs$cst$3076$html_text$$=new $APP.$cljs$core$Keyword$$(null,"html-text","html-text",2147046975);
$cljs$cst$4555$data_testid$$=new $APP.$cljs$core$Keyword$$(null,"data-testid","data-testid",102116723);$APP.$cljs$cst$226$none$$=new $APP.$cljs$core$Keyword$$(null,"none","none",1333468478);$cljs$cst$2673$app_DOT_main_DOT_data_DOT_render_wasm_SLASH_context_restored$$=new $APP.$cljs$core$Keyword$$("app.main.data.render-wasm","context-restored","app.main.data.render-wasm/context-restored",-517993519);
$cljs$cst$980$cljs_DOT_spec_DOT_alpha_SLASH_gfn$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","gfn","cljs.spec.alpha/gfn",-593120375);$cljs$cst$1232$nrepl_server$$=new $APP.$cljs$core$Keyword$$(null,"nrepl-server","nrepl-server",557025430);$APP.$cljs$cst$1956$push$$=new $APP.$cljs$core$Keyword$$(null,"push","push",799791267);$cljs$cst$3037$stopOpacity$$=new $APP.$cljs$core$Keyword$$(null,"stopOpacity","stopOpacity",-480120864);
$cljs$cst$1456$else_params$$=new $APP.$cljs$core$Keyword$$(null,"else-params","else-params",-832171646);$APP.$cljs$cst$2518$dashboard_libraries$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-libraries","dashboard-libraries",-1057436771);$cljs$cst$4250$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_apply_content_modifiers$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.edition","apply-content-modifiers","app.main.data.workspace.path.edition/apply-content-modifiers",-823918355);
$APP.$cljs$cst$1799$resize$$=new $APP.$cljs$core$Keyword$$(null,"resize","resize",297367086);$cljs$cst$2859$filterRes$$=new $APP.$cljs$core$Keyword$$(null,"filterRes","filterRes",-1696391977);$cljs$cst$1217$audit_log_archive$$=new $APP.$cljs$core$Keyword$$(null,"audit-log-archive","audit-log-archive",-1227035218);$cljs$cst$5192$not_head_copy_not_allowed$$=new $APP.$cljs$core$Keyword$$(null,"not-head-copy-not-allowed","not-head-copy-not-allowed",1731476124);
$cljs$cst$3369$vern_conflict$$=new $APP.$cljs$core$Keyword$$(null,"vern-conflict","vern-conflict",-1088162320);$APP.$cljs$cst$1739$stroke_color$$=new $APP.$cljs$core$Keyword$$(null,"stroke-color","stroke-color",-1089418937);$APP.$cljs$cst$257$left$$=new $APP.$cljs$core$Keyword$$(null,"left","left",-399115937);$APP.$cljs$cst$874$size$$=new $APP.$cljs$core$Keyword$$(null,"size","size",1098693007);
$APP.$cljs$cst$2017$square_marker$$=new $APP.$cljs$core$Keyword$$(null,"square-marker","square-marker",-789240803);$cljs$cst$694$seq_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"seq?","seq?",-1951934719,null);$cljs$cst$1878$radius_4$$=new $APP.$cljs$core$Keyword$$(null,"radius-4","radius-4",-1326301618);$cljs$cst$1877$radius_1$$=new $APP.$cljs$core$Keyword$$(null,"radius-1","radius-1",739275475);$cljs$cst$1358$webworker$$=new $APP.$cljs$core$Keyword$$(null,"webworker","webworker",-1436600668);
$cljs$cst$149$case_STAR_$$=new $APP.$cljs$core$Symbol$$(null,"case*","case*",-1938255072,null);$cljs$cst$4770$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_request_simple_export$$=new $APP.$cljs$core$Keyword$$("app.main.data.exports.assets","request-simple-export","app.main.data.exports.assets/request-simple-export",-1758800299);$cljs$cst$400$properties$$=new $APP.$cljs$core$Symbol$$(null,"properties","properties",-1968616217,null);
$APP.$cljs$cst$4245$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_clear_area_selection$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.selection","clear-area-selection","app.main.data.workspace.path.selection/clear-area-selection",-1762539275);$cljs$cst$2737$feSpecularLighting$$=new $APP.$cljs$core$Keyword$$(null,"feSpecularLighting","feSpecularLighting",1266587194);
$APP.$cljs$cst$1768$text_decoration$$=new $APP.$cljs$core$Keyword$$(null,"text-decoration","text-decoration",1836813207);$APP.$cljs$cst$2654$from_path$$=new $APP.$cljs$core$Keyword$$(null,"from-path","from-path",-1111581224);$cljs$cst$3015$tifinagh$$=new $APP.$cljs$core$Keyword$$(null,"tifinagh","tifinagh",1474030232);$cljs$cst$2597$only$$=new $APP.$cljs$core$Keyword$$(null,"only","only",1907811652);
$cljs$cst$3918$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_delete_typography$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","delete-typography","app.main.data.workspace.libraries/delete-typography",-554111820);$cljs$cst$4217$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_drag_handler$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","drag-handler","app.main.data.workspace.path.drawing/drag-handler",905141402);
$cljs$cst$3275$app_DOT_main_DOT_data_DOT_team_SLASH_update_member_role$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","update-member-role","app.main.data.team/update-member-role",194380188);$APP.$cljs$cst$5122$invite_email$$=new $APP.$cljs$core$Keyword$$(null,"invite-email","invite-email",1375794598);$APP.$cljs$cst$3308$app_DOT_main_DOT_data_DOT_team_SLASH_delete_invitation$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","delete-invitation","app.main.data.team/delete-invitation",322136827);
$cljs$cst$3463$app_DOT_main_DOT_data_DOT_comments_SLASH_retrieve_unread_comment_threads$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","retrieve-unread-comment-threads","app.main.data.comments/retrieve-unread-comment-threads",-1975176127);$APP.$cljs$cst$1536$webp$$=new $APP.$cljs$core$Keyword$$(null,"webp","webp",1501869900);
$APP.$cljs$cst$4970$app_DOT_main_DOT_data_DOT_dashboard_SLASH_handle_change_team_role$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","handle-change-team-role","app.main.data.dashboard/handle-change-team-role",823143837);$APP.$cljs$cst$3723$snap_ruler_guides$$=new $APP.$cljs$core$Keyword$$(null,"snap-ruler-guides","snap-ruler-guides",-1478768942);$cljs$cst$5138$owner_cant_leave_team$$=new $APP.$cljs$core$Keyword$$(null,"owner-cant-leave-team","owner-cant-leave-team",659839763);
$APP.$cljs$cst$2259$create_file_thumbnail$$=new $APP.$cljs$core$Keyword$$(null,"create-file-thumbnail","create-file-thumbnail",-1914149111);$cljs$cst$3013$lao$$=new $APP.$cljs$core$Keyword$$(null,"lao","lao",963598070);$cljs$cst$3894$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_event$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.wasm-text","resize-wasm-text-debounce-event","app.main.data.workspace.wasm-text/resize-wasm-text-debounce-event",-1468604289);
$APP.$cljs$cst$1994$variant$$=new $APP.$cljs$core$Keyword$$(null,"variant","variant",-424354234);$cljs$cst$2718$feFlood$$=new $APP.$cljs$core$Keyword$$(null,"feFlood","feFlood",1576205104);$cljs$cst$3968$ignore_file_library_sync_status$$=new $APP.$cljs$core$Keyword$$(null,"ignore-file-library-sync-status","ignore-file-library-sync-status",317750129);$cljs$cst$2973$family_id_buffer$$=new $APP.$cljs$core$Keyword$$(null,"family-id-buffer","family-id-buffer",2023888629);
$cljs$cst$4294$app_DOT_main_DOT_data_DOT_workspace_DOT_highlight_SLASH_highlight_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.highlight","highlight-shape","app.main.data.workspace.highlight/highlight-shape",367099759);$cljs$cst$199$strable$$=new $APP.$cljs$core$Keyword$$(null,"strable","strable",1877668047);$cljs$cst$384$decode$$=new $APP.$cljs$core$Keyword$$(null,"decode","decode",-1306165281);
$cljs$cst$3403$close_only_edition_plugins_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"close-only-edition-plugins?","close-only-edition-plugins?",1950979027);$APP.$cljs$cst$5279$orig_frame_id$$=new $APP.$cljs$core$Keyword$$(null,"orig-frame-id","orig-frame-id",525378580);$cljs$cst$1126$p1__34846_SHARP_$$=new $APP.$cljs$core$Symbol$$(null,"p1__34846#","p1__34846#",-831752880,null);$cljs$cst$4085$grid_column$$=new $APP.$cljs$core$Keyword$$(null,"grid-column","grid-column",-1086912770);
$APP.$cljs$cst$1535$jpeg$$=new $APP.$cljs$core$Keyword$$(null,"jpeg","jpeg",-646816934);$cljs$cst$5354$analyze_import$$=new $APP.$cljs$core$Keyword$$(null,"analyze-import","analyze-import",-2025506043);$cljs$cst$4278$update_comment_thread_position$$=new $APP.$cljs$core$Keyword$$(null,"update-comment-thread-position","update-comment-thread-position",2101265859);$APP.$cljs$cst$1738$plugin_data$$=new $APP.$cljs$core$Keyword$$(null,"plugin-data","plugin-data",871296431);
$cljs$cst$4260$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_start_path_edit$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.edition","start-path-edit","app.main.data.workspace.path.edition/start-path-edit",-699741029);$APP.$cljs$cst$5611$count_libraries$$=new $APP.$cljs$core$Keyword$$(null,"count-libraries","count-libraries",-1908764886);$APP.$cljs$cst$5152$field$$=new $APP.$cljs$core$Keyword$$(null,"field","field",-1302436500);
$APP.$cljs$cst$3716$scale_text$$=new $APP.$cljs$core$Keyword$$(null,"scale-text","scale-text",302781380);$cljs$cst$696$set_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"set?","set?",1636014792,null);$cljs$cst$1843$additionalItems$$=new $APP.$cljs$core$Keyword$$(null,"additionalItems","additionalItems",630706986);$cljs$cst$1437$mincol$$=new $APP.$cljs$core$Keyword$$(null,"mincol","mincol",1230695445);
$APP.$cljs$cst$3451$update_comment$$=new $APP.$cljs$core$Keyword$$(null,"update-comment","update-comment",-1347462369);$cljs$cst$5057$app_DOT_main_DOT_data_DOT_nitrate_SLASH_show_nitrate_popup$$=new $APP.$cljs$core$Keyword$$("app.main.data.nitrate","show-nitrate-popup","app.main.data.nitrate/show-nitrate-popup",-2086071692);$cljs$cst$3176$ignore_geometry_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"ignore-geometry?","ignore-geometry?",836794794);
$cljs$cst$5205$invalid_variant_properties$$=new $APP.$cljs$core$Keyword$$(null,"invalid-variant-properties","invalid-variant-properties",128877781);$APP.$cljs$cst$2133$inset$$=new $APP.$cljs$core$Keyword$$(null,"inset","inset",-396367740);$cljs$cst$164$set_BANG_$$=new $APP.$cljs$core$Symbol$$(null,"set!","set!",250714521,null);$APP.$cljs$cst$939$title$$=new $APP.$cljs$core$Keyword$$(null,"title","title",636505583);
$APP.$cljs$cst$1177$access_tokens$$=new $APP.$cljs$core$Keyword$$(null,"access-tokens","access-tokens",713316693);$APP.$cljs$cst$2574$is_local$$=new $APP.$cljs$core$Keyword$$(null,"is-local","is-local",-258841872);$APP.$cljs$cst$5132$email_has_complaints$$=new $APP.$cljs$core$Keyword$$(null,"email-has-complaints","email-has-complaints",-2106579252);
$cljs$cst$2148$app_DOT_main_DOT_store_SLASH_ongoing_tasks$$=new $APP.$cljs$core$Keyword$$("app.main.store","ongoing-tasks","app.main.store/ongoing-tasks",1500732996);$cljs$cst$2728$glyph$$=new $APP.$cljs$core$Keyword$$(null,"glyph","glyph",2119448117);$cljs$cst$2951$app_DOT_main_DOT_data_DOT_shortcuts_SLASH_pop_shortcuts$$=new $APP.$cljs$core$Keyword$$("app.main.data.shortcuts","pop-shortcuts","app.main.data.shortcuts/pop-shortcuts",526453109);
$cljs$cst$3632$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","update-shapes-buffer","app.main.data.workspace.shapes/update-shapes-buffer",758061564);$APP.$cljs$cst$4495$workspace_assets$$=new $APP.$cljs$core$Keyword$$(null,"workspace-assets","workspace-assets",-912330383);$APP.$cljs$cst$2655$to_path$$=new $APP.$cljs$core$Keyword$$(null,"to-path","to-path",-1087845742);
$cljs$cst$3017$myanmar$$=new $APP.$cljs$core$Keyword$$(null,"myanmar","myanmar",764220601);$APP.$cljs$cst$3804$layout_gap_col$$=new $APP.$cljs$core$Keyword$$(null,"layout-gap-col","layout-gap-col",-1979319979);$APP.$cljs$cst$2467$create_share_link$$=new $APP.$cljs$core$Keyword$$(null,"create-share-link","create-share-link",-2140545233);$cljs$cst$2858$operator$$=new $APP.$cljs$core$Keyword$$(null,"operator","operator",-1860875338);
$APP.$cljs$cst$3995$blocks$$=new $APP.$cljs$core$Keyword$$(null,"blocks","blocks",-610462153);$APP.$cljs$cst$1982$border_radius$$=new $APP.$cljs$core$Keyword$$(null,"border-radius","border-radius",419594011);$cljs$cst$5001$insert_next_mention$$=new $APP.$cljs$core$Keyword$$(null,"insert-next-mention","insert-next-mention",-1023430798);$cljs$cst$1560$scroll_top$$=new $APP.$cljs$core$Keyword$$(null,"scroll-top","scroll-top",-46723100);
$APP.$cljs$cst$3262$get_teams$$=new $APP.$cljs$core$Keyword$$(null,"get-teams","get-teams",-760955609);$cljs$cst$4827$move_fast_down$$=new $APP.$cljs$core$Keyword$$(null,"move-fast-down","move-fast-down",-949416918);$cljs$cst$420$float$$=new $APP.$cljs$core$Keyword$$(null,"float","float",-1732389368);
$cljs$cst$3741$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_textpalette_QMARK_$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","show-textpalette?","app.main.data.workspace/show-textpalette?",-591861084);$APP.$cljs$cst$1679$layout_flex_dir$$=new $APP.$cljs$core$Keyword$$(null,"layout-flex-dir","layout-flex-dir",276559670);$cljs$cst$741$unreserved$$=new $APP.$cljs$core$Keyword$$(null,"unreserved","unreserved",354716524);
$APP.$cljs$cst$3171$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$=new $APP.$cljs$core$Keyword$$("app.common.files.changes-builder","library-data","app.common.files.changes-builder/library-data",351936329);$cljs$cst$2911$stroke_linejoin$$=new $APP.$cljs$core$Keyword$$(null,"stroke-linejoin","stroke-linejoin",-1810816406);
$cljs$cst$3576$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_assure_valid_current_page$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.undo","assure-valid-current-page","app.main.data.workspace.undo/assure-valid-current-page",1873691179);$cljs$cst$1121$p1__34845_SHARP_$$=new $APP.$cljs$core$Symbol$$(null,"p1__34845#","p1__34845#",1231943200,null);
$cljs$cst$4018$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_start_edit_if_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","start-edit-if-selected","app.main.data.workspace.texts/start-edit-if-selected",371880962);
$cljs$cst$4422$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_update_properties_names_and_values$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","update-properties-names-and-values","app.main.data.workspace.variants/update-properties-names-and-values",-643134898);$cljs$cst$720$sequential$$=new $APP.$cljs$core$Keyword$$(null,"sequential","sequential",-1082983960);
$APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","missing-reference","error.style-dictionary/missing-reference",599665942);$cljs$cst$5301$toggle_fullscreen$$=new $APP.$cljs$core$Keyword$$(null,"toggle-fullscreen","toggle-fullscreen",-1647254833);$APP.$cljs$cst$3977$shared$$=new $APP.$cljs$core$Keyword$$(null,"shared","shared",-384145993);
$APP.$cljs$cst$2359$notification$$=new $APP.$cljs$core$Keyword$$(null,"notification","notification",-222338233);$APP.$cljs$cst$1693$layout_grid_dir$$=new $APP.$cljs$core$Keyword$$(null,"layout-grid-dir","layout-grid-dir",1868849661);$APP.$cljs$cst$236$cljs_DOT_core_SLASH_with_meta$$=new $APP.$cljs$core$Symbol$$("cljs.core","with-meta","cljs.core/with-meta",749126446,null);
$cljs$cst$2257$app_DOT_util_DOT_sse_SLASH_clone_template$$=new $APP.$cljs$core$Keyword$$("app.util.sse","clone-template","app.util.sse/clone-template",1175830498);$cljs$cst$872$malli_DOT_generator_SLASH_no_generator$$=new $APP.$cljs$core$Keyword$$("malli.generator","no-generator","malli.generator/no-generator",934332770);$APP.$cljs$cst$1636$strokes$$=new $APP.$cljs$core$Keyword$$(null,"strokes","strokes",-1645650952);
$APP.$cljs$cst$4348$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_finalize$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.notifications","finalize","app.main.data.workspace.notifications/finalize",834117202);$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$=new $APP.$cljs$core$Keyword$$("app.common.schema","safe-number","app.common.schema/safe-number",746155378);
$cljs$cst$4336$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_disconnect$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.mcp","disconnect","app.main.data.workspace.mcp/disconnect",-2029867596);$cljs$cst$1253$enable_backend_api_doc$$=new $APP.$cljs$core$Keyword$$(null,"enable-backend-api-doc","enable-backend-api-doc",1763235126);$APP.$cljs$cst$3315$is_active$$=new $APP.$cljs$core$Keyword$$(null,"is-active","is-active",-1424968720);
$APP.$cljs$cst$2047$shape_ref$$=new $APP.$cljs$core$Keyword$$(null,"shape-ref","shape-ref",-780361329);$cljs$cst$3761$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_mask_group$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.groups","mask-group","app.main.data.workspace.groups/mask-group",650109249);$cljs$cst$2699$feConvolveMatrix$$=new $APP.$cljs$core$Keyword$$(null,"feConvolveMatrix","feConvolveMatrix",-857053754);
$cljs$cst$731$merge_required$$=new $APP.$cljs$core$Keyword$$(null,"merge-required","merge-required",75277811);$APP.$cljs$cst$3240$app_DOT_main_DOT_data_DOT_profile_SLASH_request_account_deletion$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","request-account-deletion","app.main.data.profile/request-account-deletion",-1431849983);$cljs$cst$2292$engine_version$$=new $APP.$cljs$core$Keyword$$(null,"engine-version","engine-version",2033807870);
$cljs$cst$1988$min_height$$=new $APP.$cljs$core$Keyword$$(null,"min-height","min-height",398480837);$cljs$cst$3320$app_DOT_main_DOT_data_DOT_team_SLASH_shared_files_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","shared-files-fetched","app.main.data.team/shared-files-fetched",1714765517);$cljs$cst$3052$disable_thumbnail_cache$$=new $APP.$cljs$core$Keyword$$(null,"disable-thumbnail-cache","disable-thumbnail-cache",-1747004158);
$cljs$cst$2862$xChannelSelector$$=new $APP.$cljs$core$Keyword$$(null,"xChannelSelector","xChannelSelector",778404855);$cljs$cst$1302$map_builder$$=new $APP.$cljs$core$Keyword$$(null,"map-builder","map-builder",-1843343288);$cljs$cst$3242$app_DOT_main_DOT_data_DOT_profile_SLASH_request_profile_recovery$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","request-profile-recovery","app.main.data.profile/request-profile-recovery",-593601211);
$APP.$cljs$cst$4914$recent_files$$=new $APP.$cljs$core$Keyword$$(null,"recent-files","recent-files",-314450292);$cljs$cst$2897$text_rendering$$=new $APP.$cljs$core$Keyword$$(null,"text-rendering","text-rendering",872518208);$cljs$cst$4362$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_file_restored$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.notifications","handle-file-restored","app.main.data.workspace.notifications/handle-file-restored",1482343933);
$cljs$cst$5325$rgba$$=new $APP.$cljs$core$Keyword$$(null,"rgba","rgba",-2032958718);$APP.$cljs$cst$5041$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_exit_preview_cleanup$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","exit-preview-cleanup","app.main.data.workspace.versions/exit-preview-cleanup",-2091728711);
$cljs$cst$814$clojure_DOT_test_DOT_check_DOT_generators_SLASH_keyword$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","keyword","clojure.test.check.generators/keyword",24530530,null);$APP.$cljs$cst$2375$syntax$$=new $APP.$cljs$core$Keyword$$(null,"syntax","syntax",-1637761676);$cljs$cst$3004$vietnamese$$=new $APP.$cljs$core$Keyword$$(null,"vietnamese","vietnamese",-1593849970);$APP.$cljs$cst$1803$scale_content$$=new $APP.$cljs$core$Keyword$$(null,"scale-content","scale-content",1165837834);
$APP.$cljs$cst$3585$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_fit_to_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.zoom","fit-to-shapes","app.main.data.workspace.zoom/fit-to-shapes",-433351605);$cljs$cst$3887$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_flip_vertical_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","flip-vertical-selected","app.main.data.workspace.transforms/flip-vertical-selected",1439561180);
$APP.$cljs$cst$261$head$$=new $APP.$cljs$core$Symbol$$(null,"head","head",869147608,null);$cljs$cst$2256$unable_to_process_repository_response$$=new $APP.$cljs$core$Keyword$$(null,"unable-to-process-repository-response","unable-to-process-repository-response",-694987169);$cljs$cst$2578$has_media_trimmed$$=new $APP.$cljs$core$Keyword$$(null,"has-media-trimmed","has-media-trimmed",285220007);
$APP.$cljs$cst$5045$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_enter_restore$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","enter-restore","app.main.data.workspace.versions/enter-restore",-131448163);$APP.$cljs$cst$4658$tokens_SLASH_border_radius$$=new $APP.$cljs$core$Keyword$$("tokens","border-radius","tokens/border-radius",-465372495);$APP.$cljs$cst$2556$ignore_touched$$=new $APP.$cljs$core$Keyword$$(null,"ignore-touched","ignore-touched",-179988699);
$APP.$cljs$cst$3622$parent_type$$=new $APP.$cljs$core$Keyword$$(null,"parent-type","parent-type",1460910476);$cljs$cst$4769$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_request_simple_export_wasm$$=new $APP.$cljs$core$Keyword$$("app.main.data.exports.assets","request-simple-export-wasm","app.main.data.exports.assets/request-simple-export-wasm",-1602217503);$cljs$cst$2660$media_refs$$=new $APP.$cljs$core$Keyword$$(null,"media-refs","media-refs",-2132599023);
$APP.$cljs$cst$4662$tokens_SLASH_font_size$$=new $APP.$cljs$core$Keyword$$("tokens","font-size","tokens/font-size",1578840480);$cljs$cst$3374$snapshot_already_locked$$=new $APP.$cljs$core$Keyword$$(null,"snapshot-already-locked","snapshot-already-locked",-138440288);$APP.$cljs$cst$3586$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_start_zooming$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.zoom","start-zooming","app.main.data.workspace.zoom/start-zooming",850336251);
$APP.$cljs$cst$2499$slow_progress_threshold$$=new $APP.$cljs$core$Keyword$$(null,"slow-progress-threshold","slow-progress-threshold",-1289590291);$APP.$cljs$cst$1628$suffix_fn$$=new $APP.$cljs$core$Keyword$$(null,"suffix-fn","suffix-fn",-1026050512);$cljs$cst$1827$exclusiveMinimum$$=new $APP.$cljs$core$Keyword$$(null,"exclusiveMinimum","exclusiveMinimum",-869557322);$cljs$cst$833$max_size$$=new $APP.$cljs$core$Keyword$$(null,"max-size","max-size",-874966132);
$cljs$cst$1046$distinct_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"distinct?","distinct?",-1684357959,null);$cljs$cst$1171$login_with_custom_sso$$=new $APP.$cljs$core$Keyword$$(null,"login-with-custom-sso","login-with-custom-sso",1598745070);$cljs$cst$5162$invalid_geometry$$=new $APP.$cljs$core$Keyword$$(null,"invalid-geometry","invalid-geometry",437001578);$cljs$cst$4562$data_direction$$=new $APP.$cljs$core$Keyword$$(null,"data-direction","data-direction",1954636275);
$cljs$cst$3611$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_clear_memorize_duplicated$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","clear-memorize-duplicated","app.main.data.workspace.selection/clear-memorize-duplicated",-433594579);$cljs$cst$2521$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_recent$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","go-to-dashboard-recent","app.main.data.common/go-to-dashboard-recent",-1889345749);
$APP.$cljs$cst$1592$viewer$$=new $APP.$cljs$core$Keyword$$(null,"viewer","viewer",-783949853);$cljs$cst$1554$on_event$$=new $APP.$cljs$core$Keyword$$(null,"on-event","on-event",1340574774);$APP.$cljs$cst$2883$local$$=new $APP.$cljs$core$Keyword$$(null,"local","local",-1497766724);$cljs$cst$5216$copy_nested$$=new $APP.$cljs$core$Keyword$$(null,"copy-nested","copy-nested",-718678662);$APP.$cljs$cst$1883$top_left$$=new $APP.$cljs$core$Keyword$$(null,"top-left","top-left",-1396159636);
$APP.$cljs$cst$2131$json_format_SLASH_legacy$$=new $APP.$cljs$core$Keyword$$("json-format","legacy","json-format/legacy",-1635639619);$cljs$cst$4717$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_update_token$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","update-token","app.main.data.workspace.tokens.library-edit/update-token",-1175110034);$APP.$cljs$cst$1664$nowrap$$=new $APP.$cljs$core$Keyword$$(null,"nowrap","nowrap",457264988);
$APP.$cljs$cst$4676$from_index$$=new $APP.$cljs$core$Keyword$$(null,"from-index","from-index",242234713);$APP.$cljs$cst$1854$to_p$$=new $APP.$cljs$core$Keyword$$(null,"to-p","to-p",1750614589);$cljs$cst$2791$edgeMode$$=new $APP.$cljs$core$Keyword$$(null,"edgeMode","edgeMode",-1193353208);$APP.$cljs$cst$1762$font_style$$=new $APP.$cljs$core$Keyword$$(null,"font-style","font-style",-773672352);$APP.$cljs$cst$1925$vbox$$=new $APP.$cljs$core$Keyword$$(null,"vbox","vbox",-492787765);
$cljs$cst$3738$app_DOT_main_DOT_data_DOT_workspace_SLASH_hide_palettes_QMARK_$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","hide-palettes?","app.main.data.workspace/hide-palettes?",196615363);$APP.$cljs$cst$1624$page$$=new $APP.$cljs$core$Keyword$$(null,"page","page",849072397);$APP.$cljs$cst$1273$full$$=new $APP.$cljs$core$Keyword$$(null,"full","full",436801220);$APP.$cljs$cst$5106$dashboard$$=new $APP.$cljs$core$Keyword$$(null,"dashboard","dashboard",-631747508);
$cljs$cst$1855$next_p$$=new $APP.$cljs$core$Keyword$$(null,"next-p","next-p",-465723819);$cljs$cst$4368$index_SLASH_initialize$$=new $APP.$cljs$core$Keyword$$("index","initialize","index/initialize",510000551);$cljs$cst$1274$patch$$=new $APP.$cljs$core$Keyword$$(null,"patch","patch",380775109);
$cljs$cst$3476$app_DOT_main_DOT_data_DOT_comments_SLASH_toggle_comment_options$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","toggle-comment-options","app.main.data.comments/toggle-comment-options",273894281);$cljs$cst$1831$allOf$$=new $APP.$cljs$core$Keyword$$(null,"allOf","allOf",857821143);
$cljs$cst$3791$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_clear_thumbnail$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.thumbnails","clear-thumbnail","app.main.data.workspace.thumbnails/clear-thumbnail",1788875739);$APP.$cljs$cst$4928$menu_pos$$=new $APP.$cljs$core$Keyword$$(null,"menu-pos","menu-pos",1459627496);
$cljs$cst$3745$app_DOT_main_DOT_data_DOT_workspace_SLASH_selected_palette$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","selected-palette","app.main.data.workspace/selected-palette",-1157185963);$cljs$cst$2944$wrapper_styles$$=new $APP.$cljs$core$Keyword$$(null,"wrapper-styles","wrapper-styles",484780849);
$cljs$cst$3967$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_ignore_sync$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","ignore-sync","app.main.data.workspace.libraries/ignore-sync",1151565753);$APP.$cljs$cst$4901$organization$$=new $APP.$cljs$core$Keyword$$(null,"organization","organization",-1639375379);$cljs$cst$4096$paragraph_set$$=new $APP.$cljs$core$Keyword$$(null,"paragraph-set","paragraph-set",1605922385);
$APP.$cljs$cst$4525$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_annotations_expanded$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","set-annotations-expanded","app.main.data.workspace/set-annotations-expanded",159587434);$cljs$cst$367$malli_DOT_core_SLASH_invalid_entry$$=new $APP.$cljs$core$Keyword$$("malli.core","invalid-entry","malli.core/invalid-entry",-1401097281);
$cljs$cst$4104$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_from_clipboard$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","paste-from-clipboard","app.main.data.workspace.clipboard/paste-from-clipboard",-754724549);$APP.$cljs$cst$2042$outer$$=new $APP.$cljs$core$Keyword$$(null,"outer","outer",-375185956);$APP.$cljs$cst$2397$routes$$=new $APP.$cljs$core$Keyword$$(null,"routes","routes",457900162);
$APP.$cljs$cst$3949$js_SLASH_rchanges$$=new $APP.$cljs$core$Keyword$$("js","rchanges","js/rchanges",1482699978);$cljs$cst$719$seqable$$=new $APP.$cljs$core$Keyword$$(null,"seqable","seqable",-1305253818);$cljs$cst$1820$prev$$=new $APP.$cljs$core$Keyword$$(null,"prev","prev",-1597069226);$APP.$cljs$cst$2172$router$$=new $APP.$cljs$core$Keyword$$(null,"router","router",1091916230);$APP.$cljs$cst$1759$font_variant_id$$=new $APP.$cljs$core$Keyword$$(null,"font-variant-id","font-variant-id",1488748718);
$APP.$cljs$cst$2571$deleted_at$$=new $APP.$cljs$core$Keyword$$(null,"deleted-at","deleted-at",1742232687);$APP.$cljs$cst$2085$ignore_index_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"ignore-index?","ignore-index?",-8034871);$APP.$cljs$cst$239$cljs_DOT_core_SLASH_apply$$=new $APP.$cljs$core$Symbol$$("cljs.core","apply","cljs.core/apply",1757277831,null);$cljs$cst$1455$right_params$$=new $APP.$cljs$core$Keyword$$(null,"right-params","right-params",-1790676237);
$APP.$cljs$cst$351$pred$$=new $APP.$cljs$core$Keyword$$(null,"pred","pred",1927423397);$APP.$cljs$cst$4875$align_top$$=new $APP.$cljs$core$Keyword$$(null,"align-top","align-top",576330652);$cljs$cst$2857$additive$$=new $APP.$cljs$core$Keyword$$(null,"additive","additive",-1654411690);
$cljs$cst$2140$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_pointer_update$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.notifications","handle-pointer-update","app.main.data.workspace.notifications/handle-pointer-update",614124289);$APP.$cljs$cst$5241$frames$$=new $APP.$cljs$core$Keyword$$(null,"frames","frames",1765687497);
$APP.$cljs$cst$2508$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_feedback$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","go-to-feedback","app.main.data.common/go-to-feedback",-1510038275);$APP.$cljs$cst$1984$min_width$$=new $APP.$cljs$core$Keyword$$(null,"min-width","min-width",1926193728);$APP.$cljs$cst$1813$move_to$$=new $APP.$cljs$core$Keyword$$(null,"move-to","move-to",-127537048);
$cljs$cst$1258$enable_onboarding$$=new $APP.$cljs$core$Keyword$$(null,"enable-onboarding","enable-onboarding",-179345467);$cljs$cst$1830$maximum$$=new $APP.$cljs$core$Keyword$$(null,"maximum","maximum",573880714);$cljs$cst$3675$strokeWidth$$=new $APP.$cljs$core$Keyword$$(null,"strokeWidth","strokeWidth",-2130848332);
$APP.$cljs$cst$4688$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_open_token_type$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","open-token-type","app.main.data.workspace.tokens.library-edit/open-token-type",-1027312451);$cljs$cst$5397$app_DOT_main_DOT_ui_DOT_viewer_DOT_interactions_SLASH_fixed$$=new $APP.$cljs$core$Keyword$$("app.main.ui.viewer.interactions","fixed","app.main.ui.viewer.interactions/fixed",-173194267);
$cljs$cst$2834$azimuth$$=new $APP.$cljs$core$Keyword$$(null,"azimuth","azimuth",-165971535);$APP.$cljs$cst$981$cljs_DOT_spec_DOT_alpha_SLASH_problems$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","problems","cljs.spec.alpha/problems",447400814);$cljs$cst$2738$font_face_format$$=new $APP.$cljs$core$Keyword$$(null,"font-face-format","font-face-format",975894619);
$APP.$cljs$cst$4137$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_reorder_fills$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","reorder-fills","app.main.data.workspace.colors/reorder-fills",1544017317);$APP.$cljs$cst$2334$timestamp$$=new $APP.$cljs$core$Keyword$$(null,"timestamp","timestamp",579478971);$APP.$cljs$cst$4751$palette$$=new $APP.$cljs$core$Keyword$$(null,"palette","palette",-456203511);$cljs$cst$1428$func$$=new $APP.$cljs$core$Keyword$$(null,"func","func",-238706040);
$cljs$cst$4480$app_DOT_main_DOT_data_DOT_workspace_SLASH_start_rename_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","start-rename-selected","app.main.data.workspace/start-rename-selected",2047765576);$cljs$cst$2879$bias$$=new $APP.$cljs$core$Keyword$$(null,"bias","bias",-315297926);$cljs$cst$1580$headers$$=new $APP.$cljs$core$Keyword$$(null,"headers","headers",-835030129);$APP.$cljs$cst$1655$stroke_width$$=new $APP.$cljs$core$Keyword$$(null,"stroke-width","stroke-width",716836435);
$APP.$cljs$cst$2242$specialized_panel$$=new $APP.$cljs$core$Keyword$$(null,"specialized-panel","specialized-panel",2140639966);$cljs$cst$1202$backend_api_doc$$=new $APP.$cljs$core$Keyword$$(null,"backend-api-doc","backend-api-doc",6116805);$APP.$cljs$cst$1662$column_reverse$$=new $APP.$cljs$core$Keyword$$(null,"column-reverse","column-reverse",278726587);
$cljs$cst$4948$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_project$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","delete-project","app.main.data.dashboard/delete-project",507415211);$cljs$cst$1238$tiered_file_data_storage$$=new $APP.$cljs$core$Keyword$$(null,"tiered-file-data-storage","tiered-file-data-storage",-994462663);
$cljs$cst$825$clojure_DOT_test_DOT_check_DOT_generators_SLASH_uuid$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","uuid","clojure.test.check.generators/uuid",1589373144,null);$cljs$cst$1859$next_i$$=new $APP.$cljs$core$Keyword$$(null,"next-i","next-i",-22842911);$cljs$cst$1860$next_c$$=new $APP.$cljs$core$Keyword$$(null,"next-c","next-c",-776594929);$APP.$cljs$cst$1876$show_content$$=new $APP.$cljs$core$Keyword$$(null,"show-content","show-content",-878000465);
$cljs$cst$3883$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_move_shapes_to_frame$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","move-shapes-to-frame","app.main.data.workspace.transforms/move-shapes-to-frame",-1512544373);$APP.$cljs$cst$3139$file_revn$$=new $APP.$cljs$core$Keyword$$(null,"file-revn","file-revn",1919013210);$APP.$cljs$cst$1351$chrome$$=new $APP.$cljs$core$Keyword$$(null,"chrome","chrome",1718738387);
$cljs$cst$4697$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_update_token_theme$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","update-token-theme","app.main.data.workspace.tokens.library-edit/update-token-theme",1725915766);$APP.$cljs$cst$4765$done$$=new $APP.$cljs$core$Keyword$$(null,"done","done",-889844188);
$APP.$cljs$cst$4036$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_add_typography$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","add-typography","app.main.data.workspace.texts/add-typography",-992361009);$cljs$cst$4742$max_length$$=new $APP.$cljs$core$Keyword$$(null,"max-length","max-length",-254826109);$cljs$cst$2636$restore_component$$=new $APP.$cljs$core$Keyword$$(null,"restore-component","restore-component",-354059544);
$cljs$cst$3676$strokeColor$$=new $APP.$cljs$core$Keyword$$(null,"strokeColor","strokeColor",-1017463338);$cljs$cst$4370$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_create_page$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.pages","create-page","app.main.data.workspace.pages/create-page",-101676872);$cljs$cst$407$type$$=new $APP.$cljs$core$Symbol$$(null,"type","type",-1480165421,null);$APP.$cljs$cst$4158$prop$$=new $APP.$cljs$core$Keyword$$(null,"prop","prop",-515168332);
$cljs$cst$3891$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_commit$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.wasm-text","resize-wasm-text-debounce-commit","app.main.data.workspace.wasm-text/resize-wasm-text-debounce-commit",-1698151156);$APP.$cljs$cst$4314$draw_interaction_to_frame$$=new $APP.$cljs$core$Keyword$$(null,"draw-interaction-to-frame","draw-interaction-to-frame",1468971233);
$cljs$cst$4339$mcp_SLASH_force_disconect$$=new $APP.$cljs$core$Keyword$$("mcp","force-disconect","mcp/force-disconect",-26416193);$cljs$cst$969$app_DOT_common_DOT_schema_SLASH_word_string$$=new $APP.$cljs$core$Keyword$$("app.common.schema","word-string","app.common.schema/word-string",149287535);$cljs$cst$1228$rpc_climit$$=new $APP.$cljs$core$Keyword$$(null,"rpc-climit","rpc-climit",1132078100);$cljs$cst$2905$clip$$=new $APP.$cljs$core$Keyword$$(null,"clip","clip",830998499);
$APP.$cljs$cst$302$key$$=new $APP.$cljs$core$Keyword$$(null,"key","key",-1516042587);$cljs$cst$1031$cljs_DOT_core_SLASH_vector_QMARK_$$=new $APP.$cljs$core$Symbol$$("cljs.core","vector?","cljs.core/vector?",-1550392028,null);$cljs$cst$1847$app_DOT_common_DOT_schema_DOT_openapi_SLASH_definitions_path$$=new $APP.$cljs$core$Keyword$$("app.common.schema.openapi","definitions-path","app.common.schema.openapi/definitions-path",585697057);
$APP.$cljs$cst$2972$wasm_error$$=new $APP.$cljs$core$Keyword$$(null,"wasm-error","wasm-error",-551095469);$cljs$cst$1889$invalid_path_content$$=new $APP.$cljs$core$Keyword$$(null,"invalid-path-content","invalid-path-content",995132187);$cljs$cst$4076$string_or_size_array$$=new $APP.$cljs$core$Keyword$$(null,"string-or-size-array","string-or-size-array",209186492);
$cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","invalid","cljs.spec.alpha/invalid",-1220295119);$cljs$cst$1391$logical_block$$=new $APP.$cljs$core$Keyword$$(null,"logical-block","logical-block",-581022564);$APP.$cljs$cst$4527$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_annotations_id_for_create$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","set-annotations-id-for-create","app.main.data.workspace/set-annotations-id-for-create",1708769738);
$cljs$cst$3980$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_load_library_file$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","load-library-file","app.main.data.workspace.libraries/load-library-file",-1827833053);$APP.$cljs$cst$2479$on_accept$$=new $APP.$cljs$core$Keyword$$(null,"on-accept","on-accept",705439955);
$APP.$cljs$cst$4320$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_finish_move_overlay_pos$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","finish-move-overlay-pos","app.main.data.workspace.interactions/finish-move-overlay-pos",-1111758434);$APP.$cljs$cst$3643$workspace_new_text_shapes$$=new $APP.$cljs$core$Keyword$$(null,"workspace-new-text-shapes","workspace-new-text-shapes",-1406403921);
$cljs$cst$2460$app_DOT_main_DOT_router_SLASH_nav_root$$=new $APP.$cljs$core$Keyword$$("app.main.router","nav-root","app.main.router/nav-root",-948084258);$APP.$cljs$cst$887$malli_SLASH_error$$=new $APP.$cljs$core$Keyword$$("malli","error","malli/error",-1152359159);$cljs$cst$4475$app_DOT_main_DOT_data_DOT_workspace_SLASH_start_rename_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","start-rename-shape","app.main.data.workspace/start-rename-shape",1803085729);
$APP.$cljs$cst$4179$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_gradient_stop$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","remove-gradient-stop","app.main.data.workspace.colors/remove-gradient-stop",-388175503);$APP.$cljs$cst$2211$rulers$$=new $APP.$cljs$core$Keyword$$(null,"rulers","rulers",756731282);
$cljs$cst$5259$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_fullscreen$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","toggle-fullscreen","app.main.data.viewer/toggle-fullscreen",-237211555);$cljs$cst$2881$v_ideographic$$=new $APP.$cljs$core$Keyword$$(null,"v-ideographic","v-ideographic",-1846578533);
$APP.$cljs$cst$3160$app_DOT_main_DOT_data_DOT_persistence_SLASH_commit_persisted$$=new $APP.$cljs$core$Keyword$$("app.main.data.persistence","commit-persisted","app.main.data.persistence/commit-persisted",-1619235892);$cljs$cst$786$clojure_DOT_test_DOT_check_DOT_generators_SLASH_list$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","list","clojure.test.check.generators/list",506971058,null);
$cljs$cst$4448$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_update_viewport_position_center$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.viewport","update-viewport-position-center","app.main.data.workspace.viewport/update-viewport-position-center",-954554951);$APP.$cljs$cst$1949$ease_in_out$$=new $APP.$cljs$core$Keyword$$(null,"ease-in-out","ease-in-out",1896519269);
$APP.$cljs$cst$1692$layout_align_items$$=new $APP.$cljs$core$Keyword$$(null,"layout-align-items","layout-align-items",-788507895);$APP.$cljs$cst$3093$on_shapes_ready$$=new $APP.$cljs$core$Keyword$$(null,"on-shapes-ready","on-shapes-ready",-1272268631);$APP.$cljs$cst$4002$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_editor$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","update-editor","app.main.data.workspace.texts/update-editor",1553021306);
$APP.$cljs$cst$1970$overlay_position$$=new $APP.$cljs$core$Keyword$$(null,"overlay-position","overlay-position",-2038634730);$cljs$cst$2695$feBlend$$=new $APP.$cljs$core$Keyword$$(null,"feBlend","feBlend",1357659745);$cljs$cst$5358$on_hide_comments$$=new $APP.$cljs$core$Keyword$$(null,"on-hide-comments","on-hide-comments",-1952668017);$APP.$cljs$cst$1951$ease$$=new $APP.$cljs$core$Keyword$$(null,"ease","ease",-1427802543);
$cljs$cst$5003$mention_filter$$=new $APP.$cljs$core$Keyword$$(null,"mention-filter","mention-filter",1368401887);$cljs$cst$3572$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_restore_selection$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.undo","restore-selection","app.main.data.workspace.undo/restore-selection",-247338708);$APP.$cljs$cst$5608$on_cancel$$=new $APP.$cljs$core$Keyword$$(null,"on-cancel","on-cancel",-2071892932);
$cljs$cst$2616$mov_objects$$=new $APP.$cljs$core$Keyword$$(null,"mov-objects","mov-objects",-744687289);$APP.$cljs$cst$982$cljs_DOT_spec_DOT_alpha_SLASH_spec$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","spec","cljs.spec.alpha/spec",1947137578);$cljs$cst$5403$toggle_thumbnails$$=new $APP.$cljs$core$Keyword$$(null,"toggle-thumbnails","toggle-thumbnails",-1994383704);$APP.$cljs$cst$1904$style$$=new $APP.$cljs$core$Keyword$$(null,"style","style",-496642736);
$cljs$cst$4890$zoom_workspace$$=new $APP.$cljs$core$Keyword$$(null,"zoom-workspace","zoom-workspace",-763598621);$cljs$cst$2166$blur_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"blur?","blur?",366148003);$cljs$cst$1965$app_DOT_common_DOT_types_DOT_shape_DOT_interactions_SLASH_animation$$=new $APP.$cljs$core$Keyword$$("app.common.types.shape.interactions","animation","app.common.types.shape.interactions/animation",1402188269);
$cljs$cst$2877$xlink_COLON_title$$=new $APP.$cljs$core$Keyword$$(null,"xlink:title","xlink:title",244078426);$cljs$cst$2079$visibility_group$$=new $APP.$cljs$core$Keyword$$(null,"visibility-group","visibility-group",-461928512);$cljs$cst$2725$tspan$$=new $APP.$cljs$core$Keyword$$(null,"tspan","tspan",-1557853197);
$cljs$cst$3642$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_add_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","add-shape","app.main.data.workspace.shapes/add-shape",2080836645);$APP.$cljs$cst$5413$already_requested$$=new $APP.$cljs$core$Keyword$$(null,"already-requested","already-requested",-1921328713);$cljs$cst$1304$prefer_strings$$=new $APP.$cljs$core$Keyword$$(null,"prefer-strings","prefer-strings",1254507185);
$cljs$cst$1148$parallelism$$=new $APP.$cljs$core$Keyword$$(null,"parallelism","parallelism",-930922333);$APP.$cljs$cst$4097$with_prelude_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"with-prelude?","with-prelude?",-1449344035);$APP.$cljs$cst$572$report$$=new $APP.$cljs$core$Keyword$$(null,"report","report",1394055010);
$cljs$cst$4650$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_spacing_token_separated$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","apply-spacing-token-separated","app.main.data.workspace.tokens.application/apply-spacing-token-separated",655352797);$APP.$cljs$cst$4561$is_open_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"is-open?","is-open?",-319226511);
$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$=new $APP.$cljs$core$Keyword$$("app.common.schema","email","app.common.schema/email",2070921211);$APP.$cljs$cst$1236$mcp$$=new $APP.$cljs$core$Keyword$$(null,"mcp","mcp",-1160193577);$cljs$cst$698$false_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"false?","false?",-1522377573,null);
$cljs$cst$2525$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_invitations$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","go-to-dashboard-invitations","app.main.data.common/go-to-dashboard-invitations",-1542734327);$APP.$cljs$cst$1191$token_shadow$$=new $APP.$cljs$core$Keyword$$(null,"token-shadow","token-shadow",-67613663);$cljs$cst$3704$unable_to_optimize$$=new $APP.$cljs$core$Keyword$$(null,"unable-to-optimize","unable-to-optimize",-38574044);
$cljs$cst$5031$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_initialize_version$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","initialize-version","app.main.data.workspace.versions/initialize-version",1110960909);$APP.$cljs$cst$1645$fixed_scroll$$=new $APP.$cljs$core$Keyword$$(null,"fixed-scroll","fixed-scroll",-83520691);$cljs$cst$2639$mod_typography$$=new $APP.$cljs$core$Keyword$$(null,"mod-typography","mod-typography",55947030);
$APP.$cljs$cst$3713$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_create_svg_shape_with_images$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.media","create-svg-shape-with-images","app.main.data.workspace.media/create-svg-shape-with-images",-945432051);$cljs$cst$1779$structure_parent$$=new $APP.$cljs$core$Keyword$$(null,"structure-parent","structure-parent",-188442324);$APP.$cljs$cst$2196$zoom$$=new $APP.$cljs$core$Keyword$$(null,"zoom","zoom",-1827487038);
$cljs$cst$3997$entityRanges$$=new $APP.$cljs$core$Keyword$$(null,"entityRanges","entityRanges",570254512);$APP.$cljs$cst$202$map$$=new $APP.$cljs$core$Keyword$$(null,"map","map",1371690461);$APP.$cljs$cst$1215$webhooks$$=new $APP.$cljs$core$Keyword$$(null,"webhooks","webhooks",1535047469);$APP.$cljs$cst$2119$is_new$$=new $APP.$cljs$core$Keyword$$(null,"is-new","is-new",-1424373503);$cljs$cst$1229$auto_file_snapshot$$=new $APP.$cljs$core$Keyword$$(null,"auto-file-snapshot","auto-file-snapshot",-1184648364);
$APP.$cljs$cst$339$max$$=new $APP.$cljs$core$Keyword$$(null,"max","max",61366548);$APP.$cljs$cst$1207$demo_users$$=new $APP.$cljs$core$Keyword$$(null,"demo-users","demo-users",1563448744);$APP.$cljs$cst$2576$base_font_size$$=new $APP.$cljs$core$Keyword$$(null,"base-font-size","base-font-size",-701078258);$cljs$cst$250$readers$$=new $APP.$cljs$core$Keyword$$(null,"readers","readers",-2118263030);$APP.$cljs$cst$4833$paste$$=new $APP.$cljs$core$Keyword$$(null,"paste","paste",1975741548);
$cljs$cst$168$catch$$=new $APP.$cljs$core$Symbol$$(null,"catch","catch",-1616370245,null);$cljs$cst$701$coll_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"coll?","coll?",-1874821441,null);$APP.$cljs$cst$296$path$$=new $APP.$cljs$core$Keyword$$(null,"path","path",-188191168);$cljs$cst$3398$open_plugins$$=new $APP.$cljs$core$Keyword$$(null,"open-plugins","open-plugins",-1053139426);$cljs$cst$2734$font_face_src$$=new $APP.$cljs$core$Keyword$$(null,"font-face-src","font-face-src",-900956361);
$cljs$cst$3882$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_position_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","position-shapes","app.main.data.workspace.transforms/position-shapes",1701060771);$cljs$cst$3494$app_DOT_main_DOT_data_DOT_fonts_SLASH_fonts_loaded$$=new $APP.$cljs$core$Keyword$$("app.main.data.fonts","fonts-loaded","app.main.data.fonts/fonts-loaded",484410584);
$cljs$cst$1072$max_count$$=new $APP.$cljs$core$Keyword$$(null,"max-count","max-count",1539185305);$APP.$cljs$cst$5398$login_register$$=new $APP.$cljs$core$Keyword$$(null,"login-register","login-register",1592630494);$APP.$cljs$cst$3220$email_comments$$=new $APP.$cljs$core$Keyword$$(null,"email-comments","email-comments",-1304503955);$cljs$cst$1862$close$$=new $APP.$cljs$core$Keyword$$(null,"close","close",1835149582);
$APP.$cljs$cst$1719$cell_coords$$=new $APP.$cljs$core$Keyword$$(null,"cell-coords","cell-coords",-1095377947);$cljs$cst$3703$media_max_file_size_reached$$=new $APP.$cljs$core$Keyword$$(null,"media-max-file-size-reached","media-max-file-size-reached",-1593957636);$APP.$cljs$cst$3994$inlineStyleRanges$$=new $APP.$cljs$core$Keyword$$(null,"inlineStyleRanges","inlineStyleRanges",-930533458);$APP.$cljs$cst$1808$proportion_lock$$=new $APP.$cljs$core$Keyword$$(null,"proportion-lock","proportion-lock",1363898127);
$cljs$cst$2980$emoji_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"emoji?","emoji?",-927869376);$cljs$cst$2712$font_face$$=new $APP.$cljs$core$Keyword$$(null,"font-face","font-face",-504453235);$APP.$cljs$cst$3498$uploads$$=new $APP.$cljs$core$Keyword$$(null,"uploads","uploads",-1652488906);$APP.$cljs$cst$3074$shape_titles$$=new $APP.$cljs$core$Keyword$$(null,"shape-titles","shape-titles",959632283);
$APP.$cljs$cst$3978$set_file_shared$$=new $APP.$cljs$core$Keyword$$(null,"set-file-shared","set-file-shared",1102909653);$cljs$cst$2093$dest_objects$$=new $APP.$cljs$core$Keyword$$(null,"dest-objects","dest-objects",1417587106);$APP.$cljs$cst$223$_Inf$$=new $APP.$cljs$core$Symbol$$(null,"-Inf","-Inf",-2123243689,null);$cljs$cst$2254$authorization$$=new $APP.$cljs$core$Keyword$$(null,"authorization","authorization",-166302136);
$cljs$cst$1361$data_uri$$=new $APP.$cljs$core$Keyword$$(null,"data-uri","data-uri",1087820220);$cljs$cst$615$__GT_$$=new $APP.$cljs$core$Keyword$$(null,"-\x3e","-\x3e",514830339);$APP.$cljs$cst$2180$library_of$$=new $APP.$cljs$core$Keyword$$(null,"library-of","library-of",-2050526569);$cljs$cst$1382$start_pos$$=new $APP.$cljs$core$Keyword$$(null,"start-pos","start-pos",668789086);
$APP.$cljs$cst$973$app_DOT_common_DOT_schema_SLASH_password$$=new $APP.$cljs$core$Keyword$$("app.common.schema","password","app.common.schema/password",836164606);$APP.$cljs$cst$1193$stroke_path$$=new $APP.$cljs$core$Keyword$$(null,"stroke-path","stroke-path",1519539425);
$cljs$cst$4213$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_start_path_undo$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.undo","start-path-undo","app.main.data.workspace.path.undo/start-path-undo",-2079853018);$APP.$cljs$cst$1161$info$$=new $APP.$cljs$core$Keyword$$(null,"info","info",-317069002);$cljs$cst$1319$trailing$$=new $APP.$cljs$core$Keyword$$(null,"trailing","trailing",-1987290406);
$APP.$cljs$cst$1953$down$$=new $APP.$cljs$core$Keyword$$(null,"down","down",1565245570);$cljs$cst$565$guard$$=new $APP.$cljs$core$Keyword$$(null,"guard","guard",-873147811);$cljs$cst$949$app_DOT_common_DOT_schema_DOT_openapi_SLASH_items$$=new $APP.$cljs$core$Keyword$$("app.common.schema.openapi","items","app.common.schema.openapi/items",-217752415);
$APP.$cljs$cst$4581$error_DOT_style_dictionary_SLASH_invalid_token_value$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","invalid-token-value","error.style-dictionary/invalid-token-value",2098581256);$cljs$cst$4063$border_start_end_radius$$=new $APP.$cljs$core$Keyword$$(null,"border-start-end-radius","border-start-end-radius",867698004);$cljs$cst$3768$shape_name$$=new $APP.$cljs$core$Keyword$$(null,"shape-name","shape-name",23994785);
$cljs$cst$2810$orientation$$=new $APP.$cljs$core$Keyword$$(null,"orientation","orientation",623557579);$APP.$cljs$cst$1667$center$$=new $APP.$cljs$core$Keyword$$(null,"center","center",-748944368);$APP.$cljs$cst$5029$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_rename_version$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","rename-version","app.main.data.workspace.versions/rename-version",-1166823355);
$APP.$cljs$cst$2216$workspace_presence$$=new $APP.$cljs$core$Keyword$$(null,"workspace-presence","workspace-presence",-919312096);$APP.$cljs$cst$2503$last_update$$=new $APP.$cljs$core$Keyword$$(null,"last-update","last-update",-983435406);$APP.$cljs$cst$1661$row_reverse$$=new $APP.$cljs$core$Keyword$$(null,"row-reverse","row-reverse",78332847);
$APP.$cljs$cst$3764$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_open_specialized_panel$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.specialized-panel","open-specialized-panel","app.main.data.workspace.specialized-panel/open-specialized-panel",2095004192);
$cljs$cst$4110$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_props$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","copy-selected-props","app.main.data.workspace.clipboard/copy-selected-props",-1744426900);$cljs$cst$2554$descendants_variant_ids_set$$=new $APP.$cljs$core$Keyword$$(null,"descendants-variant-ids-set","descendants-variant-ids-set",1890990250);$APP.$cljs$cst$1213$token_color$$=new $APP.$cljs$core$Keyword$$(null,"token-color","token-color",875683372);
$APP.$cljs$cst$1886$bottom_left$$=new $APP.$cljs$core$Keyword$$(null,"bottom-left","bottom-left",1607421488);$cljs$cst$363$entries$$=new $APP.$cljs$core$Symbol$$(null,"entries","entries",1553588366,null);$APP.$cljs$cst$2050$grids$$=new $APP.$cljs$core$Keyword$$(null,"grids","grids",44187194);$cljs$cst$1248$enable_login_with_password$$=new $APP.$cljs$core$Keyword$$(null,"enable-login-with-password","enable-login-with-password",668885383);
$cljs$cst$1469$generator_fn$$=new $APP.$cljs$core$Keyword$$(null,"generator-fn","generator-fn",811851656);$cljs$cst$866$malli_DOT_generator_SLASH_default$$=new $APP.$cljs$core$Keyword$$("malli.generator","default","malli.generator/default",-943988734);$APP.$cljs$cst$4524$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_component_annotation$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","update-component-annotation","app.main.data.workspace/update-component-annotation",-859622103);
$cljs$cst$1589$json_verbose$$=new $APP.$cljs$core$Keyword$$(null,"json-verbose","json-verbose",-542533531);$cljs$cst$2095$clojure_DOT_core_DOT_protocols_SLASH_datafy$$=new $APP.$cljs$core$Symbol$$("clojure.core.protocols","datafy","clojure.core.protocols/datafy",707534751,null);$APP.$cljs$cst$3264$members$$=new $APP.$cljs$core$Keyword$$(null,"members","members",159001018);$cljs$cst$5322$debug_SLASH_set_shape_ref$$=new $APP.$cljs$core$Keyword$$("debug","set-shape-ref","debug/set-shape-ref",1401889739);
$cljs$cst$3975$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_watch_component_changes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","watch-component-changes","app.main.data.workspace.libraries/watch-component-changes",726349778);$cljs$cst$773$max_tries$$=new $APP.$cljs$core$Keyword$$(null,"max-tries","max-tries",-1824441792);$APP.$cljs$cst$3215$password_2$$=new $APP.$cljs$core$Keyword$$(null,"password-2","password-2",-1471375738);
$APP.$cljs$cst$3152$app_DOT_main_DOT_data_DOT_persistence_SLASH_update_file_revn$$=new $APP.$cljs$core$Keyword$$("app.main.data.persistence","update-file-revn","app.main.data.persistence/update-file-revn",-1294196592);$APP.$cljs$cst$3214$password_1$$=new $APP.$cljs$core$Keyword$$(null,"password-1","password-1",983206964);$APP.$cljs$cst$3415$vtop$$=new $APP.$cljs$core$Keyword$$(null,"vtop","vtop",1654808384);
$APP.$cljs$cst$2526$dashboard_invitations$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-invitations","dashboard-invitations",-357467805);$cljs$cst$2682$custom$$=new $APP.$cljs$core$Keyword$$(null,"custom","custom",340151948);$APP.$cljs$cst$4638$expand_text_more_options$$=new $APP.$cljs$core$Keyword$$(null,"expand-text-more-options","expand-text-more-options",1399966572);
$cljs$cst$4435$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_add_new_variant$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","add-new-variant","app.main.data.workspace.variants/add-new-variant",-185616496);$APP.$cljs$cst$284$level$$=new $APP.$cljs$core$Keyword$$(null,"level","level",1290497552);$APP.$cljs$cst$2549$force_frame_id$$=new $APP.$cljs$core$Keyword$$(null,"force-frame-id","force-frame-id",1562086521);
$APP.$cljs$cst$1966$action_type$$=new $APP.$cljs$core$Keyword$$(null,"action-type","action-type",-1141667361);$cljs$cst$740$pchar$$=new $APP.$cljs$core$Keyword$$(null,"pchar","pchar",-247796372);$APP.$cljs$cst$3966$library_id$$=new $APP.$cljs$core$Keyword$$(null,"library-id","library-id",1790650983);$APP.$cljs$cst$5012$new_frame_id$$=new $APP.$cljs$core$Keyword$$(null,"new-frame-id","new-frame-id",150989205);
$cljs$cst$2144$app_DOT_main_DOT_data_DOT_workspace_DOT_persistence_SLASH_update_persistence_status$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.persistence","update-persistence-status","app.main.data.workspace.persistence/update-persistence-status",1352886816);$cljs$cst$4800$toggle_layers$$=new $APP.$cljs$core$Keyword$$(null,"toggle-layers","toggle-layers",1453515555);$APP.$cljs$cst$1289$transform$$=new $APP.$cljs$core$Keyword$$(null,"transform","transform",1381301764);
$cljs$cst$1354$macos$$=new $APP.$cljs$core$Keyword$$(null,"macos","macos",-1712303293);$cljs$cst$2814$yChannelSelector$$=new $APP.$cljs$core$Keyword$$(null,"yChannelSelector","yChannelSelector",42690605);$cljs$cst$2592$container_id$$=new $APP.$cljs$core$Keyword$$(null,"container-id","container-id",1274665684);$APP.$cljs$cst$3538$child_main$$=new $APP.$cljs$core$Keyword$$(null,"child-main","child-main",1212308227);
$cljs$cst$1151$app_DOT_common_DOT_logging_SLASH_body$$=new $APP.$cljs$core$Keyword$$("app.common.logging","body","app.common.logging/body",275332276);$APP.$cljs$cst$3910$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_duplicate_color$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","duplicate-color","app.main.data.workspace.libraries/duplicate-color",-1310467934);
$APP.$cljs$cst$1894$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_clockwise$$=new $APP.$cljs$core$Keyword$$("app.common.geom.shapes.intersect","clockwise","app.common.geom.shapes.intersect/clockwise",-588807839);$APP.$cljs$cst$2043$page_id$$=new $APP.$cljs$core$Keyword$$(null,"page-id","page-id",-872941168);$APP.$cljs$cst$1717$last_row$$=new $APP.$cljs$core$Keyword$$(null,"last-row","last-row",388121667);
$cljs$cst$4766$resource_uri$$=new $APP.$cljs$core$Keyword$$(null,"resource-uri","resource-uri",-1848708900);$APP.$cljs$cst$4603$error_SLASH_value$$=new $APP.$cljs$core$Keyword$$("error","value","error/value",420466049);$cljs$cst$2783$amplitude$$=new $APP.$cljs$core$Keyword$$(null,"amplitude","amplitude",-1387734203);
$APP.$cljs$cst$4123$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_as_image$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","copy-as-image","app.main.data.workspace.clipboard/copy-as-image",-566070704);$APP.$cljs$cst$1945$open_url$$=new $APP.$cljs$core$Keyword$$(null,"open-url","open-url",-1504173381);$cljs$cst$1448$overflowchar$$=new $APP.$cljs$core$Keyword$$(null,"overflowchar","overflowchar",-1620088106);
$cljs$cst$1457$min_remaining$$=new $APP.$cljs$core$Keyword$$(null,"min-remaining","min-remaining",962687677);$cljs$cst$3202$get_subscription_usage$$=new $APP.$cljs$core$Keyword$$(null,"get-subscription-usage","get-subscription-usage",1943951861);$APP.$cljs$cst$2522$dashboard_recent$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-recent","dashboard-recent",-1541043167);
$cljs$cst$4425$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_update_property_name$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","update-property-name","app.main.data.workspace.variants/update-property-name",1951379651);$APP.$cljs$cst$3928$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_restore_components$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","restore-components","app.main.data.workspace.libraries/restore-components",-2011030502);
$cljs$cst$3238$get_profiles_for_file_comments$$=new $APP.$cljs$core$Keyword$$(null,"get-profiles-for-file-comments","get-profiles-for-file-comments",-903478036);$cljs$cst$3797$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_watch_state_changes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.thumbnails","watch-state-changes","app.main.data.workspace.thumbnails/watch-state-changes",1728738579);
$APP.$cljs$cst$2189$workspace_drawing$$=new $APP.$cljs$core$Keyword$$(null,"workspace-drawing","workspace-drawing",-819329973);$cljs$cst$2865$mathematical$$=new $APP.$cljs$core$Keyword$$(null,"mathematical","mathematical",-944855880);$cljs$cst$2861$keyPoints$$=new $APP.$cljs$core$Keyword$$(null,"keyPoints","keyPoints",-241102985);$APP.$cljs$cst$1927$team_id$$=new $APP.$cljs$core$Keyword$$(null,"team-id","team-id",-14505725);
$APP.$cljs$cst$4162$editing_stop$$=new $APP.$cljs$core$Keyword$$(null,"editing-stop","editing-stop",-775668616);$cljs$cst$2836$xmlns_COLON_xlink$$=new $APP.$cljs$core$Keyword$$(null,"xmlns:xlink","xmlns:xlink",-316591054);$APP.$cljs$cst$1788$rotation$$=new $APP.$cljs$core$Keyword$$(null,"rotation","rotation",-1728051644);$APP.$cljs$cst$2317$event_name$$=new $APP.$cljs$core$Keyword$$(null,"event-name","event-name",927259778);$cljs$cst$764$into$$=new $APP.$cljs$core$Keyword$$(null,"into","into",-150836029);
$APP.$cljs$cst$5151$select_organization_modal$$=new $APP.$cljs$core$Keyword$$(null,"select-organization-modal","select-organization-modal",1824606948);$cljs$cst$3258$organization_slug$$=new $APP.$cljs$core$Keyword$$(null,"organization-slug","organization-slug",-854712756);$APP.$cljs$cst$3449$create_comment$$=new $APP.$cljs$core$Keyword$$(null,"create-comment","create-comment",1276859739);$cljs$cst$664$some_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"some?","some?",234752293,null);
$APP.$cljs$cst$3434$open$$=new $APP.$cljs$core$Keyword$$(null,"open","open",-1763596448);$cljs$cst$3956$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_component_thumbnail$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","update-component-thumbnail","app.main.data.workspace.libraries/update-component-thumbnail",1224427096);$cljs$cst$379$malli_DOT_core_SLASH_default$$=new $APP.$cljs$core$Keyword$$("malli.core","default","malli.core/default",-1706204176);
$cljs$cst$2982$oriya$$=new $APP.$cljs$core$Keyword$$(null,"oriya","oriya",977386913);$APP.$cljs$cst$1652$spread$$=new $APP.$cljs$core$Keyword$$(null,"spread","spread",862337191);$cljs$cst$3541$inst$$=new $APP.$cljs$core$Keyword$$(null,"inst","inst",645962501);
$cljs$cst$4279$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_set_zoom_to_separate_grouped_bubbles$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.comments","set-zoom-to-separate-grouped-bubbles","app.main.data.workspace.comments/set-zoom-to-separate-grouped-bubbles",-1713480086);
$APP.$cljs$cst$3888$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_selected_fit_content$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","selected-fit-content","app.main.data.workspace.transforms/selected-fit-content",-1229213719);$APP.$cljs$cst$1663$simple$$=new $APP.$cljs$core$Keyword$$(null,"simple","simple",-581868663);$APP.$cljs$cst$590$output$$=new $APP.$cljs$core$Symbol$$(null,"output","output",534662484,null);
$APP.$cljs$cst$3624$layout_SLASH_update$$=new $APP.$cljs$core$Keyword$$("layout","update","layout/update",-2110439502);$APP.$cljs$cst$2614$del_obj$$=new $APP.$cljs$core$Keyword$$(null,"del-obj","del-obj",-1367710701);$APP.$cljs$cst$3029$log$$=new $APP.$cljs$core$Keyword$$(null,"log","log",-1595516004);
$cljs$cst$4098$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_images$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","images","app.main.data.workspace.clipboard/images",1335143239);$cljs$cst$3024$brahmi$$=new $APP.$cljs$core$Keyword$$(null,"brahmi","brahmi",17936575);$APP.$cljs$cst$4017$update_name_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"update-name?","update-name?",-1643455272);
$cljs$cst$552$malli_DOT_core_SLASH_walk_schema_refs$$=new $APP.$cljs$core$Keyword$$("malli.core","walk-schema-refs","malli.core/walk-schema-refs",-1140065954);$cljs$cst$2667$operation_not_implemented$$=new $APP.$cljs$core$Keyword$$(null,"operation-not-implemented","operation-not-implemented",1906576164);$cljs$cst$3681$sodipodi_COLON_label$$=new $APP.$cljs$core$Keyword$$(null,"sodipodi:label","sodipodi:label",841624310);
$cljs$cst$2617$after_shape$$=new $APP.$cljs$core$Keyword$$(null,"after-shape","after-shape",2054601304);$cljs$cst$490$parse$$=new $APP.$cljs$core$Keyword$$(null,"parse","parse",-1162164619);$cljs$cst$2668$_component_id$$=new $APP.$cljs$core$Keyword$$(null,"_component-id","_component-id",-2117037839);$cljs$cst$415$type_properties$$=new $APP.$cljs$core$Keyword$$(null,"type-properties","type-properties",-1728352126);
$cljs$cst$265$linked_SLASH_set$$=new $APP.$cljs$core$Symbol$$("linked","set","linked/set",833210926,null);$cljs$cst$823$clojure_DOT_test_DOT_check_DOT_generators_SLASH_symbol$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","symbol","clojure.test.check.generators/symbol",-1305461065,null);$APP.$cljs$cst$4729$token_set_edition_id$$=new $APP.$cljs$core$Keyword$$(null,"token-set-edition-id","token-set-edition-id",-457766729);
$cljs$cst$1849$app_DOT_common_DOT_openapi$$=new $APP.$cljs$core$Keyword$$(null,"app.common.openapi","app.common.openapi",778969799);$cljs$cst$2631$add_component$$=new $APP.$cljs$core$Keyword$$(null,"add-component","add-component",1053805610);$cljs$cst$666$integer_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"integer?","integer?",1303791671,null);$APP.$cljs$cst$3421$min_zoom$$=new $APP.$cljs$core$Keyword$$(null,"min-zoom","min-zoom",1063884318);
$cljs$cst$737$select_keys$$=new $APP.$cljs$core$Keyword$$(null,"select-keys","select-keys",1945879180);$cljs$cst$562$_EQ__GT_$$=new $APP.$cljs$core$Keyword$$(null,"\x3d\x3e","\x3d\x3e",1841166128);$cljs$cst$2288$app_DOT_util_DOT_i18n_SLASH_locale$$=new $APP.$cljs$core$Keyword$$("app.util.i18n","locale","app.util.i18n/locale",-2025524154);$APP.$cljs$cst$3292$create_team_with_invitations$$=new $APP.$cljs$core$Keyword$$(null,"create-team-with-invitations","create-team-with-invitations",429565487);
$APP.$cljs$cst$3196$update_profile_props$$=new $APP.$cljs$core$Keyword$$(null,"update-profile-props","update-profile-props",1444979019);$cljs$cst$708$_GT__EQ_$$=new $APP.$cljs$core$Keyword$$(null,"\x3e\x3d","\x3e\x3d",-623615505);$cljs$cst$3365$app_DOT_main_DOT_errors_SLASH_trace$$=new $APP.$cljs$core$Keyword$$("app.main.errors","trace","app.main.errors/trace",198160606);$cljs$cst$826$complete$$=new $APP.$cljs$core$Keyword$$(null,"complete","complete",-500388775);
$APP.$cljs$cst$965$app_DOT_common_DOT_schema_SLASH_keyword$$=new $APP.$cljs$core$Keyword$$("app.common.schema","keyword","app.common.schema/keyword",123822366);$APP.$cljs$cst$247$namespaced_map$$=new $APP.$cljs$core$Keyword$$(null,"namespaced-map","namespaced-map",1235665380);
$APP.$cljs$cst$4232$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_reset_last_handler$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","reset-last-handler","app.main.data.workspace.path.drawing/reset-last-handler",-1057892147);$cljs$cst$3792$delete_file_object_thumbnail$$=new $APP.$cljs$core$Keyword$$(null,"delete-file-object-thumbnail","delete-file-object-thumbnail",1757594590);
$cljs$cst$3800$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_wasm_SLASH_persist_thumbnail$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.thumbnails-wasm","persist-thumbnail","app.main.data.workspace.thumbnails-wasm/persist-thumbnail",1127474826);$cljs$cst$3468$threads$$=new $APP.$cljs$core$Keyword$$(null,"threads","threads",-1717798734);
$cljs$cst$4322$app_DOT_main_DOT_data_DOT_workspace_DOT_layers_SLASH_pressed_opacity$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.layers","pressed-opacity","app.main.data.workspace.layers/pressed-opacity",52482405);$cljs$cst$1195$google_fonts_provider$$=new $APP.$cljs$core$Keyword$$(null,"google-fonts-provider","google-fonts-provider",232973891);$APP.$cljs$cst$4646$on_update_shape$$=new $APP.$cljs$core$Keyword$$(null,"on-update-shape","on-update-shape",-489369523);
$cljs$cst$710$_LT__EQ_$$=new $APP.$cljs$core$Keyword$$(null,"\x3c\x3d","\x3c\x3d",-395636158);$APP.$cljs$cst$2356$actions$$=new $APP.$cljs$core$Keyword$$(null,"actions","actions",-812656882);$cljs$cst$1146$same_thread$$=new $APP.$cljs$core$Keyword$$(null,"same-thread","same-thread",-1479619719);$cljs$cst$2915$stop_opacity$$=new $APP.$cljs$core$Keyword$$(null,"stop-opacity","stop-opacity",-2018003729);
$cljs$cst$3066$wasm_gl_context_init_error$$=new $APP.$cljs$core$Keyword$$(null,"wasm-gl-context-init-error","wasm-gl-context-init-error",-2060239440);$APP.$cljs$cst$898$resolve$$=new $APP.$cljs$core$Keyword$$(null,"resolve","resolve",-1584445482);$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$=new $APP.$cljs$core$Keyword$$("app.common.schema","text","app.common.schema/text",1286758422);$APP.$cljs$cst$2024$overlay$$=new $APP.$cljs$core$Keyword$$(null,"overlay","overlay",-139131598);
$cljs$cst$3921$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_component$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","add-component","app.main.data.workspace.libraries/add-component",-135663634);$cljs$cst$2693$radialGradient$$=new $APP.$cljs$core$Keyword$$(null,"radialGradient","radialGradient",1402247193);$cljs$cst$2123$active_themes$$=new $APP.$cljs$core$Keyword$$(null,"active-themes","active-themes",-868998012);
$cljs$cst$4066$max_inline_size$$=new $APP.$cljs$core$Keyword$$(null,"max-inline-size","max-inline-size",1870424342);$APP.$cljs$cst$4109$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_text$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","copy-selected-text","app.main.data.workspace.clipboard/copy-selected-text",259733889);
$cljs$cst$4328$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_connect$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.mcp","connect","app.main.data.workspace.mcp/connect",-761499546);$APP.$cljs$cst$2328$total$$=new $APP.$cljs$core$Keyword$$(null,"total","total",1916810418);$APP.$cljs$cst$4956$dashboard_search_result$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-search-result","dashboard-search-result",1480869810);
$APP.$cljs$cst$4185$has_token_applied$$=new $APP.$cljs$core$Keyword$$(null,"has-token-applied","has-token-applied",-2051558353);$cljs$cst$564$output$$=new $APP.$cljs$core$Keyword$$(null,"output","output",-1105869043);$APP.$cljs$cst$3707$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_upload_fill_image$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.media","upload-fill-image","app.main.data.workspace.media/upload-fill-image",1325282481);
$APP.$cljs$cst$2872$target$$=new $APP.$cljs$core$Keyword$$(null,"target","target",253001721);$cljs$cst$393$malli_DOT_core_SLASH_coll_check_limit$$=new $APP.$cljs$core$Keyword$$("malli.core","coll-check-limit","malli.core/coll-check-limit",956583593);$cljs$cst$4588$error_DOT_style_dictionary_SLASH_composite_line_height_needs_font_size$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","composite-line-height-needs-font-size","error.style-dictionary/composite-line-height-needs-font-size",-1348579572);
$cljs$cst$3457$app_DOT_main_DOT_data_DOT_comments_SLASH_refresh_comment_thread$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","refresh-comment-thread","app.main.data.comments/refresh-comment-thread",1417625688);$APP.$cljs$cst$4140$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_add_fill$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","add-fill","app.main.data.workspace.colors/add-fill",2104769943);
$cljs$cst$2746$font_face_name$$=new $APP.$cljs$core$Keyword$$(null,"font-face-name","font-face-name",3825661);$APP.$cljs$cst$1666$space_evenly$$=new $APP.$cljs$core$Keyword$$(null,"space-evenly","space-evenly",-998758715);$cljs$cst$4121$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_image$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","paste-image","app.main.data.workspace.clipboard/paste-image",-1049201927);
$cljs$cst$197$nil$$=new $APP.$cljs$core$Keyword$$(null,"nil","nil",99600501);$APP.$cljs$cst$3532$library$$=new $APP.$cljs$core$Keyword$$(null,"library","library",467978288);$cljs$cst$4458$app_DOT_main_DOT_data_DOT_workspace_SLASH_library_resolved$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","library-resolved","app.main.data.workspace/library-resolved",-944700851);
$cljs$cst$4606$warning_DOT_style_dictionary_SLASH_invalid_referenced_token_value_opacity$$=new $APP.$cljs$core$Keyword$$("warning.style-dictionary","invalid-referenced-token-value-opacity","warning.style-dictionary/invalid-referenced-token-value-opacity",1549690788);
$cljs$cst$4434$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_resposition_and_resize_variant$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","resposition-and-resize-variant","app.main.data.workspace.variants/resposition-and-resize-variant",-384338766);$APP.$cljs$cst$2477$accept_style$$=new $APP.$cljs$core$Keyword$$(null,"accept-style","accept-style",630742659);$APP.$cljs$cst$4810$h_distribute$$=new $APP.$cljs$core$Keyword$$(null,"h-distribute","h-distribute",1044416837);
$cljs$cst$4099$images$$=new $APP.$cljs$core$Keyword$$(null,"images","images",1757475080);$cljs$cst$2771$elevation$$=new $APP.$cljs$core$Keyword$$(null,"elevation","elevation",-1609348796);$cljs$cst$3916$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_typography$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","update-typography","app.main.data.workspace.libraries/update-typography",-2118297692);
$cljs$cst$1194$soft_file_schema_validation$$=new $APP.$cljs$core$Keyword$$(null,"soft-file-schema-validation","soft-file-schema-validation",500463011);$APP.$cljs$cst$3324$owner_id$$=new $APP.$cljs$core$Keyword$$(null,"owner-id","owner-id",-58940392);$cljs$cst$1844$pattern$$=new $APP.$cljs$core$Keyword$$(null,"pattern","pattern",242135423);$cljs$cst$677$ident_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"ident?","ident?",-2061359468,null);
$APP.$cljs$cst$206$reader_exception$$=new $APP.$cljs$core$Keyword$$(null,"reader-exception","reader-exception",-1938323098);$cljs$cst$1384$trailing_white_space$$=new $APP.$cljs$core$Keyword$$(null,"trailing-white-space","trailing-white-space",1496006996);$APP.$cljs$cst$4487$app_DOT_main_DOT_data_DOT_workspace_SLASH_relocate_page$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","relocate-page","app.main.data.workspace/relocate-page",1396350911);
$APP.$cljs$cst$4522$app_DOT_main_DOT_data_DOT_workspace_SLASH_start_rename_page_item$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","start-rename-page-item","app.main.data.workspace/start-rename-page-item",279403443);$cljs$cst$5377$ldap_not_initialized$$=new $APP.$cljs$core$Keyword$$(null,"ldap-not-initialized","ldap-not-initialized",2044423174);$APP.$cljs$cst$2204$hover$$=new $APP.$cljs$core$Keyword$$(null,"hover","hover",-341141711);
$APP.$cljs$cst$2524$dashboard_members$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-members","dashboard-members",726788044);$APP.$cljs$cst$3149$saving$$=new $APP.$cljs$core$Keyword$$(null,"saving","saving",-567560703);$cljs$cst$4100$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","copy-selected","app.main.data.workspace.clipboard/copy-selected",-355255732);
$APP.$cljs$cst$3850$bounds$$=new $APP.$cljs$core$Keyword$$(null,"bounds","bounds",1691609455);$cljs$cst$2804$contentScriptType$$=new $APP.$cljs$core$Keyword$$(null,"contentScriptType","contentScriptType",1526654634);$APP.$cljs$cst$4839$toggle_focus_mode$$=new $APP.$cljs$core$Keyword$$(null,"toggle-focus-mode","toggle-focus-mode",-1702630161);$APP.$cljs$cst$2173$teams$$=new $APP.$cljs$core$Keyword$$(null,"teams","teams",1677714510);
$APP.$cljs$cst$2029$multiply$$=new $APP.$cljs$core$Keyword$$(null,"multiply","multiply",-1036907048);$APP.$cljs$cst$2371$wilds$$=new $APP.$cljs$core$Keyword$$(null,"wilds","wilds",132271223);$APP.$cljs$cst$3683$ignore_selection_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"ignore-selection?","ignore-selection?",1748318677);$cljs$cst$5340$panel$$=new $APP.$cljs$core$Keyword$$(null,"panel","panel",-558637456);
$APP.$cljs$cst$2399$meta_merge$$=new $APP.$cljs$core$Keyword$$(null,"meta-merge","meta-merge",638856199);$APP.$cljs$cst$5073$extra_errors$$=new $APP.$cljs$core$Keyword$$(null,"extra-errors","extra-errors",876684434);$APP.$cljs$cst$1863$from$$=new $APP.$cljs$core$Keyword$$(null,"from","from",1815293044);$cljs$cst$4886$tools$$=new $APP.$cljs$core$Keyword$$(null,"tools","tools",-1241731990);
$APP.$cljs$cst$3849$index_SLASH_query_snap$$=new $APP.$cljs$core$Keyword$$("index","query-snap","index/query-snap",1806121434);$cljs$cst$5318$path_editor$$=new $APP.$cljs$core$Keyword$$(null,"path-editor","path-editor",399326731);$APP.$cljs$cst$3514$app_DOT_main_DOT_data_DOT_project_SLASH_files_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.project","files-fetched","app.main.data.project/files-fetched",32635619);
$cljs$cst$704$ifn_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"ifn?","ifn?",-2106461064,null);$APP.$cljs$cst$2418$reitit_DOT_trie_SLASH_trie_compiler$$=new $APP.$cljs$core$Keyword$$("reitit.trie","trie-compiler","reitit.trie/trie-compiler",2125029755);$APP.$cljs$cst$5150$cancel_key$$=new $APP.$cljs$core$Keyword$$(null,"cancel-key","cancel-key",1694146993);$APP.$cljs$cst$5042$backup$$=new $APP.$cljs$core$Keyword$$(null,"backup","backup",26347393);
$cljs$cst$2570$paste_feature_not_enabled$$=new $APP.$cljs$core$Keyword$$(null,"paste-feature-not-enabled","paste-feature-not-enabled",163689318);$cljs$cst$685$qualified_symbol_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"qualified-symbol?","qualified-symbol?",98763807,null);$cljs$cst$1401$current$$=new $APP.$cljs$core$Keyword$$(null,"current","current",-1088038603);$APP.$cljs$cst$3662$column_tracks$$=new $APP.$cljs$core$Keyword$$(null,"column-tracks","column-tracks",291761616);
$cljs$cst$1506$__GT_$$=new $APP.$cljs$core$Symbol$$(null,"-\x3e","-\x3e",-2139605430,null);$APP.$cljs$cst$224$Inf$$=new $APP.$cljs$core$Symbol$$(null,"Inf","Inf",647172781,null);$APP.$cljs$cst$4001$new$$=new $APP.$cljs$core$Keyword$$(null,"new","new",-2085437848);$APP.$cljs$cst$3379$alert$$=new $APP.$cljs$core$Keyword$$(null,"alert","alert",-571950580);$cljs$cst$752$port$$=new $APP.$cljs$core$Keyword$$(null,"port","port",1534937262);
$APP.$cljs$cst$5618$expires_at$$=new $APP.$cljs$core$Keyword$$(null,"expires-at","expires-at",1654982210);$cljs$cst$1488$_DOT__DOT_$$=new $APP.$cljs$core$Symbol$$(null,"..","..",-300507420,null);$cljs$cst$361$children$$=new $APP.$cljs$core$Symbol$$(null,"children","children",699969545,null);$APP.$cljs$cst$2272$object_id$$=new $APP.$cljs$core$Keyword$$(null,"object-id","object-id",-754527291);
$cljs$cst$4069$margin_inline_start$$=new $APP.$cljs$core$Keyword$$(null,"margin-inline-start","margin-inline-start",320232954);$APP.$cljs$cst$205$default$$=new $APP.$cljs$core$Keyword$$(null,"default","default",-1987822328);$APP.$cljs$cst$4953$app_DOT_main_DOT_data_DOT_dashboard_SLASH_rename_file$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","rename-file","app.main.data.dashboard/rename-file",808622966);
$APP.$cljs$cst$1616$multiple$$=new $APP.$cljs$core$Keyword$$(null,"multiple","multiple",1244445549);$cljs$cst$207$ex_kind$$=new $APP.$cljs$core$Keyword$$(null,"ex-kind","ex-kind",1581199296);$APP.$cljs$cst$3506$app_DOT_main_DOT_data_DOT_fonts_SLASH_delete_font_variants$$=new $APP.$cljs$core$Keyword$$("app.main.data.fonts","delete-font-variants","app.main.data.fonts/delete-font-variants",-390227477);
$cljs$cst$4147$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_shadow$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","change-shadow","app.main.data.workspace.colors/change-shadow",1547764423);$APP.$cljs$cst$2657$before_group$$=new $APP.$cljs$core$Keyword$$(null,"before-group","before-group",1198330267);$APP.$cljs$cst$2238$workspace_text_modifier$$=new $APP.$cljs$core$Keyword$$(null,"workspace-text-modifier","workspace-text-modifier",1403277807);
$APP.$cljs$cst$104$cljs_DOT_core_SLASH_none$$=new $APP.$cljs$core$Keyword$$("cljs.core","none","cljs.core/none",926646439);$APP.$cljs$cst$4529$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_preview_blend_mode$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","set-preview-blend-mode","app.main.data.workspace/set-preview-blend-mode",-629971646);$APP.$cljs$cst$1767$vertical_align$$=new $APP.$cljs$core$Keyword$$(null,"vertical-align","vertical-align",651007333);
$APP.$cljs$cst$5415$error_report_id$$=new $APP.$cljs$core$Keyword$$(null,"error-report-id","error-report-id",848722092);$APP.$cljs$cst$5284$overlay_id$$=new $APP.$cljs$core$Keyword$$(null,"overlay-id","overlay-id",-1525970518);$cljs$cst$5156$error_code$$=new $APP.$cljs$core$Keyword$$(null,"error-code","error-code",180497232);$APP.$cljs$cst$924$accept$$=new $APP.$cljs$core$Keyword$$(null,"accept","accept",1874130431);
$APP.$cljs$cst$2400$update_paths$$=new $APP.$cljs$core$Keyword$$(null,"update-paths","update-paths",-813404599);$cljs$cst$4364$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_select_frame_tool$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.pages","select-frame-tool","app.main.data.workspace.pages/select-frame-tool",-968606818);$cljs$cst$2968$panic$$=new $APP.$cljs$core$Keyword$$(null,"panic","panic",-1043312570);
$cljs$cst$5058$app_DOT_main_DOT_data_DOT_nitrate_SLASH_get_nitrate_connectivity$$=new $APP.$cljs$core$Keyword$$("app.main.data.nitrate","get-nitrate-connectivity","app.main.data.nitrate/get-nitrate-connectivity",-1535032157);$APP.$cljs$cst$270$forward$$=new $APP.$cljs$core$Keyword$$(null,"forward","forward",-557345303);$cljs$cst$5104$default_member_id$$=new $APP.$cljs$core$Keyword$$(null,"default-member-id","default-member-id",1537017749);
$APP.$cljs$cst$5308$join_nodes$$=new $APP.$cljs$core$Keyword$$(null,"join-nodes","join-nodes",923290343);$cljs$cst$4807$toggle_lock_size$$=new $APP.$cljs$core$Keyword$$(null,"toggle-lock-size","toggle-lock-size",-1521532508);$APP.$cljs$cst$4408$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_hover_layout_track$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","hover-layout-track","app.main.data.workspace.shape-layout/hover-layout-track",1082473851);
$cljs$cst$596$malli_DOT_core_SLASH_invalid_input_schema$$=new $APP.$cljs$core$Keyword$$("malli.core","invalid-input-schema","malli.core/invalid-input-schema",-833477915);$cljs$cst$1079$cljs_DOT_spec_DOT_alpha_SLASH_kfn$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","kfn","cljs.spec.alpha/kfn",672643897);$APP.$cljs$cst$23$first$$=new $APP.$cljs$core$Symbol$$(null,"first","first",996428481,null);
$cljs$cst$2892$overline_thickness$$=new $APP.$cljs$core$Keyword$$(null,"overline-thickness","overline-thickness",-1687103105);$APP.$cljs$cst$4804$toggle_layout_flex$$=new $APP.$cljs$core$Keyword$$(null,"toggle-layout-flex","toggle-layout-flex",-419502780);$cljs$cst$1306$prefer_buffers$$=new $APP.$cljs$core$Keyword$$(null,"prefer-buffers","prefer-buffers",377042081);$cljs$cst$2251$attempt$$=new $APP.$cljs$core$Keyword$$(null,"attempt","attempt",1611761308);
$cljs$cst$1370$per_line_prefix$$=new $APP.$cljs$core$Keyword$$(null,"per-line-prefix","per-line-prefix",846941813);$cljs$cst$4607$warning_SLASH_code$$=new $APP.$cljs$core$Keyword$$("warning","code","warning/code",1535644202);$APP.$cljs$cst$1637$content$$=new $APP.$cljs$core$Keyword$$(null,"content","content",15833224);$APP.$cljs$cst$4847$toggle_visibility$$=new $APP.$cljs$core$Keyword$$(null,"toggle-visibility","toggle-visibility",502586674);
$APP.$cljs$cst$4171$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_finalize_colorpicker$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","finalize-colorpicker","app.main.data.workspace.colors/finalize-colorpicker",1984531720);$cljs$cst$1107$cljs_DOT_core_SLASH_nil_QMARK_$$=new $APP.$cljs$core$Symbol$$("cljs.core","nil?","cljs.core/nil?",945071861,null);$cljs$cst$5185$cycles_ids$$=new $APP.$cljs$core$Keyword$$(null,"cycles-ids","cycles-ids",-532391784);
$cljs$cst$3297$app_DOT_main_DOT_data_DOT_team_SLASH_leave_current_team$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","leave-current-team","app.main.data.team/leave-current-team",1086395474);$cljs$cst$1837$maxProperties$$=new $APP.$cljs$core$Keyword$$(null,"maxProperties","maxProperties",1289793027);$APP.$cljs$cst$1673$manual$$=new $APP.$cljs$core$Keyword$$(null,"manual","manual",-237370608);$APP.$cljs$cst$4850$undo$$=new $APP.$cljs$core$Keyword$$(null,"undo","undo",-1818036302);
$APP.$cljs$cst$4293$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_set_hover_guide$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.guides","set-hover-guide","app.main.data.workspace.guides/set-hover-guide",-1998691670);$cljs$cst$1234$render_wasm_dpr$$=new $APP.$cljs$core$Keyword$$(null,"render-wasm-dpr","render-wasm-dpr",286455414);$cljs$cst$672$neg_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"neg?","neg?",-1902175577,null);
$APP.$cljs$cst$3299$resend_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"resend?","resend?",-682387124);$APP.$cljs$cst$2213$recent_colors$$=new $APP.$cljs$core$Keyword$$(null,"recent-colors","recent-colors",237681180);$cljs$cst$3940$update_layout_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"update-layout?","update-layout?",-2012814935);$APP.$cljs$cst$1718$last_column$$=new $APP.$cljs$core$Keyword$$(null,"last-column","last-column",2053855408);
$APP.$cljs$cst$3618$return_ref$$=new $APP.$cljs$core$Keyword$$(null,"return-ref","return-ref",1355506357);$APP.$cljs$cst$4563$current_value$$=new $APP.$cljs$core$Keyword$$(null,"current-value","current-value",2066017989);$APP.$cljs$cst$4731$token_set_new_path$$=new $APP.$cljs$core$Keyword$$(null,"token-set-new-path","token-set-new-path",-718647152);$cljs$cst$5095$select_class$$=new $APP.$cljs$core$Keyword$$(null,"select-class","select-class",238488449);
$cljs$cst$3562$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_materialize_undo$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.undo","materialize-undo","app.main.data.workspace.undo/materialize-undo",-731495176);$cljs$cst$3343$auth_backend$$=new $APP.$cljs$core$Keyword$$(null,"auth-backend","auth-backend",1958958121);$cljs$cst$2082$shadow_group$$=new $APP.$cljs$core$Keyword$$(null,"shadow-group","shadow-group",1422309239);
$cljs$cst$3193$media_type_not_allowed$$=new $APP.$cljs$core$Keyword$$(null,"media-type-not-allowed","media-type-not-allowed",77597312);$cljs$cst$2935$marker_end$$=new $APP.$cljs$core$Keyword$$(null,"marker-end","marker-end",341488703);$cljs$cst$3348$provider$$=new $APP.$cljs$core$Keyword$$(null,"provider","provider",-302056900);$APP.$cljs$cst$2502$healthy$$=new $APP.$cljs$core$Keyword$$(null,"healthy","healthy",-215908271);
$APP.$cljs$cst$5316$add_node$$=new $APP.$cljs$core$Keyword$$(null,"add-node","add-node",-2069253988);$cljs$cst$341$properties$$=new $APP.$cljs$core$Keyword$$(null,"properties","properties",685819552);$APP.$cljs$cst$2276$post$$=new $APP.$cljs$core$Keyword$$(null,"post","post",269697687);$cljs$cst$3614$id_original$$=new $APP.$cljs$core$Keyword$$(null,"id-original","id-original",-1521290158);
$APP.$cljs$cst$3521$changed_sub_attr$$=new $APP.$cljs$core$Keyword$$(null,"changed-sub-attr","changed-sub-attr",280796634);$cljs$cst$3561$selected_after$$=new $APP.$cljs$core$Keyword$$(null,"selected-after","selected-after",-1541218630);$APP.$cljs$cst$5503$rules$$=new $APP.$cljs$core$Keyword$$(null,"rules","rules",1198912366);$APP.$cljs$cst$1685$layout_padding_type$$=new $APP.$cljs$core$Keyword$$(null,"layout-padding-type","layout-padding-type",-1407674837);
$APP.$cljs$cst$4546$set_size$$=new $APP.$cljs$core$Keyword$$(null,"set-size","set-size",-1037159587);$APP.$cljs$cst$4026$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","update-text-modifier","app.main.data.workspace.texts/update-text-modifier",297172056);$APP.$cljs$cst$5255$viewport_size$$=new $APP.$cljs$core$Keyword$$(null,"viewport-size","viewport-size",-1787032748);
$APP.$cljs$cst$4574$unit$$=new $APP.$cljs$core$Keyword$$(null,"unit","unit",375175175);$cljs$cst$5097$caution_item_fn$$=new $APP.$cljs$core$Keyword$$(null,"caution-item-fn","caution-item-fn",-331091117);$APP.$cljs$cst$2584$backend$$=new $APP.$cljs$core$Keyword$$(null,"backend","backend",-847489124);
$cljs$cst$4538$app_DOT_main_DOT_data_DOT_workspace_SLASH_close_layers_search$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","close-layers-search","app.main.data.workspace/close-layers-search",-169074233);$cljs$cst$2560$app_DOT_common_DOT_features_SLASH_features$$=new $APP.$cljs$core$Keyword$$("app.common.features","features","app.common.features/features",-559981229);$cljs$cst$3423$owner_email$$=new $APP.$cljs$core$Keyword$$(null,"owner-email","owner-email",-2131394980);
$APP.$cljs$cst$3972$starting_tab$$=new $APP.$cljs$core$Keyword$$(null,"starting-tab","starting-tab",-1478861215);$cljs$cst$3599$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_shift_select_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","shift-select-shapes","app.main.data.workspace.selection/shift-select-shapes",-314497046);$APP.$cljs$cst$2218$paddings_selected$$=new $APP.$cljs$core$Keyword$$(null,"paddings-selected","paddings-selected",1140014065);
$APP.$cljs$cst$3416$vbottom$$=new $APP.$cljs$core$Keyword$$(null,"vbottom","vbottom",-2106028734);$APP.$cljs$cst$1902$scale$$=new $APP.$cljs$core$Keyword$$(null,"scale","scale",-230427353);$cljs$cst$3213$cancel_email_change$$=new $APP.$cljs$core$Keyword$$(null,"cancel-email-change","cancel-email-change",-1474418788);$APP.$cljs$cst$1973$background_overlay$$=new $APP.$cljs$core$Keyword$$(null,"background-overlay","background-overlay",1186220424);
$cljs$cst$1153$app_DOT_common_DOT_logging_SLASH_context$$=new $APP.$cljs$core$Keyword$$("app.common.logging","context","app.common.logging/context",1292978112);$APP.$cljs$cst$1635$stroke_image$$=new $APP.$cljs$core$Keyword$$(null,"stroke-image","stroke-image",-1975913214);$APP.$cljs$cst$4659$fields$$=new $APP.$cljs$core$Keyword$$(null,"fields","fields",-1932066230);
$APP.$cljs$cst$3954$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_component_sync$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","update-component-sync","app.main.data.workspace.libraries/update-component-sync",1255755566);$cljs$cst$950$app_DOT_common_DOT_schema_DOT_openapi_SLASH_unique_items$$=new $APP.$cljs$core$Keyword$$("app.common.schema.openapi","unique-items","app.common.schema.openapi/unique-items",-2108286573);
$cljs$cst$3020$syriac$$=new $APP.$cljs$core$Keyword$$(null,"syriac","syriac",-841890245);$cljs$cst$4681$atom$$=new $APP.$cljs$core$Keyword$$(null,"atom","atom",-397043653);$APP.$cljs$cst$3504$app_DOT_main_DOT_data_DOT_fonts_SLASH_delete_font$$=new $APP.$cljs$core$Keyword$$("app.main.data.fonts","delete-font","app.main.data.fonts/delete-font",-296165289);$APP.$cljs$cst$2092$keep_ids_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"keep-ids?","keep-ids?",-236947248);
$cljs$cst$3396$app_DOT_main_DOT_data_DOT_plugins_SLASH_save_plugin_permissions_peek$$=new $APP.$cljs$core$Keyword$$("app.main.data.plugins","save-plugin-permissions-peek","app.main.data.plugins/save-plugin-permissions-peek",1462044449);$APP.$cljs$cst$575$props$$=new $APP.$cljs$core$Keyword$$(null,"props","props",453281727);$cljs$cst$4207$undo_stack$$=new $APP.$cljs$core$Keyword$$(null,"undo-stack","undo-stack",244619892);$cljs$cst$147$phase$$=new $APP.$cljs$core$Keyword$$(null,"phase","phase",575722892);
$APP.$cljs$cst$2393$terminators$$=new $APP.$cljs$core$Keyword$$(null,"terminators","terminators",-1448255712);$cljs$cst$1486$when_first$$=new $APP.$cljs$core$Symbol$$(null,"when-first","when-first",821699168,null);$cljs$cst$3923$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_rename_component$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","rename-component","app.main.data.workspace.libraries/rename-component",-451245762);
$APP.$cljs$cst$2561$restriction$$=new $APP.$cljs$core$Keyword$$(null,"restriction","restriction",-1380234912);$cljs$cst$765$lambdaisland_SLASH_uri$$=new $APP.$cljs$core$Symbol$$("lambdaisland","uri","lambdaisland/uri",-75335492,null);$cljs$cst$4803$toggle_assets$$=new $APP.$cljs$core$Keyword$$(null,"toggle-assets","toggle-assets",-2023224028);$APP.$cljs$cst$4911$search_result$$=new $APP.$cljs$core$Keyword$$(null,"search-result","search-result",528142443);
$APP.$cljs$cst$2118$new_at_path$$=new $APP.$cljs$core$Keyword$$(null,"new-at-path","new-at-path",-777014351);$APP.$cljs$cst$4822$redo$$=new $APP.$cljs$core$Keyword$$(null,"redo","redo",501190664);$cljs$cst$3601$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_all$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","select-all","app.main.data.workspace.selection/select-all",-803833257);
$APP.$cljs$cst$4316$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_start_move_overlay_pos$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","start-move-overlay-pos","app.main.data.workspace.interactions/start-move-overlay-pos",-1138313803);$cljs$cst$3826$wasm_props$$=new $APP.$cljs$core$Keyword$$(null,"wasm-props","wasm-props",-484881436);$APP.$cljs$cst$4133$picked_shift_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"picked-shift?","picked-shift?",199891600);
$cljs$cst$1264$enable_token_shadow$$=new $APP.$cljs$core$Keyword$$(null,"enable-token-shadow","enable-token-shadow",1478209528);$cljs$cst$1073$cljs_DOT_spec_DOT_alpha_SLASH_kind_form$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","kind-form","cljs.spec.alpha/kind-form",-1047104697);$APP.$cljs$cst$2599$attr$$=new $APP.$cljs$core$Keyword$$(null,"attr","attr",-604132353);$APP.$cljs$cst$1611$rect$$=new $APP.$cljs$core$Keyword$$(null,"rect","rect",-108902628);
$cljs$cst$4283$comment_id$$=new $APP.$cljs$core$Keyword$$(null,"comment-id","comment-id",-1387285800);$APP.$cljs$cst$4009$editor_styles$$=new $APP.$cljs$core$Keyword$$(null,"editor-styles","editor-styles",721216512);$cljs$cst$2961$subscr$$=new $APP.$cljs$core$Keyword$$(null,"subscr","subscr",100986586);
$cljs$cst$4211$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_end_path_undo$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.undo","end-path-undo","app.main.data.workspace.path.undo/end-path-undo",1735332515);$cljs$cst$4200$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_clear_edition_mode$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.common","clear-edition-mode","app.main.data.workspace.common/clear-edition-mode",1327339287);
$cljs$cst$861$vector_min$$=new $APP.$cljs$core$Keyword$$(null,"vector-min","vector-min",-2065952790);$cljs$cst$4536$app_DOT_main_DOT_data_DOT_workspace_SLASH_open_layers_search$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","open-layers-search","app.main.data.workspace/open-layers-search",275336809);$cljs$cst$4103$replace_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"replace?","replace?",-877816403);
$cljs$cst$4888$navigation_workspace$$=new $APP.$cljs$core$Keyword$$(null,"navigation-workspace","navigation-workspace",-600908724);$APP.$cljs$cst$381$enter$$=new $APP.$cljs$core$Keyword$$(null,"enter","enter",1792452624);$APP.$cljs$cst$498$tuple$$=new $APP.$cljs$core$Keyword$$(null,"tuple","tuple",-472667284);$cljs$cst$1468$bracket_info$$=new $APP.$cljs$core$Keyword$$(null,"bracket-info","bracket-info",-1600092774);
$cljs$cst$4193$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_insert_point$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.drawing.curve","insert-point","app.main.data.workspace.drawing.curve/insert-point",-997179771);$cljs$cst$4138$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_fill$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","change-fill","app.main.data.workspace.colors/change-fill",1690758679);
$APP.$cljs$cst$3418$hright$$=new $APP.$cljs$core$Keyword$$(null,"hright","hright",-2037540371);$cljs$cst$4592$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_type$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","invalid-token-value-shadow-type","error.style-dictionary/invalid-token-value-shadow-type",-1470937584);$APP.$cljs$cst$2313$profile_id$$=new $APP.$cljs$core$Keyword$$(null,"profile-id","profile-id",1866572309);
$APP.$cljs$cst$1680$layout_gap$$=new $APP.$cljs$core$Keyword$$(null,"layout-gap","layout-gap",140632911);$APP.$cljs$cst$3718$assets$$=new $APP.$cljs$core$Keyword$$(null,"assets","assets",210278279);$cljs$cst$3735$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_toggle_layout_flag$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.layout","toggle-layout-flag","app.main.data.workspace.layout/toggle-layout-flag",143616395);
$cljs$cst$3637$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_event$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","update-shapes-buffer-event","app.main.data.workspace.shapes/update-shapes-buffer-event",-391275919);$cljs$cst$1078$distinct$$=new $APP.$cljs$core$Keyword$$(null,"distinct","distinct",-1788879121);$APP.$cljs$cst$1910$vertical$$=new $APP.$cljs$core$Keyword$$(null,"vertical","vertical",718696748);
$APP.$cljs$cst$4071$border$$=new $APP.$cljs$core$Keyword$$(null,"border","border",1444987323);$APP.$cljs$cst$2516$search_term$$=new $APP.$cljs$core$Keyword$$(null,"search-term","search-term",356193544);$cljs$cst$3144$selected_before$$=new $APP.$cljs$core$Keyword$$(null,"selected-before","selected-before",-1174526201);$cljs$cst$691$map_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"map?","map?",-1780568534,null);
$APP.$cljs$cst$4003$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_focus_editor$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","focus-editor","app.main.data.workspace.texts/focus-editor",2138710187);$APP.$cljs$cst$1959$animation_type$$=new $APP.$cljs$core$Keyword$$(null,"animation-type","animation-type",-1444568230);
$APP.$cljs$cst$4106$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_svg$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","copy-selected-svg","app.main.data.workspace.clipboard/copy-selected-svg",1829114841);$cljs$cst$2690$clipPath$$=new $APP.$cljs$core$Keyword$$(null,"clipPath","clipPath",-934619797);$cljs$cst$1555$validate_fn$$=new $APP.$cljs$core$Keyword$$(null,"validate-fn","validate-fn",1430169944);
$APP.$cljs$cst$3554$prev_handler$$=new $APP.$cljs$core$Keyword$$(null,"prev-handler","prev-handler",1106999648);$APP.$cljs$cst$4725$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_assign_token_set_context_menu$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","assign-token-set-context-menu","app.main.data.workspace.tokens.library-edit/assign-token-set-context-menu",473661719);
$cljs$cst$1492$struct$$=new $APP.$cljs$core$Symbol$$(null,"struct","struct",325972931,null);$APP.$cljs$cst$2363$path_conflicts$$=new $APP.$cljs$core$Keyword$$(null,"path-conflicts","path-conflicts",-1238675313);$APP.$cljs$cst$1546$msg$$=new $APP.$cljs$core$Keyword$$(null,"msg","msg",-1386103444);$APP.$cljs$cst$3427$participants$$=new $APP.$cljs$core$Keyword$$(null,"participants","participants",673603367);$APP.$cljs$cst$1950$ease_in$$=new $APP.$cljs$core$Keyword$$(null,"ease-in","ease-in",-819423123);
$APP.$cljs$cst$4389$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_stop_grid_layout_editing$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid-layout.editor","stop-grid-layout-editing","app.main.data.workspace.grid-layout.editor/stop-grid-layout-editing",-641808288);$APP.$cljs$cst$4876$thumbnail_set$$=new $APP.$cljs$core$Keyword$$(null,"thumbnail-set","thumbnail-set",-614504484);$APP.$cljs$cst$5094$invalid$$=new $APP.$cljs$core$Keyword$$(null,"invalid","invalid",412869516);
$APP.$cljs$cst$2450$lookup$$=new $APP.$cljs$core$Keyword$$(null,"lookup","lookup",1225356838);$APP.$cljs$cst$4686$unfolded_token_types$$=new $APP.$cljs$core$Keyword$$(null,"unfolded-token-types","unfolded-token-types",1677747758);$cljs$cst$3908$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_rename_color$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","rename-color","app.main.data.workspace.libraries/rename-color",-1436624502);
$APP.$cljs$cst$4669$tokens_SLASH_stroke_width$$=new $APP.$cljs$core$Keyword$$("tokens","stroke-width","tokens/stroke-width",1459195033);$cljs$cst$5257$app_DOT_main_DOT_data_DOT_viewer_SLASH_zoom_to_fill$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","zoom-to-fill","app.main.data.viewer/zoom-to-fill",-1543797260);$APP.$cljs$cst$2312$context$$=new $APP.$cljs$core$Keyword$$(null,"context","context",-830191113);
$APP.$cljs$cst$4450$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_update_viewport_size$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.viewport","update-viewport-size","app.main.data.workspace.viewport/update-viewport-size",1719826927);$APP.$cljs$cst$2230$project$$=new $APP.$cljs$core$Keyword$$(null,"project","project",1124394579);
$APP.$cljs$cst$4128$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_show_palette$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","show-palette","app.main.data.workspace.colors/show-palette",-357908053);$cljs$cst$2781$refY$$=new $APP.$cljs$core$Keyword$$(null,"refY","refY",113675749);$cljs$cst$4463$app_DOT_main_DOT_data_DOT_workspace_SLASH_zoom_to_frame$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","zoom-to-frame","app.main.data.workspace/zoom-to-frame",349712294);
$cljs$cst$2886$refX$$=new $APP.$cljs$core$Keyword$$(null,"refX","refX",1265839261);$cljs$cst$1771$text_cb$$=new $APP.$cljs$core$Keyword$$(null,"text-cb","text-cb",33486268);$cljs$cst$3243$request_profile_recovery$$=new $APP.$cljs$core$Keyword$$(null,"request-profile-recovery","request-profile-recovery",-1226574152);
$cljs$cst$4045$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_v2_update_text_shape_content$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","v2-update-text-shape-content","app.main.data.workspace.texts/v2-update-text-shape-content",702141646);$APP.$cljs$cst$4975$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_files$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","delete-files","app.main.data.dashboard/delete-files",-1227239895);
$APP.$cljs$cst$3520$property_value$$=new $APP.$cljs$core$Keyword$$(null,"property-value","property-value",1516163307);$APP.$cljs$cst$4820$bring_front$$=new $APP.$cljs$core$Keyword$$(null,"bring-front","bring-front",244467975);$APP.$cljs$cst$2379$parameters$$=new $APP.$cljs$core$Keyword$$(null,"parameters","parameters",-1229919748);$cljs$cst$5336$hover_shape$$=new $APP.$cljs$core$Keyword$$(null,"hover-shape","hover-shape",1763258041);
$cljs$cst$4516$app_DOT_main_DOT_data_DOT_workspace_SLASH_change_canvas_color$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","change-canvas-color","app.main.data.workspace/change-canvas-color",1969630674);$cljs$cst$772$ex_fn$$=new $APP.$cljs$core$Keyword$$(null,"ex-fn","ex-fn",-284925510);$cljs$cst$2802$clipPathUnits$$=new $APP.$cljs$core$Keyword$$(null,"clipPathUnits","clipPathUnits",-1747479222);
$cljs$cst$4349$subscribe_file$$=new $APP.$cljs$core$Keyword$$(null,"subscribe-file","subscribe-file",-646014766);$APP.$cljs$cst$2607$object_type$$=new $APP.$cljs$core$Keyword$$(null,"object-type","object-type",-1889869015);$APP.$cljs$cst$3503$update_font$$=new $APP.$cljs$core$Keyword$$(null,"update-font","update-font",-1331477528);$cljs$cst$1137$integrant_DOT_core_SLASH_build_failed_spec$$=new $APP.$cljs$core$Keyword$$("integrant.core","build-failed-spec","integrant.core/build-failed-spec",1167262590);
$APP.$cljs$cst$1850$close_path$$=new $APP.$cljs$core$Keyword$$(null,"close-path","close-path",1220079654);$cljs$cst$3471$show$$=new $APP.$cljs$core$Keyword$$(null,"show","show",-576705889);$APP.$cljs$cst$56$base$$=new $APP.$cljs$core$Symbol$$(null,"base","base",1825810849,null);$APP.$cljs$cst$938$decode_SLASH_json$$=new $APP.$cljs$core$Keyword$$("decode","json","decode/json",468276044);
$cljs$cst$4402$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_layout$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","update-layout","app.main.data.workspace.shape-layout/update-layout",-842733116);
$cljs$cst$4643$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_spacing_token$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","apply-spacing-token","app.main.data.workspace.tokens.application/apply-spacing-token",-105474155);$cljs$cst$3028$meroitic$$=new $APP.$cljs$core$Keyword$$(null,"meroitic","meroitic",1079957951);
$APP.$cljs$cst$3179$apply_changes_local_library_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"apply-changes-local-library?","apply-changes-local-library?",1077602630);$APP.$cljs$cst$1737$modified_at$$=new $APP.$cljs$core$Keyword$$(null,"modified-at","modified-at",-932048179);$APP.$cljs$cst$5027$localized_date$$=new $APP.$cljs$core$Keyword$$(null,"localized-date","localized-date",-1568818775);$cljs$cst$2151$mod$$=new $APP.$cljs$core$Keyword$$(null,"mod","mod",-130487320);
$cljs$cst$5169$frame_not_found$$=new $APP.$cljs$core$Keyword$$(null,"frame-not-found","frame-not-found",1905603142);$cljs$cst$4329$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_handle_pong$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.mcp","handle-pong","app.main.data.workspace.mcp/handle-pong",-82670746);$cljs$cst$286$reserve_chars$$=new $APP.$cljs$core$Keyword$$(null,"reserve-chars","reserve-chars",1038553515);
$cljs$cst$1491$loop$$=new $APP.$cljs$core$Symbol$$(null,"loop","loop",1244978678,null);$APP.$cljs$cst$1914$profile$$=new $APP.$cljs$core$Keyword$$(null,"profile","profile",-545963874);$cljs$cst$3188$app_DOT_main_DOT_data_DOT_media_SLASH_blobs$$=new $APP.$cljs$core$Keyword$$("app.main.data.media","blobs","app.main.data.media/blobs",426101340);$cljs$cst$5160$_type$$=new $APP.$cljs$core$Keyword$$(null,"_type","_type",-970742198);
$cljs$cst$2635$skip_undelete_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"skip-undelete?","skip-undelete?",2065473489);$cljs$cst$1622$remove_blocked$$=new $APP.$cljs$core$Keyword$$(null,"remove-blocked","remove-blocked",-2130484791);$cljs$cst$451$malli_DOT_core_SLASH_missing_key$$=new $APP.$cljs$core$Keyword$$("malli.core","missing-key","malli.core/missing-key",1439107666);$APP.$cljs$cst$2215$typographies$$=new $APP.$cljs$core$Keyword$$(null,"typographies","typographies",-482095730);
$APP.$cljs$cst$2353$timeout$$=new $APP.$cljs$core$Keyword$$(null,"timeout","timeout",-318625318);$cljs$cst$1458$max_columns$$=new $APP.$cljs$core$Keyword$$(null,"max-columns","max-columns",1742323262);$APP.$cljs$cst$3547$expanded$$=new $APP.$cljs$core$Keyword$$(null,"expanded","expanded",-3020742);$APP.$cljs$cst$1884$top_right$$=new $APP.$cljs$core$Keyword$$(null,"top-right","top-right",284698505);
$APP.$cljs$cst$1643$component_file$$=new $APP.$cljs$core$Keyword$$(null,"component-file","component-file",-1378670433);$cljs$cst$3944$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_library_thumbnails_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","library-thumbnails-fetched","app.main.data.workspace.libraries/library-thumbnails-fetched",-1756832726);$cljs$cst$2856$keyTimes$$=new $APP.$cljs$core$Keyword$$(null,"keyTimes","keyTimes",1244883478);
$cljs$cst$5378$admin_only_profile$$=new $APP.$cljs$core$Keyword$$(null,"admin-only-profile","admin-only-profile",-1460712669);$APP.$cljs$cst$2475$omit$$=new $APP.$cljs$core$Keyword$$(null,"omit","omit",-1917972325);$APP.$cljs$cst$3992$unlink_file_from_library$$=new $APP.$cljs$core$Keyword$$(null,"unlink-file-from-library","unlink-file-from-library",576056185);$APP.$cljs$cst$3436$comments$$=new $APP.$cljs$core$Keyword$$(null,"comments","comments",-293346423);
$APP.$cljs$cst$1214$token_import_from_library$$=new $APP.$cljs$core$Keyword$$(null,"token-import-from-library","token-import-from-library",844569164);$APP.$cljs$cst$886$malli_DOT_error_SLASH_error$$=new $APP.$cljs$core$Keyword$$("malli.error","error","malli.error/error",-522553785);$cljs$cst$3687$normalize$$=new $APP.$cljs$core$Keyword$$(null,"normalize","normalize",-1904390051);$cljs$cst$365$order$$=new $APP.$cljs$core$Keyword$$(null,"order","order",-1254677256);
$cljs$cst$648$encode$$=new $APP.$cljs$core$Keyword$$(null,"encode","encode",-1753429702);$APP.$cljs$cst$5072$validators$$=new $APP.$cljs$core$Keyword$$(null,"validators","validators",-1973346672);$cljs$cst$952$app_DOT_common_DOT_schema_SLASH_set_of_strings$$=new $APP.$cljs$core$Keyword$$("app.common.schema","set-of-strings","app.common.schema/set-of-strings",1794281466);
$cljs$cst$3942$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_go_to_local_component$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","go-to-local-component","app.main.data.workspace.libraries/go-to-local-component",1322939461);$cljs$cst$777$max_elements$$=new $APP.$cljs$core$Keyword$$(null,"max-elements","max-elements",433034073);$APP.$cljs$cst$3697$no_cors$$=new $APP.$cljs$core$Keyword$$(null,"no-cors","no-cors",-603212056);
$cljs$cst$3566$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_start_undo_transaction$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.undo","start-undo-transaction","app.main.data.workspace.undo/start-undo-transaction",2132602364);$cljs$cst$1465$colnum$$=new $APP.$cljs$core$Keyword$$(null,"colnum","colnum",2023796854);$cljs$cst$4059$grid_template_rows$$=new $APP.$cljs$core$Keyword$$(null,"grid-template-rows","grid-template-rows",-372292629);
$cljs$cst$734$malli_DOT_util_SLASH_reducing_children_must_be_non_empty$$=new $APP.$cljs$core$Keyword$$("malli.util","reducing-children-must-be-non-empty","malli.util/reducing-children-must-be-non-empty",-2057410793);$cljs$cst$3961$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_set_updating_library$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","set-updating-library","app.main.data.workspace.libraries/set-updating-library",-1008288470);
$cljs$cst$2745$altGlyphItem$$=new $APP.$cljs$core$Keyword$$(null,"altGlyphItem","altGlyphItem",1507499165);$cljs$cst$368$entry$$=new $APP.$cljs$core$Keyword$$(null,"entry","entry",505168823);$APP.$cljs$cst$1231$terms_and_privacy_checkbox$$=new $APP.$cljs$core$Keyword$$(null,"terms-and-privacy-checkbox","terms-and-privacy-checkbox",-1938913707);$APP.$cljs$cst$338$min$$=new $APP.$cljs$core$Keyword$$(null,"min","min",444991522);
$APP.$cljs$cst$1764$text_direction$$=new $APP.$cljs$core$Keyword$$(null,"text-direction","text-direction",590275785);$cljs$cst$1825$geom$$=new $APP.$cljs$core$Keyword$$(null,"geom","geom",1207084371);$APP.$cljs$cst$2120$is_group$$=new $APP.$cljs$core$Keyword$$(null,"is-group","is-group",1574418960);$cljs$cst$2953$timer$$=new $APP.$cljs$core$Keyword$$(null,"timer","timer",-1266967739);$APP.$cljs$cst$2178$persistence$$=new $APP.$cljs$core$Keyword$$(null,"persistence","persistence",-203044807);
$cljs$cst$1088$rep_PLUS_$$=new $APP.$cljs$core$Keyword$$(null,"rep+","rep+",-281382396);$APP.$cljs$cst$3948$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_reset_component$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","reset-component","app.main.data.workspace.libraries/reset-component",603206836);$cljs$cst$3342$app_DOT_main_DOT_data_DOT_auth_SLASH_logged_in$$=new $APP.$cljs$core$Keyword$$("app.main.data.auth","logged-in","app.main.data.auth/logged-in",944094603);
$cljs$cst$700$zero_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"zero?","zero?",325758897,null);$cljs$cst$4426$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_update_property_value$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","update-property-value","app.main.data.workspace.variants/update-property-value",807023037);$cljs$cst$5381$get_sso_provider$$=new $APP.$cljs$core$Keyword$$(null,"get-sso-provider","get-sso-provider",336930270);
$APP.$cljs$cst$2651$set_group_path$$=new $APP.$cljs$core$Keyword$$(null,"set-group-path","set-group-path",1404470053);$cljs$cst$5304$open_workspace$$=new $APP.$cljs$core$Keyword$$(null,"open-workspace","open-workspace",674618620);$cljs$cst$2580$app_DOT_common_DOT_types_DOT_file_SLASH_data$$=new $APP.$cljs$core$Keyword$$("app.common.types.file","data","app.common.types.file/data",564605466);
$APP.$cljs$cst$4299$app_DOT_main_DOT_data_DOT_workspace_DOT_highlight_SLASH_clear_search_match_highlight$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.highlight","clear-search-match-highlight","app.main.data.workspace.highlight/clear-search-match-highlight",-948582512);$cljs$cst$2977$style_name$$=new $APP.$cljs$core$Keyword$$(null,"style-name","style-name",977914017);
$cljs$cst$4325$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_set_mcp_active$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.mcp","set-mcp-active","app.main.data.workspace.mcp/set-mcp-active",-666714555);$cljs$cst$1848$app_DOT_common_DOT_schema_DOT_openapi_SLASH_embed$$=new $APP.$cljs$core$Keyword$$("app.common.schema.openapi","embed","app.common.schema.openapi/embed",2010301748);
$cljs$cst$4195$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_finish_drawing$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.drawing.curve","finish-drawing","app.main.data.workspace.drawing.curve/finish-drawing",-1275239528);$APP.$cljs$cst$4924$app_DOT_main_DOT_data_DOT_dashboard_SLASH_fetch_deleted_files$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","fetch-deleted-files","app.main.data.dashboard/fetch-deleted-files",-1974788947);
$cljs$cst$5328$viewer_libraries$$=new $APP.$cljs$core$Keyword$$(null,"viewer-libraries","viewer-libraries",-1612687816);$cljs$cst$3464$current_team_comments_users$$=new $APP.$cljs$core$Keyword$$(null,"current-team-comments-users","current-team-comments-users",430050833);$cljs$cst$2523$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_members$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","go-to-dashboard-members","app.main.data.common/go-to-dashboard-members",-434330469);
$cljs$cst$3871$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_set_ghost_displacement$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","set-ghost-displacement","app.main.data.workspace.transforms/set-ghost-displacement",-253602999);$APP.$cljs$cst$4000$old$$=new $APP.$cljs$core$Keyword$$(null,"old","old",-1825222690);$APP.$cljs$cst$2532$workspace$$=new $APP.$cljs$core$Keyword$$(null,"workspace","workspace",-1096735709);
$APP.$cljs$cst$971$prefix$$=new $APP.$cljs$core$Keyword$$(null,"prefix","prefix",-265908465);$cljs$cst$5170$invalid_frame$$=new $APP.$cljs$core$Keyword$$(null,"invalid-frame","invalid-frame",-1077960585);$cljs$cst$3702$invalid_image$$=new $APP.$cljs$core$Keyword$$(null,"invalid-image","invalid-image",127294201);$APP.$cljs$cst$4575$error_DOT_import_SLASH_json_parse_error$$=new $APP.$cljs$core$Keyword$$("error.import","json-parse-error","error.import/json-parse-error",503270464);
$cljs$cst$4940$app_DOT_main_DOT_data_DOT_dashboard_SLASH_duplicate_project$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","duplicate-project","app.main.data.dashboard/duplicate-project",1509170664);$cljs$cst$2072$layer_effects_group$$=new $APP.$cljs$core$Keyword$$(null,"layer-effects-group","layer-effects-group",-93250121);$APP.$cljs$cst$4044$finalize_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"finalize?","finalize?",687625539);
$APP.$cljs$cst$5020$preview_id$$=new $APP.$cljs$core$Keyword$$(null,"preview-id","preview-id",1300598454);$cljs$cst$3654$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_toggle_file_thumbnail_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","toggle-file-thumbnail-selected","app.main.data.workspace.shapes/toggle-file-thumbnail-selected",308632699);
$cljs$cst$4343$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_init$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.mcp","init","app.main.data.workspace.mcp/init",-451452513);$cljs$cst$1426$rest$$=new $APP.$cljs$core$Keyword$$(null,"rest","rest",-1241696419);$APP.$cljs$cst$4862$artboard_selection$$=new $APP.$cljs$core$Keyword$$(null,"artboard-selection","artboard-selection",528432632);$cljs$cst$3352$resp$$=new $APP.$cljs$core$Keyword$$(null,"resp","resp",1418702376);
$APP.$cljs$cst$4909$get_projects$$=new $APP.$cljs$core$Keyword$$(null,"get-projects","get-projects",933934649);$cljs$cst$2888$attributeName$$=new $APP.$cljs$core$Keyword$$(null,"attributeName","attributeName",-400177890);$cljs$cst$4308$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_update_interaction$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","update-interaction","app.main.data.workspace.interactions/update-interaction",-1731234551);
$APP.$cljs$cst$2545$asset_type$$=new $APP.$cljs$core$Keyword$$(null,"asset-type","asset-type",-1419820094);$APP.$cljs$cst$2730$ellipse$$=new $APP.$cljs$core$Keyword$$(null,"ellipse","ellipse",1135891702);$cljs$cst$3444$update_comment_thread_status$$=new $APP.$cljs$core$Keyword$$(null,"update-comment-thread-status","update-comment-thread-status",1793106048);
$cljs$cst$3099$viewport_interest_area_threshold$$=new $APP.$cljs$core$Keyword$$(null,"viewport_interest_area_threshold","viewport_interest_area_threshold",793517798);$cljs$cst$3845$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_delta_rotation_modifiers$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.modifiers","set-delta-rotation-modifiers","app.main.data.workspace.modifiers/set-delta-rotation-modifiers",-1633341513);
$APP.$cljs$cst$3720$snap_guides$$=new $APP.$cljs$core$Keyword$$(null,"snap-guides","snap-guides",-1395069816);$cljs$cst$4218$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_finish_drag$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","finish-drag","app.main.data.workspace.path.drawing/finish-drag",291514611);$cljs$cst$3492$app_DOT_main_DOT_fonts_SLASH_otf_file_id$$=new $APP.$cljs$core$Keyword$$("app.main.fonts","otf-file-id","app.main.fonts/otf-file-id",313412300);
$cljs$cst$4988$user_can_edit$$=new $APP.$cljs$core$Keyword$$(null,"user-can-edit","user-can-edit",-477003905);$cljs$cst$5103$field_name$$=new $APP.$cljs$core$Keyword$$(null,"field-name","field-name",1300687948);$cljs$cst$5006$h_dir$$=new $APP.$cljs$core$Keyword$$(null,"h-dir","h-dir",1678725750);$APP.$cljs$cst$1939$click$$=new $APP.$cljs$core$Keyword$$(null,"click","click",1912301393);$APP.$cljs$cst$2030$soft_light$$=new $APP.$cljs$core$Keyword$$(null,"soft-light","soft-light",513207899);
$APP.$cljs$cst$5360$nitrate_activation_success$$=new $APP.$cljs$core$Keyword$$(null,"nitrate-activation-success","nitrate-activation-success",-1824278693);$cljs$cst$4558$on_pointer_leave_option$$=new $APP.$cljs$core$Keyword$$(null,"on-pointer-leave-option","on-pointer-leave-option",1851242568);$APP.$cljs$cst$1985$vertical_padding$$=new $APP.$cljs$core$Keyword$$(null,"vertical-padding","vertical-padding",50408610);
$cljs$cst$4858$move_fast_left$$=new $APP.$cljs$core$Keyword$$(null,"move-fast-left","move-fast-left",1147435382);$cljs$cst$4256$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_finish_move_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.edition","finish-move-selected","app.main.data.workspace.path.edition/finish-move-selected",-645782363);$cljs$cst$2798$preserveAspectRatio$$=new $APP.$cljs$core$Keyword$$(null,"preserveAspectRatio","preserveAspectRatio",1832131817);
$APP.$cljs$cst$4456$app_DOT_main_DOT_data_DOT_workspace_SLASH_initialize_layout$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","initialize-layout","app.main.data.workspace/initialize-layout",-346313965);$cljs$cst$628$child_bounds$$=new $APP.$cljs$core$Keyword$$(null,"child-bounds","child-bounds",1368514738);
$cljs$cst$824$clojure_DOT_test_DOT_check_DOT_generators_SLASH_symbol_ns$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","symbol-ns","clojure.test.check.generators/symbol-ns",-862629490,null);$APP.$cljs$cst$2206$token_context_menu$$=new $APP.$cljs$core$Keyword$$(null,"token-context-menu","token-context-menu",1588110807);$APP.$cljs$cst$5411$hide_logo$$=new $APP.$cljs$core$Keyword$$(null,"hide-logo","hide-logo",-332089125);
$APP.$cljs$cst$2002$variant_name$$=new $APP.$cljs$core$Keyword$$(null,"variant-name","variant-name",-1785573622);$cljs$cst$5226$navigation_dashboard$$=new $APP.$cljs$core$Keyword$$(null,"navigation-dashboard","navigation-dashboard",-1099692958);$cljs$cst$4013$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_root_attrs$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","update-root-attrs","app.main.data.workspace.texts/update-root-attrs",470119238);
$cljs$cst$3135$ignore_wasm_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"ignore-wasm?","ignore-wasm?",-324568531);$APP.$cljs$cst$1640$fill_color_ref_file$$=new $APP.$cljs$core$Keyword$$(null,"fill-color-ref-file","fill-color-ref-file",-952903255);$cljs$cst$3810$line_max_height$$=new $APP.$cljs$core$Keyword$$(null,"line-max-height","line-max-height",-737603808);$cljs$cst$5376$profile_blocked$$=new $APP.$cljs$core$Keyword$$(null,"profile-blocked","profile-blocked",188698258);
$cljs$cst$3645$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_delete_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","delete-shapes","app.main.data.workspace.shapes/delete-shapes",1337837165);$APP.$cljs$cst$2536$dashboard_deleted$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-deleted","dashboard-deleted",-551384632);$cljs$cst$2680$app_DOT_main_DOT_fonts_SLASH_on_loaded$$=new $APP.$cljs$core$Keyword$$("app.main.fonts","on-loaded","app.main.fonts/on-loaded",820185832);
$APP.$cljs$cst$2528$dashboard_webhooks$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-webhooks","dashboard-webhooks",-1830316512);$cljs$cst$161$js_STAR_$$=new $APP.$cljs$core$Symbol$$(null,"js*","js*",-1134233646,null);$APP.$cljs$cst$716$repeat$$=new $APP.$cljs$core$Keyword$$(null,"repeat","repeat",832692087);$APP.$cljs$cst$4680$parent_to_child$$=new $APP.$cljs$core$Keyword$$(null,"parent-to-child","parent-to-child",-698517616);
$cljs$cst$1774$text_content_text$$=new $APP.$cljs$core$Keyword$$(null,"text-content-text","text-content-text",1379059411);$cljs$cst$4050$padding_inline_end$$=new $APP.$cljs$core$Keyword$$(null,"padding-inline-end","padding-inline-end",-647416958);$APP.$cljs$cst$1874$hide_fill_on_export$$=new $APP.$cljs$core$Keyword$$(null,"hide-fill-on-export","hide-fill-on-export",-1674607391);
$cljs$cst$3955$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_launch_component_sync$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","launch-component-sync","app.main.data.workspace.libraries/launch-component-sync",-468570781);$APP.$cljs$cst$2270$revn$$=new $APP.$cljs$core$Keyword$$(null,"revn","revn",-633391765);$APP.$cljs$cst$489$empty$$=new $APP.$cljs$core$Keyword$$(null,"empty","empty",767870958);
$cljs$cst$1393$nl_t$$=new $APP.$cljs$core$Keyword$$(null,"nl-t","nl-t",-1608382114);$APP.$cljs$cst$4934$app_DOT_main_DOT_data_DOT_dashboard_SLASH_stop_edit_file_name$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","stop-edit-file-name","app.main.data.dashboard/stop-edit-file-name",1215006280);$cljs$cst$347$varargs$$=new $APP.$cljs$core$Keyword$$(null,"varargs","varargs",1030150858);$APP.$cljs$cst$3055$layout_lines$$=new $APP.$cljs$core$Keyword$$(null,"layout-lines","layout-lines",-1868555037);
$APP.$cljs$cst$228$read_cond$$=new $APP.$cljs$core$Keyword$$(null,"read-cond","read-cond",1056899244);$cljs$cst$2851$v_mathematical$$=new $APP.$cljs$core$Keyword$$(null,"v-mathematical","v-mathematical",-639453547);$cljs$cst$3602$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_deselect_all$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","deselect-all","app.main.data.workspace.selection/deselect-all",-1662679693);
$APP.$cljs$cst$5345$async_errors$$=new $APP.$cljs$core$Keyword$$(null,"async-errors","async-errors",-1865115559);$cljs$cst$4366$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_initialize_page_STAR_$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.pages","initialize-page*","app.main.data.workspace.pages/initialize-page*",-142066834);$APP.$cljs$cst$5357$show_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"show?","show?",1543842127);
$APP.$cljs$cst$3385$after$$=new $APP.$cljs$core$Keyword$$(null,"after","after",594996914);$cljs$cst$1269$enable_render_switch$$=new $APP.$cljs$core$Keyword$$(null,"enable-render-switch","enable-render-switch",-1587988229);$cljs$cst$3349$app_DOT_main_DOT_data_DOT_auth_SLASH_login_with_sso$$=new $APP.$cljs$core$Keyword$$("app.main.data.auth","login-with-sso","app.main.data.auth/login-with-sso",-1613996868);
$cljs$cst$2531$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_workspace$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","go-to-workspace","app.main.data.common/go-to-workspace",1683786268);$APP.$cljs$cst$4994$on_close$$=new $APP.$cljs$core$Keyword$$(null,"on-close","on-close",-761178394);$APP.$cljs$cst$2611$obj$$=new $APP.$cljs$core$Keyword$$(null,"obj","obj",981763962);
$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$=new $APP.$cljs$core$Keyword$$("app.common.schema","int","app.common.schema/int",519552051);$APP.$cljs$cst$175$form$$=new $APP.$cljs$core$Symbol$$(null,"form","form",16469056,null);$cljs$cst$4330$connected_tab$$=new $APP.$cljs$core$Keyword$$(null,"connected-tab","connected-tab",988499736);$APP.$cljs$cst$2940$styles$$=new $APP.$cljs$core$Keyword$$(null,"styles","styles",1954480375);
$APP.$cljs$cst$4526$workspace_annotations$$=new $APP.$cljs$core$Keyword$$(null,"workspace-annotations","workspace-annotations",-1857761670);$cljs$cst$680$keyword_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"keyword?","keyword?",1917797069,null);$cljs$cst$4122$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_link_to_clipboard$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","copy-link-to-clipboard","app.main.data.workspace.clipboard/copy-link-to-clipboard",-2034235592);
$APP.$cljs$cst$4446$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_sync_wasm_workspace_viewport$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.viewport","sync-wasm-workspace-viewport","app.main.data.workspace.viewport/sync-wasm-workspace-viewport",398177847);$APP.$cljs$cst$4923$deleted_files$$=new $APP.$cljs$core$Keyword$$(null,"deleted-files","deleted-files",-555859130);
$APP.$cljs$cst$5394$register_profile$$=new $APP.$cljs$core$Keyword$$(null,"register-profile","register-profile",-590987011);$APP.$cljs$cst$5063$app_DOT_main_DOT_data_DOT_nitrate_SLASH_add_team_to_org$$=new $APP.$cljs$core$Keyword$$("app.main.data.nitrate","add-team-to-org","app.main.data.nitrate/add-team-to-org",964594580);$APP.$cljs$cst$2696$textPath$$=new $APP.$cljs$core$Keyword$$(null,"textPath","textPath",269260449);
$cljs$cst$3316$app_DOT_main_DOT_data_DOT_team_SLASH_update_webhook$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","update-webhook","app.main.data.team/update-webhook",1627752910);$cljs$cst$3759$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_ungroup_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.groups","ungroup-shapes","app.main.data.workspace.groups/ungroup-shapes",-1575715894);
$cljs$cst$702$associative_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"associative?","associative?",-141666771,null);$cljs$cst$1368$done_nl$$=new $APP.$cljs$core$Keyword$$(null,"done-nl","done-nl",-381024340);$APP.$cljs$cst$4792$escape$$=new $APP.$cljs$core$Keyword$$(null,"escape","escape",-991601952);$APP.$cljs$cst$1132$cljs_DOT_spec_DOT_alpha_SLASH_failure$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","failure","cljs.spec.alpha/failure",188258592);
$APP.$cljs$cst$3553$last_point$$=new $APP.$cljs$core$Keyword$$(null,"last-point","last-point",-247743763);$cljs$cst$4777$app_DOT_main_DOT_data_DOT_preview_SLASH_update_preview$$=new $APP.$cljs$core$Keyword$$("app.main.data.preview","update-preview","app.main.data.preview/update-preview",-201546492);$cljs$cst$4257$current_move$$=new $APP.$cljs$core$Keyword$$(null,"current-move","current-move",-2114936122);
$cljs$cst$4477$app_DOT_main_DOT_data_DOT_workspace_SLASH_rename_shape_or_variant$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","rename-shape-or-variant","app.main.data.workspace/rename-shape-or-variant",-1027514045);$cljs$cst$2678$builtin$$=new $APP.$cljs$core$Keyword$$(null,"builtin","builtin",-1707593346);
$APP.$cljs$cst$4960$app_DOT_main_DOT_data_DOT_dashboard_SLASH_duplicate_file$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","duplicate-file","app.main.data.dashboard/duplicate-file",1371387416);$cljs$cst$4552$label_class$$=new $APP.$cljs$core$Keyword$$(null,"label-class","label-class",-2068991202);$APP.$cljs$cst$5266$viewer_animations$$=new $APP.$cljs$core$Keyword$$(null,"viewer-animations","viewer-animations",-575904375);
$APP.$cljs$cst$2020$darken$$=new $APP.$cljs$core$Keyword$$(null,"darken","darken",1770242949);$cljs$cst$1271$commit_hash$$=new $APP.$cljs$core$Keyword$$(null,"commit-hash","commit-hash",1158389730);$cljs$cst$1772$attribute_cb$$=new $APP.$cljs$core$Keyword$$(null,"attribute-cb","attribute-cb",417371796);$cljs$cst$2533$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_viewer$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","go-to-viewer","app.main.data.common/go-to-viewer",1637454289);
$APP.$cljs$cst$3829$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_update_modifiers$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.modifiers","update-modifiers","app.main.data.workspace.modifiers/update-modifiers",-705310363);$APP.$cljs$cst$3208$app_DOT_main_DOT_data_DOT_profile_SLASH_update_profile$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","update-profile","app.main.data.profile/update-profile",2016618526);
$APP.$cljs$cst$2345$hide$$=new $APP.$cljs$core$Keyword$$(null,"hide","hide",-596913169);$APP.$cljs$cst$3126$configure$$=new $APP.$cljs$core$Keyword$$(null,"configure","configure",1586823664);$APP.$cljs$cst$3990$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_detach_library$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","detach-library","app.main.data.workspace.libraries/detach-library",527267229);
$cljs$cst$5251$app_DOT_main_DOT_data_DOT_viewer_SLASH_increase_zoom$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","increase-zoom","app.main.data.viewer/increase-zoom",-1630925657);$APP.$cljs$cst$3851$ranges$$=new $APP.$cljs$core$Keyword$$(null,"ranges","ranges",1887686682);$cljs$cst$2991$bengali$$=new $APP.$cljs$core$Keyword$$(null,"bengali","bengali",841130917);$cljs$cst$3526$ignore_parents_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"ignore-parents?","ignore-parents?",1793745865);
$APP.$cljs$cst$4146$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_stroke_attrs$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","change-stroke-attrs","app.main.data.workspace.colors/change-stroke-attrs",-1829191602);$APP.$cljs$cst$3515$app_DOT_main_DOT_data_DOT_project_SLASH_fetch_files$$=new $APP.$cljs$core$Keyword$$("app.main.data.project","fetch-files","app.main.data.project/fetch-files",1623536159);
$cljs$cst$3121$many_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"many?","many?",-605360673);$cljs$cst$5105$leave_and_reassign_org$$=new $APP.$cljs$core$Keyword$$(null,"leave-and-reassign-org","leave-and-reassign-org",-2029626823);$cljs$cst$3340$login_redirect$$=new $APP.$cljs$core$Keyword$$(null,"login-redirect","login-redirect",-2132232884);$cljs$cst$2564$file_feature_mismatch$$=new $APP.$cljs$core$Keyword$$(null,"file-feature-mismatch","file-feature-mismatch",-792098307);
$cljs$cst$4115$hibt$$=new $APP.$cljs$core$Keyword$$(null,"hibt","hibt",-864980972);$APP.$cljs$cst$1786$origin$$=new $APP.$cljs$core$Keyword$$(null,"origin","origin",1037372088);$APP.$cljs$cst$2004$is_variant_container$$=new $APP.$cljs$core$Keyword$$(null,"is-variant-container","is-variant-container",-1294533822);$APP.$cljs$cst$4815$draw_rect$$=new $APP.$cljs$core$Keyword$$(null,"draw-rect","draw-rect",-1268379642);
$APP.$cljs$cst$148$_AMPERSAND_$$=new $APP.$cljs$core$Symbol$$(null,"\x26","\x26",-2144855648,null);$APP.$cljs$cst$5016$include_libraries$$=new $APP.$cljs$core$Keyword$$(null,"include-libraries","include-libraries",1396501919);$APP.$cljs$cst$979$_PERCENT_$$=new $APP.$cljs$core$Symbol$$(null,"%","%",-950237169,null);$cljs$cst$3345$app_DOT_main_DOT_data_DOT_auth_SLASH_login$$=new $APP.$cljs$core$Keyword$$("app.main.data.auth","login","app.main.data.auth/login",783166603);
$cljs$cst$352$registry$$=new $APP.$cljs$core$Keyword$$(null,"registry","registry",1021159018);$cljs$cst$5202$swap_slot$$=new $APP.$cljs$core$Keyword$$(null,"swap-slot","swap-slot",-1698060244);$cljs$cst$4809$open_dashboard$$=new $APP.$cljs$core$Keyword$$(null,"open-dashboard","open-dashboard",-1383226235);$cljs$cst$165$_DOT_$$=new $APP.$cljs$core$Symbol$$(null,".",".",1975675962,null);$APP.$cljs$cst$220$_SLASH_$$=new $APP.$cljs$core$Symbol$$(null,"/","/",-1371932971,null);
$cljs$cst$1044$cljs_DOT_core_SLASH_coll_QMARK_$$=new $APP.$cljs$core$Symbol$$("cljs.core","coll?","cljs.core/coll?",1208130522,null);$cljs$cst$5092$default_checked$$=new $APP.$cljs$core$Keyword$$(null,"default-checked","default-checked",1039965863);$APP.$cljs$cst$1712$layout_item_z_index$$=new $APP.$cljs$core$Keyword$$(null,"layout-item-z-index","layout-item-z-index",728479455);
$cljs$cst$5270$app_DOT_main_DOT_data_DOT_viewer_SLASH_flash_interactions$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","flash-interactions","app.main.data.viewer/flash-interactions",1108194904);$APP.$cljs$cst$2478$primary$$=new $APP.$cljs$core$Keyword$$(null,"primary","primary",817773892);$cljs$cst$1119$cljs_DOT_spec_DOT_alpha_SLASH_kvs__GT_map$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","kvs-\x3emap","cljs.spec.alpha/kvs-\x3emap",579713455);
$APP.$cljs$cst$3731$prototype$$=new $APP.$cljs$core$Keyword$$(null,"prototype","prototype",-1121365005);$cljs$cst$5355$import_files$$=new $APP.$cljs$core$Keyword$$(null,"import-files","import-files",1048427091);$APP.$cljs$cst$602$_$$=new $APP.$cljs$core$Symbol$$(null,"_","_",-1201019570,null);$APP.$cljs$cst$1600$b$$=new $APP.$cljs$core$Symbol$$(null,"b","b",-1172211299,null);$APP.$cljs$cst$1599$a$$=new $APP.$cljs$core$Symbol$$(null,"a","a",-482876059,null);
$cljs$cst$852$malli_DOT_generator_SLASH_unsatisfiable_schema$$=new $APP.$cljs$core$Keyword$$("malli.generator","unsatisfiable-schema","malli.generator/unsatisfiable-schema",919209538);$APP.$cljs$cst$3181$prev_before_path$$=new $APP.$cljs$core$Keyword$$(null,"prev-before-path","prev-before-path",788140603);
$cljs$cst$4120$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_svg_text$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","paste-svg-text","app.main.data.workspace.clipboard/paste-svg-text",-566155277);$APP.$cljs$cst$19$i$$=new $APP.$cljs$core$Symbol$$(null,"i","i",253690212,null);$cljs$cst$355$k$$=new $APP.$cljs$core$Symbol$$(null,"k","k",-505765866,null);$cljs$cst$316$m$$=new $APP.$cljs$core$Symbol$$(null,"m","m",-1021758608,null);
$APP.$cljs$cst$2427$p$$=new $APP.$cljs$core$Symbol$$(null,"p","p",1791580836,null);$APP.$cljs$cst$14$s$$=new $APP.$cljs$core$Symbol$$(null,"s","s",-948495851,null);$cljs$cst$57$v$$=new $APP.$cljs$core$Symbol$$(null,"v","v",1661996586,null);$cljs$cst$5296$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_page$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","go-to-page","app.main.data.viewer/go-to-page",-599885403);
$cljs$cst$3737$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_set_options_mode$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.layout","set-options-mode","app.main.data.workspace.layout/set-options-mode",641151177);$cljs$cst$3674$strokeOpacity$$=new $APP.$cljs$core$Keyword$$(null,"strokeOpacity","strokeOpacity",-565583263);$cljs$cst$3689$strict_entities$$=new $APP.$cljs$core$Keyword$$(null,"strict-entities","strict-entities",-551773933);
$cljs$cst$1196$exporter_svgo$$=new $APP.$cljs$core$Keyword$$(null,"exporter-svgo","exporter-svgo",215673571);$APP.$cljs$cst$1672$auto$$=new $APP.$cljs$core$Keyword$$(null,"auto","auto",-566279492);$APP.$cljs$cst$1722$permissions$$=new $APP.$cljs$core$Keyword$$(null,"permissions","permissions",67803075);$cljs$cst$605$function$$=new $APP.$cljs$core$Keyword$$(null,"function","function",-2127255473);$cljs$cst$4061$border_width$$=new $APP.$cljs$core$Keyword$$(null,"border-width","border-width",-1512605390);
$cljs$cst$371$naked_keys$$=new $APP.$cljs$core$Keyword$$(null,"naked-keys","naked-keys",-90769828);$APP.$cljs$cst$1946$open_overlay$$=new $APP.$cljs$core$Keyword$$(null,"open-overlay","open-overlay",-611391651);$APP.$cljs$cst$4181$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_sort_colorpicker_stops$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","sort-colorpicker-stops","app.main.data.workspace.colors/sort-colorpicker-stops",-460550682);
$APP.$cljs$cst$275$hint$$=new $APP.$cljs$core$Keyword$$(null,"hint","hint",439639918);$APP.$cljs$cst$4692$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_clear_tokens_paths$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","clear-tokens-paths","app.main.data.workspace.tokens.library-edit/clear-tokens-paths",711179200);$cljs$cst$918$encoders$$=new $APP.$cljs$core$Keyword$$(null,"encoders","encoders",-111722908);
$APP.$cljs$cst$4853$toggle_textpalette$$=new $APP.$cljs$core$Keyword$$(null,"toggle-textpalette","toggle-textpalette",-1581028492);$cljs$cst$806$clojure_DOT_test_DOT_check_DOT_generators_SLASH_any_printable$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","any-printable","clojure.test.check.generators/any-printable",-1570493991,null);$cljs$cst$1593$admin$$=new $APP.$cljs$core$Keyword$$(null,"admin","admin",-1239101627);
$APP.$cljs$cst$1983$spacing$$=new $APP.$cljs$core$Keyword$$(null,"spacing","spacing",204422175);$APP.$cljs$cst$243$cljs_DOT_core_SLASH_vec$$=new $APP.$cljs$core$Symbol$$("cljs.core","vec","cljs.core/vec",307622519,null);$APP.$cljs$cst$769$state$$=new $APP.$cljs$core$Keyword$$(null,"state","state",-1988618099);$cljs$cst$3742$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_rulers_QMARK_$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","show-rulers?","app.main.data.workspace/show-rulers?",1922241389);
$APP.$cljs$cst$2244$progress$$=new $APP.$cljs$core$Keyword$$(null,"progress","progress",244323547);$cljs$cst$3263$app_DOT_main_DOT_data_DOT_team_SLASH_members_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","members-fetched","app.main.data.team/members-fetched",-128392737);$APP.$cljs$cst$3280$stats$$=new $APP.$cljs$core$Keyword$$(null,"stats","stats",-85643011);$APP.$cljs$cst$1933$square$$=new $APP.$cljs$core$Keyword$$(null,"square","square",812434677);
$cljs$cst$1263$enable_token_color$$=new $APP.$cljs$core$Keyword$$(null,"enable-token-color","enable-token-color",1246947059);$APP.$cljs$cst$2045$main_instance$$=new $APP.$cljs$core$Keyword$$(null,"main-instance","main-instance",476264761);$APP.$cljs$cst$3083$canvas$$=new $APP.$cljs$core$Keyword$$(null,"canvas","canvas",-1798817489);
$APP.$cljs$cst$4919$app_DOT_main_DOT_data_DOT_dashboard_SLASH_fetch_builtin_templates$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","fetch-builtin-templates","app.main.data.dashboard/fetch-builtin-templates",1341565156);$cljs$cst$5214$copy_top$$=new $APP.$cljs$core$Keyword$$(null,"copy-top","copy-top",-817189511);$APP.$cljs$cst$5797$on_toggle_expand$$=new $APP.$cljs$core$Keyword$$(null,"on-toggle-expand","on-toggle-expand",227315372);
$APP.$cljs$cst$1932$display$$=new $APP.$cljs$core$Keyword$$(null,"display","display",242065432);$APP.$cljs$cst$2487$app_DOT_main_DOT_data_DOT_common_SLASH_create_team_access_request$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","create-team-access-request","app.main.data.common/create-team-access-request",-1355196738);
$APP.$cljs$cst$4134$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_pick_color$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","pick-color","app.main.data.workspace.colors/pick-color",-1649301031);$APP.$cljs$cst$1968$preserve_scroll$$=new $APP.$cljs$core$Keyword$$(null,"preserve-scroll","preserve-scroll",-1515148069);
$APP.$cljs$cst$4906$app_DOT_main_DOT_data_DOT_dashboard_SLASH_finalize$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","finalize","app.main.data.dashboard/finalize",624606997);$APP.$cljs$cst$2352$inline_actions$$=new $APP.$cljs$core$Keyword$$(null,"inline-actions","inline-actions",-1590886374);$APP.$cljs$cst$1292$start$$=new $APP.$cljs$core$Keyword$$(null,"start","start",-355208981);
$APP.$cljs$cst$4722$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_show_token_context_menu$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","show-token-context-menu","app.main.data.workspace.tokens.library-edit/show-token-context-menu",-762808545);$cljs$cst$3178$uops$$=new $APP.$cljs$core$Keyword$$(null,"uops","uops",-1510697393);$cljs$cst$4611$warning_SLASH_message$$=new $APP.$cljs$core$Keyword$$("warning","message","warning/message",-1396136870);
$cljs$cst$5305$navigation_viewer$$=new $APP.$cljs$core$Keyword$$(null,"navigation-viewer","navigation-viewer",74246747);$APP.$cljs$cst$4695$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_nested_token_path$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","toggle-nested-token-path","app.main.data.workspace.tokens.library-edit/toggle-nested-token-path",-2102622867);
$cljs$cst$2923$baseline_shift$$=new $APP.$cljs$core$Keyword$$(null,"baseline-shift","baseline-shift",-2068063947);$cljs$cst$5281$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_section$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","go-to-section","app.main.data.viewer/go-to-section",1726546114);$APP.$cljs$cst$2362$reitit_DOT_exception_SLASH_cause$$=new $APP.$cljs$core$Keyword$$("reitit.exception","cause","reitit.exception/cause",2130128734);
$cljs$cst$5233$comments_show$$=new $APP.$cljs$core$Keyword$$(null,"comments-show","comments-show",1040621660);$cljs$cst$5330$geometry$$=new $APP.$cljs$core$Keyword$$(null,"geometry","geometry",-405034994);$APP.$cljs$cst$4864$align_right$$=new $APP.$cljs$core$Keyword$$(null,"align-right","align-right",-189896040);$cljs$cst$576$malli_DOT_core_SLASH_invalid_arity$$=new $APP.$cljs$core$Keyword$$("malli.core","invalid-arity","malli.core/invalid-arity",577014581);
$APP.$cljs$cst$1731$end_x$$=new $APP.$cljs$core$Keyword$$(null,"end-x","end-x",-1323983821);$APP.$cljs$cst$1732$end_y$$=new $APP.$cljs$core$Keyword$$(null,"end-y","end-y",859881965);$cljs$cst$4081$column_row$$=new $APP.$cljs$core$Keyword$$(null,"column-row","column-row",868545736);$APP.$cljs$cst$1757$font_id$$=new $APP.$cljs$core$Keyword$$(null,"font-id","font-id",-390084123);
$cljs$cst$4377$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_shapes_to_path_SLASH_convert_selected_to_path$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.shapes-to-path","convert-selected-to-path","app.main.data.workspace.path.shapes-to-path/convert-selected-to-path",-414137768);$cljs$cst$2129$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_simple_value$$=new $APP.$cljs$core$Keyword$$("app.common.types.tokens-lib","simple-value","app.common.types.tokens-lib/simple-value",-1723851317);
$APP.$cljs$cst$2185$dashboard_local$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-local","dashboard-local",-334594003);$cljs$cst$2974$font_loaded$$=new $APP.$cljs$core$Keyword$$(null,"font-loaded","font-loaded",-649984775);$cljs$cst$4987$manifest$$=new $APP.$cljs$core$Keyword$$(null,"manifest","manifest",-1386791956);$APP.$cljs$cst$5400$share_link$$=new $APP.$cljs$core$Keyword$$(null,"share-link","share-link",1324379138);
$APP.$cljs$cst$4223$edit_mode$$=new $APP.$cljs$core$Keyword$$(null,"edit-mode","edit-mode",1940640993);$APP.$cljs$cst$2220$margins_selected$$=new $APP.$cljs$core$Keyword$$(null,"margins-selected","margins-selected",890458559);$APP.$cljs$cst$3484$current_share_id$$=new $APP.$cljs$core$Keyword$$(null,"current-share-id","current-share-id",-280704217);$APP.$cljs$cst$5335$selected_shapes$$=new $APP.$cljs$core$Keyword$$(null,"selected-shapes","selected-shapes",-40235010);
$cljs$cst$444$not$$=new $APP.$cljs$core$Keyword$$(null,"not","not",-595976884);$APP.$cljs$cst$1760$font_size$$=new $APP.$cljs$core$Keyword$$(null,"font-size","font-size",-1847940346);$APP.$cljs$cst$2188$workspace_global$$=new $APP.$cljs$core$Keyword$$(null,"workspace-global","workspace-global",-1341112178);
$APP.$cljs$cst$3907$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_color_data$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","update-color-data","app.main.data.workspace.libraries/update-color-data",-874532473);$cljs$cst$2486$has_file_libraries$$=new $APP.$cljs$core$Keyword$$(null,"has-file-libraries","has-file-libraries",183957263);$APP.$cljs$cst$3724$dynamic_alignment$$=new $APP.$cljs$core$Keyword$$(null,"dynamic-alignment","dynamic-alignment",-1699946765);
$APP.$cljs$cst$4048$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_replace_text_in_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","replace-text-in-shapes","app.main.data.workspace.texts/replace-text-in-shapes",907250916);$APP.$cljs$cst$3752$hide_toolbar$$=new $APP.$cljs$core$Keyword$$(null,"hide-toolbar","hide-toolbar",-1320052666);
$APP.$cljs$cst$2500$app_DOT_main_DOT_data_DOT_common_SLASH_initialize_progress$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","initialize-progress","app.main.data.common/initialize-progress",-1910225354);$cljs$cst$2243$updating_library$$=new $APP.$cljs$core$Keyword$$(null,"updating-library","updating-library",1829693573);$cljs$cst$5171$component_not_main$$=new $APP.$cljs$core$Keyword$$(null,"component-not-main","component-not-main",-1388012781);
$APP.$cljs$cst$4519$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_gap_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","set-gap-selected","app.main.data.workspace/set-gap-selected",492549877);$cljs$cst$3567$transactions_pending$$=new $APP.$cljs$core$Keyword$$(null,"transactions-pending","transactions-pending",-59999859);
$cljs$cst$3627$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_toggle_focus_mode$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","toggle-focus-mode","app.main.data.workspace.selection/toggle-focus-mode",2048185160);$cljs$cst$5174$invalid_main_instance_id$$=new $APP.$cljs$core$Keyword$$(null,"invalid-main-instance-id","invalid-main-instance-id",-584539934);$cljs$cst$745$reserved$$=new $APP.$cljs$core$Keyword$$(null,"reserved","reserved",-775228297);
$cljs$cst$4342$get_current_mcp_token$$=new $APP.$cljs$core$Keyword$$(null,"get-current-mcp-token","get-current-mcp-token",1246797888);$APP.$cljs$cst$3402$plugin$$=new $APP.$cljs$core$Keyword$$(null,"plugin","plugin",-1688841923);$cljs$cst$1989$sided_paddings$$=new $APP.$cljs$core$Keyword$$(null,"sided-paddings","sided-paddings",1192080137);$cljs$cst$2970$ttf_file_id$$=new $APP.$cljs$core$Keyword$$(null,"ttf-file-id","ttf-file-id",-1342545748);
$APP.$cljs$cst$3698$blobs$$=new $APP.$cljs$core$Keyword$$(null,"blobs","blobs",-1606355916);$APP.$cljs$cst$2245$access_token_created$$=new $APP.$cljs$core$Keyword$$(null,"access-token-created","access-token-created",294001579);$APP.$cljs$cst$1980$dimensions$$=new $APP.$cljs$core$Keyword$$(null,"dimensions","dimensions",-254818097);
$APP.$cljs$cst$4733$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_clear_token_set_creation$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","clear-token-set-creation","app.main.data.workspace.tokens.library-edit/clear-token-set-creation",-574025068);$cljs$cst$5200$component_duplicate_slot$$=new $APP.$cljs$core$Keyword$$(null,"component-duplicate-slot","component-duplicate-slot",-981521019);
$cljs$cst$5136$no_enough_members_for_leave$$=new $APP.$cljs$core$Keyword$$(null,"no-enough-members-for-leave","no-enough-members-for-leave",132163040);$APP.$cljs$cst$1400$block$$=new $APP.$cljs$core$Keyword$$(null,"block","block",664686210);$APP.$cljs$cst$2820$radius$$=new $APP.$cljs$core$Keyword$$(null,"radius","radius",-2073122258);$cljs$cst$3387$server_error$$=new $APP.$cljs$core$Keyword$$(null,"server-error","server-error",-426815993);
$APP.$cljs$cst$5109$dimmed$$=new $APP.$cljs$core$Keyword$$(null,"dimmed","dimmed",-791586346);$APP.$cljs$cst$3150$run_id$$=new $APP.$cljs$core$Keyword$$(null,"run-id","run-id",-1745267908);$cljs$cst$464$malli_DOT_core_SLASH_limits$$=new $APP.$cljs$core$Keyword$$("malli.core","limits","malli.core/limits",-1343466863);$APP.$cljs$cst$2071$layout_container$$=new $APP.$cljs$core$Keyword$$(null,"layout-container","layout-container",684815305);
$APP.$cljs$cst$1999$leaf$$=new $APP.$cljs$core$Keyword$$(null,"leaf","leaf",1306118732);$cljs$cst$105$more_marker$$=new $APP.$cljs$core$Keyword$$(null,"more-marker","more-marker",-14717935);$APP.$cljs$cst$2028$hard_light$$=new $APP.$cljs$core$Keyword$$(null,"hard-light","hard-light",-37591145);$cljs$cst$1218$client_header_check_middleware$$=new $APP.$cljs$core$Keyword$$(null,"client-header-check-middleware","client-header-check-middleware",1313314510);
$cljs$cst$3647$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_create_and_add_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","create-and-add-shape","app.main.data.workspace.shapes/create-and-add-shape",-1895732796);$cljs$cst$5351$import_success$$=new $APP.$cljs$core$Keyword$$(null,"import-success","import-success",-1164176997);$cljs$cst$5191$not_head_main_not_allowed$$=new $APP.$cljs$core$Keyword$$(null,"not-head-main-not-allowed","not-head-main-not-allowed",-1213809819);
$APP.$cljs$cst$1638$components$$=new $APP.$cljs$core$Keyword$$(null,"components","components",-1073188942);$cljs$cst$2280$blob_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"blob?","blob?",-327089451);$cljs$cst$870$gen_SLASH_schema$$=new $APP.$cljs$core$Keyword$$("gen","schema","gen/schema",-1582038959);
$cljs$cst$4635$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_layout_sizing_limits$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","update-layout-sizing-limits","app.main.data.workspace.tokens.application/update-layout-sizing-limits",1587363227);$cljs$cst$1725$app_DOT_common_DOT_types_DOT_color_SLASH_hex_color$$=new $APP.$cljs$core$Keyword$$("app.common.types.color","hex-color","app.common.types.color/hex-color",905576833);
$APP.$cljs$cst$2090$update_original_shape$$=new $APP.$cljs$core$Keyword$$(null,"update-original-shape","update-original-shape",1527494425);$cljs$cst$3796$requester$$=new $APP.$cljs$core$Keyword$$(null,"requester","requester",2032946161);$APP.$cljs$cst$2225$clipboard_style$$=new $APP.$cljs$core$Keyword$$(null,"clipboard-style","clipboard-style",987303829);$APP.$cljs$cst$5013$show_sidebar_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"show-sidebar?","show-sidebar?",-1548438810);
$cljs$cst$761$multikeys$$=new $APP.$cljs$core$Keyword$$(null,"multikeys","multikeys",-695183366);$cljs$cst$2901$color_rendering$$=new $APP.$cljs$core$Keyword$$(null,"color-rendering","color-rendering",-891830687);$APP.$cljs$cst$2132$json_format_SLASH_dtcg$$=new $APP.$cljs$core$Keyword$$("json-format","dtcg","json-format/dtcg",-2034606706);$cljs$cst$2755$baseProfile$$=new $APP.$cljs$core$Keyword$$(null,"baseProfile","baseProfile",-448131232);
$cljs$cst$3905$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_clear_color_for_rename$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","clear-color-for-rename","app.main.data.workspace.libraries/clear-color-for-rename",-1233782195);$APP.$cljs$cst$5134$hero$$=new $APP.$cljs$core$Keyword$$(null,"hero","hero",1983137057);
$cljs$cst$3461$app_DOT_main_DOT_data_DOT_comments_SLASH_retrieve_comments$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","retrieve-comments","app.main.data.comments/retrieve-comments",-591535096);$APP.$cljs$cst$1534$png$$=new $APP.$cljs$core$Keyword$$(null,"png","png",551930691);$APP.$cljs$cst$4865$align_hcenter$$=new $APP.$cljs$core$Keyword$$(null,"align-hcenter","align-hcenter",369876664);
$cljs$cst$2807$horiz_origin_y$$=new $APP.$cljs$core$Keyword$$(null,"horiz-origin-y","horiz-origin-y",1864809354);$cljs$cst$3312$delete_team$$=new $APP.$cljs$core$Keyword$$(null,"delete-team","delete-team",323575412);$cljs$cst$2799$horiz_origin_x$$=new $APP.$cljs$core$Keyword$$(null,"horiz-origin-x","horiz-origin-x",1522984617);$APP.$cljs$cst$3426$seqn$$=new $APP.$cljs$core$Keyword$$(null,"seqn","seqn",406413591);
$cljs$cst$4296$app_DOT_main_DOT_data_DOT_workspace_DOT_highlight_SLASH_dehighlight_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.highlight","dehighlight-shape","app.main.data.workspace.highlight/dehighlight-shape",1924177456);$APP.$cljs$cst$3445$is_resolved$$=new $APP.$cljs$core$Keyword$$(null,"is-resolved","is-resolved",403882551);
$APP.$cljs$cst$4319$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_move_overlay_pos$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","move-overlay-pos","app.main.data.workspace.interactions/move-overlay-pos",-610980627);$cljs$cst$5111$render_fn$$=new $APP.$cljs$core$Keyword$$(null,"render-fn","render-fn",398796518);$APP.$cljs$cst$1080$count$$=new $APP.$cljs$core$Keyword$$(null,"count","count",2139924085);
$APP.$cljs$cst$3563$workspace_undo$$=new $APP.$cljs$core$Keyword$$(null,"workspace-undo","workspace-undo",-1544884606);$cljs$cst$1249$enable_export_file_v3$$=new $APP.$cljs$core$Keyword$$(null,"enable-export-file-v3","enable-export-file-v3",840578489);$cljs$cst$4531$app_DOT_main_DOT_data_DOT_workspace_SLASH_find_components_norefs$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","find-components-norefs","app.main.data.workspace/find-components-norefs",1513370826);
$APP.$cljs$cst$1212$token_base_font_size$$=new $APP.$cljs$core$Keyword$$(null,"token-base-font-size","token-base-font-size",-1444587637);$APP.$cljs$cst$5024$loaded$$=new $APP.$cljs$core$Keyword$$(null,"loaded","loaded",-1246482293);$cljs$cst$263$linked_SLASH_map$$=new $APP.$cljs$core$Symbol$$("linked","map","linked/map",-195852787,null);$cljs$cst$650$explain$$=new $APP.$cljs$core$Keyword$$(null,"explain","explain",484226146);
$APP.$cljs$cst$2210$snap_pixel_grid$$=new $APP.$cljs$core$Keyword$$(null,"snap-pixel-grid","snap-pixel-grid",-1263132602);$APP.$cljs$cst$5026$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_create_version$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","create-version","app.main.data.workspace.versions/create-version",981657945);
$APP.$cljs$cst$4021$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","resize-text","app.main.data.workspace.texts/resize-text",377982849);$cljs$cst$1$readably$$=new $APP.$cljs$core$Keyword$$(null,"readably","readably",1129599760);$cljs$cst$2273$rename_to$$=new $APP.$cljs$core$Keyword$$(null,"rename-to","rename-to",610483329);
$APP.$cljs$cst$3984$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_attach_library_finished$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","attach-library-finished","app.main.data.workspace.libraries/attach-library-finished",-109043980);$APP.$cljs$cst$4954$app_DOT_main_DOT_data_DOT_dashboard_SLASH_set_file_shared$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","set-file-shared","app.main.data.dashboard/set-file-shared",-875921747);
$APP.$cljs$cst$4178$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_add_auto$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","update-colorpicker-add-auto","app.main.data.workspace.colors/update-colorpicker-add-auto",1581488935);$APP.$cljs$cst$2327$app_DOT_main_DOT_data_DOT_event_SLASH_initialize$$=new $APP.$cljs$core$Keyword$$("app.main.data.event","initialize","app.main.data.event/initialize",-1618391629);
$cljs$cst$4696$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_create_token_theme$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","create-token-theme","app.main.data.workspace.tokens.library-edit/create-token-theme",-581595599);$APP.$cljs$cst$3141$stack_undo_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"stack-undo?","stack-undo?",1633924062);$APP.$cljs$cst$1657$row_span$$=new $APP.$cljs$core$Keyword$$(null,"row-span","row-span",-365554241);
$APP.$cljs$cst$5412$sent$$=new $APP.$cljs$core$Keyword$$(null,"sent","sent",-1537501490);$APP.$cljs$cst$3604$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_shapes_by_current_selrect$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","select-shapes-by-current-selrect","app.main.data.workspace.selection/select-shapes-by-current-selrect",-1839601210);
$cljs$cst$812$clojure_DOT_test_DOT_check_DOT_generators_SLASH_double$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","double","clojure.test.check.generators/double",668331090,null);$APP.$cljs$cst$4468$workspace_persistence$$=new $APP.$cljs$core$Keyword$$(null,"workspace-persistence","workspace-persistence",2007839858);$cljs$cst$2775$kernelMatrix$$=new $APP.$cljs$core$Keyword$$(null,"kernelMatrix","kernelMatrix",252444132);
$APP.$cljs$cst$1674$area$$=new $APP.$cljs$core$Keyword$$(null,"area","area",472007256);$cljs$cst$5268$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_first_frame$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","select-first-frame","app.main.data.viewer/select-first-frame",383131704);$APP.$cljs$cst$1726$mtype$$=new $APP.$cljs$core$Keyword$$(null,"mtype","mtype",-1724656120);$APP.$cljs$cst$5405$who_comment$$=new $APP.$cljs$core$Keyword$$(null,"who-comment","who-comment",-313192010);
$cljs$cst$2942$clipUnits$$=new $APP.$cljs$core$Keyword$$(null,"clipUnits","clipUnits",-2007627726);$cljs$cst$2981$fallback_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"fallback?","fallback?",-1074968796);
$APP.$cljs$cst$4687$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_restore_unfolded_token_types$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","restore-unfolded-token-types","app.main.data.workspace.tokens.library-edit/restore-unfolded-token-types",1132993159);
$APP.$cljs$cst$3709$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_process_svg_component$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.media","process-svg-component","app.main.data.workspace.media/process-svg-component",797837409);$APP.$cljs$cst$5149$current_organization_id$$=new $APP.$cljs$core$Keyword$$(null,"current-organization-id","current-organization-id",-542218991);$cljs$cst$634$re_min_max$$=new $APP.$cljs$core$Keyword$$(null,"re-min-max","re-min-max",1020871707);
$cljs$cst$1356$linux$$=new $APP.$cljs$core$Keyword$$(null,"linux","linux",-238042662);$cljs$cst$4576$error_DOT_style_dictionary_SLASH_invalid_token_value_font_weight$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","invalid-token-value-font-weight","error.style-dictionary/invalid-token-value-font-weight",-1037871167);
$cljs$cst$4198$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_changes_SLASH_save_path_content$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.changes","save-path-content","app.main.data.workspace.path.changes/save-path-content",-863862726);$cljs$cst$3655$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_relocate_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","relocate-shapes","app.main.data.workspace.shapes/relocate-shapes",154933971);
$APP.$cljs$cst$4871$toggle_rulers$$=new $APP.$cljs$core$Keyword$$(null,"toggle-rulers","toggle-rulers",228269563);$cljs$cst$2160$movement$$=new $APP.$cljs$core$Keyword$$(null,"movement","movement",1777030977);$cljs$cst$1145$virtual$$=new $APP.$cljs$core$Keyword$$(null,"virtual","virtual",-1139229001);$cljs$cst$3034$stopcolor$$=new $APP.$cljs$core$Keyword$$(null,"stopcolor","stopcolor",-1241628911);
$APP.$cljs$cst$2226$workspace_focus_selected$$=new $APP.$cljs$core$Keyword$$(null,"workspace-focus-selected","workspace-focus-selected",978051257);$APP.$cljs$cst$2464$app_DOT_main_DOT_router_SLASH_initialize_history$$=new $APP.$cljs$core$Keyword$$("app.main.router","initialize-history","app.main.router/initialize-history",377149557);
$cljs$cst$4363$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_library_change$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.notifications","handle-library-change","app.main.data.workspace.notifications/handle-library-change",1098362084);$APP.$cljs$cst$847$failure$$=new $APP.$cljs$core$Keyword$$(null,"failure","failure",720415879);
$APP.$cljs$cst$4275$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_handle_comment_layer_click$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.comments","handle-comment-layer-click","app.main.data.workspace.comments/handle-comment-layer-click",1482069432);$APP.$cljs$cst$1734$opacity$$=new $APP.$cljs$core$Keyword$$(null,"opacity","opacity",397153780);$APP.$cljs$cst$2108$sets$$=new $APP.$cljs$core$Keyword$$(null,"sets","sets",400955582);
$APP.$cljs$cst$195$offset$$=new $APP.$cljs$core$Keyword$$(null,"offset","offset",296498311);$APP.$cljs$cst$5140$on_confirm$$=new $APP.$cljs$core$Keyword$$(null,"on-confirm","on-confirm",1527003038);$APP.$cljs$cst$896$wrap$$=new $APP.$cljs$core$Keyword$$(null,"wrap","wrap",851669987);$cljs$cst$3483$app_DOT_main_DOT_data_DOT_comments_SLASH_fetch_profiles$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","fetch-profiles","app.main.data.comments/fetch-profiles",1482024457);
$APP.$cljs$cst$4874$toggle_theme$$=new $APP.$cljs$core$Keyword$$(null,"toggle-theme","toggle-theme",-91905156);$APP.$cljs$cst$1754$invalid_type$$=new $APP.$cljs$core$Keyword$$(null,"invalid-type","invalid-type",-1552570890);$APP.$cljs$cst$3501$app_DOT_main_DOT_data_DOT_fonts_SLASH_add_font$$=new $APP.$cljs$core$Keyword$$("app.main.data.fonts","add-font","app.main.data.fonts/add-font",-1155803849);$cljs$cst$4789$italic$$=new $APP.$cljs$core$Keyword$$(null,"italic","italic",32599196);
$cljs$cst$4067$border_color$$=new $APP.$cljs$core$Keyword$$(null,"border-color","border-color",-2059162761);$APP.$cljs$cst$3732$design$$=new $APP.$cljs$core$Keyword$$(null,"design","design",1241338903);$cljs$cst$1618$ignore_children_fn$$=new $APP.$cljs$core$Keyword$$(null,"ignore-children-fn","ignore-children-fn",576274564);$cljs$cst$5212$main_top$$=new $APP.$cljs$core$Keyword$$(null,"main-top","main-top",1522428454);
$cljs$cst$2064$bool_content$$=new $APP.$cljs$core$Keyword$$(null,"bool-content","bool-content",1114257725);$cljs$cst$1585$average$$=new $APP.$cljs$core$Keyword$$(null,"average","average",-492356168);$APP.$cljs$cst$1941$navigate$$=new $APP.$cljs$core$Keyword$$(null,"navigate","navigate",657596805);$APP.$cljs$cst$5372$error_msg$$=new $APP.$cljs$core$Keyword$$(null,"error-msg","error-msg",-1409360623);$cljs$cst$2299$screen_height$$=new $APP.$cljs$core$Keyword$$(null,"screen-height","screen-height",141363033);
$cljs$cst$2754$xml_COLON_lang$$=new $APP.$cljs$core$Keyword$$(null,"xml:lang","xml:lang",-1485113568);$APP.$cljs$cst$61$root$$=new $APP.$cljs$core$Symbol$$(null,"root","root",1191874074,null);$cljs$cst$2985$runic$$=new $APP.$cljs$core$Keyword$$(null,"runic","runic",-276407709);$cljs$cst$4857$move_unit_right$$=new $APP.$cljs$core$Keyword$$(null,"move-unit-right","move-unit-right",-182503082);$cljs$cst$1714$remove_empty_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"remove-empty?","remove-empty?",-2004264696);
$APP.$cljs$cst$2308$event_namespace$$=new $APP.$cljs$core$Keyword$$(null,"event-namespace","event-namespace",-1246033011);$cljs$cst$4445$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_variants_switch$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","variants-switch","app.main.data.workspace.variants/variants-switch",-2126966764);
$APP.$cljs$cst$3629$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_finalize_page$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.pages","finalize-page","app.main.data.workspace.pages/finalize-page",526513034);$APP.$cljs$cst$1728$radial$$=new $APP.$cljs$core$Keyword$$(null,"radial","radial",-1334240714);$APP.$cljs$cst$849$error$$=new $APP.$cljs$core$Keyword$$(null,"error","error",-978969032);
$APP.$cljs$cst$2051$interactions$$=new $APP.$cljs$core$Keyword$$(null,"interactions","interactions",550841811);$APP.$cljs$cst$2198$object$$=new $APP.$cljs$core$Keyword$$(null,"object","object",1474613949);$cljs$cst$4597$error_DOT_style_dictionary_SLASH_invalid_token_value_text_case$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","invalid-token-value-text-case","error.style-dictionary/invalid-token-value-text-case",-1959663654);
$cljs$cst$1934$pdf$$=new $APP.$cljs$core$Keyword$$(null,"pdf","pdf",1586765132);$APP.$cljs$cst$5347$on_finish_import$$=new $APP.$cljs$core$Keyword$$(null,"on-finish-import","on-finish-import",1088832986);$APP.$cljs$cst$1991$horizontal_padding$$=new $APP.$cljs$core$Keyword$$(null,"horizontal-padding","horizontal-padding",-1543677678);$APP.$cljs$cst$3646$undo_id$$=new $APP.$cljs$core$Keyword$$(null,"undo-id","undo-id",-650073754);
$APP.$cljs$cst$1938$mouse_enter$$=new $APP.$cljs$core$Keyword$$(null,"mouse-enter","mouse-enter",678856303);$APP.$cljs$cst$4431$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_reorder_variant_properties$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","reorder-variant-properties","app.main.data.workspace.variants/reorder-variant-properties",-1549102244);$APP.$cljs$cst$4135$picked_color$$=new $APP.$cljs$core$Keyword$$(null,"picked-color","picked-color",-1962236902);
$cljs$cst$1155$app_DOT_common_DOT_logging_SLASH_logger$$=new $APP.$cljs$core$Keyword$$("app.common.logging","logger","app.common.logging/logger",-2023501234);$cljs$cst$578$args$$=new $APP.$cljs$core$Keyword$$(null,"args","args",1315556576);$APP.$cljs$cst$882$error_SLASH_message$$=new $APP.$cljs$core$Keyword$$("error","message","error/message",-502809098);
$cljs$cst$5388$email_does_not_match_invitation$$=new $APP.$cljs$core$Keyword$$(null,"email-does-not-match-invitation","email-does-not-match-invitation",-1798001872);$APP.$cljs$cst$4125$export_shapes$$=new $APP.$cljs$core$Keyword$$(null,"export-shapes","export-shapes",341502938);$cljs$cst$5087$auto_focus_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"auto-focus?","auto-focus?",1021654593);$APP.$cljs$cst$1942$close_overlay$$=new $APP.$cljs$core$Keyword$$(null,"close-overlay","close-overlay",1224325518);
$APP.$cljs$cst$4951$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_file$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","delete-file","app.main.data.dashboard/delete-file",-1450992873);$cljs$cst$1805$precise_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"precise?","precise?",-353383452);$APP.$cljs$cst$3750$workspace_visited$$=new $APP.$cljs$core$Keyword$$(null,"workspace-visited","workspace-visited",479274314);
$APP.$cljs$cst$1683$layout_gap_type$$=new $APP.$cljs$core$Keyword$$(null,"layout-gap-type","layout-gap-type",-1483813598);$cljs$cst$493$malli_DOT_core_SLASH_cannot_provide_empty_and_bounded_props$$=new $APP.$cljs$core$Keyword$$("malli.core","cannot-provide-empty-and-bounded-props","malli.core/cannot-provide-empty-and-bounded-props",1469796922);$cljs$cst$158$new$$=new $APP.$cljs$core$Symbol$$(null,"new","new",-444906321,null);
$cljs$cst$1176$log_invitation_tokens$$=new $APP.$cljs$core$Keyword$$(null,"log-invitation-tokens","log-invitation-tokens",-1898382027);$APP.$cljs$cst$4675$tokens_SLASH_spacing$$=new $APP.$cljs$core$Keyword$$("tokens","spacing","tokens/spacing",-697448015);$APP.$cljs$cst$2014$diamond_marker$$=new $APP.$cljs$core$Keyword$$(null,"diamond-marker","diamond-marker",-496524178);
$APP.$cljs$cst$4502$app_DOT_main_DOT_data_DOT_workspace_SLASH_unselect_all_assets$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","unselect-all-assets","app.main.data.workspace/unselect-all-assets",436596758);$APP.$cljs$cst$5291$app_DOT_main_DOT_data_DOT_viewer_SLASH_shift_select_to$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","shift-select-to","app.main.data.viewer/shift-select-to",-1698238213);
$cljs$cst$2471$app_DOT_main_DOT_data_DOT_common_SLASH_show_shared_dialog$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","show-shared-dialog","app.main.data.common/show-shared-dialog",-1265775444);$APP.$cljs$cst$5409$register_email_sent$$=new $APP.$cljs$core$Keyword$$(null,"register-email-sent","register-email-sent",1898188574);$cljs$cst$1482$lift_ns$$=new $APP.$cljs$core$Symbol$$(null,"lift-ns","lift-ns",602311926,null);
$APP.$cljs$cst$1900$leftright$$=new $APP.$cljs$core$Keyword$$(null,"leftright","leftright",1894963129);$cljs$cst$3825$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_clear_local_transform$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.modifiers","clear-local-transform","app.main.data.workspace.modifiers/clear-local-transform",-136322627);$cljs$cst$1473$arg1$$=new $APP.$cljs$core$Keyword$$(null,"arg1","arg1",951899358);
$cljs$cst$2914$word_spacing$$=new $APP.$cljs$core$Keyword$$(null,"word-spacing","word-spacing",-1211711602);$cljs$cst$1475$arg3$$=new $APP.$cljs$core$Keyword$$(null,"arg3","arg3",-1486822496);$cljs$cst$5215$library_exists$$=new $APP.$cljs$core$Keyword$$(null,"library-exists","library-exists",390234417);$cljs$cst$1474$arg2$$=new $APP.$cljs$core$Keyword$$(null,"arg2","arg2",1729550917);
$cljs$cst$5195$component_nil_objects_not_allowed$$=new $APP.$cljs$core$Keyword$$(null,"component-nil-objects-not-allowed","component-nil-objects-not-allowed",1630110673);$cljs$cst$1192$perf_logs$$=new $APP.$cljs$core$Keyword$$(null,"perf-logs","perf-logs",-2006058847);$APP.$cljs$cst$4838$insert_image$$=new $APP.$cljs$core$Keyword$$(null,"insert-image","insert-image",-460453042);$cljs$cst$2740$animateMotion$$=new $APP.$cljs$core$Keyword$$(null,"animateMotion","animateMotion",-472450597);
$APP.$cljs$cst$4856$zoom_selected$$=new $APP.$cljs$core$Keyword$$(null,"zoom-selected","zoom-selected",-1583985803);$cljs$cst$3757$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_group_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.groups","group-shapes","app.main.data.workspace.groups/group-shapes",1694900769);$APP.$cljs$cst$5145$choose_key$$=new $APP.$cljs$core$Keyword$$(null,"choose-key","choose-key",-740191994);
$APP.$cljs$cst$2281$wait$$=new $APP.$cljs$core$Keyword$$(null,"wait","wait",-260664777);$cljs$cst$2993$latin_ext$$=new $APP.$cljs$core$Keyword$$(null,"latin-ext","latin-ext",-1782999545);$APP.$cljs$cst$260$value$$=new $APP.$cljs$core$Keyword$$(null,"value","value",305978217);$cljs$cst$5299$open_interactions$$=new $APP.$cljs$core$Keyword$$(null,"open-interactions","open-interactions",674426882);
$APP.$cljs$cst$3227$onboarding_viewed$$=new $APP.$cljs$core$Keyword$$(null,"onboarding-viewed","onboarding-viewed",-399988124);$cljs$cst$657$clojure_DOT_string$$=new $APP.$cljs$core$Symbol$$(null,"clojure.string","clojure.string",-1415552165,null);$cljs$cst$4401$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_toggle_shape_layout$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","toggle-shape-layout","app.main.data.workspace.shape-layout/toggle-shape-layout",1842778168);
$APP.$cljs$cst$4589$error_DOT_import_SLASH_no_token_files_found$$=new $APP.$cljs$core$Keyword$$("error.import","no-token-files-found","error.import/no-token-files-found",-1804804754);$cljs$cst$2267$retrieve_list_of_builtin_templates$$=new $APP.$cljs$core$Keyword$$(null,"retrieve-list-of-builtin-templates","retrieve-list-of-builtin-templates",-515432481);$cljs$cst$551$malli_DOT_core_SLASH_invalid_ref$$=new $APP.$cljs$core$Keyword$$("malli.core","invalid-ref","malli.core/invalid-ref",-1109933109);
$APP.$cljs$cst$5278$go_to_frame$$=new $APP.$cljs$core$Keyword$$(null,"go-to-frame","go-to-frame",466960655);$cljs$cst$1166$app_DOT_common_DOT_logging_SLASH_trace$$=new $APP.$cljs$core$Keyword$$("app.common.logging","trace","app.common.logging/trace",1508486088);$cljs$cst$3206$app_DOT_main_DOT_data_DOT_profile_SLASH_persist_profile$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","persist-profile","app.main.data.profile/persist-profile",-305039457);
$APP.$cljs$cst$2240$workspace_grid_edition$$=new $APP.$cljs$core$Keyword$$(null,"workspace-grid-edition","workspace-grid-edition",-40250766);$APP.$cljs$cst$2325$bench$$=new $APP.$cljs$core$Keyword$$(null,"bench","bench",1414206922);$cljs$cst$2868$limitingConeAngle$$=new $APP.$cljs$core$Keyword$$(null,"limitingConeAngle","limitingConeAngle",-215963912);$APP.$cljs$cst$5784$selected_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"selected?","selected?",-742502788);
$APP.$cljs$cst$4182$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_select_colorpicket_gradient_stop$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","select-colorpicket-gradient-stop","app.main.data.workspace.colors/select-colorpicket-gradient-stop",519167619);$cljs$cst$2581$app_DOT_common_DOT_types_DOT_file_SLASH_file$$=new $APP.$cljs$core$Keyword$$("app.common.types.file","file","app.common.types.file/file",-455840505);
$cljs$cst$3808$line_min_height$$=new $APP.$cljs$core$Keyword$$(null,"line-min-height","line-min-height",-691270023);$APP.$cljs$cst$1807$proportion$$=new $APP.$cljs$core$Keyword$$(null,"proportion","proportion",-1209284230);$APP.$cljs$cst$1974$position_relative_to$$=new $APP.$cljs$core$Keyword$$(null,"position-relative-to","position-relative-to",-1904679190);$APP.$cljs$cst$4825$hide_ui$$=new $APP.$cljs$core$Keyword$$(null,"hide-ui","hide-ui",834012905);
$APP.$cljs$cst$4605$resolved_value$$=new $APP.$cljs$core$Keyword$$(null,"resolved-value","resolved-value",676275626);$cljs$cst$3584$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_zoom_to_selected_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.zoom","zoom-to-selected-shape","app.main.data.workspace.zoom/zoom-to-selected-shape",1169962919);$cljs$cst$867$gen_SLASH_return$$=new $APP.$cljs$core$Keyword$$("gen","return","gen/return",-1891612265);
$cljs$cst$2835$alphabetic$$=new $APP.$cljs$core$Keyword$$(null,"alphabetic","alphabetic",1536352849);$cljs$cst$1421$right_margin$$=new $APP.$cljs$core$Keyword$$(null,"right-margin","right-margin",-810413306);$APP.$cljs$cst$4453$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_start_panning$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.viewport","start-panning","app.main.data.workspace.viewport/start-panning",299875625);
$APP.$cljs$cst$3617$change_selection_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"change-selection?","change-selection?",1166805125);$cljs$cst$1219$redis_cache$$=new $APP.$cljs$core$Keyword$$(null,"redis-cache","redis-cache",-1046974065);$APP.$cljs$cst$1227$user_feedback$$=new $APP.$cljs$core$Keyword$$(null,"user-feedback","user-feedback",89199827);$cljs$cst$1049$cljs_DOT_core_SLASH_set_QMARK_$$=new $APP.$cljs$core$Symbol$$("cljs.core","set?","cljs.core/set?",-1176684971,null);
$cljs$cst$3314$delete_webhook$$=new $APP.$cljs$core$Keyword$$(null,"delete-webhook","delete-webhook",1803171729);$cljs$cst$5370$not_valid_teams$$=new $APP.$cljs$core$Keyword$$(null,"not-valid-teams","not-valid-teams",513372332);$APP.$cljs$cst$4969$app_DOT_main_DOT_data_DOT_dashboard_SLASH_open_selected_file$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","open-selected-file","app.main.data.dashboard/open-selected-file",-1578788297);
$APP.$cljs$cst$5399$share$$=new $APP.$cljs$core$Keyword$$(null,"share","share",-589433933);$cljs$cst$4630$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_fill_stroke$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","update-fill-stroke","app.main.data.workspace.tokens.application/update-fill-stroke",-1851616297);$cljs$cst$3820$reverse_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"reverse?","reverse?",-1672868474);
$APP.$cljs$cst$3440$create_comment_thread$$=new $APP.$cljs$core$Keyword$$(null,"create-comment-thread","create-comment-thread",11123715);$APP.$cljs$cst$2683$action$$=new $APP.$cljs$core$Keyword$$(null,"action","action",-811238024);$APP.$cljs$cst$3216$password_old$$=new $APP.$cljs$core$Keyword$$(null,"password-old","password-old",119312255);$cljs$cst$2278$elapsed$$=new $APP.$cljs$core$Keyword$$(null,"elapsed","elapsed",-1293489698);
$APP.$cljs$cst$2964$use_for_thumbnail$$=new $APP.$cljs$core$Keyword$$(null,"use-for-thumbnail","use-for-thumbnail",1921212442);$APP.$cljs$cst$2828$lang$$=new $APP.$cljs$core$Keyword$$(null,"lang","lang",-1819677104);$cljs$cst$5391$email_as_password$$=new $APP.$cljs$core$Keyword$$(null,"email-as-password","email-as-password",-1539580403);$APP.$cljs$cst$5075$valid$$=new $APP.$cljs$core$Keyword$$(null,"valid","valid",155614240);
$APP.$cljs$cst$1890$svg_attrs$$=new $APP.$cljs$core$Keyword$$(null,"svg-attrs","svg-attrs",524765772);$cljs$cst$4757$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_show_workspace_export_dialog$$=new $APP.$cljs$core$Keyword$$("app.main.data.exports.assets","show-workspace-export-dialog","app.main.data.exports.assets/show-workspace-export-dialog",1408325039);$APP.$cljs$cst$2339$allow_click_outside$$=new $APP.$cljs$core$Keyword$$(null,"allow-click-outside","allow-click-outside",624193625);
$APP.$cljs$cst$6303$auth_register_validate$$=new $APP.$cljs$core$Keyword$$(null,"auth-register-validate","auth-register-validate",1333056214);$APP.$cljs$cst$2468$app_DOT_main_DOT_data_DOT_common_SLASH_delete_share_link$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","delete-share-link","app.main.data.common/delete-share-link",1582371551);$cljs$cst$1497$with_open$$=new $APP.$cljs$core$Symbol$$(null,"with-open","with-open",172119667,null);
$APP.$cljs$cst$4131$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_stop_picker$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","stop-picker","app.main.data.workspace.colors/stop-picker",-843726767);$cljs$cst$4992$error_manifest$$=new $APP.$cljs$core$Keyword$$(null,"error-manifest","error-manifest",617632861);$APP.$cljs$cst$5239$get_view_only_bundle$$=new $APP.$cljs$core$Keyword$$(null,"get-view-only-bundle","get-view-only-bundle",477015725);
$APP.$cljs$cst$3776$embed$$=new $APP.$cljs$core$Keyword$$(null,"embed","embed",-1354913349);$APP.$cljs$cst$2377$reitit_DOT_trie_SLASH_unclosed_brackets$$=new $APP.$cljs$core$Keyword$$("reitit.trie","unclosed-brackets","reitit.trie/unclosed-brackets",1599327560);$cljs$cst$3778$aspect_ratio$$=new $APP.$cljs$core$Keyword$$(null,"aspect-ratio","aspect-ratio",1674013504);$APP.$cljs$cst$4496$open_status$$=new $APP.$cljs$core$Keyword$$(null,"open-status","open-status",-381209745);
$cljs$cst$1257$enable_email_verification$$=new $APP.$cljs$core$Keyword$$(null,"enable-email-verification","enable-email-verification",732407373);$APP.$cljs$cst$2958$detect_center_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"detect-center?","detect-center?",1398000690);$cljs$cst$517$malli_DOT_core_SLASH_index_out_of_bounds$$=new $APP.$cljs$core$Keyword$$("malli.core","index-out-of-bounds","malli.core/index-out-of-bounds",-371273844);
$cljs$cst$3906$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_color$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","update-color","app.main.data.workspace.libraries/update-color",1151050694);$cljs$cst$2875$v_hanging$$=new $APP.$cljs$core$Keyword$$(null,"v-hanging","v-hanging",-956218086);
$cljs$cst$2470$app_DOT_main_DOT_data_DOT_common_SLASH_show_notification$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","show-notification","app.main.data.common/show-notification",-598664195);$cljs$cst$2941$ratio$$=new $APP.$cljs$core$Keyword$$(null,"ratio","ratio",-926560044);
$cljs$cst$4284$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_navigate_to_comment_id$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.comments","navigate-to-comment-id","app.main.data.workspace.comments/navigate-to-comment-id",-1941017349);$APP.$cljs$cst$5044$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_restore_version$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","restore-version","app.main.data.workspace.versions/restore-version",-271431225);
$APP.$cljs$cst$3159$lagged$$=new $APP.$cljs$core$Keyword$$(null,"lagged","lagged",2006121946);$cljs$cst$2619$reorder_children$$=new $APP.$cljs$core$Keyword$$(null,"reorder-children","reorder-children",-522450648);$cljs$cst$1418$lines$$=new $APP.$cljs$core$Keyword$$(null,"lines","lines",-700165781);
$APP.$cljs$cst$3411$app_DOT_main_DOT_data_DOT_plugins_SLASH_set_file_plugin_data$$=new $APP.$cljs$core$Keyword$$("app.main.data.plugins","set-file-plugin-data","app.main.data.plugins/set-file-plugin-data",-1253379679);$cljs$cst$3481$update_comment_thread_frame$$=new $APP.$cljs$core$Keyword$$(null,"update-comment-thread-frame","update-comment-thread-frame",-1416539315);$APP.$cljs$cst$1162$warn$$=new $APP.$cljs$core$Keyword$$(null,"warn","warn",-436710552);
$cljs$cst$948$ordered$$=new $APP.$cljs$core$Keyword$$(null,"ordered","ordered",1187041426);$APP.$cljs$cst$2540$include_deleted_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"include-deleted?","include-deleted?",-689388372);$cljs$cst$1399$indent_t$$=new $APP.$cljs$core$Keyword$$(null,"indent-t","indent-t",528318969);$APP.$cljs$cst$2369$top_displace$$=new $APP.$cljs$core$Keyword$$(null,"top-displace","top-displace",-2094589019);
$APP.$cljs$cst$1967$destination$$=new $APP.$cljs$core$Keyword$$(null,"destination","destination",-253872483);$cljs$cst$1141$cached$$=new $APP.$cljs$core$Keyword$$(null,"cached","cached",1437727905);$APP.$cljs$cst$4385$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_set_selection$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid-layout.editor","set-selection","app.main.data.workspace.grid-layout.editor/set-selection",-1992082205);
$cljs$cst$3593$last_selected$$=new $APP.$cljs$core$Keyword$$(null,"last-selected","last-selected",1253647018);$cljs$cst$4640$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_shape_dimensions$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","update-shape-dimensions","app.main.data.workspace.tokens.application/update-shape-dimensions",-1097951426);
$APP.$cljs$cst$1866$stroke_style$$=new $APP.$cljs$core$Keyword$$(null,"stroke-style","stroke-style",-1661861146);$cljs$cst$3817$to_bound_width$$=new $APP.$cljs$core$Keyword$$(null,"to-bound-width","to-bound-width",-163351398);$cljs$cst$5401$in_team$$=new $APP.$cljs$core$Keyword$$(null,"in-team","in-team",1291962061);$APP.$cljs$cst$2013$line_arrow$$=new $APP.$cljs$core$Keyword$$(null,"line-arrow","line-arrow",-1440558012);
$cljs$cst$1350$firefox$$=new $APP.$cljs$core$Keyword$$(null,"firefox","firefox",1283768880);$cljs$cst$340$malli_DOT_core_SLASH_child_error$$=new $APP.$cljs$core$Keyword$$("malli.core","child-error","malli.core/child-error",-473817473);$APP.$cljs$cst$1741$stroke_color_gradient$$=new $APP.$cljs$core$Keyword$$(null,"stroke-color-gradient","stroke-color-gradient",-195812260);
$cljs$cst$1164$app_DOT_common_DOT_logging_SLASH_message$$=new $APP.$cljs$core$Keyword$$("app.common.logging","message","app.common.logging/message",-984224085);$cljs$cst$579$malli_DOT_core_SLASH_invalid_input$$=new $APP.$cljs$core$Keyword$$("malli.core","invalid-input","malli.core/invalid-input",2010057279);$APP.$cljs$cst$2588$container$$=new $APP.$cljs$core$Keyword$$(null,"container","container",-1736937707);
$APP.$cljs$cst$3361$app_DOT_main_DOT_data_DOT_auth_SLASH_create_demo_profile$$=new $APP.$cljs$core$Keyword$$("app.main.data.auth","create-demo-profile","app.main.data.auth/create-demo-profile",1415198086);$APP.$cljs$cst$4868$toggle_lock$$=new $APP.$cljs$core$Keyword$$(null,"toggle-lock","toggle-lock",-266873991);
$cljs$cst$4694$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_path$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","toggle-token-path","app.main.data.workspace.tokens.library-edit/toggle-token-path",-1177603494);$cljs$cst$1075$cljs_DOT_spec_DOT_alpha_SLASH_cpred$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","cpred","cljs.spec.alpha/cpred",-693471218);
$cljs$cst$4035$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_apply_typography$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","apply-typography","app.main.data.workspace.texts/apply-typography",1717453619);$cljs$cst$1955$out$$=new $APP.$cljs$core$Keyword$$(null,"out","out",-910545517);$cljs$cst$3780$root_shape$$=new $APP.$cljs$core$Keyword$$(null,"root-shape","root-shape",1863248774);$cljs$cst$2793$pointsAtY$$=new $APP.$cljs$core$Keyword$$(null,"pointsAtY","pointsAtY",1796506952);
$cljs$cst$3021$greek$$=new $APP.$cljs$core$Keyword$$(null,"greek","greek",-21364933);$cljs$cst$2871$pointsAtX$$=new $APP.$cljs$core$Keyword$$(null,"pointsAtX","pointsAtX",-1688251623);$APP.$cljs$cst$3057$grid_cells$$=new $APP.$cljs$core$Keyword$$(null,"grid-cells","grid-cells",-486475418);$cljs$cst$2768$pointsAtZ$$=new $APP.$cljs$core$Keyword$$(null,"pointsAtZ","pointsAtZ",-1238005533);$cljs$cst$4326$active$$=new $APP.$cljs$core$Keyword$$(null,"active","active",1895962068);
$cljs$cst$378$malli_DOT_core_SLASH_lazy_entries$$=new $APP.$cljs$core$Keyword$$("malli.core","lazy-entries","malli.core/lazy-entries",762112361);$cljs$cst$2827$unicode_range$$=new $APP.$cljs$core$Keyword$$(null,"unicode-range","unicode-range",-2014392944);$cljs$cst$4799$open_comments$$=new $APP.$cljs$core$Keyword$$(null,"open-comments","open-comments",-198204701);
$APP.$cljs$cst$5240$app_DOT_main_DOT_data_DOT_viewer_SLASH_apply_changes_viewer$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","apply-changes-viewer","app.main.data.viewer/apply-changes-viewer",-49291536);$APP.$cljs$cst$4030$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_commit_position_data$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","commit-position-data","app.main.data.workspace.texts/commit-position-data",1056332356);
$cljs$cst$3030$paragraph$$=new $APP.$cljs$core$Keyword$$(null,"paragraph","paragraph",296707709);$cljs$cst$2143$app_DOT_main_DOT_data_DOT_websocket_SLASH_send_message$$=new $APP.$cljs$core$Keyword$$("app.main.data.websocket","send-message","app.main.data.websocket/send-message",1713313880);$cljs$cst$452$malli_DOT_core_SLASH_extra_key$$=new $APP.$cljs$core$Keyword$$("malli.core","extra-key","malli.core/extra-key",574816512);
$cljs$cst$1778$geometry_child$$=new $APP.$cljs$core$Keyword$$(null,"geometry-child","geometry-child",2018812678);$APP.$cljs$cst$4670$tokens_SLASH_sizing$$=new $APP.$cljs$core$Keyword$$("tokens","sizing","tokens/sizing",1684518093);$cljs$cst$4381$updated_ids$$=new $APP.$cljs$core$Keyword$$(null,"updated-ids","updated-ids",554327170);$cljs$cst$382$leave$$=new $APP.$cljs$core$Keyword$$(null,"leave","leave",1022579443);
$cljs$cst$4337$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_update_mcp_plugin_connection$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.mcp","update-mcp-plugin-connection","app.main.data.workspace.mcp/update-mcp-plugin-connection",-1306883614);$cljs$cst$2686$transparent$$=new $APP.$cljs$core$Keyword$$(null,"transparent","transparent",-2073609949);$cljs$cst$3840$transforms$$=new $APP.$cljs$core$Keyword$$(null,"transforms","transforms",793344554);
$cljs$cst$2268$stream_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"stream?","stream?",-1451356708);$APP.$cljs$cst$1582$omit_default_headers$$=new $APP.$cljs$core$Keyword$$(null,"omit-default-headers","omit-default-headers",-2108409502);$cljs$cst$5224$general_dashboard$$=new $APP.$cljs$core$Keyword$$(null,"general-dashboard","general-dashboard",1757742988);$cljs$cst$1494$if_not$$=new $APP.$cljs$core$Symbol$$(null,"if-not","if-not",-265415609,null);
$APP.$cljs$cst$4735$placement$$=new $APP.$cljs$core$Keyword$$(null,"placement","placement",768366651);$APP.$cljs$cst$4723$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_show_token_node_context_menu$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","show-token-node-context-menu","app.main.data.workspace.tokens.library-edit/show-token-node-context-menu",-627556815);
$cljs$cst$3782$is_hidden$$=new $APP.$cljs$core$Keyword$$(null,"is-hidden","is-hidden",1850308789);$APP.$cljs$cst$3256$organization_id$$=new $APP.$cljs$core$Keyword$$(null,"organization-id","organization-id",-501672147);$cljs$cst$2080$modifiable_group$$=new $APP.$cljs$core$Keyword$$(null,"modifiable-group","modifiable-group",131767925);$cljs$cst$567$malli_DOT_core_SLASH_explain_output$$=new $APP.$cljs$core$Keyword$$("malli.core","explain-output","malli.core/explain-output",-124321573);
$cljs$cst$3873$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_reorder_layout_child$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","reorder-layout-child","app.main.data.workspace.transforms/reorder-layout-child",-752044762);$cljs$cst$5206$variant_not_main$$=new $APP.$cljs$core$Keyword$$(null,"variant-not-main","variant-not-main",-1470670810);
$cljs$cst$3407$app_DOT_main_DOT_data_DOT_plugins_SLASH_check_open_plugin$$=new $APP.$cljs$core$Keyword$$("app.main.data.plugins","check-open-plugin","app.main.data.plugins/check-open-plugin",-1802413529);$APP.$cljs$cst$200$vector$$=new $APP.$cljs$core$Keyword$$(null,"vector","vector",1902966158);$APP.$cljs$cst$837$trial$$=new $APP.$cljs$core$Keyword$$(null,"trial","trial",-677458347);
$APP.$cljs$cst$5023$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_fetch_versions$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","fetch-versions","app.main.data.workspace.versions/fetch-versions",575668956);$APP.$cljs$cst$2950$shortcuts$$=new $APP.$cljs$core$Keyword$$(null,"shortcuts","shortcuts",1717107810);$APP.$cljs$cst$3540$local_change_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"local-change?","local-change?",619740746);
$cljs$cst$3621$is_external_library$$=new $APP.$cljs$core$Keyword$$(null,"is-external-library","is-external-library",-1562006393);$cljs$cst$2925$stroke_miterlimit$$=new $APP.$cljs$core$Keyword$$(null,"stroke-miterlimit","stroke-miterlimit",1151270808);$APP.$cljs$cst$3590$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_handle_area_selection$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","handle-area-selection","app.main.data.workspace.selection/handle-area-selection",1531956952);
$cljs$cst$5007$v_dir$$=new $APP.$cljs$core$Keyword$$(null,"v-dir","v-dir",395606617);$cljs$cst$2934$enable_background$$=new $APP.$cljs$core$Keyword$$(null,"enable-background","enable-background",-858721379);$cljs$cst$3787$time$$=new $APP.$cljs$core$Keyword$$(null,"time","time",1385887882);$cljs$cst$4476$app_DOT_main_DOT_data_DOT_workspace_SLASH_end_rename_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","end-rename-shape","app.main.data.workspace/end-rename-shape",1266093757);
$APP.$cljs$cst$3895$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","finalize","app.main.data.workspace/finalize",-1506426600);$cljs$cst$2778$maskContentUnits$$=new $APP.$cljs$core$Keyword$$(null,"maskContentUnits","maskContentUnits",-2073756924);$APP.$cljs$cst$3539$copy_touched_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"copy-touched?","copy-touched?",-1498392371);
$cljs$cst$967$strict$$=new $APP.$cljs$core$Keyword$$(null,"strict","strict",-665564191);$APP.$cljs$cst$4511$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_grid_cell_context_menu$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","show-grid-cell-context-menu","app.main.data.workspace/show-grid-cell-context-menu",269559320);$cljs$cst$2049$locked$$=new $APP.$cljs$core$Keyword$$(null,"locked","locked",-1658763820);
$APP.$cljs$cst$4022$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_event$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","resize-text-debounce-event","app.main.data.workspace.texts/resize-text-debounce-event",-892444927);$cljs$cst$4488$app_DOT_main_DOT_data_DOT_workspace_SLASH_align_objects$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","align-objects","app.main.data.workspace/align-objects",2022797753);
$cljs$cst$438$orn$$=new $APP.$cljs$core$Keyword$$(null,"orn","orn",738436484);$APP.$cljs$cst$4711$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_drop_error$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","drop-error","app.main.data.workspace.tokens.library-edit/drop-error",-1605070531);$APP.$cljs$cst$3516$get_project_files$$=new $APP.$cljs$core$Keyword$$(null,"get-project-files","get-project-files",1403433285);
$APP.$cljs$cst$993$opt$$=new $APP.$cljs$core$Keyword$$(null,"opt","opt",-794706369);$cljs$cst$4113$prev_id$$=new $APP.$cljs$core$Keyword$$(null,"prev-id","prev-id",1028193202);$APP.$cljs$cst$2466$app_DOT_main_DOT_data_DOT_common_SLASH_create_share_link$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","create-share-link","app.main.data.common/create-share-link",-190094570);$APP.$cljs$cst$3104$wasm$$=new $APP.$cljs$core$Keyword$$(null,"wasm","wasm",-969992002);
$cljs$cst$4968$app_DOT_main_DOT_data_DOT_dashboard_SLASH_create_element$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","create-element","app.main.data.dashboard/create-element",-2119035296);$APP.$cljs$cst$4034$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_all_attrs$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","update-all-attrs","app.main.data.workspace.texts/update-all-attrs",-900372683);
$cljs$cst$1471$last$$=new $APP.$cljs$core$Keyword$$(null,"last","last",1105735132);$cljs$cst$4083$grid_row$$=new $APP.$cljs$core$Keyword$$(null,"grid-row","grid-row",-1737175087);$cljs$cst$695$char_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"char?","char?",-1072221244,null);$cljs$cst$4064$min_block_size$$=new $APP.$cljs$core$Keyword$$(null,"min-block-size","min-block-size",2039624084);$cljs$cst$2290$browser_version$$=new $APP.$cljs$core$Keyword$$(null,"browser-version","browser-version",148347308);
$cljs$cst$343$lazy$$=new $APP.$cljs$core$Keyword$$(null,"lazy","lazy",-424547181);$APP.$cljs$cst$2217$read_only_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"read-only?","read-only?",-770285386);$APP.$cljs$cst$3116$initialize_indices$$=new $APP.$cljs$core$Keyword$$(null,"initialize-indices","initialize-indices",241528700);$cljs$cst$1267$enable_feature_render_wasm$$=new $APP.$cljs$core$Keyword$$(null,"enable-feature-render-wasm","enable-feature-render-wasm",-174378963);
$cljs$cst$1485$deref$$=new $APP.$cljs$core$Keyword$$(null,"deref","deref",-145586795);$cljs$cst$3042$fillOpacity$$=new $APP.$cljs$core$Keyword$$(null,"fillOpacity","fillOpacity",619211981);$cljs$cst$1454$max_iterations$$=new $APP.$cljs$core$Keyword$$(null,"max-iterations","max-iterations",2021275563);$APP.$cljs$cst$2025$difference$$=new $APP.$cljs$core$Keyword$$(null,"difference","difference",1916101396);
$cljs$cst$3579$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_increase_zoom$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.zoom","increase-zoom","app.main.data.workspace.zoom/increase-zoom",-572099255);$cljs$cst$3509$app_DOT_main_DOT_data_DOT_project_SLASH_project_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.project","project-fetched","app.main.data.project/project-fetched",-1022027404);
$APP.$cljs$cst$5051$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_create_version_from_plugins$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","create-version-from-plugins","app.main.data.workspace.versions/create-version-from-plugins",1775351294);$APP.$cljs$cst$4674$tokens_SLASH_rotation$$=new $APP.$cljs$core$Keyword$$("tokens","rotation","tokens/rotation",-717190454);
$cljs$cst$2906$glyph_orientation_horizontal$$=new $APP.$cljs$core$Keyword$$(null,"glyph-orientation-horizontal","glyph-orientation-horizontal",436217892);$APP.$cljs$cst$2136$process_token_type$$=new $APP.$cljs$core$Keyword$$(null,"process-token-type","process-token-type",1139715555);$cljs$cst$2864$systemLanguage$$=new $APP.$cljs$core$Keyword$$(null,"systemLanguage","systemLanguage",-1820848040);$APP.$cljs$cst$1811$shape$$=new $APP.$cljs$core$Keyword$$(null,"shape","shape",1190694006);
$APP.$cljs$cst$1964$offset_effect$$=new $APP.$cljs$core$Keyword$$(null,"offset-effect","offset-effect",1997999208);$cljs$cst$4210$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_add_undo_entry$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.undo","add-undo-entry","app.main.data.workspace.path.undo/add-undo-entry",-1324903380);$APP.$cljs$cst$2357$links$$=new $APP.$cljs$core$Keyword$$(null,"links","links",-654507394);
$APP.$cljs$cst$3244$app_DOT_main_DOT_data_DOT_profile_SLASH_recover_profile$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","recover-profile","app.main.data.profile/recover-profile",1151588383);$APP.$cljs$cst$5040$unlock_file_snapshot$$=new $APP.$cljs$core$Keyword$$(null,"unlock-file-snapshot","unlock-file-snapshot",1862162537);$cljs$cst$2081$grids_group$$=new $APP.$cljs$core$Keyword$$(null,"grids-group","grids-group",1826235940);
$APP.$cljs$cst$2314$performance_info$$=new $APP.$cljs$core$Keyword$$(null,"performance-info","performance-info",-492900708);$APP.$cljs$cst$2507$app_DOT_main_DOT_data_DOT_common_SLASH_clear_progress$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","clear-progress","app.main.data.common/clear-progress",910980633);
$APP.$cljs$cst$4006$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_initialize_editor_state$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","initialize-editor-state","app.main.data.workspace.texts/initialize-editor-state",387679718);$cljs$cst$1216$rpc_rlimit$$=new $APP.$cljs$core$Keyword$$(null,"rpc-rlimit","rpc-rlimit",-1693595314);$APP.$cljs$cst$5245$users$$=new $APP.$cljs$core$Keyword$$(null,"users","users",-713552705);
$cljs$cst$5110$avatar$$=new $APP.$cljs$core$Keyword$$(null,"avatar","avatar",-1607499307);$APP.$cljs$cst$3169$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_file_data$$=new $APP.$cljs$core$Keyword$$("app.common.files.changes-builder","file-data","app.common.files.changes-builder/file-data",-1399858875);$cljs$cst$1568$max_age$$=new $APP.$cljs$core$Keyword$$(null,"max-age","max-age",-270129271);
$cljs$cst$2640$del_typography$$=new $APP.$cljs$core$Keyword$$(null,"del-typography","del-typography",553672868);$cljs$cst$663$any_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"any?","any?",-318999933,null);$APP.$cljs$cst$198$string$$=new $APP.$cljs$core$Keyword$$(null,"string","string",-1989541586);
$cljs$cst$3736$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_remove_layout_flag$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.layout","remove-layout-flag","app.main.data.workspace.layout/remove-layout-flag",-513988996);$cljs$cst$2065$geometry_group$$=new $APP.$cljs$core$Keyword$$(null,"geometry-group","geometry-group",801077954);
$APP.$cljs$cst$4254$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_start_move_path_point$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.edition","start-move-path-point","app.main.data.workspace.path.edition/start-move-path-point",1051432604);$cljs$cst$1181$log_emails$$=new $APP.$cljs$core$Keyword$$(null,"log-emails","log-emails",1044224684);$cljs$cst$4359$leave_file$$=new $APP.$cljs$core$Keyword$$(null,"leave-file","leave-file",1593548461);
$APP.$cljs$cst$4518$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_paddings_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","set-paddings-selected","app.main.data.workspace/set-paddings-selected",868339237);$APP.$cljs$cst$269$cljs_DOT_analyzer_SLASH_no_resolve$$=new $APP.$cljs$core$Keyword$$("cljs.analyzer","no-resolve","cljs.analyzer/no-resolve",-1872351017);
$APP.$cljs$cst$3309$delete_team_invitation$$=new $APP.$cljs$core$Keyword$$(null,"delete-team-invitation","delete-team-invitation",602824509);$cljs$cst$2806$markerHeight$$=new $APP.$cljs$core$Keyword$$(null,"markerHeight","markerHeight",-1744163958);$cljs$cst$3051$end_offset$$=new $APP.$cljs$core$Keyword$$(null,"end-offset","end-offset",-1290057545);$cljs$cst$1098$cljs_DOT_spec_DOT_alpha_SLASH_nil$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","nil","cljs.spec.alpha/nil",1733813950);
$cljs$cst$3174$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_index$$=new $APP.$cljs$core$Keyword$$("app.common.files.changes-builder","index","app.common.files.changes-builder/index",1293712905);$APP.$cljs$cst$3935$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_detach_components$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","detach-components","app.main.data.workspace.libraries/detach-components",-1294365757);
$cljs$cst$295$malli_DOT_core_SLASH_invalid$$=new $APP.$cljs$core$Keyword$$("malli.core","invalid","malli.core/invalid",362080900);$APP.$cljs$cst$4494$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_assets_section_open$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","set-assets-section-open","app.main.data.workspace/set-assets-section-open",286343660);$APP.$cljs$cst$582$input$$=new $APP.$cljs$core$Symbol$$(null,"input","input",-2097503808,null);
$cljs$cst$4361$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_file_deleted$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.notifications","handle-file-deleted","app.main.data.workspace.notifications/handle-file-deleted",152988797);$cljs$cst$3400$allow_background$$=new $APP.$cljs$core$Keyword$$(null,"allow-background","allow-background",-39749118);$APP.$cljs$cst$1986$max_height$$=new $APP.$cljs$core$Keyword$$(null,"max-height","max-height",-612563804);
$cljs$cst$3269$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_invitations$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","fetch-invitations","app.main.data.team/fetch-invitations",513994382);$cljs$cst$1165$app_DOT_common_DOT_logging_SLASH_cause$$=new $APP.$cljs$core$Keyword$$("app.common.logging","cause","app.common.logging/cause",-1908169987);
$cljs$cst$4277$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_update_comment_thread_position$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.comments","update-comment-thread-position","app.main.data.workspace.comments/update-comment-thread-position",-88675764);$cljs$cst$159$deftype_STAR_$$=new $APP.$cljs$core$Symbol$$(null,"deftype*","deftype*",962659890,null);$APP.$cljs$cst$4199$old_content$$=new $APP.$cljs$core$Keyword$$(null,"old-content","old-content",1851086779);
$APP.$cljs$cst$6373$settings_password$$=new $APP.$cljs$core$Keyword$$(null,"settings-password","settings-password",-1747755582);$APP.$cljs$cst$4274$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_handle_interrupt$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.comments","handle-interrupt","app.main.data.workspace.comments/handle-interrupt",-1367914269);$APP.$cljs$cst$4903$is_pinned$$=new $APP.$cljs$core$Keyword$$(null,"is-pinned","is-pinned",620920978);
$APP.$cljs$cst$5382$auth_recovery_request$$=new $APP.$cljs$core$Keyword$$(null,"auth-recovery-request","auth-recovery-request",206791454);$cljs$cst$4761$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_initialize_export_status$$=new $APP.$cljs$core$Keyword$$("app.main.data.exports.assets","initialize-export-status","app.main.data.exports.assets/initialize-export-status",232156249);
$cljs$cst$4715$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_create_token$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","create-token","app.main.data.workspace.tokens.library-edit/create-token",486532545);$APP.$cljs$cst$1868$stroke_alignment$$=new $APP.$cljs$core$Keyword$$(null,"stroke-alignment","stroke-alignment",465679340);
$APP.$cljs$cst$5039$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_unlock_version$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","unlock-version","app.main.data.workspace.versions/unlock-version",-689564215);$cljs$cst$2247$service_unavailable$$=new $APP.$cljs$core$Keyword$$(null,"service-unavailable","service-unavailable",751643155);$cljs$cst$2831$markerUnits$$=new $APP.$cljs$core$Keyword$$(null,"markerUnits","markerUnits",-440662863);
$APP.$cljs$cst$3875$nudge$$=new $APP.$cljs$core$Keyword$$(null,"nudge","nudge",-715499585);$cljs$cst$2938$htmlFor$$=new $APP.$cljs$core$Keyword$$(null,"htmlFor","htmlFor",-1050291720);$APP.$cljs$cst$342$children$$=new $APP.$cljs$core$Keyword$$(null,"children","children",-940561982);$cljs$cst$676$string_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"string?","string?",-1129175764,null);
$cljs$cst$1188$backend_openapi_doc$$=new $APP.$cljs$core$Keyword$$(null,"backend-openapi-doc","backend-openapi-doc",521885792);$APP.$cljs$cst$1669$stretch$$=new $APP.$cljs$core$Keyword$$(null,"stretch","stretch",-1888837380);$APP.$cljs$cst$3060$layout_drop_zones$$=new $APP.$cljs$core$Keyword$$(null,"layout-drop-zones","layout-drop-zones",-665395958);
$cljs$cst$851$malli_DOT_generator_SLASH_original_generator_schema$$=new $APP.$cljs$core$Keyword$$("malli.generator","original-generator-schema","malli.generator/original-generator-schema",-1122475395);$cljs$cst$4647$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_token$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","apply-token","app.main.data.workspace.tokens.application/apply-token",-1326070806);
$cljs$cst$3684$app_DOT_main_DOT_data_DOT_workspace_DOT_svg_upload_SLASH_add_svg_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.svg-upload","add-svg-shapes","app.main.data.workspace.svg-upload/add-svg-shapes",-1959694469);$APP.$cljs$cst$5274$app_DOT_main_DOT_data_DOT_viewer_SLASH_reset_nav_scroll$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","reset-nav-scroll","app.main.data.viewer/reset-nav-scroll",428495406);
$cljs$cst$2902$fill_rule$$=new $APP.$cljs$core$Keyword$$(null,"fill-rule","fill-rule",-1824841598);$APP.$cljs$cst$3589$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_update_selrect$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","update-selrect","app.main.data.workspace.selection/update-selrect",1920460791);$APP.$cljs$cst$3111$sender_id$$=new $APP.$cljs$core$Keyword$$(null,"sender-id","sender-id",-1032660135);
$APP.$cljs$cst$3406$app_DOT_main_DOT_data_DOT_plugins_SLASH_open_plugin$$=new $APP.$cljs$core$Keyword$$("app.main.data.plugins","open-plugin","app.main.data.plugins/open-plugin",77806160);$cljs$cst$1168$login_with_password$$=new $APP.$cljs$core$Keyword$$(null,"login-with-password","login-with-password",-305903165);$APP.$cljs$cst$3721$lock_guides$$=new $APP.$cljs$core$Keyword$$(null,"lock-guides","lock-guides",511855144);
$APP.$cljs$cst$3428$count_unread_comments$$=new $APP.$cljs$core$Keyword$$(null,"count-unread-comments","count-unread-comments",1085002472);$cljs$cst$2815$orient$$=new $APP.$cljs$core$Keyword$$(null,"orient","orient",1933743565);$cljs$cst$5099$caution$$=new $APP.$cljs$core$Keyword$$(null,"caution","caution",1823615934);$cljs$cst$3641$skip_edition_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"skip-edition?","skip-edition?",2067795141);
$APP.$cljs$cst$4812$toggle_snap_ruler_guide$$=new $APP.$cljs$core$Keyword$$(null,"toggle-snap-ruler-guide","toggle-snap-ruler-guide",-1040178651);$cljs$cst$4209$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_merge_head$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.undo","merge-head","app.main.data.workspace.path.undo/merge-head",703788867);$cljs$cst$916$decoders$$=new $APP.$cljs$core$Keyword$$(null,"decoders","decoders",1132818244);
$cljs$cst$3678$strokeCapEnd$$=new $APP.$cljs$core$Keyword$$(null,"strokeCapEnd","strokeCapEnd",-120833567);$APP.$cljs$cst$499$enum$$=new $APP.$cljs$core$Keyword$$(null,"enum","enum",1679018432);$APP.$cljs$cst$2041$inner$$=new $APP.$cljs$core$Keyword$$(null,"inner","inner",-1383171215);
$cljs$cst$4609$warning_DOT_style_dictionary_SLASH_invalid_referenced_token_value_stroke_width$$=new $APP.$cljs$core$Keyword$$("warning.style-dictionary","invalid-referenced-token-value-stroke-width","warning.style-dictionary/invalid-referenced-token-value-stroke-width",1689441159);
$cljs$cst$3855$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_finish_transform$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","finish-transform","app.main.data.workspace.transforms/finish-transform",-1801177009);$APP.$cljs$cst$1583$credentials$$=new $APP.$cljs$core$Keyword$$(null,"credentials","credentials",1373178854);$APP.$cljs$cst$3902$rename_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"rename?","rename?",-1728043099);
$APP.$cljs$cst$3230$onboarding_questions_answered$$=new $APP.$cljs$core$Keyword$$(null,"onboarding-questions-answered","onboarding-questions-answered",1395823145);$APP.$cljs$cst$5030$update_file_snapshot$$=new $APP.$cljs$core$Keyword$$(null,"update-file-snapshot","update-file-snapshot",149964604);$APP.$cljs$cst$2289$version$$=new $APP.$cljs$core$Keyword$$(null,"version","version",425292698);$cljs$cst$995$opt_un$$=new $APP.$cljs$core$Keyword$$(null,"opt-un","opt-un",883442496);
$APP.$cljs$cst$3801$line_width$$=new $APP.$cljs$core$Keyword$$(null,"line-width","line-width",-906934988);$APP.$cljs$cst$738$fragment$$=new $APP.$cljs$core$Keyword$$(null,"fragment","fragment",826775688);$cljs$cst$991$cljs_DOT_spec_DOT_alpha_SLASH_keys$$=new $APP.$cljs$core$Symbol$$("cljs.spec.alpha","keys","cljs.spec.alpha/keys",1109346032,null);$cljs$cst$1839$uniqueItems$$=new $APP.$cljs$core$Keyword$$(null,"uniqueItems","uniqueItems",-826722268);
$cljs$cst$2142$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_pointer_send$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.notifications","handle-pointer-send","app.main.data.workspace.notifications/handle-pointer-send",-1463250994);$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$=new $APP.$cljs$core$Keyword$$("app.common.schema","uuid","app.common.schema/uuid",-451405422);
$cljs$cst$5203$not_a_variant$$=new $APP.$cljs$core$Keyword$$(null,"not-a-variant","not-a-variant",596614706);$APP.$cljs$cst$1417$circle$$=new $APP.$cljs$core$Keyword$$(null,"circle","circle",1903212362);$APP.$cljs$cst$5050$get_file_snapshot$$=new $APP.$cljs$core$Keyword$$(null,"get-file-snapshot","get-file-snapshot",1161048335);
$APP.$cljs$cst$3255$app_DOT_main_DOT_data_DOT_team_SLASH_teams_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","teams-fetched","app.main.data.team/teams-fetched",1747661254);$APP.$cljs$cst$1696$layout_grid_cells$$=new $APP.$cljs$core$Keyword$$(null,"layout-grid-cells","layout-grid-cells",2100726187);
$cljs$cst$2529$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_settings$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","go-to-dashboard-settings","app.main.data.common/go-to-dashboard-settings",-658677935);$cljs$cst$3571$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_check_open_transactions$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.undo","check-open-transactions","app.main.data.workspace.undo/check-open-transactions",-815936958);
$cljs$cst$3651$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shape_flags$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","update-shape-flags","app.main.data.workspace.shapes/update-shape-flags",89719760);$cljs$cst$2583$app_DOT_common_DOT_types_DOT_file_SLASH_typographies$$=new $APP.$cljs$core$Keyword$$("app.common.types.file","typographies","app.common.types.file/typographies",313227253);
$APP.$cljs$cst$3821$ignore_constraints$$=new $APP.$cljs$core$Keyword$$(null,"ignore-constraints","ignore-constraints",-1221464851);$APP.$cljs$cst$5393$auth_register_success$$=new $APP.$cljs$core$Keyword$$(null,"auth-register-success","auth-register-success",-965924859);$APP.$cljs$cst$2665$not_found$$=new $APP.$cljs$core$Keyword$$(null,"not-found","not-found",-629079980);$cljs$cst$3833$ignore_snap_pixel$$=new $APP.$cljs$core$Keyword$$(null,"ignore-snap-pixel","ignore-snap-pixel",1451661032);
$APP.$cljs$cst$1875$hide_in_viewer$$=new $APP.$cljs$core$Keyword$$(null,"hide-in-viewer","hide-in-viewer",1478442312);$APP.$cljs$cst$4843$select_all$$=new $APP.$cljs$core$Keyword$$(null,"select-all","select-all",-1382041584);$cljs$cst$535$malli_DOT_core_SLASH_walked_refs$$=new $APP.$cljs$core$Keyword$$("malli.core","walked-refs","malli.core/walked-refs",-2010140962);$cljs$cst$2823$contentStyleType$$=new $APP.$cljs$core$Keyword$$(null,"contentStyleType","contentStyleType",-224655281);
$APP.$cljs$cst$3061$parent_bounds$$=new $APP.$cljs$core$Keyword$$(null,"parent-bounds","parent-bounds",-168980852);$cljs$cst$3470$app_DOT_main_DOT_data_DOT_comments_SLASH_close_comment_thread$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","close-comment-thread","app.main.data.comments/close-comment-thread",509630048);$cljs$cst$1412$buffer_block$$=new $APP.$cljs$core$Keyword$$(null,"buffer-block","buffer-block",-10937307);
$cljs$cst$1167$app_DOT_common_DOT_logging_SLASH_default$$=new $APP.$cljs$core$Keyword$$("app.common.logging","default","app.common.logging/default",993090353);$cljs$cst$2097$clojure_DOT_datafy_SLASH_obj$$=new $APP.$cljs$core$Keyword$$("clojure.datafy","obj","clojure.datafy/obj",-330079421);$cljs$cst$3988$get_library_usage$$=new $APP.$cljs$core$Keyword$$(null,"get-library-usage","get-library-usage",-1890750106);$APP.$cljs$cst$5019$loading$$=new $APP.$cljs$core$Keyword$$(null,"loading","loading",-737050189);
$APP.$cljs$cst$5317$move_nodes$$=new $APP.$cljs$core$Keyword$$(null,"move-nodes","move-nodes",-633826850);$APP.$cljs$cst$2310$app_DOT_main_DOT_data_DOT_event_SLASH_type$$=new $APP.$cljs$core$Keyword$$("app.main.data.event","type","app.main.data.event/type",-599808406);$APP.$cljs$cst$4352$topic$$=new $APP.$cljs$core$Keyword$$(null,"topic","topic",-1960480691);$APP.$cljs$cst$2620$add_page$$=new $APP.$cljs$core$Keyword$$(null,"add-page","add-page",304111762);
$cljs$cst$5350$import_progress$$=new $APP.$cljs$core$Keyword$$(null,"import-progress","import-progress",-1408128405);$cljs$cst$5379$wrong_credentials$$=new $APP.$cljs$core$Keyword$$(null,"wrong-credentials","wrong-credentials",2055788730);$cljs$cst$252$queue$$=new $APP.$cljs$core$Symbol$$(null,"queue","queue",-1198599890,null);$cljs$cst$4353$connect$$=new $APP.$cljs$core$Keyword$$(null,"connect","connect",1232828233);
$APP.$cljs$cst$4304$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_rename_flow$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","rename-flow","app.main.data.workspace.interactions/rename-flow",423387319);$cljs$cst$5331$app_DOT_util_DOT_code_highlight_SLASH_highlight_BANG_$$=new $APP.$cljs$core$Symbol$$("app.util.code-highlight","highlight!","app.util.code-highlight/highlight!",-728712751,null);
$APP.$cljs$cst$1961$easing$$=new $APP.$cljs$core$Keyword$$(null,"easing","easing",735372043);$cljs$cst$3431$mentions$$=new $APP.$cljs$core$Keyword$$(null,"mentions","mentions",-1355741087);$cljs$cst$1242$prepl_server$$=new $APP.$cljs$core$Keyword$$(null,"prepl-server","prepl-server",-942717220);$cljs$cst$2568$missing_features_in_paste_content$$=new $APP.$cljs$core$Keyword$$(null,"missing-features-in-paste-content","missing-features-in-paste-content",1178098165);
$cljs$cst$5155$webhook_validation$$=new $APP.$cljs$core$Keyword$$(null,"webhook-validation","webhook-validation",-1228580175);$APP.$cljs$cst$2114$new_editing_set_path$$=new $APP.$cljs$core$Keyword$$(null,"new-editing-set-path","new-editing-set-path",1502705622);$cljs$cst$1367$start_col$$=new $APP.$cljs$core$Keyword$$(null,"start-col","start-col",668080143);$APP.$cljs$cst$3844$delta_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"delta?","delta?",-1801433442);
$APP.$cljs$cst$2227$plugins_permissions_peek$$=new $APP.$cljs$core$Keyword$$(null,"plugins-permissions-peek","plugins-permissions-peek",1646727084);$cljs$cst$5165$duplicated_children$$=new $APP.$cljs$core$Keyword$$(null,"duplicated-children","duplicated-children",-504084340);$APP.$cljs$cst$3665$column_total_gap$$=new $APP.$cljs$core$Keyword$$(null,"column-total-gap","column-total-gap",1781452557);$APP.$cljs$cst$4866$unmask$$=new $APP.$cljs$core$Keyword$$(null,"unmask","unmask",-978841832);
$cljs$cst$2$meta$$=new $APP.$cljs$core$Keyword$$(null,"meta","meta",1499536964);$cljs$cst$856$malli_DOT_generator_SLASH_invalid_property$$=new $APP.$cljs$core$Keyword$$("malli.generator","invalid-property","malli.generator/invalid-property",-418941875);$APP.$cljs$cst$2481$binfile_v1$$=new $APP.$cljs$core$Keyword$$(null,"binfile-v1","binfile-v1",1008484704);$cljs$cst$2662$fix_not_implemented$$=new $APP.$cljs$core$Keyword$$(null,"fix-not-implemented","fix-not-implemented",1978248380);
$APP.$cljs$cst$4832$bool_difference$$=new $APP.$cljs$core$Keyword$$(null,"bool-difference","bool-difference",1638220619);$APP.$cljs$cst$2483$binfile_v3$$=new $APP.$cljs$core$Keyword$$(null,"binfile-v3","binfile-v3",-2038359825);$cljs$cst$3852$index_SLASH_query_snap_xy$$=new $APP.$cljs$core$Keyword$$("index","query-snap-xy","index/query-snap-xy",737924586);$APP.$cljs$cst$3218$update_profile_password$$=new $APP.$cljs$core$Keyword$$(null,"update-profile-password","update-profile-password",-979479751);
$cljs$cst$2186$render_state$$=new $APP.$cljs$core$Keyword$$(null,"render-state","render-state",2053902270);$APP.$cljs$cst$4235$hover_points$$=new $APP.$cljs$core$Keyword$$(null,"hover-points","hover-points",-372943198);$cljs$cst$3964$sync_dialog$$=new $APP.$cljs$core$Keyword$$(null,"sync-dialog","sync-dialog",918022418);$cljs$cst$1182$email_whitelist$$=new $APP.$cljs$core$Keyword$$(null,"email-whitelist","email-whitelist",-418961261);
$APP.$cljs$cst$1909$horizontal$$=new $APP.$cljs$core$Keyword$$(null,"horizontal","horizontal",2062109475);$cljs$cst$3248$get_access_tokens$$=new $APP.$cljs$core$Keyword$$(null,"get-access-tokens","get-access-tokens",2009261502);$cljs$cst$4780$font_size_dec$$=new $APP.$cljs$core$Keyword$$(null,"font-size-dec","font-size-dec",-1007348714);$cljs$cst$3785$exact$$=new $APP.$cljs$core$Keyword$$(null,"exact","exact",1438022323);
$APP.$cljs$cst$4107$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_css$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","copy-selected-css","app.main.data.workspace.clipboard/copy-selected-css",1504637036);$APP.$cljs$cst$3391$throw_validation_errors$$=new $APP.$cljs$core$Keyword$$(null,"throw-validation-errors","throw-validation-errors",1088706153);$cljs$cst$2275$raw_transit_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"raw-transit?","raw-transit?",1086268953);
$APP.$cljs$cst$2534$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$=new $APP.$cljs$core$Keyword$$("app.main.data.persistence","force-persist","app.main.data.persistence/force-persist",-1937686199);$cljs$cst$4786$text_editor$$=new $APP.$cljs$core$Keyword$$(null,"text-editor","text-editor",-767771325);$cljs$cst$2839$glyph_name$$=new $APP.$cljs$core$Keyword$$(null,"glyph-name","glyph-name",-1290126189);
$cljs$cst$2722$feDiffuseLighting$$=new $APP.$cljs$core$Keyword$$(null,"feDiffuseLighting","feDiffuseLighting",743368050);$APP.$cljs$cst$5610$unpublish$$=new $APP.$cljs$core$Keyword$$(null,"unpublish","unpublish",-1397708862);$cljs$cst$150$defrecord_STAR_$$=new $APP.$cljs$core$Symbol$$(null,"defrecord*","defrecord*",-1936366207,null);
$APP.$cljs$cst$3229$app_DOT_main_DOT_data_DOT_profile_SLASH_mark_questions_as_answered$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","mark-questions-as-answered","app.main.data.profile/mark-questions-as-answered",328106487);$APP.$cljs$cst$4031$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","update-position-data","app.main.data.workspace.texts/update-position-data",1071451524);
$cljs$cst$491$unparse$$=new $APP.$cljs$core$Keyword$$(null,"unparse","unparse",-1504915552);$APP.$cljs$cst$4005$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_finalize_editor_state$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","finalize-editor-state","app.main.data.workspace.texts/finalize-editor-state",-201608113);$cljs$cst$1019$opt_specs$$=new $APP.$cljs$core$Keyword$$(null,"opt-specs","opt-specs",-384905450);
$cljs$cst$3007$gujarati$$=new $APP.$cljs$core$Keyword$$(null,"gujarati","gujarati",722386737);$cljs$cst$577$arities$$=new $APP.$cljs$core$Keyword$$(null,"arities","arities",-1781122917);$APP.$cljs$cst$839$depth$$=new $APP.$cljs$core$Keyword$$(null,"depth","depth",1768663640);$cljs$cst$1441$commachar$$=new $APP.$cljs$core$Keyword$$(null,"commachar","commachar",652859327);
$APP.$cljs$cst$3889$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_resize_text_editor$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","resize-text-editor","app.main.data.workspace.transforms/resize-text-editor",-2053748947);$cljs$cst$4074$size_array$$=new $APP.$cljs$core$Keyword$$(null,"size-array","size-array",-1012282519);
$APP.$cljs$cst$3989$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_cleanup_unlinked_libraries$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","cleanup-unlinked-libraries","app.main.data.workspace.libraries/cleanup-unlinked-libraries",1367483397);$cljs$cst$1252$enable_backend_svgo$$=new $APP.$cljs$core$Keyword$$(null,"enable-backend-svgo","enable-backend-svgo",1448850085);
$APP.$cljs$cst$5395$create_welcome_file$$=new $APP.$cljs$core$Keyword$$(null,"create-welcome-file","create-welcome-file",1201110474);$cljs$cst$3318$app_DOT_main_DOT_data_DOT_team_SLASH_create_webhook$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","create-webhook","app.main.data.team/create-webhook",-1180018953);$APP.$cljs$cst$954$format$$=new $APP.$cljs$core$Keyword$$(null,"format","format",-1306924766);
$APP.$cljs$cst$4244$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_update_area_selection$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.selection","update-area-selection","app.main.data.workspace.path.selection/update-area-selection",1476390772);$APP.$cljs$cst$1243$token_typography_row$$=new $APP.$cljs$core$Keyword$$(null,"token-typography-row","token-typography-row",939627037);
$APP.$cljs$cst$1908$layer_blur$$=new $APP.$cljs$core$Keyword$$(null,"layer-blur","layer-blur",2003227989);$APP.$cljs$cst$233$clojure_DOT_core_SLASH_unquote_splicing$$=new $APP.$cljs$core$Symbol$$("clojure.core","unquote-splicing","clojure.core/unquote-splicing",-552003150,null);$APP.$cljs$cst$3183$email$$=new $APP.$cljs$core$Keyword$$(null,"email","email",1415816706);$APP.$cljs$cst$4088$justify_items$$=new $APP.$cljs$core$Keyword$$(null,"justify-items","justify-items",1638310783);
$cljs$cst$3381$file_version_not_supported$$=new $APP.$cljs$core$Keyword$$(null,"file-version-not-supported","file-version-not-supported",-2120659694);$cljs$cst$787$clojure_DOT_test_DOT_check_DOT_generators_SLASH_map$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","map","clojure.test.check.generators/map",45738796,null);$APP.$cljs$cst$1366$section$$=new $APP.$cljs$core$Keyword$$(null,"section","section",-300141526);
$APP.$cljs$cst$5086$help_icon$$=new $APP.$cljs$core$Keyword$$(null,"help-icon","help-icon",765943608);$APP.$cljs$cst$1627$component_id$$=new $APP.$cljs$core$Keyword$$(null,"component-id","component-id",1551113783);$APP.$cljs$cst$1724$gradient$$=new $APP.$cljs$core$Keyword$$(null,"gradient","gradient",-1983908971);$cljs$cst$4356$text_color$$=new $APP.$cljs$core$Keyword$$(null,"text-color","text-color",1728708298);
$APP.$cljs$cst$5363$nitrate_code_activation$$=new $APP.$cljs$core$Keyword$$(null,"nitrate-code-activation","nitrate-code-activation",877886206);$cljs$cst$1266$enable_feature_fdata_objects_map$$=new $APP.$cljs$core$Keyword$$(null,"enable-feature-fdata-objects-map","enable-feature-fdata-objects-map",533022170);$APP.$cljs$cst$2376$bracket$$=new $APP.$cljs$core$Keyword$$(null,"bracket","bracket",-600276523);
$APP.$cljs$cst$2658$move_token_set_group$$=new $APP.$cljs$core$Keyword$$(null,"move-token-set-group","move-token-set-group",132768939);$cljs$cst$4649$applied_to_variant$$=new $APP.$cljs$core$Keyword$$(null,"applied-to-variant","applied-to-variant",1933509599);$APP.$cljs$cst$1896$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_coplanar$$=new $APP.$cljs$core$Keyword$$("app.common.geom.shapes.intersect","coplanar","app.common.geom.shapes.intersect/coplanar",2062490877);
$cljs$cst$4373$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_id$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.pages","id","app.main.data.workspace.pages/id",422466501);$cljs$cst$1419$pretty$$=new $APP.$cljs$core$Keyword$$(null,"pretty","pretty",-1916372486);$APP.$cljs$cst$2343$warning$$=new $APP.$cljs$core$Keyword$$(null,"warning","warning",-1685650671);$cljs$cst$3854$y_ranges$$=new $APP.$cljs$core$Keyword$$(null,"y-ranges","y-ranges",484411693);
$cljs$cst$790$clojure_DOT_test_DOT_check_DOT_generators_SLASH_vector$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","vector","clojure.test.check.generators/vector",1081775325,null);$cljs$cst$3344$is_muted$$=new $APP.$cljs$core$Keyword$$(null,"is-muted","is-muted",-431849576);
$cljs$cst$4578$error_DOT_style_dictionary_SLASH_invalid_token_value_font_family$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","invalid-token-value-font-family","error.style-dictionary/invalid-token-value-font-family",-2130547996);$cljs$cst$1247$enable_registration$$=new $APP.$cljs$core$Keyword$$(null,"enable-registration","enable-registration",-1366746290);$APP.$cljs$cst$2622$del_page$$=new $APP.$cljs$core$Keyword$$(null,"del-page","del-page",-1821214846);
$APP.$cljs$cst$3113$payload$$=new $APP.$cljs$core$Keyword$$(null,"payload","payload",-383036092);$APP.$cljs$cst$301$values$$=new $APP.$cljs$core$Keyword$$(null,"values","values",372645556);$cljs$cst$1503$let$$=new $APP.$cljs$core$Symbol$$(null,"let","let",358118826,null);$cljs$cst$1819$curve_to$$=new $APP.$cljs$core$Keyword$$(null,"curve-to","curve-to",-936461191);$APP.$cljs$cst$1373$section$$=new $APP.$cljs$core$Symbol$$(null,"section","section",1340390001,null);
$cljs$cst$3022$old_italic$$=new $APP.$cljs$core$Keyword$$(null,"old-italic","old-italic",2142922587);$APP.$cljs$cst$4418$copied_tracks$$=new $APP.$cljs$core$Keyword$$(null,"copied-tracks","copied-tracks",-1861163689);$cljs$cst$4554$on_selected$$=new $APP.$cljs$core$Keyword$$(null,"on-selected","on-selected",236596581);$cljs$cst$2264$get_raw_file$$=new $APP.$cljs$core$Keyword$$(null,"get-raw-file","get-raw-file",-2017081582);
$APP.$cljs$cst$4720$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_bulk_delete_tokens$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","bulk-delete-tokens","app.main.data.workspace.tokens.library-edit/bulk-delete-tokens",1951039856);$cljs$cst$2495$app_DOT_main_DOT_data_DOT_common_SLASH_team_membership_change$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","team-membership-change","app.main.data.common/team-membership-change",1650446399);
$cljs$cst$2976$wasm_id$$=new $APP.$cljs$core$Keyword$$(null,"wasm-id","wasm-id",1590636146);$cljs$cst$2713$feMergeNode$$=new $APP.$cljs$core$Keyword$$(null,"feMergeNode","feMergeNode",-1691678771);$cljs$cst$5060$teams_to_leave$$=new $APP.$cljs$core$Keyword$$(null,"teams-to-leave","teams-to-leave",-315985584);$cljs$cst$1087$forms$$=new $APP.$cljs$core$Keyword$$(null,"forms","forms",2045992350);$APP.$cljs$cst$4794$draw_frame$$=new $APP.$cljs$core$Keyword$$(null,"draw-frame","draw-frame",657391841);
$cljs$cst$2704$fePointLight$$=new $APP.$cljs$core$Keyword$$(null,"fePointLight","fePointLight",-1658537624);$cljs$cst$5175$invalid_main_instance_page$$=new $APP.$cljs$core$Keyword$$(null,"invalid-main-instance-page","invalid-main-instance-page",-2135139325);$APP.$cljs$cst$2212$colors$$=new $APP.$cljs$core$Keyword$$(null,"colors","colors",1157174732);$cljs$cst$3373$only_creator_can_unlock$$=new $APP.$cljs$core$Keyword$$(null,"only-creator-can-unlock","only-creator-can-unlock",1799851042);
$cljs$cst$5009$is_grabbing$$=new $APP.$cljs$core$Keyword$$(null,"is-grabbing","is-grabbing",1756392012);$APP.$cljs$cst$5062$app_DOT_main_DOT_data_DOT_nitrate_SLASH_remove_team_from_org$$=new $APP.$cljs$core$Keyword$$("app.main.data.nitrate","remove-team-from-org","app.main.data.nitrate/remove-team-from-org",146862486);$cljs$cst$5167$child_id$$=new $APP.$cljs$core$Keyword$$(null,"child-id","child-id",1325542429);$APP.$cljs$cst$3931$id_ref$$=new $APP.$cljs$core$Keyword$$(null,"id-ref","id-ref",349210285);
$cljs$cst$2258$app_DOT_util_DOT_sse_SLASH_import_binfile$$=new $APP.$cljs$core$Keyword$$("app.util.sse","import-binfile","app.util.sse/import-binfile",-1363470717);$APP.$cljs$cst$4623$shadow_index$$=new $APP.$cljs$core$Keyword$$(null,"shadow-index","shadow-index",-1389271741);$APP.$cljs$cst$4808$toggle_colorpalette$$=new $APP.$cljs$core$Keyword$$(null,"toggle-colorpalette","toggle-colorpalette",-172926492);$cljs$cst$659$namespaces$$=new $APP.$cljs$core$Keyword$$(null,"namespaces","namespaces",-1444157469);
$cljs$cst$1499$defonce$$=new $APP.$cljs$core$Symbol$$(null,"defonce","defonce",-1681484013,null);$cljs$cst$5267$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_next_frame$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","select-next-frame","app.main.data.viewer/select-next-frame",-259216972);$APP.$cljs$cst$1621$remove_hidden$$=new $APP.$cljs$core$Keyword$$(null,"remove-hidden","remove-hidden",-1900786853);
$cljs$cst$2579$migrations$$=new $APP.$cljs$core$Keyword$$(null,"migrations","migrations",1963762970);$cljs$cst$857$gen_SLASH_infinite_QMARK_$$=new $APP.$cljs$core$Keyword$$("gen","infinite?","gen/infinite?",-2017652832);$APP.$cljs$cst$3733$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_ensure_layout$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.layout","ensure-layout","app.main.data.workspace.layout/ensure-layout",1851046511);
$cljs$cst$5137$member_does_not_exist$$=new $APP.$cljs$core$Keyword$$(null,"member-does-not-exist","member-does-not-exist",1388767352);$cljs$cst$1355$windows$$=new $APP.$cljs$core$Keyword$$(null,"windows","windows",2068861701);$cljs$cst$3487$total_chunks$$=new $APP.$cljs$core$Keyword$$(null,"total-chunks","total-chunks",1541029573);$cljs$cst$3447$update_comment_thread$$=new $APP.$cljs$core$Keyword$$(null,"update-comment-thread","update-comment-thread",-1577949030);
$cljs$cst$3376$svg_parser$$=new $APP.$cljs$core$Keyword$$(null,"svg-parser","svg-parser",-257903184);$cljs$cst$4964$milliseconds$$=new $APP.$cljs$core$Keyword$$(null,"milliseconds","milliseconds",-1238025512);$cljs$cst$4281$app_DOT_main_DOT_data_DOT_workspace_SLASH_workspace_initialized$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","workspace-initialized","app.main.data.workspace/workspace-initialized",647513818);
$APP.$cljs$cst$1357$browser$$=new $APP.$cljs$core$Keyword$$(null,"browser","browser",828191719);$APP.$cljs$cst$2368$replace$$=new $APP.$cljs$core$Keyword$$(null,"replace","replace",-786587770);$APP.$cljs$cst$3384$before$$=new $APP.$cljs$core$Keyword$$(null,"before","before",-1633692388);$APP.$cljs$cst$2535$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_deleted$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","go-to-dashboard-deleted","app.main.data.common/go-to-dashboard-deleted",-1309149964);
$APP.$cljs$cst$1598$is_owner$$=new $APP.$cljs$core$Keyword$$(null,"is-owner","is-owner",-1163290132);$cljs$cst$3519$property_name$$=new $APP.$cljs$core$Keyword$$(null,"property-name","property-name",-1399851434);$cljs$cst$4276$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_center_to_comment_thread$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.comments","center-to-comment-thread","app.main.data.workspace.comments/center-to-comment-thread",-1924511754);
$cljs$cst$2558$app_DOT_common_DOT_types_DOT_container_SLASH_touched$$=new $APP.$cljs$core$Keyword$$("app.common.types.container","touched","app.common.types.container/touched",245224963);$APP.$cljs$cst$4172$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_gradient$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","update-colorpicker-gradient","app.main.data.workspace.colors/update-colorpicker-gradient",1552146744);
$cljs$cst$3305$get_team_invitation_token$$=new $APP.$cljs$core$Keyword$$(null,"get-team-invitation-token","get-team-invitation-token",-412833462);$cljs$cst$1858$prev_c$$=new $APP.$cljs$core$Keyword$$(null,"prev-c","prev-c",1580249416);$cljs$cst$2291$engine$$=new $APP.$cljs$core$Keyword$$(null,"engine","engine",1459054265);
$cljs$cst$4154$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_picker_for_selected_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","picker-for-selected-shape","app.main.data.workspace.colors/picker-for-selected-shape",-652305754);$cljs$cst$1857$prev_i$$=new $APP.$cljs$core$Keyword$$(null,"prev-i","prev-i",182192286);$APP.$cljs$cst$1911$ignore_margin_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"ignore-margin?","ignore-margin?",1173241988);
$APP.$cljs$cst$4698$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_set_token_theme_active$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","set-token-theme-active","app.main.data.workspace.tokens.library-edit/set-token-theme-active",1867802601);$cljs$cst$5218$copy_any$$=new $APP.$cljs$core$Keyword$$(null,"copy-any","copy-any",2079055581);$cljs$cst$3649$converted_from$$=new $APP.$cljs$core$Keyword$$(null,"converted-from","converted-from",1608276057);
$APP.$cljs$cst$4492$app_DOT_main_DOT_data_DOT_workspace_SLASH_workspace_focus_lost$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","workspace-focus-lost","app.main.data.workspace/workspace-focus-lost",1572750041);$APP.$cljs$cst$2038$mixed$$=new $APP.$cljs$core$Keyword$$(null,"mixed","mixed",737211760);$APP.$cljs$cst$3245$recover_profile$$=new $APP.$cljs$core$Keyword$$(null,"recover-profile","recover-profile",627730638);
$cljs$cst$5000$insert_selected_mention$$=new $APP.$cljs$core$Keyword$$(null,"insert-selected-mention","insert-selected-mention",-711779812);$cljs$cst$345$double$$=new $APP.$cljs$core$Keyword$$(null,"double","double",884886883);$cljs$cst$2553$any_variant_container_descendant$$=new $APP.$cljs$core$Keyword$$(null,"any-variant-container-descendant","any-variant-container-descendant",2062709349);$cljs$cst$3025$kannada$$=new $APP.$cljs$core$Keyword$$(null,"kannada","kannada",-1605659329);
$APP.$cljs$cst$4937$app_DOT_main_DOT_data_DOT_dashboard_SLASH_create_project$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","create-project","app.main.data.dashboard/create-project",180950463);$cljs$cst$2598$assign$$=new $APP.$cljs$core$Keyword$$(null,"assign","assign",-1590426222);$APP.$cljs$cst$1406$pos$$=new $APP.$cljs$core$Keyword$$(null,"pos","pos",-864607220);$APP.$cljs$cst$1632$fill_image$$=new $APP.$cljs$core$Keyword$$(null,"fill-image","fill-image",-99895848);
$cljs$cst$1203$audit_log_gc$$=new $APP.$cljs$core$Keyword$$(null,"audit-log-gc","audit-log-gc",1187975685);$cljs$cst$2943$svg_defs$$=new $APP.$cljs$core$Keyword$$(null,"svg-defs","svg-defs",364869720);$cljs$cst$4755$widget_visible$$=new $APP.$cljs$core$Keyword$$(null,"widget-visible","widget-visible",939047906);$cljs$cst$1122$cljs_DOT_core_SLASH_zipmap$$=new $APP.$cljs$core$Symbol$$("cljs.core","zipmap","cljs.core/zipmap",-1902130674,null);
$APP.$cljs$cst$5143$text_key$$=new $APP.$cljs$core$Keyword$$(null,"text-key","text-key",-771258146);$cljs$cst$5033$restore_file_snapshot$$=new $APP.$cljs$core$Keyword$$(null,"restore-file-snapshot","restore-file-snapshot",1965192434);$cljs$cst$4485$app_DOT_main_DOT_data_DOT_workspace_SLASH_start_editing_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","start-editing-selected","app.main.data.workspace/start-editing-selected",-2103360348);
$cljs$cst$1856$prev_p$$=new $APP.$cljs$core$Keyword$$(null,"prev-p","prev-p",-1536591838);$APP.$cljs$cst$217$end_line$$=new $APP.$cljs$core$Keyword$$(null,"end-line","end-line",1837326455);$APP.$cljs$cst$2135$json_format$$=new $APP.$cljs$core$Keyword$$(null,"json-format","json-format",-1581359788);$APP.$cljs$cst$2403$template$$=new $APP.$cljs$core$Keyword$$(null,"template","template",-702405684);
$cljs$cst$3633$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_stop$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","update-shapes-buffer-stop","app.main.data.workspace.shapes/update-shapes-buffer-stop",-554327870);$APP.$cljs$cst$3442$app_DOT_main_DOT_data_DOT_comments_SLASH_create_thread_on_viewer$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","create-thread-on-viewer","app.main.data.comments/create-thread-on-viewer",166744307);
$APP.$cljs$cst$5346$import$$=new $APP.$cljs$core$Keyword$$(null,"import","import",-1399500709);$cljs$cst$4360$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_file_change$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.notifications","handle-file-change","app.main.data.workspace.notifications/handle-file-change",-1600731558);$APP.$cljs$cst$1136$token$$=new $APP.$cljs$core$Keyword$$(null,"token","token",-1211463215);
$cljs$cst$2721$stop$$=new $APP.$cljs$core$Keyword$$(null,"stop","stop",-2140911342);$cljs$cst$3795$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_update_thumbnail$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.thumbnails","update-thumbnail","app.main.data.workspace.thumbnails/update-thumbnail",-250727281);$APP.$cljs$cst$1729$start_x$$=new $APP.$cljs$core$Keyword$$(null,"start-x","start-x",-193941684);$cljs$cst$5319$app$$=new $APP.$cljs$core$Keyword$$(null,"app","app",-560961707);
$cljs$cst$2779$tableValues$$=new $APP.$cljs$core$Keyword$$(null,"tableValues","tableValues",-524228700);$cljs$cst$749$digit$$=new $APP.$cljs$core$Keyword$$(null,"digit","digit",1612650493);$APP.$cljs$cst$3663$start_p$$=new $APP.$cljs$core$Keyword$$(null,"start-p","start-p",767587445);$APP.$cljs$cst$1817$c2x$$=new $APP.$cljs$core$Keyword$$(null,"c2x","c2x",-699963108);$APP.$cljs$cst$1818$c2y$$=new $APP.$cljs$core$Keyword$$(null,"c2y","c2y",1361944924);
$cljs$cst$3259$organization_owner_id$$=new $APP.$cljs$core$Keyword$$(null,"organization-owner-id","organization-owner-id",1979469339);$APP.$cljs$cst$2451$conflicts$$=new $APP.$cljs$core$Keyword$$(null,"conflicts","conflicts",-1219561816);$cljs$cst$3265$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_members$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","fetch-members","app.main.data.team/fetch-members",-204945333);
$APP.$cljs$cst$3915$edit_typography$$=new $APP.$cljs$core$Keyword$$(null,"edit-typography","edit-typography",-679697712);$APP.$cljs$cst$1730$start_y$$=new $APP.$cljs$core$Keyword$$(null,"start-y","start-y",-771244577);$APP.$cljs$cst$5609$delete_shared_libraries$$=new $APP.$cljs$core$Keyword$$(null,"delete-shared-libraries","delete-shared-libraries",769506220);$APP.$cljs$cst$1815$c1x$$=new $APP.$cljs$core$Keyword$$(null,"c1x","c1x",-1789291378);
$APP.$cljs$cst$1816$c1y$$=new $APP.$cljs$core$Keyword$$(null,"c1y","c1y",-1210747344);$APP.$cljs$cst$4387$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_clear_selection$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid-layout.editor","clear-selection","app.main.data.workspace.grid-layout.editor/clear-selection",1229404566);$cljs$cst$1246$transit_readable_response$$=new $APP.$cljs$core$Keyword$$(null,"transit-readable-response","transit-readable-response",-1801163201);
$APP.$cljs$cst$429$and$$=new $APP.$cljs$core$Keyword$$(null,"and","and",-971899817);$cljs$cst$943$encode_SLASH_string$$=new $APP.$cljs$core$Keyword$$("encode","string","encode/string",-137314532);$cljs$cst$4559$default_value$$=new $APP.$cljs$core$Keyword$$(null,"default-value","default-value",232220170);$APP.$cljs$cst$1656$row$$=new $APP.$cljs$core$Keyword$$(null,"row","row",-570139521);$cljs$cst$3341$welcome_file_id$$=new $APP.$cljs$core$Keyword$$(null,"welcome-file-id","welcome-file-id",594574650);
$cljs$cst$2792$repeatCount$$=new $APP.$cljs$core$Keyword$$(null,"repeatCount","repeatCount",1447663848);$cljs$cst$2248$bad_gateway$$=new $APP.$cljs$core$Keyword$$(null,"bad-gateway","bad-gateway",1203629050);$APP.$cljs$cst$418$any$$=new $APP.$cljs$core$Keyword$$(null,"any","any",1705907423);
$APP.$cljs$cst$4530$app_DOT_main_DOT_data_DOT_workspace_SLASH_unset_preview_blend_mode$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","unset-preview-blend-mode","app.main.data.workspace/unset-preview-blend-mode",1606695736);$cljs$cst$2855$primitiveUnits$$=new $APP.$cljs$core$Keyword$$(null,"primitiveUnits","primitiveUnits",-1734004779);$cljs$cst$5334$html$$=new $APP.$cljs$core$Keyword$$(null,"html","html",-998796897);
$APP.$cljs$cst$1873$applied_tokens$$=new $APP.$cljs$core$Keyword$$(null,"applied-tokens","applied-tokens",1937742871);$APP.$cljs$cst$3390$natural_child_ordering$$=new $APP.$cljs$core$Keyword$$(null,"natural-child-ordering","natural-child-ordering",648760544);$cljs$cst$1481$cljs_DOT_core$$=new $APP.$cljs$core$Symbol$$(null,"cljs.core","cljs.core",770546058,null);$cljs$cst$288$miser$$=new $APP.$cljs$core$Keyword$$(null,"miser","miser",-556060186);
$cljs$cst$2741$hkern$$=new $APP.$cljs$core$Keyword$$(null,"hkern","hkern",38968123);$APP.$cljs$cst$1936$mouse_leave$$=new $APP.$cljs$core$Keyword$$(null,"mouse-leave","mouse-leave",135558349);$cljs$cst$1096$amp$$=new $APP.$cljs$core$Keyword$$(null,"amp","amp",271690571);$cljs$cst$1832$anyOf$$=new $APP.$cljs$core$Keyword$$(null,"anyOf","anyOf",-1046092155);$cljs$cst$3325$avatar_bg_url$$=new $APP.$cljs$core$Keyword$$(null,"avatar-bg-url","avatar-bg-url",-454414693);
$APP.$cljs$cst$5047$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_enter_preview$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","enter-preview","app.main.data.workspace.versions/enter-preview",1157604693);$APP.$cljs$cst$1134$invitation_token$$=new $APP.$cljs$core$Keyword$$(null,"invitation-token","invitation-token",-310125311);
$cljs$cst$4231$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_change_edit_mode$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","change-edit-mode","app.main.data.workspace.path.drawing/change-edit-mode",792108482);$APP.$cljs$cst$3383$link_message$$=new $APP.$cljs$core$Keyword$$(null,"link-message","link-message",893661043);$cljs$cst$2904$stop_color$$=new $APP.$cljs$core$Keyword$$(null,"stop-color","stop-color",316173955);
$cljs$cst$3303$app_DOT_main_DOT_data_DOT_team_SLASH_copy_invitation_link$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","copy-invitation-link","app.main.data.team/copy-invitation-link",-836652211);$cljs$cst$1288$key__GT_prop$$=new $APP.$cljs$core$Keyword$$(null,"key-\x3eprop","key-\x3eprop",-1028452531);$cljs$cst$5302$next_frame$$=new $APP.$cljs$core$Keyword$$(null,"next-frame","next-frame",-636070893);$APP.$cljs$cst$2124$all$$=new $APP.$cljs$core$Keyword$$(null,"all","all",892129742);
$APP.$cljs$cst$2286$update_team_photo$$=new $APP.$cljs$core$Keyword$$(null,"update-team-photo","update-team-photo",539796592);$APP.$cljs$cst$3108$app_DOT_main_DOT_features_SLASH_initialize$$=new $APP.$cljs$core$Keyword$$("app.main.features","initialize","app.main.features/initialize",1791758028);$cljs$cst$807$clojure_DOT_test_DOT_check_DOT_generators_SLASH_boolean$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","boolean","clojure.test.check.generators/boolean",1586992347,null);
$APP.$cljs$cst$717$alt$$=new $APP.$cljs$core$Keyword$$(null,"alt","alt",-3214426);$cljs$cst$289$indentation$$=new $APP.$cljs$core$Keyword$$(null,"indentation","indentation",-902544874);$APP.$cljs$cst$3435$draft$$=new $APP.$cljs$core$Keyword$$(null,"draft","draft",1421831058);$APP.$cljs$cst$3765$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_undo$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.common","undo","app.main.data.workspace.common/undo",-1459605934);
$APP.$cljs$cst$2364$conflicting$$=new $APP.$cljs$core$Keyword$$(null,"conflicting","conflicting",2003828416);$APP.$cljs$cst$5141$invitation_modal$$=new $APP.$cljs$core$Keyword$$(null,"invitation-modal","invitation-modal",-1270137375);$APP.$cljs$cst$1325$delay$$=new $APP.$cljs$core$Keyword$$(null,"delay","delay",-574225219);$cljs$cst$2764$stdDeviation$$=new $APP.$cljs$core$Keyword$$(null,"stdDeviation","stdDeviation",1418775521);
$cljs$cst$3098$node_batch_threshold$$=new $APP.$cljs$core$Keyword$$(null,"node_batch_threshold","node_batch_threshold",-1732220154);$APP.$cljs$cst$4672$tokens_SLASH_opacity$$=new $APP.$cljs$core$Keyword$$("tokens","opacity","tokens/opacity",1131118906);$APP.$cljs$cst$2100$tokens$$=new $APP.$cljs$core$Keyword$$(null,"tokens","tokens",-818939304);$APP.$cljs$cst$3204$get_profile$$=new $APP.$cljs$core$Keyword$$(null,"get-profile","get-profile",1713676914);
$APP.$cljs$cst$1891$position_data$$=new $APP.$cljs$core$Keyword$$(null,"position-data","position-data",-499622376);$cljs$cst$686$uuid_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"uuid?","uuid?",400077689,null);$cljs$cst$1244$frontend_svgo$$=new $APP.$cljs$core$Keyword$$(null,"frontend-svgo","frontend-svgo",-1259208707);
$cljs$cst$4700$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_delete_token_theme$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","delete-token-theme","app.main.data.workspace.tokens.library-edit/delete-token-theme",-1311408142);
$APP.$cljs$cst$4656$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_token_from_input$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","apply-token-from-input","app.main.data.workspace.tokens.application/apply-token-from-input",1753780419);$cljs$cst$597$_scope$$=new $APP.$cljs$core$Keyword$$(null,"_scope","_scope",882472555);
$APP.$cljs$cst$4306$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_add_new_interaction$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","add-new-interaction","app.main.data.workspace.interactions/add-new-interaction",455178270);$cljs$cst$2929$pointer_events$$=new $APP.$cljs$core$Keyword$$(null,"pointer-events","pointer-events",-1053858853);
$cljs$cst$3450$app_DOT_main_DOT_data_DOT_comments_SLASH_update_comment$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","update-comment","app.main.data.comments/update-comment",-1864826865);$cljs$cst$1381$end_pos$$=new $APP.$cljs$core$Keyword$$(null,"end-pos","end-pos",-1643883926);$cljs$cst$369$malli_DOT_core_SLASH_duplicate_keys$$=new $APP.$cljs$core$Keyword$$("malli.core","duplicate-keys","malli.core/duplicate-keys",1684166326);
$APP.$cljs$cst$4848$toggle_snap_guides$$=new $APP.$cljs$core$Keyword$$(null,"toggle-snap-guides","toggle-snap-guides",1054346098);$cljs$cst$3924$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_rename_component_and_main_instance$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","rename-component-and-main-instance","app.main.data.workspace.libraries/rename-component-and-main-instance",1096064141);
$APP.$cljs$cst$4151$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_all_strokes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","remove-all-strokes","app.main.data.workspace.colors/remove-all-strokes",260699134);$cljs$cst$358$malli_DOT_core_SLASH_invalid_schema$$=new $APP.$cljs$core$Keyword$$("malli.core","invalid-schema","malli.core/invalid-schema",1923990979);
$cljs$cst$2128$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_tokens_lib$$=new $APP.$cljs$core$Keyword$$("app.common.types.tokens-lib","tokens-lib","app.common.types.tokens-lib/tokens-lib",1206706540);$APP.$cljs$cst$3802$num_children$$=new $APP.$cljs$core$Keyword$$(null,"num-children","num-children",-1656107233);$cljs$cst$2105$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_node$$=new $APP.$cljs$core$Keyword$$("app.common.types.tokens-lib","node","app.common.types.tokens-lib/node",-2091664271);
$cljs$cst$5217$main_any$$=new $APP.$cljs$core$Keyword$$(null,"main-any","main-any",1012350127);$APP.$cljs$cst$4157$on_change$$=new $APP.$cljs$core$Keyword$$(null,"on-change","on-change",-732046149);$APP.$cljs$cst$4677$to_index$$=new $APP.$cljs$core$Keyword$$(null,"to-index","to-index",2106835987);$APP.$cljs$cst$4550$modal$$=new $APP.$cljs$core$Keyword$$(null,"modal","modal",-1031880850);$cljs$cst$2296$device_vendor$$=new $APP.$cljs$core$Keyword$$(null,"device-vendor","device-vendor",2012647423);
$APP.$cljs$cst$1658$column_span$$=new $APP.$cljs$core$Keyword$$(null,"column-span","column-span",1302376857);$cljs$cst$966$app_DOT_common_DOT_schema_SLASH_contains_any$$=new $APP.$cljs$core$Keyword$$("app.common.schema","contains-any","app.common.schema/contains-any",545508409);
$cljs$cst$3705$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_process_media_objects$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.media","process-media-objects","app.main.data.workspace.media/process-media-objects",-2102281761);$cljs$cst$1279$branch$$=new $APP.$cljs$core$Keyword$$(null,"branch","branch",-74633925);$APP.$cljs$cst$3117$file_raw$$=new $APP.$cljs$core$Keyword$$(null,"file-raw","file-raw",-341717768);
$APP.$cljs$cst$4501$app_DOT_main_DOT_data_DOT_workspace_SLASH_select_assets$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","select-assets","app.main.data.workspace/select-assets",-638797101);$cljs$cst$4802$start_measure$$=new $APP.$cljs$core$Keyword$$(null,"start-measure","start-measure",-1604243196);
$APP.$cljs$cst$4301$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_add_flow_selected_frame$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","add-flow-selected-frame","app.main.data.workspace.interactions/add-flow-selected-frame",-93942544);$APP.$cljs$cst$4661$tokens_SLASH_color$$=new $APP.$cljs$core$Keyword$$("tokens","color","tokens/color",1619883579);
$APP.$cljs$cst$4236$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_path_pointer_leave$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.selection","path-pointer-leave","app.main.data.workspace.path.selection/path-pointer-leave",-1814776447);$APP.$cljs$cst$1733$stops$$=new $APP.$cljs$core$Keyword$$(null,"stops","stops",-1205459005);$cljs$cst$4947$rename_project$$=new $APP.$cljs$core$Keyword$$(null,"rename-project","rename-project",640216451);
$APP.$cljs$cst$1861$segment$$=new $APP.$cljs$core$Keyword$$(null,"segment","segment",-964921196);$APP.$cljs$cst$1916$files$$=new $APP.$cljs$core$Keyword$$(null,"files","files",-472457450);$APP.$cljs$cst$2122$themes$$=new $APP.$cljs$core$Keyword$$(null,"themes","themes",-702786642);$cljs$cst$3458$app_DOT_main_DOT_data_DOT_comments_SLASH_comment_threads_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","comment-threads-fetched","app.main.data.comments/comment-threads-fetched",-1874255683);
$APP.$cljs$cst$1736$ref_file$$=new $APP.$cljs$core$Keyword$$(null,"ref-file","ref-file",255004238);$APP.$cljs$cst$4795$bool_intersection$$=new $APP.$cljs$core$Keyword$$(null,"bool-intersection","bool-intersection",2106050785);$APP.$cljs$cst$4503$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_component_in_assets$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","show-component-in-assets","app.main.data.workspace/show-component-in-assets",26575746);
$cljs$cst$2898$image_rendering$$=new $APP.$cljs$core$Keyword$$(null,"image-rendering","image-rendering",770251905);$cljs$cst$2076$exports_group$$=new $APP.$cljs$core$Keyword$$(null,"exports-group","exports-group",-1337580552);$APP.$cljs$cst$4386$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_remove_selection$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid-layout.editor","remove-selection","app.main.data.workspace.grid-layout.editor/remove-selection",884403180);
$APP.$cljs$cst$1315$rfn$$=new $APP.$cljs$core$Keyword$$(null,"rfn","rfn",-990883444);$APP.$cljs$cst$3982$library_summary$$=new $APP.$cljs$core$Keyword$$(null,"library-summary","library-summary",908431551);$cljs$cst$3132$index_SLASH_update$$=new $APP.$cljs$core$Keyword$$("index","update","index/update",945065946);$cljs$cst$3350$provider_not_configured$$=new $APP.$cljs$core$Keyword$$(null,"provider-not-configured","provider-not-configured",609627056);
$cljs$cst$3747$app_DOT_main_DOT_data_DOT_workspace_SLASH_selected_palette_colorpicker$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","selected-palette-colorpicker","app.main.data.workspace/selected-palette-colorpicker",1592339174);$cljs$cst$5061$app_DOT_main_DOT_data_DOT_nitrate_SLASH_leave_org$$=new $APP.$cljs$core$Keyword$$("app.main.data.nitrate","leave-org","app.main.data.nitrate/leave-org",570428350);
$cljs$cst$156$letfn_STAR_$$=new $APP.$cljs$core$Symbol$$(null,"letfn*","letfn*",-110097810,null);$cljs$cst$3993$penpot_selection$$=new $APP.$cljs$core$Keyword$$(null,"penpot-selection","penpot-selection",-2017334082);$APP.$cljs$cst$44$state$$=new $APP.$cljs$core$Symbol$$(null,"state","state",-348086572,null);$cljs$cst$533$malli_DOT_core_SLASH_missing_property$$=new $APP.$cljs$core$Keyword$$("malli.core","missing-property","malli.core/missing-property",-818756333);
$APP.$cljs$cst$5446$red$$=new $APP.$cljs$core$Keyword$$(null,"red","red",-969428204);$cljs$cst$2146$hint_origin$$=new $APP.$cljs$core$Keyword$$(null,"hint-origin","hint-origin",-1188161082);$cljs$cst$550$ref$$=new $APP.$cljs$core$Keyword$$(null,"ref","ref",1289896967);$cljs$cst$3078$removed_mixed$$=new $APP.$cljs$core$Keyword$$(null,"removed-mixed","removed-mixed",-588684214);
$APP.$cljs$cst$2449$reitit_DOT_core_SLASH_path_conflicting$$=new $APP.$cljs$core$Keyword$$("reitit.core","path-conflicting","reitit.core/path-conflicting",617644429);$cljs$cst$3580$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_decrease_zoom$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.zoom","decrease-zoom","app.main.data.workspace.zoom/decrease-zoom",1109846343);$cljs$cst$1084$ret$$=new $APP.$cljs$core$Keyword$$(null,"ret","ret",-468222814);
$APP.$cljs$cst$3730$add$$=new $APP.$cljs$core$Keyword$$(null,"add","add",235287739);$APP.$cljs$cst$4032$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data_debounce$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","update-position-data-debounce","app.main.data.workspace.texts/update-position-data-debounce",568799460);$cljs$cst$992$req$$=new $APP.$cljs$core$Keyword$$(null,"req","req",-326448303);
$cljs$cst$2994$chinese$$=new $APP.$cljs$core$Keyword$$(null,"chinese","chinese",-59488313);$APP.$cljs$cst$2121$token_set$$=new $APP.$cljs$core$Keyword$$(null,"token-set","token-set",655734075);$cljs$cst$1489$defmacro$$=new $APP.$cljs$core$Symbol$$(null,"defmacro","defmacro",2054157304,null);$APP.$cljs$cst$3511$get_project$$=new $APP.$cljs$core$Keyword$$(null,"get-project","get-project",621757082);
$APP.$cljs$cst$4602$error_SLASH_detail$$=new $APP.$cljs$core$Keyword$$("error","detail","error/detail",-1373701625);$APP.$cljs$cst$4660$tokens_SLASH_shadow$$=new $APP.$cljs$core$Keyword$$("tokens","shadow","tokens/shadow",1716253537);$APP.$cljs$cst$3525$cell$$=new $APP.$cljs$core$Keyword$$(null,"cell","cell",764245084);
$cljs$cst$4188$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_common_SLASH_handle_finish_drawing$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.drawing.common","handle-finish-drawing","app.main.data.workspace.drawing.common/handle-finish-drawing",605061012);
$APP.$cljs$cst$4259$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_start_move_handler$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.edition","start-move-handler","app.main.data.workspace.path.edition/start-move-handler",-685497280);$APP.$cljs$cst$5090$on_blur$$=new $APP.$cljs$core$Keyword$$(null,"on-blur","on-blur",814300747);
$APP.$cljs$cst$2392$reitit_DOT_trie_SLASH_multiple_terminators$$=new $APP.$cljs$core$Keyword$$("reitit.trie","multiple-terminators","reitit.trie/multiple-terminators",-116295163);$APP.$cljs$cst$4027$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_event$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","update-text-modifier-debounce-event","app.main.data.workspace.texts/update-text-modifier-debounce-event",1695192681);
$APP.$cljs$cst$231$runtime_exception$$=new $APP.$cljs$core$Keyword$$(null,"runtime-exception","runtime-exception",-1495664514);$APP.$cljs$cst$5070$quantity$$=new $APP.$cljs$core$Keyword$$(null,"quantity","quantity",-1929050694);$APP.$cljs$cst$2023$normal$$=new $APP.$cljs$core$Keyword$$(null,"normal","normal",-1519123858);$cljs$cst$871$gen_SLASH_fmap$$=new $APP.$cljs$core$Keyword$$("gen","fmap","gen/fmap",-1585733563);
$cljs$cst$5102$num_teams_to_delete$$=new $APP.$cljs$core$Keyword$$(null,"num-teams-to-delete","num-teams-to-delete",-1599831677);$APP.$cljs$cst$3271$app_DOT_main_DOT_data_DOT_team_SLASH_team_initialized$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","team-initialized","app.main.data.team/team-initialized",-765687715);$cljs$cst$422$qualified_keyword$$=new $APP.$cljs$core$Keyword$$(null,"qualified-keyword","qualified-keyword",736041675);
$cljs$cst$2246$offline$$=new $APP.$cljs$core$Keyword$$(null,"offline","offline",-107631935);$APP.$cljs$cst$2237$rendered_at$$=new $APP.$cljs$core$Keyword$$(null,"rendered-at","rendered-at",-1173398632);$cljs$cst$931$data_validation$$=new $APP.$cljs$core$Keyword$$(null,"data-validation","data-validation",-893817907);$cljs$cst$3807$line_min_width$$=new $APP.$cljs$core$Keyword$$(null,"line-min-width","line-min-width",-1500903047);
$cljs$cst$2752$divisor$$=new $APP.$cljs$core$Keyword$$(null,"divisor","divisor",-25029120);$cljs$cst$2517$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_libraries$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","go-to-dashboard-libraries","app.main.data.common/go-to-dashboard-libraries",-165601239);
$cljs$cst$3650$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_create_artboard_from_selection$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","create-artboard-from-selection","app.main.data.workspace.shapes/create-artboard-from-selection",1204722774);$APP.$cljs$cst$5052$nothing$$=new $APP.$cljs$core$Keyword$$(null,"nothing","nothing",-1022703296);$cljs$cst$2761$exponent$$=new $APP.$cljs$core$Keyword$$(null,"exponent","exponent",2083463617);
$APP.$cljs$cst$4929$app_DOT_main_DOT_data_DOT_dashboard_SLASH_toggle_file_select$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","toggle-file-select","app.main.data.dashboard/toggle-file-select",-767554472);$APP.$cljs$cst$561$raw$$=new $APP.$cljs$core$Keyword$$(null,"raw","raw",1604651272);
$APP.$cljs$cst$4926$app_DOT_main_DOT_data_DOT_dashboard_SLASH_clear_file_select$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","clear-file-select","app.main.data.dashboard/clear-file-select",-107086303);$cljs$cst$3448$app_DOT_main_DOT_data_DOT_comments_SLASH_create_comment$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","create-comment","app.main.data.comments/create-comment",-1445923829);
$cljs$cst$1508$binding$$=new $APP.$cljs$core$Symbol$$(null,"binding","binding",-2114503176,null);$APP.$cljs$cst$2170$viewport$$=new $APP.$cljs$core$Keyword$$(null,"viewport","viewport",443342715);$cljs$cst$3295$app_DOT_main_DOT_data_DOT_team_SLASH_team_leaved$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","team-leaved","app.main.data.team/team-leaved",1476806175);$cljs$cst$1241$soft_quotes$$=new $APP.$cljs$core$Keyword$$(null,"soft-quotes","soft-quotes",2080231996);
$APP.$cljs$cst$4324$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize_workspace$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","finalize-workspace","app.main.data.workspace/finalize-workspace",203141404);$APP.$cljs$cst$4023$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_save_font$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","save-font","app.main.data.workspace.texts/save-font",-1999563757);
$APP.$cljs$cst$4870$detach_component$$=new $APP.$cljs$core$Keyword$$(null,"detach-component","detach-component",761982427);$APP.$cljs$cst$2033$exclude$$=new $APP.$cljs$core$Keyword$$(null,"exclude","exclude",-1230250334);$cljs$cst$2647$set_token_theme$$=new $APP.$cljs$core$Keyword$$(null,"set-token-theme","set-token-theme",-1994995543);
$cljs$cst$4939$app_DOT_main_DOT_data_DOT_dashboard_SLASH_project_duplicated$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","project-duplicated","app.main.data.dashboard/project-duplicated",-1069292527);$APP.$cljs$cst$1963$direction$$=new $APP.$cljs$core$Keyword$$(null,"direction","direction",-633359395);
$cljs$cst$3879$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_update_position$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","update-position","app.main.data.workspace.transforms/update-position",524068701);$APP.$cljs$cst$4528$id_for_create$$=new $APP.$cljs$core$Keyword$$(null,"id-for-create","id-for-create",1988159458);
$APP.$cljs$cst$2465$app_DOT_main_DOT_data_DOT_common_SLASH_share_link_created$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","share-link-created","app.main.data.common/share-link-created",-89040063);$APP.$cljs$cst$4913$app_DOT_main_DOT_data_DOT_dashboard_SLASH_recent_files_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","recent-files-fetched","app.main.data.dashboard/recent-files-fetched",1922744559);
$cljs$cst$5179$should_not_be_component_root$$=new $APP.$cljs$core$Keyword$$(null,"should-not-be-component-root","should-not-be-component-root",-1750007912);$cljs$cst$5269$app_DOT_main_DOT_data_DOT_viewer_SLASH_set_interactions_mode$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","set-interactions-mode","app.main.data.viewer/set-interactions-mode",-620916070);
$cljs$cst$4486$app_DOT_main_DOT_data_DOT_workspace_SLASH_select_parent_layer$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","select-parent-layer","app.main.data.workspace/select-parent-layer",-1982254562);$APP.$cljs$cst$4830$bool_union$$=new $APP.$cljs$core$Keyword$$(null,"bool-union","bool-union",-400530038);$APP.$cljs$cst$2550$force_parent_id$$=new $APP.$cljs$core$Keyword$$(null,"force-parent-id","force-parent-id",724093063);
$APP.$cljs$cst$2053$starting_frame$$=new $APP.$cljs$core$Keyword$$(null,"starting-frame","starting-frame",-1907986271);$APP.$cljs$cst$2060$pixel_grid_opacity$$=new $APP.$cljs$core$Keyword$$(null,"pixel-grid-opacity","pixel-grid-opacity",-2103648966);$cljs$cst$5163$parent_not_found$$=new $APP.$cljs$core$Keyword$$(null,"parent-not-found","parent-not-found",451342282);$cljs$cst$629$re_validator$$=new $APP.$cljs$core$Keyword$$(null,"re-validator","re-validator",-180375208);
$APP.$cljs$cst$4679$path_exists$$=new $APP.$cljs$core$Keyword$$(null,"path-exists","path-exists",4854463);$cljs$cst$300$malli_DOT_core_SLASH_input_remaining$$=new $APP.$cljs$core$Keyword$$("malli.core","input-remaining","malli.core/input-remaining",372310422);$cljs$cst$1584$network$$=new $APP.$cljs$core$Keyword$$(null,"network","network",2050004697);$cljs$cst$2609$comment_thread_id$$=new $APP.$cljs$core$Keyword$$(null,"comment-thread-id","comment-thread-id",239314476);
$APP.$cljs$cst$4272$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_initialize_comments$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.comments","initialize-comments","app.main.data.workspace.comments/initialize-comments",1789582778);$APP.$cljs$cst$4841$decrease_zoom$$=new $APP.$cljs$core$Keyword$$(null,"decrease-zoom","decrease-zoom",-316768753);$APP.$cljs$cst$4938$create_project$$=new $APP.$cljs$core$Keyword$$(null,"create-project","create-project",-2068207849);
$cljs$cst$970$app_DOT_common_DOT_schema_SLASH_uri$$=new $APP.$cljs$core$Keyword$$("app.common.schema","uri","app.common.schema/uri",-383357038);$APP.$cljs$cst$5074$clean_data$$=new $APP.$cljs$core$Keyword$$(null,"clean-data","clean-data",1601974651);$cljs$cst$1434$parameter_from_args$$=new $APP.$cljs$core$Keyword$$(null,"parameter-from-args","parameter-from-args",-758446196);
$cljs$cst$1108$cljs_DOT_core_SLASH_sequential_QMARK_$$=new $APP.$cljs$core$Symbol$$("cljs.core","sequential?","cljs.core/sequential?",1777854658,null);$APP.$cljs$cst$2019$screen$$=new $APP.$cljs$core$Keyword$$(null,"screen","screen",1990059748);$APP.$cljs$cst$1452$selector$$=new $APP.$cljs$core$Keyword$$(null,"selector","selector",762528866);$cljs$cst$2625$add_color$$=new $APP.$cljs$core$Keyword$$(null,"add-color","add-color",2130863672);
$APP.$cljs$cst$2672$inspect$$=new $APP.$cljs$core$Keyword$$(null,"inspect","inspect",688794057);$APP.$cljs$cst$4239$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_path_handler_leave$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.selection","path-handler-leave","app.main.data.workspace.path.selection/path-handler-leave",1323519696);$APP.$cljs$cst$1923$edit_path$$=new $APP.$cljs$core$Keyword$$(null,"edit-path","edit-path",-1066566229);
$cljs$cst$776$min_elements$$=new $APP.$cljs$core$Keyword$$(null,"min-elements","min-elements",949370780);$cljs$cst$3573$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_undo_to_index$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.undo","undo-to-index","app.main.data.workspace.undo/undo-to-index",-2070841694);
$APP.$cljs$cst$5015$app_DOT_main_DOT_data_DOT_exports_DOT_files_SLASH_export_files$$=new $APP.$cljs$core$Keyword$$("app.main.data.exports.files","export-files","app.main.data.exports.files/export-files",1145324384);$cljs$cst$3170$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_applied_changes_count$$=new $APP.$cljs$core$Keyword$$("app.common.files.changes-builder","applied-changes-count","app.common.files.changes-builder/applied-changes-count",-1830540901);
$cljs$cst$706$empty_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"empty?","empty?",76408555,null);$APP.$cljs$cst$5314$separate_nodes$$=new $APP.$cljs$core$Keyword$$(null,"separate-nodes","separate-nodes",-1215076842);$cljs$cst$4321$app_DOT_main_DOT_data_DOT_workspace_DOT_layers_SLASH_set_opacity$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.layers","set-opacity","app.main.data.workspace.layers/set-opacity",86390947);
$APP.$cljs$cst$1901$topbottom$$=new $APP.$cljs$core$Keyword$$(null,"topbottom","topbottom",207067417);$cljs$cst$2692$linearGradient$$=new $APP.$cljs$core$Keyword$$(null,"linearGradient","linearGradient",1711964727);$APP.$cljs$cst$3053$grid_layout$$=new $APP.$cljs$core$Keyword$$(null,"grid-layout","grid-layout",-227324382);$cljs$cst$2762$bbox$$=new $APP.$cljs$core$Keyword$$(null,"bbox","bbox",678077025);$APP.$cljs$cst$294$indent$$=new $APP.$cljs$core$Keyword$$(null,"indent","indent",-148200125);
$cljs$cst$129$descendants$$=new $APP.$cljs$core$Keyword$$(null,"descendants","descendants",1824886031);$cljs$cst$3773$data_old_width$$=new $APP.$cljs$core$Keyword$$(null,"data-old-width","data-old-width",193537062);$APP.$cljs$cst$3148$app_DOT_main_DOT_data_DOT_persistence_SLASH_update_status$$=new $APP.$cljs$core$Keyword$$("app.main.data.persistence","update-status","app.main.data.persistence/update-status",1791929606);
$cljs$cst$449$malli_DOT_core_SLASH_val$$=new $APP.$cljs$core$Keyword$$("malli.core","val","malli.core/val",39501268);$APP.$cljs$cst$4805$add_comment$$=new $APP.$cljs$core$Keyword$$(null,"add-comment","add-comment",-1169367708);$APP.$cljs$cst$4880$bring_back$$=new $APP.$cljs$core$Keyword$$(null,"bring-back","bring-back",4389822);$cljs$cst$880$malli_DOT_error_SLASH_unknown$$=new $APP.$cljs$core$Keyword$$("malli.error","unknown","malli.error/unknown",594142330);
$cljs$cst$3947$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_ext_library_changed$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","ext-library-changed","app.main.data.workspace.libraries/ext-library-changed",278123498);$cljs$cst$5227$go_to_libs$$=new $APP.$cljs$core$Keyword$$(null,"go-to-libs","go-to-libs",13087431);$APP.$cljs$cst$1328$next$$=new $APP.$cljs$core$Keyword$$(null,"next","next",-117701485);
$APP.$cljs$cst$5312$snap_nodes$$=new $APP.$cljs$core$Keyword$$(null,"snap-nodes","snap-nodes",42271851);$APP.$cljs$cst$1186$subscriptions_old$$=new $APP.$cljs$core$Keyword$$(null,"subscriptions-old","subscriptions-old",-338159584);$cljs$cst$661$malli_DOT_core_SLASH_disable_sci$$=new $APP.$cljs$core$Keyword$$("malli.core","disable-sci","malli.core/disable-sci",-907669760);$cljs$cst$1835$oneOf$$=new $APP.$cljs$core$Keyword$$(null,"oneOf","oneOf",1209080187);
$APP.$cljs$cst$4111$copied_props$$=new $APP.$cljs$core$Keyword$$(null,"copied-props","copied-props",377336865);$APP.$cljs$cst$2219$gap_selected$$=new $APP.$cljs$core$Keyword$$(null,"gap-selected","gap-selected",-1435692040);$APP.$cljs$cst$5131$email_has_permanent_bounces$$=new $APP.$cljs$core$Keyword$$(null,"email-has-permanent-bounces","email-has-permanent-bounces",223647074);$cljs$cst$3429$count_comments$$=new $APP.$cljs$core$Keyword$$(null,"count-comments","count-comments",2017472395);
$APP.$cljs$cst$4310$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_start_edit_interaction$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","start-edit-interaction","app.main.data.workspace.interactions/start-edit-interaction",-740776923);$APP.$cljs$cst$4202$snap_toggled$$=new $APP.$cljs$core$Keyword$$(null,"snap-toggled","snap-toggled",-1650735574);
$APP.$cljs$cst$3712$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_create_svg_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.media","create-svg-shape","app.main.data.workspace.media/create-svg-shape",-72398721);$cljs$cst$3454$app_DOT_main_DOT_data_DOT_comments_SLASH_delete_comment_thread_on_viewer$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","delete-comment-thread-on-viewer","app.main.data.comments/delete-comment-thread-on-viewer",-2140755261);
$APP.$cljs$cst$4922$will_be_deleted_at$$=new $APP.$cljs$core$Keyword$$(null,"will-be-deleted-at","will-be-deleted-at",-1174985202);$cljs$cst$5371$org_owner_cannot_leave$$=new $APP.$cljs$core$Keyword$$(null,"org-owner-cannot-leave","org-owner-cannot-leave",-573125657);
$cljs$cst$4411$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_layout_child$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","update-layout-child","app.main.data.workspace.shape-layout/update-layout-child",1240212393);$cljs$cst$4073$padding_inline_start$$=new $APP.$cljs$core$Keyword$$(null,"padding-inline-start","padding-inline-start",1837266335);
$cljs$cst$3466$app_DOT_main_DOT_data_DOT_comments_SLASH_mark_all_threads_as_read$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","mark-all-threads-as-read","app.main.data.comments/mark-all-threads-as-read",1535803927);$cljs$cst$4357$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_presence$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.notifications","handle-presence","app.main.data.workspace.notifications/handle-presence",1491898407);
$APP.$cljs$cst$2643$set_id$$=new $APP.$cljs$core$Keyword$$(null,"set-id","set-id",675256473);$cljs$cst$1603$app_DOT_common_DOT_geom_DOT_matrix_SLASH_matrix$$=new $APP.$cljs$core$Keyword$$("app.common.geom.matrix","matrix","app.common.geom.matrix/matrix",-2125853053);$APP.$cljs$cst$232$illegal_state$$=new $APP.$cljs$core$Keyword$$(null,"illegal-state","illegal-state",-1519851182);$cljs$cst$2719$feMorphology$$=new $APP.$cljs$core$Keyword$$(null,"feMorphology","feMorphology",-1890781328);
$cljs$cst$3443$app_DOT_main_DOT_data_DOT_comments_SLASH_update_comment_thread_status$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","update-comment-thread-status","app.main.data.comments/update-comment-thread-status",1362543344);$cljs$cst$1276$commit$$=new $APP.$cljs$core$Keyword$$(null,"commit","commit",113374389);$cljs$cst$3701$unable_to_access_to_url$$=new $APP.$cljs$core$Keyword$$(null,"unable-to-access-to-url","unable-to-access-to-url",1056683412);
$cljs$cst$4756$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_clear_export_state$$=new $APP.$cljs$core$Keyword$$("app.main.data.exports.assets","clear-export-state","app.main.data.exports.assets/clear-export-state",1793686057);$APP.$cljs$cst$2046$remote_synced$$=new $APP.$cljs$core$Keyword$$(null,"remote-synced","remote-synced",1564821477);$APP.$cljs$cst$4493$show_distances_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"show-distances?","show-distances?",-2103559896);
$cljs$cst$2870$vert_adv_y$$=new $APP.$cljs$core$Keyword$$(null,"vert-adv-y","vert-adv-y",-641097319);$APP.$cljs$cst$2115$new_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"new?","new?",777958557);$cljs$cst$581$malli_DOT_core_SLASH_invalid_guard$$=new $APP.$cljs$core$Keyword$$("malli.core","invalid-guard","malli.core/invalid-guard",-946413611);$APP.$cljs$cst$421$boolean$$=new $APP.$cljs$core$Keyword$$(null,"boolean","boolean",-1919418404);
$cljs$cst$1201$sec_fetch_metadata_middleware$$=new $APP.$cljs$core$Keyword$$(null,"sec-fetch-metadata-middleware","sec-fetch-metadata-middleware",-1137691291);$APP.$cljs$cst$4905$app_DOT_main_DOT_data_DOT_dashboard_SLASH_initialize$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","initialize","app.main.data.dashboard/initialize",-1368877159);
$APP.$cljs$cst$3843$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_rotation_modifiers$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.modifiers","set-rotation-modifiers","app.main.data.workspace.modifiers/set-rotation-modifiers",-286134133);$cljs$cst$2661$broken_children$$=new $APP.$cljs$core$Keyword$$(null,"broken-children","broken-children",2066711501);$cljs$cst$3285$get_webhooks$$=new $APP.$cljs$core$Keyword$$(null,"get-webhooks","get-webhooks",1755105908);
$cljs$cst$2797$ideographic$$=new $APP.$cljs$core$Keyword$$(null,"ideographic","ideographic",-335748120);$APP.$cljs$cst$1947$top_center$$=new $APP.$cljs$core$Keyword$$(null,"top-center","top-center",1447995281);$cljs$cst$2067$text_font_group$$=new $APP.$cljs$core$Keyword$$(null,"text-font-group","text-font-group",-123303706);$cljs$cst$3639$no_select_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"no-select?","no-select?",345814430);
$cljs$cst$2785$preserveAlpha$$=new $APP.$cljs$core$Keyword$$(null,"preserveAlpha","preserveAlpha",258823046);$cljs$cst$2830$begin$$=new $APP.$cljs$core$Keyword$$(null,"begin","begin",-319034319);$cljs$cst$2860$lengthAdjust$$=new $APP.$cljs$core$Keyword$$(null,"lengthAdjust","lengthAdjust",1978553687);$APP.$cljs$cst$646$parser$$=new $APP.$cljs$core$Keyword$$(null,"parser","parser",-1543495310);$APP.$cljs$cst$4797$draw_ellipse$$=new $APP.$cljs$core$Keyword$$(null,"draw-ellipse","draw-ellipse",-1242523678);
$APP.$cljs$cst$4395$from_frame_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"from-frame?","from-frame?",-131850262);$cljs$cst$5265$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_prev_frame$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","select-prev-frame","app.main.data.viewer/select-prev-frame",-1525895540);$APP.$cljs$cst$2031$color_dodge$$=new $APP.$cljs$core$Keyword$$(null,"color-dodge","color-dodge",-1461064835);
$APP.$cljs$cst$5289$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","select-shape","app.main.data.viewer/select-shape",-1797220962);$APP.$cljs$cst$2473$confirm$$=new $APP.$cljs$core$Keyword$$(null,"confirm","confirm",-2004000608);$APP.$cljs$cst$4142$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_fill$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","remove-fill","app.main.data.workspace.colors/remove-fill",-1701933108);
$APP.$cljs$cst$1659$grid$$=new $APP.$cljs$core$Keyword$$(null,"grid","grid",402978600);$cljs$cst$689$seqable_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"seqable?","seqable?",72462495,null);$cljs$cst$1092$splice$$=new $APP.$cljs$core$Keyword$$(null,"splice","splice",449588165);$cljs$cst$3168$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_component_id$$=new $APP.$cljs$core$Keyword$$("app.common.files.changes-builder","component-id","app.common.files.changes-builder/component-id",1959593011);
$APP.$cljs$cst$255$length$$=new $APP.$cljs$core$Keyword$$(null,"length","length",588987862);$cljs$cst$4378$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_shapes_to_path_SLASH_convert_selected_strokes_to_path$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.shapes-to-path","convert-selected-strokes-to-path","app.main.data.workspace.path.shapes-to-path/convert-selected-strokes-to-path",1094697921);$APP.$cljs$cst$5154$webhook$$=new $APP.$cljs$core$Keyword$$(null,"webhook","webhook",-860093016);
$APP.$cljs$cst$5410$recovery_email_sent$$=new $APP.$cljs$core$Keyword$$(null,"recovery-email-sent","recovery-email-sent",721273155);$APP.$cljs$cst$1710$layout_item_align_self$$=new $APP.$cljs$core$Keyword$$(null,"layout-item-align-self","layout-item-align-self",-1976194692);
$cljs$cst$4225$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_end_edition$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","end-edition","app.main.data.workspace.path.drawing/end-edition",-228545187);$cljs$cst$2671$pre_context_lost_options_mode$$=new $APP.$cljs$core$Keyword$$(null,"pre-context-lost-options-mode","pre-context-lost-options-mode",-1707695620);$APP.$cljs$cst$3185$photo_url$$=new $APP.$cljs$core$Keyword$$(null,"photo-url","photo-url",-1816449182);
$cljs$cst$3680$inkscape_COLON_label$$=new $APP.$cljs$core$Keyword$$(null,"inkscape:label","inkscape:label",-1121170584);$cljs$cst$763$keywordize_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"keywordize?","keywordize?",-234306912);$APP.$cljs$cst$1921$selected$$=new $APP.$cljs$core$Keyword$$(null,"selected","selected",574897764);
$cljs$cst$4441$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_combine_as_variants$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","combine-as-variants","app.main.data.workspace.variants/combine-as-variants",1023651382);$cljs$cst$5300$prev_frame$$=new $APP.$cljs$core$Keyword$$(null,"prev-frame","prev-frame",1252533703);
$cljs$cst$3892$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_ids$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.wasm-text","resize-wasm-text-debounce-ids","app.main.data.workspace.wasm-text/resize-wasm-text-debounce-ids",900652551);$APP.$cljs$cst$4972$app_DOT_main_DOT_data_DOT_dashboard_SLASH_handle_user_org_change$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","handle-user-org-change","app.main.data.dashboard/handle-user-org-change",-1069405331);
$cljs$cst$1259$enable_dashboard_templates_section$$=new $APP.$cljs$core$Keyword$$(null,"enable-dashboard-templates-section","enable-dashboard-templates-section",-667416679);$APP.$cljs$cst$2613$operations$$=new $APP.$cljs$core$Keyword$$(null,"operations","operations",1630691895);$cljs$cst$4287$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_update_guides$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.guides","update-guides","app.main.data.workspace.guides/update-guides",1416907688);
$APP.$cljs$cst$162$fn_STAR_$$=new $APP.$cljs$core$Symbol$$(null,"fn*","fn*",-752876845,null);$cljs$cst$392$child$$=new $APP.$cljs$core$Keyword$$(null,"child","child",623967545);$APP.$cljs$cst$3107$app_DOT_main_DOT_features_SLASH_enable_feature$$=new $APP.$cljs$core$Keyword$$("app.main.features","enable-feature","app.main.features/enable-feature",-2137493388);$cljs$cst$705$fn_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"fn?","fn?",1820990818,null);
$cljs$cst$532$dispatch$$=new $APP.$cljs$core$Keyword$$(null,"dispatch","dispatch",1319337009);$cljs$cst$2936$paint_order$$=new $APP.$cljs$core$Keyword$$(null,"paint-order","paint-order",1313558207);$cljs$cst$3336$app_DOT_main_DOT_data_DOT_websocket_SLASH_finalize$$=new $APP.$cljs$core$Keyword$$("app.main.data.websocket","finalize","app.main.data.websocket/finalize",-1838092854);
$APP.$cljs$cst$2333$external_session_id$$=new $APP.$cljs$core$Keyword$$(null,"external-session-id","external-session-id",-965075146);$APP.$cljs$cst$3184$theme$$=new $APP.$cljs$core$Keyword$$(null,"theme","theme",-1247880880);$APP.$cljs$cst$1812$command$$=new $APP.$cljs$core$Keyword$$(null,"command","command",-894540724);$cljs$cst$3096$blur_downscale_threshold$$=new $APP.$cljs$core$Keyword$$(null,"blur_downscale_threshold","blur_downscale_threshold",-2143755978);
$cljs$cst$2908$writing_mode$$=new $APP.$cljs$core$Keyword$$(null,"writing-mode","writing-mode",-1707110905);$APP.$cljs$cst$4498$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_assets_group_open$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","set-assets-group-open","app.main.data.workspace/set-assets-group-open",1694747588);
$APP.$cljs$cst$5247$app_DOT_main_DOT_data_DOT_viewer_SLASH_fetch_comment_threads$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","fetch-comment-threads","app.main.data.viewer/fetch-comment-threads",1999699180);$APP.$cljs$cst$3124$transfer$$=new $APP.$cljs$core$Keyword$$(null,"transfer","transfer",327423400);$cljs$cst$4783$selected_shapes_data$$=new $APP.$cljs$core$Symbol$$(null,"selected-shapes-data","selected-shapes-data",-1378388112,null);
$cljs$cst$3537$shapes_group$$=new $APP.$cljs$core$Keyword$$(null,"shapes-group","shapes-group",1443424131);$APP.$cljs$cst$2952$bot$$=new $APP.$cljs$core$Keyword$$(null,"bot","bot",-950896508);$cljs$cst$4393$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_initialize_shape_layout$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","initialize-shape-layout","app.main.data.workspace.shape-layout/initialize-shape-layout",-2040772463);
$cljs$cst$5264$app_DOT_main_DOT_data_DOT_viewer_SLASH_close_thumbnails_panel$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","close-thumbnails-panel","app.main.data.viewer/close-thumbnails-panel",846917843);$APP.$cljs$cst$4467$workspace_media_objects$$=new $APP.$cljs$core$Keyword$$(null,"workspace-media-objects","workspace-media-objects",-1373417168);$APP.$cljs$cst$1987$horizontal_margin$$=new $APP.$cljs$core$Keyword$$(null,"horizontal-margin","horizontal-margin",1659318629);
$APP.$cljs$cst$4047$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_replace_layer_names_in_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","replace-layer-names-in-shapes","app.main.data.workspace.texts/replace-layer-names-in-shapes",-332716750);$APP.$cljs$cst$3268$invitations$$=new $APP.$cljs$core$Keyword$$(null,"invitations","invitations",-1668975235);$cljs$cst$1802$reflow$$=new $APP.$cljs$core$Keyword$$(null,"reflow","reflow",-1736202629);
$cljs$cst$3677$strokeCapStart$$=new $APP.$cljs$core$Keyword$$(null,"strokeCapStart","strokeCapStart",-1203895731);$cljs$cst$3306$app_DOT_main_DOT_data_DOT_team_SLASH_update_invitation_role$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","update-invitation-role","app.main.data.team/update-invitation-role",-1416415162);$cljs$cst$3983$link_file_to_library$$=new $APP.$cljs$core$Keyword$$(null,"link-file-to-library","link-file-to-library",448879413);
$cljs$cst$2223$workspace_v2_editor_state$$=new $APP.$cljs$core$Keyword$$(null,"workspace-v2-editor-state","workspace-v2-editor-state",-2092501766);$APP.$cljs$cst$570$errors$$=new $APP.$cljs$core$Keyword$$(null,"errors","errors",-908790718);$APP.$cljs$cst$3082$features_runtime$$=new $APP.$cljs$core$Keyword$$(null,"features-runtime","features-runtime",-389800627);$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$=new $APP.$cljs$core$Keyword$$("app.common.time","inst","app.common.time/inst",1401175972);
$APP.$cljs$cst$4024$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_commit_update_text_modifier$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","commit-update-text-modifier","app.main.data.workspace.texts/commit-update-text-modifier",-898731876);$APP.$cljs$cst$6374$settings_options$$=new $APP.$cljs$core$Keyword$$(null,"settings-options","settings-options",1577810826);
$cljs$cst$951$app_DOT_common_DOT_schema_SLASH_vec$$=new $APP.$cljs$core$Keyword$$("app.common.schema","vec","app.common.schema/vec",801005460);$APP.$cljs$cst$2370$prepend$$=new $APP.$cljs$core$Keyword$$(null,"prepend","prepend",342616040);$APP.$cljs$cst$2716$font$$=new $APP.$cljs$core$Keyword$$(null,"font","font",-1506159249);
$APP.$cljs$cst$3156$app_DOT_main_DOT_data_DOT_persistence_SLASH_persist_commit$$=new $APP.$cljs$core$Keyword$$("app.main.data.persistence","persist-commit","app.main.data.persistence/persist-commit",-1661371886);$cljs$cst$4233$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_check_changed_content$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","check-changed-content","app.main.data.workspace.path.drawing/check-changed-content",1678819773);
$cljs$cst$1163$fatal$$=new $APP.$cljs$core$Keyword$$(null,"fatal","fatal",1874419888);$APP.$cljs$cst$2208$hover_ids$$=new $APP.$cljs$core$Keyword$$(null,"hover-ids","hover-ids",-792079290);$cljs$cst$4159$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_color_in_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","change-color-in-selected","app.main.data.workspace.colors/change-color-in-selected",-438070394);
$cljs$cst$2700$feDisplacementMap$$=new $APP.$cljs$core$Keyword$$(null,"feDisplacementMap","feDisplacementMap",176959495);$cljs$cst$3357$app_DOT_main_DOT_data_DOT_auth_SLASH_logout$$=new $APP.$cljs$core$Keyword$$("app.main.data.auth","logout","app.main.data.auth/logout",1269314021);$APP.$cljs$cst$3224$update_profile_notifications$$=new $APP.$cljs$core$Keyword$$(null,"update-profile-notifications","update-profile-notifications",1757892382);
$cljs$cst$2463$app_DOT_main_DOT_router_SLASH_nav_raw$$=new $APP.$cljs$core$Keyword$$("app.main.router","nav-raw","app.main.router/nav-raw",-70793015);$cljs$cst$4372$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_rename_page$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.pages","rename-page","app.main.data.workspace.pages/rename-page",-862208872);
$cljs$cst$4119$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_text$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","paste-text","app.main.data.workspace.clipboard/paste-text",729394274);$cljs$cst$5385$go_back_callback$$=new $APP.$cljs$core$Keyword$$(null,"go-back-callback","go-back-callback",-551843948);
$cljs$cst$3869$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_start_move_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","start-move-selected","app.main.data.workspace.transforms/start-move-selected",1856855753);
$APP.$cljs$cst$4759$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_show_workspace_export_frames_dialog$$=new $APP.$cljs$core$Keyword$$("app.main.data.exports.assets","show-workspace-export-frames-dialog","app.main.data.exports.assets/show-workspace-export-frames-dialog",-1173311717);$cljs$cst$4651$frame_children$$=new $APP.$cljs$core$Keyword$$(null,"frame-children","frame-children",-1877478373);
$APP.$cljs$cst$3161$app_DOT_main_DOT_data_DOT_persistence_SLASH_run_persistence_task$$=new $APP.$cljs$core$Keyword$$("app.main.data.persistence","run-persistence-task","app.main.data.persistence/run-persistence-task",852560259);$APP.$cljs$cst$2315$file_stats$$=new $APP.$cljs$core$Keyword$$(null,"file-stats","file-stats",1549464101);
$cljs$cst$4484$app_DOT_main_DOT_data_DOT_workspace_SLASH_relocate_selected_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","relocate-selected-shapes","app.main.data.workspace/relocate-selected-shapes",-426112807);$APP.$cljs$cst$2183$selected_files$$=new $APP.$cljs$core$Keyword$$(null,"selected-files","selected-files",1045525459);$APP.$cljs$cst$4831$copy_props$$=new $APP.$cljs$core$Keyword$$(null,"copy-props","copy-props",1215339691);
$APP.$cljs$cst$1557$event_type$$=new $APP.$cljs$core$Keyword$$(null,"event-type","event-type",319722813);$APP.$cljs$cst$4042$original_content$$=new $APP.$cljs$core$Keyword$$(null,"original-content","original-content",-527645724);$APP.$cljs$cst$1867$blend_mode$$=new $APP.$cljs$core$Keyword$$(null,"blend-mode","blend-mode",-1393007224);$cljs$cst$2984$japanese$$=new $APP.$cljs$core$Keyword$$(null,"japanese","japanese",-331893406);
$cljs$cst$1466$directive$$=new $APP.$cljs$core$Keyword$$(null,"directive","directive",793559132);$cljs$cst$4631$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_layout_item_margin$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","update-layout-item-margin","app.main.data.workspace.tokens.application/update-layout-item-margin",740999564);$APP.$cljs$cst$3876$big$$=new $APP.$cljs$core$Keyword$$(null,"big","big",903550151);
$APP.$cljs$cst$3223$notifications$$=new $APP.$cljs$core$Keyword$$(null,"notifications","notifications",1685638001);$APP.$cljs$cst$3779$background_color$$=new $APP.$cljs$core$Keyword$$(null,"background-color","background-color",570434026);$cljs$cst$3380$feature_mismatch$$=new $APP.$cljs$core$Keyword$$(null,"feature-mismatch","feature-mismatch",-514436878);$cljs$cst$3101$image_resources$$=new $APP.$cljs$core$Keyword$$(null,"image-resources","image-resources",-2012689410);
$cljs$cst$3893$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce_inner$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.wasm-text","resize-wasm-text-debounce-inner","app.main.data.workspace.wasm-text/resize-wasm-text-debounce-inner",995485041);$APP.$cljs$cst$179$form$$=new $APP.$cljs$core$Keyword$$(null,"form","form",-1624062471);$APP.$cljs$cst$1630$pages_index$$=new $APP.$cljs$core$Keyword$$(null,"pages-index","pages-index",-1376462145);
$APP.$cljs$cst$1608$group$$=new $APP.$cljs$core$Keyword$$(null,"group","group",582596132);$APP.$cljs$cst$4973$deleted_teams$$=new $APP.$cljs$core$Keyword$$(null,"deleted-teams","deleted-teams",-1407234344);$cljs$cst$4590$error_DOT_style_dictionary_SLASH_invalid_token_value_opacity$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","invalid-token-value-opacity","error.style-dictionary/invalid-token-value-opacity",-1542237618);
$APP.$cljs$cst$3714$sitemap$$=new $APP.$cljs$core$Keyword$$(null,"sitemap","sitemap",-1803284096);$APP.$cljs$cst$4394$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_finalize_shape_layout$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","finalize-shape-layout","app.main.data.workspace.shape-layout/finalize-shape-layout",1203299725);
$APP.$cljs$cst$4958$app_DOT_main_DOT_data_DOT_dashboard_SLASH_create_file$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","create-file","app.main.data.dashboard/create-file",1672646055);$cljs$cst$1402$mandatory$$=new $APP.$cljs$core$Keyword$$(null,"mandatory","mandatory",542802336);$APP.$cljs$cst$2003$variant_error$$=new $APP.$cljs$core$Keyword$$(null,"variant-error","variant-error",-42521934);
$APP.$cljs$cst$4221$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_start_path_from_point$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","start-path-from-point","app.main.data.workspace.path.drawing/start-path-from-point",1488097888);$APP.$cljs$cst$1178$registration$$=new $APP.$cljs$core$Keyword$$(null,"registration","registration",1079145595);$cljs$cst$2957$on_hold$$=new $APP.$cljs$core$Keyword$$(null,"on-hold","on-hold",-295274098);
$cljs$cst$4764$healthy_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"healthy?","healthy?",1027593366);$APP.$cljs$cst$751$password$$=new $APP.$cljs$core$Keyword$$(null,"password","password",417022471);$cljs$cst$3691$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_svg_uploaded$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.media","svg-uploaded","app.main.data.workspace.media/svg-uploaded",960276736);
$APP.$cljs$cst$2084$skip_copies_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"skip-copies?","skip-copies?",1278015996);$cljs$cst$3640$no_update_layout_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"no-update-layout?","no-update-layout?",-390161987);
$cljs$cst$3886$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_flip_horizontal_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","flip-horizontal-selected","app.main.data.workspace.transforms/flip-horizontal-selected",702685415);$cljs$cst$1318$leading$$=new $APP.$cljs$core$Keyword$$(null,"leading","leading",-1239035032);$APP.$cljs$cst$2610$add_obj$$=new $APP.$cljs$core$Keyword$$(null,"add-obj","add-obj",-1569519983);
$cljs$cst$4817$open_inspect$$=new $APP.$cljs$core$Keyword$$(null,"open-inspect","open-inspect",-59540794);$cljs$cst$4507$disable_flatten_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"disable-flatten?","disable-flatten?",1058516011);$APP.$cljs$cst$3395$throwValidationErrors$$=new $APP.$cljs$core$Keyword$$(null,"throwValidationErrors","throwValidationErrors",1845405210);$cljs$cst$2618$allow_altering_copies$$=new $APP.$cljs$core$Keyword$$(null,"allow-altering-copies","allow-altering-copies",1930197967);
$cljs$cst$3287$app_DOT_main_DOT_data_DOT_team_SLASH_team_created$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","team-created","app.main.data.team/team-created",-1962244948);$cljs$cst$423$qualified_symbol$$=new $APP.$cljs$core$Keyword$$(null,"qualified-symbol","qualified-symbol",-665513695);
$cljs$cst$3945$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_fetch_library_thumbnails$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","fetch-library-thumbnails","app.main.data.workspace.libraries/fetch-library-thumbnails",-946653266);$cljs$cst$1256$enable_secure_session_cookies$$=new $APP.$cljs$core$Keyword$$(null,"enable-secure-session-cookies","enable-secure-session-cookies",-811252810);
$APP.$cljs$cst$2628$add_media$$=new $APP.$cljs$core$Keyword$$(null,"add-media","add-media",1778802009);$cljs$cst$4752$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_toggle_detail_visibililty$$=new $APP.$cljs$core$Keyword$$("app.main.data.exports.assets","toggle-detail-visibililty","app.main.data.exports.assets/toggle-detail-visibililty",-630730977);$cljs$cst$3783$thumbnail_uri$$=new $APP.$cljs$core$Keyword$$(null,"thumbnail-uri","thumbnail-uri",1904972561);
$cljs$cst$4773$force_multiple$$=new $APP.$cljs$core$Keyword$$(null,"force-multiple","force-multiple",1918068049);$APP.$cljs$cst$4823$toggle_layout_grid$$=new $APP.$cljs$core$Keyword$$(null,"toggle-layout-grid","toggle-layout-grid",-1385848312);$APP.$cljs$cst$5311$delete_node$$=new $APP.$cljs$core$Keyword$$(null,"delete-node","delete-node",-573394678);$APP.$cljs$cst$5244$libraries$$=new $APP.$cljs$core$Keyword$$(null,"libraries","libraries",-303286011);
$APP.$cljs$cst$1678$justify_self$$=new $APP.$cljs$core$Keyword$$(null,"justify-self","justify-self",-2135975605);$cljs$cst$2774$intercept$$=new $APP.$cljs$core$Keyword$$(null,"intercept","intercept",-2141938204);$cljs$cst$3644$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_move_shapes_into_frame$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","move-shapes-into-frame","app.main.data.workspace.shapes/move-shapes-into-frame",1690401691);
$cljs$cst$225$else$$=new $APP.$cljs$core$Keyword$$(null,"else","else",-1508377146);$cljs$cst$416$from_ast$$=new $APP.$cljs$core$Keyword$$(null,"from-ast","from-ast",-246238449);$cljs$cst$1425$seq$$=new $APP.$cljs$core$Keyword$$(null,"seq","seq",-1817803783);$cljs$cst$254$sep$$=new $APP.$cljs$core$Keyword$$(null,"sep","sep",1970430530);$cljs$cst$1490$defn$$=new $APP.$cljs$core$Symbol$$(null,"defn","defn",-126010802,null);$APP.$cljs$cst$203$set$$=new $APP.$cljs$core$Keyword$$(null,"set","set",304602554);
$APP.$cljs$cst$5310$draw_nodes$$=new $APP.$cljs$core$Keyword$$(null,"draw-nodes","draw-nodes",1085190985);$APP.$cljs$cst$1559$scroll_left$$=new $APP.$cljs$core$Keyword$$(null,"scroll-left","scroll-left",-211761103);$cljs$cst$4585$error_DOT_token_SLASH_number_too_large$$=new $APP.$cljs$core$Keyword$$("error.token","number-too-large","error.token/number-too-large",1728828587);$cljs$cst$4055$max_block_size$$=new $APP.$cljs$core$Keyword$$(null,"max-block-size","max-block-size",-1751985816);
$cljs$cst$3962$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_sync_file$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","sync-file","app.main.data.workspace.libraries/sync-file",-2095175456);$cljs$cst$1275$major$$=new $APP.$cljs$core$Keyword$$(null,"major","major",-27376078);$cljs$cst$1518$app_DOT_common_DOT_geom_DOT_point_SLASH_point$$=new $APP.$cljs$core$Keyword$$("app.common.geom.point","point","app.common.geom.point/point",1811057644);
$cljs$cst$4778$app_DOT_main_DOT_data_DOT_preview_SLASH_open_preview_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.preview","open-preview-selected","app.main.data.preview/open-preview-selected",532840787);$APP.$cljs$cst$1755$frontend_binary_fills$$=new $APP.$cljs$core$Keyword$$(null,"frontend-binary-fills","frontend-binary-fills",-342747503);$cljs$cst$3814$child_max_width$$=new $APP.$cljs$core$Keyword$$(null,"child-max-width","child-max-width",-1197823794);
$APP.$cljs$cst$2750$polygon$$=new $APP.$cljs$core$Keyword$$(null,"polygon","polygon",837053759);$cljs$cst$3212$app_DOT_main_DOT_data_DOT_profile_SLASH_cancel_email_change$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","cancel-email-change","app.main.data.profile/cancel-email-change",-957917627);$cljs$cst$5084$on_change_value$$=new $APP.$cljs$core$Keyword$$(null,"on-change-value","on-change-value",-922771799);$cljs$cst$1438$colinc$$=new $APP.$cljs$core$Keyword$$(null,"colinc","colinc",-584873385);
$APP.$cljs$cst$1888$bool_type$$=new $APP.$cljs$core$Keyword$$(null,"bool-type","bool-type",-1094918459);$cljs$cst$1324$sch$$=new $APP.$cljs$core$Keyword$$(null,"sch","sch",-877249434);$cljs$cst$3594$board_id$$=new $APP.$cljs$core$Keyword$$(null,"board-id","board-id",-1767919501);$cljs$cst$3545$alt_duplication_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"alt-duplication?","alt-duplication?",650822057);$cljs$cst$721$every$$=new $APP.$cljs$core$Keyword$$(null,"every","every",-2060295878);
$APP.$cljs$cst$3930$initial_point$$=new $APP.$cljs$core$Keyword$$(null,"initial-point","initial-point",-1460665937);$cljs$cst$3207$update_profile$$=new $APP.$cljs$core$Keyword$$(null,"update-profile","update-profile",1458083625);$APP.$cljs$cst$3322$get_team_shared_files$$=new $APP.$cljs$core$Keyword$$(null,"get-team-shared-files","get-team-shared-files",1195206608);$cljs$cst$5008$is_hover$$=new $APP.$cljs$core$Keyword$$(null,"is-hover","is-hover",967709367);
$cljs$cst$1338$app_DOT_util_DOT_storage_SLASH_last_refresh$$=new $APP.$cljs$core$Keyword$$("app.util.storage","last-refresh","app.util.storage/last-refresh",-1234332050);$APP.$cljs$cst$3462$get_comments$$=new $APP.$cljs$core$Keyword$$(null,"get-comments","get-comments",1914340167);$APP.$cljs$cst$93$right$$=new $APP.$cljs$core$Symbol$$(null,"right","right",1187949694,null);$cljs$cst$3453$delete_comment_thread$$=new $APP.$cljs$core$Keyword$$(null,"delete-comment-thread","delete-comment-thread",-1495575933);
$cljs$cst$4049$border_style$$=new $APP.$cljs$core$Keyword$$(null,"border-style","border-style",-485574304);$APP.$cljs$cst$3767$head$$=new $APP.$cljs$core$Keyword$$(null,"head","head",-771383919);$APP.$cljs$cst$6307$change_email$$=new $APP.$cljs$core$Keyword$$(null,"change-email","change-email",-1066380073);$APP.$cljs$cst$3606$include_frames_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"include-frames?","include-frames?",-256091430);
$APP.$cljs$cst$3502$app_DOT_main_DOT_data_DOT_fonts_SLASH_update_font$$=new $APP.$cljs$core$Keyword$$("app.main.data.fonts","update-font","app.main.data.fonts/update-font",1239820208);$APP.$cljs$cst$4829$flip_horizontal$$=new $APP.$cljs$core$Keyword$$(null,"flip-horizontal","flip-horizontal",1160987018);
$cljs$cst$4037$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_v2_update_text_editor_styles$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","v2-update-text-editor-styles","app.main.data.workspace.texts/v2-update-text-editor-styles",-1649752436);$APP.$cljs$cst$2511$default_project_id$$=new $APP.$cljs$core$Keyword$$(null,"default-project-id","default-project-id",-850768589);
$APP.$cljs$cst$3228$release_notes_viewed$$=new $APP.$cljs$core$Keyword$$(null,"release-notes-viewed","release-notes-viewed",-1668623270);$cljs$cst$5211$variant_component_bad_id$$=new $APP.$cljs$core$Keyword$$(null,"variant-component-bad-id","variant-component-bad-id",1038925937);$cljs$cst$2889$gradientTransform$$=new $APP.$cljs$core$Keyword$$(null,"gradientTransform","gradientTransform",-364684930);$cljs$cst$2633$del_component$$=new $APP.$cljs$core$Keyword$$(null,"del-component","del-component",-883241442);
$cljs$cst$2996$ethiopic$$=new $APP.$cljs$core$Keyword$$(null,"ethiopic","ethiopic",1727041736);$cljs$cst$566$malli_DOT_core_SLASH_explain_input$$=new $APP.$cljs$core$Keyword$$("malli.core","explain-input","malli.core/explain-input",1441627811);$cljs$cst$3006$thai$$=new $APP.$cljs$core$Keyword$$(null,"thai","thai",-49788081);$APP.$cljs$cst$5569$comma$$=new $APP.$cljs$core$Keyword$$(null,"comma","comma",1699024745);
$cljs$cst$1301$arrayBuilder$$=new $APP.$cljs$core$Keyword$$(null,"arrayBuilder","arrayBuilder",1446317421);$cljs$cst$801$clojure_DOT_test_DOT_check_DOT_generators_SLASH_large_integer_STAR_$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","large-integer*","clojure.test.check.generators/large-integer*",-437830670,null);$cljs$cst$3864$no_wasm_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"no-wasm?","no-wasm?",1342151640);
$cljs$cst$1903$image_fix$$=new $APP.$cljs$core$Keyword$$(null,"image-fix","image-fix",-823773862);$APP.$cljs$cst$5407$recovery_request$$=new $APP.$cljs$core$Keyword$$(null,"recovery-request","recovery-request",-1814480618);$cljs$cst$1174$oidc_registration$$=new $APP.$cljs$core$Keyword$$(null,"oidc-registration","oidc-registration",528293329);
$cljs$cst$4481$app_DOT_main_DOT_data_DOT_workspace_SLASH_vertical_order_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","vertical-order-selected","app.main.data.workspace/vertical-order-selected",826004224);$cljs$cst$2715$feSpotLight$$=new $APP.$cljs$core$Keyword$$(null,"feSpotLight","feSpotLight",663371214);$cljs$cst$768$seed$$=new $APP.$cljs$core$Keyword$$(null,"seed","seed",68613327);$APP.$cljs$cst$2452$validate$$=new $APP.$cljs$core$Keyword$$(null,"validate","validate",-201300827);
$APP.$cljs$cst$2322$app_DOT_main_DOT_data_DOT_event_SLASH_snapshot_performance_info$$=new $APP.$cljs$core$Keyword$$("app.main.data.event","snapshot-performance-info","app.main.data.event/snapshot-performance-info",116165252);$cljs$cst$4577$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","invalid-token-value-shadow","error.style-dictionary/invalid-token-value-shadow",1280239811);
$cljs$cst$1303$mapBuilder$$=new $APP.$cljs$core$Keyword$$(null,"mapBuilder","mapBuilder",-278083754);$cljs$cst$2637$purge_component$$=new $APP.$cljs$core$Keyword$$(null,"purge-component","purge-component",2041170044);$cljs$cst$2681$app_DOT_main_DOT_fonts_SLASH_woff1_file_id$$=new $APP.$cljs$core$Keyword$$("app.main.fonts","woff1-file-id","app.main.fonts/woff1-file-id",2117136543);$APP.$cljs$cst$2498$hints$$=new $APP.$cljs$core$Keyword$$(null,"hints","hints",-991113151);
$APP.$cljs$cst$3079$itype$$=new $APP.$cljs$core$Keyword$$(null,"itype","itype",-1679163844);$APP.$cljs$cst$2324$app_DOT_main_DOT_data_DOT_event_SLASH_store_performace_info$$=new $APP.$cljs$core$Keyword$$("app.main.data.event","store-performace-info","app.main.data.event/store-performace-info",1565391522);$cljs$cst$606$malli_DOT_core_SLASH_non_function_childs$$=new $APP.$cljs$core$Keyword$$("malli.core","non-function-childs","malli.core/non-function-childs",-1591582832);
$cljs$cst$1305$preferStrings$$=new $APP.$cljs$core$Keyword$$(null,"preferStrings","preferStrings",-1532249482);$cljs$cst$902$malli_DOT_transform_SLASH_compiled$$=new $APP.$cljs$core$Keyword$$("malli.transform","compiled","malli.transform/compiled",-1910053091);$cljs$cst$2582$app_DOT_common_DOT_types_DOT_file_SLASH_colors$$=new $APP.$cljs$core$Keyword$$("app.common.types.file","colors","app.common.types.file/colors",880706307);
$cljs$cst$4216$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_add_node$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","add-node","app.main.data.workspace.path.drawing/add-node",1655796338);$cljs$cst$1183$smtp_debug$$=new $APP.$cljs$core$Keyword$$(null,"smtp-debug","smtp-debug",1778374773);$cljs$cst$3000$telugu$$=new $APP.$cljs$core$Keyword$$(null,"telugu","telugu",-687861364);
$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$=new $APP.$cljs$core$Keyword$$("app.common.schema.openapi","type","app.common.schema.openapi/type",-2037057739);$APP.$cljs$cst$3535$reset_touched_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"reset-touched?","reset-touched?",1763538527);$APP.$cljs$cst$4920$get_builtin_templates$$=new $APP.$cljs$core$Keyword$$(null,"get-builtin-templates","get-builtin-templates",-981643185);
$cljs$cst$3527$new_component_file$$=new $APP.$cljs$core$Keyword$$(null,"new-component-file","new-component-file",1499041440);$cljs$cst$1081$min_count$$=new $APP.$cljs$core$Keyword$$(null,"min-count","min-count",1594709013);$cljs$cst$3672$xmlns$$=new $APP.$cljs$core$Keyword$$(null,"xmlns","xmlns",-1862095571);$APP.$cljs$cst$2035$auto_height$$=new $APP.$cljs$core$Keyword$$(null,"auto-height","auto-height",-960519663);
$APP.$cljs$cst$3531$old_id$$=new $APP.$cljs$core$Keyword$$(null,"old-id","old-id",-512581150);$cljs$cst$2876$requiredFeatures$$=new $APP.$cljs$core$Keyword$$(null,"requiredFeatures","requiredFeatures",207337914);$cljs$cst$3811$children_data$$=new $APP.$cljs$core$Keyword$$(null,"children-data","children-data",2027614482);$cljs$cst$3941$retries$$=new $APP.$cljs$core$Keyword$$(null,"retries","retries",1888092808);
$cljs$cst$4192$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_setup_frame$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.drawing.curve","setup-frame","app.main.data.workspace.drawing.curve/setup-frame",149327428);$APP.$cljs$cst$4984$neutral$$=new $APP.$cljs$core$Keyword$$(null,"neutral","neutral",-1941956087);$cljs$cst$1595$owner$$=new $APP.$cljs$core$Keyword$$(null,"owner","owner",-392611939);
$APP.$cljs$cst$5161$thumbnail$$=new $APP.$cljs$core$Keyword$$(null,"thumbnail","thumbnail",-867906798);$cljs$cst$4403$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_add_layout_track$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","add-layout-track","app.main.data.workspace.shape-layout/add-layout-track",1339707980);$APP.$cljs$cst$5082$placeholder$$=new $APP.$cljs$core$Keyword$$(null,"placeholder","placeholder",-104873083);
$cljs$cst$3598$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_deselect_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","deselect-shape","app.main.data.workspace.selection/deselect-shape",-406856111);$APP.$cljs$cst$4549$js_SLASH_observer$$=new $APP.$cljs$core$Keyword$$("js","observer","js/observer",-1103718059);$APP.$cljs$cst$5839$maxHeight$$=new $APP.$cljs$core$Keyword$$(null,"maxHeight","maxHeight",-2066822365);
$APP.$cljs$cst$2656$before_path$$=new $APP.$cljs$core$Keyword$$(null,"before-path","before-path",-1341220519);$cljs$cst$1260$enable_google_fonts_provider$$=new $APP.$cljs$core$Keyword$$(null,"enable-google-fonts-provider","enable-google-fonts-provider",-325404774);$APP.$cljs$cst$3555$drag_handler$$=new $APP.$cljs$core$Keyword$$(null,"drag-handler","drag-handler",401100376);$APP.$cljs$cst$2354$callback$$=new $APP.$cljs$core$Keyword$$(null,"callback","callback",-705136228);
$APP.$cljs$cst$3158$app_DOT_main_DOT_data_DOT_persistence_SLASH_error$$=new $APP.$cljs$core$Keyword$$("app.main.data.persistence","error","app.main.data.persistence/error",-446088197);$APP.$cljs$cst$5390$email_already_exists$$=new $APP.$cljs$core$Keyword$$(null,"email-already-exists","email-already-exists",-516776612);
$cljs$cst$4004$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_editor_state$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","update-editor-state","app.main.data.workspace.texts/update-editor-state",1174660022);$cljs$cst$414$to_ast$$=new $APP.$cljs$core$Keyword$$(null,"to-ast","to-ast",-21935298);$cljs$cst$989$cljs_DOT_core_SLASH_map_QMARK_$$=new $APP.$cljs$core$Symbol$$("cljs.core","map?","cljs.core/map?",-1390345523,null);
$APP.$cljs$cst$2350$controls$$=new $APP.$cljs$core$Keyword$$(null,"controls","controls",1340701452);$APP.$cljs$cst$1619$parent_id$$=new $APP.$cljs$core$Keyword$$(null,"parent-id","parent-id",-1400729131);$cljs$cst$2669$app_DOT_main_DOT_data_DOT_render_wasm_SLASH_context_lost$$=new $APP.$cljs$core$Keyword$$("app.main.data.render-wasm","context-lost","app.main.data.render-wasm/context-lost",456976323);$cljs$cst$3010$tibetan$$=new $APP.$cljs$core$Keyword$$(null,"tibetan","tibetan",-1226351341);
$cljs$cst$350$malli_DOT_core_SLASH_duplicate_arities$$=new $APP.$cljs$core$Keyword$$("malli.core","duplicate-arities","malli.core/duplicate-arities",-374423504);$cljs$cst$2770$requiredExtensions$$=new $APP.$cljs$core$Keyword$$(null,"requiredExtensions","requiredExtensions",-1251917917);$APP.$cljs$cst$3682$create_file_media_object_from_url$$=new $APP.$cljs$core$Keyword$$(null,"create-file-media-object-from-url","create-file-media-object-from-url",660909681);
$cljs$cst$4269$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_handle_drawing$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.drawing","handle-drawing","app.main.data.workspace.drawing/handle-drawing",124524270);$cljs$cst$2874$rendering_intent$$=new $APP.$cljs$core$Keyword$$(null,"rendering-intent","rendering-intent",-45468422);$cljs$cst$658$malli_DOT_core$$=new $APP.$cljs$core$Symbol$$(null,"malli.core","malli.core",-2051169970,null);
$APP.$cljs$cst$5071$seats$$=new $APP.$cljs$core$Keyword$$(null,"seats","seats",936438203);$APP.$cljs$cst$2394$reitit_DOT_impl_SLASH_accumulator$$=new $APP.$cljs$core$Keyword$$("reitit.impl","accumulator","reitit.impl/accumulator",1345422212);$cljs$cst$5235$unresolved$$=new $APP.$cljs$core$Keyword$$(null,"unresolved","unresolved",833458441);$APP.$cljs$cst$4826$toggle_guides$$=new $APP.$cljs$core$Keyword$$(null,"toggle-guides","toggle-guides",-17172503);
$cljs$cst$4046$prev_content$$=new $APP.$cljs$core$Keyword$$(null,"prev-content","prev-content",165417916);$cljs$cst$1170$login_with_gitlab$$=new $APP.$cljs$core$Keyword$$(null,"login-with-gitlab","login-with-gitlab",-81921144);$APP.$cljs$cst$3180$before_group_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"before-group?","before-group?",1667453550);$cljs$cst$904$this$$=new $APP.$cljs$core$Keyword$$(null,"this","this",-611633625);
$APP.$cljs$cst$960$app_DOT_common_DOT_schema_SLASH_number$$=new $APP.$cljs$core$Keyword$$("app.common.schema","number","app.common.schema/number",-157963053);$APP.$cljs$cst$1644$file_id$$=new $APP.$cljs$core$Keyword$$(null,"file-id","file-id",-811871323);$cljs$cst$1143$vthread$$=new $APP.$cljs$core$Keyword$$(null,"vthread","vthread",441141075);$APP.$cljs$cst$256$padding$$=new $APP.$cljs$core$Keyword$$(null,"padding","padding",1660304693);
$cljs$cst$2840$cap_height$$=new $APP.$cljs$core$Keyword$$(null,"cap-height","cap-height",1034322643);$APP.$cljs$cst$3922$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_multiple_components$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","add-multiple-components","app.main.data.workspace.libraries/add-multiple-components",1001418593);$APP.$cljs$cst$5273$nav_scroll$$=new $APP.$cljs$core$Keyword$$(null,"nav-scroll","nav-scroll",1125136089);
$APP.$cljs$cst$2457$history$$=new $APP.$cljs$core$Keyword$$(null,"history","history",-247395220);$APP.$cljs$cst$2650$rename_token_set_group$$=new $APP.$cljs$core$Keyword$$(null,"rename-token-set-group","rename-token-set-group",696993584);$APP.$cljs$cst$4902$is_default$$=new $APP.$cljs$core$Keyword$$(null,"is-default","is-default",1401171070);
$cljs$cst$2539$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_level$$=new $APP.$cljs$core$Keyword$$("app.common.schema.desc-native","level","app.common.schema.desc-native/level",-839786332);$APP.$cljs$cst$3109$enabled$$=new $APP.$cljs$core$Keyword$$(null,"enabled","enabled",1195909756);$APP.$cljs$cst$5153$asc$$=new $APP.$cljs$core$Keyword$$(null,"asc","asc",356854569);$APP.$cljs$cst$2309$event_symbol$$=new $APP.$cljs$core$Keyword$$(null,"event-symbol","event-symbol",-1673621604);
$APP.$cljs$cst$2205$context_menu$$=new $APP.$cljs$core$Keyword$$(null,"context-menu","context-menu",-1002713451);$cljs$cst$4261$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_stop_path_edit$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.edition","stop-path-edit","app.main.data.workspace.path.edition/stop-path-edit",-1219697474);$cljs$cst$1906$blend_filters$$=new $APP.$cljs$core$Keyword$$(null,"blend-filters","blend-filters",-1725368612);
$cljs$cst$2104$tokens_tree$$=new $APP.$cljs$core$Keyword$$(null,"tokens-tree","tokens-tree",-1251912938);$APP.$cljs$cst$4974$app_DOT_main_DOT_data_DOT_dashboard_SLASH_handle_organization_deleted$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","handle-organization-deleted","app.main.data.dashboard/handle-organization-deleted",-1585035767);$cljs$cst$372$lazy_refs$$=new $APP.$cljs$core$Keyword$$(null,"lazy-refs","lazy-refs",409178818);
$APP.$cljs$cst$5157$hint_level$$=new $APP.$cljs$core$Keyword$$(null,"hint-level","hint-level",263640346);$APP.$cljs$cst$4641$shape_ids$$=new $APP.$cljs$core$Keyword$$(null,"shape-ids","shape-ids",699231806);$cljs$cst$1156$app_DOT_common_DOT_logging_SLASH_level$$=new $APP.$cljs$core$Keyword$$("app.common.logging","level","app.common.logging/level",1936739415);$cljs$cst$370$arr$$=new $APP.$cljs$core$Keyword$$(null,"arr","arr",474961448);
$cljs$cst$3090$next_index$$=new $APP.$cljs$core$Keyword$$(null,"next-index","next-index",-711843894);$APP.$cljs$cst$5076$initial$$=new $APP.$cljs$core$Keyword$$(null,"initial","initial",1854648214);$APP.$cljs$cst$139$type$$=new $APP.$cljs$core$Keyword$$(null,"type","type",1174270348);$APP.$cljs$cst$4978$app_DOT_main_DOT_data_DOT_dashboard_SLASH_restore_files$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","restore-files","app.main.data.dashboard/restore-files",-1025998028);
$cljs$cst$692$vector_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"vector?","vector?",-61367869,null);$cljs$cst$1976$rtl$$=new $APP.$cljs$core$Keyword$$(null,"rtl","rtl",695259902);$cljs$cst$4350$subscribe_team$$=new $APP.$cljs$core$Keyword$$(null,"subscribe-team","subscribe-team",1911996188);$APP.$cljs$cst$1676$position$$=new $APP.$cljs$core$Keyword$$(null,"position","position",-2011731912);$cljs$cst$4999$hide_mentions$$=new $APP.$cljs$core$Keyword$$(null,"hide-mentions","hide-mentions",1980291578);
$cljs$cst$2337$app_DOT_main_DOT_data_DOT_modal_SLASH_show_modal$$=new $APP.$cljs$core$Keyword$$("app.main.data.modal","show-modal","app.main.data.modal/show-modal",-1770734394);$cljs$cst$2360$app_DOT_main_DOT_data_DOT_notifications_SLASH_hide$$=new $APP.$cljs$core$Keyword$$("app.main.data.notifications","hide","app.main.data.notifications/hide",-465940781);$cljs$cst$145$cause$$=new $APP.$cljs$core$Keyword$$(null,"cause","cause",231901252);
$APP.$cljs$cst$3356$auth_login$$=new $APP.$cljs$core$Keyword$$(null,"auth-login","auth-login",-1527817479);$cljs$cst$4380$new_shape$$=new $APP.$cljs$core$Keyword$$(null,"new-shape","new-shape",-1536110067);$cljs$cst$3890$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.wasm-text","resize-wasm-text","app.main.data.workspace.wasm-text/resize-wasm-text",-677095419);
$APP.$cljs$cst$3118$instance$$=new $APP.$cljs$core$Keyword$$(null,"instance","instance",-2121349050);$cljs$cst$5213$main_nested$$=new $APP.$cljs$core$Keyword$$(null,"main-nested","main-nested",-707473388);$cljs$cst$956$app_DOT_common_DOT_schema_SLASH_coll_of_uuid$$=new $APP.$cljs$core$Keyword$$("app.common.schema","coll-of-uuid","app.common.schema/coll-of-uuid",-1448105897);$APP.$cljs$cst$2624$reg_objects$$=new $APP.$cljs$core$Keyword$$(null,"reg-objects","reg-objects",1473118866);
$cljs$cst$2709$animateColor$$=new $APP.$cljs$core$Keyword$$(null,"animateColor","animateColor",-870070005);$APP.$cljs$cst$267$precision$$=new $APP.$cljs$core$Keyword$$(null,"precision","precision",-1175707478);$cljs$cst$3884$element_type$$=new $APP.$cljs$core$Keyword$$(null,"element-type","element-type",-1609504232);$APP.$cljs$cst$1660$flex$$=new $APP.$cljs$core$Keyword$$(null,"flex","flex",-1425124628);
$cljs$cst$4302$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_remove_flow$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","remove-flow","app.main.data.workspace.interactions/remove-flow",-1699904987);$cljs$cst$4338$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_connect_mcp$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.mcp","connect-mcp","app.main.data.workspace.mcp/connect-mcp",1683040707);
$APP.$cljs$cst$2052$curve$$=new $APP.$cljs$core$Keyword$$(null,"curve","curve",-569677866);$cljs$cst$253$js$$=new $APP.$cljs$core$Symbol$$(null,"js","js",-886355190,null);$APP.$cljs$cst$2530$dashboard_settings$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-settings","dashboard-settings",1232740502);$cljs$cst$5199$duplicate_slot$$=new $APP.$cljs$core$Keyword$$(null,"duplicate-slot","duplicate-slot",1321081054);$cljs$cst$5332$css$$=new $APP.$cljs$core$Keyword$$(null,"css","css",1135045163);
$APP.$cljs$cst$3950$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_reset_components$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","reset-components","app.main.data.workspace.libraries/reset-components",2087889209);$APP.$cljs$cst$258$right$$=new $APP.$cljs$core$Keyword$$(null,"right","right",-452581833);
$APP.$cljs$cst$4716$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_bulk_create_tokens$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","bulk-create-tokens","app.main.data.workspace.tokens.library-edit/bulk-create-tokens",1125558604);$APP.$cljs$cst$4008$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_cursor_to_end$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","cursor-to-end","app.main.data.workspace.texts/cursor-to-end",-1476614484);
$APP.$cljs$cst$5068$nitrate_form$$=new $APP.$cljs$core$Keyword$$(null,"nitrate-form","nitrate-form",-1290547359);$APP.$cljs$cst$1742$stroke_color_ref_id$$=new $APP.$cljs$core$Keyword$$(null,"stroke-color-ref-id","stroke-color-ref-id",1785439761);$APP.$cljs$cst$3417$hcenter$$=new $APP.$cljs$core$Keyword$$(null,"hcenter","hcenter",-1502998396);$cljs$cst$3834$subtree_ids_by_id$$=new $APP.$cljs$core$Keyword$$(null,"subtree-ids-by-id","subtree-ids-by-id",-1203682988);
$APP.$cljs$cst$4011$editor_state$$=new $APP.$cljs$core$Keyword$$(null,"editor-state","editor-state",579582138);$APP.$cljs$cst$4262$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_split_segments$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.edition","split-segments","app.main.data.workspace.path.edition/split-segments",-1641031725);
$cljs$cst$4599$error_DOT_style_dictionary_SLASH_invalid_token_value_typography$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","invalid-token-value-typography","error.style-dictionary/invalid-token-value-typography",-300328291);$APP.$cljs$cst$4129$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_start_picker$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","start-picker","app.main.data.workspace.colors/start-picker",216193503);
$APP.$cljs$cst$4950$app_DOT_main_DOT_data_DOT_dashboard_SLASH_file_deleted$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","file-deleted","app.main.data.dashboard/file-deleted",-1133811731);$APP.$cljs$cst$2088$all_frames_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"all-frames?","all-frames?",-104533347);$cljs$cst$3474$app_DOT_main_DOT_data_DOT_comments_SLASH_create_draft$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","create-draft","app.main.data.comments/create-draft",-1272674029);
$cljs$cst$3998$entityMap$$=new $APP.$cljs$core$Keyword$$(null,"entityMap","entityMap",1771692951);$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$=new $APP.$cljs$core$Keyword$$("app.main.data.event","name","app.main.data.event/name",-541742837);$APP.$cljs$cst$1915$profiles$$=new $APP.$cljs$core$Keyword$$(null,"profiles","profiles",507634713);$cljs$cst$5342$grid_element$$=new $APP.$cljs$core$Keyword$$(null,"grid-element","grid-element",515673421);
$APP.$cljs$cst$5414$is_viewer$$=new $APP.$cljs$core$Keyword$$(null,"is-viewer","is-viewer",-1388243148);$APP.$cljs$cst$4859$start_editing$$=new $APP.$cljs$core$Keyword$$(null,"start-editing","start-editing",36503254);$APP.$cljs$cst$1930$item_length$$=new $APP.$cljs$core$Keyword$$(null,"item-length","item-length",-2094673604);$cljs$cst$3284$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_webhooks$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","fetch-webhooks","app.main.data.team/fetch-webhooks",-1001690679);
$APP.$cljs$cst$2490$role$$=new $APP.$cljs$core$Keyword$$(null,"role","role",-736691072);$cljs$cst$6$ns$$=new $APP.$cljs$core$Symbol$$(null,"ns","ns",2082130287,null);$APP.$cljs$cst$3685$stack$$=new $APP.$cljs$core$Keyword$$(null,"stack","stack",-793405930);$cljs$cst$3700$invalid_svg_file$$=new $APP.$cljs$core$Keyword$$(null,"invalid-svg-file","invalid-svg-file",1057558874);$APP.$cljs$cst$111$pending$$=new $APP.$cljs$core$Keyword$$(null,"pending","pending",-220036727);
$APP.$cljs$cst$3201$subscription$$=new $APP.$cljs$core$Keyword$$(null,"subscription","subscription",1949009182);$cljs$cst$3173$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_undefined$$=new $APP.$cljs$core$Keyword$$("app.common.files.changes-builder","undefined","app.common.files.changes-builder/undefined",-486440736);$APP.$cljs$cst$3726$hide_palettes$$=new $APP.$cljs$core$Keyword$$(null,"hide-palettes","hide-palettes",-1168299178);
$APP.$cljs$cst$4156$disable_gradient$$=new $APP.$cljs$core$Keyword$$(null,"disable-gradient","disable-gradient",669966752);$cljs$cst$4949$delete_project$$=new $APP.$cljs$core$Keyword$$(null,"delete-project","delete-project",-1196614829);$cljs$cst$5188$nested_main_not_allowed$$=new $APP.$cljs$core$Keyword$$(null,"nested-main-not-allowed","nested-main-not-allowed",1962230911);
$APP.$cljs$cst$3658$app_DOT_main_DOT_data_DOT_workspace_DOT_bool_SLASH_group_to_bool$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.bool","group-to-bool","app.main.data.workspace.bool/group-to-bool",1540299050);$cljs$cst$210$col$$=new $APP.$cljs$core$Keyword$$(null,"col","col",-1959363084);$cljs$cst$2726$vkern$$=new $APP.$cljs$core$Keyword$$(null,"vkern","vkern",-2073308972);$APP.$cljs$cst$2059$pixel_grid_color$$=new $APP.$cljs$core$Keyword$$(null,"pixel-grid-color","pixel-grid-color",-1270479729);
$cljs$cst$3110$app_DOT_main_DOT_features_SLASH_recompute_features$$=new $APP.$cljs$core$Keyword$$("app.main.features","recompute-features","app.main.features/recompute-features",-4576154);$cljs$cst$4388$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_clean_selection$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid-layout.editor","clean-selection","app.main.data.workspace.grid-layout.editor/clean-selection",-1297822824);
$cljs$cst$2995$gurmukhi$$=new $APP.$cljs$core$Keyword$$(null,"gurmukhi","gurmukhi",1350541448);$cljs$cst$4628$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_shape_rotation$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","update-shape-rotation","app.main.data.workspace.tokens.application/update-shape-rotation",-436751301);$APP.$cljs$cst$1562$top$$=new $APP.$cljs$core$Keyword$$(null,"top","top",-1856271961);
$APP.$cljs$cst$3226$app_DOT_main_DOT_data_DOT_profile_SLASH_mark_onboarding_as_viewed$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","mark-onboarding-as-viewed","app.main.data.profile/mark-onboarding-as-viewed",-514151808);$APP.$cljs$cst$4604$error_SLASH_exception$$=new $APP.$cljs$core$Keyword$$("error","exception","error/exception",1312810496);$APP.$cljs$cst$1708$layout_item_h_sizing$$=new $APP.$cljs$core$Keyword$$(null,"layout-item-h-sizing","layout-item-h-sizing",136908527);
$APP.$cljs$cst$4534$find_and_replace$$=new $APP.$cljs$core$Keyword$$(null,"find-and-replace","find-and-replace",-541536169);$cljs$cst$766$value_fn$$=new $APP.$cljs$core$Keyword$$(null,"value-fn","value-fn",544624790);$APP.$cljs$cst$4292$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_update_guide_color$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.guides","update-guide-color","app.main.data.workspace.guides/update-guide-color",937698359);
$APP.$cljs$cst$1623$blocked$$=new $APP.$cljs$core$Keyword$$(null,"blocked","blocked",181326681);$cljs$cst$4228$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_handle_new_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","handle-new-shape","app.main.data.workspace.path.drawing/handle-new-shape",-610817203);$APP.$cljs$cst$3115$cmd$$=new $APP.$cljs$core$Keyword$$(null,"cmd","cmd",-302931143);
$cljs$cst$4573$paragraph_spacing$$=new $APP.$cljs$core$Keyword$$(null,"paragraph-spacing","paragraph-spacing",-1853018274);$cljs$cst$1483$not_delivered$$=new $APP.$cljs$core$Keyword$$(null,"not-delivered","not-delivered",1599158697);$cljs$cst$908$transformers$$=new $APP.$cljs$core$Keyword$$(null,"transformers","transformers",-734201565);$cljs$cst$1411$miser_width$$=new $APP.$cljs$core$Keyword$$(null,"miser-width","miser-width",-1310049437);
$cljs$cst$3668$shape_cells$$=new $APP.$cljs$core$Keyword$$(null,"shape-cells","shape-cells",1406817502);$cljs$cst$4080$reverse_row$$=new $APP.$cljs$core$Keyword$$(null,"reverse-row","reverse-row",2097961623);$cljs$cst$3615$id_duplicated$$=new $APP.$cljs$core$Keyword$$(null,"id-duplicated","id-duplicated",-308911643);$cljs$cst$574$malli_DOT_core_SLASH_missing_function$$=new $APP.$cljs$core$Keyword$$("malli.core","missing-function","malli.core/missing-function",1913462487);
$cljs$cst$3294$update_team$$=new $APP.$cljs$core$Keyword$$(null,"update-team","update-team",1861918263);$APP.$cljs$cst$4451$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_activate_panning$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.viewport","activate-panning","app.main.data.workspace.viewport/activate-panning",-1292961995);$cljs$cst$3177$rops$$=new $APP.$cljs$core$Keyword$$(null,"rops","rops",-1261038322);
$cljs$cst$4636$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_generate_text_shape_update$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","generate-text-shape-update","app.main.data.workspace.tokens.application/generate-text-shape-update",210687731);
$APP.$cljs$cst$4271$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_change_preset$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.drawing","change-preset","app.main.data.workspace.drawing/change-preset",1353790695);$cljs$cst$3425$file_name$$=new $APP.$cljs$core$Keyword$$(null,"file-name","file-name",-1654217259);
$cljs$cst$3283$app_DOT_main_DOT_data_DOT_team_SLASH_webhooks_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","webhooks-fetched","app.main.data.team/webhooks-fetched",1471512138);$cljs$cst$1617$root$$=new $APP.$cljs$core$Keyword$$(null,"root","root",-448657453);$cljs$cst$1498$with_local_vars$$=new $APP.$cljs$core$Symbol$$(null,"with-local-vars","with-local-vars",837642072,null);
$APP.$cljs$cst$1684$layout_wrap_type$$=new $APP.$cljs$core$Keyword$$(null,"layout-wrap-type","layout-wrap-type",186626597);$APP.$cljs$cst$4078$absolute$$=new $APP.$cljs$core$Keyword$$(null,"absolute","absolute",1655386478);$APP.$cljs$cst$3241$delete_profile$$=new $APP.$cljs$core$Keyword$$(null,"delete-profile","delete-profile",-1573088455);$cljs$cst$961$app_DOT_common_DOT_schema_SLASH_safe_int$$=new $APP.$cljs$core$Keyword$$("app.common.schema","safe-int","app.common.schema/safe-int",-730426809);
$cljs$cst$5324$on_change_format$$=new $APP.$cljs$core$Keyword$$(null,"on-change-format","on-change-format",-1600641015);$cljs$cst$4258$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_move_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.edition","move-selected","app.main.data.workspace.path.edition/move-selected",-971064472);$cljs$cst$670$nat_int_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"nat-int?","nat-int?",-1879663400,null);
$APP.$cljs$cst$4242$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_select_node$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.selection","select-node","app.main.data.workspace.path.selection/select-node",-990331561);$cljs$cst$4191$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_box_SLASH_handle_drawing$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.drawing.box","handle-drawing","app.main.data.workspace.drawing.box/handle-drawing",1605587535);
$cljs$cst$3749$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_set_workspace_visited$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.common","set-workspace-visited","app.main.data.workspace.common/set-workspace-visited",-1135725929);$cljs$cst$2978$is_emoji$$=new $APP.$cljs$core$Keyword$$(null,"is-emoji","is-emoji",-1643384064);$cljs$cst$5133$email_domain_is_not_allowed$$=new $APP.$cljs$core$Keyword$$(null,"email-domain-is-not-allowed","email-domain-is-not-allowed",-1746810955);
$APP.$cljs$cst$2455$app_DOT_main_DOT_router_SLASH_replace$$=new $APP.$cljs$core$Keyword$$("app.main.router","replace","app.main.router/replace",466128885);$APP.$cljs$cst$2306$app_DOT_main_DOT_data_DOT_event_SLASH_context$$=new $APP.$cljs$core$Keyword$$("app.main.data.event","context","app.main.data.event/context",-411684139);
$cljs$cst$2514$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_search$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","go-to-dashboard-search","app.main.data.common/go-to-dashboard-search",1377924631);$cljs$cst$4889$panels$$=new $APP.$cljs$core$Keyword$$(null,"panels","panels",801034044);
$cljs$cst$3569$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_commit_undo_transaction$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.undo","commit-undo-transaction","app.main.data.workspace.undo/commit-undo-transaction",317661795);$cljs$cst$5219$not_component$$=new $APP.$cljs$core$Keyword$$(null,"not-component","not-component",-384260224);$cljs$cst$1470$allows_separator$$=new $APP.$cljs$core$Keyword$$(null,"allows-separator","allows-separator",-818967742);
$cljs$cst$4541$app_DOT_main_DOT_ui_DOT_hooks_DOT_resize_SLASH_state$$=new $APP.$cljs$core$Keyword$$("app.main.ui.hooks.resize","state","app.main.ui.hooks.resize/state",172840657);$cljs$cst$3192$app_DOT_main_DOT_data_DOT_media_SLASH_files$$=new $APP.$cljs$core$Keyword$$("app.main.data.media","files","app.main.data.media/files",1806158910);
$APP.$cljs$cst$3951$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_component$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","update-component","app.main.data.workspace.libraries/update-component",-1052916500);$cljs$cst$3909$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_delete_color$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","delete-color","app.main.data.workspace.libraries/delete-color",997486262);
$APP.$cljs$cst$5130$member_is_muted$$=new $APP.$cljs$core$Keyword$$(null,"member-is-muted","member-is-muted",161120640);$cljs$cst$3433$app_DOT_main_DOT_data_DOT_comments_SLASH_created_thread_on_workspace$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","created-thread-on-workspace","app.main.data.comments/created-thread-on-workspace",-653179153);$cljs$cst$633$re_transformer$$=new $APP.$cljs$core$Keyword$$(null,"re-transformer","re-transformer",-1516368461);
$APP.$cljs$cst$2329$async$$=new $APP.$cljs$core$Keyword$$(null,"async","async",1050769601);$cljs$cst$5207$parent_not_variant$$=new $APP.$cljs$core$Keyword$$(null,"parent-not-variant","parent-not-variant",-2092115268);$APP.$cljs$cst$1690$layout_justify_items$$=new $APP.$cljs$core$Keyword$$(null,"layout-justify-items","layout-justify-items",1271685173);$APP.$cljs$cst$4916$get_team_recent_files$$=new $APP.$cljs$core$Keyword$$(null,"get-team-recent-files","get-team-recent-files",-1548935774);
$cljs$cst$2887$attributeType$$=new $APP.$cljs$core$Keyword$$(null,"attributeType","attributeType",1055561918);$cljs$cst$681$simple_keyword_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"simple-keyword?","simple-keyword?",-367134735,null);$APP.$cljs$cst$3748$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_does_not_exist$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.layout","does-not-exist","app.main.data.workspace.layout/does-not-exist",-431015942);
$cljs$cst$5178$should_be_component_root$$=new $APP.$cljs$core$Keyword$$(null,"should-be-component-root","should-be-component-root",-1019597852);$cljs$cst$3195$media_type_mismatch$$=new $APP.$cljs$core$Keyword$$(null,"media-type-mismatch","media-type-mismatch",-608739035);$APP.$cljs$cst$4379$entries$$=new $APP.$cljs$core$Keyword$$(null,"entries","entries",-86943161);
$cljs$cst$3189$cljs_DOT_spec_DOT_alpha_SLASH_coll_of$$=new $APP.$cljs$core$Symbol$$("cljs.spec.alpha","coll-of","cljs.spec.alpha/coll-of",1019430407,null);$APP.$cljs$cst$3867$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_start_rotate$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","start-rotate","app.main.data.workspace.transforms/start-rotate",-1356627299);
$cljs$cst$4374$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_name$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.pages","name","app.main.data.workspace.pages/name",813037210);$cljs$cst$2767$accent_height$$=new $APP.$cljs$core$Keyword$$(null,"accent-height","accent-height",-1189857342);$APP.$cljs$cst$2603$grid_type$$=new $APP.$cljs$core$Keyword$$(null,"grid-type","grid-type",2068412029);
$APP.$cljs$cst$4645$attributes_to_remove$$=new $APP.$cljs$core$Keyword$$(null,"attributes-to-remove","attributes-to-remove",1017662650);$APP.$cljs$cst$4708$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_import_tokens_lib$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","import-tokens-lib","app.main.data.workspace.tokens.library-edit/import-tokens-lib",-907896943);
$APP.$cljs$cst$2504$app_DOT_main_DOT_data_DOT_common_SLASH_update_progress$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","update-progress","app.main.data.common/update-progress",-591721569);$cljs$cst$3581$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_set_zoom$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.zoom","set-zoom","app.main.data.workspace.zoom/set-zoom",-1730670049);
$cljs$cst$2538$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_simplified$$=new $APP.$cljs$core$Keyword$$("app.common.schema.desc-native","simplified","app.common.schema.desc-native/simplified",-2123092483);$APP.$cljs$cst$2021$saturation$$=new $APP.$cljs$core$Keyword$$(null,"saturation","saturation",-14247929);$cljs$cst$1050$cljs_DOT_core_SLASH_list_QMARK_$$=new $APP.$cljs$core$Symbol$$("cljs.core","list?","cljs.core/list?",-684796618,null);
$APP.$cljs$cst$1905$drop_shadow$$=new $APP.$cljs$core$Keyword$$(null,"drop-shadow","drop-shadow",878776332);$APP.$cljs$cst$4671$tokens_SLASH_dimensions$$=new $APP.$cljs$core$Keyword$$("tokens","dimensions","tokens/dimensions",-1123009431);$cljs$cst$1390$buffer_blob$$=new $APP.$cljs$core$Keyword$$(null,"buffer-blob","buffer-blob",-1830112173);$APP.$cljs$cst$3231$onboarding_questions$$=new $APP.$cljs$core$Keyword$$(null,"onboarding-questions","onboarding-questions",1680690249);
$APP.$cljs$cst$227$features$$=new $APP.$cljs$core$Keyword$$(null,"features","features",-1146962336);$APP.$cljs$cst$2307$event_origin$$=new $APP.$cljs$core$Keyword$$(null,"event-origin","event-origin",-1803146545);$cljs$cst$4790$app_DOT_main_DOT_data_DOT_workspace_DOT_shortcuts_SLASH_esc_pressed$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shortcuts","esc-pressed","app.main.data.workspace.shortcuts/esc-pressed",-755562393);
$APP.$cljs$cst$2181$project_id$$=new $APP.$cljs$core$Keyword$$(null,"project-id","project-id",206449307);$APP.$cljs$cst$4075$shadows$$=new $APP.$cljs$core$Keyword$$(null,"shadows","shadows",-1489088471);$APP.$cljs$cst$2395$path_params$$=new $APP.$cljs$core$Keyword$$(null,"path-params","path-params",-48130597);$cljs$cst$3011$bamum$$=new $APP.$cljs$core$Keyword$$(null,"bamum","bamum",-1327772939);
$cljs$cst$5292$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_all$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","select-all","app.main.data.viewer/select-all",427508670);$APP.$cljs$cst$3221$email_invites$$=new $APP.$cljs$core$Keyword$$(null,"email-invites","email-invites",1802476410);
$APP.$cljs$cst$4499$app_DOT_main_DOT_data_DOT_workspace_SLASH_toggle_selected_assets$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","toggle-selected-assets","app.main.data.workspace/toggle-selected-assets",1325899622);$cljs$cst$3378$app_DOT_main_DOT_errors_SLASH_exceptional_state$$=new $APP.$cljs$core$Keyword$$("app.main.errors","exceptional-state","app.main.errors/exceptional-state",1603386584);
$cljs$cst$3043$selected_colors$$=new $APP.$cljs$core$Keyword$$(null,"selected-colors","selected-colors",1087242297);$APP.$cljs$cst$4012$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_range$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","update-text-range","app.main.data.workspace.texts/update-text-range",-1094206256);$APP.$cljs$cst$3669$row_total_size$$=new $APP.$cljs$core$Keyword$$(null,"row-total-size","row-total-size",-2056972834);
$cljs$cst$2708$color_profile$$=new $APP.$cljs$core$Keyword$$(null,"color-profile","color-profile",1755323818);$APP.$cljs$cst$594$cat$$=new $APP.$cljs$core$Keyword$$(null,"cat","cat",-1457810207);$APP.$cljs$cst$1348$safari_18$$=new $APP.$cljs$core$Keyword$$(null,"safari-18","safari-18",1634928902);$APP.$cljs$cst$1352$safari_17$$=new $APP.$cljs$core$Keyword$$(null,"safari-17","safari-17",412083955);
$APP.$cljs$cst$4253$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_move_point$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.edition","move-point","app.main.data.workspace.path.edition/move-point",-1301992025);$APP.$cljs$cst$1347$safari_16$$=new $APP.$cljs$core$Keyword$$(null,"safari-16","safari-16",-2098723899);$cljs$cst$4779$font_size_inc$$=new $APP.$cljs$core$Keyword$$(null,"font-size-inc","font-size-inc",1041720707);
$cljs$cst$3548$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_toggle_collapse$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.collapse","toggle-collapse","app.main.data.workspace.collapse/toggle-collapse",1946156583);$cljs$cst$868$gen_SLASH_elements$$=new $APP.$cljs$core$Keyword$$("gen","elements","gen/elements",657813311);$cljs$cst$5004$insert_mention$$=new $APP.$cljs$core$Keyword$$(null,"insert-mention","insert-mention",-490505880);
$cljs$cst$2999$khmer$$=new $APP.$cljs$core$Keyword$$(null,"khmer","khmer",-1851491350);$APP.$cljs$cst$2469$delete_share_link$$=new $APP.$cljs$core$Keyword$$(null,"delete-share-link","delete-share-link",454000514);$APP.$cljs$cst$4685$app_DOT_main_DOT_ui_DOT_workspace_DOT_tokens_SLASH_unfolded_token_types$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.tokens","unfolded-token-types","app.main.ui.workspace.tokens/unfolded-token-types",-446211437);
$cljs$cst$1179$login_with_ldap$$=new $APP.$cljs$core$Keyword$$(null,"login-with-ldap","login-with-ldap",1944357469);$APP.$cljs$cst$4668$tokens_SLASH_text_decoration$$=new $APP.$cljs$core$Keyword$$("tokens","text-decoration","tokens/text-decoration",-1724115927);$APP.$cljs$cst$272$assertion$$=new $APP.$cljs$core$Keyword$$(null,"assertion","assertion",-1645134882);$cljs$cst$3815$child_max_height$$=new $APP.$cljs$core$Keyword$$(null,"child-max-height","child-max-height",994590678);
$cljs$cst$2776$patternUnits$$=new $APP.$cljs$core$Keyword$$(null,"patternUnits","patternUnits",-1458803100);$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$=new $APP.$cljs$core$Keyword$$("app.common.schema","boolean","app.common.schema/boolean",-727386221);$APP.$cljs$cst$3346$app_DOT_main_DOT_data_DOT_event_SLASH_source$$=new $APP.$cljs$core$Keyword$$("app.main.data.event","source","app.main.data.event/source",1802544019);
$cljs$cst$4489$app_DOT_main_DOT_data_DOT_workspace_SLASH_distribute_objects$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","distribute-objects","app.main.data.workspace/distribute-objects",379745207);$APP.$cljs$cst$4835$rename$$=new $APP.$cljs$core$Keyword$$(null,"rename","rename",1508157613);$APP.$cljs$cst$4891$alignment$$=new $APP.$cljs$core$Keyword$$(null,"alignment","alignment",1040093386);
$APP.$cljs$cst$4653$expand_with_children$$=new $APP.$cljs$core$Keyword$$(null,"expand-with-children","expand-with-children",-1923116463);$cljs$cst$4560$dropdown_class$$=new $APP.$cljs$core$Keyword$$(null,"dropdown-class","dropdown-class",-1809197876);$APP.$cljs$cst$1748$fill_color_gradient$$=new $APP.$cljs$core$Keyword$$(null,"fill-color-gradient","fill-color-gradient",-2028374870);$APP.$cljs$cst$5344$tab$$=new $APP.$cljs$core$Keyword$$(null,"tab","tab",-559583621);
$cljs$cst$5389$registration_disabled$$=new $APP.$cljs$core$Keyword$$(null,"registration-disabled","registration-disabled",-1481878041);$cljs$cst$679$qualified_ident_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"qualified-ident?","qualified-ident?",-928894763,null);$cljs$cst$2849$xlink_COLON_actuate$$=new $APP.$cljs$core$Keyword$$(null,"xlink:actuate","xlink:actuate",1846130965);$APP.$cljs$cst$5065$nitrate_dialog$$=new $APP.$cljs$core$Keyword$$(null,"nitrate-dialog","nitrate-dialog",1993979164);
$cljs$cst$2674$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_v3_SLASH_v3_update_text_editor_styles$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts-v3","v3-update-text-editor-styles","app.main.data.workspace.texts-v3/v3-update-text-editor-styles",833367699);$APP.$cljs$cst$2563$feature$$=new $APP.$cljs$core$Keyword$$(null,"feature","feature",27242652);$APP.$cljs$cst$78$tag$$=new $APP.$cljs$core$Keyword$$(null,"tag","tag",-1290361223);
$APP.$cljs$cst$2287$label$$=new $APP.$cljs$core$Keyword$$(null,"label","label",1718410804);$cljs$cst$4935$app_DOT_main_DOT_data_DOT_dashboard_SLASH_project_created$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","project-created","app.main.data.dashboard/project-created",-1879505768);$cljs$cst$2724$feComposite$$=new $APP.$cljs$core$Keyword$$(null,"feComposite","feComposite",2042815955);
$APP.$cljs$cst$3222$app_DOT_main_DOT_data_DOT_profile_SLASH_update_notifications$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","update-notifications","app.main.data.profile/update-notifications",774323308);$cljs$cst$2150$ctrl$$=new $APP.$cljs$core$Keyword$$(null,"ctrl","ctrl",361402094);$APP.$cljs$cst$2492$team$$=new $APP.$cljs$core$Keyword$$(null,"team","team",1355747699);
$APP.$cljs$cst$3913$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_delete_media$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","delete-media","app.main.data.workspace.libraries/delete-media",-1252997417);$cljs$cst$3039$gradient_units$$=new $APP.$cljs$core$Keyword$$(null,"gradient-units","gradient-units",-1502403779);$cljs$cst$154$loop_STAR_$$=new $APP.$cljs$core$Symbol$$(null,"loop*","loop*",615029416,null);
$APP.$cljs$cst$4220$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_close_path_drag_end$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","close-path-drag-end","app.main.data.workspace.path.drawing/close-path-drag-end",-232898488);
$cljs$cst$4410$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_change_layout_track$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","change-layout-track","app.main.data.workspace.shape-layout/change-layout-track",-1377767973);$cljs$cst$808$clojure_DOT_test_DOT_check_DOT_generators_SLASH_char$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","char","clojure.test.check.generators/char",-1426343459,null);
$APP.$cljs$cst$5053$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_restore_version_from_plugins$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","restore-version-from-plugins","app.main.data.workspace.versions/restore-version-from-plugins",-1455971033);
$cljs$cst$3841$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_move_frame_comment_threads$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.comments","move-frame-comment-threads","app.main.data.workspace.comments/move-frame-comment-threads",-1863105348);$cljs$cst$3002$javanese$$=new $APP.$cljs$core$Keyword$$(null,"javanese","javanese",755903469);$APP.$cljs$cst$1641$stroke_color_ref_file$$=new $APP.$cljs$core$Keyword$$(null,"stroke-color-ref-file","stroke-color-ref-file",2014652279);
$APP.$cljs$cst$3353$app_DOT_main_DOT_data_DOT_auth_SLASH_login_from_token$$=new $APP.$cljs$core$Keyword$$("app.main.data.auth","login-from-token","app.main.data.auth/login-from-token",-37432826);$APP.$cljs$cst$4508$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_page_item_context_menu$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","show-page-item-context-menu","app.main.data.workspace/show-page-item-context-menu",-836313139);
$APP.$cljs$cst$2948$disabled$$=new $APP.$cljs$core$Keyword$$(null,"disabled","disabled",-1529784218);$cljs$cst$3885$moved$$=new $APP.$cljs$core$Keyword$$(null,"moved","moved",486549219);$APP.$cljs$cst$4255$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_drag_selected_points$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.edition","drag-selected-points","app.main.data.workspace.path.edition/drag-selected-points",1833717476);
$APP.$cljs$cst$1295$on_error$$=new $APP.$cljs$core$Keyword$$(null,"on-error","on-error",1728533530);$cljs$cst$1752$internal$$=new $APP.$cljs$core$Keyword$$(null,"internal","internal",-854870097);$cljs$cst$98$cljs_DOT_core_SLASH_not_found$$=new $APP.$cljs$core$Keyword$$("cljs.core","not-found","cljs.core/not-found",-1572889185);
$cljs$cst$5286$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_overlay$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","toggle-overlay","app.main.data.viewer/toggle-overlay",-748340857);$APP.$cljs$cst$2606$set_plugin_data$$=new $APP.$cljs$core$Keyword$$(null,"set-plugin-data","set-plugin-data",379252905);$APP.$cljs$cst$889$default_locale$$=new $APP.$cljs$core$Keyword$$(null,"default-locale","default-locale",-677515761);
$APP.$cljs$cst$4995$plugin_try_out$$=new $APP.$cljs$core$Keyword$$(null,"plugin-try-out","plugin-try-out",235173416);$cljs$cst$2965$svg_transform$$=new $APP.$cljs$core$Keyword$$(null,"svg-transform","svg-transform",-1664613325);$cljs$cst$2880$viewBox$$=new $APP.$cljs$core$Keyword$$(null,"viewBox","viewBox",-469489477);$cljs$cst$1144$thread$$=new $APP.$cljs$core$Keyword$$(null,"thread","thread",947001524);$APP.$cljs$cst$4963$num_files$$=new $APP.$cljs$core$Keyword$$(null,"num-files","num-files",1227997359);
$cljs$cst$3827$prev_wasm_props$$=new $APP.$cljs$core$Keyword$$(null,"prev-wasm-props","prev-wasm-props",2005132939);$APP.$cljs$cst$4345$mcp_SLASH_enable$$=new $APP.$cljs$core$Keyword$$("mcp","enable","mcp/enable",-1838729942);$APP.$cljs$cst$4346$mcp_SLASH_disable$$=new $APP.$cljs$core$Keyword$$("mcp","disable","mcp/disable",1717677074);$APP.$cljs$cst$2191$export_error_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"export-error?","export-error?",-1564759176);
$cljs$cst$2711$animate$$=new $APP.$cljs$core$Keyword$$(null,"animate","animate",1850194573);$APP.$cljs$cst$4169$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_colorpicker_onchange_runner$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","colorpicker-onchange-runner","app.main.data.workspace.colors/colorpicker-onchange-runner",562715911);$cljs$cst$3816$to_bound_height$$=new $APP.$cljs$core$Keyword$$(null,"to-bound-height","to-bound-height",1545099969);
$cljs$cst$2825$arabic_form$$=new $APP.$cljs$core$Keyword$$(null,"arabic-form","arabic-form",-246736017);$APP.$cljs$cst$2590$remove$$=new $APP.$cljs$core$Keyword$$(null,"remove","remove",-131428414);$cljs$cst$4941$duplicate_project$$=new $APP.$cljs$core$Keyword$$(null,"duplicate-project","duplicate-project",-1075466496);$APP.$cljs$cst$5032$restore_dialog$$=new $APP.$cljs$core$Keyword$$(null,"restore-dialog","restore-dialog",230231813);
$APP.$cljs$cst$2207$page_item$$=new $APP.$cljs$core$Keyword$$(null,"page-item","page-item",-547415760);$APP.$cljs$cst$4908$app_DOT_main_DOT_data_DOT_dashboard_SLASH_fetch_projects$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","fetch-projects","app.main.data.dashboard/fetch-projects",-1013150815);$cljs$cst$2910$clip_rule$$=new $APP.$cljs$core$Keyword$$(null,"clip-rule","clip-rule",335492201);
$cljs$cst$4222$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_start_edition$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","start-edition","app.main.data.workspace.path.drawing/start-edition",-1854348662);$cljs$cst$4143$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_all_fills$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","remove-all-fills","app.main.data.workspace.colors/remove-all-fills",-1401227824);
$cljs$cst$4229$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_start_draw_mode$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","start-draw-mode","app.main.data.workspace.path.drawing/start-draw-mode",1212441248);$cljs$cst$3246$app_DOT_main_DOT_data_DOT_profile_SLASH_access_tokens_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","access-tokens-fetched","app.main.data.profile/access-tokens-fetched",-398221297);
$cljs$cst$155$do$$=new $APP.$cljs$core$Symbol$$(null,"do","do",1686842252,null);$cljs$cst$2824$specularExponent$$=new $APP.$cljs$core$Keyword$$(null,"specularExponent","specularExponent",1420581103);$APP.$cljs$cst$4086$align_items$$=new $APP.$cljs$core$Keyword$$(null,"align-items","align-items",-267946462);$APP.$cljs$cst$3952$js_SLASH_local_changes$$=new $APP.$cljs$core$Keyword$$("js","local-changes","js/local-changes",936763287);
$cljs$cst$1349$other$$=new $APP.$cljs$core$Keyword$$(null,"other","other",995793544);$cljs$cst$4095$grid_area$$=new $APP.$cljs$core$Keyword$$(null,"grid-area","grid-area",-1829717451);$APP.$cljs$cst$3164$remote$$=new $APP.$cljs$core$Keyword$$(null,"remote","remote",-1593576576);$APP.$cljs$cst$3133$redo_changes$$=new $APP.$cljs$core$Keyword$$(null,"redo-changes","redo-changes",974223824);$APP.$cljs$cst$5054$dropdown_SLASH_open$$=new $APP.$cljs$core$Keyword$$("dropdown","open","dropdown/open",824533839);
$APP.$cljs$cst$3432$comment$$=new $APP.$cljs$core$Keyword$$(null,"comment","comment",532206069);$APP.$cljs$cst$242$sym$$=new $APP.$cljs$core$Keyword$$(null,"sym","sym",-1444860305);$cljs$cst$2838$overline_position$$=new $APP.$cljs$core$Keyword$$(null,"overline-position","overline-position",1793937810);$cljs$cst$682$qualified_keyword_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"qualified-keyword?","qualified-keyword?",375456001,null);
$cljs$cst$3828$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_current_move_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","current-move-selected","app.main.data.workspace.transforms/current-move-selected",-1360032117);$APP.$cljs$cst$1943$prev_screen$$=new $APP.$cljs$core$Keyword$$(null,"prev-screen","prev-screen",1175524591);
$cljs$cst$4265$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_tools_SLASH_toggle_snap$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.tools","toggle-snap","app.main.data.workspace.path.tools/toggle-snap",-1160865838);$cljs$cst$3424$page_name$$=new $APP.$cljs$core$Keyword$$(null,"page-name","page-name",974981762);$cljs$cst$1208$file_schema_validation$$=new $APP.$cljs$core$Keyword$$(null,"file-schema-validation","file-schema-validation",-492656024);
$cljs$cst$2697$feDistantLight$$=new $APP.$cljs$core$Keyword$$(null,"feDistantLight","feDistantLight",-973970366);$APP.$cljs$cst$2338$app_DOT_main_DOT_data_DOT_modal_SLASH_modal$$=new $APP.$cljs$core$Keyword$$("app.main.data.modal","modal","app.main.data.modal/modal",2103156851);$APP.$cljs$cst$28$fn$$=new $APP.$cljs$core$Symbol$$(null,"fn","fn",465265323,null);$APP.$cljs$cst$3661$row_tracks$$=new $APP.$cljs$core$Keyword$$(null,"row-tracks","row-tracks",-1727486848);
$cljs$cst$1501$dotimes$$=new $APP.$cljs$core$Symbol$$(null,"dotimes","dotimes",-818708397,null);$cljs$cst$4323$press_opacity_id$$=new $APP.$cljs$core$Keyword$$(null,"press-opacity-id","press-opacity-id",-774656842);$cljs$cst$3706$media_loading$$=new $APP.$cljs$core$Keyword$$(null,"media-loading","media-loading",1502530571);$cljs$cst$3623$is_variant$$=new $APP.$cljs$core$Keyword$$(null,"is-variant","is-variant",-1643856989);
$APP.$cljs$cst$4510$grid_track$$=new $APP.$cljs$core$Keyword$$(null,"grid-track","grid-track",1096508183);$cljs$cst$669$neg_int_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"neg-int?","neg-int?",-1610409390,null);$cljs$cst$1502$cond$$=new $APP.$cljs$core$Symbol$$(null,"cond","cond",1606708055,null);$cljs$cst$3743$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_none$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.layout","none","app.main.data.workspace.layout/none",1099104099);
$APP.$cljs$cst$1761$font_weight$$=new $APP.$cljs$core$Keyword$$(null,"font-weight","font-weight",2085804583);$APP.$cljs$cst$1538$svg$$=new $APP.$cljs$core$Keyword$$(null,"svg","svg",856789142);$APP.$cljs$cst$3439$get_comment_thread$$=new $APP.$cljs$core$Keyword$$(null,"get-comment-thread","get-comment-thread",-378373473);$APP.$cljs$cst$248$clojure_DOT_core_SLASH_deref$$=new $APP.$cljs$core$Symbol$$("clojure.core","deref","clojure.core/deref",188719157,null);
$cljs$cst$5201$missing_slot$$=new $APP.$cljs$core$Keyword$$(null,"missing-slot","missing-slot",-1465143531);$cljs$cst$1565$ascent$$=new $APP.$cljs$core$Keyword$$(null,"ascent","ascent",-1986032338);$cljs$cst$4290$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_remove_guides$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.guides","remove-guides","app.main.data.workspace.guides/remove-guides",737489793);
$cljs$cst$1221$soft_rpc_rlimit$$=new $APP.$cljs$core$Keyword$$(null,"soft-rpc-rlimit","soft-rpc-rlimit",-1526292753);$APP.$cljs$cst$1615$layout$$=new $APP.$cljs$core$Keyword$$(null,"layout","layout",-2120940921);$cljs$cst$157$if$$=new $APP.$cljs$core$Symbol$$(null,"if","if",1181717262,null);$APP.$cljs$cst$5419$get_team_info$$=new $APP.$cljs$core$Keyword$$(null,"get-team-info","get-team-info",-1384996455);$cljs$cst$3050$end_para$$=new $APP.$cljs$core$Keyword$$(null,"end-para","end-para",-354953982);
$cljs$cst$3974$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_component_changed$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","component-changed","app.main.data.workspace.libraries/component-changed",242163013);$APP.$cljs$cst$2544$asset_id$$=new $APP.$cljs$core$Keyword$$(null,"asset-id","asset-id",249736185);$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$=new $APP.$cljs$core$Keyword$$("app.main.data.event","origin","app.main.data.event/origin",-1096683174);
$cljs$cst$3771$data_old_x$$=new $APP.$cljs$core$Keyword$$(null,"data-old-x","data-old-x",1262470324);$APP.$cljs$cst$2138$selected_token_set_id$$=new $APP.$cljs$core$Keyword$$(null,"selected-token-set-id","selected-token-set-id",-1828640116);$cljs$cst$3772$data_old_y$$=new $APP.$cljs$core$Keyword$$(null,"data-old-y","data-old-y",132754460);$APP.$cljs$cst$4840$flip_vertical$$=new $APP.$cljs$core$Keyword$$(null,"flip-vertical","flip-vertical",-1929513553);
$APP.$cljs$cst$4887$basics$$=new $APP.$cljs$core$Keyword$$(null,"basics","basics",1919388640);$cljs$cst$3234$delete_profile_photo$$=new $APP.$cljs$core$Keyword$$(null,"delete-profile-photo","delete-profile-photo",1093203873);$cljs$cst$138$uuid$$=new $APP.$cljs$core$Symbol$$(null,"uuid","uuid",-504564192,null);
$cljs$cst$3558$app_DOT_main_DOT_data_DOT_workspace_DOT_edition_SLASH_start_edition_mode$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.edition","start-edition-mode","app.main.data.workspace.edition/start-edition-mode",1067713961);$cljs$cst$2844$dur$$=new $APP.$cljs$core$Keyword$$(null,"dur","dur",1464522452);$cljs$cst$3$dup$$=new $APP.$cljs$core$Keyword$$(null,"dup","dup",556298533);$cljs$cst$855$gen_SLASH_max$$=new $APP.$cljs$core$Keyword$$("gen","max","gen/max",61264228);
$APP.$cljs$cst$109$status$$=new $APP.$cljs$core$Keyword$$(null,"status","status",-1997798413);$cljs$cst$5088$auto_focus$$=new $APP.$cljs$core$Keyword$$(null,"auto-focus","auto-focus",1250006231);$cljs$cst$494$malli_DOT_core_SLASH_tuple_size$$=new $APP.$cljs$core$Keyword$$("malli.core","tuple-size","malli.core/tuple-size",-1004468077);$APP.$cljs$cst$1958$slide$$=new $APP.$cljs$core$Keyword$$(null,"slide","slide",142491892);
$APP.$cljs$cst$4930$app_DOT_main_DOT_data_DOT_dashboard_SLASH_show_file_menu_with_position$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","show-file-menu-with-position","app.main.data.dashboard/show-file-menu-with-position",1901428190);$cljs$cst$1124$cljs_DOT_spec_DOT_alpha_SLASH_k$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","k","cljs.spec.alpha/k",-1602615178);$cljs$cst$4824$select_next$$=new $APP.$cljs$core$Keyword$$(null,"select-next","select-next",-959991288);
$cljs$cst$4196$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_handle_drawing$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.drawing.curve","handle-drawing","app.main.data.workspace.drawing.curve/handle-drawing",571234859);$cljs$cst$5326$hsla$$=new $APP.$cljs$core$Keyword$$(null,"hsla","hsla",1815162996);$APP.$cljs$cst$2543$shape_id$$=new $APP.$cljs$core$Keyword$$(null,"shape-id","shape-id",981169327);
$APP.$cljs$cst$5282$snap_to$$=new $APP.$cljs$core$Keyword$$(null,"snap-to","snap-to",922955891);$APP.$cljs$cst$4591$error_DOT_token_SLASH_direct_self_reference$$=new $APP.$cljs$core$Keyword$$("error.token","direct-self-reference","error.token/direct-self-reference",1855619343);$cljs$cst$1509$struct_map$$=new $APP.$cljs$core$Symbol$$(null,"struct-map","struct-map",-1387540878,null);$cljs$cst$1395$end_block_t$$=new $APP.$cljs$core$Keyword$$(null,"end-block-t","end-block-t",1544648735);
$cljs$cst$1125$cljs_DOT_spec_DOT_alpha_SLASH_v$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","v","cljs.spec.alpha/v",552625740);$APP.$cljs$cst$2032$color_burn$$=new $APP.$cljs$core$Keyword$$(null,"color-burn","color-burn",-540235169);$cljs$cst$1142$current_thread$$=new $APP.$cljs$core$Keyword$$(null,"current-thread","current-thread",-1723055768);$cljs$cst$3089$strokeLinejoin$$=new $APP.$cljs$core$Keyword$$(null,"strokeLinejoin","strokeLinejoin",-721488076);
$cljs$cst$2854$baseFrequency$$=new $APP.$cljs$core$Keyword$$(null,"baseFrequency","baseFrequency",-1013443755);$APP.$cljs$cst$4921$app_DOT_main_DOT_data_DOT_dashboard_SLASH_deleted_files_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","deleted-files-fetched","app.main.data.dashboard/deleted-files-fetched",-890046446);
$cljs$cst$3847$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_apply_modifiers$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.modifiers","apply-modifiers","app.main.data.workspace.modifiers/apply-modifiers",1960839948);$APP.$cljs$cst$1705$layout_item_min_h$$=new $APP.$cljs$core$Keyword$$(null,"layout-item-min-h","layout-item-min-h",200739548);$APP.$cljs$cst$4936$project_for_edit$$=new $APP.$cljs$core$Keyword$$(null,"project-for-edit","project-for-edit",-763691370);
$cljs$cst$3943$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_initialize_page$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.pages","initialize-page","app.main.data.workspace.pages/initialize-page",-80938988);$cljs$cst$4344$mcp_SLASH_ping$$=new $APP.$cljs$core$Keyword$$("mcp","ping","mcp/ping",-1670734442);$APP.$cljs$cst$1416$stream$$=new $APP.$cljs$core$Keyword$$(null,"stream","stream",1534941648);
$APP.$cljs$cst$1713$sort_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"sort?","sort?",-567661924);$APP.$cljs$cst$1720$plugin_id$$=new $APP.$cljs$core$Keyword$$(null,"plugin-id","plugin-id",-1788213395);$APP.$cljs$cst$3959$id_new_component$$=new $APP.$cljs$core$Keyword$$(null,"id-new-component","id-new-component",-1833761545);$cljs$cst$3313$app_DOT_main_DOT_data_DOT_team_SLASH_delete_webhook$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","delete-webhook","app.main.data.team/delete-webhook",1885812780);
$cljs$cst$2551$top_children$$=new $APP.$cljs$core$Keyword$$(null,"top-children","top-children",1245943383);$APP.$cljs$cst$571$scope$$=new $APP.$cljs$core$Keyword$$(null,"scope","scope",-439358418);$APP.$cljs$cst$1707$layout_item_min_w$$=new $APP.$cljs$core$Keyword$$(null,"layout-item-min-w","layout-item-min-w",-504161548);$APP.$cljs$cst$1975$url$$=new $APP.$cljs$core$Keyword$$(null,"url","url",276297046);$cljs$cst$3048$start_para$$=new $APP.$cljs$core$Keyword$$(null,"start-para","start-para",1332705210);
$APP.$cljs$cst$2513$term$$=new $APP.$cljs$core$Keyword$$(null,"term","term",-1817390416);$cljs$cst$4033$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_attrs$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","update-attrs","app.main.data.workspace.texts/update-attrs",-6808024);$APP.$cljs$cst$3072$show_export_metadata$$=new $APP.$cljs$core$Keyword$$(null,"show-export-metadata","show-export-metadata",-1612589127);
$APP.$cljs$cst$4894$plugin_management$$=new $APP.$cljs$core$Keyword$$(null,"plugin-management","plugin-management",-1941842397);$cljs$cst$3003$malayalam$$=new $APP.$cljs$core$Keyword$$(null,"malayalam","malayalam",1037991502);$cljs$cst$3130$app_DOT_main_DOT_data_DOT_changes_SLASH_update_indexes$$=new $APP.$cljs$core$Keyword$$("app.main.data.changes","update-indexes","app.main.data.changes/update-indexes",-1023381144);
$APP.$cljs$cst$1981$typography$$=new $APP.$cljs$core$Keyword$$(null,"typography","typography",-399568138);$cljs$cst$2594$show_touched$$=new $APP.$cljs$core$Keyword$$(null,"show-touched","show-touched",2135884991);$cljs$cst$3233$app_DOT_main_DOT_data_DOT_profile_SLASH_delete_photo$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","delete-photo","app.main.data.profile/delete-photo",1936641823);
$cljs$cst$5100$leave_and_reassign$$=new $APP.$cljs$core$Keyword$$(null,"leave-and-reassign","leave-and-reassign",-602937808);$cljs$cst$2703$use$$=new $APP.$cljs$core$Keyword$$(null,"use","use",-1846382424);$cljs$cst$2720$feGaussianBlur$$=new $APP.$cljs$core$Keyword$$(null,"feGaussianBlur","feGaussianBlur",1334510033);$APP.$cljs$cst$1806$ignore_lock_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"ignore-lock?","ignore-lock?",1533033230);
$APP.$cljs$cst$3659$app_DOT_main_DOT_data_DOT_workspace_DOT_bool_SLASH_bool_to_group$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.bool","bool-to-group","app.main.data.workspace.bool/bool-to-group",1880089387);$cljs$cst$5303$toggle_zoom_style$$=new $APP.$cljs$core$Keyword$$(null,"toggle-zoom-style","toggle-zoom-style",-1590983685);$APP.$cljs$cst$2175$comment_threads$$=new $APP.$cljs$core$Keyword$$(null,"comment-threads","comment-threads",1951187179);
$APP.$cljs$cst$4544$on_pointer_move$$=new $APP.$cljs$core$Keyword$$(null,"on-pointer-move","on-pointer-move",-775121695);$APP.$cljs$cst$1430$params$$=new $APP.$cljs$core$Keyword$$(null,"params","params",710516235);$APP.$cljs$cst$2612$mod_obj$$=new $APP.$cljs$core$Keyword$$(null,"mod-obj","mod-obj",-1152190456);$cljs$cst$903$malli_DOT_transform_SLASH_too_deep_compilation$$=new $APP.$cljs$core$Keyword$$("malli.transform","too-deep-compilation","malli.transform/too-deep-compilation",-1157462070);
$cljs$cst$662$malli_DOT_core_SLASH_sci_options$$=new $APP.$cljs$core$Keyword$$("malli.core","sci-options","malli.core/sci-options",905728020);$cljs$cst$862$generator$$=new $APP.$cljs$core$Keyword$$(null,"generator","generator",-572962281);$APP.$cljs$cst$1579$uri$$=new $APP.$cljs$core$Keyword$$(null,"uri","uri",-774711847);$cljs$cst$3097$max_blocking_time_ms$$=new $APP.$cljs$core$Keyword$$(null,"max_blocking_time_ms","max_blocking_time_ms",-1621426982);
$APP.$cljs$cst$4933$app_DOT_main_DOT_data_DOT_dashboard_SLASH_start_edit_file_menu$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","start-edit-file-menu","app.main.data.dashboard/start-edit-file-menu",-1952572977);$cljs$cst$3366$handled$$=new $APP.$cljs$core$Keyword$$(null,"handled","handled",1889700151);$APP.$cljs$cst$2956$on_drag$$=new $APP.$cljs$core$Keyword$$(null,"on-drag","on-drag",-69159091);
$cljs$cst$3094$force_sync$$=new $APP.$cljs$core$Keyword$$(null,"force-sync","force-sync",-221292965);$cljs$cst$3367$unhandled$$=new $APP.$cljs$core$Keyword$$(null,"unhandled","unhandled",-114756435);$APP.$cljs$cst$1480$doc$$=new $APP.$cljs$core$Keyword$$(null,"doc","doc",1913296891);
$APP.$cljs$cst$3162$app_DOT_main_DOT_data_DOT_persistence_SLASH_initialize_persistence$$=new $APP.$cljs$core$Keyword$$("app.main.data.persistence","initialize-persistence","app.main.data.persistence/initialize-persistence",1230204553);$APP.$cljs$cst$2236$thumbnails_meta$$=new $APP.$cljs$core$Keyword$$(null,"thumbnails-meta","thumbnails-meta",-596144408);
$cljs$cst$4264$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_tools_SLASH_process_path_tool$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.tools","process-path-tool","app.main.data.workspace.path.tools/process-path-tool",1225713567);$cljs$cst$1851$app_DOT_common_DOT_types_DOT_path_SLASH_content$$=new $APP.$cljs$core$Keyword$$("app.common.types.path","content","app.common.types.path/content",1349685944);
$APP.$cljs$cst$2402$handler$$=new $APP.$cljs$core$Keyword$$(null,"handler","handler",-195596612);$cljs$cst$474$malli_DOT_core_SLASH_in$$=new $APP.$cljs$core$Keyword$$("malli.core","in","malli.core/in",-1208578537);$cljs$cst$4392$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_layout_positions$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","update-layout-positions","app.main.data.workspace.shape-layout/update-layout-positions",-42063987);
$cljs$cst$4811$open_color_picker$$=new $APP.$cljs$core$Keyword$$(null,"open-color-picker","open-color-picker",-1582984859);$cljs$cst$3198$app_DOT_main_DOT_data_DOT_profile_SLASH_set_profile$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","set-profile","app.main.data.profile/set-profile",145925411);$cljs$cst$3522$ignore_tree$$=new $APP.$cljs$core$Keyword$$(null,"ignore-tree","ignore-tree",864252283);
$APP.$cljs$cst$3210$app_DOT_main_DOT_data_DOT_profile_SLASH_request_email_change$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","request-email-change","app.main.data.profile/request-email-change",1254180691);$APP.$cljs$cst$1472$separator$$=new $APP.$cljs$core$Keyword$$(null,"separator","separator",-1628749125);$APP.$cljs$cst$3899$fragment_id$$=new $APP.$cljs$core$Keyword$$(null,"fragment-id","fragment-id",216690564);
$cljs$cst$854$gen_SLASH_min$$=new $APP.$cljs$core$Keyword$$("gen","min","gen/min",444569458);$cljs$cst$4644$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_sizing_token$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","apply-sizing-token","app.main.data.workspace.tokens.application/apply-sizing-token",-1119191447);$APP.$cljs$cst$2472$graphics$$=new $APP.$cljs$core$Keyword$$(null,"graphics","graphics",-2079995979);
$cljs$cst$4355$pointer_update$$=new $APP.$cljs$core$Keyword$$(null,"pointer-update","pointer-update",508088975);$cljs$cst$4227$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_handle_drawing_end$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","handle-drawing-end","app.main.data.workspace.path.drawing/handle-drawing-end",-2005869406);
$APP.$cljs$cst$234$clojure_DOT_core_SLASH_unquote$$=new $APP.$cljs$core$Symbol$$("clojure.core","unquote","clojure.core/unquote",843087510,null);$APP.$cljs$cst$4952$delete_file$$=new $APP.$cljs$core$Keyword$$(null,"delete-file","delete-file",527846719);$cljs$cst$3946$get_file_object_thumbnails$$=new $APP.$cljs$core$Keyword$$(null,"get-file-object-thumbnails","get-file-object-thumbnails",574280650);
$APP.$cljs$cst$5126$dashboard_team_webhooks$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-team-webhooks","dashboard-team-webhooks",884385449);$APP.$cljs$cst$1631$objects$$=new $APP.$cljs$core$Keyword$$(null,"objects","objects",2099713734);$cljs$cst$335$sci_DOT_core_SLASH_eval_string_STAR_$$=new $APP.$cljs$core$Symbol$$("sci.core","eval-string*","sci.core/eval-string*",2134763594,null);$APP.$cljs$cst$1810$modifiers$$=new $APP.$cljs$core$Keyword$$(null,"modifiers","modifiers",50378834);
$APP.$cljs$cst$298$schema$$=new $APP.$cljs$core$Keyword$$(null,"schema","schema",-1582001791);$APP.$cljs$cst$2453$app_DOT_main_DOT_router_SLASH_initialize_router$$=new $APP.$cljs$core$Keyword$$("app.main.router","initialize-router","app.main.router/initialize-router",-1818163306);
$APP.$cljs$cst$3155$app_DOT_main_DOT_data_DOT_persistence_SLASH_discard_persistence_state$$=new $APP.$cljs$core$Keyword$$("app.main.data.persistence","discard-persistence-state","app.main.data.persistence/discard-persistence-state",-693149898);$APP.$cljs$cst$2515$dashboard_search$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-search","dashboard-search",-644447359);
$APP.$cljs$cst$4513$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_guide_context_menu$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","show-guide-context-menu","app.main.data.workspace/show-guide-context-menu",-421635296);$APP.$cljs$cst$178$splicing_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"splicing?","splicing?",-428596366);$cljs$cst$2846$surfaceScale$$=new $APP.$cljs$core$Keyword$$(null,"surfaceScale","surfaceScale",2133929940);
$cljs$cst$1077$cljs_DOT_spec_DOT_alpha_SLASH_describe$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","describe","cljs.spec.alpha/describe",1883026911);$APP.$cljs$cst$2152$editing$$=new $APP.$cljs$core$Keyword$$(null,"editing","editing",1365491601);$APP.$cljs$cst$3953$js_SLASH_nonlocal_changes$$=new $APP.$cljs$core$Keyword$$("js","nonlocal-changes","js/nonlocal-changes",-147626396);$APP.$cljs$cst$1944$toggle_overlay$$=new $APP.$cljs$core$Keyword$$(null,"toggle-overlay","toggle-overlay",1195934961);
$cljs$cst$748$scheme$$=new $APP.$cljs$core$Keyword$$(null,"scheme","scheme",90199613);$APP.$cljs$cst$171$test$$=new $APP.$cljs$core$Keyword$$(null,"test","test",577538877);$APP.$cljs$cst$3286$app_DOT_main_DOT_data_DOT_team_SLASH_update_team_photo$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","update-team-photo","app.main.data.team/update-team-photo",-1731113001);
$cljs$cst$3856$duplicate_move_started_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"duplicate-move-started?","duplicate-move-started?",-158515824);$APP.$cljs$cst$2199$edition$$=new $APP.$cljs$core$Keyword$$(null,"edition","edition",1337508089);$cljs$cst$1095$cljs_DOT_spec_DOT_alpha_SLASH_amp$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","amp","cljs.spec.alpha/amp",831147508);$APP.$cljs$cst$2057$guides$$=new $APP.$cljs$core$Keyword$$(null,"guides","guides",-1398390510);
$cljs$cst$4584$error_DOT_style_dictionary_SLASH_value_with_units$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","value-with-units","error.style-dictionary/value-with-units",-1838622742);$APP.$cljs$cst$4925$get_team_deleted_files$$=new $APP.$cljs$core$Keyword$$(null,"get-team-deleted-files","get-team-deleted-files",888137090);$cljs$cst$3047$focus_offset$$=new $APP.$cljs$core$Keyword$$(null,"focus-offset","focus-offset",2058579811);
$cljs$cst$4214$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_shortcuts_SLASH_esc_pressed$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.shortcuts","esc-pressed","app.main.data.workspace.path.shortcuts/esc-pressed",2080782952);$APP.$cljs$cst$4396$calculate_params_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"calculate-params?","calculate-params?",-38704171);
$cljs$cst$1097$cljs_DOT_spec_DOT_alpha_SLASH_alt$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","alt","cljs.spec.alpha/alt",523685437);$APP.$cljs$cst$1353$safari_26$$=new $APP.$cljs$core$Keyword$$(null,"safari-26","safari-26",-1413754827);$APP.$cljs$cst$2165$double_click$$=new $APP.$cljs$core$Keyword$$(null,"double-click","double-click",-733492993);$cljs$cst$445$malli_DOT_core_SLASH_walk_entry_vals$$=new $APP.$cljs$core$Keyword$$("malli.core","walk-entry-vals","malli.core/walk-entry-vals",-64238340);
$cljs$cst$4580$error_DOT_style_dictionary_SLASH_value_with_percent$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","value-with-percent","error.style-dictionary/value-with-percent",1914161576);$cljs$cst$1015$keys_pred$$=new $APP.$cljs$core$Keyword$$(null,"keys-pred","keys-pred",858984739);$APP.$cljs$cst$4593$error_DOT_token_SLASH_name_collision$$=new $APP.$cljs$core$Keyword$$("error.token","name-collision","error.token/name-collision",-1323055277);
$cljs$cst$3209$app_DOT_main_DOT_data_DOT_profile_SLASH_toggle_theme$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","toggle-theme","app.main.data.profile/toggle-theme",481874575);$APP.$cljs$cst$3536$child_inst$$=new $APP.$cljs$core$Keyword$$(null,"child-inst","child-inst",2129957566);$APP.$cljs$cst$2542$annotation$$=new $APP.$cljs$core$Keyword$$(null,"annotation","annotation",-344661666);$cljs$cst$2593$show_ids$$=new $APP.$cljs$core$Keyword$$(null,"show-ids","show-ids",1853916915);
$APP.$cljs$cst$241$cljs_DOT_core_SLASH_array_map$$=new $APP.$cljs$core$Symbol$$("cljs.core","array-map","cljs.core/array-map",-1519210683,null);$APP.$cljs$cst$2969$fonts$$=new $APP.$cljs$core$Keyword$$(null,"fonts","fonts",1683167295);$APP.$cljs$cst$3290$emails$$=new $APP.$cljs$core$Keyword$$(null,"emails","emails",306754554);$APP.$cljs$cst$5089$on_focus$$=new $APP.$cljs$core$Keyword$$(null,"on-focus","on-focus",-13737624);
$APP.$cljs$cst$4127$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_colorpalette_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","colorpalette-selected","app.main.data.workspace.colors/colorpalette-selected",-553076822);$cljs$cst$5320$debug_SLASH_repair_current_file$$=new $APP.$cljs$core$Keyword$$("debug","repair-current-file","debug/repair-current-file",-71878210);$cljs$cst$3781$show_grids_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"show-grids?","show-grids?",-1588571301);
$cljs$cst$4962$app_DOT_main_DOT_data_DOT_dashboard_SLASH_move_files$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","move-files","app.main.data.dashboard/move-files",1848681271);$cljs$cst$3560$lock$$=new $APP.$cljs$core$Keyword$$(null,"lock","lock",-488188066);$APP.$cljs$cst$1588$text$$=new $APP.$cljs$core$Keyword$$(null,"text","text",-1790561697);
$cljs$cst$353$malli_DOT_core_SLASH_allow_invalid_refs$$=new $APP.$cljs$core$Keyword$$("malli.core","allow-invalid-refs","malli.core/allow-invalid-refs",-1863169617);$cljs$cst$1845$minLength$$=new $APP.$cljs$core$Keyword$$(null,"minLength","minLength",-1538722770);$APP.$cljs$cst$4846$increase_zoom$$=new $APP.$cljs$core$Keyword$$(null,"increase-zoom","increase-zoom",853377297);$APP.$cljs$cst$3114$buffer_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"buffer?","buffer?",607721787);
$APP.$cljs$cst$4517$app_DOT_main_DOT_data_DOT_workspace_SLASH_change_pixel_grid_color$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","change-pixel-grid-color","app.main.data.workspace/change-pixel-grid-color",-845321922);$APP.$cljs$cst$4785$subsections$$=new $APP.$cljs$core$Keyword$$(null,"subsections","subsections",689265297);$cljs$cst$2913$stroke_dashoffset$$=new $APP.$cljs$core$Keyword$$(null,"stroke-dashoffset","stroke-dashoffset",-782320340);
$cljs$cst$3372$only_creator_can_lock$$=new $APP.$cljs$core$Keyword$$(null,"only-creator-can-lock","only-creator-can-lock",-1061349571);$cljs$cst$2141$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_change_hover_state$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","change-hover-state","app.main.data.workspace.selection/change-hover-state",972605989);$cljs$cst$2817$horiz_adv_x$$=new $APP.$cljs$core$Keyword$$(null,"horiz-adv-x","horiz-adv-x",1555956653);
$APP.$cljs$cst$1704$layout_item_max_h$$=new $APP.$cljs$core$Keyword$$(null,"layout-item-max-h","layout-item-max-h",-1762118307);$cljs$cst$3289$create_team$$=new $APP.$cljs$core$Keyword$$(null,"create-team","create-team",1092298721);$APP.$cljs$cst$2266$app_DOT_util_DOT_sse_SLASH_permanently_delete_team_files$$=new $APP.$cljs$core$Keyword$$("app.util.sse","permanently-delete-team-files","app.util.sse/permanently-delete-team-files",2138355294);
$cljs$cst$2626$mod_color$$=new $APP.$cljs$core$Keyword$$(null,"mod-color","mod-color",1087466354);$cljs$cst$4051$box_shadow$$=new $APP.$cljs$core$Keyword$$(null,"box-shadow","box-shadow",1600206755);$APP.$cljs$cst$4548$js_SLASH_node$$=new $APP.$cljs$core$Keyword$$("js","node","js/node",581197925);$APP.$cljs$cst$1634$fills$$=new $APP.$cljs$core$Keyword$$(null,"fills","fills",902966780);
$cljs$cst$3981$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_attach_library$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","attach-library","app.main.data.workspace.libraries/attach-library",245542385);$cljs$cst$130$ancestors$$=new $APP.$cljs$core$Keyword$$(null,"ancestors","ancestors",-776045424);$APP.$cljs$cst$1706$layout_item_max_w$$=new $APP.$cljs$core$Keyword$$(null,"layout-item-max-w","layout-item-max-w",1954460366);
$cljs$cst$4208$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_redo_path$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.undo","redo-path","app.main.data.workspace.path.undo/redo-path",-2139290544);$APP.$cljs$cst$2062$main_instance_id$$=new $APP.$cljs$core$Keyword$$(null,"main-instance-id","main-instance-id",1035682372);$cljs$cst$1429$def$$=new $APP.$cljs$core$Keyword$$(null,"def","def",-1043430536);
$cljs$cst$4117$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","paste-shapes","app.main.data.workspace.clipboard/paste-shapes",307773185);$APP.$cljs$cst$5147$title_key$$=new $APP.$cljs$core$Keyword$$(null,"title-key","title-key",830482796);$cljs$cst$2629$mod_media$$=new $APP.$cljs$core$Keyword$$(null,"mod-media","mod-media",556146292);
$cljs$cst$3225$app_DOT_main_DOT_data_DOT_profile_SLASH_update_profile_props$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","update-profile-props","app.main.data.profile/update-profile-props",853020256);$APP.$cljs$cst$1625$component$$=new $APP.$cljs$core$Keyword$$(null,"component","component",1555936782);$APP.$cljs$cst$3729$del$$=new $APP.$cljs$core$Keyword$$(null,"del","del",574975584);$cljs$cst$1018$req_keys$$=new $APP.$cljs$core$Keyword$$(null,"req-keys","req-keys",514319221);
$cljs$cst$2795$targetY$$=new $APP.$cljs$core$Keyword$$(null,"targetY","targetY",-333568504);$cljs$cst$2812$targetX$$=new $APP.$cljs$core$Keyword$$(null,"targetX","targetX",1235875596);$APP.$cljs$cst$4690$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_type$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","toggle-token-type","app.main.data.workspace.tokens.library-edit/toggle-token-type",-502069981);
$APP.$cljs$cst$1711$layout_item_absolute$$=new $APP.$cljs$core$Keyword$$(null,"layout-item-absolute","layout-item-absolute",1832387265);$cljs$cst$4704$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_duplicate_token_set$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","duplicate-token-set","app.main.data.workspace.tokens.library-edit/duplicate-token-set",-1673643418);
$cljs$cst$3035$stopColor$$=new $APP.$cljs$core$Keyword$$(null,"stopColor","stopColor",265518586);$APP.$cljs$cst$4297$app_DOT_main_DOT_data_DOT_workspace_DOT_highlight_SLASH_set_search_match_highlight$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.highlight","set-search-match-highlight","app.main.data.workspace.highlight/set-search-match-highlight",-343090134);$cljs$cst$285$map_entry_separator$$=new $APP.$cljs$core$Keyword$$(null,"map-entry-separator","map-entry-separator",-1791684417);
$cljs$cst$3550$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_collapse_all$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.collapse","collapse-all","app.main.data.workspace.collapse/collapse-all",-1129278533);$cljs$cst$673$float_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"float?","float?",673884616,null);$APP.$cljs$cst$1280$main$$=new $APP.$cljs$core$Keyword$$(null,"main","main",-2117802661);
$cljs$cst$3038$gradientunits$$=new $APP.$cljs$core$Keyword$$(null,"gradientunits","gradientunits",1995839676);$cljs$cst$2765$font_stretch$$=new $APP.$cljs$core$Keyword$$(null,"font-stretch","font-stretch",-1432788830);
$APP.$cljs$cst$4657$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_token_on_color_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","apply-token-on-color-selected","app.main.data.workspace.tokens.application/apply-token-on-color-selected",1061965462);$cljs$cst$5232$show_interactions$$=new $APP.$cljs$core$Keyword$$(null,"show-interactions","show-interactions",622664467);
$APP.$cljs$cst$3673$image_data$$=new $APP.$cljs$core$Keyword$$(null,"image-data","image-data",-377483758);$cljs$cst$3203$app_DOT_main_DOT_data_DOT_profile_SLASH_fetch_profile$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","fetch-profile","app.main.data.profile/fetch-profile",721190654);$cljs$cst$3347$app_DOT_main_DOT_data_DOT_auth_SLASH_login_with_ldap$$=new $APP.$cljs$core$Keyword$$("app.main.data.auth","login-with-ldap","app.main.data.auth/login-with-ldap",1589848961);
$APP.$cljs$cst$2501$threshold$$=new $APP.$cljs$core$Keyword$$(null,"threshold","threshold",204221583);$cljs$cst$3102$wasm_reload_context_failure$$=new $APP.$cljs$core$Keyword$$(null,"wasm-reload-context-failure","wasm-reload-context-failure",1952710806);$APP.$cljs$cst$240$cljs_DOT_core_SLASH_hash_map$$=new $APP.$cljs$core$Symbol$$("cljs.core","hash-map","cljs.core/hash-map",303385767,null);
$cljs$cst$2566$migration_in_progress$$=new $APP.$cljs$core$Keyword$$(null,"migration-in-progress","migration-in-progress",800384336);$cljs$cst$3276$update_team_member_role$$=new $APP.$cljs$core$Keyword$$(null,"update-team-member-role","update-team-member-role",1047320646);$cljs$cst$5329$layout_element$$=new $APP.$cljs$core$Keyword$$(null,"layout-element","layout-element",1221436156);
$APP.$cljs$cst$5246$app_DOT_main_DOT_data_DOT_viewer_SLASH_bundle_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","bundle-fetched","app.main.data.viewer/bundle-fetched",-1017688155);$APP.$cljs$cst$3154$app_DOT_main_DOT_data_DOT_persistence_SLASH_append_commit$$=new $APP.$cljs$core$Keyword$$("app.main.data.persistence","append-commit","app.main.data.persistence/append-commit",-486425046);
$APP.$cljs$cst$3925$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_duplicate_component$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","duplicate-component","app.main.data.workspace.libraries/duplicate-component",-736658175);$cljs$cst$4014$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_paragraph_attrs$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","update-paragraph-attrs","app.main.data.workspace.texts/update-paragraph-attrs",-653068763);
$cljs$cst$2300$screen_color_depth$$=new $APP.$cljs$core$Keyword$$(null,"screen-color-depth","screen-color-depth",-114651382);$cljs$cst$126$keyword_fn$$=new $APP.$cljs$core$Keyword$$(null,"keyword-fn","keyword-fn",-64566675);$APP.$cljs$cst$4423$shape_for_rename$$=new $APP.$cljs$core$Keyword$$(null,"shape-for-rename","shape-for-rename",2104336641);$APP.$cljs$cst$1809$horiz$$=new $APP.$cljs$core$Keyword$$(null,"horiz","horiz",-776322169);
$cljs$cst$4084$z_index$$=new $APP.$cljs$core$Keyword$$(null,"z-index","z-index",1892827090);$cljs$cst$5189$root_copy_not_allowed$$=new $APP.$cljs$core$Keyword$$(null,"root-copy-not-allowed","root-copy-not-allowed",-829410346);$APP.$cljs$cst$4784$underline$$=new $APP.$cljs$core$Keyword$$(null,"underline","underline",2018066703);$cljs$cst$2585$ignore_sync_until$$=new $APP.$cljs$core$Keyword$$(null,"ignore-sync-until","ignore-sync-until",-722845166);
$cljs$cst$1270$enable_render_wasm_info$$=new $APP.$cljs$core$Keyword$$(null,"enable-render-wasm-info","enable-render-wasm-info",-911608122);$cljs$cst$1090$cljs_DOT_spec_DOT_alpha_SLASH_rep$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","rep","cljs.spec.alpha/rep",1483217317);$cljs$cst$5352$import_error$$=new $APP.$cljs$core$Keyword$$(null,"import-error","import-error",1672727808);
$APP.$cljs$cst$3722$display_artboard_names$$=new $APP.$cljs$core$Keyword$$(null,"display-artboard-names","display-artboard-names",-579016150);$cljs$cst$5002$insert_prev_mention$$=new $APP.$cljs$core$Keyword$$(null,"insert-prev-mention","insert-prev-mention",-933004389);$cljs$cst$1919$omit_blocked_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"omit-blocked?","omit-blocked?",558115876);$APP.$cljs$cst$1198$render_switch$$=new $APP.$cljs$core$Keyword$$(null,"render-switch","render-switch",1386607780);
$cljs$cst$5183$ref_shape_is_head$$=new $APP.$cljs$core$Keyword$$(null,"ref-shape-is-head","ref-shape-is-head",842662811);$cljs$cst$5396$prepare_register_profile$$=new $APP.$cljs$core$Keyword$$(null,"prepare-register-profile","prepare-register-profile",-1420419189);$cljs$cst$4340$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_user_disconnect_mcp$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.mcp","user-disconnect-mcp","app.main.data.workspace.mcp/user-disconnect-mcp",-1330109983);
$APP.$cljs$cst$3848$guide$$=new $APP.$cljs$core$Keyword$$(null,"guide","guide",-935563924);$APP.$cljs$cst$4313$draw_interaction_to$$=new $APP.$cljs$core$Keyword$$(null,"draw-interaction-to","draw-interaction-to",-518719969);$APP.$cljs$cst$246$unsupported_operation$$=new $APP.$cljs$core$Keyword$$(null,"unsupported-operation","unsupported-operation",1890540953);$APP.$cljs$cst$4318$move_overlay_index$$=new $APP.$cljs$core$Keyword$$(null,"move-overlay-index","move-overlay-index",1594879653);
$APP.$cljs$cst$4691$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_clear_tokens_types$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","clear-tokens-types","app.main.data.workspace.tokens.library-edit/clear-tokens-types",-205042096);$cljs$cst$292$val_fn$$=new $APP.$cljs$core$Keyword$$(null,"val-fn","val-fn",-474077741);$APP.$cljs$cst$1709$layout_item_v_sizing$$=new $APP.$cljs$core$Keyword$$(null,"layout-item-v-sizing","layout-item-v-sizing",1684690641);
$cljs$cst$47$validator$$=new $APP.$cljs$core$Keyword$$(null,"validator","validator",-1966190681);$cljs$cst$5375$callback_url$$=new $APP.$cljs$core$Keyword$$(null,"callback-url","callback-url",-2640317);$APP.$cljs$cst$2055$default_grids$$=new $APP.$cljs$core$Keyword$$(null,"default-grids","default-grids",-2097814871);$APP.$cljs$cst$2689$mask$$=new $APP.$cljs$core$Keyword$$(null,"mask","mask",-585748447);
$APP.$cljs$cst$4371$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_duplicate_page$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.pages","duplicate-page","app.main.data.workspace.pages/duplicate-page",-622790476);$cljs$cst$3446$app_DOT_main_DOT_data_DOT_comments_SLASH_update_comment_thread$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","update-comment-thread","app.main.data.comments/update-comment-thread",-2103195254);
$cljs$cst$4457$app_DOT_main_DOT_data_DOT_workspace_SLASH_check_libraries_synchronization$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","check-libraries-synchronization","app.main.data.workspace/check-libraries-synchronization",420100831);$cljs$cst$1300$array_builder$$=new $APP.$cljs$core$Keyword$$(null,"array-builder","array-builder",1275998041);$cljs$cst$3088$strokeLinecap$$=new $APP.$cljs$core$Keyword$$(null,"strokeLinecap","strokeLinecap",-1974748357);
$cljs$cst$614$childs$$=new $APP.$cljs$core$Keyword$$(null,"childs","childs",-1293201887);$cljs$cst$3744$selected_palette$$=new $APP.$cljs$core$Keyword$$(null,"selected-palette","selected-palette",-928747602);$APP.$cljs$cst$1561$scroll_width$$=new $APP.$cljs$core$Keyword$$(null,"scroll-width","scroll-width",-752407930);$cljs$cst$1045$cljs_DOT_core_SLASH__LT__EQ_$$=new $APP.$cljs$core$Symbol$$("cljs.core","\x3c\x3d","cljs.core/\x3c\x3d",1677001748,null);
$APP.$cljs$cst$1360$fullname$$=new $APP.$cljs$core$Keyword$$(null,"fullname","fullname",1638772587);$APP.$cljs$cst$2955$on_drop$$=new $APP.$cljs$core$Keyword$$(null,"on-drop","on-drop",1867868491);$APP.$cljs$cst$2200$options_mode$$=new $APP.$cljs$core$Keyword$$(null,"options-mode","options-mode",-1788898697);$APP.$cljs$cst$5673$step$$=new $APP.$cljs$core$Keyword$$(null,"step","step",1288888124);$APP.$cljs$cst$1278$base$$=new $APP.$cljs$core$Keyword$$(null,"base","base",185279322);
$cljs$cst$2070$content_group$$=new $APP.$cljs$core$Keyword$$(null,"content-group","content-group",-531031163);$cljs$cst$2826$widths$$=new $APP.$cljs$core$Keyword$$(null,"widths","widths",-1467327440);$APP.$cljs$cst$2456$app_DOT_main_DOT_router_SLASH_new_window$$=new $APP.$cljs$core$Keyword$$("app.main.router","new-window","app.main.router/new-window",1705407424);
$APP.$cljs$cst$4443$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_combine_selected_as_variants$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","combine-selected-as-variants","app.main.data.workspace.variants/combine-selected-as-variants",-1261075073);$APP.$cljs$cst$4523$app_DOT_main_DOT_data_DOT_workspace_SLASH_stop_rename_page_item$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","stop-rename-page-item","app.main.data.workspace/stop-rename-page-item",-931411905);
$cljs$cst$1251$enable_exporter_svgo$$=new $APP.$cljs$core$Keyword$$(null,"enable-exporter-svgo","enable-exporter-svgo",841382487);$cljs$cst$2596$root_id$$=new $APP.$cljs$core$Keyword$$(null,"root-id","root-id",1294683809);$cljs$cst$4819$paste_replace$$=new $APP.$cljs$core$Keyword$$(null,"paste-replace","paste-replace",-694317945);$cljs$cst$1254$enable_backend_openapi_doc$$=new $APP.$cljs$core$Keyword$$(null,"enable-backend-openapi-doc","enable-backend-openapi-doc",336430877);
$cljs$cst$2634$delta$$=new $APP.$cljs$core$Keyword$$(null,"delta","delta",108939957);$APP.$cljs$cst$4520$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_margins_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","set-margins-selected","app.main.data.workspace/set-margins-selected",-61238202);$APP.$cljs$cst$2224$workspace_wasm_editor_styles$$=new $APP.$cljs$core$Keyword$$(null,"workspace-wasm-editor-styles","workspace-wasm-editor-styles",-1164797697);
$cljs$cst$2102$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_token_set$$=new $APP.$cljs$core$Keyword$$("app.common.types.tokens-lib","token-set","app.common.types.tokens-lib/token-set",169935610);$APP.$cljs$cst$3254$app_DOT_main_DOT_data_DOT_team_SLASH_current_team_id$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","current-team-id","app.main.data.team/current-team-id",675116812);$APP.$cljs$cst$2367$displace$$=new $APP.$cljs$core$Keyword$$(null,"displace","displace",-1153355602);
$APP.$cljs$cst$4816$draw_path$$=new $APP.$cljs$core$Keyword$$(null,"draw-path","draw-path",-1562145274);$cljs$cst$4639$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_generate_font_weight_text_shape_update$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","generate-font-weight-text-shape-update","app.main.data.workspace.tokens.application/generate-font-weight-text-shape-update",-1706226523);
$cljs$cst$2666$not_implemented$$=new $APP.$cljs$core$Keyword$$(null,"not-implemented","not-implemented",1918806714);$APP.$cljs$cst$4452$panning$$=new $APP.$cljs$core$Keyword$$(null,"panning","panning",-1931627491);$cljs$cst$4553$input_id$$=new $APP.$cljs$core$Keyword$$(null,"input-id","input-id",1217549113);$cljs$cst$1383$type_tag$$=new $APP.$cljs$core$Keyword$$(null,"type-tag","type-tag",-1873863267);
$APP.$cljs$cst$3607$ignore_groups_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"ignore-groups?","ignore-groups?",1142155659);$cljs$cst$1842$nullable$$=new $APP.$cljs$core$Keyword$$(null,"nullable","nullable",317149691);$cljs$cst$819$clojure_DOT_test_DOT_check_DOT_generators_SLASH_simple_type_printable$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","simple-type-printable","clojure.test.check.generators/simple-type-printable",-58489962,null);
$APP.$cljs$cst$727$exception$$=new $APP.$cljs$core$Keyword$$(null,"exception","exception",-335277064);$cljs$cst$3478$owner_photo_id$$=new $APP.$cljs$core$Keyword$$(null,"owner-photo-id","owner-photo-id",1979327434);$cljs$cst$1551$potok_DOT_v2_DOT_core_SLASH_undefined$$=new $APP.$cljs$core$Keyword$$("potok.v2.core","undefined","potok.v2.core/undefined",-94368560);
$APP.$cljs$cst$4291$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_remove_frame_guides$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.guides","remove-frame-guides","app.main.data.workspace.guides/remove-frame-guides",-1112880648);$APP.$cljs$cst$281$max_width$$=new $APP.$cljs$core$Keyword$$(null,"max-width","max-width",-1939924051);$cljs$cst$4753$detail_visible$$=new $APP.$cljs$core$Keyword$$(null,"detail-visible","detail-visible",-1852231289);
$APP.$cljs$cst$4971$app_DOT_main_DOT_data_DOT_dashboard_SLASH_handle_change_team_org$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","handle-change-team-org","app.main.data.dashboard/handle-change-team-org",-1440550750);$cljs$cst$660$malli_DOT_core_SLASH_sci_not_available$$=new $APP.$cljs$core$Keyword$$("malli.core","sci-not-available","malli.core/sci-not-available",-1400847277);
$cljs$cst$3559$app_DOT_main_DOT_data_DOT_workspace_DOT_edition_SLASH_clear_edition_mode$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.edition","clear-edition-mode","app.main.data.workspace.edition/clear-edition-mode",1519383038);$cljs$cst$3081$feature_text_editor_wasm$$=new $APP.$cljs$core$Keyword$$(null,"feature-text-editor-wasm","feature-text-editor-wasm",-1642868609);
$APP.$cljs$cst$4705$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_set_enabled_token_set$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","set-enabled-token-set","app.main.data.workspace.tokens.library-edit/set-enabled-token-set",-866264668);
$cljs$cst$4413$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_change_cells_mode$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","change-cells-mode","app.main.data.workspace.shape-layout/change-cells-mode",-187374808);$APP.$cljs$cst$1597$is_admin$$=new $APP.$cljs$core$Keyword$$(null,"is-admin","is-admin",-1352205216);
$APP.$cljs$cst$4019$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_commit_resize_text$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","commit-resize-text","app.main.data.workspace.texts/commit-resize-text",-1450936270);$cljs$cst$3354$app_DOT_main_DOT_data_DOT_auth_SLASH_login_from_register$$=new $APP.$cljs$core$Keyword$$("app.main.data.auth","login-from-register","app.main.data.auth/login-from-register",-1141216339);
$cljs$cst$5258$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_zoom_style$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","toggle-zoom-style","app.main.data.viewer/toggle-zoom-style",349756229);$APP.$cljs$cst$4327$connection_status$$=new $APP.$cljs$core$Keyword$$(null,"connection-status","connection-status",2011317083);$APP.$cljs$cst$945$error_SLASH_code$$=new $APP.$cljs$core$Keyword$$("error","code","error/code",-1740032098);
$cljs$cst$1422$suppress_namespaces$$=new $APP.$cljs$core$Keyword$$(null,"suppress-namespaces","suppress-namespaces",2130686956);$APP.$cljs$cst$5263$show_thumbnails$$=new $APP.$cljs$core$Keyword$$(null,"show-thumbnails","show-thumbnails",405341805);$cljs$cst$2772$xlink_COLON_show$$=new $APP.$cljs$core$Keyword$$(null,"xlink:show","xlink:show",1334818180);$cljs$cst$2187$lost$$=new $APP.$cljs$core$Keyword$$(null,"lost","lost",-744692984);
$APP.$cljs$cst$3211$request_email_change$$=new $APP.$cljs$core$Keyword$$(null,"request-email-change","request-email-change",562477360);$APP.$cljs$cst$2355$cancel$$=new $APP.$cljs$core$Keyword$$(null,"cancel","cancel",-1964088360);$cljs$cst$3452$app_DOT_main_DOT_data_DOT_comments_SLASH_delete_comment_thread_on_workspace$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","delete-comment-thread-on-workspace","app.main.data.comments/delete-comment-thread-on-workspace",862132009);
$cljs$cst$1362$cur$$=new $APP.$cljs$core$Keyword$$(null,"cur","cur",1153190599);$cljs$cst$2757$strikethrough_thickness$$=new $APP.$cljs$core$Keyword$$(null,"strikethrough-thickness","strikethrough-thickness",2087500993);$APP.$cljs$cst$4881$cut$$=new $APP.$cljs$core$Keyword$$(null,"cut","cut",-1042666209);$cljs$cst$5327$background_image$$=new $APP.$cljs$core$Keyword$$(null,"background-image","background-image",-1142314704);
$APP.$cljs$cst$2201$default_font$$=new $APP.$cljs$core$Keyword$$(null,"default-font","default-font",-1606411738);$APP.$cljs$cst$3696$on_svg$$=new $APP.$cljs$core$Keyword$$(null,"on-svg","on-svg",981409697);$cljs$cst$2924$color_interpolation_filters$$=new $APP.$cljs$core$Keyword$$(null,"color-interpolation-filters","color-interpolation-filters",-519168139);$cljs$cst$1158$app_DOT_common_DOT_logging_SLASH_props$$=new $APP.$cljs$core$Keyword$$("app.common.logging","props","app.common.logging/props",-2005375352);
$cljs$cst$383$malli_DOT_core_SLASH_invalid_transformer$$=new $APP.$cljs$core$Keyword$$("malli.core","invalid-transformer","malli.core/invalid-transformer",962129811);$APP.$cljs$cst$3666$layout_bounds$$=new $APP.$cljs$core$Keyword$$(null,"layout-bounds","layout-bounds",-1028383563);$APP.$cljs$cst$1612$image$$=new $APP.$cljs$core$Keyword$$(null,"image","image",-58725096);
$cljs$cst$348$malli_DOT_core_SLASH_multiple_varargs$$=new $APP.$cljs$core$Keyword$$("malli.core","multiple-varargs","malli.core/multiple-varargs",1982057671);$cljs$cst$4041$content_has_text_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"content-has-text?","content-has-text?",1812713130);$APP.$cljs$cst$4955$app_DOT_main_DOT_data_DOT_dashboard_SLASH_set_file_thumbnail$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","set-file-thumbnail","app.main.data.dashboard/set-file-thumbnail",1221585802);
$APP.$cljs$cst$5128$profile_is_muted$$=new $APP.$cljs$core$Keyword$$(null,"profile-is-muted","profile-is-muted",-1029142459);$APP.$cljs$cst$1396$relative_to$$=new $APP.$cljs$core$Keyword$$(null,"relative-to","relative-to",-470100051);$APP.$cljs$cst$1606$frame$$=new $APP.$cljs$core$Keyword$$(null,"frame","frame",-1711082588);$APP.$cljs$cst$1245$hide_release_modal$$=new $APP.$cljs$core$Keyword$$(null,"hide-release-modal","hide-release-modal",2076796063);
$APP.$cljs$cst$3252$app_DOT_main_DOT_data_DOT_profile_SLASH_delete_access_token$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","delete-access-token","app.main.data.profile/delete-access-token",446209693);$APP.$cljs$cst$4150$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_stroke$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","remove-stroke","app.main.data.workspace.colors/remove-stroke",428008657);
$APP.$cljs$cst$4164$current_color$$=new $APP.$cljs$core$Keyword$$(null,"current-color","current-color",1731984119);$APP.$cljs$cst$1694$layout_grid_rows$$=new $APP.$cljs$core$Keyword$$(null,"layout-grid-rows","layout-grid-rows",743773947);$cljs$cst$2649$theme_paths$$=new $APP.$cljs$core$Keyword$$(null,"theme-paths","theme-paths",1306140239);$cljs$cst$3302$create_team_invitations$$=new $APP.$cljs$core$Keyword$$(null,"create-team-invitations","create-team-invitations",-1043494311);
$cljs$cst$5348$import_ready$$=new $APP.$cljs$core$Keyword$$(null,"import-ready","import-ready",-1694649791);$cljs$cst$3692$assemble_file_media_object$$=new $APP.$cljs$core$Keyword$$(null,"assemble-file-media-object","assemble-file-media-object",109074468);$cljs$cst$2461$app_DOT_main_DOT_router_SLASH_reload$$=new $APP.$cljs$core$Keyword$$("app.main.router","reload","app.main.router/reload",1848509416);
$cljs$cst$5252$app_DOT_main_DOT_data_DOT_viewer_SLASH_decrease_zoom$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","decrease-zoom","app.main.data.viewer/decrease-zoom",-2129972803);$cljs$cst$1017$req_specs$$=new $APP.$cljs$core$Keyword$$(null,"req-specs","req-specs",553962313);
$cljs$cst$3755$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_set_workspace_read_only$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.common","set-workspace-read-only","app.main.data.workspace.common/set-workspace-read-only",685254856);$APP.$cljs$cst$2401$coerce$$=new $APP.$cljs$core$Keyword$$(null,"coerce","coerce",1917884504);
$APP.$cljs$cst$4472$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_nudge$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","update-nudge","app.main.data.workspace/update-nudge",726860706);$APP.$cljs$cst$2641$set_tokens_lib$$=new $APP.$cljs$core$Keyword$$(null,"set-tokens-lib","set-tokens-lib",276527580);$cljs$cst$5011$new_position_y$$=new $APP.$cljs$core$Keyword$$(null,"new-position-y","new-position-y",1655805839);
$cljs$cst$1123$cljs_DOT_core_SLASH_map$$=new $APP.$cljs$core$Symbol$$("cljs.core","map","cljs.core/map",-338988913,null);$APP.$cljs$cst$4892$main_menu$$=new $APP.$cljs$core$Keyword$$(null,"main-menu","main-menu",-1471790381);$cljs$cst$1500$when_let$$=new $APP.$cljs$core$Symbol$$(null,"when-let","when-let",-1383043480,null);
$cljs$cst$863$malli_DOT_generator_SLASH_distinct_generator_failure$$=new $APP.$cljs$core$Keyword$$("malli.generator","distinct-generator-failure","malli.generator/distinct-generator-failure",-2085139904);$cljs$cst$4056$padding_block_end$$=new $APP.$cljs$core$Keyword$$(null,"padding-block-end","padding-block-end",923602025);$cljs$cst$5010$new_position_x$$=new $APP.$cljs$core$Keyword$$(null,"new-position-x","new-position-x",-944422613);
$APP.$cljs$cst$4616$verbosity$$=new $APP.$cljs$core$Keyword$$(null,"verbosity","verbosity",-780202586);$APP.$cljs$cst$4818$v_distribute$$=new $APP.$cljs$core$Keyword$$(null,"v-distribute","v-distribute",1681287974);$cljs$cst$3317$update_webhook$$=new $APP.$cljs$core$Keyword$$(null,"update-webhook","update-webhook",1982105527);
$cljs$cst$4706$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_set$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","toggle-token-set","app.main.data.workspace.tokens.library-edit/toggle-token-set",126220304);$APP.$cljs$cst$1291$class$$=new $APP.$cljs$core$Keyword$$(null,"class","class",-2030961996);
$cljs$cst$3638$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","update-shapes","app.main.data.workspace.shapes/update-shapes",-30456202);$cljs$cst$687$uri_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"uri?","uri?",2029475116,null);$APP.$cljs$cst$1795$index$$=new $APP.$cljs$core$Keyword$$(null,"index","index",-1531685915);
$cljs$cst$4070$grid_template_columns$$=new $APP.$cljs$core$Keyword$$(null,"grid-template-columns","grid-template-columns",-594112133);$cljs$cst$3793$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_SLASH_assoc_thumbnail$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.thumbnails","assoc-thumbnail","app.main.data.workspace.thumbnails/assoc-thumbnail",1159203426);
$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$=new $APP.$cljs$core$Keyword$$("app.common.files.changes-builder","page-id","app.common.files.changes-builder/page-id",-522011764);$cljs$cst$4594$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_blur$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","invalid-token-value-shadow-blur","error.style-dictionary/invalid-token-value-shadow-blur",1597718933);
$APP.$cljs$cst$4470$app_DOT_main_DOT_data_DOT_workspace_SLASH_rename_file$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","rename-file","app.main.data.workspace/rename-file",-1400530581);$cljs$cst$492$bounded$$=new $APP.$cljs$core$Keyword$$(null,"bounded","bounded",-1973595643);$APP.$cljs$cst$4627$tokenscript$$=new $APP.$cljs$core$Keyword$$(null,"tokenscript","tokenscript",-1399248500);$cljs$cst$4189$initialized_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"initialized?","initialized?",1707939066);
$APP.$cljs$cst$3239$app_DOT_main_DOT_data_DOT_profile_SLASH_profile_deleted$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","profile-deleted","app.main.data.profile/profile-deleted",-1669169122);$APP.$cljs$cst$4124$wasm_export$$=new $APP.$cljs$core$Keyword$$(null,"wasm-export","wasm-export",-305480110);$APP.$cljs$cst$4860$toggle_alignment$$=new $APP.$cljs$core$Keyword$$(null,"toggle-alignment","toggle-alignment",-428434056);
$APP.$cljs$cst$1187$demo_warning$$=new $APP.$cljs$core$Keyword$$(null,"demo-warning","demo-warning",328616032);$APP.$cljs$cst$4693$folded_token_paths$$=new $APP.$cljs$core$Keyword$$(null,"folded-token-paths","folded-token-paths",-415476994);$cljs$cst$4772$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_request_multiple_export$$=new $APP.$cljs$core$Keyword$$("app.main.data.exports.assets","request-multiple-export","app.main.data.exports.assets/request-multiple-export",430043139);
$APP.$cljs$cst$277$opts$$=new $APP.$cljs$core$Symbol$$(null,"opts","opts",1795607228,null);$cljs$cst$4967$app_DOT_main_DOT_data_DOT_dashboard_SLASH_clone_template$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","clone-template","app.main.data.dashboard/clone-template",-1909834924);$APP.$cljs$cst$4872$paste_props$$=new $APP.$cljs$core$Keyword$$(null,"paste-props","paste-props",197304251);$APP.$cljs$cst$1650$offset_x$$=new $APP.$cljs$core$Keyword$$(null,"offset-x","offset-x",1036466230);
$APP.$cljs$cst$4289$workspace_guides$$=new $APP.$cljs$core$Keyword$$(null,"workspace-guides","workspace-guides",-728045274);$APP.$cljs$cst$1651$offset_y$$=new $APP.$cljs$core$Keyword$$(null,"offset-y","offset-y",2076844008);$cljs$cst$4093$grid_template_areas$$=new $APP.$cljs$core$Keyword$$(null,"grid-template-areas","grid-template-areas",-1162938120);$APP.$cljs$cst$1359$photo_id$$=new $APP.$cljs$core$Keyword$$(null,"photo-id","photo-id",108052797);
$APP.$cljs$cst$1626$touched$$=new $APP.$cljs$core$Keyword$$(null,"touched","touched",-609134419);$APP.$cljs$cst$3175$with_objects_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"with-objects?","with-objects?",1705995428);$APP.$cljs$cst$2348$inline$$=new $APP.$cljs$core$Keyword$$(null,"inline","inline",1399884222);
$cljs$cst$3404$app_DOT_main_DOT_data_DOT_plugins_SLASH_close_current_plugin$$=new $APP.$cljs$core$Keyword$$("app.main.data.plugins","close-current-plugin","app.main.data.plugins/close-current-plugin",-1566988759);$APP.$cljs$cst$2058$background$$=new $APP.$cljs$core$Keyword$$(null,"background","background",-863952629);$cljs$cst$1205$render_wasm_info$$=new $APP.$cljs$core$Keyword$$(null,"render-wasm-info","render-wasm-info",-744689114);
$APP.$cljs$cst$2340$app_DOT_main_DOT_data_DOT_modal_SLASH_update_modal_props$$=new $APP.$cljs$core$Keyword$$("app.main.data.modal","update-modal-props","app.main.data.modal/update-modal-props",-1646685110);$cljs$cst$2819$calcMode$$=new $APP.$cljs$core$Keyword$$(null,"calcMode","calcMode",-1989439090);$APP.$cljs$cst$3071$pixel_grid$$=new $APP.$cljs$core$Keyword$$(null,"pixel-grid","pixel-grid",-148102857);
$cljs$cst$2847$underline_position$$=new $APP.$cljs$core$Keyword$$(null,"underline-position","underline-position",2105325589);$APP.$cljs$cst$4535$find_replace_mode_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"find-replace-mode?","find-replace-mode?",721055929);$APP.$cljs$cst$932$app_DOT_common_DOT_schema_SLASH_explain$$=new $APP.$cljs$core$Keyword$$("app.common.schema","explain","app.common.schema/explain",1944111705);
$cljs$cst$630$re_explainer$$=new $APP.$cljs$core$Keyword$$(null,"re-explainer","re-explainer",-1266871200);$APP.$cljs$cst$5315$make_curve$$=new $APP.$cljs$core$Keyword$$(null,"make-curve","make-curve",-1823500424);$APP.$cljs$cst$2176$share_links$$=new $APP.$cljs$core$Keyword$$(null,"share-links","share-links",-307384490);$cljs$cst$2729$feTile$$=new $APP.$cljs$core$Keyword$$(null,"feTile","feTile",-75598698);$cljs$cst$213$eof$$=new $APP.$cljs$core$Keyword$$(null,"eof","eof",-489063237);
$APP.$cljs$cst$2323$total_shapes$$=new $APP.$cljs$core$Keyword$$(null,"total-shapes","total-shapes",-1728271112);$cljs$cst$3351$redirect_uri$$=new $APP.$cljs$core$Keyword$$(null,"redirect-uri","redirect-uri",374475842);$APP.$cljs$cst$2221$workspace_editor$$=new $APP.$cljs$core$Keyword$$(null,"workspace-editor","workspace-editor",1700926848);$cljs$cst$5085$show_success_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"show-success?","show-success?",-529629397);
$cljs$cst$3865$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_update_dimensions$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","update-dimensions","app.main.data.workspace.transforms/update-dimensions",-469929331);$cljs$cst$739$authority$$=new $APP.$cljs$core$Keyword$$(null,"authority","authority",-551669367);
$APP.$cljs$cst$4263$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_create_node_at_position$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.edition","create-node-at-position","app.main.data.workspace.path.edition/create-node-at-position",-351710409);$APP.$cljs$cst$1777$geometry_parent$$=new $APP.$cljs$core$Keyword$$(null,"geometry-parent","geometry-parent",1427808503);
$APP.$cljs$cst$3456$delete_comment$$=new $APP.$cljs$core$Keyword$$(null,"delete-comment","delete-comment",701145765);$APP.$cljs$cst$2474$cancel_label$$=new $APP.$cljs$core$Keyword$$(null,"cancel-label","cancel-label",-1093310551);$cljs$cst$994$req_un$$=new $APP.$cljs$core$Keyword$$(null,"req-un","req-un",1074571008);$APP.$cljs$cst$1293$end$$=new $APP.$cljs$core$Keyword$$(null,"end","end",-268185958);$cljs$cst$2297$device_model$$=new $APP.$cljs$core$Keyword$$(null,"device-model","device-model",-1108995606);
$APP.$cljs$cst$97$not_native$$=new $APP.$cljs$core$Symbol$$(null,"not-native","not-native",-236392494,null);$APP.$cljs$cst$984$reason$$=new $APP.$cljs$core$Keyword$$(null,"reason","reason",-2070751759);$cljs$cst$1753$invalid_fill$$=new $APP.$cljs$core$Keyword$$(null,"invalid-fill","invalid-fill",88906591);
$cljs$cst$4598$error_DOT_style_dictionary_SLASH_invalid_token_value_text_decoration$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","invalid-token-value-text-decoration","error.style-dictionary/invalid-token-value-text-decoration",234419485);$cljs$cst$2907$kerning$$=new $APP.$cljs$core$Keyword$$(null,"kerning","kerning",702175623);$APP.$cljs$cst$3105$renderer$$=new $APP.$cljs$core$Keyword$$(null,"renderer","renderer",336841071);
$APP.$cljs$cst$2391$reitit_DOT_trie_SLASH_parameters$$=new $APP.$cljs$core$Keyword$$("reitit.trie","parameters","reitit.trie/parameters",-1304786787);$APP.$cljs$cst$2743$polyline$$=new $APP.$cljs$core$Keyword$$(null,"polyline","polyline",-1731551044);$APP.$cljs$cst$4985$ghost$$=new $APP.$cljs$core$Keyword$$(null,"ghost","ghost",-1531157576);$cljs$cst$3544$variant_props$$=new $APP.$cljs$core$Keyword$$(null,"variant-props","variant-props",1890974034);
$cljs$cst$3970$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_notify_sync_file$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","notify-sync-file","app.main.data.workspace.libraries/notify-sync-file",-2008415410);$cljs$cst$5193$not_component_not_allowed$$=new $APP.$cljs$core$Keyword$$(null,"not-component-not-allowed","not-component-not-allowed",-90463620);$cljs$cst$128$parents$$=new $APP.$cljs$core$Keyword$$(null,"parents","parents",-2027538891);
$cljs$cst$3310$app_DOT_main_DOT_data_DOT_team_SLASH_team_deleted$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","team-deleted","app.main.data.team/team-deleted",1479146302);$cljs$cst$4252$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_set_modifiers$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.edition","set-modifiers","app.main.data.workspace.path.edition/set-modifiers",-1530576040);
$APP.$cljs$cst$4243$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_deselect_all$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.selection","deselect-all","app.main.data.workspace.path.selection/deselect-all",-1275706508);$cljs$cst$1404$logical_blocks$$=new $APP.$cljs$core$Keyword$$(null,"logical-blocks","logical-blocks",-1466339776);$APP.$cljs$cst$291$key_fn$$=new $APP.$cljs$core$Keyword$$(null,"key-fn","key-fn",-636154479);
$cljs$cst$3630$mod_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"mod?","mod?",964661324);$cljs$cst$2638$add_typography$$=new $APP.$cljs$core$Keyword$$(null,"add-typography","add-typography",187539002);$cljs$cst$3397$app_DOT_main_DOT_data_DOT_plugins_SLASH_save_current_plugin$$=new $APP.$cljs$core$Keyword$$("app.main.data.plugins","save-current-plugin","app.main.data.plugins/save-current-plugin",-587981712);
$cljs$cst$3319$create_webhook$$=new $APP.$cljs$core$Keyword$$(null,"create-webhook","create-webhook",-997639408);$cljs$cst$3739$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_colorpalette_QMARK_$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","show-colorpalette?","app.main.data.workspace/show-colorpalette?",1262958508);$cljs$cst$3086$image_id$$=new $APP.$cljs$core$Keyword$$(null,"image-id","image-id",-988480565);
$cljs$cst$683$symbol_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"symbol?","symbol?",1820680511,null);$cljs$cst$4514$app_DOT_main_DOT_data_DOT_workspace_SLASH_hide_context_menu$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","hide-context-menu","app.main.data.workspace/hide-context-menu",1649353875);
$cljs$cst$4429$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_remove_empty_properties$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","remove-empty-properties","app.main.data.workspace.variants/remove-empty-properties",317322171);$cljs$cst$2918$flood_opacity$$=new $APP.$cljs$core$Keyword$$(null,"flood-opacity","flood-opacity",-479030608);$APP.$cljs$cst$2319$total_components$$=new $APP.$cljs$core$Keyword$$(null,"total-components","total-components",1903682778);
$cljs$cst$2537$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_default$$=new $APP.$cljs$core$Keyword$$("app.common.schema.desc-native","default","app.common.schema.desc-native/default",145934244);$APP.$cljs$cst$3904$color_for_rename$$=new $APP.$cljs$core$Keyword$$(null,"color-for-rename","color-for-rename",-1584502786);$APP.$cljs$cst$2234$fullscreen_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"fullscreen?","fullscreen?",-1171717820);
$APP.$cljs$cst$3667$row_total_gap$$=new $APP.$cljs$core$Keyword$$(null,"row-total-gap","row-total-gap",-853642856);$APP.$cljs$cst$4893$show_command$$=new $APP.$cljs$core$Keyword$$(null,"show-command","show-command",-828831303);$cljs$cst$3033$xlink_href$$=new $APP.$cljs$core$Keyword$$(null,"xlink-href","xlink-href",244956585);$cljs$cst$5173$component_not_found$$=new $APP.$cljs$core$Keyword$$(null,"component-not-found","component-not-found",482222671);
$APP.$cljs$cst$1629$immediate_suffix_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"immediate-suffix?","immediate-suffix?",-127830647);$cljs$cst$4618$brokenReferences$$=new $APP.$cljs$core$Keyword$$(null,"brokenReferences","brokenReferences",-359732824);
$cljs$cst$4286$app_DOT_main_DOT_data_DOT_workspace_DOT_fix_deleted_fonts_SLASH_fix_deleted_fonts_for_page$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.fix-deleted-fonts","fix-deleted-fonts-for-page","app.main.data.workspace.fix-deleted-fonts/fix-deleted-fonts-for-page",1505644212);$APP.$cljs$cst$2316$counters$$=new $APP.$cljs$core$Keyword$$(null,"counters","counters",33475982);
$APP.$cljs$cst$1972$close_click_outside$$=new $APP.$cljs$core$Keyword$$(null,"close-click-outside","close-click-outside",1133482612);$cljs$cst$4082$flex_shrink$$=new $APP.$cljs$core$Keyword$$(null,"flex-shrink","flex-shrink",1481146383);$cljs$cst$2949$app_DOT_main_DOT_data_DOT_shortcuts_SLASH_push_shortcuts$$=new $APP.$cljs$core$Keyword$$("app.main.data.shortcuts","push-shortcuts","app.main.data.shortcuts/push-shortcuts",926243235);
$cljs$cst$4459$app_DOT_main_DOT_data_DOT_workspace_SLASH_fetch_libries$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","fetch-libries","app.main.data.workspace/fetch-libries",-317037973);$cljs$cst$5187$root_main_not_allowed$$=new $APP.$cljs$core$Keyword$$(null,"root-main-not-allowed","root-main-not-allowed",1386008676);$APP.$cljs$cst$2675$family$$=new $APP.$cljs$core$Keyword$$(null,"family","family",-1313145692);
$cljs$cst$4439$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_rename_variant$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","rename-variant","app.main.data.workspace.variants/rename-variant",-1736167912);$APP.$cljs$cst$5038$lock_file_snapshot$$=new $APP.$cljs$core$Keyword$$(null,"lock-file-snapshot","lock-file-snapshot",641874912);$APP.$cljs$cst$143$via$$=new $APP.$cljs$core$Keyword$$(null,"via","via",-1904457336);
$APP.$cljs$cst$3605$index_SLASH_query_selection$$=new $APP.$cljs$core$Keyword$$("index","query-selection","index/query-selection",-1103332922);$cljs$cst$2077$blur_group$$=new $APP.$cljs$core$Keyword$$(null,"blur-group","blur-group",-1135959686);$cljs$cst$1394$start_block_t$$=new $APP.$cljs$core$Keyword$$(null,"start-block-t","start-block-t",-373430594);$cljs$cst$2822$xlink_COLON_type$$=new $APP.$cljs$core$Keyword$$(null,"xlink:type","xlink:type",-1668107217);
$cljs$cst$869$gen_SLASH_gen$$=new $APP.$cljs$core$Keyword$$("gen","gen","gen/gen",142743606);$cljs$cst$534$malli_DOT_core_SLASH_potentially_recursive_seqex$$=new $APP.$cljs$core$Keyword$$("malli.core","potentially-recursive-seqex","malli.core/potentially-recursive-seqex",-1574993850);$cljs$cst$2694$altGlyph$$=new $APP.$cljs$core$Keyword$$(null,"altGlyph","altGlyph",-1373771936);$cljs$cst$4212$undo_lock$$=new $APP.$cljs$core$Keyword$$(null,"undo-lock","undo-lock",-163038764);
$cljs$cst$4608$warning_SLASH_fn$$=new $APP.$cljs$core$Keyword$$("warning","fn","warning/fn",-218854416);$cljs$cst$4551$label_text$$=new $APP.$cljs$core$Keyword$$(null,"label-text","label-text",-1566972381);$cljs$cst$5176$invalid_main_instance$$=new $APP.$cljs$core$Keyword$$(null,"invalid-main-instance","invalid-main-instance",1361049883);$cljs$cst$665$number_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"number?","number?",-1747282210,null);
$APP.$cljs$cst$1671$fixed$$=new $APP.$cljs$core$Keyword$$(null,"fixed","fixed",-562004358);$APP.$cljs$cst$2512$dashboard_files$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-files","dashboard-files",-1779590854);$APP.$cljs$cst$4390$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_locate_board$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid-layout.editor","locate-board","app.main.data.workspace.grid-layout.editor/locate-board",212264121);
$cljs$cst$728$malli_DOT_core_SLASH_instrument_requires_function_schema$$=new $APP.$cljs$core$Keyword$$("malli.core","instrument-requires-function-schema","malli.core/instrument-requires-function-schema",676671761);$cljs$cst$2106$is_source$$=new $APP.$cljs$core$Keyword$$(null,"is-source","is-source",562449867);$APP.$cljs$cst$1766$letter_spacing$$=new $APP.$cljs$core$Keyword$$(null,"letter-spacing","letter-spacing",-948993767);
$cljs$cst$2559$app_DOT_common_DOT_schema_DOT_desc_js_like_SLASH_inline$$=new $APP.$cljs$core$Keyword$$("app.common.schema.desc-js-like","inline","app.common.schema.desc-js-like/inline",1288677112);$APP.$cljs$cst$1979$text_case$$=new $APP.$cljs$core$Keyword$$(null,"text-case","text-case",1049419399);$APP.$cljs$cst$1581$body$$=new $APP.$cljs$core$Keyword$$(null,"body","body",-2049205669);$APP.$cljs$cst$320$mode$$=new $APP.$cljs$core$Keyword$$(null,"mode","mode",654403691);
$APP.$cljs$cst$2169$interrupt$$=new $APP.$cljs$core$Keyword$$(null,"interrupt","interrupt",-1601071178);$cljs$cst$3018$modi$$=new $APP.$cljs$core$Keyword$$(null,"modi","modi",-125885639);$cljs$cst$3191$app_DOT_main_DOT_data_DOT_media_SLASH_file_QMARK_$$=new $APP.$cljs$core$Symbol$$("app.main.data.media","file?","app.main.data.media/file?",1402746591,null);$APP.$cljs$cst$1931$gutter$$=new $APP.$cljs$core$Keyword$$(null,"gutter","gutter",1047805662);
$APP.$cljs$cst$5077$initial_errors$$=new $APP.$cljs$core$Keyword$$(null,"initial-errors","initial-errors",1471331795);$cljs$cst$107$fallback_impl$$=new $APP.$cljs$core$Keyword$$(null,"fallback-impl","fallback-impl",-1501286995);$APP.$cljs$cst$725$name$$=new $APP.$cljs$core$Keyword$$(null,"name","name",1843675177);$cljs$cst$4788$bold$$=new $APP.$cljs$core$Keyword$$(null,"bold","bold",-116809535);
$cljs$cst$3728$element_options$$=new $APP.$cljs$core$Keyword$$(null,"element-options","element-options",134701240);$cljs$cst$1829$exclusiveMaximum$$=new $APP.$cljs$core$Keyword$$(null,"exclusiveMaximum","exclusiveMaximum",1883434466);$cljs$cst$5142$selected_id$$=new $APP.$cljs$core$Keyword$$(null,"selected-id","selected-id",-1028389044);$cljs$cst$1089$cljs_DOT_spec_DOT_alpha_SLASH_pcat$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","pcat","cljs.spec.alpha/pcat",26406623);
$APP.$cljs$cst$2303$placeholder_SLASH_map$$=new $APP.$cljs$core$Keyword$$("placeholder","map","placeholder/map",-43461776);$cljs$cst$3903$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_color$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","add-color","app.main.data.workspace.libraries/add-color",-136560140);$cljs$cst$1407$writing$$=new $APP.$cljs$core$Keyword$$(null,"writing","writing",-1486865108);
$cljs$cst$3122$ignore_response_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"ignore-response?","ignore-response?",-1427500946);$APP.$cljs$cst$127$keywordize_keys$$=new $APP.$cljs$core$Keyword$$(null,"keywordize-keys","keywordize-keys",1310784252);$cljs$cst$3657$app_DOT_main_DOT_data_DOT_workspace_DOT_bool_SLASH_create_bool_union$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.bool","create-bool-union","app.main.data.workspace.bool/create-bool-union",-720276073);
$cljs$cst$251$inst$$=new $APP.$cljs$core$Symbol$$(null,"inst","inst",-2008473268,null);$cljs$cst$667$int_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"int?","int?",1799729645,null);$APP.$cljs$cst$2398$expand$$=new $APP.$cljs$core$Keyword$$(null,"expand","expand",595248157);$cljs$cst$2279$unexpected_response$$=new $APP.$cljs$core$Keyword$$(null,"unexpected-response","unexpected-response",-1471929181);$APP.$cljs$cst$194$buffer$$=new $APP.$cljs$core$Keyword$$(null,"buffer","buffer",617295198);
$APP.$cljs$cst$4177$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_add_stop$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","update-colorpicker-add-stop","app.main.data.workspace.colors/update-colorpicker-add-stop",1169850309);$APP.$cljs$cst$5280$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_frame_auto$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","go-to-frame-auto","app.main.data.viewer/go-to-frame-auto",-879855067);
$APP.$cljs$cst$237$cljs_DOT_core_SLASH_sequence$$=new $APP.$cljs$core$Symbol$$("cljs.core","sequence","cljs.core/sequence",1908459032,null);$cljs$cst$1834$additionalProperties$$=new $APP.$cljs$core$Keyword$$(null,"additionalProperties","additionalProperties",-1203767392);$cljs$cst$3914$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_typography$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","add-typography","app.main.data.workspace.libraries/add-typography",-1016874370);
$cljs$cst$3575$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_redo$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.undo","redo","app.main.data.workspace.undo/redo",552169249);$cljs$cst$4092$flex_grow$$=new $APP.$cljs$core$Keyword$$(null,"flex-grow","flex-grow",1865160747);$cljs$cst$1016$opt_keys$$=new $APP.$cljs$core$Keyword$$(null,"opt-keys","opt-keys",1262688261);
$cljs$cst$4727$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_set_selected_token_set_id$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","set-selected-token-set-id","app.main.data.workspace.tokens.library-edit/set-selected-token-set-id",1953220092);$cljs$cst$2758$accumulate$$=new $APP.$cljs$core$Keyword$$(null,"accumulate","accumulate",-887744287);$APP.$cljs$cst$3112$reply_to$$=new $APP.$cljs$core$Keyword$$(null,"reply-to","reply-to",-145674792);
$cljs$cst$8$str$$=new $APP.$cljs$core$Symbol$$(null,"str","str",-1564826950,null);$cljs$cst$5014$detach$$=new $APP.$cljs$core$Keyword$$(null,"detach","detach",-1092200572);$APP.$cljs$cst$1587$response_type$$=new $APP.$cljs$core$Keyword$$(null,"response-type","response-type",-1493770458);$APP.$cljs$cst$2233$comments_local$$=new $APP.$cljs$core$Keyword$$(null,"comments-local","comments-local",-777921181);
$cljs$cst$3414$app_DOT_common_DOT_attrs_SLASH_unset$$=new $APP.$cljs$core$Keyword$$("app.common.attrs","unset","app.common.attrs/unset",-1523604502);$cljs$cst$1020$pred_forms$$=new $APP.$cljs$core$Keyword$$(null,"pred-forms","pred-forms",172611832);$cljs$cst$1262$enable_render_wasm_dpr$$=new $APP.$cljs$core$Keyword$$(null,"enable-render-wasm-dpr","enable-render-wasm-dpr",995807953);
$cljs$cst$3932$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_instantiate_component$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","instantiate-component","app.main.data.workspace.libraries/instantiate-component",1762375279);$APP.$cljs$cst$108$val$$=new $APP.$cljs$core$Keyword$$(null,"val","val",128701612);$cljs$cst$1210$urepl_server$$=new $APP.$cljs$core$Keyword$$(null,"urepl-server","urepl-server",742341353);
$cljs$cst$3001$vai$$=new $APP.$cljs$core$Keyword$$(null,"vai","vai",611244557);$cljs$cst$3327$organization_custom_photo$$=new $APP.$cljs$core$Keyword$$(null,"organization-custom-photo","organization-custom-photo",903585248);$APP.$cljs$cst$3938$update_layout$$=new $APP.$cljs$core$Keyword$$(null,"update-layout","update-layout",-1904092183);$APP.$cljs$cst$1610$bool$$=new $APP.$cljs$core$Keyword$$(null,"bool","bool",1444635321);
$APP.$cljs$cst$4814$align_left$$=new $APP.$cljs$core$Keyword$$(null,"align-left","align-left",-412752091);$cljs$cst$0$flush_on_newline$$=new $APP.$cljs$core$Keyword$$(null,"flush-on-newline","flush-on-newline",-151457939);$APP.$cljs$cst$5231$interactions_mode$$=new $APP.$cljs$core$Keyword$$(null,"interactions-mode","interactions-mode",-1234827377);
$cljs$cst$4300$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_add_flow$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","add-flow","app.main.data.workspace.interactions/add-flow",1321840081);$cljs$cst$793$clojure_DOT_test_DOT_check_DOT_generators_SLASH_elements$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","elements","clojure.test.check.generators/elements",438991326,null);
$cljs$cst$3288$app_DOT_main_DOT_data_DOT_team_SLASH_create_team$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","create-team","app.main.data.team/create-team",2113808240);$APP.$cljs$cst$4090$flex_direction$$=new $APP.$cljs$core$Keyword$$(null,"flex-direction","flex-direction",364609438);$cljs$cst$2966$is_mask_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"is-mask?","is-mask?",162096519);
$cljs$cst$774$max_tries_or_opts$$=new $APP.$cljs$core$Keyword$$(null,"max-tries-or-opts","max-tries-or-opts",-609860571);$APP.$cljs$cst$5338$detail$$=new $APP.$cljs$core$Keyword$$(null,"detail","detail",-1545345025);$APP.$cljs$cst$4918$builtin_templates$$=new $APP.$cljs$core$Keyword$$(null,"builtin-templates","builtin-templates",698520902);$APP.$cljs$cst$2061$comment_thread_positions$$=new $APP.$cljs$core$Keyword$$(null,"comment-thread-positions","comment-thread-positions",1712485078);
$cljs$cst$4474$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","update-shape","app.main.data.workspace/update-shape",-1091008128);$cljs$cst$2749$view$$=new $APP.$cljs$core$Keyword$$(null,"view","view",1247994814);$cljs$cst$2710$altGlyphDef$$=new $APP.$cljs$core$Keyword$$(null,"altGlyphDef","altGlyphDef",449263660);$cljs$cst$2919$lighting_color$$=new $APP.$cljs$core$Keyword$$(null,"lighting-color","lighting-color",-1324714767);
$cljs$cst$3326$custom_photo$$=new $APP.$cljs$core$Keyword$$(null,"custom-photo","custom-photo",2039215883);$cljs$cst$4062$margin_block_start$$=new $APP.$cljs$core$Keyword$$(null,"margin-block-start","margin-block-start",1770237075);$APP.$cljs$cst$4238$hover_handlers$$=new $APP.$cljs$core$Keyword$$(null,"hover-handlers","hover-handlers",976618668);
$cljs$cst$4465$app_DOT_main_DOT_data_DOT_workspace_SLASH_initialize_file$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","initialize-file","app.main.data.workspace/initialize-file",-1043378303);$cljs$cst$941$encode_SLASH_json$$=new $APP.$cljs$core$Keyword$$("encode","json","encode/json",303857460);$cljs$cst$4997$display_mentions$$=new $APP.$cljs$core$Keyword$$(null,"display-mentions","display-mentions",-424302104);
$cljs$cst$4634$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_layout_gap$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","update-layout-gap","app.main.data.workspace.tokens.application/update-layout-gap",1668695045);
$cljs$cst$3874$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_nudge_selected_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","nudge-selected-shapes","app.main.data.workspace.transforms/nudge-selected-shapes",-2083477304);$cljs$cst$259$both$$=new $APP.$cljs$core$Keyword$$(null,"both","both",-393648840);
$cljs$cst$3625$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_duplicate_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","duplicate-selected","app.main.data.workspace.selection/duplicate-selected",-1398135140);$cljs$cst$2707$feComponentTransfer$$=new $APP.$cljs$core$Keyword$$(null,"feComponentTransfer","feComponentTransfer",998219049);$cljs$cst$2930$font_size_adjust$$=new $APP.$cljs$core$Keyword$$(null,"font-size-adjust","font-size-adjust",-104156772);
$cljs$cst$4068$border_end_end_radius$$=new $APP.$cljs$core$Keyword$$(null,"border-end-end-radius","border-end-end-radius",670676344);$APP.$cljs$cst$219$symbol$$=new $APP.$cljs$core$Keyword$$(null,"symbol","symbol",-1038572696);$cljs$cst$5083$show_error$$=new $APP.$cljs$core$Keyword$$(null,"show-error","show-error",-664946683);$APP.$cljs$cst$1838$items$$=new $APP.$cljs$core$Keyword$$(null,"items","items",1031954938);
$cljs$cst$2736$feOffset$$=new $APP.$cljs$core$Keyword$$(null,"feOffset","feOffset",492428602);$cljs$cst$3145$translation_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"translation?","translation?",701354827);$cljs$cst$1185$email_verification$$=new $APP.$cljs$core$Keyword$$(null,"email-verification","email-verification",-2006200871);$cljs$cst$1316$handlerForForeign$$=new $APP.$cljs$core$Keyword$$(null,"handlerForForeign","handlerForForeign",-44914005);
$cljs$cst$3699$force_media$$=new $APP.$cljs$core$Keyword$$(null,"force-media","force-media",-1307284609);$cljs$cst$5059$teams_to_delete$$=new $APP.$cljs$core$Keyword$$(null,"teams-to-delete","teams-to-delete",483823986);$cljs$cst$595$catn$$=new $APP.$cljs$core$Keyword$$(null,"catn","catn",-48807277);
$APP.$cljs$cst$4460$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_page_position_data$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","update-page-position-data","app.main.data.workspace/update-page-position-data",-871462718);$APP.$cljs$cst$4806$fit_all$$=new $APP.$cljs$core$Keyword$$(null,"fit-all","fit-all",90208612);
$APP.$cljs$cst$4020$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_props$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","resize-text-debounce-props","app.main.data.workspace.texts/resize-text-debounce-props",861311250);$cljs$cst$2342$app_DOT_main_DOT_data_DOT_modal_SLASH_update_modal$$=new $APP.$cljs$core$Keyword$$("app.main.data.modal","update-modal","app.main.data.modal/update-modal",-1545911932);
$APP.$cljs$cst$3507$delete_font_variant$$=new $APP.$cljs$core$Keyword$$(null,"delete-font-variant","delete-font-variant",1348703111);$cljs$cst$3574$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_undo$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.undo","undo","app.main.data.workspace.undo/undo",-525724021);$APP.$cljs$cst$4961$duplicate_file$$=new $APP.$cljs$core$Keyword$$(null,"duplicate-file","duplicate-file",-875616544);
$APP.$cljs$cst$1346$safari$$=new $APP.$cljs$core$Keyword$$(null,"safari","safari",497115653);$APP.$cljs$cst$4482$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_shape_index$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","set-shape-index","app.main.data.workspace/set-shape-index",-1785790840);$APP.$cljs$cst$2903$stroke$$=new $APP.$cljs$core$Keyword$$(null,"stroke","stroke",1741823555);
$APP.$cljs$cst$235$clojure_DOT_core_SLASH_list$$=new $APP.$cljs$core$Symbol$$("clojure.core","list","clojure.core/list",-1119203325,null);$cljs$cst$2928$marker_mid$$=new $APP.$cljs$core$Keyword$$(null,"marker-mid","marker-mid",-505338277);$cljs$cst$5367$edition_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"edition?","edition?",594759303);$APP.$cljs$cst$4663$tokens_SLASH_letter_spacing$$=new $APP.$cljs$core$Keyword$$("tokens","letter-spacing","tokens/letter-spacing",70255795);
$APP.$cljs$cst$1735$ref_id$$=new $APP.$cljs$core$Keyword$$(null,"ref-id","ref-id",-1783010884);$cljs$cst$4412$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_grid_cells$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","update-grid-cells","app.main.data.workspace.shape-layout/update-grid-cells",2086769469);
$cljs$cst$5277$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_frame$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","go-to-frame","app.main.data.viewer/go-to-frame",-2013221731);$APP.$cljs$cst$5374$settings_profile$$=new $APP.$cljs$core$Keyword$$(null,"settings-profile","settings-profile",-520294200);$cljs$cst$1277$minor$$=new $APP.$cljs$core$Keyword$$(null,"minor","minor",-608536071);$cljs$cst$1225$quotes$$=new $APP.$cljs$core$Keyword$$(null,"quotes","quotes",-844987790);
$cljs$cst$1887$relative$$=new $APP.$cljs$core$Keyword$$(null,"relative","relative",22796862);$cljs$cst$2773$restart$$=new $APP.$cljs$core$Keyword$$(null,"restart","restart",-1779883612);$cljs$cst$2811$panose_1$$=new $APP.$cljs$core$Keyword$$(null,"panose-1","panose-1",-1528382164);$cljs$cst$800$clojure_DOT_test_DOT_check_DOT_generators_SLASH_return$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","return","clojure.test.check.generators/return",1744522038,null);
$cljs$cst$569$check$$=new $APP.$cljs$core$Keyword$$(null,"check","check",1226308904);$cljs$cst$3480$app_DOT_main_DOT_data_DOT_comments_SLASH_update_comment_thread_frame$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","update-comment-thread-frame","app.main.data.comments/update-comment-thread-frame",1186444445);
$APP.$cljs$cst$2326$app_DOT_main_DOT_data_DOT_workspace_SLASH_all_libraries_resolved$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","all-libraries-resolved","app.main.data.workspace/all-libraries-resolved",-391037696);$cljs$cst$3603$selected_frame$$=new $APP.$cljs$core$Keyword$$(null,"selected-frame","selected-frame",-617585651);$cljs$cst$2869$fy$$=new $APP.$cljs$core$Keyword$$(null,"fy","fy",550788984);
$APP.$cljs$cst$1869$stroke_cap_end$$=new $APP.$cljs$core$Keyword$$(null,"stroke-cap-end","stroke-cap-end",-411370737);$cljs$cst$2882$fx$$=new $APP.$cljs$core$Keyword$$(null,"fx","fx",-1237829572);$cljs$cst$4610$warning_SLASH_unknown$$=new $APP.$cljs$core$Keyword$$("warning","unknown","warning/unknown",-1993610101);$APP.$cljs$cst$1747$fill_opacity$$=new $APP.$cljs$core$Keyword$$(null,"fill-opacity","fill-opacity",-537571170);
$cljs$cst$3044$anchor_para$$=new $APP.$cljs$core$Keyword$$(null,"anchor-para","anchor-para",-1599568776);$APP.$cljs$cst$1920$workspace_local$$=new $APP.$cljs$core$Keyword$$(null,"workspace-local","workspace-local",1916337699);$cljs$cst$2083$skip_components_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"skip-components?","skip-components?",1022507747);$cljs$cst$718$altn$$=new $APP.$cljs$core$Keyword$$(null,"altn","altn",1717854417);
$APP.$cljs$cst$394$namespace$$=new $APP.$cljs$core$Keyword$$(null,"namespace","namespace",-377510372);$APP.$cljs$cst$936$description$$=new $APP.$cljs$core$Keyword$$(null,"description","description",-1428560544);$APP.$cljs$cst$1865$stroke_cap_start$$=new $APP.$cljs$core$Keyword$$(null,"stroke-cap-start","stroke-cap-start",-2018645757);$APP.$cljs$cst$1607$frame_id$$=new $APP.$cljs$core$Keyword$$(null,"frame-id","frame-id",-636372072);
$APP.$cljs$cst$1913$children_bounds$$=new $APP.$cljs$core$Keyword$$(null,"children-bounds","children-bounds",-1464963835);$cljs$cst$2547$allow_main_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"allow-main?","allow-main?",-837994938);$cljs$cst$1937$mouse_over$$=new $APP.$cljs$core$Keyword$$(null,"mouse-over","mouse-over",-882913683);$APP.$cljs$cst$3131$changes$$=new $APP.$cljs$core$Keyword$$(null,"changes","changes",1492088);
$cljs$cst$4432$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_set_variant_id$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","set-variant-id","app.main.data.workspace.variants/set-variant-id",-615417257);$APP.$cljs$cst$1798$move$$=new $APP.$cljs$core$Keyword$$(null,"move","move",-2110884309);$cljs$cst$2808$dy$$=new $APP.$cljs$core$Keyword$$(null,"dy","dy",1719547243);$cljs$cst$2777$dx$$=new $APP.$cljs$core$Keyword$$(null,"dx","dx",-381796732);
$cljs$cst$4058$margin_block_end$$=new $APP.$cljs$core$Keyword$$(null,"margin-block-end","margin-block-end",-1287470806);$cljs$cst$4438$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_duplicate_or_add_variant$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","duplicate-or-add-variant","app.main.data.workspace.variants/duplicate-or-add-variant",-1689023993);$cljs$cst$3077$watcher$$=new $APP.$cljs$core$Keyword$$(null,"watcher","watcher",2145165251);
$cljs$cst$2800$xml_COLON_space$$=new $APP.$cljs$core$Keyword$$(null,"xml:space","xml:space",-1976466326);$APP.$cljs$cst$4204$alt_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"alt?","alt?",-1427998432);$APP.$cljs$cst$883$en$$=new $APP.$cljs$core$Keyword$$(null,"en","en",88457073);$cljs$cst$1444$colon_up_arrow$$=new $APP.$cljs$core$Keyword$$(null,"colon-up-arrow","colon-up-arrow",244853007);$APP.$cljs$cst$1935$after_delay$$=new $APP.$cljs$core$Keyword$$(null,"after-delay","after-delay",-2054763582);
$cljs$cst$4333$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_notify_other_tabs_disconnect$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.mcp","notify-other-tabs-disconnect","app.main.data.workspace.mcp/notify-other-tabs-disconnect",1212357E3);
$cljs$cst$4354$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_change_team_role$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.notifications","handle-change-team-role","app.main.data.workspace.notifications/handle-change-team-role",210963290);
$cljs$cst$3634$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_commit$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","update-shapes-buffer-commit","app.main.data.workspace.shapes/update-shapes-buffer-commit",-218630666);$cljs$cst$1033$cljs_DOT_core_SLASH_count$$=new $APP.$cljs$core$Symbol$$("cljs.core","count","cljs.core/count",-921270233,null);$cljs$cst$2809$g2$$=new $APP.$cljs$core$Keyword$$(null,"g2","g2",-479351381);
$cljs$cst$2832$g1$$=new $APP.$cljs$core$Keyword$$(null,"g1","g1",1986774193);$APP.$cljs$cst$1833$required$$=new $APP.$cljs$core$Keyword$$(null,"required","required",1807647006);$APP.$cljs$cst$4579$error_DOT_token_SLASH_empty_input$$=new $APP.$cljs$core$Keyword$$("error.token","empty-input","error.token/empty-input",-1506425915);
$cljs$cst$2546$app_DOT_common_DOT_types_DOT_container_SLASH_container$$=new $APP.$cljs$core$Keyword$$("app.common.types.container","container","app.common.types.container/container",-604703537);$cljs$cst$1105$cljs_DOT_core_SLASH_fn$$=new $APP.$cljs$core$Symbol$$("cljs.core","fn","cljs.core/fn",-1065745098,null);
$APP.$cljs$cst$4161$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_apply_color_from_colorpicker$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","apply-color-from-colorpicker","app.main.data.workspace.colors/apply-color-from-colorpicker",-1265564807);$APP.$cljs$cst$516$fn$$=new $APP.$cljs$core$Keyword$$(null,"fn","fn",-1175266204);$APP.$cljs$cst$3933$external_library$$=new $APP.$cljs$core$Keyword$$(null,"external-library","external-library",93332093);
$cljs$cst$2922$marker_start$$=new $APP.$cljs$core$Keyword$$(null,"marker-start","marker-start",-56273582);$APP.$cljs$cst$947$kind$$=new $APP.$cljs$core$Keyword$$(null,"kind","kind",-717265803);$cljs$cst$2494$change$$=new $APP.$cljs$core$Keyword$$(null,"change","change",-1163046502);$cljs$cst$2867$by$$=new $APP.$cljs$core$Keyword$$(null,"by","by",30600856);$APP.$cljs$cst$1563$bottom$$=new $APP.$cljs$core$Keyword$$(null,"bottom","bottom",-1550509018);
$APP.$cljs$cst$4728$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_start_token_set_edition$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","start-token-set-edition","app.main.data.workspace.tokens.library-edit/start-token-set-edition",-1181165769);$cljs$cst$4821$move_unit_down$$=new $APP.$cljs$core$Keyword$$(null,"move-unit-down","move-unit-down",1480083783);
$APP.$cljs$cst$4241$selected_points$$=new $APP.$cljs$core$Keyword$$(null,"selected-points","selected-points",-1374936179);$APP.$cljs$cst$3708$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_process_img_component$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.media","process-img-component","app.main.data.workspace.media/process-img-component",-1524222794);$cljs$cst$2632$mod_component$$=new $APP.$cljs$core$Keyword$$(null,"mod-component","mod-component",335097879);
$APP.$cljs$cst$1721$icon$$=new $APP.$cljs$core$Keyword$$(null,"icon","icon",1679606541);$APP.$cljs$cst$1898$cy$$=new $APP.$cljs$core$Keyword$$(null,"cy","cy",755331060);$APP.$cljs$cst$3499$height_warning_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"height-warning?","height-warning?",1727594341);$cljs$cst$5230$comments_mode$$=new $APP.$cljs$core$Keyword$$(null,"comments-mode","comments-mode",-590013405);$APP.$cljs$cst$1897$cx$$=new $APP.$cljs$core$Keyword$$(null,"cx","cx",1272694324);
$cljs$cst$3277$app_DOT_main_DOT_data_DOT_team_SLASH_delete_member$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","delete-member","app.main.data.team/delete-member",-1611932477);$cljs$cst$3985$variants_count$$=new $APP.$cljs$core$Keyword$$(null,"variants-count","variants-count",-147525642);
$APP.$cljs$cst$5037$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_lock_version$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","lock-version","app.main.data.workspace.versions/lock-version",1380868749);$APP.$cljs$cst$4298$search_match_highlight$$=new $APP.$cljs$core$Keyword$$(null,"search-match-highlight","search-match-highlight",917748691);$APP.$cljs$cst$4787$line_through$$=new $APP.$cljs$core$Keyword$$(null,"line-through","line-through",-250988971);
$APP.$cljs$cst$2037$solid$$=new $APP.$cljs$core$Keyword$$(null,"solid","solid",-2023773691);$cljs$cst$1836$minProperties$$=new $APP.$cljs$core$Keyword$$(null,"minProperties","minProperties",100355152);$cljs$cst$4101$copied_shapes$$=new $APP.$cljs$core$Keyword$$(null,"copied-shapes","copied-shapes",-573831497);$cljs$cst$3987$used_in$$=new $APP.$cljs$core$Keyword$$(null,"used-in","used-in",641553323);$APP.$cljs$cst$2056$flows$$=new $APP.$cljs$core$Keyword$$(null,"flows","flows",-1369576628);
$cljs$cst$315$malli_DOT_core_SLASH_invalid_type$$=new $APP.$cljs$core$Keyword$$("malli.core","invalid-type","malli.core/invalid-type",-1367388450);$APP.$cljs$cst$1371$suffix$$=new $APP.$cljs$core$Keyword$$(null,"suffix","suffix",367373057);$APP.$cljs$cst$4455$af$$=new $APP.$cljs$core$Keyword$$(null,"af","af",1448016173);$cljs$cst$1822$c2$$=new $APP.$cljs$core$Keyword$$(null,"c2","c2",-1561880371);
$cljs$cst$3495$app_DOT_main_DOT_data_DOT_fonts_SLASH_fetch_fonts$$=new $APP.$cljs$core$Keyword$$("app.main.data.fonts","fetch-fonts","app.main.data.fonts/fetch-fonts",967009596);$APP.$cljs$cst$4421$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_paste_grid_tracks$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","paste-grid-tracks","app.main.data.workspace.shape-layout/paste-grid-tracks",1199371823);
$APP.$cljs$cst$1821$c1$$=new $APP.$cljs$core$Keyword$$(null,"c1","c1",1132530803);$cljs$cst$4440$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_rename_comp_or_variant_and_main$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","rename-comp-or-variant-and-main","app.main.data.workspace.variants/rename-comp-or-variant-and-main",-304307975);$APP.$cljs$cst$2231$viewer_local$$=new $APP.$cljs$core$Keyword$$(null,"viewer-local","viewer-local",1813008498);
$cljs$cst$2688$map_to$$=new $APP.$cljs$core$Keyword$$(null,"map-to","map-to",2011737634);$APP.$cljs$cst$4025$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_ids$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","update-text-modifier-debounce-ids","app.main.data.workspace.texts/update-text-modifier-debounce-ids",88238649);$cljs$cst$1433$at$$=new $APP.$cljs$core$Keyword$$(null,"at","at",1476951349);
$APP.$cljs$cst$2222$workspace_editor_state$$=new $APP.$cljs$core$Keyword$$(null,"workspace-editor-state","workspace-editor-state",-794384251);$APP.$cljs$cst$4175$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_stops$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","update-colorpicker-stops","app.main.data.workspace.colors/update-colorpicker-stops",303559819);
$cljs$cst$2255$challenge_required$$=new $APP.$cljs$core$Keyword$$(null,"challenge-required","challenge-required",2136495006);$cljs$cst$1180$email_blacklist$$=new $APP.$cljs$core$Keyword$$(null,"email-blacklist","email-blacklist",860982338);$APP.$cljs$cst$4089$justify_content$$=new $APP.$cljs$core$Keyword$$(null,"justify-content","justify-content",-1990475787);$cljs$cst$2992$cyrillic$$=new $APP.$cljs$core$Keyword$$(null,"cyrillic","cyrillic",-1535699162);
$cljs$cst$5172$component_main_external$$=new $APP.$cljs$core$Keyword$$(null,"component-main-external","component-main-external",-1426309457);$APP.$cljs$cst$3140$save_undo_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"save-undo?","save-undo?",-1533746853);$APP.$cljs$cst$1716$first_column$$=new $APP.$cljs$core$Keyword$$(null,"first-column","first-column",22621775);$APP.$cljs$cst$216$column$$=new $APP.$cljs$core$Keyword$$(null,"column","column",2078222095);
$cljs$cst$853$malli_DOT_generator_SLASH_never_gen$$=new $APP.$cljs$core$Keyword$$("malli.generator","never-gen","malli.generator/never-gen",-887335792);$cljs$cst$860$op$$=new $APP.$cljs$core$Keyword$$(null,"op","op",-1882987955);$cljs$cst$2727$defs$$=new $APP.$cljs$core$Keyword$$(null,"defs","defs",1398449717);$APP.$cljs$cst$2321$total_typographies$$=new $APP.$cljs$core$Keyword$$(null,"total-typographies","total-typographies",-453409679);
$cljs$cst$3296$reassign_to$$=new $APP.$cljs$core$Keyword$$(null,"reassign-to","reassign-to",-161965705);$APP.$cljs$cst$3412$ox$$=new $APP.$cljs$core$Keyword$$(null,"ox","ox",571335403);$APP.$cljs$cst$433$or$$=new $APP.$cljs$core$Keyword$$(null,"or","or",235744169);$cljs$cst$3488$woff1_file_id$$=new $APP.$cljs$core$Keyword$$(null,"woff1-file-id","woff1-file-id",1153304603);$cljs$cst$2293$os$$=new $APP.$cljs$core$Keyword$$(null,"os","os",795021913);
$cljs$cst$2780$zoomAndPan$$=new $APP.$cljs$core$Keyword$$(null,"zoomAndPan","zoomAndPan",-449580731);$APP.$cljs$cst$3413$oy$$=new $APP.$cljs$core$Keyword$$(null,"oy","oy",-831335459);$APP.$cljs$cst$4710$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_delete_token_set_group$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","delete-token-set-group","app.main.data.workspace.tokens.library-edit/delete-token-set-group",1613518656);
$cljs$cst$4206$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_undo_SLASH_undo_path$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.undo","undo-path","app.main.data.workspace.path.undo/undo-path",-442631179);$APP.$cljs$cst$1960$duration$$=new $APP.$cljs$core$Keyword$$(null,"duration","duration",1444101068);$APP.$cljs$cst$1646$r1$$=new $APP.$cljs$core$Keyword$$(null,"r1","r1",690974900);
$APP.$cljs$cst$2103$update_token_fn$$=new $APP.$cljs$core$Keyword$$(null,"update-token-fn","update-token-fn",-805038447);$APP.$cljs$cst$1648$r3$$=new $APP.$cljs$core$Keyword$$(null,"r3","r3",-2027148174);$APP.$cljs$cst$1647$r2$$=new $APP.$cljs$core$Keyword$$(null,"r2","r2",252844174);$cljs$cst$2748$switch$$=new $APP.$cljs$core$Keyword$$(null,"switch","switch",71881310);$APP.$cljs$cst$5158$danger$$=new $APP.$cljs$core$Keyword$$(null,"danger","danger",-624338030);
$APP.$cljs$cst$2332$session_id$$=new $APP.$cljs$core$Keyword$$(null,"session-id","session-id",-1147060351);$APP.$cljs$cst$3866$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_change_orientation$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","change-orientation","app.main.data.workspace.transforms/change-orientation",-140139154);$cljs$cst$1415$buffer_level$$=new $APP.$cljs$core$Keyword$$(null,"buffer-level","buffer-level",928864731);
$cljs$cst$1085$ps$$=new $APP.$cljs$core$Keyword$$(null,"ps","ps",292358046);$APP.$cljs$cst$1649$r4$$=new $APP.$cljs$core$Keyword$$(null,"r4","r4",1134323163);$APP.$cljs$cst$2159$pt$$=new $APP.$cljs$core$Keyword$$(null,"pt","pt",556460867);$cljs$cst$4614$transformGroup$$=new $APP.$cljs$core$Keyword$$(null,"transformGroup","transformGroup",2048632909);$APP.$cljs$cst$2960$over$$=new $APP.$cljs$core$Keyword$$(null,"over","over",192553051);
$cljs$cst$3134$app_DOT_main_DOT_data_DOT_changes_SLASH_sync_wasm_structural_changes$$=new $APP.$cljs$core$Keyword$$("app.main.data.changes","sync-wasm-structural-changes","app.main.data.changes/sync-wasm-structural-changes",-932186908);$cljs$cst$1106$cljs_DOT_core_SLASH_or$$=new $APP.$cljs$core$Symbol$$("cljs.core","or","cljs.core/or",1201033885,null);$APP.$cljs$cst$1912$ignore_shadow_margin_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"ignore-shadow-margin?","ignore-shadow-margin?",-10356246);
$cljs$cst$463$map_of$$=new $APP.$cljs$core$Keyword$$(null,"map-of","map-of",1189682355);$APP.$cljs$cst$1323$ms$$=new $APP.$cljs$core$Keyword$$(null,"ms","ms",-1152709733);$cljs$cst$2986$tamil$$=new $APP.$cljs$core$Keyword$$(null,"tamil","tamil",870246788);$APP.$cljs$cst$3163$app_DOT_main_DOT_data_DOT_persistence_SLASH_persistence_notification$$=new $APP.$cljs$core$Keyword$$("app.main.data.persistence","persistence-notification","app.main.data.persistence/persistence-notification",-1959405001);
$APP.$cljs$cst$3219$dashboard_comments$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-comments","dashboard-comments",-1615685019);$APP.$cljs$cst$1093$p1$$=new $APP.$cljs$core$Keyword$$(null,"p1","p1",-936759954);$cljs$cst$1413$pretty_writer$$=new $APP.$cljs$core$Keyword$$(null,"pretty-writer","pretty-writer",-1222834267);
$APP.$cljs$cst$4105$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_from_event$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","paste-from-event","app.main.data.workspace.clipboard/paste-from-event",1440439287);$APP.$cljs$cst$1687$p3$$=new $APP.$cljs$core$Keyword$$(null,"p3","p3",1731040739);$APP.$cljs$cst$1091$p2$$=new $APP.$cljs$core$Keyword$$(null,"p2","p2",905500641);$APP.$cljs$cst$176$ns$$=new $APP.$cljs$core$Keyword$$(null,"ns","ns",441598760);
$APP.$cljs$cst$1688$p4$$=new $APP.$cljs$core$Keyword$$(null,"p4","p4",-1090126814);$cljs$cst$2702$font_face_uri$$=new $APP.$cljs$core$Keyword$$(null,"font-face-uri","font-face-uri",1173705095);$APP.$cljs$cst$2653$move_token_set$$=new $APP.$cljs$core$Keyword$$(null,"move-token-set","move-token-set",1469939284);$cljs$cst$2497$removed$$=new $APP.$cljs$core$Keyword$$(null,"removed","removed",609626430);$cljs$cst$2069$mask_group$$=new $APP.$cljs$core$Keyword$$(null,"mask-group","mask-group",1146803642);
$cljs$cst$2714$mpath$$=new $APP.$cljs$core$Keyword$$(null,"mpath","mpath",526090606);$APP.$cljs$cst$1703$m4$$=new $APP.$cljs$core$Keyword$$(null,"m4","m4",-1624571215);$APP.$cljs$cst$4246$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_handle_area_selection$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.selection","handle-area-selection","app.main.data.workspace.path.selection/handle-area-selection",71306449);
$APP.$cljs$cst$1702$m3$$=new $APP.$cljs$core$Keyword$$(null,"m3","m3",-703635357);$cljs$cst$1086$ks$$=new $APP.$cljs$core$Keyword$$(null,"ks","ks",1900203942);$APP.$cljs$cst$1701$m2$$=new $APP.$cljs$core$Keyword$$(null,"m2","m2",-587003306);
$cljs$cst$4701$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_create_token_set$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","create-token-set","app.main.data.workspace.tokens.library-edit/create-token-set",-1509240223);$APP.$cljs$cst$1700$m1$$=new $APP.$cljs$core$Keyword$$(null,"m1","m1",-108094626);
$APP.$cljs$cst$4703$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_rename_token_set_group$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","rename-token-set-group","app.main.data.workspace.tokens.library-edit/rename-token-set-group",-1614537215);$APP.$cljs$cst$3250$app_DOT_main_DOT_data_DOT_profile_SLASH_create_access_token$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","create-access-token","app.main.data.profile/create-access-token",-1348344493);
$cljs$cst$1487$condp$$=new $APP.$cljs$core$Symbol$$(null,"condp","condp",1054325175,null);$cljs$cst$4057$min_inline_size$$=new $APP.$cljs$core$Keyword$$(null,"min-inline-size","min-inline-size",-2050841943);$APP.$cljs$cst$2947$overwrite$$=new $APP.$cljs$core$Keyword$$(null,"overwrite","overwrite",1291442417);$APP.$cljs$cst$4849$reset_zoom$$=new $APP.$cljs$core$Keyword$$(null,"reset-zoom","reset-zoom",540867442);
$cljs$cst$2249$max_retries$$=new $APP.$cljs$core$Keyword$$(null,"max-retries","max-retries",-1933762121);$APP.$cljs$cst$2954$data_type$$=new $APP.$cljs$core$Keyword$$(null,"data-type","data-type",-326421468);$cljs$cst$3769$filter_in$$=new $APP.$cljs$core$Keyword$$(null,"filter-in","filter-in",1424647666);$cljs$cst$5184$shape_ref_cycle$$=new $APP.$cljs$core$Keyword$$(null,"shape-ref-cycle","shape-ref-cycle",-1233535891);
$cljs$cst$3770$filter_id$$=new $APP.$cljs$core$Keyword$$(null,"filter-id","filter-id",-84826199);$cljs$cst$4043$workspace_text_session_geom$$=new $APP.$cljs$core$Keyword$$(null,"workspace-text-session-geom","workspace-text-session-geom",769084484);$cljs$cst$3917$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_rename_typography$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","rename-typography","app.main.data.workspace.libraries/rename-typography",1632768510);
$cljs$cst$3278$delete_team_member$$=new $APP.$cljs$core$Keyword$$(null,"delete-team-member","delete-team-member",400304162);$cljs$cst$4652$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_unapply_token$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","unapply-token","app.main.data.workspace.tokens.application/unapply-token",-990592613);
$cljs$cst$366$malli_DOT_core_SLASH_key_missing$$=new $APP.$cljs$core$Keyword$$("malli.core","key-missing","malli.core/key-missing",-161579801);$APP.$cljs$cst$266$id$$=new $APP.$cljs$core$Keyword$$(null,"id","id",-1388402092);$cljs$cst$3853$x_ranges$$=new $APP.$cljs$core$Keyword$$(null,"x-ranges","x-ranges",-188706060);$cljs$cst$2885$k2$$=new $APP.$cljs$core$Keyword$$(null,"k2","k2",1429301820);$cljs$cst$1841$maxItems$$=new $APP.$cljs$core$Keyword$$(null,"maxItems","maxItems",576652798);
$cljs$cst$2884$k1$$=new $APP.$cljs$core$Keyword$$(null,"k1","k1",952658428);$APP.$cljs$cst$3513$app_DOT_main_DOT_data_DOT_project_SLASH_finalize_project$$=new $APP.$cljs$core$Keyword$$("app.main.data.project","finalize-project","app.main.data.project/finalize-project",-533802710);$cljs$cst$2848$k4$$=new $APP.$cljs$core$Keyword$$(null,"k4","k4",-899960619);$cljs$cst$2845$k3$$=new $APP.$cljs$core$Keyword$$(null,"k3","k3",1937862580);
$APP.$cljs$cst$297$in$$=new $APP.$cljs$core$Keyword$$(null,"in","in",-1531184865);$cljs$cst$4072$border_start_start_radius$$=new $APP.$cljs$core$Keyword$$(null,"border-start-start-radius","border-start-start-radius",520714431);$APP.$cljs$cst$1596$can_edit$$=new $APP.$cljs$core$Keyword$$(null,"can-edit","can-edit",442089902);$APP.$cljs$cst$4869$create_component_variant$$=new $APP.$cljs$core$Keyword$$(null,"create-component-variant","create-component-variant",1450799770);
$cljs$cst$3123$completed$$=new $APP.$cljs$core$Keyword$$(null,"completed","completed",-486056503);$APP.$cljs$cst$890$error_SLASH_path$$=new $APP.$cljs$core$Keyword$$("error","path","error/path",-419192760);$cljs$cst$1586$app_DOT_util_DOT_http_SLASH_response$$=new $APP.$cljs$core$Keyword$$("app.util.http","response","app.util.http/response",-877557607);$cljs$cst$730$merge_default$$=new $APP.$cljs$core$Keyword$$(null,"merge-default","merge-default",1152742083);
$cljs$cst$3438$app_DOT_main_DOT_data_DOT_comments_SLASH_create_thread_on_workspace$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","create-thread-on-workspace","app.main.data.comments/create-thread-on-workspace",558477768);$APP.$cljs$cst$1997$cursor$$=new $APP.$cljs$core$Keyword$$(null,"cursor","cursor",1011937484);$cljs$cst$4053$margin_inline_end$$=new $APP.$cljs$core$Keyword$$(null,"margin-inline-end","margin-inline-end",-1696808891);
$cljs$cst$1152$js$$=new $APP.$cljs$core$Keyword$$(null,"js","js",1768080579);$cljs$cst$4943$move_project$$=new $APP.$cljs$core$Keyword$$(null,"move-project","move-project",797212190);$cljs$cst$1261$enable_component_thumbnails$$=new $APP.$cljs$core$Keyword$$(null,"enable-component-thumbnails","enable-component-thumbnails",-939868166);$cljs$cst$5256$fit$$=new $APP.$cljs$core$Keyword$$(null,"fit","fit",869444807);$APP.$cljs$cst$1526$y2$$=new $APP.$cljs$core$Keyword$$(null,"y2","y2",-718691301);
$APP.$cljs$cst$1524$y1$$=new $APP.$cljs$core$Keyword$$(null,"y1","y1",589123466);$APP.$cljs$cst$1697$fix$$=new $APP.$cljs$core$Keyword$$(null,"fix","fix",-1031773329);$cljs$cst$3459$app_DOT_main_DOT_data_DOT_comments_SLASH_retrieve_comment_threads$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","retrieve-comment-threads","app.main.data.comments/retrieve-comment-threads",-1073541648);
$APP.$cljs$cst$2602$set_default_grid$$=new $APP.$cljs$core$Keyword$$(null,"set-default-grid","set-default-grid",-1968413784);$cljs$cst$5384$on_success_callback$$=new $APP.$cljs$core$Keyword$$(null,"on-success-callback","on-success-callback",1038309943);$cljs$cst$4332$mcp_SLASH_pong$$=new $APP.$cljs$core$Keyword$$("mcp","pong","mcp/pong",-172116804);$APP.$cljs$cst$4667$tokens_SLASH_typography$$=new $APP.$cljs$core$Keyword$$("tokens","typography","tokens/typography",468555404);
$APP.$cljs$cst$983$cljs_DOT_spec_DOT_alpha_SLASH_value$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","value","cljs.spec.alpha/value",1974786274);$APP.$cljs$cst$1668$space_between$$=new $APP.$cljs$core$Keyword$$(null,"space-between","space-between",1908176695);$cljs$cst$357$malli_DOT_core_SLASH_infinitely_expanding_schema$$=new $APP.$cljs$core$Keyword$$("malli.core","infinitely-expanding-schema","malli.core/infinitely-expanding-schema",-827169082);
$cljs$cst$1443$up_arrow$$=new $APP.$cljs$core$Keyword$$(null,"up-arrow","up-arrow",1705310333);$cljs$cst$675$boolean_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"boolean?","boolean?",1790940868,null);$cljs$cst$2782$patternContentUnits$$=new $APP.$cljs$core$Keyword$$(null,"patternContentUnits","patternContentUnits",652936965);$cljs$cst$1533$app_DOT_common_DOT_geom_DOT_rect_SLASH_rect$$=new $APP.$cljs$core$Keyword$$("app.common.geom.rect","rect","app.common.geom.rect/rect",-1838463012);
$APP.$cljs$cst$2346$visible$$=new $APP.$cljs$core$Keyword$$(null,"visible","visible",-1024216805);$APP.$cljs$cst$2125$partial$$=new $APP.$cljs$core$Keyword$$(null,"partial","partial",241141745);$APP.$cljs$cst$1880$flip_y$$=new $APP.$cljs$core$Keyword$$(null,"flip-y","flip-y",935998815);$APP.$cljs$cst$1879$flip_x$$=new $APP.$cljs$core$Keyword$$(null,"flip-x","flip-x",891276861);$APP.$cljs$cst$1654$shadow$$=new $APP.$cljs$core$Keyword$$(null,"shadow","shadow",873231803);
$APP.$cljs$cst$4184$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_activate_colorpicker_image$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","activate-colorpicker-image","app.main.data.workspace.colors/activate-colorpicker-image",148735960);$cljs$cst$2572$media_id$$=new $APP.$cljs$core$Keyword$$(null,"media-id","media-id",-1004710193);$APP.$cljs$cst$1594$editor$$=new $APP.$cljs$core$Keyword$$(null,"editor","editor",-989377770);
$cljs$cst$3422$owner_fullname$$=new $APP.$cljs$core$Keyword$$(null,"owner-fullname","owner-fullname",882997923);$APP.$cljs$cst$5055$app_DOT_main_DOT_data_DOT_nitrate_SLASH_nitrate_entry_active$$=new $APP.$cljs$core$Keyword$$("app.main.data.nitrate","nitrate-entry-active","app.main.data.nitrate/nitrate-entry-active",1254500243);$APP.$cljs$cst$2263$app_DOT_util_DOT_sse_SLASH_export_binfile$$=new $APP.$cljs$core$Keyword$$("app.util.sse","export-binfile","app.util.sse/export-binfile",-1934301614);
$cljs$cst$1476$right_bracket$$=new $APP.$cljs$core$Keyword$$(null,"right-bracket","right-bracket",951856080);$cljs$cst$2677$ttf_url$$=new $APP.$cljs$core$Keyword$$(null,"ttf-url","ttf-url",1019700400);$APP.$cljs$cst$1548$source$$=new $APP.$cljs$core$Symbol$$(null,"source","source",1206599988,null);
$APP.$cljs$cst$4383$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_hover_grid_cell$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid-layout.editor","hover-grid-cell","app.main.data.workspace.grid-layout.editor/hover-grid-cell",1974310204);$APP.$cljs$cst$1954$up$$=new $APP.$cljs$core$Keyword$$(null,"up","up",-269712113);$APP.$cljs$cst$4564$aria_label$$=new $APP.$cljs$core$Keyword$$(null,"aria-label","aria-label",455891514);
$cljs$cst$2341$app_DOT_main_DOT_data_DOT_modal_SLASH_hide_modal$$=new $APP.$cljs$core$Keyword$$("app.main.data.modal","hide-modal","app.main.data.modal/hide-modal",-1613895013);$cljs$cst$3896$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.wasm-text","resize-wasm-text-debounce","app.main.data.workspace.wasm-text/resize-wasm-text-debounce",1348694639);
$APP.$cljs$cst$1523$x1$$=new $APP.$cljs$core$Keyword$$(null,"x1","x1",-1863922247);$cljs$cst$1307$preferBuffers$$=new $APP.$cljs$core$Keyword$$(null,"preferBuffers","preferBuffers",1843176451);$APP.$cljs$cst$3200$editors$$=new $APP.$cljs$core$Keyword$$(null,"editors","editors",557792993);$cljs$cst$2555$any_main_descendant$$=new $APP.$cljs$core$Keyword$$(null,"any-main-descendant","any-main-descendant",540661315);
$APP.$cljs$cst$4767$filename$$=new $APP.$cljs$core$Keyword$$(null,"filename","filename",-1428840783);$cljs$cst$4781$app_DOT_main_DOT_refs_SLASH_selected_shapes_data$$=new $APP.$cljs$core$Symbol$$("app.main.refs","selected-shapes-data","app.main.refs/selected-shapes-data",416940216,null);$APP.$cljs$cst$1525$x2$$=new $APP.$cljs$core$Keyword$$(null,"x2","x2",-1362513475);
$cljs$cst$3957$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_component_swap$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","component-swap","app.main.data.workspace.libraries/component-swap",-1342940411);$APP.$cljs$cst$204$hierarchy$$=new $APP.$cljs$core$Keyword$$(null,"hierarchy","hierarchy",-1053470341);
$cljs$cst$4415$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_update_grid_cell_position$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","update-grid-cell-position","app.main.data.workspace.shape-layout/update-grid-cell-position",262646518);$cljs$cst$2788$font_variant$$=new $APP.$cljs$core$Keyword$$(null,"font-variant","font-variant",1251503591);
$APP.$cljs$cst$1237$component_thumbnails$$=new $APP.$cljs$core$Keyword$$(null,"component-thumbnails","component-thumbnails",96380471);$APP.$cljs$cst$2698$desc$$=new $APP.$cljs$core$Keyword$$(null,"desc","desc",2093485764);$cljs$cst$2843$u2$$=new $APP.$cljs$core$Keyword$$(null,"u2","u2",1850032340);$cljs$cst$2794$u1$$=new $APP.$cljs$core$Keyword$$(null,"u1","u1",-1841624632);
$APP.$cljs$cst$4240$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_select_node_area$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.selection","select-node-area","app.main.data.workspace.path.selection/select-node-area",-759785288);$cljs$cst$2739$feFuncA$$=new $APP.$cljs$core$Keyword$$(null,"feFuncA","feFuncA",448232667);$cljs$cst$2705$feFuncB$$=new $APP.$cljs$core$Keyword$$(null,"feFuncB","feFuncB",-299280343);
$cljs$cst$2747$feFuncG$$=new $APP.$cljs$core$Keyword$$(null,"feFuncG","feFuncG",-7326338);$cljs$cst$3307$update_team_invitation_role$$=new $APP.$cljs$core$Keyword$$(null,"update-team-invitation-role","update-team-invitation-role",206939756);$cljs$cst$4427$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_update_error$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","update-error","app.main.data.workspace.variants/update-error",514760823);
$APP.$cljs$cst$230$allow$$=new $APP.$cljs$core$Keyword$$(null,"allow","allow",-1857325745);$APP.$cljs$cst$5028$create_file_snapshot$$=new $APP.$cljs$core$Keyword$$(null,"create-file-snapshot","create-file-snapshot",-501759469);$cljs$cst$962$app_DOT_common_DOT_schema_SLASH_safe_double$$=new $APP.$cljs$core$Keyword$$("app.common.schema","safe-double","app.common.schema/safe-double",-720421367);$cljs$cst$2744$feFuncR$$=new $APP.$cljs$core$Keyword$$(null,"feFuncR","feFuncR",1165394045);
$APP.$cljs$cst$1864$to$$=new $APP.$cljs$core$Keyword$$(null,"to","to",192099007);$APP.$cljs$cst$2485$has_libraries$$=new $APP.$cljs$core$Keyword$$(null,"has-libraries","has-libraries",1869731297);$APP.$cljs$cst$4665$tokens_SLASH_text_case$$=new $APP.$cljs$core$Keyword$$("tokens","text-case","tokens/text-case",181298221);$cljs$cst$2801$markerWidth$$=new $APP.$cljs$core$Keyword$$(null,"markerWidth","markerWidth",-568766230);$APP.$cljs$cst$1314$wfn$$=new $APP.$cljs$core$Keyword$$(null,"wfn","wfn",-1437298400);
$cljs$cst$4612$warning_SLASH_value$$=new $APP.$cljs$core$Keyword$$("warning","value","warning/value",1465330453);$APP.$cljs$cst$1544$abort$$=new $APP.$cljs$core$Keyword$$(null,"abort","abort",521193198);$APP.$cljs$cst$5025$get_file_snapshots$$=new $APP.$cljs$core$Keyword$$(null,"get-file-snapshots","get-file-snapshots",1534053253);$cljs$cst$5229$create_new_project$$=new $APP.$cljs$core$Keyword$$(null,"create-new-project","create-new-project",304792374);
$cljs$cst$1414$sections$$=new $APP.$cljs$core$Keyword$$(null,"sections","sections",-886710106);$cljs$cst$4965$move_files$$=new $APP.$cljs$core$Keyword$$(null,"move-files","move-files",-536857601);$cljs$cst$2601$set_remote_synced$$=new $APP.$cljs$core$Keyword$$(null,"set-remote-synced","set-remote-synced",1195610599);$cljs$cst$655$termination_safe$$=new $APP.$cljs$core$Keyword$$(null,"termination-safe","termination-safe",-1845225130);
$APP.$cljs$cst$3715$colorpalette$$=new $APP.$cljs$core$Keyword$$(null,"colorpalette","colorpalette",-2142723517);$cljs$cst$3824$snap_ignore_axis$$=new $APP.$cljs$core$Keyword$$(null,"snap-ignore-axis","snap-ignore-axis",642992690);$cljs$cst$3799$app_DOT_main_DOT_data_DOT_workspace_DOT_thumbnails_wasm_SLASH_render_thumbnail$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.thumbnails-wasm","render-thumbnail","app.main.data.workspace.thumbnails-wasm/render-thumbnail",-1798212932);
$cljs$cst$3293$app_DOT_main_DOT_data_DOT_team_SLASH_update_team$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","update-team","app.main.data.team/update-team",1243061138);$APP.$cljs$cst$3497$create_font_variant$$=new $APP.$cljs$core$Keyword$$(null,"create-font-variant","create-font-variant",-341336194);$cljs$cst$268$app_DOT_common_DOT_data_SLASH_close_BANG_$$=new $APP.$cljs$core$Symbol$$("app.common.data","close!","app.common.data/close!",986923301,null);
$cljs$cst$512$re$$=new $APP.$cljs$core$Keyword$$(null,"re","re",228676202);$cljs$cst$1824$t2$$=new $APP.$cljs$core$Keyword$$(null,"t2","t2",-748855222);$cljs$cst$3091$background_opacity$$=new $APP.$cljs$core$Keyword$$(null,"background-opacity","background-opacity",-1073748756);$cljs$cst$1823$t1$$=new $APP.$cljs$core$Keyword$$(null,"t1","t1",24972444);$APP.$cljs$cst$1882$ry$$=new $APP.$cljs$core$Keyword$$(null,"ry","ry",-334598563);
$APP.$cljs$cst$1881$rx$$=new $APP.$cljs$core$Keyword$$(null,"rx","rx",1627208482);$APP.$cljs$cst$4845$toggle_history$$=new $APP.$cljs$core$Keyword$$(null,"toggle-history","toggle-history",-1813993552);$cljs$cst$1250$enable_frontend_svgo$$=new $APP.$cljs$core$Keyword$$(null,"enable-frontend-svgo","enable-frontend-svgo",912369995);
$cljs$cst$4505$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_shape_context_menu$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","show-shape-context-menu","app.main.data.workspace/show-shape-context-menu",1953943978);$cljs$cst$5386$accept_newsletter_updates$$=new $APP.$cljs$core$Keyword$$(null,"accept-newsletter-updates","accept-newsletter-updates",-611935651);$APP.$cljs$cst$2476$accept_label$$=new $APP.$cljs$core$Keyword$$(null,"accept-label","accept-label",1215904838);
$APP.$cljs$cst$4512$cells$$=new $APP.$cljs$core$Keyword$$(null,"cells","cells",-985166822);$APP.$cljs$cst$4586$error_DOT_import_SLASH_invalid_token_name$$=new $APP.$cljs$core$Keyword$$("error.import","invalid-token-name","error.import/invalid-token-name",-1589247189);$APP.$cljs$cst$2520$dashboard_fonts$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-fonts","dashboard-fonts",-1313435498);$cljs$cst$3125$dropped$$=new $APP.$cljs$core$Keyword$$(null,"dropped","dropped",-1651285782);
$cljs$cst$3831$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_temporary_selrect$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.modifiers","set-temporary-selrect","app.main.data.workspace.modifiers/set-temporary-selrect",-51398342);$cljs$cst$4077$tracks$$=new $APP.$cljs$core$Keyword$$(null,"tracks","tracks",-326768501);$APP.$cljs$cst$4966$template_id$$=new $APP.$cljs$core$Keyword$$(null,"template-id","template-id",1952916477);
$APP.$cljs$cst$1929$margin$$=new $APP.$cljs$core$Keyword$$(null,"margin","margin",-995903681);$cljs$cst$2679$google$$=new $APP.$cljs$core$Keyword$$(null,"google","google",578454873);$cljs$cst$4944$app_DOT_main_DOT_data_DOT_dashboard_SLASH_toggle_project_pin$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","toggle-project-pin","app.main.data.dashboard/toggle-project-pin",2028304822);$APP.$cljs$cst$2482$legacy_zip$$=new $APP.$cljs$core$Keyword$$(null,"legacy-zip","legacy-zip",1673362658);
$cljs$cst$959$app_DOT_common_DOT_schema_SLASH_double$$=new $APP.$cljs$core$Keyword$$("app.common.schema","double","app.common.schema/double",-567705842);$APP.$cljs$cst$2318$events$$=new $APP.$cljs$core$Keyword$$(null,"events","events",1792552201);$APP.$cljs$cst$3595$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_interrupt$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.specialized-panel","interrupt","app.main.data.workspace.specialized-panel/interrupt",-2063805375);
$APP.$cljs$cst$3960$component_swap$$=new $APP.$cljs$core$Keyword$$(null,"component-swap","component-swap",-190693695);$cljs$cst$933$app_DOT_common_DOT_schema_SLASH_id$$=new $APP.$cljs$core$Keyword$$("app.common.schema","id","app.common.schema/id",1146380349);
$cljs$cst$4633$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_shape_position$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","update-shape-position","app.main.data.workspace.tokens.application/update-shape-position",-465108657);$APP.$cljs$cst$4882$align_vcenter$$=new $APP.$cljs$core$Keyword$$(null,"align-vcenter","align-vcenter",-2036108737);$APP.$cljs$cst$1962$way$$=new $APP.$cljs$core$Keyword$$(null,"way","way",1564954669);
$APP.$cljs$cst$974$app_DOT_common_DOT_schema_SLASH_any$$=new $APP.$cljs$core$Keyword$$("app.common.schema","any","app.common.schema/any",-1231442794);$cljs$cst$5107$team_form$$=new $APP.$cljs$core$Keyword$$(null,"team-form","team-form",1411783122);$cljs$cst$3777$include_metadata$$=new $APP.$cljs$core$Keyword$$(null,"include-metadata","include-metadata",1795532512);$APP.$cljs$cst$3304$auth_verify_token$$=new $APP.$cljs$core$Keyword$$(null,"auth-verify-token","auth-verify-token",-675769474);
$APP.$cljs$cst$3197$plugins$$=new $APP.$cljs$core$Keyword$$(null,"plugins","plugins",1900073717);$APP.$cljs$cst$4771$is_wasm$$=new $APP.$cljs$core$Keyword$$(null,"is-wasm","is-wasm",1488655884);$APP.$cljs$cst$2001$variant_properties$$=new $APP.$cljs$core$Keyword$$(null,"variant-properties","variant-properties",749060490);$APP.$cljs$cst$5283$fixed_source_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"fixed-source?","fixed-source?",1767450450);
$APP.$cljs$cst$1770$grow_type$$=new $APP.$cljs$core$Keyword$$(null,"grow-type","grow-type",-908344411);$APP.$cljs$cst$4376$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_delete_page$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.pages","delete-page","app.main.data.workspace.pages/delete-page",2094037607);$cljs$cst$4102$in_viewport$$=new $APP.$cljs$core$Keyword$$(null,"in-viewport","in-viewport",-45347096);
$APP.$cljs$cst$3272$app_DOT_main_DOT_data_DOT_team_SLASH_initialize_team$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","initialize-team","app.main.data.team/initialize-team",957607773);$cljs$cst$2605$set_flow$$=new $APP.$cljs$core$Keyword$$(null,"set-flow","set-flow",-468241463);$cljs$cst$5254$app_DOT_main_DOT_data_DOT_viewer_SLASH_zoom_to_fit$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","zoom-to-fit","app.main.data.viewer/zoom-to-fit",-1525509635);
$cljs$cst$5198$misplaced_slot$$=new $APP.$cljs$core$Keyword$$(null,"misplaced-slot","misplaced-slot",-272544637);$APP.$cljs$cst$1758$font_family$$=new $APP.$cljs$core$Keyword$$(null,"font-family","font-family",-667419874);
$cljs$cst$4637$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_generate_font_family_text_shape_update$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","generate-font-family-text-shape-update","app.main.data.workspace.tokens.application/generate-font-family-text-shape-update",1321671565);
$cljs$cst$3635$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_update_shapes_buffer_changes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","update-shapes-buffer-changes","app.main.data.workspace.shapes/update-shapes-buffer-changes",-530788438);$APP.$cljs$cst$2372$catch_all$$=new $APP.$cljs$core$Keyword$$(null,"catch-all","catch-all",1184112570);
$APP.$cljs$cst$2489$create_team_access_request$$=new $APP.$cljs$core$Keyword$$(null,"create-team-access-request","create-team-access-request",1803920101);$APP.$cljs$cst$4883$draw_curve$$=new $APP.$cljs$core$Keyword$$(null,"draw-curve","draw-curve",1664540671);$cljs$cst$3147$app_DOT_main_DOT_data_DOT_changes_SLASH_commit_changes$$=new $APP.$cljs$core$Keyword$$("app.main.data.changes","commit-changes","app.main.data.changes/commit-changes",1277456228);
$cljs$cst$2732$animateTransform$$=new $APP.$cljs$core$Keyword$$(null,"animateTransform","animateTransform",759329815);$APP.$cljs$cst$4197$preserve_move_to$$=new $APP.$cljs$core$Keyword$$(null,"preserve-move-to","preserve-move-to",1880571212);$APP.$cljs$cst$735$merge$$=new $APP.$cljs$core$Keyword$$(null,"merge","merge",-1804319409);$cljs$cst$1268$enable_token_import_from_library$$=new $APP.$cljs$core$Keyword$$(null,"enable-token-import-from-library","enable-token-import-from-library",1204365033);
$cljs$cst$3301$resend$$=new $APP.$cljs$core$Keyword$$(null,"resend","resend",-958877571);$cljs$cst$3838$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_apply_wasm_modifiesr$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.modifiers","apply-wasm-modifiesr","app.main.data.workspace.modifiers/apply-wasm-modifiesr",1138986038);$APP.$cljs$cst$2946$tooltip$$=new $APP.$cljs$core$Keyword$$(null,"tooltip","tooltip",-1809677058);
$cljs$cst$3648$app_DOT_main_DOT_data_DOT_workspace_DOT_shapes_SLASH_create_artboard_from_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shapes","create-artboard-from-shapes","app.main.data.workspace.shapes/create-artboard-from-shapes",-284689606);$APP.$cljs$cst$4533$open_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"open?","open?",1238443125);$cljs$cst$3172$apply_to_library_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"apply-to-library?","apply-to-library?",-440115882);
$cljs$cst$3582$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_reset_zoom$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.zoom","reset-zoom","app.main.data.workspace.zoom/reset-zoom",192130986);$APP.$cljs$cst$1948$bottom_center$$=new $APP.$cljs$core$Keyword$$(null,"bottom-center","bottom-center",1844600634);$cljs$cst$282$cljs_DOT_core_SLASH_deref$$=new $APP.$cljs$core$Symbol$$("cljs.core","deref","cljs.core/deref",1901963335,null);
$cljs$cst$1775$text_content_attribute$$=new $APP.$cljs$core$Keyword$$(null,"text-content-attribute","text-content-attribute",2029723884);$cljs$cst$3901$obj_id$$=new $APP.$cljs$core$Keyword$$(null,"obj-id","obj-id",1871733713);$APP.$cljs$cst$4219$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_close_path_drag_start$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","close-path-drag-start","app.main.data.workspace.path.drawing/close-path-drag-start",-315624480);
$APP.$cljs$cst$5417$get_file_info$$=new $APP.$cljs$core$Keyword$$(null,"get-file-info","get-file-info",1238727450);$cljs$cst$1496$when$$=new $APP.$cljs$core$Symbol$$(null,"when","when",1064114221,null);$APP.$cljs$cst$3754$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_toggle_toolbar_visibility$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.common","toggle-toolbar-visibility","app.main.data.workspace.common/toggle-toolbar-visibility",-924303789);
$cljs$cst$3868$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_increase_rotation$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","increase-rotation","app.main.data.workspace.transforms/increase-rotation",1727435167);$cljs$cst$2735$feMerge$$=new $APP.$cljs$core$Keyword$$(null,"feMerge","feMerge",1663055097);$cljs$cst$3009$symbols_2$$=new $APP.$cljs$core$Keyword$$(null,"symbols-2","symbols-2",-1632799182);
$cljs$cst$895$unknown$$=new $APP.$cljs$core$Keyword$$(null,"unknown","unknown",-935977881);$cljs$cst$2899$stroke_dasharray$$=new $APP.$cljs$core$Keyword$$(null,"stroke-dasharray","stroke-dasharray",-942933855);$cljs$cst$4444$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_variant_switch$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","variant-switch","app.main.data.workspace.variants/variant-switch",-986252718);
$APP.$cljs$cst$2645$attrs$$=new $APP.$cljs$core$Keyword$$(null,"attrs","attrs",-2090668713);$cljs$cst$789$clojure_DOT_test_DOT_check_DOT_generators_SLASH_set$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","set","clojure.test.check.generators/set",-1027639543,null);$cljs$cst$413$property_pred$$=new $APP.$cljs$core$Keyword$$(null,"property-pred","property-pred",1813304729);
$cljs$cst$3260$organization_avatar_bg_url$$=new $APP.$cljs$core$Keyword$$(null,"organization-avatar-bg-url","organization-avatar-bg-url",-1361493096);$cljs$cst$3774$data_old_height$$=new $APP.$cljs$core$Keyword$$(null,"data-old-height","data-old-height",-1528057579);
$APP.$cljs$cst$3763$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_clear_specialized_panel$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.specialized-panel","clear-specialized-panel","app.main.data.workspace.specialized-panel/clear-specialized-panel",1527860029);$APP.$cljs$cst$2462$href$$=new $APP.$cljs$core$Keyword$$(null,"href","href",-793805698);$cljs$cst$5297$overlays$$=new $APP.$cljs$core$Keyword$$(null,"overlays","overlays",-1346586303);
$APP.$cljs$cst$1620$hidden$$=new $APP.$cljs$core$Keyword$$(null,"hidden","hidden",-312506092);$cljs$cst$3534$reset_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"reset?","reset?",-1051875415);$cljs$cst$3266$get_team_members$$=new $APP.$cljs$core$Keyword$$(null,"get-team-members","get-team-members",15863431);$APP.$cljs$cst$4673$tokens_SLASH_number$$=new $APP.$cljs$core$Keyword$$("tokens","number","tokens/number",1767411312);
$cljs$cst$1082$cljs_DOT_spec_DOT_alpha_SLASH_conform_all$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","conform-all","cljs.spec.alpha/conform-all",45201917);$APP.$cljs$cst$5649$list_style$$=new $APP.$cljs$core$Keyword$$(null,"list-style","list-style",-809622358);$cljs$cst$968$app_DOT_common_DOT_schema_SLASH_fn$$=new $APP.$cljs$core$Keyword$$("app.common.schema","fn","app.common.schema/fn",-520191477);
$cljs$cst$5166$child_not_found$$=new $APP.$cljs$core$Keyword$$(null,"child-not-found","child-not-found",1723767489);$APP.$cljs$cst$5127$invite_members$$=new $APP.$cljs$core$Keyword$$(null,"invite-members","invite-members",683231892);$cljs$cst$2663$syncing$$=new $APP.$cljs$core$Keyword$$(null,"syncing","syncing",-291323582);$APP.$cljs$cst$1569$created_at$$=new $APP.$cljs$core$Keyword$$(null,"created-at","created-at",-89248644);
$cljs$cst$2803$vert_origin_y$$=new $APP.$cljs$core$Keyword$$(null,"vert-origin-y","vert-origin-y",-1770906134);$cljs$cst$3839$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_move_frame_guides$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.guides","move-frame-guides","app.main.data.workspace.guides/move-frame-guides",1545364171);$cljs$cst$2642$set_token$$=new $APP.$cljs$core$Keyword$$(null,"set-token","set-token",1378179451);
$cljs$cst$1209$backend_svgo$$=new $APP.$cljs$core$Keyword$$(null,"backend-svgo","backend-svgo",-1327232376);$APP.$cljs$cst$4851$bool_exclude$$=new $APP.$cljs$core$Keyword$$(null,"bool-exclude","bool-exclude",906557011);$APP.$cljs$cst$209$line$$=new $APP.$cljs$core$Keyword$$(null,"line","line",212345235);$APP.$cljs$cst$1578$method$$=new $APP.$cljs$core$Keyword$$(null,"method","method",55703592);
$APP.$cljs$cst$3971$libraries_dialog$$=new $APP.$cljs$core$Keyword$$(null,"libraries-dialog","libraries-dialog",-29719008);$APP.$cljs$cst$3291$app_DOT_main_DOT_data_DOT_team_SLASH_create_team_with_invitations$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","create-team-with-invitations","app.main.data.team/create-team-with-invitations",-1634362488);$cljs$cst$4506$disable_booleans_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"disable-booleans?","disable-booleans?",990388370);
$APP.$cljs$cst$5418$team_default$$=new $APP.$cljs$core$Keyword$$(null,"team-default","team-default",-1232424959);$cljs$cst$3996$app_DOT_common_DOT_text_SLASH_novalue$$=new $APP.$cljs$core$Keyword$$("app.common.text","novalue","app.common.text/novalue",-632023824);
$APP.$cljs$cst$4305$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_add_interaction$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","add-interaction","app.main.data.workspace.interactions/add-interaction",-1145468509);$cljs$cst$816$clojure_DOT_test_DOT_check_DOT_generators_SLASH_large_integer$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","large-integer","clojure.test.check.generators/large-integer",-865967138,null);
$cljs$cst$2962$once_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"once?","once?",-872881597);$cljs$cst$2983$coptic$$=new $APP.$cljs$core$Keyword$$(null,"coptic","coptic",-403969758);$APP.$cljs$cst$3636$reg_objects_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"reg-objects?","reg-objects?",-195730116);
$cljs$cst$3878$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_move_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","move-selected","app.main.data.workspace.transforms/move-selected",1781006970);$cljs$cst$2916$clip_path$$=new $APP.$cljs$core$Keyword$$(null,"clip-path","clip-path",-439959120);$cljs$cst$4557$on_pointer_enter_option$$=new $APP.$cljs$core$Keyword$$(null,"on-pointer-enter-option","on-pointer-enter-option",-403377657);
$cljs$cst$712$not_EQ_$$=new $APP.$cljs$core$Keyword$$(null,"not\x3d","not\x3d",-173995323);$APP.$cljs$cst$287$linear$$=new $APP.$cljs$core$Keyword$$(null,"linear","linear",872268697);$APP.$cljs$cst$1918$current_page_id$$=new $APP.$cljs$core$Keyword$$(null,"current-page-id","current-page-id",310685425);
$APP.$cljs$cst$4721$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_duplicate_token$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","duplicate-token","app.main.data.workspace.tokens.library-edit/duplicate-token",2037386924);$APP.$cljs$cst$5392$app_DOT_main_DOT_ui_DOT_auth_DOT_register_SLASH_email$$=new $APP.$cljs$core$Keyword$$("app.main.ui.auth.register","email","app.main.ui.auth.register/email",1302079451);
$APP.$cljs$cst$4148$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_add_shadow$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","add-shadow","app.main.data.workspace.colors/add-shadow",-74119050);$cljs$cst$4600$error_DOT_import_SLASH_style_dictionary_reference_errors$$=new $APP.$cljs$core$Keyword$$("error.import","style-dictionary-reference-errors","error.import/style-dictionary-reference-errors",-51943298);
$APP.$cljs$cst$5313$merge_nodes$$=new $APP.$cljs$core$Keyword$$(null,"merge-nodes","merge-nodes",714582572);$cljs$cst$699$true_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"true?","true?",-1600332395,null);$APP.$cljs$cst$4183$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_activate_colorpicker_color$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","activate-colorpicker-color","app.main.data.workspace.colors/activate-colorpicker-color",1237584096);
$cljs$cst$349$infos$$=new $APP.$cljs$core$Keyword$$(null,"infos","infos",-927309652);$cljs$cst$955$app_DOT_common_DOT_schema_SLASH_set_of_uuid$$=new $APP.$cljs$core$Keyword$$("app.common.schema","set-of-uuid","app.common.schema/set-of-uuid",-313818768);$cljs$cst$4288$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_remove_guide$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.guides","remove-guide","app.main.data.workspace.guides/remove-guide",1176689377);
$cljs$cst$3969$date$$=new $APP.$cljs$core$Keyword$$(null,"date","date",-1463434462);$cljs$cst$1272$modifier$$=new $APP.$cljs$core$Keyword$$(null,"modifier","modifier",1634442788);$APP.$cljs$cst$1190$cors$$=new $APP.$cljs$core$Keyword$$(null,"cors","cors",1066181665);$APP.$cljs$cst$142$data$$=new $APP.$cljs$core$Keyword$$(null,"data","data",-232669377);$APP.$cljs$cst$5756$created_by$$=new $APP.$cljs$core$Keyword$$(null,"created-by","created-by",-1870794445);
$APP.$cljs$cst$4167$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_apply_color_from_asserts$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","apply-color-from-asserts","app.main.data.workspace.colors/apply-color-from-asserts",-1849369541);$APP.$cljs$cst$4165$radial_gradient$$=new $APP.$cljs$core$Keyword$$(null,"radial-gradient","radial-gradient",-635026259);
$cljs$cst$2527$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_webhooks$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","go-to-dashboard-webhooks","app.main.data.common/go-to-dashboard-webhooks",-1984277947);$cljs$cst$2294$os_version$$=new $APP.$cljs$core$Keyword$$(null,"os-version","os-version",409171217);$APP.$cljs$cst$1591$blob$$=new $APP.$cljs$core$Keyword$$(null,"blob","blob",1636965233);
$cljs$cst$337$sci_DOT_core_SLASH_fork$$=new $APP.$cljs$core$Symbol$$("sci.core","fork","sci.core/fork",-1806691042,null);$cljs$cst$907$double$$=new $APP.$cljs$core$Symbol$$(null,"double","double",-1769548886,null);$cljs$cst$4247$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_update_selection$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.selection","update-selection","app.main.data.workspace.path.selection/update-selection",1398542135);
$APP.$cljs$cst$746$alpha$$=new $APP.$cljs$core$Keyword$$(null,"alpha","alpha",-1574982441);$APP.$cljs$cst$2252$validation$$=new $APP.$cljs$core$Keyword$$(null,"validation","validation",-2141396518);$cljs$cst$1495$when_not$$=new $APP.$cljs$core$Symbol$$(null,"when-not","when-not",-1223136340,null);$APP.$cljs$cst$1653$blur$$=new $APP.$cljs$core$Keyword$$(null,"blur","blur",-453500461);$cljs$cst$1439$padchar$$=new $APP.$cljs$core$Keyword$$(null,"padchar","padchar",2018584530);
$cljs$cst$703$sequential_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"sequential?","sequential?",1102351463,null);$APP.$cljs$cst$2171$route$$=new $APP.$cljs$core$Keyword$$(null,"route","route",329891309);$APP.$cljs$cst$2305$placeholder_SLASH_fn$$=new $APP.$cljs$core$Keyword$$("placeholder","fn","placeholder/fn",-761763945);$APP.$cljs$cst$3409$days$$=new $APP.$cljs$core$Keyword$$(null,"days","days",-1394072564);
$cljs$cst$536$malli_DOT_core_SLASH_walk_refs$$=new $APP.$cljs$core$Keyword$$("malli.core","walk-refs","malli.core/walk-refs",755904802);$cljs$cst$3533$shape_inst$$=new $APP.$cljs$core$Keyword$$(null,"shape-inst","shape-inst",814505728);$APP.$cljs$cst$3106$app_DOT_main_DOT_features_SLASH_toggle_feature$$=new $APP.$cljs$core$Keyword$$("app.main.features","toggle-feature","app.main.features/toggle-feature",-1719396584);
$cljs$cst$3973$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_touch_component$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","touch-component","app.main.data.workspace.libraries/touch-component",1998603176);$cljs$cst$5225$go_to_drafts$$=new $APP.$cljs$core$Keyword$$(null,"go-to-drafts","go-to-drafts",-411440066);$cljs$cst$1076$conform_keys$$=new $APP.$cljs$core$Keyword$$(null,"conform-keys","conform-keys",-1800041814);
$APP.$cljs$cst$1780$structure_child$$=new $APP.$cljs$core$Keyword$$(null,"structure-child","structure-child",-1244004583);$cljs$cst$4331$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_handle_ping$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.mcp","handle-ping","app.main.data.workspace.mcp/handle-ping",1302120991);$APP.$cljs$cst$92$left$$=new $APP.$cljs$core$Symbol$$(null,"left","left",1241415590,null);
$APP.$cljs$cst$3609$using_selrect_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"using-selrect?","using-selrect?",-223163153);$cljs$cst$919$default_encoder$$=new $APP.$cljs$core$Keyword$$(null,"default-encoder","default-encoder",117541207);
$APP.$cljs$cst$4309$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_remove_all_interactions_nav_to$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","remove-all-interactions-nav-to","app.main.data.workspace.interactions/remove-all-interactions-nav-to",-1166281130);$cljs$cst$879$malli_DOT_error_SLASH_misspelled_value$$=new $APP.$cljs$core$Keyword$$("malli.error","misspelled-value","malli.error/misspelled-value",-1135752848);
$APP.$cljs$cst$2541$deleted$$=new $APP.$cljs$core$Keyword$$(null,"deleted","deleted",-510100639);$APP.$cljs$cst$1871$constraints_v$$=new $APP.$cljs$core$Keyword$$(null,"constraints-v","constraints-v",1840495122);$cljs$cst$3986$library_used_in$$=new $APP.$cljs$core$Keyword$$(null,"library-used-in","library-used-in",1633557054);
$APP.$cljs$cst$5238$app_DOT_main_DOT_data_DOT_viewer_SLASH_fetch_bundle$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","fetch-bundle","app.main.data.viewer/fetch-bundle",273986653);$APP.$cljs$cst$5129$max_invitations_by_request$$=new $APP.$cljs$core$Keyword$$(null,"max-invitations-by-request","max-invitations-by-request",-1517961638);$APP.$cljs$cst$1872$constraints_h$$=new $APP.$cljs$core$Keyword$$(null,"constraints-h","constraints-h",-260205452);
$APP.$cljs$cst$2182$is_shared$$=new $APP.$cljs$core$Keyword$$(null,"is-shared","is-shared",2126511925);$cljs$cst$3524$ignore_flows_for$$=new $APP.$cljs$core$Keyword$$(null,"ignore-flows-for","ignore-flows-for",-641074503);$cljs$cst$3881$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_update_positions$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","update-positions","app.main.data.workspace.transforms/update-positions",1729520309);
$cljs$cst$4341$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_manage_mcp_notification$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.mcp","manage-mcp-notification","app.main.data.workspace.mcp/manage-mcp-notification",49409302);$cljs$cst$580$malli_DOT_core_SLASH_invalid_output$$=new $APP.$cljs$core$Keyword$$("malli.core","invalid-output","malli.core/invalid-output",-147363519);
$APP.$cljs$cst$4509$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_track_context_menu$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","show-track-context-menu","app.main.data.workspace/show-track-context-menu",1392002592);$cljs$cst$4877$move_unit_left$$=new $APP.$cljs$core$Keyword$$(null,"move-unit-left","move-unit-left",-871314243);
$cljs$cst$4632$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_layout_padding$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","update-layout-padding","app.main.data.workspace.tokens.application/update-layout-padding",1814449754);$cljs$cst$3798$persist_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"persist?","persist?",-1772568760);
$cljs$cst$3758$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_group_selected$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.groups","group-selected","app.main.data.workspace.groups/group-selected",353677864);$cljs$cst$4449$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_update_viewport_position$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.viewport","update-viewport-position","app.main.data.workspace.viewport/update-viewport-position",-47991104);
$cljs$cst$1206$soft_file_validation$$=new $APP.$cljs$core$Keyword$$(null,"soft-file-validation","soft-file-validation",-339876473);$cljs$cst$3058$bounding_boxes$$=new $APP.$cljs$core$Keyword$$(null,"bounding-boxes","bounding-boxes",-542662202);$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$=new $APP.$cljs$core$Keyword$$("app.common.schema","one-of","app.common.schema/one-of",1806653447);
$APP.$cljs$cst$3508$app_DOT_main_DOT_data_DOT_fonts_SLASH_add_recent_font$$=new $APP.$cljs$core$Keyword$$("app.main.data.fonts","add-recent-font","app.main.data.fonts/add-recent-font",-616232459);$cljs$cst$2358$app_DOT_main_DOT_data_DOT_notifications_SLASH_show$$=new $APP.$cljs$core$Keyword$$("app.main.data.notifications","show","app.main.data.notifications/show",-2058845717);
$cljs$cst$4016$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_with_function$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","update-text-with-function","app.main.data.workspace.texts/update-text-with-function",-372442532);
$cljs$cst$4285$app_DOT_main_DOT_data_DOT_workspace_DOT_fix_deleted_fonts_SLASH_fix_deleted_fonts_for_local_library$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.fix-deleted-fonts","fix-deleted-fonts-for-local-library","app.main.data.workspace.fix-deleted-fonts/fix-deleted-fonts-for-local-library",-314408718);$APP.$cljs$cst$1745$fill_color_ref_id$$=new $APP.$cljs$core$Keyword$$(null,"fill-color-ref-id","fill-color-ref-id",-1755428098);
$APP.$cljs$cst$3388$error_SLASH_field$$=new $APP.$cljs$core$Keyword$$("error","field","error/field",-1330531468);$cljs$cst$2756$stitchTiles$$=new $APP.$cljs$core$Keyword$$(null,"stitchTiles","stitchTiles",-1715449791);$APP.$cljs$cst$3364$app_DOT_main_DOT_errors_SLASH_instance$$=new $APP.$cljs$core$Keyword$$("app.main.errors","instance","app.main.errors/instance",2062011223);$cljs$cst$5356$on_end$$=new $APP.$cljs$core$Keyword$$(null,"on-end","on-end",1933704364);
$cljs$cst$4796$clear_undo$$=new $APP.$cljs$core$Keyword$$(null,"clear-undo","clear-undo",-1965756862);$APP.$cljs$cst$4917$app_DOT_main_DOT_data_DOT_dashboard_SLASH_libraries_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","libraries-fetched","app.main.data.dashboard/libraries-fetched",1645518018);$cljs$cst$568$malli_DOT_core_SLASH_explain_guard$$=new $APP.$cljs$core$Keyword$$("malli.core","explain-guard","malli.core/explain-guard",-1119572847);
$APP.$cljs$cst$4713$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_drop_token_set$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","drop-token-set","app.main.data.workspace.tokens.library-edit/drop-token-set",1538739186);$APP.$cljs$cst$3717$show_pixel_grid$$=new $APP.$cljs$core$Keyword$$(null,"show-pixel-grid","show-pixel-grid",-247932281);
$cljs$cst$3578$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_auto$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.zoom","auto","app.main.data.workspace.zoom/auto",1266077460);$cljs$cst$4774$export_update$$=new $APP.$cljs$core$Keyword$$(null,"export-update","export-update",1935824931);$APP.$cljs$cst$5066$nitrate_license$$=new $APP.$cljs$core$Keyword$$(null,"nitrate-license","nitrate-license",1049768773);
$APP.$cljs$cst$1971$overlay_pos_type$$=new $APP.$cljs$core$Keyword$$(null,"overlay-pos-type","overlay-pos-type",-1941746455);$APP.$cljs$cst$2365$name_conflicts$$=new $APP.$cljs$core$Keyword$$(null,"name-conflicts","name-conflicts",-2016386444);$cljs$cst$3311$app_DOT_main_DOT_data_DOT_team_SLASH_delete_team$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","delete-team","app.main.data.team/delete-team",212490685);
$cljs$cst$3809$line_max_width$$=new $APP.$cljs$core$Keyword$$(null,"line-max-width","line-max-width",-2085887686);$APP.$cljs$cst$245$cljs_DOT_core_SLASH_list$$=new $APP.$cljs$core$Symbol$$("cljs.core","list","cljs.core/list",-1331406371,null);$APP.$cljs$cst$1230$telemetry$$=new $APP.$cljs$core$Keyword$$(null,"telemetry","telemetry",-764940235);$APP.$cljs$cst$2573$thumbnail_id$$=new $APP.$cljs$core$Keyword$$(null,"thumbnail-id","thumbnail-id",406242421);
$cljs$cst$3789$max_time$$=new $APP.$cljs$core$Keyword$$(null,"max-time","max-time",857408479);$APP.$cljs$cst$201$list$$=new $APP.$cljs$core$Keyword$$(null,"list","list",765357683);$cljs$cst$2074$constraints_group$$=new $APP.$cljs$core$Keyword$$(null,"constraints-group","constraints-group",-1724513344);$cljs$cst$1405$buffering$$=new $APP.$cljs$core$Keyword$$(null,"buffering","buffering",-876713613);$cljs$cst$1147$platform$$=new $APP.$cljs$core$Keyword$$(null,"platform","platform",-1086422114);
$APP.$cljs$cst$3927$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_restore_component$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","restore-component","app.main.data.workspace.libraries/restore-component",606822092);$cljs$cst$1445$base_args$$=new $APP.$cljs$core$Keyword$$(null,"base-args","base-args",-1268706822);$cljs$cst$1773$text_content_structure$$=new $APP.$cljs$core$Keyword$$(null,"text-content-structure","text-content-structure",-2085099684);
$APP.$cljs$cst$3408$app_DOT_main_DOT_data_DOT_plugins_SLASH_update_plugins_permissions_peek$$=new $APP.$cljs$core$Keyword$$("app.main.data.plugins","update-plugins-permissions-peek","app.main.data.plugins/update-plugins-permissions-peek",443191422);$cljs$cst$2873$patternTransform$$=new $APP.$cljs$core$Keyword$$(null,"patternTransform","patternTransform",-1380251494);
$cljs$cst$3475$app_DOT_main_DOT_data_DOT_comments_SLASH_update_draft_thread$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","update-draft-thread","app.main.data.comments/update-draft-thread",-1440724778);$APP.$cljs$cst$1870$exports$$=new $APP.$cljs$core$Keyword$$(null,"exports","exports",-745008272);$cljs$cst$1556$event$$=new $APP.$cljs$core$Keyword$$(null,"event","event",301435442);$APP.$cljs$cst$2177$export$$=new $APP.$cljs$core$Keyword$$(null,"export","export",214356590);
$cljs$cst$1440$commainterval$$=new $APP.$cljs$core$Keyword$$(null,"commainterval","commainterval",-1980061083);$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$=new $APP.$cljs$core$Keyword$$("app.common.schema","set","app.common.schema/set",1226590145);$APP.$cljs$cst$1727$keep_aspect_ratio$$=new $APP.$cljs$core$Keyword$$(null,"keep-aspect-ratio","keep-aspect-ratio",-475848727);$cljs$cst$1169$login_with_google$$=new $APP.$cljs$core$Keyword$$(null,"login-with-google","login-with-google",-360269339);
$APP.$cljs$cst$4038$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_v2_sync_wasm_text_layout$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","v2-sync-wasm-text-layout","app.main.data.workspace.texts/v2-sync-wasm-text-layout",-1805561166);$APP.$cljs$cst$4587$error_DOT_import_SLASH_style_dictionary_unknown_error$$=new $APP.$cljs$core$Keyword$$("error.import","style-dictionary-unknown-error","error.import/style-dictionary-unknown-error",-317476276);
$cljs$cst$2997$sinhala$$=new $APP.$cljs$core$Keyword$$(null,"sinhala","sinhala",-1694245590);$cljs$cst$4433$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_focus_property$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","focus-property","app.main.data.workspace.variants/focus-property",847873142);$cljs$cst$881$malli_DOT_error_SLASH_misspelled_key$$=new $APP.$cljs$core$Keyword$$("malli.error","misspelled-key","malli.error/misspelled-key",616486174);
$APP.$cljs$cst$238$cljs_DOT_core_SLASH_concat$$=new $APP.$cljs$core$Symbol$$("cljs.core","concat","cljs.core/concat",-1133584918,null);$APP.$cljs$cst$1996$weight$$=new $APP.$cljs$core$Keyword$$(null,"weight","weight",-1262796205);
$cljs$cst$5361$app_DOT_main_DOT_ui_DOT_nitrate_DOT_nitrate_code_activation_modal_SLASH_redeem_nitrate_activation_code$$=new $APP.$cljs$core$Keyword$$("app.main.ui.nitrate.nitrate-code-activation-modal","redeem-nitrate-activation-code","app.main.ui.nitrate.nitrate-code-activation-modal/redeem-nitrate-activation-code",1820279352);$cljs$cst$2945$app_DOT_main_DOT_broadcast_SLASH_event$$=new $APP.$cljs$core$Keyword$$("app.main.broadcast","event","app.main.broadcast/event",-1531468833);
$cljs$cst$934$app_DOT_common_DOT_schema_SLASH_type$$=new $APP.$cljs$core$Keyword$$("app.common.schema","type","app.common.schema/type",-418801773);$APP.$cljs$cst$4234$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_path_pointer_enter$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.selection","path-pointer-enter","app.main.data.workspace.path.selection/path-pointer-enter",-1500705105);
$cljs$cst$2145$app_DOT_main_DOT_router_SLASH_assign_exception$$=new $APP.$cljs$core$Keyword$$("app.main.router","assign-exception","app.main.router/assign-exception",-192148203);$APP.$cljs$cst$3182$prev_before_group_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"prev-before-group?","prev-before-group?",1113354384);$cljs$cst$678$simple_ident_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"simple-ident?","simple-ident?",194189851,null);
$APP.$cljs$cst$6375$settings_integrations$$=new $APP.$cljs$core$Keyword$$(null,"settings-integrations","settings-integrations",-475154746);$APP.$cljs$cst$4007$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_editor_select_all$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","editor-select-all","app.main.data.workspace.texts/editor-select-all",2022116732);$APP.$cljs$cst$2012$round$$=new $APP.$cljs$core$Keyword$$(null,"round","round",2009433328);
$cljs$cst$3592$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_shape$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","select-shape","app.main.data.workspace.selection/select-shape",-431177915);$APP.$cljs$cst$144$trace$$=new $APP.$cljs$core$Keyword$$(null,"trace","trace",-1082747415);$APP.$cljs$cst$2361$app_DOT_main_DOT_router_SLASH_navigate$$=new $APP.$cljs$core$Keyword$$("app.main.router","navigate","app.main.router/navigate",-477162538);
$APP.$cljs$cst$1223$subscriptions$$=new $APP.$cljs$core$Keyword$$(null,"subscriptions","subscriptions",1250949776);$APP.$cljs$cst$4010$editor_instance$$=new $APP.$cljs$core$Keyword$$(null,"editor-instance","editor-instance",-1602615018);$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$=new $APP.$cljs$core$Keyword$$("malli.core","into-schema","malli.core/into-schema",1522165759);$cljs$cst$2763$xlink_COLON_arcrole$$=new $APP.$cljs$core$Keyword$$(null,"xlink:arcrole","xlink:arcrole",-376517951);
$APP.$cljs$cst$3251$create_access_token$$=new $APP.$cljs$core$Keyword$$(null,"create-access-token","create-access-token",-865569728);$APP.$cljs$cst$3217$app_DOT_main_DOT_data_DOT_profile_SLASH_update_password$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","update-password","app.main.data.profile/update-password",1111855582);
$cljs$cst$5276$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_frame_by_index$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","go-to-frame-by-index","app.main.data.viewer/go-to-frame-by-index",1308227509);$APP.$cljs$cst$2063$main_instance_page$$=new $APP.$cljs$core$Keyword$$(null,"main-instance-page","main-instance-page",1727937139);$APP.$cljs$cst$3880$absolute_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"absolute?","absolute?",1457842844);
$cljs$cst$3788$calc_time$$=new $APP.$cljs$core$Keyword$$(null,"calc-time","calc-time",1430633842);$cljs$cst$3049$start_offset$$=new $APP.$cljs$core$Keyword$$(null,"start-offset","start-offset",1295473814);$APP.$cljs$cst$4416$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_create_cell_board$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","create-cell-board","app.main.data.workspace.shape-layout/create-cell-board",-1425068008);
$APP.$cljs$cst$4666$tokens_SLASH_font_weight$$=new $APP.$cljs$core$Keyword$$("tokens","font-weight","tokens/font-weight",-2003804083);$cljs$cst$4462$app_DOT_main_DOT_data_DOT_workspace_SLASH_bundle_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","bundle-fetched","app.main.data.workspace/bundle-fetched",1862881298);$cljs$cst$4991$error_url$$=new $APP.$cljs$core$Keyword$$(null,"error-url","error-url",-1022635896);
$cljs$cst$5253$app_DOT_main_DOT_data_DOT_viewer_SLASH_reset_zoom$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","reset-zoom","app.main.data.viewer/reset-zoom",-869768188);$cljs$cst$2963$xml$$=new $APP.$cljs$core$Keyword$$(null,"xml","xml",-1170142052);$APP.$cljs$cst$2228$pages$$=new $APP.$cljs$core$Keyword$$(null,"pages","pages",-285406513);
$cljs$cst$5298$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_workspace$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","go-to-workspace","app.main.data.viewer/go-to-workspace",-2073521677);$cljs$cst$2094$app_DOT_common_DOT_types_DOT_shape_tree_SLASH_old_id$$=new $APP.$cljs$core$Keyword$$("app.common.types.shape-tree","old-id","app.common.types.shape-tree/old-id",-1625827509);$APP.$cljs$cst$4861$ungroup$$=new $APP.$cljs$core$Keyword$$(null,"ungroup","ungroup",-1629254184);
$cljs$cst$1240$file_validation$$=new $APP.$cljs$core$Keyword$$(null,"file-validation","file-validation",1111858459);$cljs$cst$1175$login_with_oidc$$=new $APP.$cljs$core$Keyword$$(null,"login-with-oidc","login-with-oidc",688254834);$APP.$cljs$cst$1675$area_name$$=new $APP.$cljs$core$Keyword$$(null,"area-name","area-name",-496581211);$APP.$cljs$cst$1682$column_gap$$=new $APP.$cljs$core$Keyword$$(null,"column-gap","column-gap",384822863);
$cljs$cst$3523$ignore_mask$$=new $APP.$cljs$core$Keyword$$(null,"ignore-mask","ignore-mask",-19600370);$APP.$cljs$cst$5144$accept_key$$=new $APP.$cljs$core$Keyword$$(null,"accept-key","accept-key",1651901631);$cljs$cst$2271$form_data_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"form-data?","form-data?",1304045150);$cljs$cst$3467$mark_all_threads_as_read$$=new $APP.$cljs$core$Keyword$$(null,"mark-all-threads-as-read","mark-all-threads-as-read",-1110285497);
$cljs$cst$4461$workspace_ready$$=new $APP.$cljs$core$Keyword$$(null,"workspace-ready","workspace-ready",418955745);$cljs$cst$2604$set_guide$$=new $APP.$cljs$core$Keyword$$(null,"set-guide","set-guide",-793086394);$APP.$cljs$cst$1969$animation$$=new $APP.$cljs$core$Keyword$$(null,"animation","animation",-1248293244);$cljs$cst$2284$upload_chunk$$=new $APP.$cljs$core$Keyword$$(null,"upload-chunk","upload-chunk",143658064);
$cljs$cst$4582$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_spread$$=new $APP.$cljs$core$Keyword$$("error.style-dictionary","invalid-token-value-shadow-spread","error.style-dictionary/invalid-token-value-shadow-spread",-522549398);$cljs$cst$5404$shown_thumbnails$$=new $APP.$cljs$core$Keyword$$(null,"shown-thumbnails","shown-thumbnails",-749491477);
$cljs$cst$1120$cljs_DOT_spec_DOT_alpha_SLASH_conformer$$=new $APP.$cljs$core$Symbol$$("cljs.spec.alpha","conformer","cljs.spec.alpha/conformer",2140085535,null);$APP.$cljs$cst$2265$update_file$$=new $APP.$cljs$core$Keyword$$(null,"update-file","update-file",-511736043);$APP.$cljs$cst$1172$login$$=new $APP.$cljs$core$Keyword$$(null,"login","login",55217519);
$APP.$cljs$cst$3587$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_finish_zooming$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.zoom","finish-zooming","app.main.data.workspace.zoom/finish-zooming",-355347318);$cljs$cst$4863$zoom_lense_increase$$=new $APP.$cljs$core$Keyword$$(null,"zoom-lense-increase","zoom-lense-increase",-938698120);$cljs$cst$2066$text_display_group$$=new $APP.$cljs$core$Keyword$$(null,"text-display-group","text-display-group",-1254503578);
$APP.$cljs$cst$5275$app_DOT_main_DOT_data_DOT_viewer_SLASH_complete_animation$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","complete-animation","app.main.data.viewer/complete-animation",-1327497536);$cljs$cst$1477$cljs_DOT_core_SLASH_lift_ns$$=new $APP.$cljs$core$Symbol$$("cljs.core","lift-ns","cljs.core/lift-ns",463499081,null);$cljs$cst$2298$screen_width$$=new $APP.$cljs$core$Keyword$$(null,"screen-width","screen-width",1557963263);
$APP.$cljs$cst$5139$expired$$=new $APP.$cljs$core$Keyword$$(null,"expired","expired",917709975);$cljs$cst$2627$del_color$$=new $APP.$cljs$core$Keyword$$(null,"del-color","del-color",-1547350867);$cljs$cst$3477$app_DOT_main_DOT_data_DOT_comments_SLASH_hide_comment_options$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","hide-comment-options","app.main.data.comments/hide-comment-options",151145654);
$cljs$cst$1558$scroll_height$$=new $APP.$cljs$core$Keyword$$(null,"scroll-height","scroll-height",882644149);$APP.$cljs$cst$2630$del_media$$=new $APP.$cljs$core$Keyword$$(null,"del-media","del-media",-149779060);$APP.$cljs$cst$3143$file_vern$$=new $APP.$cljs$core$Keyword$$(null,"file-vern","file-vern",336101510);
$cljs$cst$4398$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_create_layout_from_selection$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","create-layout-from-selection","app.main.data.workspace.shape-layout/create-layout-from-selection",270819660);$APP.$cljs$cst$3725$display_guides$$=new $APP.$cljs$core$Keyword$$(null,"display-guides","display-guides",-1025684907);
$cljs$cst$5159$masking_child_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"masking-child?","masking-child?",1265911452);$cljs$cst$2262$create_file_object_thumbnail$$=new $APP.$cljs$core$Keyword$$(null,"create-file-object-thumbnail","create-file-object-thumbnail",-1990532944);$cljs$cst$1173$login_with_github$$=new $APP.$cljs$core$Keyword$$(null,"login-with-github","login-with-github",518824080);$APP.$cljs$cst$4382$groups$$=new $APP.$cljs$core$Keyword$$(null,"groups","groups",-136896102);
$cljs$cst$5262$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_thumbnails_panel$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","toggle-thumbnails-panel","app.main.data.viewer/toggle-thumbnails-panel",-1804516951);$cljs$cst$4436$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_transform_in_variant$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","transform-in-variant","app.main.data.workspace.variants/transform-in-variant",-1072127094);
$cljs$cst$1633$metadata$$=new $APP.$cljs$core$Keyword$$(null,"metadata","metadata",1799301597);$cljs$cst$3819$child_height$$=new $APP.$cljs$core$Keyword$$(null,"child-height","child-height",-1775428512);$APP.$cljs$cst$3485$chunk_size$$=new $APP.$cljs$core$Keyword$$(null,"chunk-size","chunk-size",-205934374);$APP.$cljs$cst$2039$dashed$$=new $APP.$cljs$core$Keyword$$(null,"dashed","dashed",-1449249319);
$APP.$cljs$cst$2419$reitit_DOT_core_SLASH_router$$=new $APP.$cljs$core$Keyword$$("reitit.core","router","reitit.core/router",1293076450);$APP.$cljs$cst$4166$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_add_recent_color$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","add-recent-color","app.main.data.workspace.colors/add-recent-color",1883780309);$cljs$cst$990$gfn$$=new $APP.$cljs$core$Keyword$$(null,"gfn","gfn",791517474);
$cljs$cst$3872$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_start_move$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","start-move","app.main.data.workspace.transforms/start-move",1943175830);$cljs$cst$3490$woff2_file_id$$=new $APP.$cljs$core$Keyword$$(null,"woff2-file-id","woff2-file-id",369972739);
$cljs$cst$4280$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_navigate_to_comment_from_dashboard$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.comments","navigate-to-comment-from-dashboard","app.main.data.workspace.comments/navigate-to-comment-from-dashboard",-1454602969);$APP.$cljs$cst$214$regex$$=new $APP.$cljs$core$Keyword$$(null,"regex","regex",939488856);$cljs$cst$1907$inner_shadow$$=new $APP.$cljs$core$Keyword$$(null,"inner-shadow","inner-shadow",-548982250);
$APP.$cljs$cst$4980$app_DOT_main_DOT_data_DOT_dashboard_SLASH_restore_project_immediately$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","restore-project-immediately","app.main.data.dashboard/restore-project-immediately",-206008453);$APP.$cljs$cst$4173$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_color$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","update-colorpicker-color","app.main.data.workspace.colors/update-colorpicker-color",-1234106185);
$cljs$cst$2896$text_anchor$$=new $APP.$cljs$core$Keyword$$(null,"text-anchor","text-anchor",585613696);$cljs$cst$2912$shape_rendering$$=new $APP.$cljs$core$Keyword$$(null,"shape-rendering","shape-rendering",955846315);$cljs$cst$573$gen$$=new $APP.$cljs$core$Keyword$$(null,"gen","gen",142575302);$cljs$cst$3491$app_DOT_main_DOT_fonts_SLASH_ttf_file_id$$=new $APP.$cljs$core$Keyword$$("app.main.fonts","ttf-file-id","app.main.fonts/ttf-file-id",218081328);
$APP.$cljs$cst$2116$group_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"group?","group?",-1871629417);$cljs$cst$5307$zoom_viewer$$=new $APP.$cljs$core$Keyword$$(null,"zoom-viewer","zoom-viewer",-1383581982);$APP.$cljs$cst$1297$get$$=new $APP.$cljs$core$Keyword$$(null,"get","get",1683182755);$cljs$cst$3036$stopopacity$$=new $APP.$cljs$core$Keyword$$(null,"stopopacity","stopopacity",-1465341352);$cljs$cst$3375$worker_error$$=new $APP.$cljs$core$Keyword$$(null,"worker-error","worker-error",-1820227890);
$APP.$cljs$cst$4915$app_DOT_main_DOT_data_DOT_dashboard_SLASH_fetch_recent_files$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","fetch-recent-files","app.main.data.dashboard/fetch-recent-files",-157817221);$APP.$cljs$cst$2335$get_enabled_flags$$=new $APP.$cljs$core$Keyword$$(null,"get-enabled-flags","get-enabled-flags",626207437);
$APP.$cljs$cst$5021$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_init_versions_state$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","init-versions-state","app.main.data.workspace.versions/init-versions-state",-1179770191);$cljs$cst$3756$shape_path$$=new $APP.$cljs$core$Keyword$$(null,"shape-path","shape-path",79876289);
$APP.$cljs$cst$4907$app_DOT_main_DOT_data_DOT_dashboard_SLASH_projects_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","projects-fetched","app.main.data.dashboard/projects-fetched",-1575596718);$APP.$cljs$cst$4237$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_path_handler_enter$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.selection","path-handler-enter","app.main.data.workspace.path.selection/path-handler-enter",-1369135598);
$cljs$cst$827$property$$=new $APP.$cljs$core$Keyword$$(null,"property","property",-1114278232);$APP.$cljs$cst$1298$color$$=new $APP.$cljs$core$Keyword$$(null,"color","color",1011675173);$APP.$cljs$cst$1432$colon$$=new $APP.$cljs$core$Keyword$$(null,"colon","colon",-965200945);$APP.$cljs$cst$5309$make_corner$$=new $APP.$cljs$core$Keyword$$(null,"make-corner","make-corner",-1029141688);$cljs$cst$656$aliases$$=new $APP.$cljs$core$Keyword$$(null,"aliases","aliases",1346874714);
$cljs$cst$2250$base_delay_ms$$=new $APP.$cljs$core$Keyword$$(null,"base-delay-ms","base-delay-ms",463049020);$cljs$cst$792$clojure_DOT_test_DOT_check_DOT_generators_SLASH_fmap$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","fmap","clojure.test.check.generators/fmap",1957997092,null);
$APP.$cljs$cst$5022$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_update_versions_state$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","update-versions-state","app.main.data.workspace.versions/update-versions-state",-403020738);$APP.$cljs$cst$4163$linear_gradient$$=new $APP.$cljs$core$Keyword$$(null,"linear-gradient","linear-gradient",1752751047);$cljs$cst$4996$mention$$=new $APP.$cljs$core$Keyword$$(null,"mention","mention",-1057367181);
$cljs$cst$4267$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_clear_drawing$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.drawing","clear-drawing","app.main.data.workspace.drawing/clear-drawing",-691958826);$APP.$cljs$cst$3656$force_shape_id$$=new $APP.$cljs$core$Keyword$$(null,"force-shape-id","force-shape-id",-1073846094);$APP.$cljs$cst$4424$trigger$$=new $APP.$cljs$core$Keyword$$(null,"trigger","trigger",103466139);
$cljs$cst$668$pos_int_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"pos-int?","pos-int?",-1205815015,null);$APP.$cljs$cst$3929$start_move_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"start-move?","start-move?",952844762);$cljs$cst$3613$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_memorize_duplicated$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","memorize-duplicated","app.main.data.workspace.selection/memorize-duplicated",-1965907575);
$APP.$cljs$cst$5067$show_contact_sales_option$$=new $APP.$cljs$core$Keyword$$(null,"show-contact-sales-option","show-contact-sales-option",-1555208026);$cljs$cst$3355$app_DOT_main_DOT_data_DOT_auth_SLASH_logged_out$$=new $APP.$cljs$core$Keyword$$("app.main.data.auth","logged-out","app.main.data.auth/logged-out",614492580);$cljs$cst$4782$app_DOT_main_DOT_refs$$=new $APP.$cljs$core$Symbol$$(null,"app.main.refs","app.main.refs",-748762075,null);
$cljs$cst$684$simple_symbol_QMARK_$$=new $APP.$cljs$core$Symbol$$(null,"simple-symbol?","simple-symbol?",1408454822,null);$cljs$cst$885$malli_DOT_error_SLASH_likely_misspelling_of$$=new $APP.$cljs$core$Keyword$$("malli.error","likely-misspelling-of","malli.error/likely-misspelling-of",1504085033);$APP.$cljs$cst$2015$triangle_arrow$$=new $APP.$cljs$core$Keyword$$(null,"triangle-arrow","triangle-arrow",270775124);
$APP.$cljs$cst$3937$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_nav_to_component_file$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","nav-to-component-file","app.main.data.workspace.libraries/nav-to-component-file",-98499692);
$APP.$cljs$cst$3919$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_duplicate_typography$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","duplicate-typography","app.main.data.workspace.libraries/duplicate-typography",-791052786);$cljs$cst$631$re_parser$$=new $APP.$cljs$core$Keyword$$(null,"re-parser","re-parser",-1229625564);
$cljs$cst$4709$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_delete_token_set$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","delete-token-set","app.main.data.workspace.tokens.library-edit/delete-token-set",-546870967);$cljs$cst$5343$flex_element$$=new $APP.$cljs$core$Keyword$$(null,"flex-element","flex-element",-876437350);$APP.$cljs$cst$5135$scd_message$$=new $APP.$cljs$core$Keyword$$(null,"scd-message","scd-message",89862664);
$cljs$cst$4895$preview_frame$$=new $APP.$cljs$core$Keyword$$(null,"preview-frame","preview-frame",441598316);$cljs$cst$2733$feColorMatrix$$=new $APP.$cljs$core$Keyword$$(null,"feColorMatrix","feColorMatrix",-1697260201);$cljs$cst$743$gen_delims$$=new $APP.$cljs$core$Keyword$$(null,"gen-delims","gen-delims",-1487021297);$cljs$cst$1083$cljs_DOT_spec_DOT_alpha_SLASH_accept$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","accept","cljs.spec.alpha/accept",370988198);
$cljs$cst$1567$app_DOT_util_DOT_dom_SLASH_focus_element$$=new $APP.$cljs$core$Keyword$$("app.util.dom","focus-element","app.util.dom/focus-element",899201855);$cljs$cst$4504$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_context_menu$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","show-context-menu","app.main.data.workspace/show-context-menu",-1116685582);$cljs$cst$153$finally$$=new $APP.$cljs$core$Symbol$$(null,"finally","finally",-1065347064,null);
$APP.$cljs$cst$4065$gap$$=new $APP.$cljs$core$Keyword$$(null,"gap","gap",80255254);$APP.$cljs$cst$1922$workspace_modifiers$$=new $APP.$cljs$core$Keyword$$(null,"workspace-modifiers","workspace-modifiers",1432219828);$cljs$cst$4617$warnings$$=new $APP.$cljs$core$Keyword$$(null,"warnings","warnings",-735437651);
$cljs$cst$4719$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_delete_token$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.library-edit","delete-token","app.main.data.workspace.tokens.library-edit/delete-token",-1773722969);$APP.$cljs$cst$828$result$$=new $APP.$cljs$core$Keyword$$(null,"result","result",1415092211);$APP.$cljs$cst$3822$snap_pixel_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"snap-pixel?","snap-pixel?",-1854606324);
$APP.$cljs$cst$4028$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_clean_text_modifier$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","clean-text-modifier","app.main.data.workspace.texts/clean-text-modifier",-292436858);$cljs$cst$3486$create_upload_session$$=new $APP.$cljs$core$Keyword$$(null,"create-upload-session","create-upload-session",-947158500);
$APP.$cljs$cst$5290$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_selection$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","toggle-selection","app.main.data.viewer/toggle-selection",1667521467);$APP.$cljs$cst$3153$app_DOT_main_DOT_data_DOT_persistence_SLASH_discard_commit$$=new $APP.$cljs$core$Keyword$$("app.main.data.persistence","discard-commit","app.main.data.persistence/discard-commit",553409677);
$APP.$cljs$cst$4367$workspace_trimmed_page$$=new $APP.$cljs$core$Keyword$$(null,"workspace-trimmed-page","workspace-trimmed-page",-460377068);$cljs$cst$140$cljs_DOT_core_SLASH_ExceptionInfo$$=new $APP.$cljs$core$Symbol$$("cljs.core","ExceptionInfo","cljs.core/ExceptionInfo",701839050,null);$cljs$cst$3186$app_DOT_main_DOT_data_DOT_media_SLASH_blob$$=new $APP.$cljs$core$Keyword$$("app.main.data.media","blob","app.main.data.media/blob",-491326055);
$cljs$cst$462$closed$$=new $APP.$cljs$core$Keyword$$(null,"closed","closed",-919675359);$APP.$cljs$cst$167$quote$$=new $APP.$cljs$core$Symbol$$(null,"quote","quote",1377916282,null);$APP.$cljs$cst$229$preserve$$=new $APP.$cljs$core$Keyword$$(null,"preserve","preserve",1276846509);$APP.$cljs$cst$1605$selrect$$=new $APP.$cljs$core$Keyword$$(null,"selrect","selrect",1966287292);
$cljs$cst$3546$app_DOT_main_DOT_data_DOT_workspace_DOT_collapse_SLASH_expand_all_parents$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.collapse","expand-all-parents","app.main.data.workspace.collapse/expand-all-parents",889288025);$APP.$cljs$cst$884$error_SLASH_fn$$=new $APP.$cljs$core$Keyword$$("error","fn","error/fn",-1263293860);$APP.$cljs$cst$2239$colorpicker$$=new $APP.$cljs$core$Keyword$$(null,"colorpicker","colorpicker",-1310754644);
$APP.$cljs$cst$2406$required$$=new $APP.$cljs$core$Symbol$$(null,"required","required",-846788763,null);$APP.$cljs$cst$3410$updated_at$$=new $APP.$cljs$core$Keyword$$(null,"updated-at","updated-at",-1592622336);$cljs$cst$5209$variant_bad_variant_name$$=new $APP.$cljs$core$Keyword$$(null,"variant-bad-variant-name","variant-bad-variant-name",-995497356);$APP.$cljs$cst$2016$circle_marker$$=new $APP.$cljs$core$Keyword$$(null,"circle-marker","circle-marker",-241178759);
$cljs$cst$1224$token_tokenscript$$=new $APP.$cljs$core$Keyword$$(null,"token-tokenscript","token-tokenscript",-1940327983);$cljs$cst$4428$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_remove_property$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","remove-property","app.main.data.workspace.variants/remove-property",95421074);$cljs$cst$3095$aa_threshold$$=new $APP.$cljs$core$Keyword$$(null,"aa_threshold","aa_threshold",566331892);
$cljs$cst$3775$use_thumbnails$$=new $APP.$cljs$core$Keyword$$(null,"use-thumbnails","use-thumbnails",1849918701);$APP.$cljs$cst$4132$picked_color_select$$=new $APP.$cljs$core$Keyword$$(null,"picked-color-select","picked-color-select",-1074320132);$APP.$cljs$cst$4419$track_indices$$=new $APP.$cljs$core$Keyword$$(null,"track-indices","track-indices",-158402255);$cljs$cst$1940$mouse_press$$=new $APP.$cljs$core$Keyword$$(null,"mouse-press","mouse-press",-273498051);
$APP.$cljs$cst$3146$commit_id$$=new $APP.$cljs$core$Keyword$$(null,"commit-id","commit-id",480429844);$cljs$cst$3528$new_shape_id$$=new $APP.$cljs$core$Keyword$$(null,"new-shape-id","new-shape-id",954303512);$APP.$cljs$cst$4174$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_activate_colorpicker_gradient$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","activate-colorpicker-gradient","app.main.data.workspace.colors/activate-colorpicker-gradient",-1312135871);
$APP.$cljs$cst$1639$media$$=new $APP.$cljs$core$Keyword$$(null,"media","media",-1066138403);$cljs$cst$106$alt_impl$$=new $APP.$cljs$core$Keyword$$(null,"alt-impl","alt-impl",670969595);$APP.$cljs$cst$4791$duplicate$$=new $APP.$cljs$core$Keyword$$(null,"duplicate","duplicate",-1107405184);$cljs$cst$1840$minItems$$=new $APP.$cljs$core$Keyword$$(null,"minItems","minItems",1950622069);$APP.$cljs$cst$3382$max_quote_reached$$=new $APP.$cljs$core$Keyword$$(null,"max-quote-reached","max-quote-reached",183086757);
$APP.$cljs$cst$166$var$$=new $APP.$cljs$core$Symbol$$(null,"var","var",870848730,null);$cljs$cst$1436$minpad$$=new $APP.$cljs$core$Keyword$$(null,"minpad","minpad",323570901);$APP.$cljs$cst$2232$viewer_overlays$$=new $APP.$cljs$core$Keyword$$(null,"viewer-overlays","viewer-overlays",-1841198928);$cljs$cst$1828$minimum$$=new $APP.$cljs$core$Keyword$$(null,"minimum","minimum",-1621006059);
$cljs$cst$2931$glyph_orientation_vertical$$=new $APP.$cljs$core$Keyword$$(null,"glyph-orientation-vertical","glyph-orientation-vertical",1701745981);$APP.$cljs$cst$4180$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","update-colorpicker","app.main.data.workspace.colors/update-colorpicker",-444024938);$APP.$cljs$cst$5402$is_logged$$=new $APP.$cljs$core$Keyword$$(null,"is-logged","is-logged",702589853);
$cljs$cst$3900$raw_change$$=new $APP.$cljs$core$Keyword$$(null,"raw-change","raw-change",1940823897);$cljs$cst$3863$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_trigger_bounding_box_cloaking$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.transforms","trigger-bounding-box-cloaking","app.main.data.workspace.transforms/trigger-bounding-box-cloaking",-109183821);$APP.$cljs$cst$1740$stroke_opacity$$=new $APP.$cljs$core$Keyword$$(null,"stroke-opacity","stroke-opacity",-1191543159);
$cljs$cst$3671$view_box$$=new $APP.$cljs$core$Keyword$$(null,"view-box","view-box",-1792199155);$APP.$cljs$cst$4545$parent_ref$$=new $APP.$cljs$core$Keyword$$(null,"parent-ref","parent-ref",-860935235);$cljs$cst$1204$secure_session_cookies$$=new $APP.$cljs$core$Keyword$$(null,"secure-session-cookies","secure-session-cookies",-1405592250);$cljs$cst$1014$pred_exprs$$=new $APP.$cljs$core$Keyword$$(null,"pred-exprs","pred-exprs",1792271395);
$cljs$cst$4904$total_count$$=new $APP.$cljs$core$Keyword$$(null,"total-count","total-count",-1999441386);$cljs$cst$2821$diffuseConstant$$=new $APP.$cljs$core$Keyword$$(null,"diffuseConstant","diffuseConstant",1963513774);$APP.$cljs$cst$2203$vport$$=new $APP.$cljs$core$Keyword$$(null,"vport","vport",-1317419022);$APP.$cljs$cst$3556$preview$$=new $APP.$cljs$core$Keyword$$(null,"preview","preview",451279890);$cljs$cst$2091$force_id$$=new $APP.$cljs$core$Keyword$$(null,"force-id","force-id",916825032);
$cljs$cst$412$malli_DOT_core_SLASH_schema$$=new $APP.$cljs$core$Keyword$$("malli.core","schema","malli.core/schema",-1780373863);$cljs$cst$424$uuid$$=new $APP.$cljs$core$Keyword$$(null,"uuid","uuid",-2145095719);$cljs$cst$4437$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_add_component_or_variant$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","add-component-or-variant","app.main.data.workspace.variants/add-component-or-variant",1400958828);
$APP.$cljs$cst$2304$placeholder_SLASH_coll$$=new $APP.$cljs$core$Keyword$$("placeholder","coll","placeholder/coll",-2075266112);$APP.$cljs$cst$290$width$$=new $APP.$cljs$core$Keyword$$(null,"width","width",-384071477);$cljs$cst$4648$applied_to$$=new $APP.$cljs$core$Keyword$$(null,"applied-to","applied-to",1142736910);$cljs$cst$2742$tref$$=new $APP.$cljs$core$Keyword$$(null,"tref","tref",77832220);$cljs$cst$4619$references$$=new $APP.$cljs$core$Keyword$$(null,"references","references",882562509);
$cljs$cst$3830$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_modifiers$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.modifiers","set-modifiers","app.main.data.workspace.modifiers/set-modifiers",-925598309);$APP.$cljs$cst$4855$bring_backward$$=new $APP.$cljs$core$Keyword$$(null,"bring-backward","bring-backward",-1847662891);$cljs$cst$3334$opened$$=new $APP.$cljs$core$Keyword$$(null,"opened","opened",-1451743091);
$APP.$cljs$cst$2623$mov_page$$=new $APP.$cljs$core$Keyword$$(null,"mov-page","mov-page",799279210);$cljs$cst$4303$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_update_flow$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","update-flow","app.main.data.workspace.interactions/update-flow",207732240);$APP.$cljs$cst$2344$success$$=new $APP.$cljs$core$Keyword$$(null,"success","success",1890645906);
$cljs$cst$395$malli_DOT_core_SLASH_non_associative_schema$$=new $APP.$cljs$core$Keyword$$("malli.core","non-associative-schema","malli.core/non-associative-schema",-588379948);$APP.$cljs$cst$5125$dashboard_team_invitations$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-team-invitations","dashboard-team-invitations",2059131944);$cljs$cst$3628$workspace_pre_focus$$=new $APP.$cljs$core$Keyword$$(null,"workspace-pre-focus","workspace-pre-focus",1343741403);
$cljs$cst$3823$snap_precision$$=new $APP.$cljs$core$Keyword$$(null,"snap-precision","snap-precision",637714362);$APP.$cljs$cst$2959$draggable_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"draggable?","draggable?",-236042740);$APP.$cljs$cst$4867$show_shortcuts$$=new $APP.$cljs$core$Keyword$$(null,"show-shortcuts","show-shortcuts",749740024);$APP.$cljs$cst$4993$plugin_permissions$$=new $APP.$cljs$core$Keyword$$(null,"plugin-permissions","plugin-permissions",-1579203559);
$APP.$cljs$cst$2026$luminosity$$=new $APP.$cljs$core$Keyword$$(null,"luminosity","luminosity",-483901643);$APP.$cljs$cst$4547$js_SLASH_prev_val$$=new $APP.$cljs$core$Keyword$$("js","prev-val","js/prev-val",1324827446);$cljs$cst$905$malli_DOT_transform_SLASH_invalid_transformer$$=new $APP.$cljs$core$Keyword$$("malli.transform","invalid-transformer","malli.transform/invalid-transformer",-1717093616);$APP.$cljs$cst$1928$projects$$=new $APP.$cljs$core$Keyword$$(null,"projects","projects",-364845983);
$cljs$cst$2900$mask_type$$=new $APP.$cljs$core$Keyword$$(null,"mask-type","mask-type",-1876682271);$cljs$cst$4515$app_DOT_main_DOT_data_DOT_workspace_SLASH_toggle_distances_display$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","toggle-distances-display","app.main.data.workspace/toggle-distances-display",-1005138727);
$APP.$cljs$cst$4273$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_finalize$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.comments","finalize","app.main.data.workspace.comments/finalize",1021332360);$APP.$cljs$cst$4454$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_finish_panning$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.viewport","finish-panning","app.main.data.workspace.viewport/finish-panning",52976006);
$APP.$cljs$cst$4912$search_files$$=new $APP.$cljs$core$Keyword$$(null,"search-files","search-files",473802622);$cljs$cst$5101$teams_to_transfer$$=new $APP.$cljs$core$Keyword$$(null,"teams-to-transfer","teams-to-transfer",-482496664);$cljs$cst$170$def$$=new $APP.$cljs$core$Symbol$$(null,"def","def",597100991,null);
$APP.$cljs$cst$4500$app_DOT_main_DOT_data_DOT_workspace_SLASH_select_single_asset$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","select-single-asset","app.main.data.workspace/select-single-asset",-126229974);$APP.$cljs$cst$1665$space_around$$=new $APP.$cljs$core$Keyword$$(null,"space-around","space-around",248184132);$cljs$cst$3401$plugin_permissions_update$$=new $APP.$cljs$core$Keyword$$(null,"plugin-permissions-update","plugin-permissions-update",-1916481193);
$APP.$cljs$cst$3151$saved$$=new $APP.$cljs$core$Keyword$$(null,"saved","saved",288760660);$cljs$cst$4642$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_dimensions_token$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","apply-dimensions-token","app.main.data.workspace.tokens.application/apply-dimensions-token",880823234);$APP.$cljs$cst$4664$tokens_SLASH_font_family$$=new $APP.$cljs$core$Keyword$$("tokens","font-family","tokens/font-family",-461865292);
$APP.$cljs$cst$2274$get_file$$=new $APP.$cljs$core$Keyword$$(null,"get-file","get-file",-588292783);$APP.$cljs$cst$1199$audit_log$$=new $APP.$cljs$core$Keyword$$(null,"audit-log","audit-log",1352683940);$APP.$cljs$cst$3686$trim$$=new $APP.$cljs$core$Keyword$$(null,"trim","trim",774319767);$APP.$cljs$cst$1926$current_team_id$$=new $APP.$cljs$core$Keyword$$(null,"current-team-id","current-team-id",999946995);
$cljs$cst$3616$move_delta_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"move-delta?","move-delta?",1707744700);$APP.$cljs$cst$1787$transform_inverse$$=new $APP.$cljs$core$Keyword$$(null,"transform-inverse","transform-inverse",1233122576);$APP.$cljs$cst$2134$error_DOT_import_SLASH_invalid_json_data$$=new $APP.$cljs$core$Keyword$$("error.import","invalid-json-data","error.import/invalid-json-data",231259630);
$APP.$cljs$cst$1698$layout_item_margin_type$$=new $APP.$cljs$core$Keyword$$(null,"layout-item-margin-type","layout-item-margin-type",-1313230390);$APP.$cljs$cst$3142$tags$$=new $APP.$cljs$core$Keyword$$(null,"tags","tags",1771418977);$cljs$cst$3564$transaction$$=new $APP.$cljs$core$Keyword$$(null,"transaction","transaction",1777321997);$APP.$cljs$cst$3591$corners$$=new $APP.$cljs$core$Keyword$$(null,"corners","corners",-137817903);
$cljs$cst$4430$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_add_new_property$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.variants","add-new-property","app.main.data.workspace.variants/add-new-property",-1851122032);$APP.$cljs$cst$4959$create_file$$=new $APP.$cljs$core$Keyword$$(null,"create-file","create-file",-39781249);$APP.$cljs$cst$5049$snapshot_id$$=new $APP.$cljs$core$Keyword$$(null,"snapshot-id","snapshot-id",210383587);
$cljs$cst$1159$app_DOT_common_DOT_logging_SLASH_timestamp$$=new $APP.$cljs$core$Keyword$$("app.common.logging","timestamp","app.common.logging/timestamp",-1174599550);$APP.$cljs$cst$3273$app_DOT_main_DOT_data_DOT_team_SLASH_finalize_team$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","finalize-team","app.main.data.team/finalize-team",-645954379);$cljs$cst$3026$symbols$$=new $APP.$cljs$core$Keyword$$(null,"symbols","symbols",1211743);
$APP.$cljs$cst$4537$layers_search$$=new $APP.$cljs$core$Keyword$$(null,"layers-search","layers-search",872311273);$cljs$cst$419$some$$=new $APP.$cljs$core$Keyword$$(null,"some","some",-1951079573);$cljs$cst$4215$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_preview_next_point$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.drawing","preview-next-point","app.main.data.workspace.path.drawing/preview-next-point",-51717842);
$cljs$cst$3482$app_DOT_main_DOT_data_DOT_comments_SLASH_detach_comment_thread$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","detach-comment-thread","app.main.data.comments/detach-comment-thread",377501501);$cljs$cst$2921$dominant_baseline$$=new $APP.$cljs$core$Keyword$$(null,"dominant-baseline","dominant-baseline",609259826);$APP.$cljs$cst$1977$sizing$$=new $APP.$cljs$core$Keyword$$(null,"sizing","sizing",-1868029885);
$APP.$cljs$cst$2018$hue$$=new $APP.$cljs$core$Keyword$$(null,"hue","hue",-508078848);$cljs$cst$822$clojure_DOT_test_DOT_check_DOT_generators_SLASH_string_alphanumeric$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","string-alphanumeric","clojure.test.check.generators/string-alphanumeric",836374939,null);$APP.$cljs$cst$5364$yearly$$=new $APP.$cljs$core$Keyword$$(null,"yearly","yearly",1010642817);
$APP.$cljs$cst$3377$comment_error$$=new $APP.$cljs$core$Keyword$$(null,"comment-error","comment-error",371413856);$APP.$cljs$cst$3740$textpalette$$=new $APP.$cljs$core$Keyword$$(null,"textpalette","textpalette",-1296342868);$APP.$cljs$cst$2454$app_DOT_main_DOT_router_SLASH_navigated$$=new $APP.$cljs$core$Keyword$$("app.main.router","navigated","app.main.router/navigated",-343379749);
$cljs$cst$5194$instance_head_not_frame$$=new $APP.$cljs$core$Keyword$$(null,"instance-head-not-frame","instance-head-not-frame",829436563);$APP.$cljs$cst$5123$dashboard_team_members$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-team-members","dashboard-team-members",-736569143);$APP.$cljs$cst$3577$zoom_inverse$$=new $APP.$cljs$core$Keyword$$(null,"zoom-inverse","zoom-inverse",-1760246179);$cljs$cst$2998$sora_sompeng$$=new $APP.$cljs$core$Keyword$$(null,"sora-sompeng","sora-sompeng",2067371434);
$APP.$cljs$cst$3386$on_click$$=new $APP.$cljs$core$Keyword$$(null,"on-click","on-click",1632826543);$cljs$cst$2086$app_DOT_common_DOT_types_DOT_shape_tree_SLASH_index_frames$$=new $APP.$cljs$core$Keyword$$("app.common.types.shape-tree","index-frames","app.common.types.shape-tree/index-frames",-155995028);$APP.$cljs$cst$5237$app_DOT_main_DOT_data_DOT_viewer_SLASH_finalize$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","finalize","app.main.data.viewer/finalize",654031499);
$APP.$cljs$cst$1467$flags$$=new $APP.$cljs$core$Keyword$$(null,"flags","flags",1775418075);$cljs$cst$3812$child_min_width$$=new $APP.$cljs$core$Keyword$$(null,"child-min-width","child-min-width",-1878111322);$APP.$cljs$cst$1853$from_p$$=new $APP.$cljs$core$Keyword$$(null,"from-p","from-p",2047181810);$APP.$cljs$cst$1133$assertion_failed$$=new $APP.$cljs$core$Keyword$$(null,"assertion-failed","assertion-failed",-970534477);
$cljs$cst$3092$on_render$$=new $APP.$cljs$core$Keyword$$(null,"on-render","on-render",2096729391);$cljs$cst$5287$app_DOT_main_DOT_data_DOT_viewer_SLASH_close_overlay$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","close-overlay","app.main.data.viewer/close-overlay",-1269949120);$APP.$cljs$cst$1403$fill$$=new $APP.$cljs$core$Keyword$$(null,"fill","fill",883462889);
$APP.$cljs$cst$4407$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_reorder_layout_track$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.shape-layout","reorder-layout-track","app.main.data.workspace.shape-layout/reorder-layout-track",1831596773);$cljs$cst$2842$numOctaves$$=new $APP.$cljs$core$Keyword$$(null,"numOctaves","numOctaves",810606547);
$APP.$cljs$cst$3338$app_DOT_main_DOT_data_DOT_websocket_SLASH_message$$=new $APP.$cljs$core$Keyword$$("app.main.data.websocket","message","app.main.data.websocket/message",-2128948247);$cljs$cst$3065$gl_context$$=new $APP.$cljs$core$Keyword$$(null,"gl-context","gl-context",2058385711);$APP.$cljs$cst$6376$settings_notifications$$=new $APP.$cljs$core$Keyword$$(null,"settings-notifications","settings-notifications",-990272802);
$cljs$cst$4112$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_selected_props$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","paste-selected-props","app.main.data.workspace.clipboard/paste-selected-props",417256302);$cljs$cst$797$clojure_DOT_test_DOT_check_DOT_generators_SLASH_such_that$$=new $APP.$cljs$core$Symbol$$("clojure.test.check.generators","such-that","clojure.test.check.generators/such-that",-1754178732,null);
$cljs$cst$2005$used_pos$$=new $APP.$cljs$core$Keyword$$(null,"used-pos","used-pos",614992);$cljs$cst$4654$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_on_toggle_token$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.application","on-toggle-token","app.main.data.workspace.tokens.application/on-toggle-token",-1824967338);
$cljs$cst$859$malli_DOT_generator_SLASH_generator_ast$$=new $APP.$cljs$core$Keyword$$("malli.generator","generator-ast","malli.generator/generator-ast",-1769943051);$cljs$cst$2988$music$$=new $APP.$cljs$core$Keyword$$(null,"music","music",-1063514396);$APP.$cljs$cst$208$file$$=new $APP.$cljs$core$Keyword$$(null,"file","file",-1269645878);$APP.$cljs$cst$3069$text_outline$$=new $APP.$cljs$core$Keyword$$(null,"text-outline","text-outline",-2026960525);
$cljs$cst$3190$app_DOT_main_DOT_data_DOT_media_SLASH_file$$=new $APP.$cljs$core$Keyword$$("app.main.data.media","file","app.main.data.media/file",-1955317758);$cljs$cst$1200$strict_session_cookies$$=new $APP.$cljs$core$Keyword$$(null,"strict-session-cookies","strict-session-cookies",1762560900);$cljs$cst$3392$app_DOT_plugins_DOT_flags_SLASH_reset$$=new $APP.$cljs$core$Keyword$$("app.plugins.flags","reset","app.plugins.flags/reset",2067187122);
$APP.$cljs$cst$2174$current_project_id$$=new $APP.$cljs$core$Keyword$$(null,"current-project-id","current-project-id",1950829814);$APP.$cljs$cst$4726$token_set_context_menu$$=new $APP.$cljs$core$Keyword$$(null,"token-set-context-menu","token-set-context-menu",1640583502);$cljs$cst$775$num_elements$$=new $APP.$cljs$core$Keyword$$(null,"num-elements","num-elements",1960422107);$APP.$cljs$cst$1699$layout_item_margin$$=new $APP.$cljs$core$Keyword$$(null,"layout-item-margin","layout-item-margin",1666327708);
$cljs$cst$4149$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_add_stroke$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","add-stroke","app.main.data.workspace.colors/add-stroke",-1631590065);$cljs$cst$5204$invalid_variant_id$$=new $APP.$cljs$core$Keyword$$(null,"invalid-variant-id","invalid-variant-id",1217967624);
$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$=new $APP.$cljs$core$Keyword$$("app.common.schema.openapi","format","app.common.schema.openapi/format",1235016623);$cljs$cst$5295$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_dashboard$$=new $APP.$cljs$core$Keyword$$("app.main.data.viewer","go-to-dashboard","app.main.data.viewer/go-to-dashboard",-1938263263);$APP.$cljs$cst$1998$with_spaces_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"with-spaces?","with-spaces?",3340243);
$APP.$cljs$cst$4762$in_progress$$=new $APP.$cljs$core$Keyword$$(null,"in-progress","in-progress",2126442630);$APP.$cljs$cst$4483$app_DOT_main_DOT_data_DOT_workspace_SLASH_reorder_children$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","reorder-children","app.main.data.workspace/reorder-children",-163468785);$APP.$cljs$cst$3430$thread_id$$=new $APP.$cljs$core$Keyword$$(null,"thread-id","thread-id",895608538);
$cljs$cst$3512$app_DOT_main_DOT_data_DOT_project_SLASH_initialize_project$$=new $APP.$cljs$core$Keyword$$("app.main.data.project","initialize-project","app.main.data.project/initialize-project",-1472717746);$cljs$cst$4873$move_fast_up$$=new $APP.$cljs$core$Keyword$$(null,"move-fast-up","move-fast-up",773005692);$cljs$cst$1566$descent$$=new $APP.$cljs$core$Keyword$$(null,"descent","descent",1331783219);
$APP.$cljs$cst$4532$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_clipboard_style$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","set-clipboard-style","app.main.data.workspace/set-clipboard-style",1125559197);$cljs$cst$3087$fillRule$$=new $APP.$cljs$core$Keyword$$(null,"fillRule","fillRule",-1827524923);$cljs$cst$3999$$id$$=new $APP.$cljs$core$Keyword$$(null,"$id","$id",-1635392559);$cljs$cst$5091$tab_index$$=new $APP.$cljs$core$Keyword$$(null,"tab-index","tab-index",895755393);
$APP.$cljs$cst$2073$name_group$$=new $APP.$cljs$core$Keyword$$(null,"name-group","name-group",1478986286);$APP.$cljs$cst$4409$hover_track$$=new $APP.$cljs$core$Keyword$$(null,"hover-track","hover-track",-995236856);$cljs$cst$4942$app_DOT_main_DOT_data_DOT_dashboard_SLASH_move_project$$=new $APP.$cljs$core$Keyword$$("app.main.data.dashboard","move-project","app.main.data.dashboard/move-project",-1447817466);
$APP.$cljs$cst$3976$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_set_file_shared$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","set-file-shared","app.main.data.workspace.libraries/set-file-shared",116618641);$cljs$cst$3040$gradienttransform$$=new $APP.$cljs$core$Keyword$$(null,"gradienttransform","gradienttransform",-1259862407);$cljs$cst$778$infinite_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"infinite?","infinite?",-2017886608);
$cljs$cst$2833$z$$=new $APP.$cljs$core$Keyword$$(null,"z","z",-789527183);$cljs$cst$1446$w$$=new $APP.$cljs$core$Keyword$$(null,"w","w",354169001);$APP.$cljs$cst$3670$v$$=new $APP.$cljs$core$Keyword$$(null,"v","v",21465059);$cljs$cst$4626$interactive_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"interactive?","interactive?",367617676);$APP.$cljs$cst$1511$y$$=new $APP.$cljs$core$Keyword$$(null,"y","y",-1757859776);$APP.$cljs$cst$1510$x$$=new $APP.$cljs$core$Keyword$$(null,"x","x",2099068185);
$APP.$cljs$cst$4168$s$$=new $APP.$cljs$core$Keyword$$(null,"s","s",1705939918);$APP.$cljs$cst$1743$r$$=new $APP.$cljs$core$Keyword$$(null,"r","r",-471384190);$APP.$cljs$cst$2269$query_params$$=new $APP.$cljs$core$Keyword$$(null,"query-params","query-params",900640534);$APP.$cljs$cst$1852$t$$=new $APP.$cljs$core$Keyword$$(null,"t","t",-1397832519);$cljs$cst$1451$n$$=new $APP.$cljs$core$Keyword$$(null,"n","n",562130025);
$APP.$cljs$cst$4447$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_initialize_viewport$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.viewport","initialize-viewport","app.main.data.workspace.viewport/initialize-viewport",1754018350);$cljs$cst$3790$min_time$$=new $APP.$cljs$core$Keyword$$(null,"min-time","min-time",736615549);$cljs$cst$733$k$$=new $APP.$cljs$core$Keyword$$(null,"k","k",-2146297393);$APP.$cljs$cst$4793$find$$=new $APP.$cljs$core$Keyword$$(null,"find","find",496279456);
$APP.$cljs$cst$1744$g$$=new $APP.$cljs$core$Keyword$$(null,"g","g",1738089905);$cljs$cst$598$f$$=new $APP.$cljs$core$Keyword$$(null,"f","f",-1597136552);$APP.$cljs$cst$1899$h$$=new $APP.$cljs$core$Keyword$$(null,"h","h",1109658740);$cljs$cst$1521$c$$=new $APP.$cljs$core$Keyword$$(null,"c","c",-1763192079);
$cljs$cst$3136$app_DOT_main_DOT_data_DOT_changes_SLASH_apply_changes_localy$$=new $APP.$cljs$core$Keyword$$("app.main.data.changes","apply-changes-localy","app.main.data.changes/apply-changes-localy",71562413);$APP.$cljs$cst$1520$b$$=new $APP.$cljs$core$Keyword$$(null,"b","b",1482224470);$cljs$cst$1449$e$$=new $APP.$cljs$core$Keyword$$(null,"e","e",1381269198);$cljs$cst$1447$d$$=new $APP.$cljs$core$Keyword$$(null,"d","d",1972142424);
$APP.$cljs$cst$1102$_$$=new $APP.$cljs$core$Keyword$$(null,"_","_",1453416199);$cljs$cst$1804$change_property$$=new $APP.$cljs$core$Keyword$$(null,"change-property","change-property",271308648);$APP.$cljs$cst$1519$a$$=new $APP.$cljs$core$Keyword$$(null,"a","a",-2123407586);$cljs$cst$711$_EQ_$$=new $APP.$cljs$core$Keyword$$(null,"\x3d","\x3d",1152933628);$cljs$cst$709$_LT_$$=new $APP.$cljs$core$Keyword$$(null,"\x3c","\x3c",-646864291);
$APP.$cljs$cst$5242$all_frames$$=new $APP.$cljs$core$Keyword$$(null,"all-frames","all-frames",-524337179);$APP.$cljs$cst$744$host$$=new $APP.$cljs$core$Keyword$$(null,"host","host",-1558485167);$APP.$cljs$cst$2336$app_DOT_main_DOT_data_DOT_event_SLASH_event$$=new $APP.$cljs$core$Keyword$$("app.main.data.event","event","app.main.data.event/event",-1765150124);$cljs$cst$4879$stop_measure$$=new $APP.$cljs$core$Keyword$$(null,"stop-measure","stop-measure",-977043491);
$APP.$cljs$cst$4837$copy_link$$=new $APP.$cljs$core$Keyword$$(null,"copy-link","copy-link",-2059434674);$cljs$cst$715$_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"?","?",-1703165233);$APP.$cljs$cst$1545$operation_aborted$$=new $APP.$cljs$core$Keyword$$(null,"operation-aborted","operation-aborted",-860372392);$cljs$cst$160$let_STAR_$$=new $APP.$cljs$core$Symbol$$(null,"let*","let*",1920721458,null);$cljs$cst$707$_GT_$$=new $APP.$cljs$core$Keyword$$(null,"\x3e","\x3e",-555517146);
$APP.$cljs$cst$4091$flex_wrap$$=new $APP.$cljs$core$Keyword$$(null,"flex-wrap","flex-wrap",455413707);$cljs$cst$151$try$$=new $APP.$cljs$core$Symbol$$(null,"try","try",-1273693247,null);$cljs$cst$5323$copy_data$$=new $APP.$cljs$core$Keyword$$(null,"copy-data","copy-data",-320904302);$cljs$cst$713$_PLUS_$$=new $APP.$cljs$core$Keyword$$(null,"+","+",1913524883);$cljs$cst$714$_STAR_$$=new $APP.$cljs$core$Keyword$$(null,"*","*",-1294732318);
$cljs$cst$3846$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_apply_modifiers_STAR_$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.modifiers","apply-modifiers*","app.main.data.workspace.modifiers/apply-modifiers*",1001902394);$cljs$cst$4194$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_curve_SLASH_points$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.drawing.curve","points","app.main.data.workspace.drawing.curve/points",1859601459);
$APP.$cljs$cst$1478$private$$=new $APP.$cljs$core$Keyword$$(null,"private","private",-558947994);$APP.$cljs$cst$4622$shadow_key$$=new $APP.$cljs$core$Keyword$$(null,"shadow-key","shadow-key",-1799237015);$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","op","cljs.spec.alpha/op",-1269055252);$cljs$cst$5098$on_submit$$=new $APP.$cljs$core$Keyword$$(null,"on-submit","on-submit",1227871159);
$cljs$cst$4464$app_DOT_main_DOT_data_DOT_workspace_SLASH_fetch_bundle$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","fetch-bundle","app.main.data.workspace/fetch-bundle",1704636394);$cljs$cst$5182$component_id_mismatch$$=new $APP.$cljs$core$Keyword$$(null,"component-id-mismatch","component-id-mismatch",-239216999);$APP.$cljs$cst$4295$highlighted$$=new $APP.$cljs$core$Keyword$$(null,"highlighted","highlighted",1723498733);
$cljs$cst$2168$interrupt_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"interrupt?","interrupt?",275320536);$cljs$cst$2975$font_url$$=new $APP.$cljs$core$Keyword$$(null,"font-url","font-url",253222612);$APP.$cljs$cst$4108$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_css_nested$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","copy-selected-css-nested","app.main.data.workspace.clipboard/copy-selected-css-nested",-783228551);
$APP.$cljs$cst$3437$content_size$$=new $APP.$cljs$core$Keyword$$(null,"content-size","content-size",-78683431);$APP.$cljs$cst$3257$organization_name$$=new $APP.$cljs$core$Keyword$$(null,"organization-name","organization-name",1335899468);$cljs$cst$3194$app_DOT_main_DOT_data_DOT_media_SLASH_media_upload$$=new $APP.$cljs$core$Keyword$$("app.main.data.media","media-upload","app.main.data.media/media-upload",1206899563);
$cljs$cst$3056$simple_selection$$=new $APP.$cljs$core$Keyword$$(null,"simple-selection","simple-selection",1793712036);$APP.$cljs$cst$4136$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_pick_color_select$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.colors","pick-color-select","app.main.data.workspace.colors/pick-color-select",545436544);$APP.$cljs$cst$1993$attributes$$=new $APP.$cljs$core$Keyword$$(null,"attributes","attributes",-74013604);
$cljs$cst$3600$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","select-shapes","app.main.data.workspace.selection/select-shapes",1502749611);$APP.$cljs$cst$2149$shift$$=new $APP.$cljs$core$Keyword$$(null,"shift","shift",997140064);$APP.$cljs$cst$3059$layout_content_bounds$$=new $APP.$cljs$core$Keyword$$(null,"layout-content-bounds","layout-content-bounds",-1216447768);
$APP.$cljs$cst$4655$all_attributes$$=new $APP.$cljs$core$Keyword$$(null,"all-attributes","all-attributes",-1495901763);$cljs$cst$4466$app_DOT_main_DOT_data_DOT_workspace_SLASH_initialize_workspace$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","initialize-workspace","app.main.data.workspace/initialize-workspace",401698955);$cljs$cst$4052$padding_block_start$$=new $APP.$cljs$core$Keyword$$(null,"padding-block-start","padding-block-start",1054404612);
$APP.$cljs$cst$3282$get_team_stats$$=new $APP.$cljs$core$Keyword$$(null,"get-team-stats","get-team-stats",253209389);$APP.$cljs$cst$1681$row_gap$$=new $APP.$cljs$core$Keyword$$(null,"row-gap","row-gap",-1809905537);$APP.$cljs$cst$3128$public_uri$$=new $APP.$cljs$core$Keyword$$(null,"public-uri","public-uri",-1456511719);$cljs$cst$3465$get_unread_comment_threads$$=new $APP.$cljs$core$Keyword$$(null,"get-unread-comment-threads","get-unread-comment-threads",1878932620);
$cljs$cst$3557$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_common_SLASH_finish_path$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.path.common","finish-path","app.main.data.workspace.path.common/finish-path",-1299126936);$APP.$cljs$cst$2687$hex$$=new $APP.$cljs$core$Keyword$$(null,"hex","hex",41691346);$APP.$cljs$cst$4601$error_SLASH_unknown$$=new $APP.$cljs$core$Keyword$$("error","unknown","error/unknown",-848619937);
$APP.$cljs$cst$1924$content_modifiers$$=new $APP.$cljs$core$Keyword$$(null,"content-modifiers","content-modifiers",158766480);$APP.$cljs$cst$2137$workspace_tokens$$=new $APP.$cljs$core$Keyword$$(null,"workspace-tokens","workspace-tokens",-15136920);$cljs$cst$2548$main_instance_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"main-instance?","main-instance?",-1502113126);$APP.$cljs$cst$1365$parent$$=new $APP.$cljs$core$Keyword$$(null,"parent","parent",-878878779);
$APP.$cljs$cst$2330$app_DOT_main_DOT_data_DOT_profile_SLASH_logout$$=new $APP.$cljs$core$Keyword$$("app.main.data.profile","logout","app.main.data.profile/logout",-280567330);$cljs$cst$2850$externalResourcesRequired$$=new $APP.$cljs$core$Keyword$$(null,"externalResourcesRequired","externalResourcesRequired",111334837);
$cljs$cst$3455$app_DOT_main_DOT_data_DOT_comments_SLASH_delete_comment$$=new $APP.$cljs$core$Keyword$$("app.main.data.comments","delete-comment","app.main.data.comments/delete-comment",-938163211);$cljs$cst$1453$clauses$$=new $APP.$cljs$core$Keyword$$(null,"clauses","clauses",1454841241);$APP.$cljs$cst$2087$bottom_frames_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"bottom-frames?","bottom-frames?",1381369412);
$APP.$cljs$cst$1609$masked_group$$=new $APP.$cljs$core$Keyword$$(null,"masked-group","masked-group",1899947873);$cljs$cst$2301$screen_orientation$$=new $APP.$cljs$core$Keyword$$(null,"screen-orientation","screen-orientation",-1569291418);$APP.$cljs$cst$3129$build_data$$=new $APP.$cljs$core$Keyword$$(null,"build-data","build-data",980428267);$APP.$cljs$cst$2458$app_DOT_main_DOT_router_SLASH_window_name$$=new $APP.$cljs$core$Keyword$$("app.main.router","window-name","app.main.router/window-name",321663835);
$cljs$cst$3936$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_detach_selected_components$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.libraries","detach-selected-components","app.main.data.workspace.libraries/detach-selected-components",952152488);
$cljs$cst$4114$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_transit_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.clipboard","paste-transit-shapes","app.main.data.workspace.clipboard/paste-transit-shapes",-1375295342);$cljs$cst$4282$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_navigate_to_comment$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.comments","navigate-to-comment","app.main.data.workspace.comments/navigate-to-comment",1412820367);
$cljs$cst$3570$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_reset_undo$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.undo","reset-undo","app.main.data.workspace.undo/reset-undo",963720812);$APP.$cljs$cst$3612$duplicated$$=new $APP.$cljs$core$Keyword$$(null,"duplicated","duplicated",1960480511);$APP.$cljs$cst$411$compile$$=new $APP.$cljs$core$Keyword$$(null,"compile","compile",608186429);
$cljs$cst$2591$with_context_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"with-context?","with-context?",-56752853);$APP.$cljs$cst$2117$parent_path$$=new $APP.$cljs$core$Keyword$$(null,"parent-path","parent-path",-2115866866);$APP.$cljs$cst$4927$menu_open$$=new $APP.$cljs$core$Keyword$$(null,"menu-open","menu-open",1430293295);$cljs$cst$762$duplicates$$=new $APP.$cljs$core$Keyword$$(null,"duplicates","duplicates",1265485699);
$APP.$cljs$cst$522$maybe$$=new $APP.$cljs$core$Keyword$$(null,"maybe","maybe",-314397560);$cljs$cst$4775$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_retry_last_export$$=new $APP.$cljs$core$Keyword$$("app.main.data.exports.assets","retry-last-export","app.main.data.exports.assets/retry-last-export",56700563);$APP.$cljs$cst$3419$hleft$$=new $APP.$cljs$core$Keyword$$(null,"hleft","hleft",1814954288);$APP.$cljs$cst$215$character$$=new $APP.$cljs$core$Keyword$$(null,"character","character",380652989);
$APP.$cljs$cst$3496$get_font_variants$$=new $APP.$cljs$core$Keyword$$(null,"get-font-variants","get-font-variants",-135164076);$APP.$cljs$cst$2684$distance$$=new $APP.$cljs$core$Keyword$$(null,"distance","distance",-1671893894);$APP.$cljs$cst$2496$default_team_id$$=new $APP.$cljs$core$Keyword$$(null,"default-team-id","default-team-id",1198639706);
$APP.$cljs$cst$4539$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_layers_search_scope$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace","update-layers-search-scope","app.main.data.workspace/update-layers-search-scope",-1700607136);$APP.$cljs$cst$3518$editing_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"editing?","editing?",1646440800);
$APP.$cljs$cst$5046$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_apply_snapshot_data$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.versions","apply-snapshot-data","app.main.data.workspace.versions/apply-snapshot-data",-1015144018);$cljs$cst$1032$cljs_DOT_core_SLASH__EQ_$$=new $APP.$cljs$core$Symbol$$("cljs.core","\x3d","cljs.core/\x3d",-1891498332,null);
$cljs$cst$3626$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_update_focus_shapes$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.selection","update-focus-shapes","app.main.data.workspace.selection/update-focus-shapes",1662876450);$cljs$cst$2753$gradientUnits$$=new $APP.$cljs$core$Keyword$$(null,"gradientUnits","gradientUnits",-198536416);$APP.$cljs$cst$3137$undo_changes$$=new $APP.$cljs$core$Keyword$$(null,"undo-changes","undo-changes",794837692);
$cljs$cst$3762$app_DOT_main_DOT_data_DOT_workspace_DOT_groups_SLASH_unmask_group$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.groups","unmask-group","app.main.data.workspace.groups/unmask-group",487219487);$APP.$cljs$cst$5148$organizations$$=new $APP.$cljs$core$Keyword$$(null,"organizations","organizations",-755443762);$APP.$cljs$cst$3693$local_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"local?","local?",-1422786101);
$cljs$cst$3753$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_show_toolbar$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.common","show-toolbar","app.main.data.workspace.common/show-toolbar",-1535177689);$cljs$cst$977$cljs_DOT_spec_DOT_alpha_SLASH_unknown$$=new $APP.$cljs$core$Keyword$$("cljs.spec.alpha","unknown","cljs.spec.alpha/unknown",651034818);$cljs$cst$1505$locking$$=new $APP.$cljs$core$Symbol$$(null,"locking","locking",1542862874,null);
$cljs$cst$4015$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_attrs$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.texts","update-text-attrs","app.main.data.workspace.texts/update-text-attrs",-962056551);$cljs$cst$3267$app_DOT_main_DOT_data_DOT_team_SLASH_invitations_fetched$$=new $APP.$cljs$core$Keyword$$("app.main.data.team","invitations-fetched","app.main.data.team/invitations-fetched",1121972002);
$cljs$cst$3270$get_team_invitations$$=new $APP.$cljs$core$Keyword$$(null,"get-team-invitations","get-team-invitations",382367407);$APP.$cljs$cst$4878$align_bottom$$=new $APP.$cljs$core$Keyword$$(null,"align-bottom","align-bottom",612864893);$cljs$cst$3023$arabic$$=new $APP.$cljs$core$Keyword$$(null,"arabic","arabic",-561980419);$APP.$cljs$cst$6301$plugin_url$$=new $APP.$cljs$core$Keyword$$(null,"plugin-url","plugin-url",1542869449);
$APP.$cljs$cst$3394$naturalChildOrdering$$=new $APP.$cljs$core$Keyword$$(null,"naturalChildOrdering","naturalChildOrdering",-1223123419);$cljs$cst$2253$request_body_too_large$$=new $APP.$cljs$core$Keyword$$(null,"request-body-too-large","request-body-too-large",158334);$APP.$cljs$cst$2509$settings_feedback$$=new $APP.$cljs$core$Keyword$$(null,"settings-feedback","settings-feedback",-1884878904);
$APP.$cljs$cst$1769$text_transform$$=new $APP.$cljs$core$Keyword$$(null,"text-transform","text-transform",1685000676);$APP.$cljs$cst$3405$app_DOT_main_DOT_data_DOT_plugins_SLASH_delay_open_plugin$$=new $APP.$cljs$core$Keyword$$("app.main.data.plugins","delay-open-plugin","app.main.data.plugins/delay-open-plugin",-1762960152);
$cljs$cst$4307$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_remove_interaction$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.interactions","remove-interaction","app.main.data.workspace.interactions/remove-interaction",-171927642);$cljs$cst$2789$filterUnits$$=new $APP.$cljs$core$Keyword$$(null,"filterUnits","filterUnits",-1278010713);$cljs$cst$2569$paste_feature_not_supported$$=new $APP.$cljs$core$Keyword$$(null,"paste-feature-not-supported","paste-feature-not-supported",-204919938);
$APP.$cljs$cst$4384$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_add_to_selection$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid-layout.editor","add-to-selection","app.main.data.workspace.grid-layout.editor/add-to-selection",1344621079);$cljs$cst$5186$shape_ref_in_main$$=new $APP.$cljs$core$Keyword$$(null,"shape-ref-in-main","shape-ref-in-main",-671464993);$cljs$cst$3031$span$$=new $APP.$cljs$core$Keyword$$(null,"span","span",1394872991);
$cljs$cst$2790$pathLength$$=new $APP.$cljs$core$Keyword$$(null,"pathLength","pathLength",1753740967);$cljs$cst$1265$enable_inspect_styles$$=new $APP.$cljs$core$Keyword$$(null,"enable-inspect-styles","enable-inspect-styles",-1223000996);$APP.$cljs$cst$1957$dissolve$$=new $APP.$cljs$core$Keyword$$(null,"dissolve","dissolve",-629896345);$APP.$cljs$cst$2235$zoom_type$$=new $APP.$cljs$core$Keyword$$(null,"zoom-type","zoom-type",-1936775769);
$cljs$cst$3005$devanagari$$=new $APP.$cljs$core$Keyword$$(null,"devanagari","devanagari",737012815);$APP.$cljs$cst$888$locale$$=new $APP.$cljs$core$Keyword$$(null,"locale","locale",-2115712697);$cljs$cst$1255$enable_backend_worker$$=new $APP.$cljs$core$Keyword$$(null,"enable-backend-worker","enable-backend-worker",-317104993);$cljs$cst$2283$app_DOT_main_DOT_repo_SLASH_multipart_upload$$=new $APP.$cljs$core$Keyword$$("app.main.repo","multipart-upload","app.main.repo/multipart-upload",350994081);
$APP.$cljs$cst$3784$skip_children$$=new $APP.$cljs$core$Keyword$$(null,"skip-children","skip-children",1139347942);$cljs$cst$864$malli_DOT_generator_SLASH_such_that_failure$$=new $APP.$cljs$core$Keyword$$("malli.generator","such-that-failure","malli.generator/such-that-failure",599634585);$cljs$cst$2491$app_DOT_main_DOT_data_DOT_common_SLASH_change_team_role$$=new $APP.$cljs$core$Keyword$$("app.main.data.common","change-team-role","app.main.data.common/change-team-role",-688549173);
$cljs$cst$2766$hanging$$=new $APP.$cljs$core$Keyword$$(null,"hanging","hanging",1618688322);$APP.$cljs$cst$5359$cancel_at$$=new $APP.$cljs$core$Keyword$$(null,"cancel-at","cancel-at",-1326093135);$cljs$cst$2813$vert_origin_x$$=new $APP.$cljs$core$Keyword$$(null,"vert-origin-x","vert-origin-x",1437952844);$APP.$cljs$cst$4249$moving_handler$$=new $APP.$cljs$core$Keyword$$(null,"moving-handler","moving-handler",-188315359);var $clojure$$;$clojure$$={};$APP.$clojure$string$join$$=function $clojure$string$join$$($var_args$jscomp$309$$){switch(arguments.length){case 1:return $clojure$string$join$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$1$=function($G__24307_coll$jscomp$817_coll__$1$jscomp$453$$){var $G__24306_sb$jscomp$10$$=new $APP.$goog$string$StringBuffer$$;for($G__24307_coll$jscomp$817_coll__$1$jscomp$453$$=$APP.$cljs$core$seq$$($G__24307_coll$jscomp$817_coll__$1$jscomp$453$$);;)if($G__24307_coll$jscomp$817_coll__$1$jscomp$453$$!=null)$G__24306_sb$jscomp$10$$=$G__24306_sb$jscomp$10$$.append($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($G__24307_coll$jscomp$817_coll__$1$jscomp$453$$))),
$G__24307_coll$jscomp$817_coll__$1$jscomp$453$$=$APP.$cljs$core$next$$($G__24307_coll$jscomp$817_coll__$1$jscomp$453$$);else return $G__24306_sb$jscomp$10$$.toString()};
$APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$=function($separator$jscomp$2$$,$coll$jscomp$818_coll__$1$jscomp$454_coll__$2$jscomp$1$$){var $sb$jscomp$11$$=new $APP.$goog$string$StringBuffer$$;for($coll$jscomp$818_coll__$1$jscomp$454_coll__$2$jscomp$1$$=$APP.$cljs$core$seq$$($coll$jscomp$818_coll__$1$jscomp$454_coll__$2$jscomp$1$$);;)if($coll$jscomp$818_coll__$1$jscomp$454_coll__$2$jscomp$1$$!=null)$sb$jscomp$11$$.append($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($coll$jscomp$818_coll__$1$jscomp$454_coll__$2$jscomp$1$$))),
$coll$jscomp$818_coll__$1$jscomp$454_coll__$2$jscomp$1$$=$APP.$cljs$core$next$$($coll$jscomp$818_coll__$1$jscomp$454_coll__$2$jscomp$1$$),$coll$jscomp$818_coll__$1$jscomp$454_coll__$2$jscomp$1$$!=null&&$sb$jscomp$11$$.append($separator$jscomp$2$$);else return $sb$jscomp$11$$.toString()};$APP.$clojure$string$join$$.$cljs$lang$maxFixedArity$=2;var $cljs$tools$reader$impl$utils$ws_rx$$;$cljs$tools$reader$impl$utils$ws_rx$$=/[\s]/;$APP.$cljs$tools$reader$impl$utils$last_id$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(0);$APP.$cljs$tools$reader$reader_types$StringReader$$.prototype.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$=function(){if(this.$s_len$>this.$s_pos$){var $r$jscomp$31$$=this.s.charAt(this.$s_pos$);this.$s_pos$+=1;return $r$jscomp$31$$}return null};$APP.$cljs$tools$reader$reader_types$StringReader$$.prototype.$cljs$tools$reader$reader_types$Reader$peek_char$arity$1$=function(){return this.$s_len$>this.$s_pos$?this.s.charAt(this.$s_pos$):null};
$APP.$cljs$tools$reader$reader_types$PushbackReader$$.prototype.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$=function(){var $c$jscomp$138$$=this.$buf_pos$<this.$buf_len$?this.$buf$[this.$buf_pos$]:this.$rdr$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);this.$buf_pos$<this.$buf_len$&&(this.$buf_pos$+=1);return $APP.$cljs$tools$reader$impl$utils$char$0$$($c$jscomp$138$$)};
$APP.$cljs$tools$reader$reader_types$PushbackReader$$.prototype.$cljs$tools$reader$reader_types$Reader$peek_char$arity$1$=function(){var $c$jscomp$139$$=this.$buf_pos$<this.$buf_len$?this.$buf$[this.$buf_pos$]:this.$rdr$.$cljs$tools$reader$reader_types$Reader$peek_char$arity$1$(null);return $APP.$cljs$tools$reader$impl$utils$char$0$$($c$jscomp$139$$)};
$APP.$cljs$tools$reader$reader_types$PushbackReader$$.prototype.$cljs$tools$reader$reader_types$IPushbackReader$unread$arity$2$=function($reader$jscomp$18$$,$ch$jscomp$12$$){if($APP.$cljs$core$truth_$$($ch$jscomp$12$$)){if(this.$buf_pos$===0)throw Error("Pushback buffer is full");--this.$buf_pos$;return this.$buf$[this.$buf_pos$]=$ch$jscomp$12$$}return null};var $cljs$tools$reader$impl$inspect$inspect_STAR_$$,$method_table__5622__auto__$jscomp$inline_11333$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$inline_11334$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$inline_11335$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),
$cached_hierarchy__5625__auto__$jscomp$inline_11336$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$inline_11337$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());
$cljs$tools$reader$impl$inspect$inspect_STAR_$$=new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("cljs.tools.reader.impl.inspect","inspect*"),function($_$jscomp$163$$,$x$jscomp$657$$){return $x$jscomp$657$$==null?$cljs$cst$197$nil$$:typeof $x$jscomp$657$$==="string"?$APP.$cljs$cst$198$string$$:$x$jscomp$657$$ instanceof $APP.$cljs$core$Keyword$$?$cljs$cst$199$strable$$:typeof $x$jscomp$657$$==="number"?$cljs$cst$199$strable$$:$x$jscomp$657$$ instanceof $APP.$cljs$core$Symbol$$?
$cljs$cst$199$strable$$:$APP.$cljs$core$vector_QMARK_$$($x$jscomp$657$$)?$APP.$cljs$cst$200$vector$$:$APP.$cljs$core$list_QMARK_$$($x$jscomp$657$$)?$APP.$cljs$cst$201$list$$:$APP.$cljs$core$map_QMARK_$$($x$jscomp$657$$)?$APP.$cljs$cst$202$map$$:$APP.$cljs$core$set_QMARK_$$($x$jscomp$657$$)?$APP.$cljs$cst$203$set$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$657$$,!0)?$cljs$cst$199$strable$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$657$$,!1)?$cljs$cst$199$strable$$:
$APP.$cljs$core$type$$($x$jscomp$657$$)},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$inline_11337$$,$method_table__5622__auto__$jscomp$inline_11333$$,$prefer_table__5623__auto__$jscomp$inline_11334$$,$method_cache__5624__auto__$jscomp$inline_11335$$,$cached_hierarchy__5625__auto__$jscomp$inline_11336$$);
$cljs$tools$reader$impl$inspect$inspect_STAR_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$198$string$$,function($n$jscomp$171_truncate$jscomp$1$$,$x$jscomp$658$$){$n$jscomp$171_truncate$jscomp$1$$=$APP.$cljs$core$truth_$$($n$jscomp$171_truncate$jscomp$1$$)?5:20;var $suffix$jscomp$3$$=$x$jscomp$658$$.length>$n$jscomp$171_truncate$jscomp$1$$?'..."':'"',$y__5114__auto__$jscomp$inline_3028$$=$x$jscomp$658$$.length;return['"',$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$658$$.substring(0,
$n$jscomp$171_truncate$jscomp$1$$<$y__5114__auto__$jscomp$inline_3028$$?$n$jscomp$171_truncate$jscomp$1$$:$y__5114__auto__$jscomp$inline_3028$$)),$suffix$jscomp$3$$].join("")});$cljs$tools$reader$impl$inspect$inspect_STAR_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$199$strable$$,function($truncate$jscomp$2$$,$x$jscomp$659$$){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$659$$)});
$cljs$tools$reader$impl$inspect$inspect_STAR_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$core$IndexedSeq$$,function(){return"\x3cindexed seq\x3e"});$cljs$tools$reader$impl$inspect$inspect_STAR_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$core$PersistentArrayMapSeq$$,function(){return"\x3cmap seq\x3e"});$cljs$tools$reader$impl$inspect$inspect_STAR_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$core$NodeSeq$$,function(){return"\x3cmap seq\x3e"});
$cljs$tools$reader$impl$inspect$inspect_STAR_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$core$Cons$$,function(){return"\x3ccons\x3e"});$cljs$tools$reader$impl$inspect$inspect_STAR_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$core$LazySeq$$,function(){return"\x3clazy seq\x3e"});$cljs$tools$reader$impl$inspect$inspect_STAR_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$197$nil$$,function(){return"nil"});
$cljs$tools$reader$impl$inspect$inspect_STAR_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$201$list$$,function($truncate$jscomp$8$$,$col$jscomp$14$$){return $cljs$tools$reader$impl$inspect$inspect_STAR__col$$($truncate$jscomp$8$$,$col$jscomp$14$$,"(",")")});
$cljs$tools$reader$impl$inspect$inspect_STAR_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$202$map$$,function($truncate$jscomp$9$$,$contents$jscomp$11_m$jscomp$75$$){var $len$jscomp$53$$=$APP.$cljs$core$count$$($contents$jscomp$11_m$jscomp$75$$),$n_shown$$=$APP.$cljs$core$truth_$$($truncate$jscomp$9$$)?0:$len$jscomp$53$$;$contents$jscomp$11_m$jscomp$75$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($n_shown$$,
$contents$jscomp$11_m$jscomp$75$$));return $cljs$tools$reader$impl$inspect$inspect_STAR__col$$($truncate$jscomp$9$$,$contents$jscomp$11_m$jscomp$75$$,"{",$len$jscomp$53$$>$n_shown$$?"...}":"}")});$cljs$tools$reader$impl$inspect$inspect_STAR_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$203$set$$,function($truncate$jscomp$10$$,$col$jscomp$15$$){return $cljs$tools$reader$impl$inspect$inspect_STAR__col$$($truncate$jscomp$10$$,$col$jscomp$15$$,"#{","}")});
$cljs$tools$reader$impl$inspect$inspect_STAR_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$200$vector$$,function($truncate$jscomp$11$$,$col$jscomp$16$$){return $cljs$tools$reader$impl$inspect$inspect_STAR__col$$($truncate$jscomp$11$$,$col$jscomp$16$$,"[","]")});$cljs$tools$reader$impl$inspect$inspect_STAR_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function($truncate$jscomp$12$$,$x$jscomp$665$$){return $APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$type$$($x$jscomp$665$$)]))});var $cljs$tools$reader$impl$commons$int_pattern$$,$cljs$tools$reader$impl$commons$ratio_pattern$$,$cljs$tools$reader$impl$commons$float_pattern$$;$cljs$tools$reader$impl$commons$int_pattern$$=/^([-+]?)(?:(0)|([1-9][0-9]*)|0[xX]([0-9A-Fa-f]+)|0([0-7]+)|([1-9][0-9]?)[rR]([0-9A-Za-z]+)|0[0-9]+)(N)?$/;$cljs$tools$reader$impl$commons$ratio_pattern$$=/([-+]?[0-9]+)\/([0-9]+)/;$cljs$tools$reader$impl$commons$float_pattern$$=/([-+]?[0-9]+(\.[0-9]*)?([eE][-+]?[0-9]+)?)(M)?/;
$APP.$cljs$tools$reader$impl$commons$read_comment$$=function $cljs$tools$reader$impl$commons$read_comment$$($var_args$jscomp$323$$){for(var $args__5755__auto__$jscomp$30$$=[],$len__5749__auto___24575$$=arguments.length,$i__5750__auto___24576$$=0;;)if($i__5750__auto___24576$$<$len__5749__auto___24575$$)$args__5755__auto__$jscomp$30$$.push(arguments[$i__5750__auto___24576$$]),$i__5750__auto___24576$$+=1;else break;return $cljs$tools$reader$impl$commons$read_comment$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],
1<$args__5755__auto__$jscomp$30$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$30$$.slice(1),0,null):null)};$APP.$cljs$tools$reader$impl$commons$read_comment$$.$cljs$core$IFn$_invoke$arity$variadic$=function($rdr$jscomp$49$$){for(;;){var $c$jscomp$inline_11346$$=$rdr$jscomp$49$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);if("\n"===$c$jscomp$inline_11346$$||"\n"===$c$jscomp$inline_11346$$||$c$jscomp$inline_11346$$==null)break}return $rdr$jscomp$49$$};
$APP.$cljs$tools$reader$impl$commons$read_comment$$.$cljs$lang$maxFixedArity$=1;$APP.$cljs$tools$reader$impl$commons$read_comment$$.$cljs$lang$applyTo$=function($seq24536_seq24536__$1$$){var $G__24537$$=$APP.$cljs$core$first$$($seq24536_seq24536__$1$$);$seq24536_seq24536__$1$$=$APP.$cljs$core$next$$($seq24536_seq24536__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__24537$$,$seq24536_seq24536__$1$$)};$APP.$cljs$tools$reader$sb$$=new $APP.$goog$string$StringBuffer$$;$APP.$cljs$tools$reader$RESERVED_FEATURES$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$225$else$$,null,$APP.$cljs$cst$226$none$$,null],null),null);$APP.$cljs$tools$reader$_STAR_data_readers_STAR_$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;$APP.$cljs$tools$reader$default_data_readers$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;var $cljs$reader$days_in_month$$=function(){var $dim_norm$$=new $APP.$cljs$core$PersistentVector$$(null,13,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,31,28,31,30,31,30,31,31,30,31,30,31],null),$dim_leap$$=new $APP.$cljs$core$PersistentVector$$(null,13,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,31,29,31,30,31,30,31,31,30,31,30,31],null);return function($month$$,$leap_year_QMARK_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($leap_year_QMARK_$$)?
$dim_leap$$:$dim_norm$$,$month$$)}}(),$cljs$reader$timestamp_regex$$=/(\d\d\d\d)(?:-(\d\d)(?:-(\d\d)(?:[T](\d\d)(?::(\d\d)(?::(\d\d)(?:[.](\d+))?)?)?)?)?)?(?:[Z]|([-+])(\d\d):(\d\d))?/,$cljs$reader$_STAR_default_data_reader_fn_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$cljs$reader$_STAR_tag_table_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$cljs$cst$251$inst$$,function($s$jscomp$186_years$jscomp$inline_3074$$){if(typeof $s$jscomp$186_years$jscomp$inline_3074$$==="string"){var $JSCompiler_inline_result$jscomp$276_offset$jscomp$inline_3081_temp__5823__auto__$jscomp$inline_3073$$=$cljs$reader$parse_and_validate_timestamp$$($s$jscomp$186_years$jscomp$inline_3074$$);if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$276_offset$jscomp$inline_3081_temp__5823__auto__$jscomp$inline_3073$$)){$s$jscomp$186_years$jscomp$inline_3074$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$276_offset$jscomp$inline_3081_temp__5823__auto__$jscomp$inline_3073$$,0,null);var $months$jscomp$inline_3075$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$276_offset$jscomp$inline_3081_temp__5823__auto__$jscomp$inline_3073$$,1,null),$days$jscomp$inline_3076$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$276_offset$jscomp$inline_3081_temp__5823__auto__$jscomp$inline_3073$$,
2,null),$hours$jscomp$inline_3077$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$276_offset$jscomp$inline_3081_temp__5823__auto__$jscomp$inline_3073$$,3,null),$minutes$jscomp$inline_3078$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$276_offset$jscomp$inline_3081_temp__5823__auto__$jscomp$inline_3073$$,4,null),$seconds$jscomp$inline_3079$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$276_offset$jscomp$inline_3081_temp__5823__auto__$jscomp$inline_3073$$,
5,null),$ms$jscomp$inline_3080$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$276_offset$jscomp$inline_3081_temp__5823__auto__$jscomp$inline_3073$$,6,null);$JSCompiler_inline_result$jscomp$276_offset$jscomp$inline_3081_temp__5823__auto__$jscomp$inline_3073$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$276_offset$jscomp$inline_3081_temp__5823__auto__$jscomp$inline_3073$$,7,null);$JSCompiler_inline_result$jscomp$276_offset$jscomp$inline_3081_temp__5823__auto__$jscomp$inline_3073$$=
new Date(Date.UTC($s$jscomp$186_years$jscomp$inline_3074$$,$months$jscomp$inline_3075$$-1,$days$jscomp$inline_3076$$,$hours$jscomp$inline_3077$$,$minutes$jscomp$inline_3078$$,$seconds$jscomp$inline_3079$$,$ms$jscomp$inline_3080$$)-$JSCompiler_inline_result$jscomp$276_offset$jscomp$inline_3081_temp__5823__auto__$jscomp$inline_3073$$*60*1E3)}else throw Error(["Unrecognized date/time syntax: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$186_years$jscomp$inline_3074$$)].join(""));
return $JSCompiler_inline_result$jscomp$276_offset$jscomp$inline_3081_temp__5823__auto__$jscomp$inline_3073$$}throw Error("Instance literal expects a string for its timestamp.");},$cljs$cst$138$uuid$$,function($uuid$jscomp$2$$){if(typeof $uuid$jscomp$2$$==="string")return $APP.$cljs$core$uuid$$($uuid$jscomp$2$$);throw Error("UUID literal expects a string as its representation.");},$cljs$cst$252$queue$$,function($elems$$){if($APP.$cljs$core$vector_QMARK_$$($elems$$))return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentQueue$EMPTY$$,
$elems$$);throw Error("Queue literal expects a vector for its elements.");},$cljs$cst$253$js$$,function($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$){if($APP.$cljs$core$vector_QMARK_$$($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$)){var $arr$jscomp$136_obj$jscomp$105$$=
[];$G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$=$APP.$cljs$core$seq$$($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$);for(var $G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$=null,$G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$=
0,$G__25726_i__25579_25708_i__25623_25747_obj$jscomp$inline_3087$$=0;;)if($G__25726_i__25579_25708_i__25623_25747_obj$jscomp$inline_3087$$<$G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$){var $k_25749_key$jscomp$inline_3084_x_25710$$=$G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__25726_i__25579_25708_i__25623_25747_obj$jscomp$inline_3087$$);
$arr$jscomp$136_obj$jscomp$105$$.push($k_25749_key$jscomp$inline_3084_x_25710$$);$G__25726_i__25579_25708_i__25623_25747_obj$jscomp$inline_3087$$+=1}else if($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$=$APP.$cljs$core$seq$$($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$))$G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$=
$G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$)?($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$=$APP.$cljs$core$_chunked_first$$($G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$),
$G__25726_i__25579_25708_i__25623_25747_obj$jscomp$inline_3087$$=$APP.$cljs$core$_chunked_rest$$($G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$),$G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$=$G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$,$G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$=
$APP.$cljs$core$count$$($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$),$G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$=$G__25726_i__25579_25708_i__25623_25747_obj$jscomp$inline_3087$$):($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$=
$APP.$cljs$core$first$$($G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$),$arr$jscomp$136_obj$jscomp$105$$.push($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$),$G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$=$APP.$cljs$core$next$$($G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$),
$G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$=null,$G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$=0),$G__25726_i__25579_25708_i__25623_25747_obj$jscomp$inline_3087$$=0;else break;return $arr$jscomp$136_obj$jscomp$105$$}if($APP.$cljs$core$map_QMARK_$$($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$)){$arr$jscomp$136_obj$jscomp$105$$=
{};$G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$=$APP.$cljs$core$seq$$($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$);$G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$=null;for($G__25726_i__25579_25708_i__25623_25747_obj$jscomp$inline_3087$$=
$G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$=0;;)if($G__25726_i__25579_25708_i__25623_25747_obj$jscomp$inline_3087$$<$G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$){var $v_25750_vec__25631_25748$$=$G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__25726_i__25579_25708_i__25623_25747_obj$jscomp$inline_3087$$);
$k_25749_key$jscomp$inline_3084_x_25710$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v_25750_vec__25631_25748$$,0,null);$v_25750_vec__25631_25748$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v_25750_vec__25631_25748$$,1,null);var $obj$jscomp$inline_3083$$=$arr$jscomp$136_obj$jscomp$105$$;$k_25749_key$jscomp$inline_3084_x_25710$$=$APP.$cljs$core$name$$($k_25749_key$jscomp$inline_3084_x_25710$$);$obj$jscomp$inline_3083$$[$k_25749_key$jscomp$inline_3084_x_25710$$]=$v_25750_vec__25631_25748$$;
$G__25726_i__25579_25708_i__25623_25747_obj$jscomp$inline_3087$$+=1}else if($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$=$APP.$cljs$core$seq$$($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$)?
($G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$=$APP.$cljs$core$_chunked_first$$($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$),$G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$=$APP.$cljs$core$_chunked_rest$$($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$),
$G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$=$G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$,$G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$=$APP.$cljs$core$count$$($G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$)):($G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$=
$APP.$cljs$core$first$$($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$),$G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$,0,null),$G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$,1,null),$G__25726_i__25579_25708_i__25623_25747_obj$jscomp$inline_3087$$=$arr$jscomp$136_obj$jscomp$105$$,$G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$=$APP.$cljs$core$name$$($G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$),
$G__25726_i__25579_25708_i__25623_25747_obj$jscomp$inline_3087$$[$G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$]=$G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$,$G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$=$APP.$cljs$core$next$$($G__25758_c__5548__auto___25723_form$jscomp$23_seq__25576_25705_seq__25620_25744_seq__25620_25756__$1_temp__5825__auto___25721_temp__5825__auto___25755_x_25731$$),
$G__25727_G__25759_chunk__25577_25706_chunk__25621_25745_k_25763_key$jscomp$inline_3088_seq__25576_25722__$1$$=null,$G__25728_G__25760_c__5548__auto___25757_count__25578_25707_count__25622_25746_v_25764_vec__25641_25762$$=0),$G__25726_i__25579_25708_i__25623_25747_obj$jscomp$inline_3087$$=0;else break;return $arr$jscomp$136_obj$jscomp$105$$}throw Error("JS literal expects a vector or map containing only string or unqualified keyword keys");}],null),$APP.$cljs$core$PersistentArrayMap$EMPTY$$])));$APP.$app$common$math$PI$$=Math.PI;$APP.$app$common$math$round$$=function $app$common$math$round$$($var_args$jscomp$340$$){switch(arguments.length){case 2:return $app$common$math$round$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$2$=function($v$jscomp$98$$,$step$jscomp$25$$){return $APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$98$$/$step$jscomp$25$$)*$step$jscomp$25$$};$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$=function($v$jscomp$99$$){return Math.round($v$jscomp$99$$)};$APP.$app$common$math$round$$.$cljs$lang$maxFixedArity$=2;$APP.$clojure$set$union$$=function $clojure$set$union$$($var_args$jscomp$342$$){switch(arguments.length){case 0:return $clojure$set$union$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $clojure$set$union$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$66$$=[],$len__5749__auto___24305$$=arguments.length,$i__5750__auto___24308$$=0;;)if($i__5750__auto___24308$$<
$len__5749__auto___24305$$)$args_arr__5774__auto__$jscomp$66$$.push(arguments[$i__5750__auto___24308$$]),$i__5750__auto___24308$$+=1;else break;return $clojure$set$union$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$66$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$66$$.slice(2),0,null):null)}};$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$cljs$core$PersistentHashSet$EMPTY$$};
$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$1$=function($s1$jscomp$3$$){return $s1$jscomp$3$$};
$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$=function($s1$jscomp$4$$,$s2$jscomp$3$$){return $APP.$cljs$core$count$$($s1$jscomp$4$$)<$APP.$cljs$core$count$$($s2$jscomp$3$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$s2$jscomp$3$$,$s1$jscomp$4$$):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$s1$jscomp$4$$,$s2$jscomp$3$$)};
$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$variadic$=function($bubbled_sets_s1$jscomp$5$$,$s2$jscomp$4$$,$sets$$){$bubbled_sets_s1$jscomp$5$$=$clojure$set$bubble_max_key$$($APP.$cljs$core$count$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($sets$$,$s2$jscomp$4$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$bubbled_sets_s1$jscomp$5$$])));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$into$$,$APP.$cljs$core$first$$($bubbled_sets_s1$jscomp$5$$),
$APP.$cljs$core$rest$$($bubbled_sets_s1$jscomp$5$$))};
$APP.$clojure$set$union$$.$cljs$lang$applyTo$=function($G__24234_seq24232$$){var $G__24233$$=$APP.$cljs$core$first$$($G__24234_seq24232$$),$seq24232__$1_seq24232__$2$$=$APP.$cljs$core$next$$($G__24234_seq24232$$);$G__24234_seq24232$$=$APP.$cljs$core$first$$($seq24232__$1_seq24232__$2$$);$seq24232__$1_seq24232__$2$$=$APP.$cljs$core$next$$($seq24232__$1_seq24232__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__24233$$,$G__24234_seq24232$$,$seq24232__$1_seq24232__$2$$)};
$APP.$clojure$set$union$$.$cljs$lang$maxFixedArity$=2;
$APP.$clojure$set$intersection$$=function $clojure$set$intersection$$($var_args$jscomp$343$$){switch(arguments.length){case 1:return $clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$67$$=[],$len__5749__auto___24319$$=arguments.length,$i__5750__auto___24320$$=0;;)if($i__5750__auto___24320$$<$len__5749__auto___24319$$)$args_arr__5774__auto__$jscomp$67$$.push(arguments[$i__5750__auto___24320$$]),
$i__5750__auto___24320$$+=1;else break;return $clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$67$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$67$$.slice(2),0,null):null)}};$APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$1$=function($s1$jscomp$6$$){return $s1$jscomp$6$$};
$APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$=function($s1$jscomp$7$$,$s2$jscomp$5$$){for(;;)if($APP.$cljs$core$count$$($s2$jscomp$5$$)<$APP.$cljs$core$count$$($s1$jscomp$7$$)){var $G__24325$$=$s1$jscomp$7$$;$s1$jscomp$7$$=$s2$jscomp$5$$;$s2$jscomp$5$$=$G__24325$$}else return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($s1$jscomp$8$$,$s2$jscomp$6$$){return function($result$jscomp$82$$,$item$jscomp$23$$){return $APP.$cljs$core$contains_QMARK_$$($s2$jscomp$6$$,
$item$jscomp$23$$)?$result$jscomp$82$$:$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$82$$,$item$jscomp$23$$)}}($s1$jscomp$7$$,$s2$jscomp$5$$),$s1$jscomp$7$$,$s1$jscomp$7$$)};
$APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$variadic$=function($bubbled_sets$jscomp$1_s1$jscomp$9$$,$s2$jscomp$7$$,$sets$jscomp$1$$){$bubbled_sets$jscomp$1_s1$jscomp$9$$=$clojure$set$bubble_max_key$$(function($p1__24240_SHARP_$$){return-$APP.$cljs$core$count$$($p1__24240_SHARP_$$)},$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($sets$jscomp$1$$,$s2$jscomp$7$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$bubbled_sets$jscomp$1_s1$jscomp$9$$])));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$clojure$set$intersection$$,
$APP.$cljs$core$first$$($bubbled_sets$jscomp$1_s1$jscomp$9$$),$APP.$cljs$core$rest$$($bubbled_sets$jscomp$1_s1$jscomp$9$$))};
$APP.$clojure$set$intersection$$.$cljs$lang$applyTo$=function($G__24246_seq24244$$){var $G__24245$$=$APP.$cljs$core$first$$($G__24246_seq24244$$),$seq24244__$1_seq24244__$2$$=$APP.$cljs$core$next$$($G__24246_seq24244$$);$G__24246_seq24244$$=$APP.$cljs$core$first$$($seq24244__$1_seq24244__$2$$);$seq24244__$1_seq24244__$2$$=$APP.$cljs$core$next$$($seq24244__$1_seq24244__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__24245$$,$G__24246_seq24244$$,$seq24244__$1_seq24244__$2$$)};
$APP.$clojure$set$intersection$$.$cljs$lang$maxFixedArity$=2;
$APP.$clojure$set$difference$$=function $clojure$set$difference$$($var_args$jscomp$344$$){switch(arguments.length){case 1:return $clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$68$$=[],$len__5749__auto___24335$$=arguments.length,$i__5750__auto___24336$$=0;;)if($i__5750__auto___24336$$<$len__5749__auto___24335$$)$args_arr__5774__auto__$jscomp$68$$.push(arguments[$i__5750__auto___24336$$]),
$i__5750__auto___24336$$+=1;else break;return $clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$68$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$68$$.slice(2),0,null):null)}};$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$1$=function($s1$jscomp$10$$){return $s1$jscomp$10$$};
$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$=function($s1$jscomp$11$$,$s2$jscomp$8$$){return $APP.$cljs$core$count$$($s1$jscomp$11$$)<$APP.$cljs$core$count$$($s2$jscomp$8$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$83$$,$item$jscomp$24$$){return $APP.$cljs$core$contains_QMARK_$$($s2$jscomp$8$$,$item$jscomp$24$$)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$83$$,$item$jscomp$24$$):$result$jscomp$83$$},$s1$jscomp$11$$,
$s1$jscomp$11$$):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$disj$$,$s1$jscomp$11$$,$s2$jscomp$8$$)};$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$variadic$=function($s1$jscomp$12$$,$s2$jscomp$9$$,$sets$jscomp$2$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$clojure$set$difference$$,$s1$jscomp$12$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($sets$jscomp$2$$,$s2$jscomp$9$$))};
$APP.$clojure$set$difference$$.$cljs$lang$applyTo$=function($G__24253_seq24251$$){var $G__24252$$=$APP.$cljs$core$first$$($G__24253_seq24251$$),$seq24251__$1_seq24251__$2$$=$APP.$cljs$core$next$$($G__24253_seq24251$$);$G__24253_seq24251$$=$APP.$cljs$core$first$$($seq24251__$1_seq24251__$2$$);$seq24251__$1_seq24251__$2$$=$APP.$cljs$core$next$$($seq24251__$1_seq24251__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__24252$$,$G__24253_seq24251$$,$seq24251__$1_seq24251__$2$$)};
$APP.$clojure$set$difference$$.$cljs$lang$maxFixedArity$=2;var $clojure$walk$prewalk$$;$APP.$clojure$walk$postwalk$$=function $clojure$walk$postwalk$$($f$jscomp$344$$,$form$jscomp$25$$){return $clojure$walk$walk$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($clojure$walk$postwalk$$,$f$jscomp$344$$),$f$jscomp$344$$,$form$jscomp$25$$)};
$clojure$walk$prewalk$$=function $clojure$walk$prewalk$$($f$jscomp$345$$,$form$jscomp$26$$){return $clojure$walk$walk$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($clojure$walk$prewalk$$,$f$jscomp$345$$),$APP.$cljs$core$identity$$,$f$jscomp$345$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$345$$.$cljs$core$IFn$_invoke$arity$1$($form$jscomp$26$$):$f$jscomp$345$$($form$jscomp$26$$))};var $cuerdas$core$str_blank_re$$=$APP.$cljs$core$re_pattern$$("(?u)^[\\s\\p{Z}]+$"),$cuerdas$core$words_default_re$$;$APP.$cljs$core$re_pattern$$("^[a-zA-Z]+$");$APP.$cljs$core$re_pattern$$("^[0-9]+$");$APP.$cljs$core$re_pattern$$("^[a-zA-Z0-9]+$");var $cuerdas$core$world_pred_re$$=$APP.$cljs$core$re_pattern$$("(?u)^[\\p{N}\\p{L}_-]+$");$APP.$cljs$core$re_pattern$$("(?u)^\\p{L}+$");
var $cuerdas$core$numeric_pred_re$$=$APP.$cljs$core$re_pattern$$("^[+-]?([0-9]*\\.?[0-9]+|[0-9]+\\.?[0-9]*)([eE][+-]?[0-9]+)?$"),$cuerdas$core$trim_default_re$$=$cuerdas$core$str__GT_trim_re$$("\n\f\r\t ");$cuerdas$core$str__GT_rtrim_re$$("\n\f\r\t ");var $rxstr__$1$jscomp$inline_3103$$="^["+($goog$string$regExpEscape$$("\n\f\r\t ")+"]+");$APP.$cljs$core$re_pattern$$($rxstr__$1$jscomp$inline_3103$$);
$APP.$cuerdas$core$trim$$=function $cuerdas$core$trim$$($var_args$jscomp$349$$){switch(arguments.length){case 1:return $cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$=function($s$jscomp$215$$){return $APP.$cuerdas$core$replace$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cuerdas$core$replace$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$215$$,$cuerdas$core$trim_default_re$$,""):$APP.$cuerdas$core$replace$$($s$jscomp$215$$,$cuerdas$core$trim_default_re$$,"")};
$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$2$=function($s$jscomp$216$$,$chs$jscomp$3_rx$$){return typeof $s$jscomp$216$$==="string"?($chs$jscomp$3_rx$$=$cuerdas$core$str__GT_trim_re$$($chs$jscomp$3_rx$$),$APP.$cuerdas$core$replace$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cuerdas$core$replace$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$216$$,$chs$jscomp$3_rx$$,""):$APP.$cuerdas$core$replace$$($s$jscomp$216$$,$chs$jscomp$3_rx$$,"")):null};
$APP.$cuerdas$core$trim$$.$cljs$lang$maxFixedArity$=2;$APP.$cljs$core$re_pattern$$("(?u)[\\s\\p{Z}]+");$cuerdas$core$words_default_re$$=$APP.$cljs$core$re_pattern$$("(?u)[\\p{N}\\p{L}_-]+");
$APP.$cuerdas$core$format$$=function $cuerdas$core$format$$($var_args$jscomp$358$$){for(var $args__5755__auto__$jscomp$31$$=[],$len__5749__auto___27355$$=arguments.length,$i__5750__auto___27356$$=0;;)if($i__5750__auto___27356$$<$len__5749__auto___27355$$)$args__5755__auto__$jscomp$31$$.push(arguments[$i__5750__auto___27356$$]),$i__5750__auto___27356$$+=1;else break;return $cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args__5755__auto__$jscomp$31$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$31$$.slice(1),
0,null):null)};
$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$=function($s$jscomp$246$$,$more$jscomp$35$$){return typeof $s$jscomp$246$$==="string"?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($more$jscomp$35$$),1)&&$APP.$cljs$core$associative_QMARK_$$($APP.$cljs$core$first$$($more$jscomp$35$$))?$cuerdas$core$interpolate_format$$($s$jscomp$246$$,$APP.$cljs$core$first$$($more$jscomp$35$$)):$cuerdas$core$indexed_format$$($s$jscomp$246$$,$more$jscomp$35$$):null};
$APP.$cuerdas$core$format$$.$cljs$lang$maxFixedArity$=1;$APP.$cuerdas$core$format$$.$cljs$lang$applyTo$=function($seq26114_seq26114__$1$$){var $G__26115$$=$APP.$cljs$core$first$$($seq26114_seq26114__$1$$);$seq26114_seq26114__$1$$=$APP.$cljs$core$next$$($seq26114_seq26114__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__26115$$,$seq26114_seq26114__$1$$)};
$APP.$cuerdas$core$join$$=function $cuerdas$core$join$$($var_args$jscomp$359$$){switch(arguments.length){case 1:return $cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$1$=function($coll$jscomp$826$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$coll$jscomp$826$$)};$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$=function($separator$jscomp$3$$,$coll$jscomp$827$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$interpose$cljs$0core$0IFn$0_invoke$0arity$02$$($separator$jscomp$3$$,$coll$jscomp$827$$))};
$APP.$cuerdas$core$join$$.$cljs$lang$maxFixedArity$=2;var $cuerdas$core$stylize_re1$$=$APP.$cljs$core$re_pattern$$("(?u)(\\p{Lu}[\\p{Ll}\\u0027\\p{Ps}\\p{Pe}]*)"),$cuerdas$core$stylize_re2$$=$APP.$cljs$core$re_pattern$$("(?u)[^\\p{L}\\p{N}\\u0027\\p{Ps}\\p{Pe}]+");$APP.$cljs$core$zipmap$$("ąàáäâãåæăćčĉęèéëêĝĥìíïîĵłľńňòóöőôõðøśșšŝťțŭùúüűûñÿýçżźž","aaaaaaaaaccceeeeeghiiiijllnnoooooooossssttuuuuuunyyczzz");$APP.$cljs$core$re_pattern$$("(?u)[^\\p{L}\\p{N}]+");$APP.$cljs$core$re_pattern$$("(?u)[\\p{Z}\\s]+");var $linked$map$visit_node$$,$f$jscomp$inline_14109$$;$APP.$JSCompiler_prototypeAlias$$=$linked$map$Node$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$1$$,$k__5324__auto__$jscomp$1$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$1$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$1$$,$k25690$$,$else__5326__auto__$jscomp$1$$){switch($k25690$$ instanceof $APP.$cljs$core$Keyword$$?$k25690$$.$fqn$:null){case "value":return this.value;case "left":return this.left;case "right":return this.right;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k25690$$,$else__5326__auto__$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$1$$,$f__5344__auto__$jscomp$1$$,$init__5345__auto__$jscomp$1$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$1$$,$p__25733_v__5348__auto__$jscomp$1$$){var $k__5347__auto__$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__25733_v__5348__auto__$jscomp$1$$,0,null);$p__25733_v__5348__auto__$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__25733_v__5348__auto__$jscomp$1$$,
1,null);return $f__5344__auto__$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$1$$,$k__5347__auto__$jscomp$1$$,$p__25733_v__5348__auto__$jscomp$1$$):$f__5344__auto__$jscomp$1$$($ret__5346__auto__$jscomp$1$$,$k__5347__auto__$jscomp$1$$,$p__25733_v__5348__auto__$jscomp$1$$)},$init__5345__auto__$jscomp$1$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$1$$,$writer__5339__auto__$jscomp$1$$,$opts__5340__auto__$jscomp$1$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$1$$,function($keyval__5342__auto__$jscomp$1$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$1$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$1$$,$keyval__5342__auto__$jscomp$1$$)},"#linked.map.Node{",
", ","}",$opts__5340__auto__$jscomp$1$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,this.value],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$257$left$$,this.left],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$258$right$$,this.right],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,3,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$258$right$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $linked$map$Node$$(this.value,this.left,this.right,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 3+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$27_h__5134__auto____$1$jscomp$27$$=this.$__hash$;return $h__5134__auto__$jscomp$27_h__5134__auto____$1$jscomp$27$$!=null?$h__5134__auto__$jscomp$27_h__5134__auto____$1$jscomp$27$$:this.$__hash$=$h__5134__auto__$jscomp$27_h__5134__auto____$1$jscomp$27$$=-1739253980^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this25691$$,$other25692$$){return $other25692$$!=null&&this.constructor===$other25692$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.value,$other25692$$.value)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.left,$other25692$$.left)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.right,$other25692$$.right)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,
$other25692$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$1$$,$k__5334__auto__$jscomp$1$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$260$value$$,null,$APP.$cljs$cst$258$right$$,null,$APP.$cljs$cst$257$left$$,null],null),null),$k__5334__auto__$jscomp$1$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),
this.$__meta$),$k__5334__auto__$jscomp$1$$):new $linked$map$Node$$(this.value,this.left,this.right,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$1$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$1$$,$k25690$jscomp$1$$){switch($k25690$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k25690$jscomp$1$$.$fqn$:null){case "value":case "left":case "right":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k25690$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$1$$,$k__5332__auto__$jscomp$1$$,$G__25689$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$1$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$1$$))?
new $linked$map$Node$$($G__25689$jscomp$1$$,this.left,this.right,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$257$left$$,$k__5332__auto__$jscomp$1$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$257$left$$,$k__5332__auto__$jscomp$1$$))?new $linked$map$Node$$(this.value,$G__25689$jscomp$1$$,this.right,this.$__meta$,
this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$258$right$$,$k__5332__auto__$jscomp$1$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$258$right$$,$k__5332__auto__$jscomp$1$$))?new $linked$map$Node$$(this.value,this.left,$G__25689$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $linked$map$Node$$(this.value,this.left,this.right,
this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$1$$,$G__25689$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$260$value$$,this.value,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$257$left$$,this.left,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$258$right$$,this.right,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$1$$,$G__25689$jscomp$2$$){return new $linked$map$Node$$(this.value,this.left,this.right,$G__25689$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$1$$,$entry__5329__auto__$jscomp$1$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$1$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$1$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$1$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$1$$)};
$APP.$JSCompiler_prototypeAlias$$=$linked$map$LinkedMap$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.toString=function(){var $coll$jscomp$830$$=this;return["{",$APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",function(){return function $linked$map$iter__25869$$($s__25870$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__25870__$2_temp__5825__auto__$jscomp$53$$=$APP.$cljs$core$seq$$($s__25870$$);if($s__25870__$2_temp__5825__auto__$jscomp$53$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__25870__$2_temp__5825__auto__$jscomp$53$$)){var $JSCompiler_inline_result$jscomp$292_c__5501__auto__$jscomp$2_v$jscomp$106_vec__25882$$=$APP.$cljs$core$_chunked_first$$($s__25870__$2_temp__5825__auto__$jscomp$53$$),
$size__5502__auto__$jscomp$2$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$292_c__5501__auto__$jscomp$2_v$jscomp$106_vec__25882$$),$b__25872_k$jscomp$240$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$2$$);a:{for(var $i__25871$jscomp$inline_3116$$=0;;)if($i__25871$jscomp$inline_3116$$<$size__5502__auto__$jscomp$2$$){var $b$jscomp$inline_11366_vec__25876$jscomp$inline_3117$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$292_c__5501__auto__$jscomp$2_v$jscomp$106_vec__25882$$,
$i__25871$jscomp$inline_3116$$),$k$jscomp$inline_3118_x$jscomp$inline_11367$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_11366_vec__25876$jscomp$inline_3117$$,0,null),$v$jscomp$inline_3119$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_11366_vec__25876$jscomp$inline_3117$$,1,null);$b$jscomp$inline_11366_vec__25876$jscomp$inline_3117$$=$b__25872_k$jscomp$240$$;$k$jscomp$inline_3118_x$jscomp$inline_11367$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$inline_3118_x$jscomp$inline_11367$$),
" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$inline_3119$$)].join("");$b$jscomp$inline_11366_vec__25876$jscomp$inline_3117$$.add($k$jscomp$inline_3118_x$jscomp$inline_11367$$);$i__25871$jscomp$inline_3116$$+=1}else{$JSCompiler_inline_result$jscomp$292_c__5501__auto__$jscomp$2_v$jscomp$106_vec__25882$$=!0;break a}$JSCompiler_inline_result$jscomp$292_c__5501__auto__$jscomp$2_v$jscomp$106_vec__25882$$=void 0}return $JSCompiler_inline_result$jscomp$292_c__5501__auto__$jscomp$2_v$jscomp$106_vec__25882$$?
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__25872_k$jscomp$240$$),$linked$map$iter__25869$$($APP.$cljs$core$_chunked_rest$$($s__25870__$2_temp__5825__auto__$jscomp$53$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__25872_k$jscomp$240$$),null)}$JSCompiler_inline_result$jscomp$292_c__5501__auto__$jscomp$2_v$jscomp$106_vec__25882$$=$APP.$cljs$core$first$$($s__25870__$2_temp__5825__auto__$jscomp$53$$);$b__25872_k$jscomp$240$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$292_c__5501__auto__$jscomp$2_v$jscomp$106_vec__25882$$,
0,null);$JSCompiler_inline_result$jscomp$292_c__5501__auto__$jscomp$2_v$jscomp$106_vec__25882$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$292_c__5501__auto__$jscomp$2_v$jscomp$106_vec__25882$$,1,null);return $APP.$cljs$core$cons$$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($b__25872_k$jscomp$240$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$292_c__5501__auto__$jscomp$2_v$jscomp$106_vec__25882$$)].join(""),
$linked$map$iter__25869$$($APP.$cljs$core$rest$$($s__25870__$2_temp__5825__auto__$jscomp$53$$)))}return null}},null,null)}($coll$jscomp$830$$)}()),"}"].join("")};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$120$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$120$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($coll$jscomp$831$$,$k$jscomp$242$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$242$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($coll$jscomp$832_temp__5823__auto__$jscomp$33$$,$k$jscomp$243$$,$not_found$jscomp$61$$){$coll$jscomp$832_temp__5823__auto__$jscomp$33$$=$cljs$core$find$$(this.$delegate_map$,$k$jscomp$243$$);return $APP.$cljs$core$truth_$$($coll$jscomp$832_temp__5823__auto__$jscomp$33$$)?$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_val$$($coll$jscomp$832_temp__5823__auto__$jscomp$33$$)):$not_found$jscomp$61$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($coll$jscomp$833$$,$f$jscomp$349$$,$init$jscomp$49$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__25820_SHARP_$$,$p2__25821_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$349$$,$p1__25820_SHARP_$$),$p2__25821_SHARP_$$)},$init$jscomp$49$$,$APP.$cljs$core$seq$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$834$$,$writer$jscomp$61$$){return $APP.$cljs$core$_write$$($writer$jscomp$61$$,["#linked/map ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,this))].join(""))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return $APP.$cljs$core$meta$$(this.$delegate_map$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $linked$map$LinkedMap$$(this.head,this.$delegate_map$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return $APP.$cljs$core$count$$(this.$delegate_map$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReversible$_rseq$arity$1$=function(){return $linked$map$rseq_STAR_$$.$cljs$core$IFn$_invoke$arity$1$?$linked$map$rseq_STAR_$$.$cljs$core$IFn$_invoke$arity$1$(this):$linked$map$rseq_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $APP.$cljs$core$hash$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$839$$,$other$jscomp$121$$){return $APP.$cljs$core$equiv_map$$(this,$other$jscomp$121$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$_with_meta$$($APP.$linked$map$empty_linked_map$$,$APP.$cljs$core$meta$$(this.$delegate_map$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($coll$jscomp$841$$,$k$jscomp$244$$){return $linked$map$dissoc_STAR_$$.$cljs$core$IFn$_invoke$arity$2$?$linked$map$dissoc_STAR_$$.$cljs$core$IFn$_invoke$arity$2$(this,$k$jscomp$244$$):$linked$map$dissoc_STAR_$$(this,$k$jscomp$244$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($coll$jscomp$842$$,$k$jscomp$245$$,$v$jscomp$108$$){return $linked$map$assoc_STAR_$$.$cljs$core$IFn$_invoke$arity$3$?$linked$map$assoc_STAR_$$.$cljs$core$IFn$_invoke$arity$3$(this,$k$jscomp$245$$,$v$jscomp$108$$):$linked$map$assoc_STAR_$$(this,$k$jscomp$245$$,$v$jscomp$108$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($coll$jscomp$843$$,$k$jscomp$246$$){return $APP.$cljs$core$contains_QMARK_$$(this.$delegate_map$,$k$jscomp$246$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $linked$map$seq_STAR_$$.$cljs$core$IFn$_invoke$arity$1$?$linked$map$seq_STAR_$$.$cljs$core$IFn$_invoke$arity$1$(this):$linked$map$seq_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$845$$,$meta$jscomp$65$$){return new $linked$map$LinkedMap$$(this.head,$APP.$cljs$core$with_meta$$(this.$delegate_map$,$meta$jscomp$65$$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($G__26032_coll$jscomp$846_ret$jscomp$65$$,$G__26033_entry$jscomp$13_es$jscomp$5$$){if($APP.$cljs$core$vector_QMARK_$$($G__26033_entry$jscomp$13_es$jscomp$5$$))return this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($G__26033_entry$jscomp$13_es$jscomp$5$$,0),$APP.$cljs$core$_nth$$($G__26033_entry$jscomp$13_es$jscomp$5$$,1));$G__26032_coll$jscomp$846_ret$jscomp$65$$=this;for($G__26033_entry$jscomp$13_es$jscomp$5$$=
$APP.$cljs$core$seq$$($G__26033_entry$jscomp$13_es$jscomp$5$$);;){if($G__26033_entry$jscomp$13_es$jscomp$5$$==null)return $G__26032_coll$jscomp$846_ret$jscomp$65$$;var $e$jscomp$131$$=$APP.$cljs$core$first$$($G__26033_entry$jscomp$13_es$jscomp$5$$);if($APP.$cljs$core$vector_QMARK_$$($e$jscomp$131$$))$G__26032_coll$jscomp$846_ret$jscomp$65$$=$APP.$cljs$core$_assoc$$($G__26032_coll$jscomp$846_ret$jscomp$65$$,$APP.$cljs$core$_nth$$($e$jscomp$131$$,0),$APP.$cljs$core$_nth$$($e$jscomp$131$$,1)),$G__26033_entry$jscomp$13_es$jscomp$5$$=
$APP.$cljs$core$next$$($G__26033_entry$jscomp$13_es$jscomp$5$$);else throw Error("conj on a map takes map entries or seqables of map entries");}};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$20$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$1168$$,$args25837$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args25837$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$247$$){return this.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$247$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$248$$,$not_found$jscomp$62$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$248$$,$not_found$jscomp$62$$)};
$linked$map$visit_node$$=function $linked$map$visit_node$$($delegate_map$jscomp$4$$,$current$jscomp$3$$,$last$$,$direction$jscomp$7$$){var $node$jscomp$128_vec__25950$$=$cljs$core$find$$($delegate_map$jscomp$4$$,$current$jscomp$3$$),$entry$jscomp$16_k$jscomp$252$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($node$jscomp$128_vec__25950$$,0,null);$node$jscomp$128_vec__25950$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($node$jscomp$128_vec__25950$$,1,null);$entry$jscomp$16_k$jscomp$252$$=
$linked$map$map_entry$$($entry$jscomp$16_k$jscomp$252$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$128_vec__25950$$));var $next$jscomp$5$$=$direction$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$direction$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$128_vec__25950$$):$direction$jscomp$7$$($node$jscomp$128_vec__25950$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$3$$,$last$$)?new $APP.$cljs$core$List$$(null,$entry$jscomp$16_k$jscomp$252$$,
null,1,null):$APP.$cljs$core$cons$$($entry$jscomp$16_k$jscomp$252$$,new $APP.$cljs$core$LazySeq$$(null,function(){return $linked$map$visit_node$$.$cljs$core$IFn$_invoke$arity$4$?$linked$map$visit_node$$.$cljs$core$IFn$_invoke$arity$4$($delegate_map$jscomp$4$$,$next$jscomp$5$$,$last$$,$direction$jscomp$7$$):$linked$map$visit_node$$($delegate_map$jscomp$4$$,$next$jscomp$5$$,$last$$,$direction$jscomp$7$$)},null,null))};$APP.$linked$map$empty_linked_map$$=new $linked$map$LinkedMap$$(null,$cljs$core$PersistentHashMap$EMPTY$$);
$f$jscomp$inline_14109$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$into$$,$APP.$linked$map$empty_linked_map$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($cljs$reader$_STAR_tag_table_STAR_$$),$cljs$cst$263$linked_SLASH_map$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($cljs$reader$_STAR_tag_table_STAR_$$,$APP.$cljs$core$assoc$$,$cljs$cst$263$linked_SLASH_map$$,$f$jscomp$inline_14109$$);var $f$jscomp$inline_14112$$;$APP.$JSCompiler_prototypeAlias$$=$linked$set$LinkedSet$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return["[",$APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,this)),"]"].join("")};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$122$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$122$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($coll$jscomp$849$$,$v$jscomp$111$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$v$jscomp$111$$,null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($coll$jscomp$850$$,$v$jscomp$112$$,$not_found$jscomp$63$$){return $APP.$cljs$core$_contains_key_QMARK_$$(this.$linked_map$,$v$jscomp$112$$)?$v$jscomp$112$$:$not_found$jscomp$63$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$851$$,$writer$jscomp$62$$){return $APP.$cljs$core$_write$$($writer$jscomp$62$$,["#linked/set ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,this))].join(""))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return $APP.$cljs$core$meta$$(this.$linked_map$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $linked$set$LinkedSet$$(this.$linked_map$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return $APP.$cljs$core$_count$$(this.$linked_map$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReversible$_rseq$arity$1$=function(){var $temp__5825__auto__$jscomp$54$$=$APP.$cljs$core$_rseq$$(this.$linked_map$);return $temp__5825__auto__$jscomp$54$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$key$$,$temp__5825__auto__$jscomp$54$$):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $APP.$cljs$core$hash$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,this))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$856$$,$other$jscomp$123$$){var $coll__$1$jscomp$479$$=this;return $APP.$cljs$core$set_QMARK_$$($other$jscomp$123$$)&&$APP.$cljs$core$count$$($coll__$1$jscomp$479$$)===$APP.$cljs$core$count$$($other$jscomp$123$$)&&$APP.$cljs$core$every_QMARK_$$(function($p1__31087_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($coll__$1$jscomp$479$$,$p1__31087_SHARP_$$)},$other$jscomp$123$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$with_meta$$($APP.$linked$set$empty_linked_set$$,$APP.$cljs$core$meta$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISet$_disjoin$arity$2$=function($coll$jscomp$858$$,$v$jscomp$113$$){return new $linked$set$LinkedSet$$($APP.$cljs$core$_dissoc$$(this.$linked_map$,$v$jscomp$113$$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){var $temp__5825__auto__$jscomp$55$$=$APP.$cljs$core$seq$$(this.$linked_map$);return $temp__5825__auto__$jscomp$55$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$key$$,$temp__5825__auto__$jscomp$55$$):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$860$$,$meta$jscomp$66$$){return new $linked$set$LinkedSet$$($APP.$cljs$core$with_meta$$(this.$linked_map$,$meta$jscomp$66$$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$861$$,$o$jscomp$140$$){return new $linked$set$LinkedSet$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$linked_map$,$o$jscomp$140$$,null))};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$21$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$1188$$,$args31088$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args31088$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$253$$){return this.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$253$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$254$$,$not_found$jscomp$64$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$254$$,$not_found$jscomp$64$$)};$APP.$linked$set$empty_linked_set$$=new $linked$set$LinkedSet$$($APP.$linked$map$empty_linked_map$$);
$f$jscomp$inline_14112$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$into$$,$APP.$linked$set$empty_linked_set$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($cljs$reader$_STAR_tag_table_STAR_$$),$cljs$cst$265$linked_SLASH_set$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($cljs$reader$_STAR_tag_table_STAR_$$,$APP.$cljs$core$assoc$$,$cljs$cst$265$linked_SLASH_set$$,$f$jscomp$inline_14112$$);var $app$common$data$oassoc_in$$,$app$common$data$oassoc_in_before$$,$app$common$data$sentinel$$;$APP.$app$common$data$xf_COLON_map_id$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$);
$APP.$app$common$data$ordered_set$$=function $app$common$data$ordered_set$$($var_args$jscomp$369$$){switch(arguments.length){case 0:return $app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:for(var $args_arr__5774__auto__$jscomp$69$$=[],$len__5749__auto___31912$$=arguments.length,$i__5750__auto___31913$$=0;;)if($i__5750__auto___31913$$<$len__5749__auto___31912$$)$args_arr__5774__auto__$jscomp$69$$.push(arguments[$i__5750__auto___31913$$]),
$i__5750__auto___31913$$+=1;else break;return $app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args_arr__5774__auto__$jscomp$69$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$69$$.slice(1),0,null):null)}};$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$linked$set$empty_linked_set$$};
$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$1$=function($a$jscomp$204$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$linked$set$empty_linked_set$$,$a$jscomp$204$$)};$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$variadic$=function($a$jscomp$205$$,$xs$jscomp$18$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$conj$$,$APP.$linked$set$empty_linked_set$$,$a$jscomp$205$$,$xs$jscomp$18$$)};
$APP.$app$common$data$ordered_set$$.$cljs$lang$applyTo$=function($seq31130_seq31130__$1$$){var $G__31131$$=$APP.$cljs$core$first$$($seq31130_seq31130__$1$$);$seq31130_seq31130__$1$$=$APP.$cljs$core$next$$($seq31130_seq31130__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__31131$$,$seq31130_seq31130__$1$$)};$APP.$app$common$data$ordered_set$$.$cljs$lang$maxFixedArity$=1;
var $app$common$data$oassoc$$=function $app$common$data$oassoc$$($var_args$jscomp$371$$){for(var $args__5755__auto__$jscomp$32$$=[],$len__5749__auto___31921$$=arguments.length,$i__5750__auto___31922$$=0;;)if($i__5750__auto___31922$$<$len__5749__auto___31921$$)$args__5755__auto__$jscomp$32$$.push(arguments[$i__5750__auto___31922$$]),$i__5750__auto___31922$$+=1;else break;return $app$common$data$oassoc$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args__5755__auto__$jscomp$32$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$32$$.slice(1),
0,null):null)};$app$common$data$oassoc$$.$cljs$core$IFn$_invoke$arity$variadic$=function($o$jscomp$143$$,$kvs$jscomp$3$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$,$APP.$cljs$core$truth_$$($o$jscomp$143$$)?$o$jscomp$143$$:$APP.$linked$map$empty_linked_map$$,$kvs$jscomp$3$$)};$app$common$data$oassoc$$.$cljs$lang$maxFixedArity$=1;
$app$common$data$oassoc$$.$cljs$lang$applyTo$=function($seq31158_seq31158__$1$$){var $G__31159$$=$APP.$cljs$core$first$$($seq31158_seq31158__$1$$);$seq31158_seq31158__$1$$=$APP.$cljs$core$next$$($seq31158_seq31158__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__31159$$,$seq31158_seq31158__$1$$)};
$app$common$data$oassoc_in$$=function $app$common$data$oassoc_in$$($JSCompiler_temp$jscomp$293_o$jscomp$144$$,$first__31169_p__31165$$,$JSCompiler_inline_result$jscomp$296_v$jscomp$114$$){var $JSCompiler_temp_const$jscomp$294_seq__31168$$=$APP.$cljs$core$seq$$($first__31169_p__31165$$);$first__31169_p__31165$$=$APP.$cljs$core$first$$($JSCompiler_temp_const$jscomp$294_seq__31168$$);var $seq__31168__$1$$=$APP.$cljs$core$next$$($JSCompiler_temp_const$jscomp$294_seq__31168$$);if($seq__31168__$1$$){$JSCompiler_temp_const$jscomp$294_seq__31168$$=
$app$common$data$oassoc$$.$cljs$core$IFn$_invoke$arity$variadic$;var $G__31170$jscomp$inline_3121$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$293_o$jscomp$144$$,$first__31169_p__31165$$);$JSCompiler_inline_result$jscomp$296_v$jscomp$114$$=$app$common$data$oassoc_in$$.$cljs$core$IFn$_invoke$arity$3$?$app$common$data$oassoc_in$$.$cljs$core$IFn$_invoke$arity$3$($G__31170$jscomp$inline_3121$$,$seq__31168__$1$$,$JSCompiler_inline_result$jscomp$296_v$jscomp$114$$):$app$common$data$oassoc_in$$($G__31170$jscomp$inline_3121$$,
$seq__31168__$1$$,$JSCompiler_inline_result$jscomp$296_v$jscomp$114$$);$JSCompiler_temp$jscomp$293_o$jscomp$144$$=$JSCompiler_temp_const$jscomp$294_seq__31168$$.call($app$common$data$oassoc$$,$JSCompiler_temp$jscomp$293_o$jscomp$144$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$first__31169_p__31165$$,$JSCompiler_inline_result$jscomp$296_v$jscomp$114$$]))}else $JSCompiler_temp$jscomp$293_o$jscomp$144$$=$app$common$data$oassoc$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_temp$jscomp$293_o$jscomp$144$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$first__31169_p__31165$$,$JSCompiler_inline_result$jscomp$296_v$jscomp$114$$]));return $JSCompiler_temp$jscomp$293_o$jscomp$144$$};
$app$common$data$oassoc_in_before$$=function $app$common$data$oassoc_in_before$$($o$jscomp$147$$,$new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$,$new_v_p__31192_seq__31197$$,$v$jscomp$117$$){$new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$=$APP.$cljs$core$seq$$($new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$);var $first__31195$$=$APP.$cljs$core$first$$($new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$),$seq__31194__$1$$=$APP.$cljs$core$next$$($new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$);
$new_v_p__31192_seq__31197$$=$APP.$cljs$core$seq$$($new_v_p__31192_seq__31197$$);var $first__31198$$=$APP.$cljs$core$first$$($new_v_p__31192_seq__31197$$),$seq__31197__$1$$=$APP.$cljs$core$next$$($new_v_p__31192_seq__31197$$);$new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$=function(){var $G__31201$$=$APP.$cljs$core$keys$$($o$jscomp$147$$);return $APP.$app$common$data$index_of$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$data$index_of$$.$cljs$core$IFn$_invoke$arity$2$($G__31201$$,
$first__31195$$):$APP.$app$common$data$index_of$$($G__31201$$,$first__31195$$)}();if($APP.$cljs$core$truth_$$($new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$)){$new_v_p__31192_seq__31197$$=$seq__31197__$1$$?function(){var $G__31204$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$147$$,$first__31198$$);return $app$common$data$oassoc_in_before$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$data$oassoc_in_before$$.$cljs$core$IFn$_invoke$arity$4$($G__31204$$,$seq__31194__$1$$,
$seq__31197__$1$$,$v$jscomp$117$$):$app$common$data$oassoc_in_before$$($G__31204$$,$seq__31194__$1$$,$seq__31197__$1$$,$v$jscomp$117$$)}():$v$jscomp$117$$;var $current_index$$=function(){var $G__31208$$=$APP.$cljs$core$keys$$($o$jscomp$147$$);return $APP.$app$common$data$index_of$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$data$index_of$$.$cljs$core$IFn$_invoke$arity$2$($G__31208$$,$first__31198$$):$APP.$app$common$data$index_of$$($G__31208$$,$first__31198$$)}();$new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$=
$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($current_index$$)?$current_index$$<$new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$:$current_index$$)?$new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$-1:$new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($first__31198$$,$first__31195$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$linked$map$empty_linked_map$$,
$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$,$o$jscomp$147$$)),$first__31198$$,$new_v_p__31192_seq__31197$$),$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$+1,$o$jscomp$147$$)):$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$linked$map$empty_linked_map$$,
$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$147$$,$first__31198$$))),$first__31198$$,$new_v_p__31192_seq__31197$$),$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($new_index_p__31191_seq__31194_temp__5823__auto__$jscomp$37$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$147$$,$first__31198$$)))}return $app$common$data$oassoc_in$$($o$jscomp$147$$,
$APP.$cljs$core$cons$$($first__31198$$,$seq__31197__$1$$),$v$jscomp$117$$)};
$APP.$app$common$data$deep_merge$$=function $app$common$data$deep_merge$$($var_args$jscomp$374$$){switch(arguments.length){case 2:return $app$common$data$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$72$$=[],$len__5749__auto___31960$$=arguments.length,$i__5750__auto___31962$$=0;;)if($i__5750__auto___31962$$<$len__5749__auto___31960$$)$args_arr__5774__auto__$jscomp$72$$.push(arguments[$i__5750__auto___31962$$]),$i__5750__auto___31962$$+=
1;else break;return $app$common$data$deep_merge$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$72$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$72$$.slice(2),0,null):null)}};
$APP.$app$common$data$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$=function($a$jscomp$210$$,$b$jscomp$170$$){return $APP.$cljs$core$map_QMARK_$$($a$jscomp$210$$)?$APP.$cljs$core$merge_with$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$data$deep_merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$a$jscomp$210$$,$b$jscomp$170$$])):$b$jscomp$170$$};
$APP.$app$common$data$deep_merge$$.$cljs$core$IFn$_invoke$arity$variadic$=function($a$jscomp$211$$,$b$jscomp$171$$,$rest$jscomp$11$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$data$deep_merge$$,$a$jscomp$211$$,$APP.$cljs$core$cons$$($b$jscomp$171$$,$rest$jscomp$11$$))};
$APP.$app$common$data$deep_merge$$.$cljs$lang$applyTo$=function($G__31223_seq31221$$){var $G__31222$$=$APP.$cljs$core$first$$($G__31223_seq31221$$),$seq31221__$1_seq31221__$2$$=$APP.$cljs$core$next$$($G__31223_seq31221$$);$G__31223_seq31221$$=$APP.$cljs$core$first$$($seq31221__$1_seq31221__$2$$);$seq31221__$1_seq31221__$2$$=$APP.$cljs$core$next$$($seq31221__$1_seq31221__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__31222$$,$G__31223_seq31221$$,$seq31221__$1_seq31221__$2$$)};
$APP.$app$common$data$deep_merge$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$data$dissoc_in$$=function $app$common$data$dissoc_in$$($m$jscomp$92$$,$first__31232_p__31229$$){var $newmap_seq__31231_seq__31231__$1$$=$APP.$cljs$core$seq$$($first__31232_p__31229$$);$first__31232_p__31229$$=$APP.$cljs$core$first$$($newmap_seq__31231_seq__31231__$1$$);if($newmap_seq__31231_seq__31231__$1$$=$APP.$cljs$core$next$$($newmap_seq__31231_seq__31231__$1$$)){var $temp__5823__auto__$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$92$$,$first__31232_p__31229$$);
return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$38$$)?($newmap_seq__31231_seq__31231__$1$$=$app$common$data$dissoc_in$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$data$dissoc_in$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$38$$,$newmap_seq__31231_seq__31231__$1$$):$app$common$data$dissoc_in$$($temp__5823__auto__$jscomp$38$$,$newmap_seq__31231_seq__31231__$1$$),$APP.$cljs$core$seq$$($newmap_seq__31231_seq__31231__$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$92$$,
$first__31232_p__31229$$,$newmap_seq__31231_seq__31231__$1$$):$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$92$$,$first__31232_p__31229$$)):$m$jscomp$92$$}return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$92$$,$first__31232_p__31229$$)};
$APP.$app$common$data$concat_vec$$=function $app$common$data$concat_vec$$($var_args$jscomp$377$$){switch(arguments.length){case 0:return $app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:for(var $args_arr__5774__auto__$jscomp$75$$=[],$len__5749__auto___31987$$=arguments.length,$i__5750__auto___31989$$=0;;)if($i__5750__auto___31989$$<$len__5749__auto___31987$$)$args_arr__5774__auto__$jscomp$75$$.push(arguments[$i__5750__auto___31989$$]),
$i__5750__auto___31989$$+=1;else break;return $app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args_arr__5774__auto__$jscomp$75$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$75$$.slice(1),0,null):null)}};$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$cljs$core$PersistentVector$EMPTY$$};
$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$1$=function($c1$jscomp$13$$){return $APP.$cljs$core$vector_QMARK_$$($c1$jscomp$13$$)?$c1$jscomp$13$$:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$c1$jscomp$13$$)};
$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$=function($c1$jscomp$14$$,$more$jscomp$38$$){return $APP.$cljs$core$vector_QMARK_$$($c1$jscomp$14$$)?$app$common$data$transient_concat$$($c1$jscomp$14$$,$more$jscomp$38$$):$app$common$data$transient_concat$$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$cons$$($c1$jscomp$14$$,$more$jscomp$38$$))};
$APP.$app$common$data$concat_vec$$.$cljs$lang$applyTo$=function($seq31255_seq31255__$1$$){var $G__31256$$=$APP.$cljs$core$first$$($seq31255_seq31255__$1$$);$seq31255_seq31255__$1$$=$APP.$cljs$core$next$$($seq31255_seq31255__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__31256$$,$seq31255_seq31255__$1$$)};$APP.$app$common$data$concat_vec$$.$cljs$lang$maxFixedArity$=1;
$APP.$app$common$data$without_nils$$=function $app$common$data$without_nils$$($var_args$jscomp$383$$){switch(arguments.length){case 0:return $app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nil_QMARK_$$,$APP.$cljs$core$val$$))};
$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$=function($data$jscomp$92$$){return $APP.$cljs$core$reduce_kv$$(function($data__$1$$,$k$jscomp$263$$,$v$jscomp$119$$){return $v$jscomp$119$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($data__$1$$,$k$jscomp$263$$):$data__$1$$},$data$jscomp$92$$,$data$jscomp$92$$)};$APP.$app$common$data$without_nils$$.$cljs$lang$maxFixedArity$=1;
$APP.$app$common$data$patch_object$$=function $app$common$data$patch_object$$($var_args$jscomp$385$$){switch(arguments.length){case 1:return $app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$1$=function($changes$$){return function($p1__31312_SHARP_$$){return $APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($p1__31312_SHARP_$$,$changes$$)}};
$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$=function($object$jscomp$9$$,$changes$jscomp$1$$){return $APP.$cljs$core$truth_$$($object$jscomp$9$$)?$APP.$cljs$core$reduce_kv$$(function($object__$1$$,$key$jscomp$175$$,$value$jscomp$223$$){if($APP.$cljs$core$map_QMARK_$$($value$jscomp$223$$)){var $current$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($object__$1$$,$key$jscomp$175$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($object__$1$$,
$key$jscomp$175$$,$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$4$$,$value$jscomp$223$$))}return $value$jscomp$223$$==null&&$APP.$cljs$core$record_QMARK_$$($object__$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($object__$1$$,$key$jscomp$175$$,null):$value$jscomp$223$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($object__$1$$,$key$jscomp$175$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($object__$1$$,$key$jscomp$175$$,
$value$jscomp$223$$)},$object$jscomp$9$$,$changes$jscomp$1$$):$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$1$$)};$APP.$app$common$data$patch_object$$.$cljs$lang$maxFixedArity$=2;$app$common$data$sentinel$$={};
$APP.$app$common$data$merge$$=function $app$common$data$merge$$($var_args$jscomp$392$$){for(var $args__5755__auto__$jscomp$36$$=[],$len__5749__auto___32107$$=arguments.length,$i__5750__auto___32108$$=0;;)if($i__5750__auto___32108$$<$len__5749__auto___32107$$)$args__5755__auto__$jscomp$36$$.push(arguments[$i__5750__auto___32108$$]),$i__5750__auto___32108$$+=1;else break;return $app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$36$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$36$$.slice(0),
0,null):null)};$APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$=function($maps$jscomp$2$$){var $or__5025__auto__$jscomp$inline_3129$$=$APP.$cljs$core$first$$($maps$jscomp$2$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_3129$$)?$or__5025__auto__$jscomp$inline_3129$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$rest$$($maps$jscomp$2$$))};
$APP.$app$common$data$merge$$.$cljs$lang$maxFixedArity$=0;$APP.$app$common$data$merge$$.$cljs$lang$applyTo$=function($seq31426$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq31426$$))};
var $app$common$data$interleave_all$$=function $app$common$data$interleave_all$$($var_args$jscomp$394$$){switch(arguments.length){case 0:return $app$common$data$interleave_all$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $app$common$data$interleave_all$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$data$interleave_all$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$76$$=[],$len__5749__auto___32128$$=arguments.length,
$i__5750__auto___32129$$=0;;)if($i__5750__auto___32129$$<$len__5749__auto___32128$$)$args_arr__5774__auto__$jscomp$76$$.push(arguments[$i__5750__auto___32129$$]),$i__5750__auto___32129$$+=1;else break;return $app$common$data$interleave_all$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$76$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$76$$.slice(2),0,null):null)}};
$app$common$data$interleave_all$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$cljs$core$List$EMPTY$$};$app$common$data$interleave_all$$.$cljs$core$IFn$_invoke$arity$1$=function($c1$jscomp$15$$){return new $APP.$cljs$core$LazySeq$$(null,function(){return $c1$jscomp$15$$},null,null)};
$app$common$data$interleave_all$$.$cljs$core$IFn$_invoke$arity$2$=function($c1$jscomp$16$$,$c2$jscomp$8$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $s1$jscomp$13$$=$APP.$cljs$core$seq$$($c1$jscomp$16$$),$s2$jscomp$10$$=$APP.$cljs$core$seq$$($c2$jscomp$8$$);return $s1$jscomp$13$$&&$s2$jscomp$10$$?$APP.$cljs$core$cons$$($APP.$cljs$core$first$$($s1$jscomp$13$$),$APP.$cljs$core$cons$$($APP.$cljs$core$first$$($s2$jscomp$10$$),$app$common$data$interleave_all$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$rest$$($s1$jscomp$13$$),
$APP.$cljs$core$rest$$($s2$jscomp$10$$)))):$s1$jscomp$13$$?$s1$jscomp$13$$:$s2$jscomp$10$$?$s2$jscomp$10$$:null},null,null)};
$app$common$data$interleave_all$$.$cljs$core$IFn$_invoke$arity$variadic$=function($c1$jscomp$17$$,$c2$jscomp$9$$,$colls$jscomp$9$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $ss$jscomp$6$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$identity$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($colls$jscomp$9$$,$c2$jscomp$9$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$c1$jscomp$17$$]))));
return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$ss$jscomp$6$$),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($app$common$data$interleave_all$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$rest$$,$ss$jscomp$6$$)))},null,null)};
$app$common$data$interleave_all$$.$cljs$lang$applyTo$=function($G__31463_seq31461$$){var $G__31462$$=$APP.$cljs$core$first$$($G__31463_seq31461$$),$seq31461__$1_seq31461__$2$$=$APP.$cljs$core$next$$($G__31463_seq31461$$);$G__31463_seq31461$$=$APP.$cljs$core$first$$($seq31461__$1_seq31461__$2$$);$seq31461__$1_seq31461__$2$$=$APP.$cljs$core$next$$($seq31461__$1_seq31461__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__31462$$,$G__31463_seq31461$$,$seq31461__$1_seq31461__$2$$)};
$app$common$data$interleave_all$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$data$parse_double$$=function $app$common$data$parse_double$$($var_args$jscomp$396$$){switch(arguments.length){case 1:return $app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$=function($v$jscomp$132$$){return $APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$132$$,null)};
$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$=function($v$jscomp$133_v__$1$jscomp$9$$,$default$$jscomp$2$$){$v$jscomp$133_v__$1$jscomp$9$$=parseFloat($v$jscomp$133_v__$1$jscomp$9$$);var $or__5025__auto__$jscomp$inline_3133$$=$v$jscomp$133_v__$1$jscomp$9$$==null;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_3133$$?$or__5025__auto__$jscomp$inline_3133$$:isNaN($v$jscomp$133_v__$1$jscomp$9$$))?$default$$jscomp$2$$:$v$jscomp$133_v__$1$jscomp$9$$};
$APP.$app$common$data$parse_double$$.$cljs$lang$maxFixedArity$=2;$APP.$app$common$data$nilv$$=function $app$common$data$nilv$$($var_args$jscomp$399$$){switch(arguments.length){case 1:return $app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$1$=function($default$$jscomp$6$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__31591_SHARP_$$){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($p1__31591_SHARP_$$,$default$$jscomp$6$$)})};$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$=function($v$jscomp$140$$,$default$$jscomp$7$$){return $v$jscomp$140$$!=null?$v$jscomp$140$$:$default$$jscomp$7$$};
$APP.$app$common$data$nilv$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$data$max$$=function $app$common$data$max$$($var_args$jscomp$401$$){switch(arguments.length){case 1:return $app$common$data$max$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$data$max$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$common$data$max$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$common$data$max$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],
arguments[3]);case 5:return $app$common$data$max$$.$cljs$core$IFn$_invoke$arity$5$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4]);case 6:return $app$common$data$max$$.$cljs$core$IFn$_invoke$arity$6$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5]);default:for(var $args_arr__5774__auto__$jscomp$78$$=[],$len__5749__auto___32171$$=arguments.length,$i__5750__auto___32172$$=0;;)if($i__5750__auto___32172$$<$len__5749__auto___32171$$)$args_arr__5774__auto__$jscomp$78$$.push(arguments[$i__5750__auto___32172$$]),
$i__5750__auto___32172$$+=1;else break;return $app$common$data$max$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],6<$args_arr__5774__auto__$jscomp$78$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$78$$.slice(6),0,null):null)}};$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$1$=function($a$jscomp$218$$){return $a$jscomp$218$$};
$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$2$=function($a$jscomp$219$$,$b$jscomp$177$$){return Math.max($a$jscomp$219$$,$b$jscomp$177$$)};$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$3$=function($a$jscomp$220$$,$b$jscomp$178$$,$c$jscomp$149$$){return Math.max($a$jscomp$220$$,$b$jscomp$178$$,$c$jscomp$149$$)};
$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$4$=function($a$jscomp$221$$,$b$jscomp$179$$,$c$jscomp$150$$,$d$jscomp$112$$){return Math.max($a$jscomp$221$$,$b$jscomp$179$$,$c$jscomp$150$$,$d$jscomp$112$$)};$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$5$=function($a$jscomp$222$$,$b$jscomp$180$$,$c$jscomp$151$$,$d$jscomp$113$$,$e$jscomp$132$$){return Math.max($a$jscomp$222$$,$b$jscomp$180$$,$c$jscomp$151$$,$d$jscomp$113$$,$e$jscomp$132$$)};
$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$6$=function($a$jscomp$223$$,$b$jscomp$181$$,$c$jscomp$152$$,$d$jscomp$114$$,$e$jscomp$133$$,$f$jscomp$361$$){return Math.max($a$jscomp$223$$,$b$jscomp$181$$,$c$jscomp$152$$,$d$jscomp$114$$,$e$jscomp$133$$,$f$jscomp$361$$)};
$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$variadic$=function($a$jscomp$224$$,$b$jscomp$182$$,$c$jscomp$153$$,$d$jscomp$115$$,$e$jscomp$134$$,$f$jscomp$362$$,$other$jscomp$126$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$data$max$$,Math.max($a$jscomp$224$$,$b$jscomp$182$$,$c$jscomp$153$$,$d$jscomp$115$$,$e$jscomp$134$$,$f$jscomp$362$$),$other$jscomp$126$$)};
$APP.$app$common$data$max$$.$cljs$lang$applyTo$=function($G__31630_seq31628$$){var $G__31629$$=$APP.$cljs$core$first$$($G__31630_seq31628$$),$G__31631_seq31628__$1$$=$APP.$cljs$core$next$$($G__31630_seq31628$$);$G__31630_seq31628$$=$APP.$cljs$core$first$$($G__31631_seq31628__$1$$);var $G__31632_seq31628__$2$$=$APP.$cljs$core$next$$($G__31631_seq31628__$1$$);$G__31631_seq31628__$1$$=$APP.$cljs$core$first$$($G__31632_seq31628__$2$$);var $G__31633_seq31628__$3$$=$APP.$cljs$core$next$$($G__31632_seq31628__$2$$);
$G__31632_seq31628__$2$$=$APP.$cljs$core$first$$($G__31633_seq31628__$3$$);var $G__31634_seq31628__$4$$=$APP.$cljs$core$next$$($G__31633_seq31628__$3$$);$G__31633_seq31628__$3$$=$APP.$cljs$core$first$$($G__31634_seq31628__$4$$);var $seq31628__$5_seq31628__$6$$=$APP.$cljs$core$next$$($G__31634_seq31628__$4$$);$G__31634_seq31628__$4$$=$APP.$cljs$core$first$$($seq31628__$5_seq31628__$6$$);$seq31628__$5_seq31628__$6$$=$APP.$cljs$core$next$$($seq31628__$5_seq31628__$6$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__31629$$,
$G__31630_seq31628$$,$G__31631_seq31628__$1$$,$G__31632_seq31628__$2$$,$G__31633_seq31628__$3$$,$G__31634_seq31628__$4$$,$seq31628__$5_seq31628__$6$$)};$APP.$app$common$data$max$$.$cljs$lang$maxFixedArity$=6;
$APP.$app$common$data$min$$=function $app$common$data$min$$($var_args$jscomp$402$$){switch(arguments.length){case 1:return $app$common$data$min$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$data$min$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$common$data$min$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$common$data$min$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],
arguments[3]);case 5:return $app$common$data$min$$.$cljs$core$IFn$_invoke$arity$5$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4]);case 6:return $app$common$data$min$$.$cljs$core$IFn$_invoke$arity$6$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5]);default:for(var $args_arr__5774__auto__$jscomp$79$$=[],$len__5749__auto___32188$$=arguments.length,$i__5750__auto___32189$$=0;;)if($i__5750__auto___32189$$<$len__5749__auto___32188$$)$args_arr__5774__auto__$jscomp$79$$.push(arguments[$i__5750__auto___32189$$]),
$i__5750__auto___32189$$+=1;else break;return $app$common$data$min$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],6<$args_arr__5774__auto__$jscomp$79$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$79$$.slice(6),0,null):null)}};$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$1$=function($a$jscomp$225$$){return $a$jscomp$225$$};
$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$2$=function($a$jscomp$226$$,$b$jscomp$183$$){return Math.min($a$jscomp$226$$,$b$jscomp$183$$)};$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$3$=function($a$jscomp$227$$,$b$jscomp$184$$,$c$jscomp$154$$){return Math.min($a$jscomp$227$$,$b$jscomp$184$$,$c$jscomp$154$$)};
$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$4$=function($a$jscomp$228$$,$b$jscomp$185$$,$c$jscomp$155$$,$d$jscomp$116$$){return Math.min($a$jscomp$228$$,$b$jscomp$185$$,$c$jscomp$155$$,$d$jscomp$116$$)};$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$5$=function($a$jscomp$229$$,$b$jscomp$186$$,$c$jscomp$156$$,$d$jscomp$117$$,$e$jscomp$135$$){return Math.min($a$jscomp$229$$,$b$jscomp$186$$,$c$jscomp$156$$,$d$jscomp$117$$,$e$jscomp$135$$)};
$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$6$=function($a$jscomp$230$$,$b$jscomp$187$$,$c$jscomp$157$$,$d$jscomp$118$$,$e$jscomp$136$$,$f$jscomp$363$$){return Math.min($a$jscomp$230$$,$b$jscomp$187$$,$c$jscomp$157$$,$d$jscomp$118$$,$e$jscomp$136$$,$f$jscomp$363$$)};
$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$variadic$=function($a$jscomp$231$$,$b$jscomp$188$$,$c$jscomp$158$$,$d$jscomp$119$$,$e$jscomp$137$$,$f$jscomp$364$$,$other$jscomp$127$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$data$min$$,Math.min($a$jscomp$231$$,$b$jscomp$188$$,$c$jscomp$158$$,$d$jscomp$119$$,$e$jscomp$137$$,$f$jscomp$364$$),$other$jscomp$127$$)};
$APP.$app$common$data$min$$.$cljs$lang$applyTo$=function($G__31661_seq31659$$){var $G__31660$$=$APP.$cljs$core$first$$($G__31661_seq31659$$),$G__31662_seq31659__$1$$=$APP.$cljs$core$next$$($G__31661_seq31659$$);$G__31661_seq31659$$=$APP.$cljs$core$first$$($G__31662_seq31659__$1$$);var $G__31663_seq31659__$2$$=$APP.$cljs$core$next$$($G__31662_seq31659__$1$$);$G__31662_seq31659__$1$$=$APP.$cljs$core$first$$($G__31663_seq31659__$2$$);var $G__31664_seq31659__$3$$=$APP.$cljs$core$next$$($G__31663_seq31659__$2$$);
$G__31663_seq31659__$2$$=$APP.$cljs$core$first$$($G__31664_seq31659__$3$$);var $G__31665_seq31659__$4$$=$APP.$cljs$core$next$$($G__31664_seq31659__$3$$);$G__31664_seq31659__$3$$=$APP.$cljs$core$first$$($G__31665_seq31659__$4$$);var $seq31659__$5_seq31659__$6$$=$APP.$cljs$core$next$$($G__31665_seq31659__$4$$);$G__31665_seq31659__$4$$=$APP.$cljs$core$first$$($seq31659__$5_seq31659__$6$$);$seq31659__$5_seq31659__$6$$=$APP.$cljs$core$next$$($seq31659__$5_seq31659__$6$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__31660$$,
$G__31661_seq31659$$,$G__31662_seq31659__$1$$,$G__31663_seq31659__$2$$,$G__31664_seq31659__$3$$,$G__31665_seq31659__$4$$,$seq31659__$5_seq31659__$6$$)};$APP.$app$common$data$min$$.$cljs$lang$maxFixedArity$=6;
var $app$common$data$toggle_selection$$=function $app$common$data$toggle_selection$$($var_args$jscomp$406$$){switch(arguments.length){case 2:return $app$common$data$toggle_selection$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$common$data$toggle_selection$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$common$data$toggle_selection$$.$cljs$core$IFn$_invoke$arity$2$=function($set$$,$value$jscomp$224$$){return $app$common$data$toggle_selection$$.$cljs$core$IFn$_invoke$arity$3$($set$$,$value$jscomp$224$$,!1)};
$app$common$data$toggle_selection$$.$cljs$core$IFn$_invoke$arity$3$=function($set$jscomp$1$$,$value$jscomp$225$$,$toggle_QMARK_$$){return $APP.$cljs$core$not$$($toggle_QMARK_$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$value$jscomp$225$$):$APP.$cljs$core$contains_QMARK_$$($set$jscomp$1$$,$value$jscomp$225$$)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($set$jscomp$1$$,$value$jscomp$225$$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($set$jscomp$1$$,
$value$jscomp$225$$)};$app$common$data$toggle_selection$$.$cljs$lang$maxFixedArity$=3;$APP.$JSCompiler_prototypeAlias$$=$me$flowthing$pp$t_me$0flowthing$0pp24586$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_24588$$,$meta24587__$1$$){return new $me$flowthing$pp$t_me$0flowthing$0pp24586$$(this.$writer$,this.$opts$,this.$max_width$,this.c,$meta24587__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta24587$};
$APP.$JSCompiler_prototypeAlias$$.$me$flowthing$pp$CountKeepingWriter$write$arity$2$=function($JSCompiler_temp_const$jscomp$316__$jscomp$208$$,$JSCompiler_inline_result$jscomp$317_s$jscomp$296$$){$APP.$cljs$core$_write$$(this.$writer$,$JSCompiler_inline_result$jscomp$317_s$jscomp$296$$);$JSCompiler_temp_const$jscomp$316__$jscomp$208$$=this.c;$JSCompiler_inline_result$jscomp$317_s$jscomp$296$$=$APP.$cljs$core$_deref$$(this.c)+$JSCompiler_inline_result$jscomp$317_s$jscomp$296$$.length;$APP.$cljs$core$_vreset_BANG_$$($JSCompiler_temp_const$jscomp$316__$jscomp$208$$,
$JSCompiler_inline_result$jscomp$317_s$jscomp$296$$);return null};$APP.$JSCompiler_prototypeAlias$$.$me$flowthing$pp$CountKeepingWriter$remaining$arity$1$=function(){return this.$max_width$-$APP.$cljs$core$_deref$$(this.c)};$APP.$JSCompiler_prototypeAlias$$.$me$flowthing$pp$CountKeepingWriter$nl$arity$1$=function(){$APP.$cljs$core$_write$$(this.$writer$,"\n");$APP.$cljs$core$_vreset_BANG_$$(this.c,0);return null};
var $me$flowthing$pp$reader_macros$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$167$quote$$,"'",$APP.$cljs$cst$166$var$$,"#'",$APP.$cljs$cst$248$clojure_DOT_core_SLASH_deref$$,"@",$APP.$cljs$cst$234$clojure_DOT_core_SLASH_unquote$$,"~",$cljs$cst$282$cljs_DOT_core_SLASH_deref$$,"@",$cljs$cst$283$cljs_DOT_core_SLASH_unquote$$,"~"],null);$APP.$app$common$json$__GT_js$$=function $app$common$json$__GT_js$$($var_args$jscomp$416$$){for(var $args__5755__auto__$jscomp$41$$=[],$len__5749__auto___31123$$=arguments.length,$i__5750__auto___31124$$=0;;)if($i__5750__auto___31124$$<$len__5749__auto___31123$$)$args__5755__auto__$jscomp$41$$.push(arguments[$i__5750__auto___31124$$]),$i__5750__auto___31124$$+=1;else break;return $app$common$json$__GT_js$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args__5755__auto__$jscomp$41$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$41$$.slice(1),0,null):null)};
$APP.$app$common$json$__GT_js$$.$cljs$core$IFn$_invoke$arity$variadic$=function($x$jscomp$692$$,$map__31092__$1_p__31091$$){$map__31092__$1_p__31091$$=$APP.$cljs$core$__destructure_map$$($map__31092__$1_p__31091$$);var $key_fn$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__31092__$1_p__31091$$,$APP.$cljs$cst$291$key_fn$$,$APP.$app$common$json$write_camel_key$$);return function $app$common$json$this_fn$$($x__$1$jscomp$13$$){return $x__$1$jscomp$13$$==null?null:($x__$1$jscomp$13$$!=null?
$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x__$1$jscomp$13$$.$cljs$core$IEncodeJS$$||($x__$1$jscomp$13$$.$cljs$lang$protocol_mask$partition$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IEncodeJS$$,$x__$1$jscomp$13$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IEncodeJS$$,$x__$1$jscomp$13$$))?$cljs$core$_clj__GT_js$$($x__$1$jscomp$13$$):$x__$1$jscomp$13$$ instanceof $APP.$cljs$core$Keyword$$||$x__$1$jscomp$13$$ instanceof $APP.$cljs$core$Symbol$$?$APP.$cljs$core$name$$($x__$1$jscomp$13$$):
typeof $x__$1$jscomp$13$$==="number"?$x__$1$jscomp$13$$:$APP.$cljs$core$boolean_QMARK_$$($x__$1$jscomp$13$$)?$x__$1$jscomp$13$$:$APP.$cljs$core$map_QMARK_$$($x__$1$jscomp$13$$)?$APP.$cljs$core$reduce_kv$$(function($m$jscomp$104$$,$k$jscomp$275_k__$1$jscomp$2$$,$v$jscomp$152$$){$k$jscomp$275_k__$1$jscomp$2$$=$key_fn$$.$cljs$core$IFn$_invoke$arity$1$?$key_fn$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$275_k__$1$jscomp$2$$):$key_fn$$($k$jscomp$275_k__$1$jscomp$2$$);$m$jscomp$104$$[$k$jscomp$275_k__$1$jscomp$2$$]=
$app$common$json$this_fn$$($v$jscomp$152$$);return $m$jscomp$104$$},{},$x__$1$jscomp$13$$):$APP.$cljs$core$coll_QMARK_$$($x__$1$jscomp$13$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($arr$jscomp$138$$,$v$jscomp$153$$){$arr$jscomp$138$$.push($app$common$json$this_fn$$($v$jscomp$153$$));return $arr$jscomp$138$$},[],$x__$1$jscomp$13$$):$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($x__$1$jscomp$13$$)}($x$jscomp$692$$)};
$APP.$app$common$json$__GT_js$$.$cljs$lang$maxFixedArity$=1;$APP.$app$common$json$__GT_js$$.$cljs$lang$applyTo$=function($seq31089_seq31089__$1$$){var $G__31090$$=$APP.$cljs$core$first$$($seq31089_seq31089__$1$$);$seq31089_seq31089__$1$$=$APP.$cljs$core$next$$($seq31089_seq31089__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__31090$$,$seq31089_seq31089__$1$$)};
$APP.$app$common$json$encode$$=function $app$common$json$encode$$($var_args$jscomp$418$$){for(var $args__5755__auto__$jscomp$43$$=[],$len__5749__auto___31133$$=arguments.length,$i__5750__auto___31134$$=0;;)if($i__5750__auto___31134$$<$len__5749__auto___31133$$)$args__5755__auto__$jscomp$43$$.push(arguments[$i__5750__auto___31134$$]),$i__5750__auto___31134$$+=1;else break;return $app$common$json$encode$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args__5755__auto__$jscomp$43$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$43$$.slice(1),
0,null):null)};$APP.$app$common$json$encode$$.$cljs$core$IFn$_invoke$arity$variadic$=function($data$jscomp$96$$,$opts$jscomp$139_p__31116$$){$opts$jscomp$139_p__31116$$=$APP.$cljs$core$__destructure_map$$($opts$jscomp$139_p__31116$$);return JSON.stringify($APP.$app$common$json$__GT_js$$.$cljs$core$IFn$_invoke$arity$variadic$($data$jscomp$96$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$opts$jscomp$139_p__31116$$])),null,$APP.$cljs$cst$294$indent$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$139_p__31116$$))};
$APP.$app$common$json$encode$$.$cljs$lang$maxFixedArity$=1;$APP.$app$common$json$encode$$.$cljs$lang$applyTo$=function($seq31110_seq31110__$1$$){var $G__31111$$=$APP.$cljs$core$first$$($seq31110_seq31110__$1$$);$seq31110_seq31110__$1$$=$APP.$cljs$core$next$$($seq31110_seq31110__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__31111$$,$seq31110_seq31110__$1$$)};var $malli$impl$util$_PLUS_max_size_PLUS_$$=Number.MAX_VALUE;var $malli$impl$regex$cat_validator$$=function $malli$impl$regex$cat_validator$$($var_args$jscomp$422$$){switch(arguments.length){case 0:return $malli$impl$regex$cat_validator$$.$cljs$core$IFn$_invoke$arity$0$();default:for(var $args_arr__5774__auto__$jscomp$80$$=[],$len__5749__auto___25717$$=arguments.length,$i__5750__auto___25718$$=0;;)if($i__5750__auto___25718$$<$len__5749__auto___25717$$)$args_arr__5774__auto__$jscomp$80$$.push(arguments[$i__5750__auto___25718$$]),$i__5750__auto___25718$$+=1;
else break;return $malli$impl$regex$cat_validator$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args_arr__5774__auto__$jscomp$80$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$80$$.slice(1),0,null):null)}};
$malli$impl$regex$cat_validator$$.$cljs$core$IFn$_invoke$arity$0$=function(){return function($_$jscomp$222$$,$___$1$jscomp$69$$,$pos$jscomp$28$$,$coll$jscomp$928$$,$k$jscomp$300$$){return $k$jscomp$300$$.$cljs$core$IFn$_invoke$arity$2$?$k$jscomp$300$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$28$$,$coll$jscomp$928$$):$k$jscomp$300$$($pos$jscomp$28$$,$coll$jscomp$928$$)}};
$malli$impl$regex$cat_validator$$.$cljs$core$IFn$_invoke$arity$variadic$=function($_QMARK_kr$jscomp$1$$,$_QMARK_krs$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$13$$,$_QMARK_kr__$1$$){var $r_STAR_$$=$malli$impl$regex$entry__GT_regex$$($_QMARK_kr__$1$$);return function($driver$jscomp$15$$,$regs$jscomp$13$$,$pos$jscomp$29$$,$coll$jscomp$929$$,$k$jscomp$301$$){function $G__25001$$($pos__$1$jscomp$1$$,$coll__$1$jscomp$489$$){return $r_STAR_$$.$cljs$core$IFn$_invoke$arity$5$?
$r_STAR_$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$15$$,$regs$jscomp$13$$,$pos__$1$jscomp$1$$,$coll__$1$jscomp$489$$,$k$jscomp$301$$):$r_STAR_$$($driver$jscomp$15$$,$regs$jscomp$13$$,$pos__$1$jscomp$1$$,$coll__$1$jscomp$489$$,$k$jscomp$301$$)}return $acc$jscomp$13$$.$cljs$core$IFn$_invoke$arity$5$?$acc$jscomp$13$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$15$$,$regs$jscomp$13$$,$pos$jscomp$29$$,$coll$jscomp$929$$,$G__25001$$):$acc$jscomp$13$$($driver$jscomp$15$$,$regs$jscomp$13$$,$pos$jscomp$29$$,
$coll$jscomp$929$$,$G__25001$$)}},$malli$impl$regex$entry__GT_regex$$($_QMARK_kr$jscomp$1$$),$_QMARK_krs$$)};$malli$impl$regex$cat_validator$$.$cljs$lang$applyTo$=function($seq24989_seq24989__$1$$){var $G__24990$$=$APP.$cljs$core$first$$($seq24989_seq24989__$1$$);$seq24989_seq24989__$1$$=$APP.$cljs$core$next$$($seq24989_seq24989__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__24990$$,$seq24989_seq24989__$1$$)};$malli$impl$regex$cat_validator$$.$cljs$lang$maxFixedArity$=1;
var $malli$impl$regex$cat_explainer$$=function $malli$impl$regex$cat_explainer$$($var_args$jscomp$423$$){switch(arguments.length){case 0:return $malli$impl$regex$cat_explainer$$.$cljs$core$IFn$_invoke$arity$0$();default:for(var $args_arr__5774__auto__$jscomp$81$$=[],$len__5749__auto___25732$$=arguments.length,$i__5750__auto___25738$$=0;;)if($i__5750__auto___25738$$<$len__5749__auto___25732$$)$args_arr__5774__auto__$jscomp$81$$.push(arguments[$i__5750__auto___25738$$]),$i__5750__auto___25738$$+=1;
else break;return $malli$impl$regex$cat_explainer$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args_arr__5774__auto__$jscomp$81$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$81$$.slice(1),0,null):null)}};
$malli$impl$regex$cat_explainer$$.$cljs$core$IFn$_invoke$arity$0$=function(){return function($_$jscomp$223$$,$___$1$jscomp$70$$,$pos$jscomp$30$$,$coll$jscomp$930$$,$k$jscomp$302$$){return $k$jscomp$302$$.$cljs$core$IFn$_invoke$arity$2$?$k$jscomp$302$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$30$$,$coll$jscomp$930$$):$k$jscomp$302$$($pos$jscomp$30$$,$coll$jscomp$930$$)}};
$malli$impl$regex$cat_explainer$$.$cljs$core$IFn$_invoke$arity$variadic$=function($_QMARK_kr$jscomp$2$$,$_QMARK_krs$jscomp$1$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$14$$,$_QMARK_kr__$1$jscomp$1$$){var $r_STAR_$jscomp$1$$=$malli$impl$regex$entry__GT_regex$$($_QMARK_kr__$1$jscomp$1$$);return function($driver$jscomp$16$$,$regs$jscomp$14$$,$pos$jscomp$31$$,$coll$jscomp$931$$,$k$jscomp$303$$){function $G__25018$$($pos__$1$jscomp$2$$,$coll__$1$jscomp$490$$){return $r_STAR_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$5$?
$r_STAR_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$16$$,$regs$jscomp$14$$,$pos__$1$jscomp$2$$,$coll__$1$jscomp$490$$,$k$jscomp$303$$):$r_STAR_$jscomp$1$$($driver$jscomp$16$$,$regs$jscomp$14$$,$pos__$1$jscomp$2$$,$coll__$1$jscomp$490$$,$k$jscomp$303$$)}return $acc$jscomp$14$$.$cljs$core$IFn$_invoke$arity$5$?$acc$jscomp$14$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$16$$,$regs$jscomp$14$$,$pos$jscomp$31$$,$coll$jscomp$931$$,$G__25018$$):$acc$jscomp$14$$($driver$jscomp$16$$,$regs$jscomp$14$$,
$pos$jscomp$31$$,$coll$jscomp$931$$,$G__25018$$)}},$malli$impl$regex$entry__GT_regex$$($_QMARK_kr$jscomp$2$$),$_QMARK_krs$jscomp$1$$)};$malli$impl$regex$cat_explainer$$.$cljs$lang$applyTo$=function($seq25003_seq25003__$1$$){var $G__25004$$=$APP.$cljs$core$first$$($seq25003_seq25003__$1$$);$seq25003_seq25003__$1$$=$APP.$cljs$core$next$$($seq25003_seq25003__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__25004$$,$seq25003_seq25003__$1$$)};
$malli$impl$regex$cat_explainer$$.$cljs$lang$maxFixedArity$=1;
var $malli$impl$regex$cat_parser$$=function $malli$impl$regex$cat_parser$$($var_args$jscomp$424$$){switch(arguments.length){case 0:return $malli$impl$regex$cat_parser$$.$cljs$core$IFn$_invoke$arity$0$();default:for(var $args_arr__5774__auto__$jscomp$82$$=[],$len__5749__auto___25770$$=arguments.length,$i__5750__auto___25771$$=0;;)if($i__5750__auto___25771$$<$len__5749__auto___25770$$)$args_arr__5774__auto__$jscomp$82$$.push(arguments[$i__5750__auto___25771$$]),$i__5750__auto___25771$$+=1;else break;
return $malli$impl$regex$cat_parser$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args_arr__5774__auto__$jscomp$82$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$82$$.slice(1),0,null):null)}};
$malli$impl$regex$cat_parser$$.$cljs$core$IFn$_invoke$arity$0$=function(){return function($G__25027__$jscomp$224$$,$___$1$jscomp$71$$,$pos$jscomp$32$$,$coll$jscomp$932$$,$k$jscomp$304$$){$G__25027__$jscomp$224$$=$APP.$cljs$core$PersistentVector$EMPTY$$;return $k$jscomp$304$$.$cljs$core$IFn$_invoke$arity$3$?$k$jscomp$304$$.$cljs$core$IFn$_invoke$arity$3$($G__25027__$jscomp$224$$,$pos$jscomp$32$$,$coll$jscomp$932$$):$k$jscomp$304$$($G__25027__$jscomp$224$$,$pos$jscomp$32$$,$coll$jscomp$932$$)}};
$malli$impl$regex$cat_parser$$.$cljs$core$IFn$_invoke$arity$variadic$=function($r$jscomp$39$$,$rs$$){var $sp$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$15$$,$r__$1$$){return function($driver$jscomp$17$$,$regs$jscomp$15$$,$coll_STAR_$jscomp$7$$,$pos$jscomp$33$$,$coll$jscomp$933$$,$k$jscomp$305$$){function $G__25036$$($G__25042_v$jscomp$165$$,$pos__$1$jscomp$3$$,$coll__$1$jscomp$491$$){$G__25042_v$jscomp$165$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($coll_STAR_$jscomp$7$$,
$G__25042_v$jscomp$165$$);return $acc$jscomp$15$$.$cljs$core$IFn$_invoke$arity$6$?$acc$jscomp$15$$.$cljs$core$IFn$_invoke$arity$6$($driver$jscomp$17$$,$regs$jscomp$15$$,$G__25042_v$jscomp$165$$,$pos__$1$jscomp$3$$,$coll__$1$jscomp$491$$,$k$jscomp$305$$):$acc$jscomp$15$$($driver$jscomp$17$$,$regs$jscomp$15$$,$G__25042_v$jscomp$165$$,$pos__$1$jscomp$3$$,$coll__$1$jscomp$491$$,$k$jscomp$305$$)}return $r__$1$$.$cljs$core$IFn$_invoke$arity$5$?$r__$1$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$17$$,
$regs$jscomp$15$$,$pos$jscomp$33$$,$coll$jscomp$933$$,$G__25036$$):$r__$1$$($driver$jscomp$17$$,$regs$jscomp$15$$,$pos$jscomp$33$$,$coll$jscomp$933$$,$G__25036$$)}},function($_$jscomp$225$$,$___$1$jscomp$72$$,$coll_STAR_$jscomp$8$$,$pos$jscomp$34$$,$coll$jscomp$934$$,$k$jscomp$306$$){return $k$jscomp$306$$.$cljs$core$IFn$_invoke$arity$3$?$k$jscomp$306$$.$cljs$core$IFn$_invoke$arity$3$($coll_STAR_$jscomp$8$$,$pos$jscomp$34$$,$coll$jscomp$934$$):$k$jscomp$306$$($coll_STAR_$jscomp$8$$,$pos$jscomp$34$$,
$coll$jscomp$934$$)},$APP.$cljs$core$reverse$$($APP.$cljs$core$cons$$($r$jscomp$39$$,$rs$$)));return function($driver$jscomp$18$$,$regs$jscomp$16$$,$pos$jscomp$35$$,$coll$jscomp$935$$,$k$jscomp$307$$){var $G__25052$$=$APP.$cljs$core$PersistentVector$EMPTY$$;return $sp$$.$cljs$core$IFn$_invoke$arity$6$?$sp$$.$cljs$core$IFn$_invoke$arity$6$($driver$jscomp$18$$,$regs$jscomp$16$$,$G__25052$$,$pos$jscomp$35$$,$coll$jscomp$935$$,$k$jscomp$307$$):$sp$$($driver$jscomp$18$$,$regs$jscomp$16$$,$G__25052$$,$pos$jscomp$35$$,
$coll$jscomp$935$$,$k$jscomp$307$$)}};$malli$impl$regex$cat_parser$$.$cljs$lang$applyTo$=function($seq25022_seq25022__$1$$){var $G__25023$$=$APP.$cljs$core$first$$($seq25022_seq25022__$1$$);$seq25022_seq25022__$1$$=$APP.$cljs$core$next$$($seq25022_seq25022__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__25023$$,$seq25022_seq25022__$1$$)};$malli$impl$regex$cat_parser$$.$cljs$lang$maxFixedArity$=1;
var $malli$impl$regex$catn_parser$$=function $malli$impl$regex$catn_parser$$($var_args$jscomp$425$$){switch(arguments.length){case 1:return $malli$impl$regex$catn_parser$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:for(var $args_arr__5774__auto__$jscomp$83$$=[],$len__5749__auto___25780$$=arguments.length,$i__5750__auto___25782$$=0;;)if($i__5750__auto___25782$$<$len__5749__auto___25780$$)$args_arr__5774__auto__$jscomp$83$$.push(arguments[$i__5750__auto___25782$$]),$i__5750__auto___25782$$+=
1;else break;return $malli$impl$regex$catn_parser$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$83$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$83$$.slice(2),0,null):null)}};
$malli$impl$regex$catn_parser$$.$cljs$core$IFn$_invoke$arity$1$=function($tags$jscomp$3$$){return function($G__25076_G__25079$jscomp$inline_3272__$jscomp$226$$,$___$1$jscomp$73$$,$pos$jscomp$36$$,$coll$jscomp$936$$,$k$jscomp$308$$){$G__25076_G__25079$jscomp$inline_3272__$jscomp$226$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;$G__25076_G__25079$jscomp$inline_3272__$jscomp$226$$=$tags$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$tags$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($G__25076_G__25079$jscomp$inline_3272__$jscomp$226$$):
$tags$jscomp$3$$($G__25076_G__25079$jscomp$inline_3272__$jscomp$226$$);return $k$jscomp$308$$.$cljs$core$IFn$_invoke$arity$3$?$k$jscomp$308$$.$cljs$core$IFn$_invoke$arity$3$($G__25076_G__25079$jscomp$inline_3272__$jscomp$226$$,$pos$jscomp$36$$,$coll$jscomp$936$$):$k$jscomp$308$$($G__25076_G__25079$jscomp$inline_3272__$jscomp$226$$,$pos$jscomp$36$$,$coll$jscomp$936$$)}};
$malli$impl$regex$catn_parser$$.$cljs$core$IFn$_invoke$arity$variadic$=function($tags$jscomp$4$$,$kr$$,$krs$$){var $sp$jscomp$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$16$$,$p__25080$$){var $tag$jscomp$24$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__25080$$,0,null),$r$jscomp$40$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__25080$$,1,null);return function($driver$jscomp$19$$,$regs$jscomp$17$$,$m$jscomp$106$$,$pos$jscomp$37$$,
$coll$jscomp$937$$,$k$jscomp$309$$){function $G__25088$$($G__25091_v$jscomp$166$$,$pos__$1$jscomp$4$$,$coll__$1$jscomp$492$$){$G__25091_v$jscomp$166$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$106$$,$tag$jscomp$24$$,$G__25091_v$jscomp$166$$);return $acc$jscomp$16$$.$cljs$core$IFn$_invoke$arity$6$?$acc$jscomp$16$$.$cljs$core$IFn$_invoke$arity$6$($driver$jscomp$19$$,$regs$jscomp$17$$,$G__25091_v$jscomp$166$$,$pos__$1$jscomp$4$$,$coll__$1$jscomp$492$$,$k$jscomp$309$$):$acc$jscomp$16$$($driver$jscomp$19$$,
$regs$jscomp$17$$,$G__25091_v$jscomp$166$$,$pos__$1$jscomp$4$$,$coll__$1$jscomp$492$$,$k$jscomp$309$$)}return $r$jscomp$40$$.$cljs$core$IFn$_invoke$arity$5$?$r$jscomp$40$$.$cljs$core$IFn$_invoke$arity$5$($driver$jscomp$19$$,$regs$jscomp$17$$,$pos$jscomp$37$$,$coll$jscomp$937$$,$G__25088$$):$r$jscomp$40$$($driver$jscomp$19$$,$regs$jscomp$17$$,$pos$jscomp$37$$,$coll$jscomp$937$$,$G__25088$$)}},function($G__25096__$jscomp$227$$,$___$1$jscomp$74$$,$m$jscomp$107$$,$pos$jscomp$38$$,$coll$jscomp$938$$,$k$jscomp$310$$){$G__25096__$jscomp$227$$=
$tags$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$tags$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($m$jscomp$107$$):$tags$jscomp$4$$($m$jscomp$107$$);return $k$jscomp$310$$.$cljs$core$IFn$_invoke$arity$3$?$k$jscomp$310$$.$cljs$core$IFn$_invoke$arity$3$($G__25096__$jscomp$227$$,$pos$jscomp$38$$,$coll$jscomp$938$$):$k$jscomp$310$$($G__25096__$jscomp$227$$,$pos$jscomp$38$$,$coll$jscomp$938$$)},$APP.$cljs$core$reverse$$($APP.$cljs$core$cons$$($kr$$,$krs$$)));return function($driver$jscomp$20$$,$regs$jscomp$18$$,
$pos$jscomp$39$$,$coll$jscomp$939$$,$k$jscomp$311$$){var $G__25104$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $sp$jscomp$1$$.$cljs$core$IFn$_invoke$arity$6$?$sp$jscomp$1$$.$cljs$core$IFn$_invoke$arity$6$($driver$jscomp$20$$,$regs$jscomp$18$$,$G__25104$$,$pos$jscomp$39$$,$coll$jscomp$939$$,$k$jscomp$311$$):$sp$jscomp$1$$($driver$jscomp$20$$,$regs$jscomp$18$$,$G__25104$$,$pos$jscomp$39$$,$coll$jscomp$939$$,$k$jscomp$311$$)}};
$malli$impl$regex$catn_parser$$.$cljs$lang$applyTo$=function($G__25061_seq25059$$){var $G__25060$$=$APP.$cljs$core$first$$($G__25061_seq25059$$),$seq25059__$1_seq25059__$2$$=$APP.$cljs$core$next$$($G__25061_seq25059$$);$G__25061_seq25059$$=$APP.$cljs$core$first$$($seq25059__$1_seq25059__$2$$);$seq25059__$1_seq25059__$2$$=$APP.$cljs$core$next$$($seq25059__$1_seq25059__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__25060$$,$G__25061_seq25059$$,$seq25059__$1_seq25059__$2$$)};
$malli$impl$regex$catn_parser$$.$cljs$lang$maxFixedArity$=2;
var $malli$impl$regex$cat_unparser$$=function $malli$impl$regex$cat_unparser$$($var_args$jscomp$426$$){for(var $args__5755__auto__$jscomp$45$$=[],$len__5749__auto___25793$$=arguments.length,$i__5750__auto___25794$$=0;;)if($i__5750__auto___25794$$<$len__5749__auto___25793$$)$args__5755__auto__$jscomp$45$$.push(arguments[$i__5750__auto___25794$$]),$i__5750__auto___25794$$+=1;else break;return $malli$impl$regex$cat_unparser$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$45$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$45$$.slice(0),0,null):null)};
$malli$impl$regex$cat_unparser$$.$cljs$core$IFn$_invoke$arity$variadic$=function($unparsers$$){var $unparsers__$1$$=$APP.$cljs$core$vec$$($unparsers$$);return function($tup$$){return $APP.$cljs$core$vector_QMARK_$$($tup$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($tup$$),$APP.$cljs$core$count$$($unparsers__$1$$))?$malli$impl$util$_reduce_kv_valid$$(function($coll$jscomp$940$$,$i$jscomp$294$$,$unparser$$){return $malli$impl$util$_map_valid$$(function($p1__25112_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($coll$jscomp$940$$,
$p1__25112_SHARP_$$)},function(){var $G__25120$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tup$$,$i$jscomp$294$$);return $unparser$$.$cljs$core$IFn$_invoke$arity$1$?$unparser$$.$cljs$core$IFn$_invoke$arity$1$($G__25120$$):$unparser$$($G__25120$$)}())},$unparsers__$1$$):$cljs$cst$295$malli_DOT_core_SLASH_invalid$$}};$malli$impl$regex$cat_unparser$$.$cljs$lang$maxFixedArity$=0;$malli$impl$regex$cat_unparser$$.$cljs$lang$applyTo$=function($seq25116$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq25116$$))};
var $malli$impl$regex$catn_unparser$$=function $malli$impl$regex$catn_unparser$$($var_args$jscomp$427$$){for(var $args__5755__auto__$jscomp$46$$=[],$len__5749__auto___25796$$=arguments.length,$i__5750__auto___25797$$=0;;)if($i__5750__auto___25797$$<$len__5749__auto___25796$$)$args__5755__auto__$jscomp$46$$.push(arguments[$i__5750__auto___25797$$]),$i__5750__auto___25797$$+=1;else break;return $malli$impl$regex$catn_unparser$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args__5755__auto__$jscomp$46$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$46$$.slice(1),0,null):null)};
$malli$impl$regex$catn_unparser$$.$cljs$core$IFn$_invoke$arity$variadic$=function($tags_QMARK_$$,$unparsers$jscomp$1$$){var $unparsers__$1$jscomp$1$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$array_map$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$identity$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$unparsers$jscomp$1$$])));return function($m$jscomp$108$$){return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$56$$=
$tags_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$tags_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($m$jscomp$108$$):$tags_QMARK_$$($m$jscomp$108$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$56$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($APP.$cljs$cst$301$values$$.$cljs$core$IFn$_invoke$arity$1$($m$jscomp$108$$)),$APP.$cljs$core$count$$($unparsers__$1$jscomp$1$$)):$and__5023__auto__$jscomp$56$$}())?$malli$impl$util$_reduce_kv_valid$$(function($coll$jscomp$941$$,
$tag$jscomp$25$$,$unparser$jscomp$1$$){var $temp__5827__auto__$jscomp$4$$=$cljs$core$find$$($APP.$cljs$cst$301$values$$.$cljs$core$IFn$_invoke$arity$1$($m$jscomp$108$$),$tag$jscomp$25$$);return $temp__5827__auto__$jscomp$4$$==null?$cljs$cst$295$malli_DOT_core_SLASH_invalid$$:$malli$impl$util$_map_valid$$(function($p1__25124_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($coll$jscomp$941$$,$p1__25124_SHARP_$$)},function(){var $G__25131$$=$APP.$cljs$core$_val$$($temp__5827__auto__$jscomp$4$$);
return $unparser$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$unparser$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__25131$$):$unparser$jscomp$1$$($G__25131$$)}())},$unparsers__$1$jscomp$1$$):$cljs$cst$295$malli_DOT_core_SLASH_invalid$$}};$malli$impl$regex$catn_unparser$$.$cljs$lang$maxFixedArity$=1;
$malli$impl$regex$catn_unparser$$.$cljs$lang$applyTo$=function($seq25125_seq25125__$1$$){var $G__25126$$=$APP.$cljs$core$first$$($seq25125_seq25125__$1$$);$seq25125_seq25125__$1$$=$APP.$cljs$core$next$$($seq25125_seq25125__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__25126$$,$seq25125_seq25125__$1$$)};
var $malli$impl$regex$cat_transformer$$=function $malli$impl$regex$cat_transformer$$($var_args$jscomp$428$$){switch(arguments.length){case 0:return $malli$impl$regex$cat_transformer$$.$cljs$core$IFn$_invoke$arity$0$();default:for(var $args_arr__5774__auto__$jscomp$84$$=[],$len__5749__auto___25806$$=arguments.length,$i__5750__auto___25807$$=0;;)if($i__5750__auto___25807$$<$len__5749__auto___25806$$)$args_arr__5774__auto__$jscomp$84$$.push(arguments[$i__5750__auto___25807$$]),$i__5750__auto___25807$$+=
1;else break;return $malli$impl$regex$cat_transformer$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args_arr__5774__auto__$jscomp$84$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$84$$.slice(1),0,null):null)}};
$malli$impl$regex$cat_transformer$$.$cljs$core$IFn$_invoke$arity$0$=function(){return function($_$jscomp$228$$,$___$1$jscomp$75$$,$coll_STAR_$jscomp$9$$,$pos$jscomp$40$$,$coll$jscomp$942$$,$k$jscomp$312$$){return $k$jscomp$312$$.$cljs$core$IFn$_invoke$arity$3$?$k$jscomp$312$$.$cljs$core$IFn$_invoke$arity$3$($coll_STAR_$jscomp$9$$,$pos$jscomp$40$$,$coll$jscomp$942$$):$k$jscomp$312$$($coll_STAR_$jscomp$9$$,$pos$jscomp$40$$,$coll$jscomp$942$$)}};
$malli$impl$regex$cat_transformer$$.$cljs$core$IFn$_invoke$arity$variadic$=function($_QMARK_kr$jscomp$3$$,$_QMARK_krs$jscomp$2$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$17$$,$_QMARK_kr__$1$jscomp$2$$){var $r$jscomp$41$$=$malli$impl$regex$entry__GT_regex$$($_QMARK_kr__$1$jscomp$2$$);return function($driver$jscomp$21$$,$regs$jscomp$19$$,$coll_STAR_$jscomp$10$$,$pos$jscomp$41$$,$coll$jscomp$943$$,$k$jscomp$313$$){function $G__25150$$($coll_STAR___$1$$,
$pos__$1$jscomp$5$$,$coll__$1$jscomp$493$$){return $r$jscomp$41$$.$cljs$core$IFn$_invoke$arity$6$?$r$jscomp$41$$.$cljs$core$IFn$_invoke$arity$6$($driver$jscomp$21$$,$regs$jscomp$19$$,$coll_STAR___$1$$,$pos__$1$jscomp$5$$,$coll__$1$jscomp$493$$,$k$jscomp$313$$):$r$jscomp$41$$($driver$jscomp$21$$,$regs$jscomp$19$$,$coll_STAR___$1$$,$pos__$1$jscomp$5$$,$coll__$1$jscomp$493$$,$k$jscomp$313$$)}return $acc$jscomp$17$$.$cljs$core$IFn$_invoke$arity$6$?$acc$jscomp$17$$.$cljs$core$IFn$_invoke$arity$6$($driver$jscomp$21$$,
$regs$jscomp$19$$,$coll_STAR_$jscomp$10$$,$pos$jscomp$41$$,$coll$jscomp$943$$,$G__25150$$):$acc$jscomp$17$$($driver$jscomp$21$$,$regs$jscomp$19$$,$coll_STAR_$jscomp$10$$,$pos$jscomp$41$$,$coll$jscomp$943$$,$G__25150$$)}},$malli$impl$regex$entry__GT_regex$$($_QMARK_kr$jscomp$3$$),$_QMARK_krs$jscomp$2$$)};
$malli$impl$regex$cat_transformer$$.$cljs$lang$applyTo$=function($seq25135_seq25135__$1$$){var $G__25136$$=$APP.$cljs$core$first$$($seq25135_seq25135__$1$$);$seq25135_seq25135__$1$$=$APP.$cljs$core$next$$($seq25135_seq25135__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__25136$$,$seq25135_seq25135__$1$$)};$malli$impl$regex$cat_transformer$$.$cljs$lang$maxFixedArity$=1;
var $malli$impl$regex$alt_validator$$=function $malli$impl$regex$alt_validator$$($var_args$jscomp$429$$){for(var $args__5755__auto__$jscomp$47$$=[],$len__5749__auto___25817$$=arguments.length,$i__5750__auto___25818$$=0;;)if($i__5750__auto___25818$$<$len__5749__auto___25817$$)$args__5755__auto__$jscomp$47$$.push(arguments[$i__5750__auto___25818$$]),$i__5750__auto___25818$$+=1;else break;return $malli$impl$regex$alt_validator$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args__5755__auto__$jscomp$47$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$47$$.slice(1),0,null):null)};
$malli$impl$regex$alt_validator$$.$cljs$core$IFn$_invoke$arity$variadic$=function($_QMARK_kr$jscomp$4$$,$_QMARK_krs$jscomp$3$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($r$jscomp$42$$,$_QMARK_kr__$1$jscomp$3$$){var $r_STAR_$jscomp$2$$=$malli$impl$regex$entry__GT_regex$$($_QMARK_kr__$1$jscomp$3$$);return function($driver$jscomp$22$$,$regs$jscomp$20$$,$pos$jscomp$42$$,$coll$jscomp$944$$,$k$jscomp$314$$){$malli$impl$regex$park_validator_BANG_$$($driver$jscomp$22$$,
$r_STAR_$jscomp$2$$,$regs$jscomp$20$$,$pos$jscomp$42$$,$coll$jscomp$944$$,$k$jscomp$314$$);return $malli$impl$regex$park_validator_BANG_$$($driver$jscomp$22$$,$r$jscomp$42$$,$regs$jscomp$20$$,$pos$jscomp$42$$,$coll$jscomp$944$$,$k$jscomp$314$$)}},$malli$impl$regex$entry__GT_regex$$($_QMARK_kr$jscomp$4$$),$_QMARK_krs$jscomp$3$$)};$malli$impl$regex$alt_validator$$.$cljs$lang$maxFixedArity$=1;
$malli$impl$regex$alt_validator$$.$cljs$lang$applyTo$=function($seq25154_seq25154__$1$$){var $G__25155$$=$APP.$cljs$core$first$$($seq25154_seq25154__$1$$);$seq25154_seq25154__$1$$=$APP.$cljs$core$next$$($seq25154_seq25154__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__25155$$,$seq25154_seq25154__$1$$)};
var $malli$impl$regex$alt_explainer$$=function $malli$impl$regex$alt_explainer$$($var_args$jscomp$430$$){for(var $args__5755__auto__$jscomp$48$$=[],$len__5749__auto___25828$$=arguments.length,$i__5750__auto___25829$$=0;;)if($i__5750__auto___25829$$<$len__5749__auto___25828$$)$args__5755__auto__$jscomp$48$$.push(arguments[$i__5750__auto___25829$$]),$i__5750__auto___25829$$+=1;else break;return $malli$impl$regex$alt_explainer$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args__5755__auto__$jscomp$48$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$48$$.slice(1),0,null):null)};
$malli$impl$regex$alt_explainer$$.$cljs$core$IFn$_invoke$arity$variadic$=function($_QMARK_kr$jscomp$5$$,$_QMARK_krs$jscomp$4$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($r$jscomp$43$$,$_QMARK_kr__$1$jscomp$4$$){var $r_STAR_$jscomp$3$$=$malli$impl$regex$entry__GT_regex$$($_QMARK_kr__$1$jscomp$4$$);return function($driver$jscomp$23$$,$regs$jscomp$21$$,$pos$jscomp$43$$,$coll$jscomp$945$$,$k$jscomp$315$$){$malli$impl$regex$park_explainer_BANG_$$($driver$jscomp$23$$,
$r_STAR_$jscomp$3$$,$regs$jscomp$21$$,$pos$jscomp$43$$,$coll$jscomp$945$$,$k$jscomp$315$$);return $malli$impl$regex$park_explainer_BANG_$$($driver$jscomp$23$$,$r$jscomp$43$$,$regs$jscomp$21$$,$pos$jscomp$43$$,$coll$jscomp$945$$,$k$jscomp$315$$)}},$malli$impl$regex$entry__GT_regex$$($_QMARK_kr$jscomp$5$$),$_QMARK_krs$jscomp$4$$)};$malli$impl$regex$alt_explainer$$.$cljs$lang$maxFixedArity$=1;
$malli$impl$regex$alt_explainer$$.$cljs$lang$applyTo$=function($seq25166_seq25166__$1$$){var $G__25167$$=$APP.$cljs$core$first$$($seq25166_seq25166__$1$$);$seq25166_seq25166__$1$$=$APP.$cljs$core$next$$($seq25166_seq25166__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__25167$$,$seq25166_seq25166__$1$$)};
var $malli$impl$regex$alt_parser$$=function $malli$impl$regex$alt_parser$$($var_args$jscomp$431$$){for(var $args__5755__auto__$jscomp$49$$=[],$len__5749__auto___25840$$=arguments.length,$i__5750__auto___25841$$=0;;)if($i__5750__auto___25841$$<$len__5749__auto___25840$$)$args__5755__auto__$jscomp$49$$.push(arguments[$i__5750__auto___25841$$]),$i__5750__auto___25841$$+=1;else break;return $malli$impl$regex$alt_parser$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$49$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$49$$.slice(0),0,null):null)};
$malli$impl$regex$alt_parser$$.$cljs$core$IFn$_invoke$arity$variadic$=function($rs$jscomp$1$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(function($r$jscomp$44$$,$r_STAR_$jscomp$4$$){return function($driver$jscomp$24$$,$regs$jscomp$22$$,$pos$jscomp$44$$,$coll$jscomp$946$$,$k$jscomp$316$$){$malli$impl$regex$park_validator_BANG_$$($driver$jscomp$24$$,$r_STAR_$jscomp$4$$,$regs$jscomp$22$$,$pos$jscomp$44$$,$coll$jscomp$946$$,$k$jscomp$316$$);return $malli$impl$regex$park_validator_BANG_$$($driver$jscomp$24$$,
$r$jscomp$44$$,$regs$jscomp$22$$,$pos$jscomp$44$$,$coll$jscomp$946$$,$k$jscomp$316$$)}},$rs$jscomp$1$$)};$malli$impl$regex$alt_parser$$.$cljs$lang$maxFixedArity$=0;$malli$impl$regex$alt_parser$$.$cljs$lang$applyTo$=function($seq25180$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq25180$$))};
var $malli$impl$regex$altn_parser$$=function $malli$impl$regex$altn_parser$$($var_args$jscomp$432$$){for(var $args__5755__auto__$jscomp$50$$=[],$len__5749__auto___25852$$=arguments.length,$i__5750__auto___25853$$=0;;)if($i__5750__auto___25853$$<$len__5749__auto___25852$$)$args__5755__auto__$jscomp$50$$.push(arguments[$i__5750__auto___25853$$]),$i__5750__auto___25853$$+=1;else break;return $malli$impl$regex$altn_parser$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args__5755__auto__$jscomp$50$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$50$$.slice(2),0,null):null)};
$malli$impl$regex$altn_parser$$.$cljs$core$IFn$_invoke$arity$variadic$=function($tag$jscomp$26$$,$kr$jscomp$1$$,$krs$jscomp$1$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($r$jscomp$45$$,$p__25194_r_STAR_$jscomp$5$$){var $t$jscomp$25$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__25194_r_STAR_$jscomp$5$$,0,null);$p__25194_r_STAR_$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__25194_r_STAR_$jscomp$5$$,1,null);var $r_STAR___$1$$=
$malli$impl$regex$fmap_parser$$(function($v$jscomp$167$$){return $tag$jscomp$26$$.$cljs$core$IFn$_invoke$arity$2$?$tag$jscomp$26$$.$cljs$core$IFn$_invoke$arity$2$($t$jscomp$25$$,$v$jscomp$167$$):$tag$jscomp$26$$($t$jscomp$25$$,$v$jscomp$167$$)},$p__25194_r_STAR_$jscomp$5$$);return function($driver$jscomp$25$$,$regs$jscomp$23$$,$pos$jscomp$45$$,$coll$jscomp$947$$,$k$jscomp$317$$){$malli$impl$regex$park_validator_BANG_$$($driver$jscomp$25$$,$r_STAR___$1$$,$regs$jscomp$23$$,$pos$jscomp$45$$,$coll$jscomp$947$$,
$k$jscomp$317$$);return $malli$impl$regex$park_validator_BANG_$$($driver$jscomp$25$$,$r$jscomp$45$$,$regs$jscomp$23$$,$pos$jscomp$45$$,$coll$jscomp$947$$,$k$jscomp$317$$)}},function(){var $t$jscomp$26$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($kr$jscomp$1$$,0,null),$r$jscomp$46$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($kr$jscomp$1$$,1,null);return $malli$impl$regex$fmap_parser$$(function($v$jscomp$168$$){return $tag$jscomp$26$$.$cljs$core$IFn$_invoke$arity$2$?$tag$jscomp$26$$.$cljs$core$IFn$_invoke$arity$2$($t$jscomp$26$$,
$v$jscomp$168$$):$tag$jscomp$26$$($t$jscomp$26$$,$v$jscomp$168$$)},$r$jscomp$46$$)}(),$krs$jscomp$1$$)};$malli$impl$regex$altn_parser$$.$cljs$lang$maxFixedArity$=2;
$malli$impl$regex$altn_parser$$.$cljs$lang$applyTo$=function($G__25187_seq25185$$){var $G__25186$$=$APP.$cljs$core$first$$($G__25187_seq25185$$),$seq25185__$1_seq25185__$2$$=$APP.$cljs$core$next$$($G__25187_seq25185$$);$G__25187_seq25185$$=$APP.$cljs$core$first$$($seq25185__$1_seq25185__$2$$);$seq25185__$1_seq25185__$2$$=$APP.$cljs$core$next$$($seq25185__$1_seq25185__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__25186$$,$G__25187_seq25185$$,$seq25185__$1_seq25185__$2$$)};
var $malli$impl$regex$alt_unparser$$=function $malli$impl$regex$alt_unparser$$($var_args$jscomp$433$$){for(var $args__5755__auto__$jscomp$51$$=[],$len__5749__auto___25873$$=arguments.length,$i__5750__auto___25874$$=0;;)if($i__5750__auto___25874$$<$len__5749__auto___25873$$)$args__5755__auto__$jscomp$51$$.push(arguments[$i__5750__auto___25874$$]),$i__5750__auto___25874$$+=1;else break;return $malli$impl$regex$alt_unparser$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$51$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$51$$.slice(0),0,null):null)};
$malli$impl$regex$alt_unparser$$.$cljs$core$IFn$_invoke$arity$variadic$=function($unparsers$jscomp$2$$){return function($x$jscomp$698$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($_$jscomp$229$$,$unparse$jscomp$1$$){return $malli$impl$util$_map_valid$$($APP.$cljs$core$reduced$$,$unparse$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$unparse$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$698$$):$unparse$jscomp$1$$($x$jscomp$698$$))},$cljs$cst$295$malli_DOT_core_SLASH_invalid$$,
$unparsers$jscomp$2$$)}};$malli$impl$regex$alt_unparser$$.$cljs$lang$maxFixedArity$=0;$malli$impl$regex$alt_unparser$$.$cljs$lang$applyTo$=function($seq25207$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq25207$$))};
var $malli$impl$regex$altn_unparser$$=function $malli$impl$regex$altn_unparser$$($var_args$jscomp$434$$){for(var $args__5755__auto__$jscomp$52$$=[],$len__5749__auto___25879$$=arguments.length,$i__5750__auto___25880$$=0;;)if($i__5750__auto___25880$$<$len__5749__auto___25879$$)$args__5755__auto__$jscomp$52$$.push(arguments[$i__5750__auto___25880$$]),$i__5750__auto___25880$$+=1;else break;return $malli$impl$regex$altn_unparser$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args__5755__auto__$jscomp$52$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$52$$.slice(1),0,null):null)};
$malli$impl$regex$altn_unparser$$.$cljs$core$IFn$_invoke$arity$variadic$=function($tag_QMARK_$$,$unparsers$jscomp$3$$){var $unparsers__$1$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$unparsers$jscomp$3$$);return function($G__25219_x$jscomp$699$$){if($APP.$cljs$core$truth_$$($tag_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$tag_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__25219_x$jscomp$699$$):$tag_QMARK_$$($G__25219_x$jscomp$699$$))){var $fexpr__25218_temp__5827__auto__$jscomp$5$$=
$cljs$core$find$$($unparsers__$1$jscomp$2$$,$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($G__25219_x$jscomp$699$$));if($fexpr__25218_temp__5827__auto__$jscomp$5$$==null)return $cljs$cst$295$malli_DOT_core_SLASH_invalid$$;$G__25219_x$jscomp$699$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($G__25219_x$jscomp$699$$);$fexpr__25218_temp__5827__auto__$jscomp$5$$=$APP.$cljs$core$_val$$($fexpr__25218_temp__5827__auto__$jscomp$5$$);return $fexpr__25218_temp__5827__auto__$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?
$fexpr__25218_temp__5827__auto__$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($G__25219_x$jscomp$699$$):$fexpr__25218_temp__5827__auto__$jscomp$5$$($G__25219_x$jscomp$699$$)}return $cljs$cst$295$malli_DOT_core_SLASH_invalid$$}};$malli$impl$regex$altn_unparser$$.$cljs$lang$maxFixedArity$=1;
$malli$impl$regex$altn_unparser$$.$cljs$lang$applyTo$=function($seq25213_seq25213__$1$$){var $G__25214$$=$APP.$cljs$core$first$$($seq25213_seq25213__$1$$);$seq25213_seq25213__$1$$=$APP.$cljs$core$next$$($seq25213_seq25213__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__25214$$,$seq25213_seq25213__$1$$)};
var $malli$impl$regex$alt_transformer$$=function $malli$impl$regex$alt_transformer$$($var_args$jscomp$435$$){for(var $args__5755__auto__$jscomp$53$$=[],$len__5749__auto___25889$$=arguments.length,$i__5750__auto___25890$$=0;;)if($i__5750__auto___25890$$<$len__5749__auto___25889$$)$args__5755__auto__$jscomp$53$$.push(arguments[$i__5750__auto___25890$$]),$i__5750__auto___25890$$+=1;else break;return $malli$impl$regex$alt_transformer$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args__5755__auto__$jscomp$53$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$53$$.slice(1),0,null):null)};
$malli$impl$regex$alt_transformer$$.$cljs$core$IFn$_invoke$arity$variadic$=function($_QMARK_kr$jscomp$6$$,$_QMARK_krs$jscomp$5$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($r$jscomp$47$$,$_QMARK_kr__$1$jscomp$5$$){var $r_STAR_$jscomp$6$$=$malli$impl$regex$entry__GT_regex$$($_QMARK_kr__$1$jscomp$5$$);return function($driver$jscomp$26$$,$regs$jscomp$24$$,$coll_STAR_$jscomp$11$$,$pos$jscomp$46$$,$coll$jscomp$948$$,$k$jscomp$318$$){$malli$impl$regex$park_transformer_BANG_$$($driver$jscomp$26$$,
$r_STAR_$jscomp$6$$,$regs$jscomp$24$$,$coll_STAR_$jscomp$11$$,$pos$jscomp$46$$,$coll$jscomp$948$$,$k$jscomp$318$$);return $malli$impl$regex$park_transformer_BANG_$$($driver$jscomp$26$$,$r$jscomp$47$$,$regs$jscomp$24$$,$coll_STAR_$jscomp$11$$,$pos$jscomp$46$$,$coll$jscomp$948$$,$k$jscomp$318$$)}},$malli$impl$regex$entry__GT_regex$$($_QMARK_kr$jscomp$6$$),$_QMARK_krs$jscomp$5$$)};$malli$impl$regex$alt_transformer$$.$cljs$lang$maxFixedArity$=1;
$malli$impl$regex$alt_transformer$$.$cljs$lang$applyTo$=function($seq25224_seq25224__$1$$){var $G__25225$$=$APP.$cljs$core$first$$($seq25224_seq25224__$1$$);$seq25224_seq25224__$1$$=$APP.$cljs$core$next$$($seq25224_seq25224__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__25225$$,$seq25224_seq25224__$1$$)};
$malli$impl$regex$Cache$$.prototype.$malli$impl$regex$ICache$ensure_cached_BANG_$arity$4$=function($_$jscomp$232_max_index_values_STAR__25931$$,$f$jscomp$380$$,$pos$jscomp$71$$,$regs$jscomp$47$$){if(this.size+1>this.values.length>>1){var $capacity_STAR__25930_h$jscomp$94_max_index_25932$$=this.values.length<<1;$_$jscomp$232_max_index_values_STAR__25931$$=$cljs$core$object_array$cljs$0core$0IFn$0_invoke$0arity$01$$($capacity_STAR__25930_h$jscomp$94_max_index_25932$$);--$capacity_STAR__25930_h$jscomp$94_max_index_25932$$;
for(var $i$jscomp$295_len_25934$$=this.values.length,$collisions_collisions__$1_i_25935$$=0;;)if($collisions_collisions__$1_i_25935$$<$i$jscomp$295_len_25934$$){var $G__25945_entry$jscomp$18_or__5025__auto__$jscomp$86_temp__5827__auto__$jscomp$6_temp__5829__auto___25936_v_25937$$=this.values[$collisions_collisions__$1_i_25935$$];if($G__25945_entry$jscomp$18_or__5025__auto__$jscomp$86_temp__5827__auto__$jscomp$6_temp__5829__auto___25936_v_25937$$!=null)for(var $i_STAR__25938$$=$G__25945_entry$jscomp$18_or__5025__auto__$jscomp$86_temp__5827__auto__$jscomp$6_temp__5829__auto___25936_v_25937$$.hash&
$capacity_STAR__25930_h$jscomp$94_max_index_25932$$,$collisions_25939_collisions_25940__$1$$=0;;)if($APP.$cljs$core$truth_$$($_$jscomp$232_max_index_values_STAR__25931$$[$i_STAR__25938$$])){var $G__25942$$=$collisions_25939_collisions_25940__$1$$+=1;$i_STAR__25938$$=$i_STAR__25938$$+$collisions_25939_collisions_25940__$1$$&$capacity_STAR__25930_h$jscomp$94_max_index_25932$$;$collisions_25939_collisions_25940__$1$$=$G__25942$$}else{$_$jscomp$232_max_index_values_STAR__25931$$[$i_STAR__25938$$]=$G__25945_entry$jscomp$18_or__5025__auto__$jscomp$86_temp__5827__auto__$jscomp$6_temp__5829__auto___25936_v_25937$$;
break}$collisions_collisions__$1_i_25935$$+=1}else break;this.values=$_$jscomp$232_max_index_values_STAR__25931$$}$_$jscomp$232_max_index_values_STAR__25931$$=this.values.length-1;$capacity_STAR__25930_h$jscomp$94_max_index_25932$$=$cljs$core$hash_combine$$($cljs$core$hash_combine$$($APP.$cljs$core$hash$$($f$jscomp$380$$),$APP.$cljs$core$hash$$($pos$jscomp$71$$)),$APP.$cljs$core$hash$$($regs$jscomp$47$$));$i$jscomp$295_len_25934$$=$capacity_STAR__25930_h$jscomp$94_max_index_25932$$&$_$jscomp$232_max_index_values_STAR__25931$$;
for($collisions_collisions__$1_i_25935$$=0;;){$G__25945_entry$jscomp$18_or__5025__auto__$jscomp$86_temp__5827__auto__$jscomp$6_temp__5829__auto___25936_v_25937$$=this.values[$i$jscomp$295_len_25934$$];if($G__25945_entry$jscomp$18_or__5025__auto__$jscomp$86_temp__5827__auto__$jscomp$6_temp__5829__auto___25936_v_25937$$==null)return this.values[$i$jscomp$295_len_25934$$]=new $malli$impl$regex$CacheEntry$$($capacity_STAR__25930_h$jscomp$94_max_index_25932$$,$f$jscomp$380$$,$pos$jscomp$71$$,$regs$jscomp$47$$),
this.size+=1,!1;if($G__25945_entry$jscomp$18_or__5025__auto__$jscomp$86_temp__5827__auto__$jscomp$6_temp__5829__auto___25936_v_25937$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__25945_entry$jscomp$18_or__5025__auto__$jscomp$86_temp__5827__auto__$jscomp$6_temp__5829__auto___25936_v_25937$$.hash,$capacity_STAR__25930_h$jscomp$94_max_index_25932$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__25945_entry$jscomp$18_or__5025__auto__$jscomp$86_temp__5827__auto__$jscomp$6_temp__5829__auto___25936_v_25937$$.f,
$f$jscomp$380$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__25945_entry$jscomp$18_or__5025__auto__$jscomp$86_temp__5827__auto__$jscomp$6_temp__5829__auto___25936_v_25937$$.pos,$pos$jscomp$71$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__25945_entry$jscomp$18_or__5025__auto__$jscomp$86_temp__5827__auto__$jscomp$6_temp__5829__auto___25936_v_25937$$.$regs$,$regs$jscomp$47$$))return $G__25945_entry$jscomp$18_or__5025__auto__$jscomp$86_temp__5827__auto__$jscomp$6_temp__5829__auto___25936_v_25937$$;
$G__25945_entry$jscomp$18_or__5025__auto__$jscomp$86_temp__5827__auto__$jscomp$6_temp__5829__auto___25936_v_25937$$=$collisions_collisions__$1_i_25935$$+=1;$i$jscomp$295_len_25934$$=$i$jscomp$295_len_25934$$+$collisions_collisions__$1_i_25935$$&$_$jscomp$232_max_index_values_STAR__25931$$;$collisions_collisions__$1_i_25935$$=$G__25945_entry$jscomp$18_or__5025__auto__$jscomp$86_temp__5827__auto__$jscomp$6_temp__5829__auto___25936_v_25937$$}};
$malli$impl$regex$CheckDriver$$.prototype.$malli$impl$regex$IValidationDriver$noncaching_park_validator_BANG_$arity$6$=function($self$jscomp$25$$,$validator$jscomp$8$$,$regs$jscomp$48$$,$pos$jscomp$72$$,$coll$jscomp$969$$,$k$jscomp$339$$){var $self__$1$$=this;return this.stack.push(function(){return $validator$jscomp$8$$.$cljs$core$IFn$_invoke$arity$5$?$validator$jscomp$8$$.$cljs$core$IFn$_invoke$arity$5$($self__$1$$,$regs$jscomp$48$$,$pos$jscomp$72$$,$coll$jscomp$969$$,$k$jscomp$339$$):$validator$jscomp$8$$($self__$1$$,
$regs$jscomp$48$$,$pos$jscomp$72$$,$coll$jscomp$969$$,$k$jscomp$339$$)})};
$malli$impl$regex$CheckDriver$$.prototype.$malli$impl$regex$IValidationDriver$park_validator_BANG_$arity$6$=function($self$jscomp$26$$,$validator$jscomp$9$$,$regs$jscomp$49$$,$pos$jscomp$73$$,$coll$jscomp$970$$,$k$jscomp$340$$){return $APP.$cljs$core$truth_$$($malli$impl$regex$ensure_cached_BANG_$$(this.cache,$validator$jscomp$9$$,$pos$jscomp$73$$,$regs$jscomp$49$$))?null:this.$malli$impl$regex$IValidationDriver$noncaching_park_validator_BANG_$arity$6$(null,$validator$jscomp$9$$,$regs$jscomp$49$$,
$pos$jscomp$73$$,$coll$jscomp$970$$,$k$jscomp$340$$)};
$malli$impl$regex$ParseDriver$$.prototype.$malli$impl$regex$IValidationDriver$noncaching_park_validator_BANG_$arity$6$=function($self$jscomp$27$$,$validator$jscomp$10$$,$regs$jscomp$50$$,$pos$jscomp$74$$,$coll$jscomp$971$$,$k$jscomp$341$$){var $self__$1$jscomp$2$$=this;return this.stack.push(function(){return $validator$jscomp$10$$.$cljs$core$IFn$_invoke$arity$5$?$validator$jscomp$10$$.$cljs$core$IFn$_invoke$arity$5$($self__$1$jscomp$2$$,$regs$jscomp$50$$,$pos$jscomp$74$$,$coll$jscomp$971$$,$k$jscomp$341$$):
$validator$jscomp$10$$($self__$1$jscomp$2$$,$regs$jscomp$50$$,$pos$jscomp$74$$,$coll$jscomp$971$$,$k$jscomp$341$$)})};
$malli$impl$regex$ParseDriver$$.prototype.$malli$impl$regex$IValidationDriver$park_validator_BANG_$arity$6$=function($self$jscomp$28$$,$validator$jscomp$11$$,$regs$jscomp$51$$,$pos$jscomp$75$$,$coll$jscomp$972$$,$k$jscomp$342$$){return $APP.$cljs$core$truth_$$($malli$impl$regex$ensure_cached_BANG_$$(this.cache,$validator$jscomp$11$$,$pos$jscomp$75$$,$regs$jscomp$51$$))?null:this.$malli$impl$regex$IValidationDriver$noncaching_park_validator_BANG_$arity$6$(null,$validator$jscomp$11$$,$regs$jscomp$51$$,
$pos$jscomp$75$$,$coll$jscomp$972$$,$k$jscomp$342$$)};
$malli$impl$regex$ParseDriver$$.prototype.$malli$impl$regex$IParseDriver$noncaching_park_transformer_BANG_$arity$7$=function($driver$jscomp$45$$,$transformer$jscomp$5$$,$regs$jscomp$52$$,$coll_STAR_$jscomp$22$$,$pos$jscomp$76$$,$coll$jscomp$973$$,$k$jscomp$343$$){var $driver__$1$jscomp$8$$=this;return this.stack.push(function(){return $transformer$jscomp$5$$.$cljs$core$IFn$_invoke$arity$6$?$transformer$jscomp$5$$.$cljs$core$IFn$_invoke$arity$6$($driver__$1$jscomp$8$$,$regs$jscomp$52$$,$coll_STAR_$jscomp$22$$,
$pos$jscomp$76$$,$coll$jscomp$973$$,$k$jscomp$343$$):$transformer$jscomp$5$$($driver__$1$jscomp$8$$,$regs$jscomp$52$$,$coll_STAR_$jscomp$22$$,$pos$jscomp$76$$,$coll$jscomp$973$$,$k$jscomp$343$$)})};
$malli$impl$regex$ParseDriver$$.prototype.$malli$impl$regex$IParseDriver$park_transformer_BANG_$arity$7$=function($driver$jscomp$46$$,$transformer$jscomp$6$$,$regs$jscomp$53$$,$coll_STAR_$jscomp$23$$,$pos$jscomp$77$$,$coll$jscomp$974$$,$k$jscomp$344$$){return $APP.$cljs$core$truth_$$($malli$impl$regex$ensure_cached_BANG_$$(this.cache,$transformer$jscomp$6$$,$pos$jscomp$77$$,$regs$jscomp$53$$))?null:this.$malli$impl$regex$IParseDriver$noncaching_park_transformer_BANG_$arity$7$(null,$transformer$jscomp$6$$,
$regs$jscomp$53$$,$coll_STAR_$jscomp$23$$,$pos$jscomp$77$$,$coll$jscomp$974$$,$k$jscomp$344$$)};
$malli$impl$regex$ExplanationDriver$$.prototype.$malli$impl$regex$IExplanationDriver$noncaching_park_explainer_BANG_$arity$6$=function($self$jscomp$30$$,$validator$jscomp$12$$,$regs$jscomp$54$$,$pos$jscomp$78$$,$coll$jscomp$976$$,$k$jscomp$345$$){var $self__$1$jscomp$5$$=this;return this.stack.push(function(){return $validator$jscomp$12$$.$cljs$core$IFn$_invoke$arity$5$?$validator$jscomp$12$$.$cljs$core$IFn$_invoke$arity$5$($self__$1$jscomp$5$$,$regs$jscomp$54$$,$pos$jscomp$78$$,$coll$jscomp$976$$,
$k$jscomp$345$$):$validator$jscomp$12$$($self__$1$jscomp$5$$,$regs$jscomp$54$$,$pos$jscomp$78$$,$coll$jscomp$976$$,$k$jscomp$345$$)})};
$malli$impl$regex$ExplanationDriver$$.prototype.$malli$impl$regex$IExplanationDriver$park_explainer_BANG_$arity$6$=function($self$jscomp$31$$,$validator$jscomp$13$$,$regs$jscomp$55$$,$pos$jscomp$79$$,$coll$jscomp$977$$,$k$jscomp$346$$){return $APP.$cljs$core$truth_$$($malli$impl$regex$ensure_cached_BANG_$$(this.cache,$validator$jscomp$13$$,$pos$jscomp$79$$,$regs$jscomp$55$$))?null:this.$malli$impl$regex$IExplanationDriver$noncaching_park_explainer_BANG_$arity$6$(null,$validator$jscomp$13$$,$regs$jscomp$55$$,
$pos$jscomp$79$$,$coll$jscomp$977$$,$k$jscomp$346$$)};$malli$impl$regex$ExplanationDriver$$.prototype.$malli$impl$regex$IExplanationDriver$value_path$arity$2$=function($_$jscomp$244$$,$pos$jscomp$80$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$(this.$in$$,$pos$jscomp$80$$)};
$malli$impl$regex$ExplanationDriver$$.prototype.$malli$impl$regex$IExplanationDriver$fail_BANG_$arity$3$=function($_$jscomp$245$$,$pos$jscomp$81$$,$errors_STAR_$jscomp$2$$){return $pos$jscomp$81$$>this.$errors_max_pos$?(this.$errors_max_pos$=$pos$jscomp$81$$,this.errors=$errors_STAR_$jscomp$2$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$81$$,this.$errors_max_pos$)?this.errors=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(this.errors,$errors_STAR_$jscomp$2$$):null};$APP.$JSCompiler_prototypeAlias$$=$malli$registry$t_malli$0registry24964$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_24966$$,$meta24965__$1$$){return new $malli$registry$t_malli$0registry24964$$(this.m,this.fm,$meta24965__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta24965$};$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$_schema$arity$2$=function($_$jscomp$250$$,$type$jscomp$182$$){return this.fm.get($type$jscomp$182$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$_schemas$arity$1$=function(){return this.m};$APP.$JSCompiler_prototypeAlias$$=$malli$registry$t_malli$0registry24972$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_24974$$,$meta24973__$1$$){return new $malli$registry$t_malli$0registry24972$$(this.m,$meta24973__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta24973$};$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$_schema$arity$2$=function($_$jscomp$252$$,$type$jscomp$183$$){return this.m.$cljs$core$IFn$_invoke$arity$1$?this.m.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$183$$):this.m($type$jscomp$183$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$_schemas$arity$1$=function(){return this.m};
var $malli$registry$registry_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(new $malli$registry$t_malli$0registry24972$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$));$APP.$JSCompiler_prototypeAlias$$=$malli$registry$t_malli$0registry25009$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_25011$$,$meta25010__$1$$){return new $malli$registry$t_malli$0registry25009$$($meta25010__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta25010$};$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$_schema$arity$2$=function($_$jscomp$254$$,$type$jscomp$184$$){return $malli$registry$_schema$$($APP.$cljs$core$_deref$$($malli$registry$registry_STAR_$$),$type$jscomp$184$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$_schemas$arity$1$=function(){return $malli$registry$_schemas$$($APP.$cljs$core$_deref$$($malli$registry$registry_STAR_$$))};$APP.$JSCompiler_prototypeAlias$$=$malli$registry$t_malli$0registry25037$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_25039$$,$meta25038__$1$$){return new $malli$registry$t_malli$0registry25037$$(this.$_QMARK_registries$,this.$registries$,$meta25038__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta25038$};$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$_schema$arity$2$=function($_$jscomp$256$$,$type$jscomp$185$$){return $APP.$cljs$core$some$$(function($p1__25025_SHARP_$$){return $malli$registry$_schema$$($p1__25025_SHARP_$$,$type$jscomp$185$$)},this.$registries$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$_schemas$arity$1$=function(){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$merge$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($malli$registry$_schemas$$,$APP.$cljs$core$reverse$$(this.$registries$)))};$APP.$JSCompiler_prototypeAlias$$=$malli$registry$t_malli$0registry25073$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_25075$$,$meta25074__$1$$){return new $malli$registry$t_malli$0registry25073$$(this.db,$meta25074__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta25074$};$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$_schema$arity$2$=function($_$jscomp$258$$,$type$jscomp$186$$){return $malli$registry$_schema$$($malli$registry$registry$$($APP.$cljs$core$_deref$$(this.db)),$type$jscomp$186$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$_schemas$arity$1$=function(){return $malli$registry$_schemas$$($malli$registry$registry$$($APP.$cljs$core$_deref$$(this.db)))};$APP.$JSCompiler_prototypeAlias$$=$malli$registry$t_malli$0registry25109$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_25111$$,$meta25110__$1$$){return new $malli$registry$t_malli$0registry25109$$($meta25110__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta25110$};$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$_schema$arity$2$=function($_$jscomp$260$$,$type$jscomp$187$$){return $type$jscomp$187$$ instanceof $APP.$cljs$core$Var$$?$APP.$cljs$core$_deref$$($type$jscomp$187$$):null};$APP.$JSCompiler_prototypeAlias$$.$malli$registry$Registry$_schemas$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$=$borkdude$dynaload$LazyVar$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDeref$_deref$arity$1$=function(){if(this.$cached$!=null)return this.$cached$;var $x$jscomp$702$$=this.f.$cljs$core$IFn$_invoke$arity$0$?this.f.$cljs$core$IFn$_invoke$arity$0$():this.f();$x$jscomp$702$$!=null&&(this.$cached$=$x$jscomp$702$$);return $x$jscomp$702$$};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$22$$){switch(arguments.length-1){case 0:return this.$cljs$core$IFn$_invoke$arity$0$();case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);case 3:return this.$cljs$core$IFn$_invoke$arity$3$(arguments[1],arguments[2],arguments[3]);case 4:return this.$cljs$core$IFn$_invoke$arity$4$(arguments[1],arguments[2],arguments[3],arguments[4]);
case 5:return this.$cljs$core$IFn$_invoke$arity$5$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5]);case 6:return this.$cljs$core$IFn$_invoke$arity$6$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6]);case 7:return this.$cljs$core$IFn$_invoke$arity$7$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7]);case 8:return this.$cljs$core$IFn$_invoke$arity$8$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],
arguments[6],arguments[7],arguments[8]);case 9:return this.$cljs$core$IFn$_invoke$arity$9$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9]);case 10:return this.$cljs$core$IFn$_invoke$arity$10$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10]);case 11:return this.$cljs$core$IFn$_invoke$arity$11$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],
arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11]);case 12:return this.$cljs$core$IFn$_invoke$arity$12$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12]);case 13:return this.$cljs$core$IFn$_invoke$arity$13$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],
arguments[13]);case 14:return this.$cljs$core$IFn$_invoke$arity$14$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14]);case 15:return this.$cljs$core$IFn$_invoke$arity$15$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15]);
case 16:return this.$cljs$core$IFn$_invoke$arity$16$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16]);case 17:return this.$cljs$core$IFn$_invoke$arity$17$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],
arguments[15],arguments[16],arguments[17]);case 18:return this.$cljs$core$IFn$_invoke$arity$18$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18]);case 19:return this.$cljs$core$IFn$_invoke$arity$19$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],
arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19]);case 20:return this.$cljs$core$IFn$_invoke$arity$20$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19],arguments[20]);case 21:return this.$cljs$core$IFn$_invoke$arity$21$(arguments[1],
arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19],arguments[20],arguments[21]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};
$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$1253$$,$args25634$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args25634$$)))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$0$=function(){var $fexpr__25669$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25669$$.$cljs$core$IFn$_invoke$arity$0$?$fexpr__25669$$.$cljs$core$IFn$_invoke$arity$0$():$fexpr__25669$$()};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($a$jscomp$233$$){var $fexpr__25671$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25671$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__25671$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$233$$):$fexpr__25671$$($a$jscomp$233$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($a$jscomp$234$$,$b$jscomp$190$$){var $fexpr__25672$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25672$$.$cljs$core$IFn$_invoke$arity$2$?$fexpr__25672$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$234$$,$b$jscomp$190$$):$fexpr__25672$$($a$jscomp$234$$,$b$jscomp$190$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$3$=function($a$jscomp$235$$,$b$jscomp$191$$,$c$jscomp$162$$){var $fexpr__25674$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25674$$.$cljs$core$IFn$_invoke$arity$3$?$fexpr__25674$$.$cljs$core$IFn$_invoke$arity$3$($a$jscomp$235$$,$b$jscomp$191$$,$c$jscomp$162$$):$fexpr__25674$$($a$jscomp$235$$,$b$jscomp$191$$,$c$jscomp$162$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$4$=function($a$jscomp$236$$,$b$jscomp$192$$,$c$jscomp$163$$,$d$jscomp$120$$){var $fexpr__25676$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25676$$.$cljs$core$IFn$_invoke$arity$4$?$fexpr__25676$$.$cljs$core$IFn$_invoke$arity$4$($a$jscomp$236$$,$b$jscomp$192$$,$c$jscomp$163$$,$d$jscomp$120$$):$fexpr__25676$$($a$jscomp$236$$,$b$jscomp$192$$,$c$jscomp$163$$,$d$jscomp$120$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$5$=function($a$jscomp$237$$,$b$jscomp$193$$,$c$jscomp$164$$,$d$jscomp$121$$,$e$jscomp$138$$){var $fexpr__25677$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25677$$.$cljs$core$IFn$_invoke$arity$5$?$fexpr__25677$$.$cljs$core$IFn$_invoke$arity$5$($a$jscomp$237$$,$b$jscomp$193$$,$c$jscomp$164$$,$d$jscomp$121$$,$e$jscomp$138$$):$fexpr__25677$$($a$jscomp$237$$,$b$jscomp$193$$,$c$jscomp$164$$,$d$jscomp$121$$,$e$jscomp$138$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$6$=function($a$jscomp$238$$,$b$jscomp$194$$,$c$jscomp$165$$,$d$jscomp$122$$,$e$jscomp$139$$,$f__$1$jscomp$2$$){var $fexpr__25679$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25679$$.$cljs$core$IFn$_invoke$arity$6$?$fexpr__25679$$.$cljs$core$IFn$_invoke$arity$6$($a$jscomp$238$$,$b$jscomp$194$$,$c$jscomp$165$$,$d$jscomp$122$$,$e$jscomp$139$$,$f__$1$jscomp$2$$):$fexpr__25679$$($a$jscomp$238$$,$b$jscomp$194$$,$c$jscomp$165$$,$d$jscomp$122$$,
$e$jscomp$139$$,$f__$1$jscomp$2$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$7$=function($a$jscomp$239$$,$b$jscomp$195$$,$c$jscomp$166$$,$d$jscomp$123$$,$e$jscomp$140$$,$f__$1$jscomp$3$$,$g$jscomp$82$$){var $fexpr__25681$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25681$$.$cljs$core$IFn$_invoke$arity$7$?$fexpr__25681$$.$cljs$core$IFn$_invoke$arity$7$($a$jscomp$239$$,$b$jscomp$195$$,$c$jscomp$166$$,$d$jscomp$123$$,$e$jscomp$140$$,$f__$1$jscomp$3$$,$g$jscomp$82$$):$fexpr__25681$$($a$jscomp$239$$,$b$jscomp$195$$,
$c$jscomp$166$$,$d$jscomp$123$$,$e$jscomp$140$$,$f__$1$jscomp$3$$,$g$jscomp$82$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$8$=function($a$jscomp$240$$,$b$jscomp$196$$,$c$jscomp$167$$,$d$jscomp$124$$,$e$jscomp$141$$,$f__$1$jscomp$4$$,$g$jscomp$83$$,$h$jscomp$95$$){var $fexpr__25683$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25683$$.$cljs$core$IFn$_invoke$arity$8$?$fexpr__25683$$.$cljs$core$IFn$_invoke$arity$8$($a$jscomp$240$$,$b$jscomp$196$$,$c$jscomp$167$$,$d$jscomp$124$$,$e$jscomp$141$$,$f__$1$jscomp$4$$,$g$jscomp$83$$,$h$jscomp$95$$):$fexpr__25683$$($a$jscomp$240$$,
$b$jscomp$196$$,$c$jscomp$167$$,$d$jscomp$124$$,$e$jscomp$141$$,$f__$1$jscomp$4$$,$g$jscomp$83$$,$h$jscomp$95$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$9$=function($a$jscomp$241$$,$b$jscomp$197$$,$c$jscomp$168$$,$d$jscomp$125$$,$e$jscomp$142$$,$f__$1$jscomp$5$$,$g$jscomp$84$$,$h$jscomp$96$$,$i$jscomp$296$$){var $fexpr__25686$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25686$$.$cljs$core$IFn$_invoke$arity$9$?$fexpr__25686$$.$cljs$core$IFn$_invoke$arity$9$($a$jscomp$241$$,$b$jscomp$197$$,$c$jscomp$168$$,$d$jscomp$125$$,$e$jscomp$142$$,$f__$1$jscomp$5$$,$g$jscomp$84$$,$h$jscomp$96$$,
$i$jscomp$296$$):$fexpr__25686$$($a$jscomp$241$$,$b$jscomp$197$$,$c$jscomp$168$$,$d$jscomp$125$$,$e$jscomp$142$$,$f__$1$jscomp$5$$,$g$jscomp$84$$,$h$jscomp$96$$,$i$jscomp$296$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$10$=function($a$jscomp$242$$,$b$jscomp$198$$,$c$jscomp$169$$,$d$jscomp$126$$,$e$jscomp$143$$,$f__$1$jscomp$6$$,$g$jscomp$85$$,$h$jscomp$97$$,$i$jscomp$297$$,$j$jscomp$86$$){var $fexpr__25687$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25687$$.$cljs$core$IFn$_invoke$arity$10$?$fexpr__25687$$.$cljs$core$IFn$_invoke$arity$10$($a$jscomp$242$$,$b$jscomp$198$$,$c$jscomp$169$$,$d$jscomp$126$$,$e$jscomp$143$$,$f__$1$jscomp$6$$,$g$jscomp$85$$,
$h$jscomp$97$$,$i$jscomp$297$$,$j$jscomp$86$$):$fexpr__25687$$($a$jscomp$242$$,$b$jscomp$198$$,$c$jscomp$169$$,$d$jscomp$126$$,$e$jscomp$143$$,$f__$1$jscomp$6$$,$g$jscomp$85$$,$h$jscomp$97$$,$i$jscomp$297$$,$j$jscomp$86$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$11$=function($a$jscomp$243$$,$b$jscomp$199$$,$c$jscomp$170$$,$d$jscomp$127$$,$e$jscomp$144$$,$f__$1$jscomp$7$$,$g$jscomp$86$$,$h$jscomp$98$$,$i$jscomp$298$$,$j$jscomp$87$$,$k$jscomp$347$$){var $fexpr__25688$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25688$$.$cljs$core$IFn$_invoke$arity$11$?$fexpr__25688$$.$cljs$core$IFn$_invoke$arity$11$($a$jscomp$243$$,$b$jscomp$199$$,$c$jscomp$170$$,$d$jscomp$127$$,$e$jscomp$144$$,$f__$1$jscomp$7$$,
$g$jscomp$86$$,$h$jscomp$98$$,$i$jscomp$298$$,$j$jscomp$87$$,$k$jscomp$347$$):$fexpr__25688$$($a$jscomp$243$$,$b$jscomp$199$$,$c$jscomp$170$$,$d$jscomp$127$$,$e$jscomp$144$$,$f__$1$jscomp$7$$,$g$jscomp$86$$,$h$jscomp$98$$,$i$jscomp$298$$,$j$jscomp$87$$,$k$jscomp$347$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$12$=function($a$jscomp$244$$,$b$jscomp$200$$,$c$jscomp$171$$,$d$jscomp$128$$,$e$jscomp$145$$,$f__$1$jscomp$8$$,$g$jscomp$87$$,$h$jscomp$99$$,$i$jscomp$299$$,$j$jscomp$88$$,$k$jscomp$348$$,$l$jscomp$77$$){var $fexpr__25693$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25693$$.$cljs$core$IFn$_invoke$arity$12$?$fexpr__25693$$.$cljs$core$IFn$_invoke$arity$12$($a$jscomp$244$$,$b$jscomp$200$$,$c$jscomp$171$$,$d$jscomp$128$$,$e$jscomp$145$$,
$f__$1$jscomp$8$$,$g$jscomp$87$$,$h$jscomp$99$$,$i$jscomp$299$$,$j$jscomp$88$$,$k$jscomp$348$$,$l$jscomp$77$$):$fexpr__25693$$($a$jscomp$244$$,$b$jscomp$200$$,$c$jscomp$171$$,$d$jscomp$128$$,$e$jscomp$145$$,$f__$1$jscomp$8$$,$g$jscomp$87$$,$h$jscomp$99$$,$i$jscomp$299$$,$j$jscomp$88$$,$k$jscomp$348$$,$l$jscomp$77$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$13$=function($a$jscomp$245$$,$b$jscomp$201$$,$c$jscomp$172$$,$d$jscomp$129$$,$e$jscomp$146$$,$f__$1$jscomp$9$$,$g$jscomp$88$$,$h$jscomp$100$$,$i$jscomp$300$$,$j$jscomp$89$$,$k$jscomp$349$$,$l$jscomp$78$$,$m$jscomp$115$$){var $fexpr__25695$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25695$$.$cljs$core$IFn$_invoke$arity$13$?$fexpr__25695$$.$cljs$core$IFn$_invoke$arity$13$($a$jscomp$245$$,$b$jscomp$201$$,$c$jscomp$172$$,$d$jscomp$129$$,
$e$jscomp$146$$,$f__$1$jscomp$9$$,$g$jscomp$88$$,$h$jscomp$100$$,$i$jscomp$300$$,$j$jscomp$89$$,$k$jscomp$349$$,$l$jscomp$78$$,$m$jscomp$115$$):$fexpr__25695$$($a$jscomp$245$$,$b$jscomp$201$$,$c$jscomp$172$$,$d$jscomp$129$$,$e$jscomp$146$$,$f__$1$jscomp$9$$,$g$jscomp$88$$,$h$jscomp$100$$,$i$jscomp$300$$,$j$jscomp$89$$,$k$jscomp$349$$,$l$jscomp$78$$,$m$jscomp$115$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$14$=function($a$jscomp$246$$,$b$jscomp$202$$,$c$jscomp$173$$,$d$jscomp$130$$,$e$jscomp$147$$,$f__$1$jscomp$10$$,$g$jscomp$89$$,$h$jscomp$101$$,$i$jscomp$301$$,$j$jscomp$90$$,$k$jscomp$350$$,$l$jscomp$79$$,$m$jscomp$116$$,$n$jscomp$189$$){var $fexpr__25696$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25696$$.$cljs$core$IFn$_invoke$arity$14$?$fexpr__25696$$.$cljs$core$IFn$_invoke$arity$14$($a$jscomp$246$$,$b$jscomp$202$$,$c$jscomp$173$$,
$d$jscomp$130$$,$e$jscomp$147$$,$f__$1$jscomp$10$$,$g$jscomp$89$$,$h$jscomp$101$$,$i$jscomp$301$$,$j$jscomp$90$$,$k$jscomp$350$$,$l$jscomp$79$$,$m$jscomp$116$$,$n$jscomp$189$$):$fexpr__25696$$($a$jscomp$246$$,$b$jscomp$202$$,$c$jscomp$173$$,$d$jscomp$130$$,$e$jscomp$147$$,$f__$1$jscomp$10$$,$g$jscomp$89$$,$h$jscomp$101$$,$i$jscomp$301$$,$j$jscomp$90$$,$k$jscomp$350$$,$l$jscomp$79$$,$m$jscomp$116$$,$n$jscomp$189$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$15$=function($a$jscomp$247$$,$b$jscomp$203$$,$c$jscomp$174$$,$d$jscomp$131$$,$e$jscomp$148$$,$f__$1$jscomp$11$$,$g$jscomp$90$$,$h$jscomp$102$$,$i$jscomp$302$$,$j$jscomp$91$$,$k$jscomp$351$$,$l$jscomp$80$$,$m$jscomp$117$$,$n$jscomp$190$$,$o$jscomp$157$$){var $fexpr__25699$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25699$$.$cljs$core$IFn$_invoke$arity$15$?$fexpr__25699$$.$cljs$core$IFn$_invoke$arity$15$($a$jscomp$247$$,$b$jscomp$203$$,
$c$jscomp$174$$,$d$jscomp$131$$,$e$jscomp$148$$,$f__$1$jscomp$11$$,$g$jscomp$90$$,$h$jscomp$102$$,$i$jscomp$302$$,$j$jscomp$91$$,$k$jscomp$351$$,$l$jscomp$80$$,$m$jscomp$117$$,$n$jscomp$190$$,$o$jscomp$157$$):$fexpr__25699$$($a$jscomp$247$$,$b$jscomp$203$$,$c$jscomp$174$$,$d$jscomp$131$$,$e$jscomp$148$$,$f__$1$jscomp$11$$,$g$jscomp$90$$,$h$jscomp$102$$,$i$jscomp$302$$,$j$jscomp$91$$,$k$jscomp$351$$,$l$jscomp$80$$,$m$jscomp$117$$,$n$jscomp$190$$,$o$jscomp$157$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$16$=function($a$jscomp$248$$,$b$jscomp$204$$,$c$jscomp$175$$,$d$jscomp$132$$,$e$jscomp$149$$,$f__$1$jscomp$12$$,$g$jscomp$91$$,$h$jscomp$103$$,$i$jscomp$303$$,$j$jscomp$92$$,$k$jscomp$352$$,$l$jscomp$81$$,$m$jscomp$118$$,$n$jscomp$191$$,$o$jscomp$158$$,$p$jscomp$63$$){var $fexpr__25701$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25701$$.$cljs$core$IFn$_invoke$arity$16$?$fexpr__25701$$.$cljs$core$IFn$_invoke$arity$16$($a$jscomp$248$$,
$b$jscomp$204$$,$c$jscomp$175$$,$d$jscomp$132$$,$e$jscomp$149$$,$f__$1$jscomp$12$$,$g$jscomp$91$$,$h$jscomp$103$$,$i$jscomp$303$$,$j$jscomp$92$$,$k$jscomp$352$$,$l$jscomp$81$$,$m$jscomp$118$$,$n$jscomp$191$$,$o$jscomp$158$$,$p$jscomp$63$$):$fexpr__25701$$($a$jscomp$248$$,$b$jscomp$204$$,$c$jscomp$175$$,$d$jscomp$132$$,$e$jscomp$149$$,$f__$1$jscomp$12$$,$g$jscomp$91$$,$h$jscomp$103$$,$i$jscomp$303$$,$j$jscomp$92$$,$k$jscomp$352$$,$l$jscomp$81$$,$m$jscomp$118$$,$n$jscomp$191$$,$o$jscomp$158$$,$p$jscomp$63$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$17$=function($a$jscomp$249$$,$b$jscomp$205$$,$c$jscomp$176$$,$d$jscomp$133$$,$e$jscomp$150$$,$f__$1$jscomp$13$$,$g$jscomp$92$$,$h$jscomp$104$$,$i$jscomp$304$$,$j$jscomp$93$$,$k$jscomp$353$$,$l$jscomp$82$$,$m$jscomp$119$$,$n$jscomp$192$$,$o$jscomp$159$$,$p$jscomp$64$$,$q$jscomp$28$$){var $fexpr__25702$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25702$$.$cljs$core$IFn$_invoke$arity$17$?$fexpr__25702$$.$cljs$core$IFn$_invoke$arity$17$($a$jscomp$249$$,
$b$jscomp$205$$,$c$jscomp$176$$,$d$jscomp$133$$,$e$jscomp$150$$,$f__$1$jscomp$13$$,$g$jscomp$92$$,$h$jscomp$104$$,$i$jscomp$304$$,$j$jscomp$93$$,$k$jscomp$353$$,$l$jscomp$82$$,$m$jscomp$119$$,$n$jscomp$192$$,$o$jscomp$159$$,$p$jscomp$64$$,$q$jscomp$28$$):$fexpr__25702$$($a$jscomp$249$$,$b$jscomp$205$$,$c$jscomp$176$$,$d$jscomp$133$$,$e$jscomp$150$$,$f__$1$jscomp$13$$,$g$jscomp$92$$,$h$jscomp$104$$,$i$jscomp$304$$,$j$jscomp$93$$,$k$jscomp$353$$,$l$jscomp$82$$,$m$jscomp$119$$,$n$jscomp$192$$,$o$jscomp$159$$,
$p$jscomp$64$$,$q$jscomp$28$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$18$=function($a$jscomp$250$$,$b$jscomp$206$$,$c$jscomp$177$$,$d$jscomp$134$$,$e$jscomp$151$$,$f__$1$jscomp$14$$,$g$jscomp$93$$,$h$jscomp$105$$,$i$jscomp$305$$,$j$jscomp$94$$,$k$jscomp$354$$,$l$jscomp$83$$,$m$jscomp$120$$,$n$jscomp$193$$,$o$jscomp$160$$,$p$jscomp$65$$,$q$jscomp$29$$,$r$jscomp$48$$){var $fexpr__25703$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25703$$.$cljs$core$IFn$_invoke$arity$18$?$fexpr__25703$$.$cljs$core$IFn$_invoke$arity$18$($a$jscomp$250$$,
$b$jscomp$206$$,$c$jscomp$177$$,$d$jscomp$134$$,$e$jscomp$151$$,$f__$1$jscomp$14$$,$g$jscomp$93$$,$h$jscomp$105$$,$i$jscomp$305$$,$j$jscomp$94$$,$k$jscomp$354$$,$l$jscomp$83$$,$m$jscomp$120$$,$n$jscomp$193$$,$o$jscomp$160$$,$p$jscomp$65$$,$q$jscomp$29$$,$r$jscomp$48$$):$fexpr__25703$$($a$jscomp$250$$,$b$jscomp$206$$,$c$jscomp$177$$,$d$jscomp$134$$,$e$jscomp$151$$,$f__$1$jscomp$14$$,$g$jscomp$93$$,$h$jscomp$105$$,$i$jscomp$305$$,$j$jscomp$94$$,$k$jscomp$354$$,$l$jscomp$83$$,$m$jscomp$120$$,$n$jscomp$193$$,
$o$jscomp$160$$,$p$jscomp$65$$,$q$jscomp$29$$,$r$jscomp$48$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$19$=function($a$jscomp$251$$,$b$jscomp$207$$,$c$jscomp$178$$,$d$jscomp$135$$,$e$jscomp$152$$,$f__$1$jscomp$15$$,$g$jscomp$94$$,$h$jscomp$106$$,$i$jscomp$306$$,$j$jscomp$95$$,$k$jscomp$355$$,$l$jscomp$84$$,$m$jscomp$121$$,$n$jscomp$194$$,$o$jscomp$161$$,$p$jscomp$66$$,$q$jscomp$30$$,$r$jscomp$49$$,$s$jscomp$298$$){var $fexpr__25715$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25715$$.$cljs$core$IFn$_invoke$arity$19$?$fexpr__25715$$.$cljs$core$IFn$_invoke$arity$19$($a$jscomp$251$$,
$b$jscomp$207$$,$c$jscomp$178$$,$d$jscomp$135$$,$e$jscomp$152$$,$f__$1$jscomp$15$$,$g$jscomp$94$$,$h$jscomp$106$$,$i$jscomp$306$$,$j$jscomp$95$$,$k$jscomp$355$$,$l$jscomp$84$$,$m$jscomp$121$$,$n$jscomp$194$$,$o$jscomp$161$$,$p$jscomp$66$$,$q$jscomp$30$$,$r$jscomp$49$$,$s$jscomp$298$$):$fexpr__25715$$($a$jscomp$251$$,$b$jscomp$207$$,$c$jscomp$178$$,$d$jscomp$135$$,$e$jscomp$152$$,$f__$1$jscomp$15$$,$g$jscomp$94$$,$h$jscomp$106$$,$i$jscomp$306$$,$j$jscomp$95$$,$k$jscomp$355$$,$l$jscomp$84$$,$m$jscomp$121$$,
$n$jscomp$194$$,$o$jscomp$161$$,$p$jscomp$66$$,$q$jscomp$30$$,$r$jscomp$49$$,$s$jscomp$298$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$20$=function($a$jscomp$252$$,$b$jscomp$208$$,$c$jscomp$179$$,$d$jscomp$136$$,$e$jscomp$153$$,$f__$1$jscomp$16$$,$g$jscomp$95$$,$h$jscomp$107$$,$i$jscomp$307$$,$j$jscomp$96$$,$k$jscomp$356$$,$l$jscomp$85$$,$m$jscomp$122$$,$n$jscomp$195$$,$o$jscomp$162$$,$p$jscomp$67$$,$q$jscomp$31$$,$r$jscomp$50$$,$s$jscomp$299$$,$t$jscomp$27$$){var $fexpr__25720$$=$APP.$cljs$core$_deref$$(this);return $fexpr__25720$$.$cljs$core$IFn$_invoke$arity$20$?$fexpr__25720$$.$cljs$core$IFn$_invoke$arity$20$($a$jscomp$252$$,
$b$jscomp$208$$,$c$jscomp$179$$,$d$jscomp$136$$,$e$jscomp$153$$,$f__$1$jscomp$16$$,$g$jscomp$95$$,$h$jscomp$107$$,$i$jscomp$307$$,$j$jscomp$96$$,$k$jscomp$356$$,$l$jscomp$85$$,$m$jscomp$122$$,$n$jscomp$195$$,$o$jscomp$162$$,$p$jscomp$67$$,$q$jscomp$31$$,$r$jscomp$50$$,$s$jscomp$299$$,$t$jscomp$27$$):$fexpr__25720$$($a$jscomp$252$$,$b$jscomp$208$$,$c$jscomp$179$$,$d$jscomp$136$$,$e$jscomp$153$$,$f__$1$jscomp$16$$,$g$jscomp$95$$,$h$jscomp$107$$,$i$jscomp$307$$,$j$jscomp$96$$,$k$jscomp$356$$,$l$jscomp$85$$,
$m$jscomp$122$$,$n$jscomp$195$$,$o$jscomp$162$$,$p$jscomp$67$$,$q$jscomp$31$$,$r$jscomp$50$$,$s$jscomp$299$$,$t$jscomp$27$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$21$=function($a$jscomp$253$$,$b$jscomp$209$$,$c$jscomp$180$$,$d$jscomp$137$$,$e$jscomp$154$$,$f__$1$jscomp$17$$,$g$jscomp$96$$,$h$jscomp$108$$,$i$jscomp$308$$,$j$jscomp$97$$,$k$jscomp$357$$,$l$jscomp$86$$,$m$jscomp$123$$,$n$jscomp$196$$,$o$jscomp$163$$,$p$jscomp$68$$,$q$jscomp$32$$,$r$jscomp$51$$,$s$jscomp$300$$,$t$jscomp$28$$,$rest$jscomp$13$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_deref$$(this),
$a$jscomp$253$$,$b$jscomp$209$$,$c$jscomp$180$$,$d$jscomp$137$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$e$jscomp$154$$,$f__$1$jscomp$17$$,$g$jscomp$96$$,$h$jscomp$108$$,$i$jscomp$308$$,$j$jscomp$97$$,$k$jscomp$357$$,$l$jscomp$86$$,$m$jscomp$123$$,$n$jscomp$196$$,$o$jscomp$163$$,$p$jscomp$68$$,$q$jscomp$32$$,$r$jscomp$51$$,$s$jscomp$300$$,$t$jscomp$28$$,$rest$jscomp$13$$]))};$malli$core$_function_schema_QMARK_$$._=function(){return!1};$malli$core$_function_info$$._=function(){return null};$malli$core$_instrument_f$$._=function(){return null};$malli$core$_distributive_schema_QMARK_$$._=function(){return!1};$malli$core$_distribute_to_children$$._=function($this$$jscomp$278$$){throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Not distributive",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$298$schema$$,$this$$jscomp$278$$],null));};
$malli$core$_regex_op_QMARK_$$._=function(){return!1};$malli$core$_regex_validator$$._=function($this$$jscomp$279$$){return $malli$core$_ref_schema_QMARK_$$($this$$jscomp$279$$)?$malli$core$_regex_validator$$($malli$core$_deref$$($this$$jscomp$279$$)):$malli$impl$regex$item_validator$$($malli$core$_validator$$($this$$jscomp$279$$))};
$malli$core$_regex_explainer$$._=function($this$$jscomp$280$$,$path$jscomp$42$$){return $malli$core$_ref_schema_QMARK_$$($this$$jscomp$280$$)?$malli$core$_regex_explainer$$($malli$core$_deref$$($this$$jscomp$280$$),$path$jscomp$42$$):$malli$impl$regex$item_explainer$$($path$jscomp$42$$,$this$$jscomp$280$$,$malli$core$_explainer$$($this$$jscomp$280$$,$path$jscomp$42$$))};
$malli$core$_regex_transformer$$._=function($or__5025__auto__$jscomp$inline_3494_this$$jscomp$283$$,$transformer$jscomp$11$$,$JSCompiler_temp$jscomp$383_method$jscomp$11$$,$options$jscomp$108$$){if($malli$core$_ref_schema_QMARK_$$($or__5025__auto__$jscomp$inline_3494_this$$jscomp$283$$))$JSCompiler_temp$jscomp$383_method$jscomp$11$$=$malli$core$_regex_transformer$$($malli$core$_deref$$($or__5025__auto__$jscomp$inline_3494_this$$jscomp$283$$),$transformer$jscomp$11$$,$JSCompiler_temp$jscomp$383_method$jscomp$11$$,
$options$jscomp$108$$);else{var $JSCompiler_temp_const$jscomp$384$$=$malli$core$_validator$$($or__5025__auto__$jscomp$inline_3494_this$$jscomp$283$$);$or__5025__auto__$jscomp$inline_3494_this$$jscomp$283$$=$malli$core$_transformer$$($or__5025__auto__$jscomp$inline_3494_this$$jscomp$283$$,$transformer$jscomp$11$$,$JSCompiler_temp$jscomp$383_method$jscomp$11$$,$options$jscomp$108$$);$JSCompiler_temp$jscomp$383_method$jscomp$11$$=$malli$impl$regex$item_transformer$$($JSCompiler_temp$jscomp$383_method$jscomp$11$$,
$JSCompiler_temp_const$jscomp$384$$,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_3494_this$$jscomp$283$$)?$or__5025__auto__$jscomp$inline_3494_this$$jscomp$283$$:$APP.$cljs$core$identity$$)}return $JSCompiler_temp$jscomp$383_method$jscomp$11$$};$malli$core$_regex_min_max$$._=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,1],null)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$Tag$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$2$$,$k__5324__auto__$jscomp$2$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$2$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$2$$,$k31303$$,$else__5326__auto__$jscomp$2$$){switch($k31303$$ instanceof $APP.$cljs$core$Keyword$$?$k31303$$.$fqn$:null){case "key":return this.key;case "value":return this.value;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k31303$$,$else__5326__auto__$jscomp$2$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$2$$,$f__5344__auto__$jscomp$2$$,$init__5345__auto__$jscomp$2$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$2$$,$p__31320_v__5348__auto__$jscomp$2$$){var $k__5347__auto__$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31320_v__5348__auto__$jscomp$2$$,0,null);$p__31320_v__5348__auto__$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31320_v__5348__auto__$jscomp$2$$,
1,null);return $f__5344__auto__$jscomp$2$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$2$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$2$$,$k__5347__auto__$jscomp$2$$,$p__31320_v__5348__auto__$jscomp$2$$):$f__5344__auto__$jscomp$2$$($ret__5346__auto__$jscomp$2$$,$k__5347__auto__$jscomp$2$$,$p__31320_v__5348__auto__$jscomp$2$$)},$init__5345__auto__$jscomp$2$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$2$$,$writer__5339__auto__$jscomp$2$$,$opts__5340__auto__$jscomp$2$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$2$$,function($keyval__5342__auto__$jscomp$2$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$2$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$2$$,$keyval__5342__auto__$jscomp$2$$)},"#malli.core.Tag{",
", ","}",$opts__5340__auto__$jscomp$2$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$302$key$$,this.key],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,this.value],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,2,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$260$value$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $malli$core$Tag$$(this.key,this.value,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$28_h__5134__auto____$1$jscomp$28$$=this.$__hash$;return $h__5134__auto__$jscomp$28_h__5134__auto____$1$jscomp$28$$!=null?$h__5134__auto__$jscomp$28_h__5134__auto____$1$jscomp$28$$:this.$__hash$=$h__5134__auto__$jscomp$28_h__5134__auto____$1$jscomp$28$$=237888567^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this31304$$,$other31305$$){return $other31305$$!=null&&this.constructor===$other31305$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.key,$other31305$$.key)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.value,$other31305$$.value)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other31305$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$2$$,$k__5334__auto__$jscomp$2$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,null,$APP.$cljs$cst$260$value$$,null],null),null),$k__5334__auto__$jscomp$2$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$2$$):new $malli$core$Tag$$(this.key,this.value,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$2$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$2$$,$k31303$jscomp$1$$){switch($k31303$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k31303$jscomp$1$$.$fqn$:null){case "key":case "value":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k31303$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$2$$,$k__5332__auto__$jscomp$2$$,$G__31302$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$302$key$$,$k__5332__auto__$jscomp$2$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$302$key$$,$k__5332__auto__$jscomp$2$$))?new $malli$core$Tag$$($G__31302$jscomp$1$$,
this.value,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$2$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$2$$))?new $malli$core$Tag$$(this.key,$G__31302$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $malli$core$Tag$$(this.key,this.value,
this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$2$$,$G__31302$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$302$key$$,this.key,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$260$value$$,this.value,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$2$$,$G__31302$jscomp$2$$){return new $malli$core$Tag$$(this.key,this.value,$G__31302$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$2$$,$entry__5329__auto__$jscomp$2$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$2$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$2$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$2$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$2$$)};
$APP.$JSCompiler_prototypeAlias$$=$malli$core$Tags$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$3$$,$k__5324__auto__$jscomp$3$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$3$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$3$$,$k31374$$,$else__5326__auto__$jscomp$3$$){switch($k31374$$ instanceof $APP.$cljs$core$Keyword$$?$k31374$$.$fqn$:null){case "values":return this.values;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k31374$$,$else__5326__auto__$jscomp$3$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$3$$,$f__5344__auto__$jscomp$3$$,$init__5345__auto__$jscomp$3$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$3$$,$p__31389_v__5348__auto__$jscomp$3$$){var $k__5347__auto__$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31389_v__5348__auto__$jscomp$3$$,0,null);$p__31389_v__5348__auto__$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31389_v__5348__auto__$jscomp$3$$,
1,null);return $f__5344__auto__$jscomp$3$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$3$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$3$$,$k__5347__auto__$jscomp$3$$,$p__31389_v__5348__auto__$jscomp$3$$):$f__5344__auto__$jscomp$3$$($ret__5346__auto__$jscomp$3$$,$k__5347__auto__$jscomp$3$$,$p__31389_v__5348__auto__$jscomp$3$$)},$init__5345__auto__$jscomp$3$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$3$$,$writer__5339__auto__$jscomp$3$$,$opts__5340__auto__$jscomp$3$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$3$$,function($keyval__5342__auto__$jscomp$3$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$3$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$3$$,$keyval__5342__auto__$jscomp$3$$)},"#malli.core.Tags{",
", ","}",$opts__5340__auto__$jscomp$3$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$301$values$$,this.values],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,1,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$301$values$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $malli$core$Tags$$(this.values,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 1+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$29_h__5134__auto____$1$jscomp$29$$=this.$__hash$;return $h__5134__auto__$jscomp$29_h__5134__auto____$1$jscomp$29$$!=null?$h__5134__auto__$jscomp$29_h__5134__auto____$1$jscomp$29$$:this.$__hash$=$h__5134__auto__$jscomp$29_h__5134__auto____$1$jscomp$29$$=-1914571781^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this31376$$,$other31377$$){return $other31377$$!=null&&this.constructor===$other31377$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.values,$other31377$$.values)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other31377$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$3$$,$k__5334__auto__$jscomp$3$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$301$values$$,null],null),null),$k__5334__auto__$jscomp$3$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$3$$):new $malli$core$Tags$$(this.values,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$3$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$3$$,$k31374$jscomp$1$$){switch($k31374$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k31374$jscomp$1$$.$fqn$:null){case "values":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k31374$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$3$$,$k__5332__auto__$jscomp$3$$,$G__31373$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$301$values$$,$k__5332__auto__$jscomp$3$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$301$values$$,$k__5332__auto__$jscomp$3$$))?
new $malli$core$Tags$$($G__31373$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $malli$core$Tags$$(this.values,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$3$$,$G__31373$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$301$values$$,this.values,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$3$$,$G__31373$jscomp$2$$){return new $malli$core$Tags$$(this.values,$G__31373$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$3$$,$entry__5329__auto__$jscomp$3$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$3$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$3$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$3$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$3$$)};
var $malli$core$_fail_BANG_$$=function $malli$core$_fail_BANG_$$($var_args$jscomp$437$$){switch(arguments.length){case 1:return $malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$1$=function($type$jscomp$191$$){return $malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$191$$,null)};$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$=function($type$jscomp$192$$,$data$jscomp$99$$){throw $malli$core$_exception$$($type$jscomp$192$$,$data$jscomp$99$$);};$malli$core$_fail_BANG_$$.$cljs$lang$maxFixedArity$=2;
var $malli$core$_comp$$=function $malli$core$_comp$$($var_args$jscomp$439$$){switch(arguments.length){case 0:return $malli$core$_comp$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $malli$core$_comp$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $malli$core$_comp$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $malli$core$_comp$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:for(var $args_arr__5774__auto__$jscomp$85$$=
[],$len__5749__auto___34673$$=arguments.length,$i__5750__auto___34676$$=0;;)if($i__5750__auto___34676$$<$len__5749__auto___34673$$)$args_arr__5774__auto__$jscomp$85$$.push(arguments[$i__5750__auto___34676$$]),$i__5750__auto___34676$$+=1;else break;return $malli$core$_comp$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],3<$args_arr__5774__auto__$jscomp$85$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$85$$.slice(3),0,null):null)}};
$malli$core$_comp$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$cljs$core$identity$$};$malli$core$_comp$$.$cljs$core$IFn$_invoke$arity$1$=function($f$jscomp$389$$){return $f$jscomp$389$$};
$malli$core$_comp$$.$cljs$core$IFn$_invoke$arity$2$=function($f$jscomp$390$$,$g$jscomp$97$$){return function($G__31560_x$jscomp$715$$){$G__31560_x$jscomp$715$$=$g$jscomp$97$$.$cljs$core$IFn$_invoke$arity$1$?$g$jscomp$97$$.$cljs$core$IFn$_invoke$arity$1$($G__31560_x$jscomp$715$$):$g$jscomp$97$$($G__31560_x$jscomp$715$$);return $f$jscomp$390$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$390$$.$cljs$core$IFn$_invoke$arity$1$($G__31560_x$jscomp$715$$):$f$jscomp$390$$($G__31560_x$jscomp$715$$)}};
$malli$core$_comp$$.$cljs$core$IFn$_invoke$arity$3$=function($f$jscomp$391$$,$g$jscomp$98$$,$h$jscomp$109$$){return function($G__31567_G__31569$jscomp$inline_3500_x$jscomp$716$$){$G__31567_G__31569$jscomp$inline_3500_x$jscomp$716$$=$h$jscomp$109$$.$cljs$core$IFn$_invoke$arity$1$?$h$jscomp$109$$.$cljs$core$IFn$_invoke$arity$1$($G__31567_G__31569$jscomp$inline_3500_x$jscomp$716$$):$h$jscomp$109$$($G__31567_G__31569$jscomp$inline_3500_x$jscomp$716$$);$G__31567_G__31569$jscomp$inline_3500_x$jscomp$716$$=
$g$jscomp$98$$.$cljs$core$IFn$_invoke$arity$1$?$g$jscomp$98$$.$cljs$core$IFn$_invoke$arity$1$($G__31567_G__31569$jscomp$inline_3500_x$jscomp$716$$):$g$jscomp$98$$($G__31567_G__31569$jscomp$inline_3500_x$jscomp$716$$);return $f$jscomp$391$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$391$$.$cljs$core$IFn$_invoke$arity$1$($G__31567_G__31569$jscomp$inline_3500_x$jscomp$716$$):$f$jscomp$391$$($G__31567_G__31569$jscomp$inline_3500_x$jscomp$716$$)}};
$malli$core$_comp$$.$cljs$core$IFn$_invoke$arity$variadic$=function($f1$jscomp$4$$,$f2$jscomp$1$$,$f3$jscomp$1$$,$fs$jscomp$3$$){var $f4$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$core$_comp$$,$fs$jscomp$3$$);return function($G__31580_G__31581$jscomp$inline_11400_G__31584$jscomp$inline_11401_x$jscomp$717$$){$G__31580_G__31581$jscomp$inline_11400_G__31584$jscomp$inline_11401_x$jscomp$717$$=$f4$$.$cljs$core$IFn$_invoke$arity$1$?$f4$$.$cljs$core$IFn$_invoke$arity$1$($G__31580_G__31581$jscomp$inline_11400_G__31584$jscomp$inline_11401_x$jscomp$717$$):
$f4$$($G__31580_G__31581$jscomp$inline_11400_G__31584$jscomp$inline_11401_x$jscomp$717$$);$G__31580_G__31581$jscomp$inline_11400_G__31584$jscomp$inline_11401_x$jscomp$717$$=$f3$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$f3$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__31580_G__31581$jscomp$inline_11400_G__31584$jscomp$inline_11401_x$jscomp$717$$):$f3$jscomp$1$$($G__31580_G__31581$jscomp$inline_11400_G__31584$jscomp$inline_11401_x$jscomp$717$$);$G__31580_G__31581$jscomp$inline_11400_G__31584$jscomp$inline_11401_x$jscomp$717$$=
$f2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$f2$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__31580_G__31581$jscomp$inline_11400_G__31584$jscomp$inline_11401_x$jscomp$717$$):$f2$jscomp$1$$($G__31580_G__31581$jscomp$inline_11400_G__31584$jscomp$inline_11401_x$jscomp$717$$);return $f1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$f1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($G__31580_G__31581$jscomp$inline_11400_G__31584$jscomp$inline_11401_x$jscomp$717$$):$f1$jscomp$4$$($G__31580_G__31581$jscomp$inline_11400_G__31584$jscomp$inline_11401_x$jscomp$717$$)}};
$malli$core$_comp$$.$cljs$lang$applyTo$=function($G__31527_seq31524$$){var $G__31526$$=$APP.$cljs$core$first$$($G__31527_seq31524$$),$G__31528_seq31524__$1$$=$APP.$cljs$core$next$$($G__31527_seq31524$$);$G__31527_seq31524$$=$APP.$cljs$core$first$$($G__31528_seq31524__$1$$);var $seq31524__$2_seq31524__$3$$=$APP.$cljs$core$next$$($G__31528_seq31524__$1$$);$G__31528_seq31524__$1$$=$APP.$cljs$core$first$$($seq31524__$2_seq31524__$3$$);$seq31524__$2_seq31524__$3$$=$APP.$cljs$core$next$$($seq31524__$2_seq31524__$3$$);
return this.$cljs$core$IFn$_invoke$arity$variadic$($G__31526$$,$G__31527_seq31524$$,$G__31528_seq31524__$1$$,$seq31524__$2_seq31524__$3$$)};$malli$core$_comp$$.$cljs$lang$maxFixedArity$=3;
var $malli$core$_update_properties$$=function $malli$core$_update_properties$$($var_args$jscomp$443$$){for(var $args__5755__auto__$jscomp$55$$=[],$len__5749__auto___34750$$=arguments.length,$i__5750__auto___34751$$=0;;)if($i__5750__auto___34751$$<$len__5749__auto___34750$$)$args__5755__auto__$jscomp$55$$.push(arguments[$i__5750__auto___34751$$]),$i__5750__auto___34751$$+=1;else break;return $malli$core$_update_properties$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args__5755__auto__$jscomp$55$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$55$$.slice(2),0,null):null)};
$malli$core$_update_properties$$.$cljs$core$IFn$_invoke$arity$variadic$=function($JSCompiler_temp$jscomp$inline_14116_schema$jscomp$23$$,$f$jscomp$404_properties$jscomp$inline_14115$$,$JSCompiler_temp_const$jscomp$inline_14117_args$jscomp$129$$){$f$jscomp$404_properties$jscomp$inline_14115$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($f$jscomp$404_properties$jscomp$inline_14115$$,$malli$core$_properties$$($JSCompiler_temp$jscomp$inline_14116_schema$jscomp$23$$),
$JSCompiler_temp_const$jscomp$inline_14117_args$jscomp$129$$));if(!$malli$core$_equals$$($f$jscomp$404_properties$jscomp$inline_14115$$,$malli$core$_properties$$($JSCompiler_temp$jscomp$inline_14116_schema$jscomp$23$$))){$JSCompiler_temp_const$jscomp$inline_14117_args$jscomp$129$$=$malli$core$_into_schema$$;var $JSCompiler_temp_const$jscomp$inline_14118$$=$malli$core$_parent$$($JSCompiler_temp$jscomp$inline_14116_schema$jscomp$23$$);var $JSCompiler_inline_result$jscomp$inline_14119_and__5023__auto__$jscomp$inline_14121_or__5025__auto__$jscomp$inline_14120$$=
($JSCompiler_inline_result$jscomp$inline_14119_and__5023__auto__$jscomp$inline_14121_or__5025__auto__$jscomp$inline_14120$$=$JSCompiler_temp$jscomp$inline_14116_schema$jscomp$23$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$JSCompiler_temp$jscomp$inline_14116_schema$jscomp$23$$.$malli$core$EntrySchema$$?!0:!1:!1)?$malli$core$_entry_parser$$($JSCompiler_temp$jscomp$inline_14116_schema$jscomp$23$$):$JSCompiler_inline_result$jscomp$inline_14119_and__5023__auto__$jscomp$inline_14121_or__5025__auto__$jscomp$inline_14120$$;
$JSCompiler_inline_result$jscomp$inline_14119_and__5023__auto__$jscomp$inline_14121_or__5025__auto__$jscomp$inline_14120$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14119_and__5023__auto__$jscomp$inline_14121_or__5025__auto__$jscomp$inline_14120$$)?$JSCompiler_inline_result$jscomp$inline_14119_and__5023__auto__$jscomp$inline_14121_or__5025__auto__$jscomp$inline_14120$$:$malli$core$_children$$($JSCompiler_temp$jscomp$inline_14116_schema$jscomp$23$$);$JSCompiler_temp$jscomp$inline_14116_schema$jscomp$23$$=
$JSCompiler_temp_const$jscomp$inline_14117_args$jscomp$129$$($JSCompiler_temp_const$jscomp$inline_14118$$,$f$jscomp$404_properties$jscomp$inline_14115$$,$JSCompiler_inline_result$jscomp$inline_14119_and__5023__auto__$jscomp$inline_14121_or__5025__auto__$jscomp$inline_14120$$,$malli$core$_options$$($JSCompiler_temp$jscomp$inline_14116_schema$jscomp$23$$))}return $JSCompiler_temp$jscomp$inline_14116_schema$jscomp$23$$};$malli$core$_update_properties$$.$cljs$lang$maxFixedArity$=2;
$malli$core$_update_properties$$.$cljs$lang$applyTo$=function($G__31753_seq31751$$){var $G__31752$$=$APP.$cljs$core$first$$($G__31753_seq31751$$),$seq31751__$1_seq31751__$2$$=$APP.$cljs$core$next$$($G__31753_seq31751$$);$G__31753_seq31751$$=$APP.$cljs$core$first$$($seq31751__$1_seq31751__$2$$);$seq31751__$1_seq31751__$2$$=$APP.$cljs$core$next$$($seq31751__$1_seq31751__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__31752$$,$G__31753_seq31751$$,$seq31751__$1_seq31751__$2$$)};
$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core31774$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_31776$$,$meta31775__$1$$){return new $malli$core$t_malli$0core31774$$(this.$keyset$,this.children,this.forms,this.entries,$meta31775__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta31775$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntryParser$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntryParser$_entry_keyset$arity$1$=function(){return this.$keyset$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntryParser$_entry_children$arity$1$=function(){return this.children};$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntryParser$_entry_entries$arity$1$=function(){return this.entries};$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntryParser$_entry_forms$arity$1$=function(){return this.forms};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core31888$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_31890$$,$meta31889__$1$$){return new $malli$core$t_malli$0core31888$$(this.$_QMARK_children$,this.props,this.options,this.parser,$meta31889__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta31889$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntryParser$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntryParser$_entry_keyset$arity$1$=function(){return $malli$core$_entry_keyset$$($APP.$cljs$core$_deref$$(this.parser))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntryParser$_entry_children$arity$1$=function(){return $malli$core$_entry_children$$($APP.$cljs$core$_deref$$(this.parser))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntryParser$_entry_entries$arity$1$=function(){return $malli$core$_entry_entries$$($APP.$cljs$core$_deref$$(this.parser))};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntryParser$_entry_forms$arity$1$=function(){return $malli$core$_entry_forms$$($APP.$cljs$core$_deref$$(this.parser))};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core31908$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_31910$$,$meta31909__$1$$){return new $malli$core$t_malli$0core31908$$($meta31909__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta31909$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Transformer$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Transformer$_transformer_chain$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Transformer$_value_transformer$arity$4$=function(){return null};
var $malli$core$_into_transformer$$=function $malli$core$_into_transformer$$($G__31944_x$jscomp$720$$){return $G__31944_x$jscomp$720$$!=null&&$APP.$cljs$core$PROTOCOL_SENTINEL$$===$G__31944_x$jscomp$720$$.$malli$core$Transformer$$?$G__31944_x$jscomp$720$$:$APP.$cljs$core$fn_QMARK_$$($G__31944_x$jscomp$720$$)?($G__31944_x$jscomp$720$$=$G__31944_x$jscomp$720$$.$cljs$core$IFn$_invoke$arity$0$?$G__31944_x$jscomp$720$$.$cljs$core$IFn$_invoke$arity$0$():$G__31944_x$jscomp$720$$(),$malli$core$_into_transformer$$.$cljs$core$IFn$_invoke$arity$1$?
$malli$core$_into_transformer$$.$cljs$core$IFn$_invoke$arity$1$($G__31944_x$jscomp$720$$):$malli$core$_into_transformer$$($G__31944_x$jscomp$720$$)):$G__31944_x$jscomp$720$$==null?new $malli$core$t_malli$0core31908$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$):$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$383$malli_DOT_core_SLASH_invalid_transformer$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$G__31944_x$jscomp$720$$],null))};
$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32221$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32223$$,$meta32222__$1$$){return new $malli$core$t_malli$0core32221$$(this.form,this.options,this.$property_pred$,this.compile,this.$to_ast$,this.props,this.$meta32193$,this.$properties$,this.$map__32183$,this.children,this.min,this.$type_properties$,this.parent,this.$pred$,this.type,this.$from_ast$,this.cache,this.max,$meta32222__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32222$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return this.$to_ast$.$cljs$core$IFn$_invoke$arity$1$?this.$to_ast$.$cljs$core$IFn$_invoke$arity$1$(this):this.$to_ast$(this)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){var $self__$jscomp$1336$$=this,$temp__5823__auto__$jscomp$51$$=$APP.$cljs$core$truth_$$($self__$jscomp$1336$$.$property_pred$)?$self__$jscomp$1336$$.$property_pred$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$1336$$.$property_pred$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$1336$$.$properties$):$self__$jscomp$1336$$.$property_pred$($self__$jscomp$1336$$.$properties$):null;return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$51$$)?
function($x$jscomp$734$$){var $and__5023__auto__$jscomp$77$$=$self__$jscomp$1336$$.$pred$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$1336$$.$pred$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$734$$):$self__$jscomp$1336$$.$pred$($x$jscomp$734$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$77$$)?$temp__5823__auto__$jscomp$51$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5823__auto__$jscomp$51$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$734$$):$temp__5823__auto__$jscomp$51$$($x$jscomp$734$$):
$and__5023__auto__$jscomp$77$$}:$self__$jscomp$1336$$.$pred$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$286$$,$transformer$jscomp$14$$,$method$jscomp$14$$,$options__$1$jscomp$2$$){return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$01$$($malli$core$_value_transformer$$($transformer$jscomp$14$$,this,$method$jscomp$14$$,$options__$1$jscomp$2$$))};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$287$$,$walker$jscomp$7$$,$path$jscomp$48$$,$options__$1$jscomp$3$$){return $malli$core$_walk_leaf$$(this,$walker$jscomp$7$$,$path$jscomp$48$$,$options__$1$jscomp$3$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$289$$,$path$jscomp$49$$){var $this$__$1$jscomp$31$$=this,$validator$jscomp$16$$=$this$__$1$jscomp$31$$.$malli$core$Schema$_validator$arity$1$(null);return function($x$jscomp$736$$,$in$$jscomp$12$$,$acc$jscomp$27$$){return $APP.$cljs$core$not$$($validator$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$?$validator$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$736$$):$validator$jscomp$16$$($x$jscomp$736$$))?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$27$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$04$$($path$jscomp$49$$,$in$$jscomp$12$$,$this$__$1$jscomp$31$$,$x$jscomp$736$$)):$acc$jscomp$27$$}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$300$$,$___$1$jscomp$138$$,$default$$jscomp$12$$){return $default$$jscomp$12$$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$291$$,$key$jscomp$193$$){return $malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$395$malli_DOT_core_SLASH_non_associative_schema$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$298$schema$$,this,$APP.$cljs$cst$302$key$$,$key$jscomp$193$$],null))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$292$$,$writer$jscomp$87$$,$opts$jscomp$144$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$87$$,$opts$jscomp$144$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32192$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32194$$,$meta32193__$1$$){return new $malli$core$t_malli$0core32192$$(this.$property_pred$,this.compile,this.$to_ast$,this.props,this.$map__32183$,this.min,this.$type_properties$,this.$pred$,this.type,this.$from_ast$,this.max,$meta32193__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32193$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return this.type};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return this.$type_properties$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($form$jscomp$40_parent$jscomp$27$$,$properties$jscomp$18$$,$children$jscomp$28$$,$options$jscomp$145$$){var $self__$jscomp$1359$$=this,$parent__$1$jscomp$1$$=this;if($APP.$cljs$core$truth_$$($self__$jscomp$1359$$.compile))return $malli$core$_into_schema$$(function(){var $G__32219$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$1359$$.props,
$APP.$cljs$cst$411$compile$$),$self__$jscomp$1359$$.compile.$cljs$core$IFn$_invoke$arity$3$?$self__$jscomp$1359$$.compile.$cljs$core$IFn$_invoke$arity$3$($properties$jscomp$18$$,$children$jscomp$28$$,$options$jscomp$145$$):$self__$jscomp$1359$$.compile($properties$jscomp$18$$,$children$jscomp$28$$,$options$jscomp$145$$)]));return $malli$core$_simple_schema$$.$cljs$core$IFn$_invoke$arity$1$?$malli$core$_simple_schema$$.$cljs$core$IFn$_invoke$arity$1$($G__32219$$):$malli$core$_simple_schema$$($G__32219$$)}(),
$properties$jscomp$18$$,$children$jscomp$28$$,$options$jscomp$145$$);$form$jscomp$40_parent$jscomp$27$$=new $APP.$cljs$core$Delay$$(function(){return $malli$core$_simple_form$$($parent__$1$jscomp$1$$,$properties$jscomp$18$$,$children$jscomp$28$$,$APP.$cljs$core$identity$$,$options$jscomp$145$$)});var $cache$jscomp$10$$=$malli$core$_create_cache$$();$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($self__$jscomp$1359$$.type,$properties$jscomp$18$$,$children$jscomp$28$$,$self__$jscomp$1359$$.min,
$self__$jscomp$1359$$.max);return new $malli$core$t_malli$0core32221$$($form$jscomp$40_parent$jscomp$27$$,$options$jscomp$145$$,$self__$jscomp$1359$$.$property_pred$,$self__$jscomp$1359$$.compile,$self__$jscomp$1359$$.$to_ast$,$self__$jscomp$1359$$.props,$self__$jscomp$1359$$.$meta32193$,$properties$jscomp$18$$,$self__$jscomp$1359$$.$map__32183$,$children$jscomp$28$$,$self__$jscomp$1359$$.min,$self__$jscomp$1359$$.$type_properties$,$parent__$1$jscomp$1$$,$self__$jscomp$1359$$.$pred$,$self__$jscomp$1359$$.type,
$self__$jscomp$1359$$.$from_ast$,$cache$jscomp$10$$,$self__$jscomp$1359$$.max,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$293$$,$writer$jscomp$88$$,$opts$jscomp$145$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$88$$,$opts$jscomp$145$$)};
var $malli$core$_simple_schema$$=function $malli$core$_simple_schema$$($props$jscomp$15$$){var $G__32190_map__32183__$1$$=$APP.$cljs$core$__destructure_map$$($props$jscomp$15$$),$property_pred$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__32190_map__32183__$1$$,$cljs$cst$413$property_pred$$),$compile$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__32190_map__32183__$1$$,$APP.$cljs$cst$411$compile$$),$to_ast$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($G__32190_map__32183__$1$$,
$cljs$cst$414$to_ast$$,$malli$core$_to_type_ast$$),$min$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($G__32190_map__32183__$1$$,$APP.$cljs$cst$338$min$$,0),$type_properties$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__32190_map__32183__$1$$,$cljs$cst$415$type_properties$$),$pred$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__32190_map__32183__$1$$,$APP.$cljs$cst$351$pred$$),$type$jscomp$201$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__32190_map__32183__$1$$,
$APP.$cljs$cst$139$type$$),$from_ast$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($G__32190_map__32183__$1$$,$cljs$cst$416$from_ast$$,$malli$core$_from_value_ast$$),$max$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($G__32190_map__32183__$1$$,$APP.$cljs$cst$339$max$$,0);return $APP.$cljs$core$fn_QMARK_$$($props$jscomp$15$$)?($APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["DEPRECATED:",
"-simple-schema doesn't take fn-props, use :compile property instead"])),$G__32190_map__32183__$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$411$compile$$,function($c$jscomp$190$$,$p$jscomp$76$$){return $props$jscomp$15$$.$cljs$core$IFn$_invoke$arity$2$?$props$jscomp$15$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$190$$,$p$jscomp$76$$):$props$jscomp$15$$($c$jscomp$190$$,$p$jscomp$76$$)}],null),$malli$core$_simple_schema$$.$cljs$core$IFn$_invoke$arity$1$?$malli$core$_simple_schema$$.$cljs$core$IFn$_invoke$arity$1$($G__32190_map__32183__$1$$):
$malli$core$_simple_schema$$($G__32190_map__32183__$1$$)):new $malli$core$t_malli$0core32192$$($property_pred$jscomp$4$$,$compile$jscomp$4$$,$to_ast$jscomp$4$$,$props$jscomp$15$$,$G__32190_map__32183__$1$$,$min$jscomp$16$$,$type_properties$jscomp$4$$,$pred$jscomp$34$$,$type$jscomp$201$$,$from_ast$jscomp$4$$,$max$jscomp$16$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32354$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32356$$,$meta32355__$1$$){return new $malli$core$t_malli$0core32354$$(this.$meta32316$,this.parent,this.$properties$,this.children,this.options,this.form,this.cache,this.$__GT_parser$,$meta32355__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32355$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){var $validators$jscomp$1$$=$malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$core$_validator$$,this.children);return $malli$impl$util$_every_pred$$($validators$jscomp$1$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$294$$,$transformer$jscomp$15$$,$method$jscomp$15$$,$options__$1$jscomp$4$$){return $malli$core$_parent_children_transformer$$(this,this.children,$transformer$jscomp$15$$,$method$jscomp$15$$,$options__$1$jscomp$4$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$295$$,$walker$jscomp$8$$,$path$jscomp$50$$,$options__$1$jscomp$5$$){return $malli$core$_walk_indexed$$(this,$walker$jscomp$8$$,$path$jscomp$50$$,$options__$1$jscomp$5$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($_$jscomp$313$$,$path$jscomp$51$$){var $explainers$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($c$jscomp$191_p__32372$$){var $i$jscomp$316$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$191_p__32372$$,0,null);$c$jscomp$191_p__32372$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$191_p__32372$$,1,null);return $malli$core$_explainer$$($c$jscomp$191_p__32372$$,
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$51$$,$i$jscomp$316$$))},$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,this.children));return function($x$jscomp$737$$,$in$$jscomp$13$$,$acc$jscomp$28$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc_SINGLEQUOTE_$$,$explainer$jscomp$4$$){return $explainer$jscomp$4$$.$cljs$core$IFn$_invoke$arity$3$?$explainer$jscomp$4$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$737$$,
$in$$jscomp$13$$,$acc_SINGLEQUOTE_$$):$explainer$jscomp$4$$($x$jscomp$737$$,$in$$jscomp$13$$,$acc_SINGLEQUOTE_$$)},$acc$jscomp$28$$,$explainers$$)}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$318$$,$key$jscomp$194$$,$default$$jscomp$13$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.children,$key$jscomp$194$$,$default$$jscomp$13$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$296$$,$key$jscomp$195$$,$value$jscomp$241$$){return $malli$core$_set_assoc_children$$(this,$key$jscomp$195$$,$value$jscomp$241$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$297$$,$writer$jscomp$89$$,$opts$jscomp$146$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$89$$,$opts$jscomp$146$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32315$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32317$$,$meta32316__$1$$){return new $malli$core$t_malli$0core32315$$($meta32316__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32316$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $APP.$cljs$cst$429$and$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($parent$jscomp$30$$,$properties$jscomp$21$$,$children$jscomp$31$$,$options$jscomp$148$$){var $parent__$1$jscomp$2$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$cljs$cst$429$and$$,$properties$jscomp$21$$,$children$jscomp$31$$,1,null);var $children__$1$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__32313_SHARP_$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($p1__32313_SHARP_$$,$options$jscomp$148$$):$APP.$malli$core$schema$$($p1__32313_SHARP_$$,$options$jscomp$148$$)},$children$jscomp$31$$);return new $malli$core$t_malli$0core32354$$(this.$meta32316$,$parent__$1$jscomp$2$$,$properties$jscomp$21$$,$children__$1$$,$options$jscomp$148$$,new $APP.$cljs$core$Delay$$(function(){return $malli$core$_simple_form$$($parent__$1$jscomp$2$$,$properties$jscomp$21$$,$children__$1$$,$malli$core$_form$$,$options$jscomp$148$$)}),
$malli$core$_create_cache$$(),function($f$jscomp$413$$,$m$jscomp$131$$){var $parsers$$=function(){var $G__32348$$=$malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$413$$,$children__$1$$);return $m$jscomp$131$$.$cljs$core$IFn$_invoke$arity$1$?$m$jscomp$131$$.$cljs$core$IFn$_invoke$arity$1$($G__32348$$):$m$jscomp$131$$($G__32348$$)}();return function($p1__32314_SHARP_$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($x$jscomp$738$$,$parser$jscomp$5$$){return $malli$impl$util$_map_invalid$$($parser$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?
$parser$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$738$$):$parser$jscomp$5$$($x$jscomp$738$$))},$p1__32314_SHARP_$$,$parsers$$)}},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$298$$,$writer$jscomp$90$$,$opts$jscomp$147$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$90$$,$opts$jscomp$147$$)};
$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32419$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32421$$,$meta32420__$1$$){return new $malli$core$t_malli$0core32419$$(this.$meta32403$,this.parent,this.$properties$,this.children,this.options,this.form,this.cache,this.$__GT_parser$,$meta32420__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32420$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){var $validators$jscomp$2$$=$malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$core$_validator$$,this.children);return $malli$impl$util$_some_pred$$($validators$jscomp$2$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$299$$,$transformer$jscomp$16$$,$method$jscomp$16$$,$options__$1$jscomp$6$$){return $malli$core$_or_transformer$$(this,$transformer$jscomp$16$$,this.children,$method$jscomp$16$$,$options__$1$jscomp$6$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$300$$,$walker$jscomp$9$$,$path$jscomp$52$$,$options__$1$jscomp$7$$){return $malli$core$_walk_indexed$$(this,$walker$jscomp$9$$,$path$jscomp$52$$,$options__$1$jscomp$7$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($_$jscomp$329$$,$path$jscomp$53$$){var $explainers$jscomp$1$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($c$jscomp$192_p__32434$$){var $i$jscomp$317$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$192_p__32434$$,0,null);$c$jscomp$192_p__32434$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$192_p__32434$$,1,null);return $malli$core$_explainer$$($c$jscomp$192_p__32434$$,
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$53$$,$i$jscomp$317$$))},$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,this.children));return function($x$jscomp$739$$,$in$$jscomp$14$$,$acc$jscomp$29$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc_SINGLEQUOTE_$jscomp$1$$,$acc_SINGLEQUOTE__SINGLEQUOTE__explainer$jscomp$5$$){$acc_SINGLEQUOTE__SINGLEQUOTE__explainer$jscomp$5$$=$acc_SINGLEQUOTE__SINGLEQUOTE__explainer$jscomp$5$$.$cljs$core$IFn$_invoke$arity$3$?
$acc_SINGLEQUOTE__SINGLEQUOTE__explainer$jscomp$5$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$739$$,$in$$jscomp$14$$,$acc_SINGLEQUOTE_$jscomp$1$$):$acc_SINGLEQUOTE__SINGLEQUOTE__explainer$jscomp$5$$($x$jscomp$739$$,$in$$jscomp$14$$,$acc_SINGLEQUOTE_$jscomp$1$$);return $acc_SINGLEQUOTE_$jscomp$1$$===$acc_SINGLEQUOTE__SINGLEQUOTE__explainer$jscomp$5$$?$APP.$cljs$core$reduced$$($acc$jscomp$29$$):$acc_SINGLEQUOTE__SINGLEQUOTE__explainer$jscomp$5$$},$acc$jscomp$29$$,$explainers$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$334$$,$key$jscomp$196$$,$default$$jscomp$14$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.children,$key$jscomp$196$$,$default$$jscomp$14$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$301$$,$key$jscomp$197$$,$value$jscomp$242$$){return $malli$core$_set_assoc_children$$(this,$key$jscomp$197$$,$value$jscomp$242$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$302$$,$writer$jscomp$91$$,$opts$jscomp$148$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$91$$,$opts$jscomp$148$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32402$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32404$$,$meta32403__$1$$){return new $malli$core$t_malli$0core32402$$($meta32403__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32403$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $APP.$cljs$cst$433$or$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($parent$jscomp$33$$,$properties$jscomp$24$$,$children$jscomp$34$$,$options$jscomp$151$$){var $parent__$1$jscomp$3$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$cljs$cst$433$or$$,$properties$jscomp$24$$,$children$jscomp$34$$,1,null);var $children__$1$jscomp$1$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__32396_SHARP_$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($p1__32396_SHARP_$$,$options$jscomp$151$$):$APP.$malli$core$schema$$($p1__32396_SHARP_$$,$options$jscomp$151$$)},$children$jscomp$34$$);return new $malli$core$t_malli$0core32419$$(this.$meta32403$,$parent__$1$jscomp$3$$,$properties$jscomp$24$$,$children__$1$jscomp$1$$,$options$jscomp$151$$,new $APP.$cljs$core$Delay$$(function(){return $malli$core$_simple_form$$($parent__$1$jscomp$3$$,$properties$jscomp$24$$,$children__$1$jscomp$1$$,$malli$core$_form$$,
$options$jscomp$151$$)}),$malli$core$_create_cache$$(),function($f$jscomp$414$$){var $parsers$jscomp$1$$=$malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$414$$,$children__$1$jscomp$1$$);return function($p1__32399_SHARP_$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($_$jscomp$339$$,$parser$jscomp$6$$){return $malli$impl$util$_map_valid$$($APP.$cljs$core$reduced$$,$parser$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$parser$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($p1__32399_SHARP_$$):
$parser$jscomp$6$$($p1__32399_SHARP_$$))},$cljs$cst$295$malli_DOT_core_SLASH_invalid$$,$parsers$jscomp$1$$)}},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$303$$,$writer$jscomp$92$$,$opts$jscomp$149$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$92$$,$opts$jscomp$149$$)};
$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32494$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32496$$,$meta32495__$1$$){return new $malli$core$t_malli$0core32494$$(this.$meta32487$,this.parent,this.$properties$,this.children,this.options,this.$entry_parser$,this.form,this.cache,$meta32495__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32495$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return $malli$core$_entry_ast$$(this,$malli$core$_entry_keyset$$(this.$entry_parser$))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){return $malli$impl$util$_some_pred$$($malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($c$jscomp$193_p__32502$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$193_p__32502$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$193_p__32502$$,1,null);$c$jscomp$193_p__32502$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$193_p__32502$$,2,null);
return $malli$core$_validator$$($c$jscomp$193_p__32502$$)},this.$malli$core$Schema$_children$arity$1$(null)))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$306$$,$transformer$jscomp$17$$,$method$jscomp$17$$,$options__$1$jscomp$8$$){return $malli$core$_or_transformer$$(this,$transformer$jscomp$17$$,$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__32482_SHARP_$$){return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__32482_SHARP_$$,2)},this.$malli$core$Schema$_children$arity$1$(null)),$method$jscomp$17$$,$options__$1$jscomp$8$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$307$$,$walker$jscomp$10$$,$path$jscomp$54$$,$options__$1$jscomp$9$$){return $malli$core$_walk_entries$$(this,$walker$jscomp$10$$,$path$jscomp$54$$,$options__$1$jscomp$9$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return $malli$core$_entry_children$$(this.$entry_parser$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$309$$,$path$jscomp$55$$){var $explainers$jscomp$2$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($c$jscomp$195_p__32527$$){var $k$jscomp$376$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$195_p__32527$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$195_p__32527$$,1,null);$c$jscomp$195_p__32527$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$195_p__32527$$,
2,null);return $malli$core$_explainer$$($c$jscomp$195_p__32527$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$55$$,$k$jscomp$376$$))},this.$malli$core$Schema$_children$arity$1$(null));return function($x$jscomp$742$$,$in$$jscomp$15$$,$acc$jscomp$30$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc_SINGLEQUOTE_$jscomp$2$$,$acc_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1_explainer$jscomp$6$$){$acc_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1_explainer$jscomp$6$$=
$acc_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1_explainer$jscomp$6$$.$cljs$core$IFn$_invoke$arity$3$?$acc_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1_explainer$jscomp$6$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$742$$,$in$$jscomp$15$$,$acc_SINGLEQUOTE_$jscomp$2$$):$acc_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1_explainer$jscomp$6$$($x$jscomp$742$$,$in$$jscomp$15$$,$acc_SINGLEQUOTE_$jscomp$2$$);return $acc_SINGLEQUOTE_$jscomp$2$$===$acc_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1_explainer$jscomp$6$$?$APP.$cljs$core$reduced$$($acc$jscomp$30$$):
$acc_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1_explainer$jscomp$6$$},$acc$jscomp$30$$,$explainers$jscomp$2$$)}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntrySchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntrySchema$_entries$arity$1$=function(){return $malli$core$_entry_entries$$(this.$entry_parser$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntrySchema$_entry_parser$arity$1$=function(){return this.$entry_parser$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($this$$jscomp$311$$,$key$jscomp$198$$,$default$$jscomp$15$$){return $malli$core$_get_entries$$(this,$key$jscomp$198$$,$default$$jscomp$15$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$312$$,$key$jscomp$199$$,$value$jscomp$243$$){return $malli$core$_set_entries$$(this,$key$jscomp$199$$,$value$jscomp$243$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$313$$,$writer$jscomp$93$$,$opts$jscomp$150$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$93$$,$opts$jscomp$150$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32486$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32488$$,$meta32487__$1$$){return new $malli$core$t_malli$0core32486$$($meta32487__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32487$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $cljs$cst$438$orn$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($parent$jscomp$37$$,$properties$jscomp$27$$,$children$jscomp$37$$,$options$jscomp$155$$){var $parent__$1$jscomp$5$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($cljs$cst$438$orn$$,$properties$jscomp$27$$,$children$jscomp$37$$,1,null);var $entry_parser$jscomp$5$$=$malli$core$_create_entry_parser$$($children$jscomp$37$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$371$naked_keys$$,
!0],null),$options$jscomp$155$$);return new $malli$core$t_malli$0core32494$$(this.$meta32487$,$parent__$1$jscomp$5$$,$properties$jscomp$27$$,$children$jscomp$37$$,$options$jscomp$155$$,$entry_parser$jscomp$5$$,new $APP.$cljs$core$Delay$$(function(){return $malli$core$_create_entry_form$$($parent__$1$jscomp$5$$,$properties$jscomp$27$$,$entry_parser$jscomp$5$$,$options$jscomp$155$$)}),$malli$core$_create_cache$$(),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],
null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$314$$,$writer$jscomp$94$$,$opts$jscomp$151$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$94$$,$opts$jscomp$151$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32608$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32610$$,$meta32609__$1$$){return new $malli$core$t_malli$0core32608$$(this.form,this.options,this.$properties$,this.$schema$,this.children,this.parent,this.cache,this.$meta32590$,this.$vec__32603$,$meta32609__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32609$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return $malli$core$_to_child_ast$$(this)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){return $APP.$cljs$core$complement$$($malli$core$_validator$$(this.$schema$))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$316$$,$transformer$jscomp$18$$,$method$jscomp$18$$,$options__$1$jscomp$10$$){return $malli$core$_parent_children_transformer$$(this,this.children,$transformer$jscomp$18$$,$method$jscomp$18$$,$options__$1$jscomp$10$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$317$$,$walker$jscomp$11$$,$path$jscomp$56$$,$options__$1$jscomp$11$$){return $malli$core$_walk_indexed$$(this,$walker$jscomp$11$$,$path$jscomp$56$$,$options__$1$jscomp$11$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$319$$,$path$jscomp$57$$){var $this$__$1$jscomp$61$$=this,$validator$jscomp$18$$=$this$__$1$jscomp$61$$.$malli$core$Schema$_validator$arity$1$(null);return function($x$jscomp$745$$,$in$$jscomp$16$$,$acc$jscomp$31$$){return $APP.$cljs$core$not$$($validator$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$?$validator$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$745$$):$validator$jscomp$18$$($x$jscomp$745$$))?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$31$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$57$$,0),$in$$jscomp$16$$,$this$__$1$jscomp$61$$,$x$jscomp$745$$)):$acc$jscomp$31$$}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$368$$,$key$jscomp$200$$,$default$$jscomp$16$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.children,$key$jscomp$200$$,$default$$jscomp$16$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$321$$,$key$jscomp$201$$,$value$jscomp$244$$){return $malli$core$_set_assoc_children$$(this,$key$jscomp$201$$,$value$jscomp$244$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$322$$,$writer$jscomp$95$$,$opts$jscomp$152$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$95$$,$opts$jscomp$152$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32589$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32591$$,$meta32590__$1$$){return new $malli$core$t_malli$0core32589$$($meta32590__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32590$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $cljs$cst$444$not$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($parent$jscomp$41_schema$jscomp$34$$,$properties$jscomp$30$$,$children$jscomp$40$$,$options$jscomp$159$$){var $parent__$1$jscomp$7$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($cljs$cst$444$not$$,$properties$jscomp$30$$,$children$jscomp$40$$,1,1);var $vec__32603$jscomp$2$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__32588_SHARP_$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($p1__32588_SHARP_$$,$options$jscomp$159$$):$APP.$malli$core$schema$$($p1__32588_SHARP_$$,$options$jscomp$159$$)},$children$jscomp$40$$);$parent$jscomp$41_schema$jscomp$34$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__32603$jscomp$2$$,0,null);return new $malli$core$t_malli$0core32608$$(new $APP.$cljs$core$Delay$$(function(){return $malli$core$_simple_form$$($parent__$1$jscomp$7$$,$properties$jscomp$30$$,$vec__32603$jscomp$2$$,
$malli$core$_form$$,$options$jscomp$159$$)}),$options$jscomp$159$$,$properties$jscomp$30$$,$parent$jscomp$41_schema$jscomp$34$$,$vec__32603$jscomp$2$$,$parent__$1$jscomp$7$$,$malli$core$_create_cache$$(),this.$meta32590$,$vec__32603$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$323$$,$writer$jscomp$96$$,$opts$jscomp$153$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$96$$,$opts$jscomp$153$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32664$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32666$$,$meta32665__$1$$){return new $malli$core$t_malli$0core32664$$(this.$meta32656$,this.parent,this.$properties$,this.children,this.options,this.form,this.$schema$,this.cache,$meta32665__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32665$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return $malli$core$_to_child_ast$$(this)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){return $malli$core$_validator$$(this.$schema$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return $malli$core$_options$$(this.$schema$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$325$$,$transformer$jscomp$19$$,$method$jscomp$19$$,$options__$1$jscomp$12$$){return $malli$core$_parent_children_transformer$$(this,new $APP.$cljs$core$List$$(null,this.$schema$,null,1,null),$transformer$jscomp$19$$,$method$jscomp$19$$,$options__$1$jscomp$12$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$326$$,$walker$jscomp$12$$,$path$jscomp$58$$,$options__$1$jscomp$13$$){return $APP.$cljs$core$truth_$$($cljs$cst$445$malli_DOT_core_SLASH_walk_entry_vals$$.$cljs$core$IFn$_invoke$arity$1$($options__$1$jscomp$13$$))?$APP.$cljs$core$truth_$$($malli$core$_accept$$($walker$jscomp$12$$,this,$path$jscomp$58$$,$options__$1$jscomp$13$$))?$malli$core$_outer$$($walker$jscomp$12$$,this,$path$jscomp$58$$,new $APP.$cljs$core$List$$(null,
$malli$core$_inner$$($walker$jscomp$12$$,this.$schema$,$path$jscomp$58$$,$options__$1$jscomp$13$$),null,1,null),$options__$1$jscomp$13$$):null:$malli$core$_walk$$(this.$schema$,$walker$jscomp$12$$,$path$jscomp$58$$,$options__$1$jscomp$13$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$schema$],null)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($_$jscomp$380$$,$path$jscomp$59$$){return $malli$core$_explainer$$(this.$schema$,$path$jscomp$59$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$385$$,$key$jscomp$202$$,$default$$jscomp$17$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$key$jscomp$202$$)?this.$schema$:$default$$jscomp$17$$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($_$jscomp$386$$,$key$jscomp$203$$,$value$jscomp$245$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$key$jscomp$203$$)?$malli$core$_val_schema$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$245$$,this.$properties$):null};$APP.$JSCompiler_prototypeAlias$$.$malli$core$RefSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$RefSchema$_ref$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RefSchema$_deref$arity$1$=function(){return this.$schema$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$327$$,$writer$jscomp$97$$,$opts$jscomp$154$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$97$$,$opts$jscomp$154$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32655$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32657$$,$meta32656__$1$$){return new $malli$core$t_malli$0core32655$$($meta32656__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32656$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $cljs$cst$449$malli_DOT_core_SLASH_val$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($form$jscomp$55_parent$jscomp$45$$,$properties$jscomp$33$$,$children$jscomp$43_schema$jscomp$37$$,$options$jscomp$163$$){var $parent__$1$jscomp$9$$=this,$children__$1$jscomp$3$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__32643_SHARP_$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($p1__32643_SHARP_$$,$options$jscomp$163$$):
$APP.$malli$core$schema$$($p1__32643_SHARP_$$,$options$jscomp$163$$)},$children$jscomp$43_schema$jscomp$37$$);$form$jscomp$55_parent$jscomp$45$$=new $APP.$cljs$core$Delay$$(function(){return $malli$core$_simple_form$$($parent__$1$jscomp$9$$,$properties$jscomp$33$$,$children__$1$jscomp$3$$,$malli$core$_form$$,$options$jscomp$163$$)});$children$jscomp$43_schema$jscomp$37$$=$APP.$cljs$core$first$$($children__$1$jscomp$3$$);return new $malli$core$t_malli$0core32664$$(this.$meta32656$,$parent__$1$jscomp$9$$,
$properties$jscomp$33$$,$children__$1$jscomp$3$$,$options$jscomp$163$$,$form$jscomp$55_parent$jscomp$45$$,$children$jscomp$43_schema$jscomp$37$$,$malli$core$_create_cache$$(),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$328$$,$writer$jscomp$98$$,$opts$jscomp$155$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$98$$,$opts$jscomp$155$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32820$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32822$$,$meta32821__$1$$){return new $malli$core$t_malli$0core32820$$(this.form,this.options,this.$map__32776$,this.$properties$,this.closed,this.children,this.$entry_parser$,this.parent,this.$explicit_children$,this.$default_schema$,this.$meta32751$,this.$pred_QMARK_$,this.$__GT_parser$,this.cache,this.$p__32775$,this.$opts$,$meta32821__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32821$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return $malli$core$_entry_ast$$(this,$malli$core$_entry_keyset$$(this.$entry_parser$))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){var $self__$jscomp$1504$$=this,$keyset$jscomp$8$$=$malli$core$_entry_keyset$$(this.$entry_parser$),$default_validator$$=function(){var $G__32829$$=$APP.$cljs$core$_deref$$($self__$jscomp$1504$$.$default_schema$);return $G__32829$$==null?null:$malli$core$_validator$$($G__32829$$)}(),$validators$jscomp$3$$=function(){var $G__32830_G__32830__$1$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__32832_value$jscomp$246$$){var $key$jscomp$204$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32832_value$jscomp$246$$,0,null),$map__32836_map__32836__$1_optional$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32832_value$jscomp$246$$,1,null);$map__32836_map__32836__$1_optional$$=$APP.$cljs$core$__destructure_map$$($map__32836_map__32836__$1_optional$$);$map__32836_map__32836__$1_optional$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32836_map__32836__$1_optional$$,$APP.$cljs$cst$450$optional$$);$p__32832_value$jscomp$246$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32832_value$jscomp$246$$,2,null);var $valid_QMARK_$jscomp$3$$=$malli$core$_validator$$($p__32832_value$jscomp$246$$),$default$$jscomp$18$$=$APP.$cljs$core$boolean$0$$($map__32836_map__32836__$1_optional$$);return function($G__32837_m$jscomp$132_temp__5823__auto__$jscomp$52$$){$G__32837_m$jscomp$132_temp__5823__auto__$jscomp$52$$=$cljs$core$find$$($G__32837_m$jscomp$132_temp__5823__auto__$jscomp$52$$,$key$jscomp$204$$);return $APP.$cljs$core$truth_$$($G__32837_m$jscomp$132_temp__5823__auto__$jscomp$52$$)?
($G__32837_m$jscomp$132_temp__5823__auto__$jscomp$52$$=$APP.$cljs$core$_val$$($G__32837_m$jscomp$132_temp__5823__auto__$jscomp$52$$),$valid_QMARK_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$valid_QMARK_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($G__32837_m$jscomp$132_temp__5823__auto__$jscomp$52$$):$valid_QMARK_$jscomp$3$$($G__32837_m$jscomp$132_temp__5823__auto__$jscomp$52$$)):$default$$jscomp$18$$}},$APP.$cljs$core$_deref$$($self__$jscomp$1504$$.$explicit_children$));$G__32830_G__32830__$1$$=
$APP.$cljs$core$truth_$$($default_validator$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__32830_G__32830__$1$$,function($G__32840_m$jscomp$133$$){$G__32840_m$jscomp$133$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$32$$,$k$jscomp$378$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$32$$,$k$jscomp$378$$)},$G__32840_m$jscomp$133$$,$APP.$cljs$core$keys$$($keyset$jscomp$8$$));return $default_validator$$.$cljs$core$IFn$_invoke$arity$1$?
$default_validator$$.$cljs$core$IFn$_invoke$arity$1$($G__32840_m$jscomp$133$$):$default_validator$$($G__32840_m$jscomp$133$$)}):$G__32830_G__32830__$1$$;return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$78$$=$self__$jscomp$1504$$.closed;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$78$$)?$APP.$cljs$core$not$$($default_validator$$):$and__5023__auto__$jscomp$78$$}())?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__32830_G__32830__$1$$,function($m$jscomp$134$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$33$$,
$k$jscomp$379$$){return $APP.$cljs$core$contains_QMARK_$$($keyset$jscomp$8$$,$k$jscomp$379$$)?$acc$jscomp$33$$:$APP.$cljs$core$reduced$$(!1)},!0,$APP.$cljs$core$keys$$($m$jscomp$134$$))}):$G__32830_G__32830__$1$$}(),$validate$jscomp$2$$=$malli$impl$util$_every_pred$$($validators$jscomp$3$$);return function($m$jscomp$135$$){var $and__5023__auto__$jscomp$79$$=$self__$jscomp$1504$$.$pred_QMARK_$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$1504$$.$pred_QMARK_$.$cljs$core$IFn$_invoke$arity$1$($m$jscomp$135$$):
$self__$jscomp$1504$$.$pred_QMARK_$($m$jscomp$135$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$79$$)?$validate$jscomp$2$$($m$jscomp$135$$):$and__5023__auto__$jscomp$79$$}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$331_this_transformer$jscomp$1$$,$transformer$jscomp$20$$,$method$jscomp$20$$,$options__$1$jscomp$14$$){var $self__$jscomp$1506$$=this,$this$__$1$jscomp$73$$=this,$keyset$jscomp$9$$=$malli$core$_entry_keyset$$($this$__$1$jscomp$73$$.$entry_parser$);$this$$jscomp$331_this_transformer$jscomp$1$$=$malli$core$_value_transformer$$($transformer$jscomp$20$$,$this$__$1$jscomp$73$$,$method$jscomp$20$$,$options__$1$jscomp$14$$);
var $__GT_children_apply__GT_children__$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$34$$,$p__32848_s$jscomp$314_t$jscomp$31$$){var $k$jscomp$380$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32848_s$jscomp$314_t$jscomp$31$$,0,null);$p__32848_s$jscomp$314_t$jscomp$31$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32848_s$jscomp$314_t$jscomp$31$$,1,null);$p__32848_s$jscomp$314_t$jscomp$31$$=$malli$core$_transformer$$($p__32848_s$jscomp$314_t$jscomp$31$$,
$transformer$jscomp$20$$,$method$jscomp$20$$,$options__$1$jscomp$14$$);return $APP.$cljs$core$truth_$$($p__32848_s$jscomp$314_t$jscomp$31$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$34$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$380$$,$p__32848_s$jscomp$314_t$jscomp$31$$],null)):$acc$jscomp$34$$},$APP.$cljs$core$PersistentVector$EMPTY$$,function(){var $G__32858$$=$this$__$1$jscomp$73$$.$malli$core$EntrySchema$_entries$arity$1$(null);
return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($self__$jscomp$1506$$.$default_schema$))?$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($malli$core$_default_entry$$,$G__32858$$):$G__32858$$}()),$apply__GT_children$$=$APP.$cljs$core$seq$$($__GT_children_apply__GT_children__$1$$)?$malli$core$_map_transformer$$($__GT_children_apply__GT_children__$1$$):null,$apply__GT_default$$=function(){var $temp__5825__auto__$jscomp$61$$=function(){var $G__32859$$=$APP.$cljs$core$_deref$$($self__$jscomp$1506$$.$default_schema$);
return $G__32859$$==null?null:$malli$core$_transformer$$($G__32859$$,$transformer$jscomp$20$$,$method$jscomp$20$$,$options__$1$jscomp$14$$)}();return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$61$$)?function($x$jscomp$746$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([function(){var $G__32861$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$35$$,$k$jscomp$381$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$35$$,
$k$jscomp$381$$)},$x$jscomp$746$$,$APP.$cljs$core$keys$$($keyset$jscomp$9$$));return $temp__5825__auto__$jscomp$61$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5825__auto__$jscomp$61$$.$cljs$core$IFn$_invoke$arity$1$($G__32861$$):$temp__5825__auto__$jscomp$61$$($G__32861$$)}(),$APP.$cljs$core$select_keys$$($x$jscomp$746$$,$APP.$cljs$core$keys$$($keyset$jscomp$9$$))]))}:null}();$__GT_children_apply__GT_children__$1$$=function(){var $G__32862_G__32862__$1_G__32862__$2$$=new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$apply__GT_default$$,$apply__GT_children$$],null);$G__32862_G__32862__$1_G__32862__$2$$=$G__32862_G__32862__$1_G__32862__$2$$==null?null:$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$identity$$,$G__32862_G__32862__$1_G__32862__$2$$);$G__32862_G__32862__$1_G__32862__$2$$=$G__32862_G__32862__$1_G__32862__$2$$==null?null:$APP.$cljs$core$seq$$($G__32862_G__32862__$1_G__32862__$2$$);return $G__32862_G__32862__$1_G__32862__$2$$==
null?null:$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$core$_comp$$,$G__32862_G__32862__$1_G__32862__$2$$)}();return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$02$$($this$$jscomp$331_this_transformer$jscomp$1$$,$malli$core$_guard$$($self__$jscomp$1506$$.$pred_QMARK_$,$__GT_children_apply__GT_children__$1$$))};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$332$$,$walker$jscomp$13$$,$path$jscomp$60$$,$options__$1$jscomp$15$$){return $malli$core$_walk_entries$$(this,$walker$jscomp$13$$,$path$jscomp$60$$,$options__$1$jscomp$15$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return $malli$core$_entry_children$$(this.$entry_parser$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$334$$,$path$jscomp$61$$){var $self__$jscomp$1512$$=this,$this$__$1$jscomp$76$$=this,$keyset$jscomp$10$$=$malli$core$_entry_keyset$$($this$__$1$jscomp$76$$.$entry_parser$),$default_explainer$$=function(){var $G__32874$$=$APP.$cljs$core$_deref$$($self__$jscomp$1512$$.$default_schema$);return $G__32874$$==null?null:$malli$core$_explainer$$($G__32874$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$61$$,
$cljs$cst$379$malli_DOT_core_SLASH_default$$))}(),$explainers$jscomp$3$$=function(){var $G__32876_G__32876__$1$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__32877_schema$jscomp$39$$){var $key$jscomp$205$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32877_schema$jscomp$39$$,0,null),$map__32881_map__32881__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32877_schema$jscomp$39$$,1,null);$map__32881_map__32881__$1$$=$APP.$cljs$core$__destructure_map$$($map__32881_map__32881__$1$$);
var $optional$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32881_map__32881__$1$$,$APP.$cljs$cst$450$optional$$);$p__32877_schema$jscomp$39$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32877_schema$jscomp$39$$,2,null);var $explainer$jscomp$7$$=$malli$core$_explainer$$($p__32877_schema$jscomp$39$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$61$$,$key$jscomp$205$$));return function($G__32885_temp__5823__auto__$jscomp$53_x$jscomp$747$$,
$G__32886_in$$jscomp$17$$,$acc$jscomp$36$$){$G__32885_temp__5823__auto__$jscomp$53_x$jscomp$747$$=$cljs$core$find$$($G__32885_temp__5823__auto__$jscomp$53_x$jscomp$747$$,$key$jscomp$205$$);return $APP.$cljs$core$truth_$$($G__32885_temp__5823__auto__$jscomp$53_x$jscomp$747$$)?($G__32885_temp__5823__auto__$jscomp$53_x$jscomp$747$$=$APP.$cljs$core$_val$$($G__32885_temp__5823__auto__$jscomp$53_x$jscomp$747$$),$G__32886_in$$jscomp$17$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__32886_in$$jscomp$17$$,
$key$jscomp$205$$),$explainer$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$?$explainer$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$($G__32885_temp__5823__auto__$jscomp$53_x$jscomp$747$$,$G__32886_in$$jscomp$17$$,$acc$jscomp$36$$):$explainer$jscomp$7$$($G__32885_temp__5823__auto__$jscomp$53_x$jscomp$747$$,$G__32886_in$$jscomp$17$$,$acc$jscomp$36$$)):$APP.$cljs$core$not$$($optional$jscomp$1$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$36$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$61$$,
$key$jscomp$205$$),$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__32886_in$$jscomp$17$$,$key$jscomp$205$$),$this$__$1$jscomp$76$$,null,$cljs$cst$451$malli_DOT_core_SLASH_missing_key$$)):$acc$jscomp$36$$}},$APP.$cljs$core$_deref$$($self__$jscomp$1512$$.$explicit_children$));$G__32876_G__32876__$1$$=$APP.$cljs$core$truth_$$($default_explainer$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__32876_G__32876__$1$$,function($G__32891_x$jscomp$748$$,$in$$jscomp$18$$,$acc$jscomp$37$$){$G__32891_x$jscomp$748$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc__$1$jscomp$1$$,$k$jscomp$382$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($acc__$1$jscomp$1$$,$k$jscomp$382$$)},$G__32891_x$jscomp$748$$,$APP.$cljs$core$keys$$($keyset$jscomp$10$$));return $default_explainer$$.$cljs$core$IFn$_invoke$arity$3$?$default_explainer$$.$cljs$core$IFn$_invoke$arity$3$($G__32891_x$jscomp$748$$,$in$$jscomp$18$$,$acc$jscomp$37$$):$default_explainer$$($G__32891_x$jscomp$748$$,$in$$jscomp$18$$,
$acc$jscomp$37$$)}):$G__32876_G__32876__$1$$;return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$80$$=$self__$jscomp$1512$$.closed;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$80$$)?$APP.$cljs$core$not$$($default_explainer$$):$and__5023__auto__$jscomp$80$$}())?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__32876_G__32876__$1$$,function($x$jscomp$749$$,$in$$jscomp$19$$,$acc$jscomp$38$$){return $APP.$cljs$core$reduce_kv$$(function($acc__$1$jscomp$2$$,$k$jscomp$383$$,
$v$jscomp$185$$){return $APP.$cljs$core$contains_QMARK_$$($keyset$jscomp$10$$,$k$jscomp$383$$)?$acc__$1$jscomp$2$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc__$1$jscomp$2$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$61$$,$k$jscomp$383$$),$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($in$$jscomp$19$$,$k$jscomp$383$$),$this$__$1$jscomp$76$$,$v$jscomp$185$$,$cljs$cst$452$malli_DOT_core_SLASH_extra_key$$))},
$acc$jscomp$38$$,$x$jscomp$749$$)}):$G__32876_G__32876__$1$$}();return function($x$jscomp$750$$,$in$$jscomp$20$$,$acc$jscomp$39$$){return $APP.$cljs$core$not$$($self__$jscomp$1512$$.$pred_QMARK_$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$1512$$.$pred_QMARK_$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$750$$):$self__$jscomp$1512$$.$pred_QMARK_$($x$jscomp$750$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$39$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($path$jscomp$61$$,
$in$$jscomp$20$$,$this$__$1$jscomp$76$$,$x$jscomp$750$$,$cljs$cst$315$malli_DOT_core_SLASH_invalid_type$$)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc__$1$jscomp$3$$,$explainer$jscomp$8$$){return $explainer$jscomp$8$$.$cljs$core$IFn$_invoke$arity$3$?$explainer$jscomp$8$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$750$$,$in$$jscomp$20$$,$acc__$1$jscomp$3$$):$explainer$jscomp$8$$($x$jscomp$750$$,$in$$jscomp$20$$,$acc__$1$jscomp$3$$)},$acc$jscomp$39$$,$explainers$jscomp$3$$)}};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntrySchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntrySchema$_entries$arity$1$=function(){return $malli$core$_entry_entries$$(this.$entry_parser$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntrySchema$_entry_parser$arity$1$=function(){return this.$entry_parser$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($this$$jscomp$336$$,$key$jscomp$206$$,$default$$jscomp$19$$){return $malli$core$_get_entries$$(this,$key$jscomp$206$$,$default$$jscomp$19$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$337$$,$key$jscomp$207$$,$value$jscomp$247$$){return $malli$core$_set_entries$$(this,$key$jscomp$207$$,$value$jscomp$247$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$338$$,$writer$jscomp$99$$,$opts__$1$jscomp$5$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$99$$,$opts__$1$jscomp$5$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32750$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32752$$,$meta32751__$1$$){return new $malli$core$t_malli$0core32750$$(this.$opts$,$meta32751__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32751$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$2$(this.$opts$,$APP.$cljs$cst$202$map$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return $cljs$cst$415$type_properties$$.$cljs$core$IFn$_invoke$arity$1$(this.$opts$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($parent$jscomp$49$$,$p__32775$jscomp$2$$,$children$jscomp$46$$,$options$jscomp$167$$){var $map__32776__$1$$=$APP.$cljs$core$__destructure_map$$($p__32775$jscomp$2$$),$closed$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32776__$1$$,$cljs$cst$462$closed$$),$parent__$1$jscomp$11$$=this,$pred_QMARK_$jscomp$4$$=$APP.$cljs$cst$351$pred$$.$cljs$core$IFn$_invoke$arity$2$(this.$opts$,$APP.$cljs$core$map_QMARK_$$),
$entry_parser$jscomp$8$$=$malli$core$_create_entry_parser$$($children$jscomp$46$$,this.$opts$,$options$jscomp$167$$),$default_schema$jscomp$2$$=new $APP.$cljs$core$Delay$$(function(){var $G__32781__$1_G__32781__$2$$=$entry_parser$jscomp$8$$==null?null:$malli$core$_entry_children$$($entry_parser$jscomp$8$$);$G__32781__$1_G__32781__$2$$=$G__32781__$1_G__32781__$2$$==null?null:$malli$core$_default_entry_schema$$($G__32781__$1_G__32781__$2$$);return $G__32781__$1_G__32781__$2$$==null?null:$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($G__32781__$1_G__32781__$2$$,$options$jscomp$167$$):$APP.$malli$core$schema$$($G__32781__$1_G__32781__$2$$,$options$jscomp$167$$)}),$explicit_children$jscomp$2$$=new $APP.$cljs$core$Delay$$(function(){var $G__32787$$=$malli$core$_entry_children$$($entry_parser$jscomp$8$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($default_schema$jscomp$2$$))?$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($malli$core$_default_entry$$,
$G__32787$$):$G__32787$$});return new $malli$core$t_malli$0core32820$$(new $APP.$cljs$core$Delay$$(function(){return $malli$core$_create_entry_form$$($parent__$1$jscomp$11$$,$map__32776__$1$$,$entry_parser$jscomp$8$$,$options$jscomp$167$$)}),$options$jscomp$167$$,$map__32776__$1$$,$map__32776__$1$$,$closed$jscomp$2$$,$children$jscomp$46$$,$entry_parser$jscomp$8$$,$parent__$1$jscomp$11$$,$explicit_children$jscomp$2$$,$default_schema$jscomp$2$$,this.$meta32751$,$pred_QMARK_$jscomp$4$$,function($this$$jscomp$339$$,
$f$jscomp$415$$){function $ok_QMARK_$$($p1__32712_SHARP_$$){var $and__5023__auto__$jscomp$81$$=$pred_QMARK_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$pred_QMARK_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($p1__32712_SHARP_$$):$pred_QMARK_$jscomp$4$$($p1__32712_SHARP_$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$81$$)?!$malli$core$tag_QMARK_$$($p1__32712_SHARP_$$)&&!$malli$core$tags_QMARK_$$($p1__32712_SHARP_$$):$and__5023__auto__$jscomp$81$$}var $keyset$jscomp$11$$=$malli$core$_entry_keyset$$($malli$core$_entry_parser$$($this$$jscomp$339$$)),
$default_parser$$=function(){var $G__32791$$=$APP.$cljs$core$_deref$$($default_schema$jscomp$2$$);return $G__32791$$==null?null:$f$jscomp$415$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$415$$.$cljs$core$IFn$_invoke$arity$1$($G__32791$$):$f$jscomp$415$$($G__32791$$)}(),$parsers$jscomp$3$$=function(){var $G__32795_G__32795__$1$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__32801_schema$jscomp$40$$){var $key$jscomp$208$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32801_schema$jscomp$40$$,
0,null),$map__32805_map__32805__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32801_schema$jscomp$40$$,1,null);$map__32805_map__32805__$1$$=$APP.$cljs$core$__destructure_map$$($map__32805_map__32805__$1$$);var $optional$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32805_map__32805__$1$$,$APP.$cljs$cst$450$optional$$);$p__32801_schema$jscomp$40$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32801_schema$jscomp$40$$,2,null);var $parser$jscomp$8$$=
$f$jscomp$415$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$415$$.$cljs$core$IFn$_invoke$arity$1$($p__32801_schema$jscomp$40$$):$f$jscomp$415$$($p__32801_schema$jscomp$40$$);return function($m$jscomp$136$$){var $temp__5823__auto__$jscomp$54_v$jscomp$186$$=$cljs$core$find$$($m$jscomp$136$$,$key$jscomp$208$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$54_v$jscomp$186$$)){$temp__5823__auto__$jscomp$54_v$jscomp$186$$=$APP.$cljs$core$_val$$($temp__5823__auto__$jscomp$54_v$jscomp$186$$);var $v_STAR_$$=
$parser$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$?$parser$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$($temp__5823__auto__$jscomp$54_v$jscomp$186$$):$parser$jscomp$8$$($temp__5823__auto__$jscomp$54_v$jscomp$186$$);return $APP.$cljs$core$keyword_identical_QMARK_$$($v_STAR_$$,$cljs$cst$295$malli_DOT_core_SLASH_invalid$$)?$APP.$cljs$core$reduced$$($v_STAR_$$):$v_STAR_$$===$temp__5823__auto__$jscomp$54_v$jscomp$186$$?$m$jscomp$136$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$136$$,
$key$jscomp$208$$,$v_STAR_$$)}return $APP.$cljs$core$truth_$$($optional$jscomp$2$$)?$m$jscomp$136$$:$APP.$cljs$core$reduced$$($cljs$cst$295$malli_DOT_core_SLASH_invalid$$)}},$APP.$cljs$core$_deref$$($explicit_children$jscomp$2$$));$G__32795_G__32795__$1$$=$APP.$cljs$core$truth_$$($default_parser$$)?$APP.$cljs$core$cons$$(function($m$jscomp$137$$){var $m_SINGLEQUOTE_$$=function(){var $G__32813$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$40$$,$k$jscomp$384$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$40$$,
$k$jscomp$384$$)},$m$jscomp$137$$,$APP.$cljs$core$keys$$($keyset$jscomp$11$$));return $default_parser$$.$cljs$core$IFn$_invoke$arity$1$?$default_parser$$.$cljs$core$IFn$_invoke$arity$1$($G__32813$$):$default_parser$$($G__32813$$)}();return $APP.$cljs$core$keyword_identical_QMARK_$$($m_SINGLEQUOTE_$$,$cljs$cst$295$malli_DOT_core_SLASH_invalid$$)?$APP.$cljs$core$reduced$$($m_SINGLEQUOTE_$$):$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$select_keys$$($m$jscomp$137$$,
$APP.$cljs$core$keys$$($keyset$jscomp$11$$)),$m_SINGLEQUOTE_$$]))},$G__32795_G__32795__$1$$):$G__32795_G__32795__$1$$;return $APP.$cljs$core$truth_$$($closed$jscomp$2$$)?$APP.$cljs$core$cons$$(function($m$jscomp$138$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($m__$1$jscomp$7$$,$k$jscomp$385$$){return $APP.$cljs$core$contains_QMARK_$$($keyset$jscomp$11$$,$k$jscomp$385$$)?$m__$1$jscomp$7$$:$APP.$cljs$core$reduced$$($APP.$cljs$core$reduced$$($cljs$cst$295$malli_DOT_core_SLASH_invalid$$))},
$m$jscomp$138$$,$APP.$cljs$core$keys$$($m$jscomp$138$$))},$G__32795_G__32795__$1$$):$G__32795_G__32795__$1$$}();return function($x$jscomp$751$$){return $APP.$cljs$core$truth_$$($ok_QMARK_$$($x$jscomp$751$$))?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($m$jscomp$139$$,$parser$jscomp$9$$){return $parser$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$?$parser$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$($m$jscomp$139$$):$parser$jscomp$9$$($m$jscomp$139$$)},$x$jscomp$751$$,$parsers$jscomp$3$$):
$cljs$cst$295$malli_DOT_core_SLASH_invalid$$}},$malli$core$_create_cache$$(),$p__32775$jscomp$2$$,this.$opts$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$340$$,$writer$jscomp$100$$,$opts__$1$jscomp$6$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$100$$,$opts__$1$jscomp$6$$)};
$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32964$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32966$$,$meta32965__$1$$){return new $malli$core$t_malli$0core32964$$(this.form,this.options,this.$p__32957$,this.$properties$,this.children,this.min,this.$map__32958$,this.$value_schema$,this.parent,this.$meta32940$,this.$key_schema$,this.$__GT_parser$,this.cache,this.$validate_limits$,this.max,this.$opts$,this.$vec__32959$,$meta32965__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32965$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return $malli$core$_ast$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$463$map_of$$,$APP.$cljs$cst$302$key$$,$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$?$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$(this.$key_schema$):$malli$core$ast$$(this.$key_schema$),$APP.$cljs$cst$260$value$$,$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$?$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$(this.$value_schema$):
$malli$core$ast$$(this.$value_schema$)],null),this.$properties$,this.options)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){var $self__$jscomp$1534$$=this,$key_valid_QMARK_$$=$malli$core$_validator$$($self__$jscomp$1534$$.$key_schema$),$value_valid_QMARK_$$=$malli$core$_validator$$($self__$jscomp$1534$$.$value_schema$);return function($m$jscomp$140$$){var $and__5023__auto__$jscomp$82_and__5023__auto____$1$jscomp$20$$=$APP.$cljs$core$map_QMARK_$$($m$jscomp$140$$);return $and__5023__auto__$jscomp$82_and__5023__auto____$1$jscomp$20$$?($and__5023__auto__$jscomp$82_and__5023__auto____$1$jscomp$20$$=
$self__$jscomp$1534$$.$validate_limits$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$1534$$.$validate_limits$.$cljs$core$IFn$_invoke$arity$1$($m$jscomp$140$$):$self__$jscomp$1534$$.$validate_limits$($m$jscomp$140$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$82_and__5023__auto____$1$jscomp$20$$)?$APP.$cljs$core$reduce_kv$$(function($___$2$jscomp$20_and__5023__auto____$2$jscomp$inline_3540$$,$key$jscomp$209$$,$or__5025__auto__$jscomp$108_value$jscomp$248$$){$___$2$jscomp$20_and__5023__auto____$2$jscomp$inline_3540$$=
$key_valid_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$key_valid_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$209$$):$key_valid_QMARK_$$($key$jscomp$209$$);$or__5025__auto__$jscomp$108_value$jscomp$248$$=$APP.$cljs$core$truth_$$($___$2$jscomp$20_and__5023__auto____$2$jscomp$inline_3540$$)?$value_valid_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$value_valid_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$108_value$jscomp$248$$):$value_valid_QMARK_$$($or__5025__auto__$jscomp$108_value$jscomp$248$$):
$___$2$jscomp$20_and__5023__auto____$2$jscomp$inline_3540$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$108_value$jscomp$248$$)?$or__5025__auto__$jscomp$108_value$jscomp$248$$:$APP.$cljs$core$reduced$$(!1)},!0,$m$jscomp$140$$):$and__5023__auto__$jscomp$82_and__5023__auto____$1$jscomp$20$$):$and__5023__auto__$jscomp$82_and__5023__auto____$1$jscomp$20$$}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$341_this_transformer$jscomp$2$$,$transformer$jscomp$21$$,$method$jscomp$21$$,$options__$1$jscomp$16$$){$this$$jscomp$341_this_transformer$jscomp$2$$=$malli$core$_value_transformer$$($transformer$jscomp$21$$,this,$method$jscomp$21$$,$options__$1$jscomp$16$$);var $__GT_key$jscomp$2$$=$malli$core$_transformer$$(this.$key_schema$,$transformer$jscomp$21$$,$method$jscomp$21$$,$options__$1$jscomp$16$$),$__GT_child$jscomp$3$$=
$malli$core$_transformer$$(this.$value_schema$,$transformer$jscomp$21$$,$method$jscomp$21$$,$options__$1$jscomp$16$$),$__GT_key_child$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($__GT_key$jscomp$2$$)?$__GT_child$jscomp$3$$:$__GT_key$jscomp$2$$)?function($p1__32918_SHARP_$$,$p2__32920_SHARP_$$,$p3__32921_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__32918_SHARP_$$,$__GT_key$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$__GT_key$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($p2__32920_SHARP_$$):
$__GT_key$jscomp$2$$($p2__32920_SHARP_$$),$__GT_child$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$__GT_child$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($p3__32921_SHARP_$$):$__GT_child$jscomp$3$$($p3__32921_SHARP_$$))}:$APP.$cljs$core$truth_$$($__GT_key$jscomp$2$$)?function($p1__32922_SHARP_$$,$p2__32923_SHARP_$$,$p3__32924_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__32922_SHARP_$$,$__GT_key$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$__GT_key$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($p2__32923_SHARP_$$):
$__GT_key$jscomp$2$$($p2__32923_SHARP_$$),$p3__32924_SHARP_$$)}:$APP.$cljs$core$truth_$$($__GT_child$jscomp$3$$)?function($p1__32925_SHARP_$$,$p2__32926_SHARP_$$,$p3__32927_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__32925_SHARP_$$,$p2__32926_SHARP_$$,$__GT_child$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$__GT_child$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($p3__32927_SHARP_$$):$__GT_child$jscomp$3$$($p3__32927_SHARP_$$))}:null;return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$02$$($this$$jscomp$341_this_transformer$jscomp$2$$,
$malli$core$_guard$$($APP.$cljs$core$map_QMARK_$$,$APP.$cljs$core$truth_$$($__GT_key_child$$)?function($p1__32928_SHARP_$$){return $APP.$cljs$core$reduce_kv$$($__GT_key_child$$,$APP.$cljs$core$empty$$($p1__32928_SHARP_$$),$p1__32928_SHARP_$$)}:null))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$342$$,$walker$jscomp$14$$,$path$jscomp$62$$,$options__$1$jscomp$17$$){return $malli$core$_walk_indexed$$(this,$walker$jscomp$14$$,$path$jscomp$62$$,$options__$1$jscomp$17$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$343$$,$path$jscomp$63$$){var $self__$jscomp$1542$$=this,$this$__$1$jscomp$84$$=this,$key_explainer$$=$malli$core$_explainer$$($self__$jscomp$1542$$.$key_schema$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$63$$,0)),$value_explainer$$=$malli$core$_explainer$$($self__$jscomp$1542$$.$value_schema$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$63$$,1));return function($m$jscomp$141$$,
$in$$jscomp$21$$,$acc$jscomp$41$$){return $APP.$cljs$core$map_QMARK_$$($m$jscomp$141$$)?$APP.$cljs$core$not$$($self__$jscomp$1542$$.$validate_limits$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$1542$$.$validate_limits$.$cljs$core$IFn$_invoke$arity$1$($m$jscomp$141$$):$self__$jscomp$1542$$.$validate_limits$($m$jscomp$141$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$41$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($path$jscomp$63$$,$in$$jscomp$21$$,$this$__$1$jscomp$84$$,
$m$jscomp$141$$,$cljs$cst$464$malli_DOT_core_SLASH_limits$$)):$APP.$cljs$core$reduce_kv$$(function($G__33001_acc__$1$jscomp$4$$,$key$jscomp$210$$,$value$jscomp$249$$){var $in$__$1$jscomp$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($in$$jscomp$21$$,$key$jscomp$210$$);$G__33001_acc__$1$jscomp$4$$=$key_explainer$$.$cljs$core$IFn$_invoke$arity$3$?$key_explainer$$.$cljs$core$IFn$_invoke$arity$3$($key$jscomp$210$$,$in$__$1$jscomp$1$$,$G__33001_acc__$1$jscomp$4$$):$key_explainer$$($key$jscomp$210$$,
$in$__$1$jscomp$1$$,$G__33001_acc__$1$jscomp$4$$);return $value_explainer$$.$cljs$core$IFn$_invoke$arity$3$?$value_explainer$$.$cljs$core$IFn$_invoke$arity$3$($value$jscomp$249$$,$in$__$1$jscomp$1$$,$G__33001_acc__$1$jscomp$4$$):$value_explainer$$($value$jscomp$249$$,$in$__$1$jscomp$1$$,$G__33001_acc__$1$jscomp$4$$)},$acc$jscomp$41$$,$m$jscomp$141$$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$41$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($path$jscomp$63$$,
$in$$jscomp$21$$,$this$__$1$jscomp$84$$,$m$jscomp$141$$,$cljs$cst$315$malli_DOT_core_SLASH_invalid_type$$))}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$418$$,$key$jscomp$211$$,$default$$jscomp$20$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.children,$key$jscomp$211$$,$default$$jscomp$20$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$344$$,$key$jscomp$212$$,$value$jscomp$250$$){return $malli$core$_set_assoc_children$$(this,$key$jscomp$212$$,$value$jscomp$250$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$345$$,$writer$jscomp$101$$,$opts__$1$jscomp$7$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$101$$,$opts__$1$jscomp$7$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core32939$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_32941$$,$meta32940__$1$$){return new $malli$core$t_malli$0core32939$$(this.$opts$,$meta32940__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta32940$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$2$(this.$opts$,$cljs$cst$463$map_of$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return $cljs$cst$415$type_properties$$.$cljs$core$IFn$_invoke$arity$1$(this.$opts$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($min$jscomp$19_parent$jscomp$53$$,$p__32957$jscomp$2$$,$children$jscomp$49_form$jscomp$61$$,$options$jscomp$171$$){var $map__32958__$1$$=$APP.$cljs$core$__destructure_map$$($p__32957$jscomp$2$$);$min$jscomp$19_parent$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32958__$1$$,$APP.$cljs$cst$338$min$$);var $max$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32958__$1$$,
$APP.$cljs$cst$339$max$$),$parent__$1$jscomp$13$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($cljs$cst$463$map_of$$,$map__32958__$1$$,$children$jscomp$49_form$jscomp$61$$,2,2);var $vec__32959$jscomp$2$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__32914_SHARP_$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($p1__32914_SHARP_$$,$options$jscomp$171$$):$APP.$malli$core$schema$$($p1__32914_SHARP_$$,
$options$jscomp$171$$)},$children$jscomp$49_form$jscomp$61$$),$key_schema$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__32959$jscomp$2$$,0,null),$value_schema$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__32959$jscomp$2$$,1,null);$children$jscomp$49_form$jscomp$61$$=new $APP.$cljs$core$Delay$$(function(){return $malli$core$_simple_form$$($parent__$1$jscomp$13$$,$map__32958__$1$$,$vec__32959$jscomp$2$$,$malli$core$_form$$,$options$jscomp$171$$)});
var $cache$jscomp$31$$=$malli$core$_create_cache$$(),$validate_limits$jscomp$2$$=$malli$core$_validate_limits$$($min$jscomp$19_parent$jscomp$53$$,$max$jscomp$19$$);return new $malli$core$t_malli$0core32964$$($children$jscomp$49_form$jscomp$61$$,$options$jscomp$171$$,$p__32957$jscomp$2$$,$map__32958__$1$$,$vec__32959$jscomp$2$$,$min$jscomp$19_parent$jscomp$53$$,$map__32958__$1$$,$value_schema$jscomp$2$$,$parent__$1$jscomp$13$$,this.$meta32940$,$key_schema$jscomp$2$$,function($f$jscomp$416$$){var $key_parser$$=
$f$jscomp$416$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$416$$.$cljs$core$IFn$_invoke$arity$1$($key_schema$jscomp$2$$):$f$jscomp$416$$($key_schema$jscomp$2$$),$value_parser$$=$f$jscomp$416$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$416$$.$cljs$core$IFn$_invoke$arity$1$($value_schema$jscomp$2$$):$f$jscomp$416$$($value_schema$jscomp$2$$);return function($x$jscomp$752$$){return $APP.$cljs$core$map_QMARK_$$($x$jscomp$752$$)?$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$42$$,$k$jscomp$386_k_STAR_$$,
$v$jscomp$187_v_STAR_$jscomp$1$$){$k$jscomp$386_k_STAR_$$=$key_parser$$.$cljs$core$IFn$_invoke$arity$1$?$key_parser$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$386_k_STAR_$$):$key_parser$$($k$jscomp$386_k_STAR_$$);$v$jscomp$187_v_STAR_$jscomp$1$$=$value_parser$$.$cljs$core$IFn$_invoke$arity$1$?$value_parser$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$187_v_STAR_$jscomp$1$$):$value_parser$$($v$jscomp$187_v_STAR_$jscomp$1$$);return $APP.$cljs$core$keyword_identical_QMARK_$$($k$jscomp$386_k_STAR_$$,
$cljs$cst$295$malli_DOT_core_SLASH_invalid$$)||$APP.$cljs$core$keyword_identical_QMARK_$$($v$jscomp$187_v_STAR_$jscomp$1$$,$cljs$cst$295$malli_DOT_core_SLASH_invalid$$)?$APP.$cljs$core$reduced$$($cljs$cst$295$malli_DOT_core_SLASH_invalid$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$42$$,$k$jscomp$386_k_STAR_$$,$v$jscomp$187_v_STAR_$jscomp$1$$)},$APP.$cljs$core$empty$$($x$jscomp$752$$),$x$jscomp$752$$):$cljs$cst$295$malli_DOT_core_SLASH_invalid$$}},$cache$jscomp$31$$,$validate_limits$jscomp$2$$,
$max$jscomp$19$$,this.$opts$,$vec__32959$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$346$$,$writer$jscomp$102$$,$opts__$1$jscomp$8$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$102$$,$opts__$1$jscomp$8$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33039$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33041$$,$meta33040__$1$$){return new $malli$core$t_malli$0core33039$$(this.form,this.$vec__33032$,this.options,this.$map__33026$,this.$temp__5823__auto__$,this.$fpred$,this.$fin$,this.props,this.$properties$,this.$unparse$,this.$schema$,this.children,this.min,this.$p__33025$,this.$bounded$,this.parent,this.$map__33029$,this.type,this.$meta33018$,this.$__GT_parser$,this.$fempty$,this.cache,this.$validate_limits$,
this.max,this.parse,$meta33040__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33040$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return $malli$core$_to_child_ast$$(this)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){var $self__$jscomp$1562$$=this,$validator$jscomp$19$$=$malli$core$_validator$$($self__$jscomp$1562$$.$schema$);return function($x$jscomp$754$$){var $and__5023__auto__$jscomp$84_and__5023__auto____$1$jscomp$21$$=$self__$jscomp$1562$$.$fpred$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$1562$$.$fpred$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$754$$):$self__$jscomp$1562$$.$fpred$($x$jscomp$754$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$84_and__5023__auto____$1$jscomp$21$$)?
($and__5023__auto__$jscomp$84_and__5023__auto____$1$jscomp$21$$=$self__$jscomp$1562$$.$validate_limits$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$1562$$.$validate_limits$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$754$$):$self__$jscomp$1562$$.$validate_limits$($x$jscomp$754$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$84_and__5023__auto____$1$jscomp$21$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$43$$,$v$jscomp$188$$){return $APP.$cljs$core$truth_$$($validator$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$?
$validator$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$188$$):$validator$jscomp$19$$($v$jscomp$188$$))?$acc$jscomp$43$$:$APP.$cljs$core$reduced$$(!1)},!0,function(){var $JSCompiler_inline_result$jscomp$414_and__5023__auto____$2$jscomp$inline_3542$$=$self__$jscomp$1562$$.$bounded$;$JSCompiler_inline_result$jscomp$414_and__5023__auto____$2$jscomp$inline_3542$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$414_and__5023__auto____$2$jscomp$inline_3542$$)?!$malli$core$_safely_countable_QMARK_$$($x$jscomp$754$$):
$JSCompiler_inline_result$jscomp$414_and__5023__auto____$2$jscomp$inline_3542$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$414_and__5023__auto____$2$jscomp$inline_3542$$)?$cljs$core$eduction$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$1562$$.$bounded$),$x$jscomp$754$$])):$x$jscomp$754$$}()):$and__5023__auto__$jscomp$84_and__5023__auto____$1$jscomp$21$$):
$and__5023__auto__$jscomp$84_and__5023__auto____$1$jscomp$21$$}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$348_this_transformer$jscomp$3$$,$transformer$jscomp$22$$,$method$jscomp$22$$,$options__$1$jscomp$18$$){$this$$jscomp$348_this_transformer$jscomp$3$$=$malli$core$_value_transformer$$($transformer$jscomp$22$$,this,$method$jscomp$22$$,$options__$1$jscomp$18$$);var $child_transformer$jscomp$1$$=$malli$core$_transformer$$(this.$schema$,$transformer$jscomp$22$$,$method$jscomp$22$$,$options__$1$jscomp$18$$);
return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$02$$($this$$jscomp$348_this_transformer$jscomp$3$$,$malli$core$_guard$$(function($p1__33011_SHARP_$$){return $APP.$cljs$core$sequential_QMARK_$$($p1__33011_SHARP_$$)||$APP.$cljs$core$set_QMARK_$$($p1__33011_SHARP_$$)},$APP.$cljs$core$truth_$$($child_transformer$jscomp$1$$)?$APP.$cljs$core$truth_$$(this.$fempty$)?$malli$core$_collection_transformer$$($child_transformer$jscomp$1$$,this.$fempty$):function($p1__33012_SHARP_$$){return $malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$($child_transformer$jscomp$1$$,
$p1__33012_SHARP_$$)}:null))};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$349$$,$walker$jscomp$15$$,$path$jscomp$64$$,$options__$1$jscomp$19$$){return $APP.$cljs$core$truth_$$($malli$core$_accept$$($walker$jscomp$15$$,this,$path$jscomp$64$$,$options__$1$jscomp$19$$))?$malli$core$_outer$$($walker$jscomp$15$$,this,$path$jscomp$64$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$malli$core$_inner$$($walker$jscomp$15$$,this.$schema$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$64$$,
$cljs$cst$474$malli_DOT_core_SLASH_in$$),$options__$1$jscomp$19$$)],null),$options__$1$jscomp$19$$):null};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$350$$,$path$jscomp$65$$){var $self__$jscomp$1570$$=this,$this$__$1$jscomp$91$$=this,$explainer$jscomp$9$$=$malli$core$_explainer$$($self__$jscomp$1570$$.$schema$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$65$$,0));return function($x$jscomp$755$$,$in$$jscomp$22$$,$G__33074_acc$jscomp$44_acc__$2_vec__33071$$){if($APP.$cljs$core$not$$($self__$jscomp$1570$$.$fpred$.$cljs$core$IFn$_invoke$arity$1$?
$self__$jscomp$1570$$.$fpred$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$755$$):$self__$jscomp$1570$$.$fpred$($x$jscomp$755$$)))return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__33074_acc$jscomp$44_acc__$2_vec__33071$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($path$jscomp$65$$,$in$$jscomp$22$$,$this$__$1$jscomp$91$$,$x$jscomp$755$$,$cljs$cst$315$malli_DOT_core_SLASH_invalid_type$$));if($APP.$cljs$core$not$$($self__$jscomp$1570$$.$validate_limits$.$cljs$core$IFn$_invoke$arity$1$?
$self__$jscomp$1570$$.$validate_limits$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$755$$):$self__$jscomp$1570$$.$validate_limits$($x$jscomp$755$$)))return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__33074_acc$jscomp$44_acc__$2_vec__33071$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($path$jscomp$65$$,$in$$jscomp$22$$,$this$__$1$jscomp$91$$,$x$jscomp$755$$,$cljs$cst$464$malli_DOT_core_SLASH_limits$$));var $size$jscomp$41$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$85$$=
$self__$jscomp$1570$$.$bounded$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$85$$)?!$malli$core$_safely_countable_QMARK_$$($x$jscomp$755$$):$and__5023__auto__$jscomp$85$$}())?$self__$jscomp$1570$$.$bounded$:null,$G__33067_G__33067__$1_G__35209_first__33073$$=$APP.$cljs$core$seq$$($x$jscomp$755$$),$i__$1$jscomp$6_seq__33069_seq__33072_seq__33072__$1_xs__$1$jscomp$4$$=$APP.$cljs$core$seq$$($G__33067_G__33067__$1_G__35209_first__33073$$);$APP.$cljs$core$first$$($i__$1$jscomp$6_seq__33069_seq__33072_seq__33072__$1_xs__$1$jscomp$4$$);
$APP.$cljs$core$next$$($i__$1$jscomp$6_seq__33069_seq__33072_seq__33072__$1_xs__$1$jscomp$4$$);for($i__$1$jscomp$6_seq__33069_seq__33072_seq__33072__$1_xs__$1$jscomp$4$$=0;;){var $acc__$3$$=$G__33074_acc$jscomp$44_acc__$2_vec__33071$$,$i__$2$jscomp$1$$=$i__$1$jscomp$6_seq__33069_seq__33072_seq__33072__$1_xs__$1$jscomp$4$$;$G__33074_acc$jscomp$44_acc__$2_vec__33071$$=$G__33067_G__33067__$1_G__35209_first__33073$$;$i__$1$jscomp$6_seq__33069_seq__33072_seq__33072__$1_xs__$1$jscomp$4$$=$APP.$cljs$core$seq$$($G__33074_acc$jscomp$44_acc__$2_vec__33071$$);
$G__33067_G__33067__$1_G__35209_first__33073$$=$APP.$cljs$core$first$$($i__$1$jscomp$6_seq__33069_seq__33072_seq__33072__$1_xs__$1$jscomp$4$$);$i__$1$jscomp$6_seq__33069_seq__33072_seq__33072__$1_xs__$1$jscomp$4$$=$APP.$cljs$core$next$$($i__$1$jscomp$6_seq__33069_seq__33072_seq__33072__$1_xs__$1$jscomp$4$$);var $x__$2$$=$G__33067_G__33067__$1_G__35209_first__33073$$;if($G__33074_acc$jscomp$44_acc__$2_vec__33071$$&&($APP.$cljs$core$not$$($size$jscomp$41$$)||$i__$2$jscomp$1$$<$size$jscomp$41$$))if($G__33074_acc$jscomp$44_acc__$2_vec__33071$$=
function(){var $G__33075$jscomp$inline_3544_or__5025__auto__$jscomp$109$$=$x__$2$$;var $G__33076$jscomp$inline_3545$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($in$$jscomp$22$$,$self__$jscomp$1570$$.$fin$.$cljs$core$IFn$_invoke$arity$2$?$self__$jscomp$1570$$.$fin$.$cljs$core$IFn$_invoke$arity$2$($i__$2$jscomp$1$$,$x__$2$$):$self__$jscomp$1570$$.$fin$($i__$2$jscomp$1$$,$x__$2$$)),$G__33077$jscomp$inline_3546$$=$acc__$3$$;$G__33075$jscomp$inline_3544_or__5025__auto__$jscomp$109$$=$explainer$jscomp$9$$.$cljs$core$IFn$_invoke$arity$3$?
$explainer$jscomp$9$$.$cljs$core$IFn$_invoke$arity$3$($G__33075$jscomp$inline_3544_or__5025__auto__$jscomp$109$$,$G__33076$jscomp$inline_3545$$,$G__33077$jscomp$inline_3546$$):$explainer$jscomp$9$$($G__33075$jscomp$inline_3544_or__5025__auto__$jscomp$109$$,$G__33076$jscomp$inline_3545$$,$G__33077$jscomp$inline_3546$$);return $APP.$cljs$core$truth_$$($G__33075$jscomp$inline_3544_or__5025__auto__$jscomp$109$$)?$G__33075$jscomp$inline_3544_or__5025__auto__$jscomp$109$$:$acc__$3$$}(),$i__$1$jscomp$6_seq__33069_seq__33072_seq__33072__$1_xs__$1$jscomp$4$$){$G__33067_G__33067__$1_G__35209_first__33073$$=
$i__$2$jscomp$1$$+1;var $G__35210$$=$i__$1$jscomp$6_seq__33069_seq__33072_seq__33072__$1_xs__$1$jscomp$4$$;$i__$1$jscomp$6_seq__33069_seq__33072_seq__33072__$1_xs__$1$jscomp$4$$=$G__33067_G__33067__$1_G__35209_first__33073$$;$G__33067_G__33067__$1_G__35209_first__33073$$=$G__35210$$;continue}else return $G__33074_acc$jscomp$44_acc__$2_vec__33071$$;else return $acc__$3$$;break}}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function(){return this.$schema$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$351$$,$_$jscomp$435$$,$value$jscomp$251$$){return $malli$core$_set_children$$(this,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$value$jscomp$251$$],null))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$352$$,$writer$jscomp$103$$,$opts$jscomp$166$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$103$$,$opts$jscomp$166$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33017$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33019$$,$meta33018__$1$$){return new $malli$core$t_malli$0core33017$$(this.props,$meta33018__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33018$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$(this.props)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return $cljs$cst$415$type_properties$$.$cljs$core$IFn$_invoke$arity$1$(this.props)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($min$jscomp$22_parent$jscomp$57$$,$p__33025$jscomp$2$$,$children$jscomp$52$$,$options$jscomp$175$$){var $self__$jscomp$1585$$=this,$map__33026__$1$$=$APP.$cljs$core$__destructure_map$$($p__33025$jscomp$2$$);$min$jscomp$22_parent$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33026__$1$$,$APP.$cljs$cst$338$min$$);var $max$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33026__$1$$,
$APP.$cljs$cst$339$max$$),$parent__$1$jscomp$15$$=this,$temp__5823__auto__$jscomp$57$$=$APP.$cljs$cst$411$compile$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$1585$$.props);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$57$$))return $malli$core$_into_schema$$(function(){var $G__33027$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$1585$$.props,
$APP.$cljs$cst$411$compile$$),$temp__5823__auto__$jscomp$57$$.$cljs$core$IFn$_invoke$arity$3$?$temp__5823__auto__$jscomp$57$$.$cljs$core$IFn$_invoke$arity$3$($map__33026__$1$$,$children$jscomp$52$$,$options$jscomp$175$$):$temp__5823__auto__$jscomp$57$$($map__33026__$1$$,$children$jscomp$52$$,$options$jscomp$175$$)]));return $malli$core$_collection_schema$$.$cljs$core$IFn$_invoke$arity$1$?$malli$core$_collection_schema$$.$cljs$core$IFn$_invoke$arity$1$($G__33027$$):$malli$core$_collection_schema$$($G__33027$$)}(),
$map__33026__$1$$,$children$jscomp$52$$,$options$jscomp$175$$);var $map__33029__$1$$=$APP.$cljs$core$__destructure_map$$($self__$jscomp$1585$$.props),$fpred$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33029__$1$$,$APP.$cljs$cst$351$pred$$),$fempty$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33029__$1$$,$APP.$cljs$cst$489$empty$$),$fin$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__33029__$1$$,$APP.$cljs$cst$297$in$$,function($i$jscomp$319$$){return $i$jscomp$319$$}),
$type$jscomp$204$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33029__$1$$,$APP.$cljs$cst$139$type$$),$parse$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33029__$1$$,$cljs$cst$490$parse$$),$unparse$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33029__$1$$,$cljs$cst$491$unparse$$);$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($type$jscomp$204$$,$map__33026__$1$$,$children$jscomp$52$$,1,1);var $vec__33032$jscomp$2$$=
$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__33010_SHARP_$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($p1__33010_SHARP_$$,$options$jscomp$175$$):$APP.$malli$core$schema$$($p1__33010_SHARP_$$,$options$jscomp$175$$)},$children$jscomp$52$$),$schema$jscomp$43$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33032$jscomp$2$$,0,null),$form$jscomp$64$$=new $APP.$cljs$core$Delay$$(function(){return $malli$core$_simple_form$$($parent__$1$jscomp$15$$,
$map__33026__$1$$,$vec__33032$jscomp$2$$,$malli$core$_form$$,$options$jscomp$175$$)}),$cache$jscomp$34$$=$malli$core$_create_cache$$();if($APP.$cljs$core$truth_$$($cljs$cst$492$bounded$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$1585$$.props))){$APP.$cljs$core$truth_$$($fempty$jscomp$2$$)&&$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$493$malli_DOT_core_SLASH_cannot_provide_empty_and_bounded_props$$);var $JSCompiler_temp$jscomp$415$$=$malli$core$_needed_bounded_checks$$($min$jscomp$22_parent$jscomp$57$$,
$max$jscomp$22$$,$options$jscomp$175$$)}else $JSCompiler_temp$jscomp$415$$=null;var $bounded$jscomp$2$$=$JSCompiler_temp$jscomp$415$$,$validate_limits$jscomp$5$$=$APP.$cljs$core$truth_$$($bounded$jscomp$2$$)?$malli$core$_validate_bounded_limits$$(function(){var $y__5114__auto__$jscomp$8$$=$APP.$cljs$core$truth_$$($max$jscomp$22$$)?$max$jscomp$22$$:$bounded$jscomp$2$$;return $bounded$jscomp$2$$<$y__5114__auto__$jscomp$8$$?$bounded$jscomp$2$$:$y__5114__auto__$jscomp$8$$}(),$min$jscomp$22_parent$jscomp$57$$,
$max$jscomp$22$$):$malli$core$_validate_limits$$($min$jscomp$22_parent$jscomp$57$$,$max$jscomp$22$$);return new $malli$core$t_malli$0core33039$$($form$jscomp$64$$,$vec__33032$jscomp$2$$,$options$jscomp$175$$,$map__33026__$1$$,$temp__5823__auto__$jscomp$57$$,$fpred$jscomp$2$$,$fin$jscomp$2$$,$self__$jscomp$1585$$.props,$map__33026__$1$$,$unparse$jscomp$5$$,$schema$jscomp$43$$,$vec__33032$jscomp$2$$,$min$jscomp$22_parent$jscomp$57$$,$p__33025$jscomp$2$$,$bounded$jscomp$2$$,$parent__$1$jscomp$15$$,$map__33029__$1$$,
$type$jscomp$204$$,$self__$jscomp$1585$$.$meta33018$,function($f$jscomp$417$$,$g$jscomp$99$$){var $child_parser$$=$f$jscomp$417$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$417$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$43$$):$f$jscomp$417$$($schema$jscomp$43$$);return function($x$jscomp$756_x_SINGLEQUOTE_$$){if($APP.$cljs$core$not$$($fpred$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$fpred$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$756_x_SINGLEQUOTE_$$):$fpred$jscomp$2$$($x$jscomp$756_x_SINGLEQUOTE_$$))||
$APP.$cljs$core$not$$($validate_limits$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$validate_limits$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$756_x_SINGLEQUOTE_$$):$validate_limits$jscomp$5$$($x$jscomp$756_x_SINGLEQUOTE_$$)))return $cljs$cst$295$malli_DOT_core_SLASH_invalid$$;if($APP.$cljs$core$truth_$$($bounded$jscomp$2$$))return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($x__$1$jscomp$17$$,$v$jscomp$189$$){return $APP.$cljs$core$truth_$$($child_parser$$.$cljs$core$IFn$_invoke$arity$1$?
$child_parser$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$189$$):$child_parser$$($v$jscomp$189$$))?$x__$1$jscomp$17$$:$APP.$cljs$core$reduced$$($cljs$cst$295$malli_DOT_core_SLASH_invalid$$)},$x$jscomp$756_x_SINGLEQUOTE_$$,$malli$core$_safely_countable_QMARK_$$($x$jscomp$756_x_SINGLEQUOTE_$$)?$x$jscomp$756_x_SINGLEQUOTE_$$:$cljs$core$eduction$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$1$($bounded$jscomp$2$$),
$x$jscomp$756_x_SINGLEQUOTE_$$])));$x$jscomp$756_x_SINGLEQUOTE_$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$45$$,$v$jscomp$190_v_SINGLEQUOTE_$jscomp$1$$){$v$jscomp$190_v_SINGLEQUOTE_$jscomp$1$$=$child_parser$$.$cljs$core$IFn$_invoke$arity$1$?$child_parser$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$190_v_SINGLEQUOTE_$jscomp$1$$):$child_parser$$($v$jscomp$190_v_SINGLEQUOTE_$jscomp$1$$);return $APP.$cljs$core$keyword_identical_QMARK_$$($v$jscomp$190_v_SINGLEQUOTE_$jscomp$1$$,
$cljs$cst$295$malli_DOT_core_SLASH_invalid$$)?$APP.$cljs$core$reduced$$($cljs$cst$295$malli_DOT_core_SLASH_invalid$$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$45$$,$v$jscomp$190_v_SINGLEQUOTE_$jscomp$1$$)},$APP.$cljs$core$PersistentVector$EMPTY$$,$x$jscomp$756_x_SINGLEQUOTE_$$);return $APP.$cljs$core$keyword_identical_QMARK_$$($x$jscomp$756_x_SINGLEQUOTE_$$,$cljs$cst$295$malli_DOT_core_SLASH_invalid$$)?$x$jscomp$756_x_SINGLEQUOTE_$$:$APP.$cljs$core$truth_$$($g$jscomp$99$$)?
$g$jscomp$99$$.$cljs$core$IFn$_invoke$arity$1$?$g$jscomp$99$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$756_x_SINGLEQUOTE_$$):$g$jscomp$99$$($x$jscomp$756_x_SINGLEQUOTE_$$):$APP.$cljs$core$truth_$$($fempty$jscomp$2$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($fempty$jscomp$2$$,$x$jscomp$756_x_SINGLEQUOTE_$$):$x$jscomp$756_x_SINGLEQUOTE_$$}},$fempty$jscomp$2$$,$cache$jscomp$34$$,$validate_limits$jscomp$5$$,$max$jscomp$22$$,$parse$jscomp$3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$353$$,$writer$jscomp$104$$,$opts$jscomp$167$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$104$$,$opts$jscomp$167$$)};
var $malli$core$_collection_schema$$=function $malli$core$_collection_schema$$($props$jscomp$20$$){if($APP.$cljs$core$fn_QMARK_$$($props$jscomp$20$$)){$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["DEPRECATED:","-collection-schema doesn't take fn-props, use :compiled property instead"]));var $G__33015$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$411$compile$$,function($c$jscomp$197$$,$p$jscomp$77$$){return $props$jscomp$20$$.$cljs$core$IFn$_invoke$arity$2$?
$props$jscomp$20$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$197$$,$p$jscomp$77$$):$props$jscomp$20$$($c$jscomp$197$$,$p$jscomp$77$$)}],null);return $malli$core$_collection_schema$$.$cljs$core$IFn$_invoke$arity$1$?$malli$core$_collection_schema$$.$cljs$core$IFn$_invoke$arity$1$($G__33015$$):$malli$core$_collection_schema$$($G__33015$$)}return new $malli$core$t_malli$0core33017$$($props$jscomp$20$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],
null))};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33144$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33146$$,$meta33145__$1$$){return new $malli$core$t_malli$0core33144$$(this.form,this.options,this.$properties$,this.children,this.parent,this.size,this.$__GT_parser$,this.$meta33130$,this.cache,this.$opts$,$meta33145__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33145$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){var $self__$jscomp$1589$$=this,$validators$jscomp$4$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($malli$core$_validator$$,$self__$jscomp$1589$$.children)));return function($x$jscomp$757$$){var $and__5023__auto__$jscomp$86_and__5023__auto____$1$jscomp$22$$=
$APP.$cljs$core$vector_QMARK_$$($x$jscomp$757$$);return $and__5023__auto__$jscomp$86_and__5023__auto____$1$jscomp$22$$?($and__5023__auto__$jscomp$86_and__5023__auto____$1$jscomp$22$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($x$jscomp$757$$),$self__$jscomp$1589$$.size))?$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$46$$,$G__33149$jscomp$inline_3549_i$jscomp$320$$,$JSCompiler_inline_result$jscomp$416_validator$jscomp$20$$){$G__33149$jscomp$inline_3549_i$jscomp$320$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($x$jscomp$757$$,$G__33149$jscomp$inline_3549_i$jscomp$320$$);$JSCompiler_inline_result$jscomp$416_validator$jscomp$20$$=$JSCompiler_inline_result$jscomp$416_validator$jscomp$20$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$416_validator$jscomp$20$$.$cljs$core$IFn$_invoke$arity$1$($G__33149$jscomp$inline_3549_i$jscomp$320$$):$JSCompiler_inline_result$jscomp$416_validator$jscomp$20$$($G__33149$jscomp$inline_3549_i$jscomp$320$$);
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$416_validator$jscomp$20$$)?$acc$jscomp$46$$:$APP.$cljs$core$reduced$$(!1)},!0,$validators$jscomp$4$$):$and__5023__auto__$jscomp$86_and__5023__auto____$1$jscomp$22$$:$and__5023__auto__$jscomp$86_and__5023__auto____$1$jscomp$22$$}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$354_this_transformer$jscomp$4$$,$transformer$jscomp$23$$,$method$jscomp$23$$,$options__$1$jscomp$20$$){$this$$jscomp$354_this_transformer$jscomp$4$$=$malli$core$_value_transformer$$($transformer$jscomp$23$$,this,$method$jscomp$23$$,$options__$1$jscomp$20$$);var $__GT_children$jscomp$1_apply__GT_children$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$vector$$),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($c$jscomp$198_p__33150_temp__5829__auto__$jscomp$5$$){var $k$jscomp$387$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$198_p__33150_temp__5829__auto__$jscomp$5$$,0,null);$c$jscomp$198_p__33150_temp__5829__auto__$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$198_p__33150_temp__5829__auto__$jscomp$5$$,
1,null);$c$jscomp$198_p__33150_temp__5829__auto__$jscomp$5$$=$malli$core$_transformer$$($c$jscomp$198_p__33150_temp__5829__auto__$jscomp$5$$,$transformer$jscomp$23$$,$method$jscomp$23$$,$options__$1$jscomp$20$$);return $c$jscomp$198_p__33150_temp__5829__auto__$jscomp$5$$==null?null:new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$387$$,$c$jscomp$198_p__33150_temp__5829__auto__$jscomp$5$$],null)})),this.children);$__GT_children$jscomp$1_apply__GT_children$jscomp$1$$=
$APP.$cljs$core$seq$$($__GT_children$jscomp$1_apply__GT_children$jscomp$1$$)?$malli$core$_tuple_transformer$$($__GT_children$jscomp$1_apply__GT_children$jscomp$1$$):null;return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$02$$($this$$jscomp$354_this_transformer$jscomp$4$$,$malli$core$_guard$$($APP.$cljs$core$vector_QMARK_$$,$__GT_children$jscomp$1_apply__GT_children$jscomp$1$$))};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$355$$,$walker$jscomp$16$$,$path$jscomp$66$$,$options__$1$jscomp$21$$){return $malli$core$_walk_indexed$$(this,$walker$jscomp$16$$,$path$jscomp$66$$,$options__$1$jscomp$21$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$356$$,$path$jscomp$67$$){var $self__$jscomp$1597$$=this,$this$__$1$jscomp$97$$=this,$explainers$jscomp$4$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__33167_s$jscomp$315$$){var $i$jscomp$321$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33167_s$jscomp$315$$,0,null);$p__33167_s$jscomp$315$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33167_s$jscomp$315$$,
1,null);return $malli$core$_explainer$$($p__33167_s$jscomp$315$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$67$$,$i$jscomp$321$$))},$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$self__$jscomp$1597$$.children));return function($G__33196_G__33199$jscomp$inline_3553_acc__$3$jscomp$1_x$jscomp$758$$,$in$$jscomp$23$$,$acc$jscomp$47_acc__$2$jscomp$1_i__$2$jscomp$2$$){if($APP.$cljs$core$vector_QMARK_$$($G__33196_G__33199$jscomp$inline_3553_acc__$3$jscomp$1_x$jscomp$758$$)){if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($G__33196_G__33199$jscomp$inline_3553_acc__$3$jscomp$1_x$jscomp$758$$),
$self__$jscomp$1597$$.size))return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$47_acc__$2$jscomp$1_i__$2$jscomp$2$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($path$jscomp$67$$,$in$$jscomp$23$$,$this$__$1$jscomp$97$$,$G__33196_G__33199$jscomp$inline_3553_acc__$3$jscomp$1_x$jscomp$758$$,$cljs$cst$494$malli_DOT_core_SLASH_tuple_size$$));if($self__$jscomp$1597$$.size===0)return $acc$jscomp$47_acc__$2$jscomp$1_i__$2$jscomp$2$$;var $first__33192_i__$1$jscomp$7_seq__33185_seq__33188_xs__$1$jscomp$5$$=
$APP.$cljs$core$seq$$($G__33196_G__33199$jscomp$inline_3553_acc__$3$jscomp$1_x$jscomp$758$$);$APP.$cljs$core$first$$($first__33192_i__$1$jscomp$7_seq__33185_seq__33188_xs__$1$jscomp$5$$);$APP.$cljs$core$next$$($first__33192_i__$1$jscomp$7_seq__33185_seq__33188_xs__$1$jscomp$5$$);$first__33192_i__$1$jscomp$7_seq__33185_seq__33188_xs__$1$jscomp$5$$=$APP.$cljs$core$seq$$($explainers$jscomp$4$$);$APP.$cljs$core$first$$($first__33192_i__$1$jscomp$7_seq__33185_seq__33188_xs__$1$jscomp$5$$);$APP.$cljs$core$next$$($first__33192_i__$1$jscomp$7_seq__33185_seq__33188_xs__$1$jscomp$5$$);
$first__33192_i__$1$jscomp$7_seq__33185_seq__33188_xs__$1$jscomp$5$$=0;for(var $G__33177__$1_G__33197$jscomp$inline_3551_G__35287_seq__33191_x__$2$jscomp$1$$=$G__33196_G__33199$jscomp$inline_3553_acc__$3$jscomp$1_x$jscomp$758$$,$G__33178__$1_G__35289_es__$1_first__33195$$=$explainers$jscomp$4$$;;){$G__33196_G__33199$jscomp$inline_3553_acc__$3$jscomp$1_x$jscomp$758$$=$acc$jscomp$47_acc__$2$jscomp$1_i__$2$jscomp$2$$;$acc$jscomp$47_acc__$2$jscomp$1_i__$2$jscomp$2$$=$first__33192_i__$1$jscomp$7_seq__33185_seq__33188_xs__$1$jscomp$5$$;
$G__33177__$1_G__33197$jscomp$inline_3551_G__35287_seq__33191_x__$2$jscomp$1$$=$APP.$cljs$core$seq$$($G__33177__$1_G__33197$jscomp$inline_3551_G__35287_seq__33191_x__$2$jscomp$1$$);$first__33192_i__$1$jscomp$7_seq__33185_seq__33188_xs__$1$jscomp$5$$=$APP.$cljs$core$first$$($G__33177__$1_G__33197$jscomp$inline_3551_G__35287_seq__33191_x__$2$jscomp$1$$);var $G__35288_e__$1$jscomp$4_seq__33191__$1_seq__33194$$=$APP.$cljs$core$next$$($G__33177__$1_G__33197$jscomp$inline_3551_G__35287_seq__33191_x__$2$jscomp$1$$);
$G__33177__$1_G__33197$jscomp$inline_3551_G__35287_seq__33191_x__$2$jscomp$1$$=$first__33192_i__$1$jscomp$7_seq__33185_seq__33188_xs__$1$jscomp$5$$;$first__33192_i__$1$jscomp$7_seq__33185_seq__33188_xs__$1$jscomp$5$$=$G__35288_e__$1$jscomp$4_seq__33191__$1_seq__33194$$;$G__35288_e__$1$jscomp$4_seq__33191__$1_seq__33194$$=$APP.$cljs$core$seq$$($G__33178__$1_G__35289_es__$1_first__33195$$);$G__33178__$1_G__35289_es__$1_first__33195$$=$APP.$cljs$core$first$$($G__35288_e__$1$jscomp$4_seq__33191__$1_seq__33194$$);
var $G__33198$jscomp$inline_3552_seq__33194__$1$$=$APP.$cljs$core$next$$($G__35288_e__$1$jscomp$4_seq__33191__$1_seq__33194$$);$G__35288_e__$1$jscomp$4_seq__33191__$1_seq__33194$$=$G__33178__$1_G__35289_es__$1_first__33195$$;$G__33178__$1_G__35289_es__$1_first__33195$$=$G__33198$jscomp$inline_3552_seq__33194__$1$$;$G__33198$jscomp$inline_3552_seq__33194__$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($in$$jscomp$23$$,$acc$jscomp$47_acc__$2$jscomp$1_i__$2$jscomp$2$$);$G__33196_G__33199$jscomp$inline_3553_acc__$3$jscomp$1_x$jscomp$758$$=
$G__35288_e__$1$jscomp$4_seq__33191__$1_seq__33194$$.$cljs$core$IFn$_invoke$arity$3$?$G__35288_e__$1$jscomp$4_seq__33191__$1_seq__33194$$.$cljs$core$IFn$_invoke$arity$3$($G__33177__$1_G__33197$jscomp$inline_3551_G__35287_seq__33191_x__$2$jscomp$1$$,$G__33198$jscomp$inline_3552_seq__33194__$1$$,$G__33196_G__33199$jscomp$inline_3553_acc__$3$jscomp$1_x$jscomp$758$$):$G__35288_e__$1$jscomp$4_seq__33191__$1_seq__33194$$($G__33177__$1_G__33197$jscomp$inline_3551_G__35287_seq__33191_x__$2$jscomp$1$$,$G__33198$jscomp$inline_3552_seq__33194__$1$$,
$G__33196_G__33199$jscomp$inline_3553_acc__$3$jscomp$1_x$jscomp$758$$);if($first__33192_i__$1$jscomp$7_seq__33185_seq__33188_xs__$1$jscomp$5$$)$G__33177__$1_G__33197$jscomp$inline_3551_G__35287_seq__33191_x__$2$jscomp$1$$=$acc$jscomp$47_acc__$2$jscomp$1_i__$2$jscomp$2$$+1,$G__35288_e__$1$jscomp$4_seq__33191__$1_seq__33194$$=$first__33192_i__$1$jscomp$7_seq__33185_seq__33188_xs__$1$jscomp$5$$,$acc$jscomp$47_acc__$2$jscomp$1_i__$2$jscomp$2$$=$G__33196_G__33199$jscomp$inline_3553_acc__$3$jscomp$1_x$jscomp$758$$,
$first__33192_i__$1$jscomp$7_seq__33185_seq__33188_xs__$1$jscomp$5$$=$G__33177__$1_G__33197$jscomp$inline_3551_G__35287_seq__33191_x__$2$jscomp$1$$,$G__33177__$1_G__33197$jscomp$inline_3551_G__35287_seq__33191_x__$2$jscomp$1$$=$G__35288_e__$1$jscomp$4_seq__33191__$1_seq__33194$$;else return $G__33196_G__33199$jscomp$inline_3553_acc__$3$jscomp$1_x$jscomp$758$$}}else return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$47_acc__$2$jscomp$1_i__$2$jscomp$2$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($path$jscomp$67$$,
$in$$jscomp$23$$,$this$__$1$jscomp$97$$,$G__33196_G__33199$jscomp$inline_3553_acc__$3$jscomp$1_x$jscomp$758$$,$cljs$cst$315$malli_DOT_core_SLASH_invalid_type$$))}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$452$$,$key$jscomp$213$$,$default$$jscomp$21$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.children,$key$jscomp$213$$,$default$$jscomp$21$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$357$$,$key$jscomp$214$$,$value$jscomp$252$$){return $malli$core$_set_assoc_children$$(this,$key$jscomp$214$$,$value$jscomp$252$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$358$$,$writer$jscomp$105$$,$opts__$1$jscomp$9$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$105$$,$opts__$1$jscomp$9$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33129$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33131$$,$meta33130__$1$$){return new $malli$core$t_malli$0core33129$$(this.$opts$,$meta33130__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33130$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $APP.$cljs$cst$498$tuple$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return $cljs$cst$415$type_properties$$.$cljs$core$IFn$_invoke$arity$1$(this.$opts$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($form$jscomp$67_parent$jscomp$60$$,$properties$jscomp$46$$,$children$jscomp$55$$,$options$jscomp$178$$){var $parent__$1$jscomp$16$$=this,$children__$1$jscomp$6$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__33092_SHARP_$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($p1__33092_SHARP_$$,$options$jscomp$178$$):
$APP.$malli$core$schema$$($p1__33092_SHARP_$$,$options$jscomp$178$$)},$children$jscomp$55$$);$form$jscomp$67_parent$jscomp$60$$=new $APP.$cljs$core$Delay$$(function(){return $malli$core$_simple_form$$($parent__$1$jscomp$16$$,$properties$jscomp$46$$,$children__$1$jscomp$6$$,$malli$core$_form$$,$options$jscomp$178$$)});var $size$jscomp$44$$=$APP.$cljs$core$count$$($children__$1$jscomp$6$$);return new $malli$core$t_malli$0core33144$$($form$jscomp$67_parent$jscomp$60$$,$options$jscomp$178$$,$properties$jscomp$46$$,
$children__$1$jscomp$6$$,$parent__$1$jscomp$16$$,$size$jscomp$44$$,function($f$jscomp$418$$){var $parsers$jscomp$4$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($f$jscomp$418$$),$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$vector$$)),$children__$1$jscomp$6$$);return function($x$jscomp$759$$){return $APP.$cljs$core$vector_QMARK_$$($x$jscomp$759$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($x$jscomp$759$$),$size$jscomp$44$$)?$cljs$cst$295$malli_DOT_core_SLASH_invalid$$:$APP.$cljs$core$reduce_kv$$(function($x__$1$jscomp$19$$,$i$jscomp$323$$,$c$jscomp$199_v_STAR_$jscomp$2$$){var $v$jscomp$191$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($x__$1$jscomp$19$$,$i$jscomp$323$$);$c$jscomp$199_v_STAR_$jscomp$2$$=$c$jscomp$199_v_STAR_$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$c$jscomp$199_v_STAR_$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$191$$):
$c$jscomp$199_v_STAR_$jscomp$2$$($v$jscomp$191$$);return $APP.$cljs$core$keyword_identical_QMARK_$$($c$jscomp$199_v_STAR_$jscomp$2$$,$cljs$cst$295$malli_DOT_core_SLASH_invalid$$)?$APP.$cljs$core$reduced$$($c$jscomp$199_v_STAR_$jscomp$2$$):$c$jscomp$199_v_STAR_$jscomp$2$$===$v$jscomp$191$$?$x__$1$jscomp$19$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($x__$1$jscomp$19$$,$i$jscomp$323$$,$c$jscomp$199_v_STAR_$jscomp$2$$)},$x$jscomp$759$$,$parsers$jscomp$4$$):$cljs$cst$295$malli_DOT_core_SLASH_invalid$$}},
this.$meta33130$,$malli$core$_create_cache$$(),this.$opts$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$359$$,$writer$jscomp$106$$,$opts__$1$jscomp$10$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$106$$,$opts__$1$jscomp$10$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33218$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33220$$,$meta33219__$1$$){return new $malli$core$t_malli$0core33218$$(this.$meta33211$,this.parent,this.$properties$,this.children,this.options,this.$schema$,this.form,this.cache,$meta33219__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33219$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return $malli$core$_ast$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$499$enum$$,$APP.$cljs$cst$301$values$$,this.children],null),this.$properties$,this.options)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){var $self__$jscomp$1616$$=this;return function($x$jscomp$760$$){return $APP.$cljs$core$contains_QMARK_$$($self__$jscomp$1616$$.$schema$,$x$jscomp$760$$)}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$360$$,$transformer$jscomp$24$$,$method$jscomp$24$$,$options__$1$jscomp$22$$){return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$01$$($malli$core$_value_transformer$$($transformer$jscomp$24$$,this,$method$jscomp$24$$,$options__$1$jscomp$22$$))};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$361$$,$walker$jscomp$17$$,$path$jscomp$68$$,$options__$1$jscomp$23$$){return $malli$core$_walk_leaf$$(this,$walker$jscomp$17$$,$path$jscomp$68$$,$options__$1$jscomp$23$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$362$$,$path$jscomp$69$$){var $this$__$1$jscomp$103$$=this,$validator$jscomp$21$$=$this$__$1$jscomp$103$$.$malli$core$Schema$_validator$arity$1$(null);return function($x$jscomp$762$$,$in$$jscomp$24$$,$acc$jscomp$48$$){return $APP.$cljs$core$not$$($validator$jscomp$21$$.$cljs$core$IFn$_invoke$arity$1$?$validator$jscomp$21$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$762$$):$validator$jscomp$21$$($x$jscomp$762$$))?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$48$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$04$$($path$jscomp$69$$,$in$$jscomp$24$$,$this$__$1$jscomp$103$$,$x$jscomp$762$$)):$acc$jscomp$48$$}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$467$$,$key$jscomp$215$$,$default$$jscomp$22$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.children,$key$jscomp$215$$,$default$$jscomp$22$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$364$$,$key$jscomp$216$$,$value$jscomp$253$$){return $malli$core$_set_assoc_children$$(this,$key$jscomp$216$$,$value$jscomp$253$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$365$$,$writer$jscomp$107$$,$opts$jscomp$173$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$107$$,$opts$jscomp$173$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33210$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33212$$,$meta33211__$1$$){return new $malli$core$t_malli$0core33210$$($meta33211__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33211$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $APP.$cljs$cst$499$enum$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($parent$jscomp$64_schema$jscomp$46$$,$properties$jscomp$49$$,$children$jscomp$58$$,$options$jscomp$182$$){var $parent__$1$jscomp$18$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$cljs$cst$499$enum$$,$properties$jscomp$49$$,$children$jscomp$58$$,1,null);var $children__$1$jscomp$7$$=$APP.$cljs$core$vec$$($children$jscomp$58$$);$parent$jscomp$64_schema$jscomp$46$$=$APP.$cljs$core$set$$($children__$1$jscomp$7$$);
return new $malli$core$t_malli$0core33218$$(this.$meta33211$,$parent__$1$jscomp$18$$,$properties$jscomp$49$$,$children__$1$jscomp$7$$,$options$jscomp$182$$,$parent$jscomp$64_schema$jscomp$46$$,new $APP.$cljs$core$Delay$$(function(){return $malli$core$_simple_form$$($parent__$1$jscomp$18$$,$properties$jscomp$49$$,$children__$1$jscomp$7$$,$APP.$cljs$core$identity$$,$options$jscomp$182$$)}),$malli$core$_create_cache$$(),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],
null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$366$$,$writer$jscomp$108$$,$opts$jscomp$174$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$108$$,$opts$jscomp$174$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33258$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33260$$,$meta33259__$1$$){return new $malli$core$t_malli$0core33258$$(this.form,this.options,this.$child$,this.$properties$,this.children,this.parent,this.$vec__33254$,this.re,this.$class_QMARK_$,this.$meta33240$,this.$p__33253$,this.$matches_QMARK_$,this.cache,$meta33259__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33259$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return $malli$core$_to_value_ast$$(this)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){return $malli$core$_safe_pred$$(this.$matches_QMARK_$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$368$$,$transformer$jscomp$25$$,$method$jscomp$25$$,$options__$1$jscomp$24$$){return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$01$$($malli$core$_value_transformer$$($transformer$jscomp$25$$,this,$method$jscomp$25$$,$options__$1$jscomp$24$$))};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$369$$,$walker$jscomp$18$$,$path$jscomp$70$$,$options__$1$jscomp$25$$){return $malli$core$_walk_leaf$$(this,$walker$jscomp$18$$,$path$jscomp$70$$,$options__$1$jscomp$25$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$371$$,$path$jscomp$71$$){var $self__$jscomp$1650$$=this,$this$__$1$jscomp$112$$=this;return function($x$jscomp$764$$,$in$$jscomp$25$$,$acc$jscomp$49$$){try{return $APP.$cljs$core$not$$($self__$jscomp$1650$$.$matches_QMARK_$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$1650$$.$matches_QMARK_$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$764$$):$self__$jscomp$1650$$.$matches_QMARK_$($x$jscomp$764$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$49$$,
$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$04$$($path$jscomp$71$$,$in$$jscomp$25$$,$this$__$1$jscomp$112$$,$x$jscomp$764$$)):$acc$jscomp$49$$}catch($e33292$$){if($e33292$$ instanceof Error)return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$49$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($path$jscomp$71$$,$in$$jscomp$25$$,$this$__$1$jscomp$112$$,$x$jscomp$764$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($e33292$$))));
throw $e33292$$;}}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$479$$,$key$jscomp$217$$,$default$$jscomp$23$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.children,$key$jscomp$217$$,$default$$jscomp$23$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$373$$,$key$jscomp$218$$,$value$jscomp$254$$){return $malli$core$_set_assoc_children$$(this,$key$jscomp$218$$,$value$jscomp$254$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$374$$,$writer$jscomp$109$$,$opts$jscomp$175$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$109$$,$opts$jscomp$175$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33239$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33241$$,$meta33240__$1$$){return new $malli$core$t_malli$0core33239$$(this.$class_QMARK_$,$meta33240__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33240$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $cljs$cst$512$re$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($child$jscomp$8_parent$jscomp$68$$,$properties$jscomp$52$$,$p__33253$jscomp$2$$,$options$jscomp$186$$){var $self__$jscomp$1665$$=this;$child$jscomp$8_parent$jscomp$68$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33253$jscomp$2$$,0,null);var $parent__$1$jscomp$20$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($cljs$cst$512$re$$,$properties$jscomp$52$$,$p__33253$jscomp$2$$,
1,1);var $children__$1$jscomp$8$$=$APP.$cljs$core$vec$$($p__33253$jscomp$2$$),$re$jscomp$16$$=$APP.$cljs$core$re_pattern$$($child$jscomp$8_parent$jscomp$68$$);return new $malli$core$t_malli$0core33258$$(new $APP.$cljs$core$Delay$$(function(){return $APP.$cljs$core$truth_$$($self__$jscomp$1665$$.$class_QMARK_$)?$re$jscomp$16$$:$malli$core$_simple_form$$($parent__$1$jscomp$20$$,$properties$jscomp$52$$,$children__$1$jscomp$8$$,$APP.$cljs$core$identity$$,$options$jscomp$186$$)}),$options$jscomp$186$$,
$child$jscomp$8_parent$jscomp$68$$,$properties$jscomp$52$$,$children__$1$jscomp$8$$,$parent__$1$jscomp$20$$,$p__33253$jscomp$2$$,$re$jscomp$16$$,$self__$jscomp$1665$$.$class_QMARK_$,$self__$jscomp$1665$$.$meta33240$,$p__33253$jscomp$2$$,function($p1__33237_SHARP_$$){var $and__5023__auto__$jscomp$87$$=typeof $p1__33237_SHARP_$$==="string";return $and__5023__auto__$jscomp$87$$?$APP.$cljs$core$re_find$$($re$jscomp$16$$,$p1__33237_SHARP_$$):$and__5023__auto__$jscomp$87$$},$malli$core$_create_cache$$(),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$375$$,$writer$jscomp$110$$,$opts$jscomp$176$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$110$$,$opts$jscomp$176$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33384$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33386$$,$meta33385__$1$$){return new $malli$core$t_malli$0core33384$$(this.$meta33359$,this.parent,this.$properties$,this.children,this.options,this.f,this.form,this.cache,$meta33385__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33385$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return $malli$core$_to_value_ast$$(this)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){return $malli$core$_safe_pred$$(this.f)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$377$$,$transformer$jscomp$26$$,$method$jscomp$26$$,$options__$1$jscomp$26$$){return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$01$$($malli$core$_value_transformer$$($transformer$jscomp$26$$,this,$method$jscomp$26$$,$options__$1$jscomp$26$$))};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$378$$,$walker$jscomp$19$$,$path$jscomp$72$$,$options__$1$jscomp$27$$){return $malli$core$_walk_leaf$$(this,$walker$jscomp$19$$,$path$jscomp$72$$,$options__$1$jscomp$27$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$380$$,$path$jscomp$73$$){var $self__$jscomp$1678$$=this,$this$__$1$jscomp$121$$=this;return function($x$jscomp$766$$,$in$$jscomp$26$$,$acc$jscomp$50$$){try{return $APP.$cljs$core$not$$($self__$jscomp$1678$$.f.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$1678$$.f.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$766$$):$self__$jscomp$1678$$.f($x$jscomp$766$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$50$$,
$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$04$$($path$jscomp$73$$,$in$$jscomp$26$$,$this$__$1$jscomp$121$$,$x$jscomp$766$$)):$acc$jscomp$50$$}catch($e33444$$){if($e33444$$ instanceof Error)return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$50$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($path$jscomp$73$$,$in$$jscomp$26$$,$this$__$1$jscomp$121$$,$x$jscomp$766$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($e33444$$))));
throw $e33444$$;}}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$493$$,$key$jscomp$219$$,$default$$jscomp$24$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.children,$key$jscomp$219$$,$default$$jscomp$24$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$382$$,$key$jscomp$220$$,$value$jscomp$255$$){return $malli$core$_set_assoc_children$$(this,$key$jscomp$220$$,$value$jscomp$255$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$383$$,$writer$jscomp$111$$,$opts$jscomp$177$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$111$$,$opts$jscomp$177$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33358$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33360$$,$meta33359__$1$$){return new $malli$core$t_malli$0core33358$$($meta33359__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33359$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $APP.$cljs$cst$516$fn$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($f$jscomp$421_parent$jscomp$72$$,$properties$jscomp$55$$,$children$jscomp$64$$,$options$jscomp$190$$){var $parent__$1$jscomp$22$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$cljs$cst$516$fn$$,$properties$jscomp$55$$,$children$jscomp$64$$,1,1);var $children__$1$jscomp$9$$=$APP.$cljs$core$vec$$($children$jscomp$64$$);$f$jscomp$421_parent$jscomp$72$$=function(){var $G__33381$$=
$APP.$cljs$core$first$$($children__$1$jscomp$9$$);return $malli$core$eval$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$core$eval$cljs$0core$0IFn$0_invoke$0arity$02$$($G__33381$$,$options$jscomp$190$$):$malli$core$eval$$($G__33381$$,$options$jscomp$190$$)}();return new $malli$core$t_malli$0core33384$$(this.$meta33359$,$parent__$1$jscomp$22$$,$properties$jscomp$55$$,$children__$1$jscomp$9$$,$options$jscomp$190$$,$f$jscomp$421_parent$jscomp$72$$,new $APP.$cljs$core$Delay$$(function(){return $malli$core$_simple_form$$($parent__$1$jscomp$22$$,
$properties$jscomp$55$$,$children__$1$jscomp$9$$,$APP.$cljs$core$identity$$,$options$jscomp$190$$)}),$malli$core$_create_cache$$(),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$384$$,$writer$jscomp$112$$,$opts$jscomp$178$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$112$$,$opts$jscomp$178$$)};
$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33557$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33559$$,$meta33558__$1$$){return new $malli$core$t_malli$0core33557$$(this.form,this.options,this.$properties$,this.$schema$,this.children,this.parent,this.$vec__33548$,this.$__GT_parser$,this.$meta33507$,this.cache,$meta33558__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33558$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return $malli$core$_to_child_ast$$(this)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){var $validator$jscomp$23$$=$malli$core$_validator$$(this.$schema$);return function($x$jscomp$767$$){var $or__5025__auto__$jscomp$111$$=$x$jscomp$767$$==null;return $or__5025__auto__$jscomp$111$$?$or__5025__auto__$jscomp$111$$:$validator$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$?$validator$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$767$$):$validator$jscomp$23$$($x$jscomp$767$$)}};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$386$$,$transformer$jscomp$27$$,$method$jscomp$27$$,$options__$1$jscomp$28$$){return $malli$core$_parent_children_transformer$$(this,this.children,$transformer$jscomp$27$$,$method$jscomp$27$$,$options__$1$jscomp$28$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$387$$,$walker$jscomp$20$$,$path$jscomp$74$$,$options__$1$jscomp$29$$){return $malli$core$_walk_indexed$$(this,$walker$jscomp$20$$,$path$jscomp$74$$,$options__$1$jscomp$29$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($_$jscomp$503$$,$path$jscomp$75$$){var $explainer$jscomp$10$$=$malli$core$_explainer$$(this.$schema$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$75$$,0));return function($x$jscomp$768$$,$in$$jscomp$27$$,$acc$jscomp$51$$){return $x$jscomp$768$$==null?$acc$jscomp$51$$:$explainer$jscomp$10$$.$cljs$core$IFn$_invoke$arity$3$?$explainer$jscomp$10$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$768$$,$in$$jscomp$27$$,
$acc$jscomp$51$$):$explainer$jscomp$10$$($x$jscomp$768$$,$in$$jscomp$27$$,$acc$jscomp$51$$)}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$508$$,$key$jscomp$221$$,$default$$jscomp$25$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$key$jscomp$221$$)?this.$schema$:$default$$jscomp$25$$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$388$$,$key$jscomp$222$$,$value$jscomp$256$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$key$jscomp$222$$)?$malli$core$_set_children$$(this,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$value$jscomp$256$$],null)):$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$517$malli_DOT_core_SLASH_index_out_of_bounds$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$298$schema$$,this,$APP.$cljs$cst$302$key$$,$key$jscomp$222$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$389$$,$writer$jscomp$113$$,$opts$jscomp$179$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$113$$,$opts$jscomp$179$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33506$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33508$$,$meta33507__$1$$){return new $malli$core$t_malli$0core33506$$($meta33507__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33507$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $APP.$cljs$cst$522$maybe$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($parent$jscomp$76$$,$properties$jscomp$58$$,$children$jscomp$67$$,$options$jscomp$194$$){var $parent__$1$jscomp$24$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$cljs$cst$522$maybe$$,$properties$jscomp$58$$,$children$jscomp$67$$,1,1);var $vec__33548$jscomp$2$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__33500_SHARP_$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($p1__33500_SHARP_$$,$options$jscomp$194$$):$APP.$malli$core$schema$$($p1__33500_SHARP_$$,$options$jscomp$194$$)},$children$jscomp$67$$),$schema$jscomp$49$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33548$jscomp$2$$,0,null);return new $malli$core$t_malli$0core33557$$(new $APP.$cljs$core$Delay$$(function(){return $malli$core$_simple_form$$($parent__$1$jscomp$24$$,$properties$jscomp$58$$,$vec__33548$jscomp$2$$,$malli$core$_form$$,
$options$jscomp$194$$)}),$options$jscomp$194$$,$properties$jscomp$58$$,$schema$jscomp$49$$,$vec__33548$jscomp$2$$,$parent__$1$jscomp$24$$,$vec__33548$jscomp$2$$,function($f$jscomp$422$$){var $parser$jscomp$10$$=$f$jscomp$422$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$422$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$49$$):$f$jscomp$422$$($schema$jscomp$49$$);return function($x$jscomp$769$$){return $x$jscomp$769$$==null?$x$jscomp$769$$:$parser$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$?$parser$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$769$$):
$parser$jscomp$10$$($x$jscomp$769$$)}},this.$meta33507$,$malli$core$_create_cache$$(),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$390$$,$writer$jscomp$114$$,$opts$jscomp$180$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$114$$,$opts$jscomp$180$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33688$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return $malli$core$_entry_ast$$(this,$malli$core$_entry_keyset$$(this.$entry_parser$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$392$$,$writer$jscomp$115$$,$opts__$1$jscomp$11$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$115$$,$opts__$1$jscomp$11$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntrySchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntrySchema$_entries$arity$1$=function(){return $malli$core$_entry_entries$$(this.$entry_parser$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntrySchema$_entry_parser$arity$1$=function(){return this.$entry_parser$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33689$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$DistributiveSchema$_distributive_schema_QMARK_$arity$1$=function(){return!0};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$DistributiveSchema$_distribute_to_children$arity$3$=function($this$$jscomp$393$$,$f$jscomp$423$$){var $self__$jscomp$1727$$=this;return $self__$jscomp$1727$$.parent.$malli$core$IntoSchema$_into_schema$arity$4$(null,$self__$jscomp$1727$$.$properties$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($c$jscomp$200$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($c$jscomp$200$$,2,$f$jscomp$423$$,$self__$jscomp$1727$$.options)},
this.$malli$core$Schema$_children$arity$1$(null)),$self__$jscomp$1727$$.options)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33690$jscomp$1$$,$meta33689__$1$$){return new $malli$core$t_malli$0core33688$$(this.form,this.options,this.$properties$,this.children,this.$entry_parser$,this.parent,this.$meta33659$,this.$opts_SINGLEQUOTE_$,this.$dispatch$,this.cache,this.$finder$,this.$opts$,this.$dispatch_map$,$meta33689__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){var $self__$jscomp$1730$$=this,$find$$=function(){var $G__33704$$=$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$52$$,$k$jscomp$388$$,$s$jscomp$316$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$52$$,$k$jscomp$388$$,$malli$core$_validator$$($s$jscomp$316$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$_deref$$($self__$jscomp$1730$$.$dispatch_map$));return $self__$jscomp$1730$$.$finder$.$cljs$core$IFn$_invoke$arity$1$?
$self__$jscomp$1730$$.$finder$.$cljs$core$IFn$_invoke$arity$1$($G__33704$$):$self__$jscomp$1730$$.$finder$($G__33704$$)}();return function($x$jscomp$770$$){var $G__33705$jscomp$inline_3555_temp__5823__auto__$jscomp$58$$=$self__$jscomp$1730$$.$dispatch$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$1730$$.$dispatch$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$770$$):$self__$jscomp$1730$$.$dispatch$($x$jscomp$770$$);$G__33705$jscomp$inline_3555_temp__5823__auto__$jscomp$58$$=$find$$.$cljs$core$IFn$_invoke$arity$1$?
$find$$.$cljs$core$IFn$_invoke$arity$1$($G__33705$jscomp$inline_3555_temp__5823__auto__$jscomp$58$$):$find$$($G__33705$jscomp$inline_3555_temp__5823__auto__$jscomp$58$$);return $APP.$cljs$core$truth_$$($G__33705$jscomp$inline_3555_temp__5823__auto__$jscomp$58$$)?$G__33705$jscomp$inline_3555_temp__5823__auto__$jscomp$58$$.$cljs$core$IFn$_invoke$arity$1$?$G__33705$jscomp$inline_3555_temp__5823__auto__$jscomp$58$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$770$$):$G__33705$jscomp$inline_3555_temp__5823__auto__$jscomp$58$$($x$jscomp$770$$):
!1}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$394_this_transformer$jscomp$5$$,$transformer$jscomp$28$$,$method$jscomp$28$$,$options__$1$jscomp$30$$){var $self__$jscomp$1732$$=this;$this$$jscomp$394_this_transformer$jscomp$5$$=$malli$core$_value_transformer$$($transformer$jscomp$28$$,this,$method$jscomp$28$$,$options__$1$jscomp$30$$);var $__GT_children$jscomp$2_child_transformer$jscomp$2$$=$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$53$$,$k$jscomp$389$$,
$s$jscomp$317_t$jscomp$33$$){$s$jscomp$317_t$jscomp$33$$=$malli$core$_transformer$$($s$jscomp$317_t$jscomp$33$$,$transformer$jscomp$28$$,$method$jscomp$28$$,$options__$1$jscomp$30$$);return $APP.$cljs$core$truth_$$($s$jscomp$317_t$jscomp$33$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$53$$,$k$jscomp$389$$,$s$jscomp$317_t$jscomp$33$$):$acc$jscomp$53$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$_deref$$($self__$jscomp$1732$$.$dispatch_map$)),$find$jscomp$1$$=
$self__$jscomp$1732$$.$finder$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$1732$$.$finder$.$cljs$core$IFn$_invoke$arity$1$($__GT_children$jscomp$2_child_transformer$jscomp$2$$):$self__$jscomp$1732$$.$finder$($__GT_children$jscomp$2_child_transformer$jscomp$2$$);$__GT_children$jscomp$2_child_transformer$jscomp$2$$=$APP.$cljs$core$seq$$($__GT_children$jscomp$2_child_transformer$jscomp$2$$)?function($x$jscomp$771$$){var $G__33708$jscomp$inline_3557_temp__5827__auto__$jscomp$12$$=$self__$jscomp$1732$$.$dispatch$.$cljs$core$IFn$_invoke$arity$1$?
$self__$jscomp$1732$$.$dispatch$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$771$$):$self__$jscomp$1732$$.$dispatch$($x$jscomp$771$$);$G__33708$jscomp$inline_3557_temp__5827__auto__$jscomp$12$$=$find$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$find$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__33708$jscomp$inline_3557_temp__5827__auto__$jscomp$12$$):$find$jscomp$1$$($G__33708$jscomp$inline_3557_temp__5827__auto__$jscomp$12$$);return $G__33708$jscomp$inline_3557_temp__5827__auto__$jscomp$12$$==null?
$x$jscomp$771$$:$G__33708$jscomp$inline_3557_temp__5827__auto__$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$G__33708$jscomp$inline_3557_temp__5827__auto__$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$771$$):$G__33708$jscomp$inline_3557_temp__5827__auto__$jscomp$12$$($x$jscomp$771$$)}:null;return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$02$$($this$$jscomp$394_this_transformer$jscomp$5$$,$__GT_children$jscomp$2_child_transformer$jscomp$2$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$395$$,$walker$jscomp$21$$,$path$jscomp$76$$,$options__$1$jscomp$31$$){return $malli$core$_walk_entries$$(this,$walker$jscomp$21$$,$path$jscomp$76$$,$options__$1$jscomp$31$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return $malli$core$_entry_children$$(this.$entry_parser$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$396$$,$path$jscomp$77$$){var $self__$jscomp$1738$$=this,$this$__$1$jscomp$137$$=this,$find$jscomp$3$$=function(){var $G__33712$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$55$$,$p__33713_s$jscomp$320$$){var $k$jscomp$392$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33713_s$jscomp$320$$,0,null);$p__33713_s$jscomp$320$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33713_s$jscomp$320$$,
1,null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$55$$,$k$jscomp$392$$,$malli$core$_explainer$$($p__33713_s$jscomp$320$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$77$$,$k$jscomp$392$$)))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$this$__$1$jscomp$137$$.$malli$core$EntrySchema$_entries$arity$1$(null));return $self__$jscomp$1738$$.$finder$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$1738$$.$finder$.$cljs$core$IFn$_invoke$arity$1$($G__33712$$):
$self__$jscomp$1738$$.$finder$($G__33712$$)}();return function($x$jscomp$774$$,$in$$jscomp$28$$,$acc$jscomp$56$$){var $__GT_path_temp__5823__auto__$jscomp$59$$=function(){var $G__33717$$=$self__$jscomp$1738$$.$dispatch$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$1738$$.$dispatch$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$774$$):$self__$jscomp$1738$$.$dispatch$($x$jscomp$774$$);return $find$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$find$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($G__33717$$):
$find$jscomp$3$$($G__33717$$)}();if($APP.$cljs$core$truth_$$($__GT_path_temp__5823__auto__$jscomp$59$$))return $__GT_path_temp__5823__auto__$jscomp$59$$.$cljs$core$IFn$_invoke$arity$3$?$__GT_path_temp__5823__auto__$jscomp$59$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$774$$,$in$$jscomp$28$$,$acc$jscomp$56$$):$__GT_path_temp__5823__auto__$jscomp$59$$($x$jscomp$774$$,$in$$jscomp$28$$,$acc$jscomp$56$$);$__GT_path_temp__5823__auto__$jscomp$59$$=$APP.$cljs$core$map_QMARK_$$($x$jscomp$774$$)&&$self__$jscomp$1738$$.$dispatch$ instanceof
$APP.$cljs$core$Keyword$$?function($p1__33642_SHARP_$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p1__33642_SHARP_$$,$self__$jscomp$1738$$.$dispatch$)}:$APP.$cljs$core$identity$$;return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$56$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$05$$($__GT_path_temp__5823__auto__$jscomp$59$$.$cljs$core$IFn$_invoke$arity$1$?$__GT_path_temp__5823__auto__$jscomp$59$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$77$$):
$__GT_path_temp__5823__auto__$jscomp$59$$($path$jscomp$77$$),$__GT_path_temp__5823__auto__$jscomp$59$$.$cljs$core$IFn$_invoke$arity$1$?$__GT_path_temp__5823__auto__$jscomp$59$$.$cljs$core$IFn$_invoke$arity$1$($in$$jscomp$28$$):$__GT_path_temp__5823__auto__$jscomp$59$$($in$$jscomp$28$$),$this$__$1$jscomp$137$$,$x$jscomp$774$$,$cljs$cst$523$malli_DOT_core_SLASH_invalid_dispatch_value$$))}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($this$$jscomp$397$$,$key$jscomp$223$$,$default$$jscomp$26$$){return $malli$core$_get_entries$$(this,$key$jscomp$223$$,$default$$jscomp$26$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$398$$,$key$jscomp$224$$,$value$jscomp$257$$){return $malli$core$_set_entries$$(this,$key$jscomp$224$$,$value$jscomp$257$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33658$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33660$$,$meta33659__$1$$){return new $malli$core$t_malli$0core33658$$(this.$opts$,$meta33659__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33659$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){var $or__5025__auto__$jscomp$112$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$(this.$opts$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$112$$)?$or__5025__auto__$jscomp$112$$:$cljs$cst$531$multi$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return $cljs$cst$415$type_properties$$.$cljs$core$IFn$_invoke$arity$1$(this.$opts$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($opts_SINGLEQUOTE_$jscomp$2_parent$jscomp$80$$,$properties$jscomp$61$$,$children$jscomp$70$$,$options$jscomp$198$$){var $parent__$1$jscomp$26$$=this;$opts_SINGLEQUOTE_$jscomp$2_parent$jscomp$80$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$opts$,$APP.$cljs$core$select_keys$$($properties$jscomp$61$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$372$lazy_refs$$],null))]));var $entry_parser$jscomp$11$$=$malli$core$_create_entry_parser$$($children$jscomp$70$$,$opts_SINGLEQUOTE_$jscomp$2_parent$jscomp$80$$,$options$jscomp$198$$),$form$jscomp$82$$=new $APP.$cljs$core$Delay$$(function(){return $malli$core$_create_entry_form$$($parent__$1$jscomp$26$$,$properties$jscomp$61$$,$entry_parser$jscomp$11$$,$options$jscomp$198$$)}),$cache$jscomp$52$$=$malli$core$_create_cache$$(),$dispatch$jscomp$2$$=
function(){var $G__33681$$=$cljs$cst$532$dispatch$$.$cljs$core$IFn$_invoke$arity$1$($properties$jscomp$61$$);return $malli$core$eval$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$core$eval$cljs$0core$0IFn$0_invoke$0arity$02$$($G__33681$$,$options$jscomp$198$$):$malli$core$eval$$($G__33681$$,$options$jscomp$198$$)}(),$dispatch_map$jscomp$2$$=new $APP.$cljs$core$Delay$$(function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$malli$core$_entry_entries$$($entry_parser$jscomp$11$$))});
$APP.$cljs$core$truth_$$($dispatch$jscomp$2$$)||$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$533$malli_DOT_core_SLASH_missing_property$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$302$key$$,$cljs$cst$532$dispatch$$],null));return new $malli$core$t_malli$0core33688$$($form$jscomp$82$$,$options$jscomp$198$$,$properties$jscomp$61$$,$children$jscomp$70$$,$entry_parser$jscomp$11$$,$parent__$1$jscomp$26$$,this.$meta33659$,$opts_SINGLEQUOTE_$jscomp$2_parent$jscomp$80$$,
$dispatch$jscomp$2$$,$cache$jscomp$52$$,function($p__33686$$){var $map__33687__$1$$=$APP.$cljs$core$__destructure_map$$($p__33686$$),$default$$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33687__$1$$,$cljs$cst$379$malli_DOT_core_SLASH_default$$);return function($x$jscomp$776$$){return $map__33687__$1$$.$cljs$core$IFn$_invoke$arity$2$?$map__33687__$1$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$776$$,$default$$jscomp$27$$):$map__33687__$1$$($x$jscomp$776$$,$default$$jscomp$27$$)}},
this.$opts$,$dispatch_map$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$399$$,$writer$jscomp$116$$,$opts__$1$jscomp$12$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$116$$,$opts__$1$jscomp$12$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33738$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RefSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$RefSchema$_ref$arity$1$=function(){return this.ref};$APP.$JSCompiler_prototypeAlias$$.$malli$core$RefSchema$_deref$arity$1$=function(){return this.rf.$cljs$core$IFn$_invoke$arity$0$?this.rf.$cljs$core$IFn$_invoke$arity$0$():this.rf()};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return $malli$core$_to_value_ast$$(this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$401$$,$writer$jscomp$117$$,$opts$jscomp$186$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$117$$,$opts$jscomp$186$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_op_QMARK_$arity$1$=function(){return!1};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_validator$arity$1$=function(){return $malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$534$malli_DOT_core_SLASH_potentially_recursive_seqex$$,this)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_explainer$arity$2$=function(){return $malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$534$malli_DOT_core_SLASH_potentially_recursive_seqex$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_transformer$arity$4$=function(){return $malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$534$malli_DOT_core_SLASH_potentially_recursive_seqex$$,this)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_min_max$arity$2$=function(){return $malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$534$malli_DOT_core_SLASH_potentially_recursive_seqex$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33739$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33740$jscomp$1$$,$meta33739__$1$$){return new $malli$core$t_malli$0core33738$$(this.form,this.options,this.$properties$,this.$p__33728$,this.children,this.$type_properties$,this.rf,this.parent,this.$p__33723$,this.ref,this.$map__33733$,this.$map__33724$,this.$__GT_parser$,this.$p__33729$,this.$vec__33730$,this.cache,this.$meta33726$,this.lazy,this.$allow_invalid_refs$,$meta33739__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){var $self__$jscomp$1767$$=this,$validator$jscomp$25$$=$malli$core$_memoize$$(function(){return $malli$core$_validator$$($self__$jscomp$1767$$.rf.$cljs$core$IFn$_invoke$arity$0$?$self__$jscomp$1767$$.rf.$cljs$core$IFn$_invoke$arity$0$():$self__$jscomp$1767$$.rf())});return function($x$jscomp$777$$){var $fexpr__33741$$=$validator$jscomp$25$$();return $fexpr__33741$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__33741$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$777$$):
$fexpr__33741$$($x$jscomp$777$$)}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$408_this_transformer$jscomp$6$$,$transformer$jscomp$29$$,$method$jscomp$29$$,$options__$1$jscomp$32$$){var $self__$jscomp$1769$$=this;$this$$jscomp$408_this_transformer$jscomp$6$$=$malli$core$_value_transformer$$($transformer$jscomp$29$$,this,$method$jscomp$29$$,$options__$1$jscomp$32$$);var $deref_transformer$$=$malli$core$_memoize$$(function(){return $malli$core$_transformer$$($self__$jscomp$1769$$.rf.$cljs$core$IFn$_invoke$arity$0$?
$self__$jscomp$1769$$.rf.$cljs$core$IFn$_invoke$arity$0$():$self__$jscomp$1769$$.rf(),$transformer$jscomp$29$$,$method$jscomp$29$$,$options__$1$jscomp$32$$)});return $malli$core$_intercepting$cljs$0core$0IFn$0_invoke$0arity$02$$($this$$jscomp$408_this_transformer$jscomp$6$$,function($x$jscomp$778$$){var $temp__5827__auto__$jscomp$15$$=$deref_transformer$$();return $temp__5827__auto__$jscomp$15$$==null?$x$jscomp$778$$:$temp__5827__auto__$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5827__auto__$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$778$$):
$temp__5827__auto__$jscomp$15$$($x$jscomp$778$$)})};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$409$$,$walker$jscomp$22$$,$path$jscomp$78$$,$options__$1$jscomp$33$$){function $accept$$(){return $malli$core$_inner$$($walker$jscomp$22$$,$self__$jscomp$1770$$.rf.$cljs$core$IFn$_invoke$arity$0$?$self__$jscomp$1770$$.rf.$cljs$core$IFn$_invoke$arity$0$():$self__$jscomp$1770$$.rf(),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$78$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[0,0],null)),$malli$core$_update$$($options__$1$jscomp$33$$,$cljs$cst$535$malli_DOT_core_SLASH_walked_refs$$,function($p1__33720_SHARP_$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($p1__33720_SHARP_$$)?$p1__33720_SHARP_$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,$self__$jscomp$1770$$.ref)}))}var $self__$jscomp$1770$$=this;return $APP.$cljs$core$truth_$$($malli$core$_accept$$($walker$jscomp$22$$,this,$path$jscomp$78$$,$options__$1$jscomp$33$$))?$APP.$cljs$core$not$$(function(){var $fexpr__33742$$=
$malli$core$_boolean_fn$$($cljs$cst$536$malli_DOT_core_SLASH_walk_refs$$.$cljs$core$IFn$_invoke$arity$2$($options__$1$jscomp$33$$,!1));return $fexpr__33742$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__33742$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$1770$$.ref):$fexpr__33742$$($self__$jscomp$1770$$.ref)}())||$APP.$cljs$core$contains_QMARK_$$($cljs$cst$535$malli_DOT_core_SLASH_walked_refs$$.$cljs$core$IFn$_invoke$arity$1$($options__$1$jscomp$33$$),$self__$jscomp$1770$$.ref)?$malli$core$_outer$$($walker$jscomp$22$$,
this,$path$jscomp$78$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$1770$$.ref],null),$options__$1$jscomp$33$$):$malli$core$_outer$$($walker$jscomp$22$$,this,$path$jscomp$78$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$accept$$()],null),$options__$1$jscomp$33$$):null};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($_$jscomp$546$$,$path$jscomp$79$$){var $self__$jscomp$1775$$=this,$explainer$jscomp$12$$=$malli$core$_memoize$$(function(){return $malli$core$_explainer$$($self__$jscomp$1775$$.rf.$cljs$core$IFn$_invoke$arity$0$?$self__$jscomp$1775$$.rf.$cljs$core$IFn$_invoke$arity$0$():$self__$jscomp$1775$$.rf(),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$79$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,0],null)))});return function($x$jscomp$779$$,$in$$jscomp$29$$,$acc$jscomp$58$$){var $fexpr__33743$$=$explainer$jscomp$12$$();return $fexpr__33743$$.$cljs$core$IFn$_invoke$arity$3$?$fexpr__33743$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$779$$,$in$$jscomp$29$$,$acc$jscomp$58$$):$fexpr__33743$$($x$jscomp$779$$,$in$$jscomp$29$$,$acc$jscomp$58$$)}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$549$$,$key$jscomp$225$$,$default$$jscomp$28$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$225$$,0)?$malli$core$_pointer$$(this.ref,this.rf.$cljs$core$IFn$_invoke$arity$0$?this.rf.$cljs$core$IFn$_invoke$arity$0$():this.rf(),this.options):$default$$jscomp$28$$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$410$$,$key$jscomp$226$$,$value$jscomp$258$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$226$$,0)?$malli$core$_set_children$$(this,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$value$jscomp$258$$],null)):$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$517$malli_DOT_core_SLASH_index_out_of_bounds$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$298$schema$$,this,$APP.$cljs$cst$302$key$$,$key$jscomp$226$$],null))};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33725$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33727$$,$meta33726__$1$$){return new $malli$core$t_malli$0core33725$$(this.$p__33723$,this.$map__33724$,this.lazy,this.$type_properties$,$meta33726__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33726$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $cljs$cst$550$ref$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return this.$type_properties$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($parent$jscomp$84$$,$properties$jscomp$64$$,$p__33728$jscomp$2$$,$p__33729$jscomp$2$$){var $self__$jscomp$1786$$=this,$ref$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33728$jscomp$2$$,0,null),$map__33733__$1$$=$APP.$cljs$core$__destructure_map$$($p__33729$jscomp$2$$),$allow_invalid_refs$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33733__$1$$,$cljs$cst$353$malli_DOT_core_SLASH_allow_invalid_refs$$),
$parent__$1$jscomp$28$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($cljs$cst$550$ref$$,$properties$jscomp$64$$,$p__33728$jscomp$2$$,1,1);$malli$core$_reference_QMARK_$$($ref$jscomp$5$$)||$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$551$malli_DOT_core_SLASH_invalid_ref$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$550$ref$$,$ref$jscomp$5$$],null));var $rf$jscomp$25$$=function(){var $or__5025__auto__$jscomp$114_or__5025__auto____$1$jscomp$18$$=
function(){var $and__5023__auto__$jscomp$88$$=$self__$jscomp$1786$$.lazy;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$88$$)?$malli$core$_memoize$$(function(){var $G__33734$$=$malli$registry$_schema$$($malli$core$_registry$cljs$0core$0IFn$0_invoke$0arity$01$$($map__33733__$1$$),$ref$jscomp$5$$);return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($G__33734$$,$map__33733__$1$$):$APP.$malli$core$schema$$($G__33734$$,$map__33733__$1$$)}):
$and__5023__auto__$jscomp$88$$}();if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$114_or__5025__auto____$1$jscomp$18$$))return $or__5025__auto__$jscomp$114_or__5025__auto____$1$jscomp$18$$;$or__5025__auto__$jscomp$114_or__5025__auto____$1$jscomp$18$$=function(){var $temp__5825__auto__$jscomp$62$$=$malli$registry$_schema$$($malli$core$_registry$cljs$0core$0IFn$0_invoke$0arity$01$$($map__33733__$1$$),$ref$jscomp$5$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$62$$)?$malli$core$_memoize$$(function(){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($temp__5825__auto__$jscomp$62$$,$map__33733__$1$$):$APP.$malli$core$schema$$($temp__5825__auto__$jscomp$62$$,$map__33733__$1$$)}):null}();return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$114_or__5025__auto____$1$jscomp$18$$)?$or__5025__auto__$jscomp$114_or__5025__auto____$1$jscomp$18$$:$APP.$cljs$core$truth_$$($allow_invalid_refs$jscomp$2$$)?null:$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$551$malli_DOT_core_SLASH_invalid_ref$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$550$ref$$,$cljs$cst$550$ref$$,$ref$jscomp$5$$],null))}(),$children__$1$jscomp$11$$=$APP.$cljs$core$vec$$($p__33728$jscomp$2$$);return new $malli$core$t_malli$0core33738$$(new $APP.$cljs$core$Delay$$(function(){return $malli$core$_simple_form$$($parent__$1$jscomp$28$$,$properties$jscomp$64$$,$children__$1$jscomp$11$$,$APP.$cljs$core$identity$$,$map__33733__$1$$)}),$map__33733__$1$$,$properties$jscomp$64$$,$p__33728$jscomp$2$$,
$children__$1$jscomp$11$$,$self__$jscomp$1786$$.$type_properties$,$rf$jscomp$25$$,$parent__$1$jscomp$28$$,$self__$jscomp$1786$$.$p__33723$,$ref$jscomp$5$$,$map__33733__$1$$,$self__$jscomp$1786$$.$map__33724$,function($f$jscomp$425$$){var $parser$jscomp$12$$=$malli$core$_memoize$$(function(){var $G__33736$$=$rf$jscomp$25$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$25$$.$cljs$core$IFn$_invoke$arity$0$():$rf$jscomp$25$$();return $f$jscomp$425$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$425$$.$cljs$core$IFn$_invoke$arity$1$($G__33736$$):
$f$jscomp$425$$($G__33736$$)});return function($x$jscomp$780$$){var $fexpr__33737$$=$parser$jscomp$12$$();return $fexpr__33737$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__33737$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$780$$):$fexpr__33737$$($x$jscomp$780$$)}},$p__33729$jscomp$2$$,$p__33728$jscomp$2$$,$malli$core$_create_cache$$(),$self__$jscomp$1786$$.$meta33726$,$self__$jscomp$1786$$.lazy,$allow_invalid_refs$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],
null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$411$$,$writer$jscomp$118$$,$opts$jscomp$187$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$118$$,$opts$jscomp$187$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33751$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$malli$core$RefSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$RefSchema$_ref$arity$1$=function(){return this.id};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RefSchema$_deref$arity$1$=function(){return this.$child$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return $APP.$cljs$core$truth_$$(this.id)?$malli$core$_ast$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,this.type,$APP.$cljs$cst$260$value$$,this.id],null),this.$properties$,this.$malli$core$Schema$_options$arity$1$(null)):$APP.$cljs$core$truth_$$(this.raw)?$malli$core$_to_value_ast$$(this):$malli$core$_to_child_ast$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$413$$,$writer$jscomp$119$$,$opts$jscomp$188$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$119$$,$opts$jscomp$188$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_op_QMARK_$arity$1$=function(){return $APP.$cljs$core$truth_$$(this.$internal$)?$malli$core$_regex_op_QMARK_$$(this.$child$):!1};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_validator$arity$1$=function(){return $APP.$cljs$core$truth_$$(this.$internal$)?$malli$core$_regex_validator$$(this.$child$):$malli$impl$regex$item_validator$$($malli$core$_validator$$(this.$child$))};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_explainer$arity$2$=function($_$jscomp$558$$,$path$jscomp$80$$){return $APP.$cljs$core$truth_$$(this.$internal$)?$malli$core$_regex_explainer$$(this.$child$,$path$jscomp$80$$):$malli$impl$regex$item_explainer$$($path$jscomp$80$$,this.$child$,$malli$core$_explainer$$(this.$child$,$path$jscomp$80$$))};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_transformer$arity$4$=function($JSCompiler_temp_const$jscomp$418__$jscomp$561$$,$or__5025__auto__$jscomp$inline_3559_transformer$jscomp$30$$,$JSCompiler_temp$jscomp$417_method$jscomp$30$$,$options__$1$jscomp$34$$){$APP.$cljs$core$truth_$$(this.$internal$)?$JSCompiler_temp$jscomp$417_method$jscomp$30$$=$malli$core$_regex_transformer$$(this.$child$,$or__5025__auto__$jscomp$inline_3559_transformer$jscomp$30$$,$JSCompiler_temp$jscomp$417_method$jscomp$30$$,
$options__$1$jscomp$34$$):($JSCompiler_temp_const$jscomp$418__$jscomp$561$$=$malli$core$_validator$$(this.$child$),$or__5025__auto__$jscomp$inline_3559_transformer$jscomp$30$$=$malli$core$_transformer$$(this.$child$,$or__5025__auto__$jscomp$inline_3559_transformer$jscomp$30$$,$JSCompiler_temp$jscomp$417_method$jscomp$30$$,$options__$1$jscomp$34$$),$JSCompiler_temp$jscomp$417_method$jscomp$30$$=$malli$impl$regex$item_transformer$$($JSCompiler_temp$jscomp$417_method$jscomp$30$$,$JSCompiler_temp_const$jscomp$418__$jscomp$561$$,
$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_3559_transformer$jscomp$30$$)?$or__5025__auto__$jscomp$inline_3559_transformer$jscomp$30$$:$APP.$cljs$core$identity$$));return $JSCompiler_temp$jscomp$417_method$jscomp$30$$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_min_max$arity$2$=function($_$jscomp$562$$,$nested_QMARK_$jscomp$2$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($nested_QMARK_$jscomp$2$$)?$APP.$cljs$core$not$$(this.$internal$):$nested_QMARK_$jscomp$2$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,1],null):$malli$core$_regex_min_max$$(this.$child$,$nested_QMARK_$jscomp$2$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33752$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33753$jscomp$1$$,$meta33752__$1$$){return new $malli$core$t_malli$0core33751$$(this.form,this.options,this.$child$,this.$properties$,this.$meta33748$,this.children,this.parent,this.raw,this.$map__33746$,this.type,this.$internal$,this.cache,this.id,this.$p__33745$,$meta33752__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){return $malli$core$_validator$$(this.$child$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$414$$,$transformer$jscomp$31$$,$method$jscomp$31$$,$options__$1$jscomp$35$$){return $malli$core$_parent_children_transformer$$(this,this.children,$transformer$jscomp$31$$,$method$jscomp$31$$,$options__$1$jscomp$35$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($JSCompiler_inline_result$jscomp$421_fexpr__33754$jscomp$inline_3562_or__5025__auto__$jscomp$inline_3561_this$$jscomp$415$$,$JSCompiler_temp$jscomp$420_walker$jscomp$23$$,$path$jscomp$81$$,$options__$1$jscomp$36$$){$APP.$cljs$core$truth_$$($malli$core$_accept$$($JSCompiler_temp$jscomp$420_walker$jscomp$23$$,this,$path$jscomp$81$$,$options__$1$jscomp$36$$))?($JSCompiler_inline_result$jscomp$421_fexpr__33754$jscomp$inline_3562_or__5025__auto__$jscomp$inline_3561_this$$jscomp$415$$=
$APP.$cljs$core$not$$(this.id),$JSCompiler_inline_result$jscomp$421_fexpr__33754$jscomp$inline_3562_or__5025__auto__$jscomp$inline_3561_this$$jscomp$415$$||($JSCompiler_inline_result$jscomp$421_fexpr__33754$jscomp$inline_3562_or__5025__auto__$jscomp$inline_3561_this$$jscomp$415$$=$malli$core$_boolean_fn$$($cljs$cst$552$malli_DOT_core_SLASH_walk_schema_refs$$.$cljs$core$IFn$_invoke$arity$2$($options__$1$jscomp$36$$,!1)),$JSCompiler_inline_result$jscomp$421_fexpr__33754$jscomp$inline_3562_or__5025__auto__$jscomp$inline_3561_this$$jscomp$415$$=
$JSCompiler_inline_result$jscomp$421_fexpr__33754$jscomp$inline_3562_or__5025__auto__$jscomp$inline_3561_this$$jscomp$415$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$421_fexpr__33754$jscomp$inline_3562_or__5025__auto__$jscomp$inline_3561_this$$jscomp$415$$.$cljs$core$IFn$_invoke$arity$1$(this.id):$JSCompiler_inline_result$jscomp$421_fexpr__33754$jscomp$inline_3562_or__5025__auto__$jscomp$inline_3561_this$$jscomp$415$$(this.id)),$JSCompiler_temp$jscomp$420_walker$jscomp$23$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$421_fexpr__33754$jscomp$inline_3562_or__5025__auto__$jscomp$inline_3561_this$$jscomp$415$$)?$malli$core$_outer$$($JSCompiler_temp$jscomp$420_walker$jscomp$23$$,this,$path$jscomp$81$$,$malli$core$_inner_indexed$$($JSCompiler_temp$jscomp$420_walker$jscomp$23$$,$path$jscomp$81$$,this.children,$options__$1$jscomp$36$$),$options__$1$jscomp$36$$):$malli$core$_outer$$($JSCompiler_temp$jscomp$420_walker$jscomp$23$$,this,$path$jscomp$81$$,this.children,
$options__$1$jscomp$36$$)):$JSCompiler_temp$jscomp$420_walker$jscomp$23$$=null;return $JSCompiler_temp$jscomp$420_walker$jscomp$23$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($_$jscomp$570$$,$path$jscomp$82$$){return $malli$core$_explainer$$(this.$child$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$82$$,0))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$574$$,$key$jscomp$227$$,$default$$jscomp$29$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$227$$,0)?this.$child$:$default$$jscomp$29$$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$416$$,$key$jscomp$228$$,$value$jscomp$259$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$228$$,0)?$malli$core$_set_children$$(this,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$value$jscomp$259$$],null)):$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$517$malli_DOT_core_SLASH_index_out_of_bounds$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$298$schema$$,this,$APP.$cljs$cst$302$key$$,$key$jscomp$228$$],null))};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33747$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33749$$,$meta33748__$1$$){return new $malli$core$t_malli$0core33747$$(this.$p__33745$,this.$map__33746$,this.id,this.raw,this.$internal$,this.type,$meta33748__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33748$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return this.type};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($parent$jscomp$88$$,$properties$jscomp$67$$,$children$jscomp$76$$,$options$jscomp$206$$){var $self__$jscomp$1823$$=this,$parent__$1$jscomp$30$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($self__$jscomp$1823$$.type,$properties$jscomp$67$$,$children$jscomp$76$$,1,1);var $children__$1$jscomp$12$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__33744_SHARP_$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($p1__33744_SHARP_$$,$options$jscomp$206$$):$APP.$malli$core$schema$$($p1__33744_SHARP_$$,$options$jscomp$206$$)},$children$jscomp$76$$),$child$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($children__$1$jscomp$12$$,0);return new $malli$core$t_malli$0core33751$$(new $APP.$cljs$core$Delay$$(function(){var $or__5025__auto__$jscomp$117$$=function(){var $and__5023__auto__$jscomp$90_and__5023__auto____$1$jscomp$23_or__5025__auto__$jscomp$118$$=
$APP.$cljs$core$empty_QMARK_$$($properties$jscomp$67$$);if($and__5023__auto__$jscomp$90_and__5023__auto____$1$jscomp$23_or__5025__auto__$jscomp$118$$){$and__5023__auto__$jscomp$90_and__5023__auto____$1$jscomp$23_or__5025__auto__$jscomp$118$$=$self__$jscomp$1823$$.id;if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$90_and__5023__auto____$1$jscomp$23_or__5025__auto__$jscomp$118$$))return $and__5023__auto__$jscomp$90_and__5023__auto____$1$jscomp$23_or__5025__auto__$jscomp$118$$;$and__5023__auto__$jscomp$90_and__5023__auto____$1$jscomp$23_or__5025__auto__$jscomp$118$$=
$self__$jscomp$1823$$.raw;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$90_and__5023__auto____$1$jscomp$23_or__5025__auto__$jscomp$118$$)?$malli$core$_form$$($child$jscomp$11$$):$and__5023__auto__$jscomp$90_and__5023__auto____$1$jscomp$23_or__5025__auto__$jscomp$118$$}return $and__5023__auto__$jscomp$90_and__5023__auto____$1$jscomp$23_or__5025__auto__$jscomp$118$$}();return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$117$$)?$or__5025__auto__$jscomp$117$$:$malli$core$_simple_form$$($parent__$1$jscomp$30$$,
$properties$jscomp$67$$,$children__$1$jscomp$12$$,$malli$core$_form$$,$options$jscomp$206$$)}),$options$jscomp$206$$,$child$jscomp$11$$,$properties$jscomp$67$$,$self__$jscomp$1823$$.$meta33748$,$children__$1$jscomp$12$$,$parent__$1$jscomp$30$$,$self__$jscomp$1823$$.raw,$self__$jscomp$1823$$.$map__33746$,$self__$jscomp$1823$$.type,$self__$jscomp$1823$$.$internal$,$malli$core$_create_cache$$(),$self__$jscomp$1823$$.id,$self__$jscomp$1823$$.$p__33745$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,
[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$417$$,$writer$jscomp$120$$,$opts$jscomp$189$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$120$$,$opts$jscomp$189$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33772$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33774$$,$meta33773__$1$$){return new $malli$core$t_malli$0core33772$$(this.form,this.input,this.options,this.$guard$,this.$p__33765$,this.$properties$,this.children,this.$map__33766$,this.parent,this.$meta33760$,this.$vec__33767$,this.$__GT_checker$,this.output,this.$function_checker$,this.cache,$meta33773__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33773$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){var $G__33775_G__33775__$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$562$_EQ__GT_$$,$cljs$cst$563$input$$,$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$?$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$(this.input):$malli$core$ast$$(this.input),$cljs$cst$564$output$$,$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$?$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$(this.output):
$malli$core$ast$$(this.output)],null);$G__33775_G__33775__$1$$=$APP.$cljs$core$truth_$$(this.$guard$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__33775_G__33775__$1$$,$cljs$cst$565$guard$$,$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$?$malli$core$ast$cljs$0core$0IFn$0_invoke$0arity$01$$(this.$guard$):$malli$core$ast$$(this.$guard$)):$G__33775_G__33775__$1$$;return $APP.$cljs$core$truth_$$(this.$properties$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__33775_G__33775__$1$$,
$cljs$cst$341$properties$$,this.$properties$):$G__33775_G__33775__$1$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){var $temp__5823__auto__$jscomp$60$$=this.$__GT_checker$.$cljs$core$IFn$_invoke$arity$1$?this.$__GT_checker$.$cljs$core$IFn$_invoke$arity$1$(this):this.$__GT_checker$(this);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$60$$)?function($x$jscomp$782$$){var $JSCompiler_temp$jscomp$422$$;if($JSCompiler_temp$jscomp$422$$=$cljs$core$ifn_QMARK_$$($x$jscomp$782$$))$JSCompiler_temp$jscomp$422$$=($temp__5823__auto__$jscomp$60$$.$cljs$core$IFn$_invoke$arity$1$?
$temp__5823__auto__$jscomp$60$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$782$$):$temp__5823__auto__$jscomp$60$$($x$jscomp$782$$))==null;return $JSCompiler_temp$jscomp$422$$}:$cljs$core$ifn_QMARK_$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$419$$,$walker$jscomp$24$$,$path$jscomp$83$$,$options__$1$jscomp$37$$){return $malli$core$_walk_indexed$$(this,$walker$jscomp$24$$,$path$jscomp$83$$,$options__$1$jscomp$37$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$421$$,$path$jscomp$84$$){var $this$__$1$jscomp$162$$=this,$temp__5823__auto__$jscomp$61$$=this.$__GT_checker$.$cljs$core$IFn$_invoke$arity$1$?this.$__GT_checker$.$cljs$core$IFn$_invoke$arity$1$($this$__$1$jscomp$162$$):this.$__GT_checker$($this$__$1$jscomp$162$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$61$$))return function($map__33777_map__33777__$1_x$jscomp$784$$,$_push_in$$jscomp$30$$,
$acc$jscomp$59$$){if($APP.$cljs$core$fn_QMARK_$$($map__33777_map__33777__$1_x$jscomp$784$$)){var $res__$1_temp__5823__auto____$1$jscomp$7$$=$temp__5823__auto__$jscomp$61$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5823__auto__$jscomp$61$$.$cljs$core$IFn$_invoke$arity$1$($map__33777_map__33777__$1_x$jscomp$784$$):$temp__5823__auto__$jscomp$61$$($map__33777_map__33777__$1_x$jscomp$784$$);if($APP.$cljs$core$truth_$$($res__$1_temp__5823__auto____$1$jscomp$7$$)){var $explain_guard_map__33776__$1$$=$APP.$cljs$core$__destructure_map$$($res__$1_temp__5823__auto____$1$jscomp$7$$),
$explain_input$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($explain_guard_map__33776__$1$$,$cljs$cst$566$malli_DOT_core_SLASH_explain_input$$),$explain_output$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($explain_guard_map__33776__$1$$,$cljs$cst$567$malli_DOT_core_SLASH_explain_output$$);$explain_guard_map__33776__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($explain_guard_map__33776__$1$$,$cljs$cst$568$malli_DOT_core_SLASH_explain_guard$$);$res__$1_temp__5823__auto____$1$jscomp$7$$=
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($res__$1_temp__5823__auto____$1$jscomp$7$$,$cljs$cst$566$malli_DOT_core_SLASH_explain_input$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$567$malli_DOT_core_SLASH_explain_output$$,$cljs$cst$568$malli_DOT_core_SLASH_explain_guard$$]));$map__33777_map__33777__$1_x$jscomp$784$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$04$$($path$jscomp$84$$,
$_push_in$$jscomp$30$$,$this$__$1$jscomp$162$$,$map__33777_map__33777__$1_x$jscomp$784$$),$cljs$cst$569$check$$,$res__$1_temp__5823__auto____$1$jscomp$7$$);$map__33777_map__33777__$1_x$jscomp$784$$=$APP.$cljs$core$__destructure_map$$($map__33777_map__33777__$1_x$jscomp$784$$);var $path__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33777_map__33777__$1_x$jscomp$784$$,$APP.$cljs$cst$296$path$$),$in$__$1$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33777_map__33777__$1_x$jscomp$784$$,
$APP.$cljs$cst$297$in$$);$_push_in$$jscomp$30$$=function($acc__$1$jscomp$7$$,$i$jscomp$324$$,$e$jscomp$166$$){return $APP.$cljs$core$truth_$$($e$jscomp$166$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($acc__$1$jscomp$7$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__33757_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__33757_SHARP_$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path__$1$$,
$i$jscomp$324$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$297$in$$,$in$__$1$jscomp$2$$]))},$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$166$$))):$acc__$1$jscomp$7$$};return $_push_in$$jscomp$30$$($_push_in$$jscomp$30$$($_push_in$$jscomp$30$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$59$$,$map__33777_map__33777__$1_x$jscomp$784$$),0,$explain_input$$),1,$explain_output$$),2,$explain_guard_map__33776__$1$$)}return $acc$jscomp$59$$}return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$59$$,
$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$04$$($path$jscomp$84$$,$_push_in$$jscomp$30$$,$this$__$1$jscomp$162$$,$map__33777_map__33777__$1_x$jscomp$784$$))};var $validator$jscomp$28$$=$this$__$1$jscomp$162$$.$malli$core$Schema$_validator$arity$1$(null);return function($x$jscomp$785$$,$in$$jscomp$31$$,$acc$jscomp$60$$){return $APP.$cljs$core$not$$($validator$jscomp$28$$.$cljs$core$IFn$_invoke$arity$1$?$validator$jscomp$28$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$785$$):$validator$jscomp$28$$($x$jscomp$785$$))?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$60$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$04$$($path$jscomp$84$$,$in$$jscomp$31$$,$this$__$1$jscomp$162$$,$x$jscomp$785$$)):$acc$jscomp$60$$}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};$APP.$JSCompiler_prototypeAlias$$.$malli$core$FunctionSchema$_function_schema_QMARK_$arity$1$=function(){return!0};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$FunctionSchema$_function_info$arity$1$=function(){var $map__33779_map__33779__$1_max$jscomp$23$$=$malli$core$_regex_min_max$$(this.input,!1);$map__33779_map__33779__$1_max$jscomp$23$$=$APP.$cljs$core$__destructure_map$$($map__33779_map__33779__$1_max$jscomp$23$$);var $G__33780_G__33780__$1_min$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33779_map__33779__$1_max$jscomp$23$$,$APP.$cljs$cst$338$min$$);$map__33779_map__33779__$1_max$jscomp$23$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33779_map__33779__$1_max$jscomp$23$$,$APP.$cljs$cst$339$max$$);$G__33780_G__33780__$1_min$jscomp$23$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$338$min$$,$G__33780_G__33780__$1_min$jscomp$23$$,$cljs$cst$346$arity$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__33780_G__33780__$1_min$jscomp$23$$,$map__33779_map__33779__$1_max$jscomp$23$$)?$G__33780_G__33780__$1_min$jscomp$23$$:$cljs$cst$347$varargs$$,$cljs$cst$563$input$$,
this.input,$cljs$cst$564$output$$,this.output],null);$G__33780_G__33780__$1_min$jscomp$23$$=$APP.$cljs$core$truth_$$(this.$guard$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__33780_G__33780__$1_min$jscomp$23$$,$cljs$cst$565$guard$$,this.$guard$):$G__33780_G__33780__$1_min$jscomp$23$$;return $APP.$cljs$core$truth_$$($map__33779_map__33779__$1_max$jscomp$23$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__33780_G__33780__$1_min$jscomp$23$$,$APP.$cljs$cst$339$max$$,$map__33779_map__33779__$1_max$jscomp$23$$):
$G__33780_G__33780__$1_min$jscomp$23$$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$FunctionSchema$_instrument_f$arity$4$=function($map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$,$p__33781$$,$f$jscomp$426$$){var $map__33782__$1$$=$APP.$cljs$core$__destructure_map$$($p__33781$$),$scope$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33782__$1$$,$APP.$cljs$cst$571$scope$$),$report$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33782__$1$$,$APP.$cljs$cst$572$report$$),$gen$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33782__$1$$,
$cljs$cst$573$gen$$),$schema__$1$$=this;$map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$=$schema__$1$$.$malli$core$FunctionSchema$_function_info$arity$1$(null);$map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$=$APP.$cljs$core$__destructure_map$$($map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$);var $min$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$,$APP.$cljs$cst$338$min$$),
$max$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$,$APP.$cljs$cst$339$max$$),$input__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$,$cljs$cst$563$input$$),$output__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$,$cljs$cst$564$output$$),$guard__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$,
$cljs$cst$565$guard$$);$map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$core$_validator$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$input__$1$$,$output__$1$$],null));var $validate_input$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$,0,null),$validate_output$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$,
1,null),$validate_guard$$=function(){var $or__5025__auto__$jscomp$120$$=$guard__$1$$==null?null:$malli$core$_validator$$($guard__$1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$120$$)?$or__5025__auto__$jscomp$120$$:$APP.$cljs$core$any_QMARK_$$}();$map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__33758_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($scope$$,$p1__33758_SHARP_$$)},new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$563$input$$,$cljs$cst$564$output$$,$cljs$cst$565$guard$$],null));var $wrap_input$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$,0,null),$wrap_output$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$,1,null),$wrap_guard$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__33783_map__33783__$1_schema$jscomp$50_vec__33784_vec__33787$$,
2,null),$f__$1$jscomp$19$$=function(){var $or__5025__auto__$jscomp$121$$=$APP.$cljs$core$truth_$$($gen$$)?$gen$$.$cljs$core$IFn$_invoke$arity$1$?$gen$$.$cljs$core$IFn$_invoke$arity$1$($schema__$1$$):$gen$$($schema__$1$$):$f$jscomp$426$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$121$$)?$or__5025__auto__$jscomp$121$$:$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$574$malli_DOT_core_SLASH_missing_function$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$575$props$$,
$map__33782__$1$$],null))}();return function(){function $G__35619$$($var_args$jscomp$451$$){var $G__35634__i_args$jscomp$131$$=null;if(arguments.length>0){$G__35634__i_args$jscomp$131$$=0;for(var $G__35634__a$$=Array(arguments.length-0);$G__35634__i_args$jscomp$131$$<$G__35634__a$$.length;)$G__35634__a$$[$G__35634__i_args$jscomp$131$$]=arguments[$G__35634__i_args$jscomp$131$$+0],++$G__35634__i_args$jscomp$131$$;$G__35634__i_args$jscomp$131$$=new $APP.$cljs$core$IndexedSeq$$($G__35634__a$$,0,null)}return $G__35619__delegate$$.call(this,
$G__35634__i_args$jscomp$131$$)}function $G__35619__delegate$$($G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$){$G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$=$APP.$cljs$core$vec$$($G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$);var $G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$=$APP.$cljs$core$count$$($G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$);$APP.$cljs$core$truth_$$($wrap_input$$)&&($min$jscomp$24$$<=$G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$&&
$G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$<=($APP.$cljs$core$truth_$$($max$jscomp$24$$)?$max$jscomp$24$$:$malli$impl$util$_PLUS_max_size_PLUS_$$)||($G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$346$arity$$,$G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$,$cljs$cst$577$arities$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,
$min$jscomp$24$$,$APP.$cljs$cst$339$max$$,$max$jscomp$24$$],null)]),$cljs$cst$578$args$$,$G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$,$cljs$cst$563$input$$,$input__$1$$,$APP.$cljs$cst$298$schema$$,$schema__$1$$],null),$report$$.$cljs$core$IFn$_invoke$arity$2$?$report$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$576$malli_DOT_core_SLASH_invalid_arity$$,$G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$):$report$$($cljs$cst$576$malli_DOT_core_SLASH_invalid_arity$$,$G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$)),
$APP.$cljs$core$truth_$$($validate_input$$.$cljs$core$IFn$_invoke$arity$1$?$validate_input$$.$cljs$core$IFn$_invoke$arity$1$($G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$):$validate_input$$($G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$))||($G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$563$input$$,$input__$1$$,$cljs$cst$578$args$$,$G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$,$APP.$cljs$cst$298$schema$$,
$schema__$1$$],null),$report$$.$cljs$core$IFn$_invoke$arity$2$?$report$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$579$malli_DOT_core_SLASH_invalid_input$$,$G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$):$report$$($cljs$cst$579$malli_DOT_core_SLASH_invalid_input$$,$G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$)));$G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($f__$1$jscomp$19$$,$G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$);
if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($wrap_output$$)?$APP.$cljs$core$not$$($validate_output$$.$cljs$core$IFn$_invoke$arity$1$?$validate_output$$.$cljs$core$IFn$_invoke$arity$1$($G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$):$validate_output$$($G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$)):$wrap_output$$)){var $G__33796_35628_G__33797$jscomp$inline_11430_JSCompiler_inline_result$jscomp$inline_11429_JSCompiler_temp$jscomp$inline_11428$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$cljs$cst$564$output$$,$output__$1$$,$APP.$cljs$cst$260$value$$,$G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$,$cljs$cst$578$args$$,$G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$,$APP.$cljs$cst$298$schema$$,$schema__$1$$],null);$report$$.$cljs$core$IFn$_invoke$arity$2$?$report$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$580$malli_DOT_core_SLASH_invalid_output$$,$G__33796_35628_G__33797$jscomp$inline_11430_JSCompiler_inline_result$jscomp$inline_11429_JSCompiler_temp$jscomp$inline_11428$$):
$report$$($cljs$cst$580$malli_DOT_core_SLASH_invalid_output$$,$G__33796_35628_G__33797$jscomp$inline_11430_JSCompiler_inline_result$jscomp$inline_11429_JSCompiler_temp$jscomp$inline_11428$$)}$APP.$cljs$core$truth_$$($wrap_guard$$)?($G__33796_35628_G__33797$jscomp$inline_11430_JSCompiler_inline_result$jscomp$inline_11429_JSCompiler_temp$jscomp$inline_11428$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$,
$G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$],null),$G__33796_35628_G__33797$jscomp$inline_11430_JSCompiler_inline_result$jscomp$inline_11429_JSCompiler_temp$jscomp$inline_11428$$=$validate_guard$$.$cljs$core$IFn$_invoke$arity$1$?$validate_guard$$.$cljs$core$IFn$_invoke$arity$1$($G__33796_35628_G__33797$jscomp$inline_11430_JSCompiler_inline_result$jscomp$inline_11429_JSCompiler_temp$jscomp$inline_11428$$):$validate_guard$$($G__33796_35628_G__33797$jscomp$inline_11430_JSCompiler_inline_result$jscomp$inline_11429_JSCompiler_temp$jscomp$inline_11428$$),
$G__33796_35628_G__33797$jscomp$inline_11430_JSCompiler_inline_result$jscomp$inline_11429_JSCompiler_temp$jscomp$inline_11428$$=$APP.$cljs$core$not$$($G__33796_35628_G__33797$jscomp$inline_11430_JSCompiler_inline_result$jscomp$inline_11429_JSCompiler_temp$jscomp$inline_11428$$)):$G__33796_35628_G__33797$jscomp$inline_11430_JSCompiler_inline_result$jscomp$inline_11429_JSCompiler_temp$jscomp$inline_11428$$=$wrap_guard$$;$APP.$cljs$core$truth_$$($G__33796_35628_G__33797$jscomp$inline_11430_JSCompiler_inline_result$jscomp$inline_11429_JSCompiler_temp$jscomp$inline_11428$$)&&
($G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$565$guard$$,$guard__$1$$,$APP.$cljs$cst$260$value$$,$G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$,$cljs$cst$578$args$$,$G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$,$APP.$cljs$cst$298$schema$$,$schema__$1$$],null),$report$$.$cljs$core$IFn$_invoke$arity$2$?$report$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$581$malli_DOT_core_SLASH_invalid_guard$$,$G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$):
$report$$($cljs$cst$581$malli_DOT_core_SLASH_invalid_guard$$,$G__33799_35632_args$jscomp$130_args__$1$jscomp$3$$));return $G__33792_35622_G__33794_35625_arity$jscomp$1_value$jscomp$260$$}$G__35619$$.$cljs$lang$maxFixedArity$=0;$G__35619$$.$cljs$lang$applyTo$=function($arglist__35635_args$jscomp$132$$){$arglist__35635_args$jscomp$132$$=$APP.$cljs$core$seq$$($arglist__35635_args$jscomp$132$$);return $G__35619__delegate$$($arglist__35635_args$jscomp$132$$)};$G__35619$$.$cljs$core$IFn$_invoke$arity$variadic$=
$G__35619__delegate$$;return $G__35619$$}()};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$590$$,$key$jscomp$229$$,$default$$jscomp$30$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.children,$key$jscomp$229$$,$default$$jscomp$30$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$424$$,$key$jscomp$230$$,$value$jscomp$261$$){return $malli$core$_set_assoc_children$$(this,$key$jscomp$230$$,$value$jscomp$261$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$425$$,$writer$jscomp$121$$,$opts$jscomp$190$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$121$$,$opts$jscomp$190$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33759$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33761$$,$meta33760__$1$$){return new $malli$core$t_malli$0core33759$$($meta33760__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33760$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $cljs$cst$562$_EQ__GT_$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($output$jscomp$5_parent$jscomp$92$$,$properties$jscomp$71$$,$children$jscomp$79_guard$jscomp$3$$,$p__33765$jscomp$2$$){var $map__33766__$1$$=$APP.$cljs$core$__destructure_map$$($p__33765$jscomp$2$$),$function_checker$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33766__$1$$,$cljs$cst$593$malli_DOT_core_SLASH_function_checker$$),$parent__$1$jscomp$32$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($cljs$cst$562$_EQ__GT_$$,
$properties$jscomp$71$$,$children$jscomp$79_guard$jscomp$3$$,2,3);var $vec__33767$jscomp$2$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__33755_SHARP_$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($p1__33755_SHARP_$$,$map__33766__$1$$):$APP.$malli$core$schema$$($p1__33755_SHARP_$$,$map__33766__$1$$)},$children$jscomp$79_guard$jscomp$3$$),$input$jscomp$53$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33767$jscomp$2$$,
0,null);$output$jscomp$5_parent$jscomp$92$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33767$jscomp$2$$,1,null);$children$jscomp$79_guard$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33767$jscomp$2$$,2,null);var $form$jscomp$91$$=new $APP.$cljs$core$Delay$$(function(){return $malli$core$_create_form$$($parent__$1$jscomp$32$$.$malli$core$IntoSchema$_type$arity$1$(null),$properties$jscomp$71$$,$malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$core$_form$$,
$vec__33767$jscomp$2$$),$map__33766__$1$$)}),$cache$jscomp$61$$=$malli$core$_create_cache$$(),$__GT_checker$jscomp$2$$=$APP.$cljs$core$truth_$$($function_checker$jscomp$2$$)?function($p1__33756_SHARP_$$){return $function_checker$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$function_checker$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($p1__33756_SHARP_$$,$map__33766__$1$$):$function_checker$jscomp$2$$($p1__33756_SHARP_$$,$map__33766__$1$$)}:$APP.$cljs$core$constantly$$(null);$APP.$cljs$core$truth_$$(function(){var $G__33771$$=
$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($input$jscomp$53$$):$APP.$malli$core$type$$($input$jscomp$53$$),$fexpr__33770$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$594$cat$$,null,$cljs$cst$595$catn$$,null],null),null);return $fexpr__33770$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__33770$$.$cljs$core$IFn$_invoke$arity$1$($G__33771$$):$fexpr__33770$$($G__33771$$)}())||
$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$596$malli_DOT_core_SLASH_invalid_input_schema$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$563$input$$,$input$jscomp$53$$],null));return new $malli$core$t_malli$0core33772$$($form$jscomp$91$$,$input$jscomp$53$$,$map__33766__$1$$,$children$jscomp$79_guard$jscomp$3$$,$p__33765$jscomp$2$$,$properties$jscomp$71$$,$vec__33767$jscomp$2$$,$map__33766__$1$$,$parent__$1$jscomp$32$$,this.$meta33760$,$vec__33767$jscomp$2$$,$__GT_checker$jscomp$2$$,
$output$jscomp$5_parent$jscomp$92$$,$function_checker$jscomp$2$$,$cache$jscomp$61$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$426$$,$writer$jscomp$122$$,$opts$jscomp$191$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$122$$,$opts$jscomp$191$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33807$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33809$$,$meta33808__$1$$){return new $malli$core$t_malli$0core33807$$(this.form,this.options,this.$meta33803$,this.$p__33805$,this.$properties$,this.children,this.parent,this.$_$,this.$map__33806$,this.$__GT_checker$,this.$function_checker$,this.cache,$meta33808__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33808$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){var $temp__5823__auto__$jscomp$62$$=this.$__GT_checker$.$cljs$core$IFn$_invoke$arity$1$?this.$__GT_checker$.$cljs$core$IFn$_invoke$arity$1$(this):this.$__GT_checker$(this);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$62$$)?function($x$jscomp$787$$){var $JSCompiler_temp$jscomp$425$$;if($JSCompiler_temp$jscomp$425$$=$cljs$core$ifn_QMARK_$$($x$jscomp$787$$))$JSCompiler_temp$jscomp$425$$=($temp__5823__auto__$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$?
$temp__5823__auto__$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$787$$):$temp__5823__auto__$jscomp$62$$($x$jscomp$787$$))==null;return $JSCompiler_temp$jscomp$425$$}:$cljs$core$ifn_QMARK_$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$428$$,$walker$jscomp$25$$,$path$jscomp$85$$,$options__$1$jscomp$38$$){return $malli$core$_walk_indexed$$(this,$walker$jscomp$25$$,$path$jscomp$85$$,$options__$1$jscomp$38$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$430$$,$path$jscomp$86$$){var $this$__$1$jscomp$171$$=this,$temp__5823__auto__$jscomp$63$$=this.$__GT_checker$.$cljs$core$IFn$_invoke$arity$1$?this.$__GT_checker$.$cljs$core$IFn$_invoke$arity$1$($this$__$1$jscomp$171$$):this.$__GT_checker$($this$__$1$jscomp$171$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$63$$))return function($x$jscomp$789$$,$in$$jscomp$32$$,$acc$jscomp$61$$){if($APP.$cljs$core$fn_QMARK_$$($x$jscomp$789$$)){var $temp__5823__auto____$1$jscomp$8$$=
$temp__5823__auto__$jscomp$63$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5823__auto__$jscomp$63$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$789$$):$temp__5823__auto__$jscomp$63$$($x$jscomp$789$$);return $APP.$cljs$core$truth_$$($temp__5823__auto____$1$jscomp$8$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$61$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$04$$($path$jscomp$86$$,$in$$jscomp$32$$,$this$__$1$jscomp$171$$,
$x$jscomp$789$$),$cljs$cst$569$check$$,$temp__5823__auto____$1$jscomp$8$$)):$acc$jscomp$61$$}return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$61$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$04$$($path$jscomp$86$$,$in$$jscomp$32$$,$this$__$1$jscomp$171$$,$x$jscomp$789$$))};var $validator$jscomp$31$$=$this$__$1$jscomp$171$$.$malli$core$Schema$_validator$arity$1$(null);return function($x$jscomp$790$$,$in$$jscomp$33$$,$acc$jscomp$62$$){return $APP.$cljs$core$not$$($validator$jscomp$31$$.$cljs$core$IFn$_invoke$arity$1$?
$validator$jscomp$31$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$790$$):$validator$jscomp$31$$($x$jscomp$790$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$62$$,$malli$impl$util$_error$cljs$0core$0IFn$0_invoke$0arity$04$$($path$jscomp$86$$,$in$$jscomp$33$$,$this$__$1$jscomp$171$$,$x$jscomp$790$$)):$acc$jscomp$62$$}};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$FunctionSchema$_function_schema_QMARK_$arity$1$=function(){return!0};$APP.$JSCompiler_prototypeAlias$$.$malli$core$FunctionSchema$_function_info$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$FunctionSchema$_instrument_f$arity$4$=function($this$$jscomp$432$$,$p__33811$$,$f$jscomp$427$$,$options__$1$jscomp$39$$){var $map__33812__$1$$=$APP.$cljs$core$__destructure_map$$($p__33811$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33812__$1$$,$cljs$cst$597$_scope$$);var $report$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33812__$1$$,$APP.$cljs$cst$572$report$$),$this$__$1$jscomp$173$$=this,$arity__GT_info$$=
$malli$core$_group_by_arity_BANG_$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($G__33814$jscomp$inline_3570_JSCompiler_inline_result$jscomp$429_s$jscomp$323$$){var $JSCompiler_temp_const$jscomp$427$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$426$$=$malli$core$_function_info$$($G__33814$jscomp$inline_3570_JSCompiler_inline_result$jscomp$429_s$jscomp$323$$);$G__33814$jscomp$inline_3570_JSCompiler_inline_result$jscomp$429_s$jscomp$323$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__33812__$1$$,$APP.$cljs$cst$298$schema$$,$G__33814$jscomp$inline_3570_JSCompiler_inline_result$jscomp$429_s$jscomp$323$$);$G__33814$jscomp$inline_3570_JSCompiler_inline_result$jscomp$429_s$jscomp$323$$=$malli$core$_instrument$cljs$0core$0IFn$0_invoke$0arity$03$$?$malli$core$_instrument$cljs$0core$0IFn$0_invoke$0arity$03$$($G__33814$jscomp$inline_3570_JSCompiler_inline_result$jscomp$429_s$jscomp$323$$,$f$jscomp$427$$,$options__$1$jscomp$39$$):
$malli$core$_instrument$$($G__33814$jscomp$inline_3570_JSCompiler_inline_result$jscomp$429_s$jscomp$323$$,$f$jscomp$427$$,$options__$1$jscomp$39$$);return $JSCompiler_temp_const$jscomp$427$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp_const$jscomp$426$$,$cljs$cst$598$f$$,$G__33814$jscomp$inline_3570_JSCompiler_inline_result$jscomp$429_s$jscomp$323$$)},this.children)),$arities$$=$APP.$cljs$core$set$$($APP.$cljs$core$keys$$($arity__GT_info$$)),$varargs_info$$=$arity__GT_info$$.$cljs$core$IFn$_invoke$arity$1$?
$arity__GT_info$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$347$varargs$$):$arity__GT_info$$($cljs$cst$347$varargs$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($arities$$))?$cljs$cst$598$f$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$val$$($APP.$cljs$core$first$$($arity__GT_info$$))):function(){function $G__35656$$($var_args$jscomp$452$$){var $G__35658__i_args$jscomp$134$$=null;if(arguments.length>0){$G__35658__i_args$jscomp$134$$=0;for(var $G__35658__a$$=
Array(arguments.length-0);$G__35658__i_args$jscomp$134$$<$G__35658__a$$.length;)$G__35658__a$$[$G__35658__i_args$jscomp$134$$]=arguments[$G__35658__i_args$jscomp$134$$+0],++$G__35658__i_args$jscomp$134$$;$G__35658__i_args$jscomp$134$$=new $APP.$cljs$core$IndexedSeq$$($G__35658__a$$,0,null)}return $G__35656__delegate$$.call(this,$G__35658__i_args$jscomp$134$$)}function $G__35656__delegate$$($args$jscomp$133$$){function $report_arity$$(){var $G__33819$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$cljs$cst$346$arity$$,$arity$jscomp$2$$,$cljs$cst$577$arities$$,$arities$$,$cljs$cst$578$args$$,$args$jscomp$133$$,$cljs$cst$563$input$$,$input$jscomp$54$$,$APP.$cljs$cst$298$schema$$,$this$__$1$jscomp$173$$],null);return $report$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$report$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$576$malli_DOT_core_SLASH_invalid_arity$$,$G__33819$$):$report$jscomp$1$$($cljs$cst$576$malli_DOT_core_SLASH_invalid_arity$$,$G__33819$$)}var $arity$jscomp$2$$=$APP.$cljs$core$count$$($args$jscomp$133$$),
$map__33817_map__33817__$1$$=$arity__GT_info$$.$cljs$core$IFn$_invoke$arity$1$?$arity__GT_info$$.$cljs$core$IFn$_invoke$arity$1$($arity$jscomp$2$$):$arity__GT_info$$($arity$jscomp$2$$);$map__33817_map__33817__$1$$=$APP.$cljs$core$__destructure_map$$($map__33817_map__33817__$1$$);var $input$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33817_map__33817__$1$$,$cljs$cst$563$input$$);return $APP.$cljs$core$truth_$$($map__33817_map__33817__$1$$)?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$598$f$$.$cljs$core$IFn$_invoke$arity$1$($map__33817_map__33817__$1$$),
$args$jscomp$133$$):$APP.$cljs$core$truth_$$($varargs_info$$)?$arity$jscomp$2$$<$APP.$cljs$cst$338$min$$.$cljs$core$IFn$_invoke$arity$1$($varargs_info$$)?$report_arity$$():$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$598$f$$.$cljs$core$IFn$_invoke$arity$1$($varargs_info$$),$args$jscomp$133$$):$report_arity$$()}$G__35656$$.$cljs$lang$maxFixedArity$=0;$G__35656$$.$cljs$lang$applyTo$=function($arglist__35659_args$jscomp$135$$){$arglist__35659_args$jscomp$135$$=$APP.$cljs$core$seq$$($arglist__35659_args$jscomp$135$$);
return $G__35656__delegate$$($arglist__35659_args$jscomp$135$$)};$G__35656$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__35656__delegate$$;return $G__35656$$}()};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($___$1$jscomp$418$$,$key$jscomp$231$$,$default$$jscomp$31$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.children,$key$jscomp$231$$,$default$$jscomp$31$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$433$$,$key$jscomp$232$$,$value$jscomp$262$$){return $malli$core$_set_assoc_children$$(this,$key$jscomp$232$$,$value$jscomp$262$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$434$$,$writer$jscomp$123$$,$opts$jscomp$192$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$123$$,$opts$jscomp$192$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33802$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33804$$,$meta33803__$1$$){return new $malli$core$t_malli$0core33802$$(this.$_$,$meta33803__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33803$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return $cljs$cst$605$function$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($form$jscomp$94_parent$jscomp$95$$,$properties$jscomp$74$$,$cache$jscomp$64_children$jscomp$82$$,$p__33805$jscomp$2$$){var $map__33806__$1$$=$APP.$cljs$core$__destructure_map$$($p__33805$jscomp$2$$),$function_checker$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33806__$1$$,$cljs$cst$593$malli_DOT_core_SLASH_function_checker$$),$parent__$1$jscomp$33$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($cljs$cst$605$function$$,
$properties$jscomp$74$$,$cache$jscomp$64_children$jscomp$82$$,1,null);var $children__$1$jscomp$14$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__33800_SHARP_$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($p1__33800_SHARP_$$,$map__33806__$1$$):$APP.$malli$core$schema$$($p1__33800_SHARP_$$,$map__33806__$1$$)},$cache$jscomp$64_children$jscomp$82$$);$form$jscomp$94_parent$jscomp$95$$=new $APP.$cljs$core$Delay$$(function(){return $malli$core$_simple_form$$($parent__$1$jscomp$33$$,
$properties$jscomp$74$$,$children__$1$jscomp$14$$,$malli$core$_form$$,$map__33806__$1$$)});$cache$jscomp$64_children$jscomp$82$$=$malli$core$_create_cache$$();var $__GT_checker$jscomp$5$$=$APP.$cljs$core$truth_$$($function_checker$jscomp$5$$)?function($p1__33801_SHARP_$$){return $function_checker$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$?$function_checker$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$($p1__33801_SHARP_$$,$map__33806__$1$$):$function_checker$jscomp$5$$($p1__33801_SHARP_$$,$map__33806__$1$$)}:
$APP.$cljs$core$constantly$$(null);$APP.$cljs$core$every_QMARK_$$($cljs$core$every_pred$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$core$_function_schema_QMARK_$$,$malli$core$_function_info$$),$children__$1$jscomp$14$$)||$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$606$malli_DOT_core_SLASH_non_function_childs$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$342$children$$,$children__$1$jscomp$14$$],null));$malli$core$_group_by_arity_BANG_$$($malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$core$_function_info$$,
$children__$1$jscomp$14$$));return new $malli$core$t_malli$0core33807$$($form$jscomp$94_parent$jscomp$95$$,$map__33806__$1$$,this.$meta33803$,$p__33805$jscomp$2$$,$properties$jscomp$74$$,$children__$1$jscomp$14$$,$parent__$1$jscomp$33$$,this.$_$,$map__33806__$1$$,$__GT_checker$jscomp$5$$,$function_checker$jscomp$5$$,$cache$jscomp$64_children$jscomp$82$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$435$$,$writer$jscomp$124$$,$opts$jscomp$193$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$124$$,$opts$jscomp$193$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33838$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$malli$core$RefSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$RefSchema$_ref$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RefSchema$_deref$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.$schema$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$FunctionSchema$_function_schema_QMARK_$arity$1$=function(){return $malli$core$_function_schema_QMARK_$$($APP.$cljs$core$_deref$$(this.$schema$))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$FunctionSchema$_function_info$arity$1$=function(){return $malli$core$_function_info$$($APP.$cljs$core$_deref$$(this.$schema$))};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$FunctionSchema$_instrument_f$arity$4$=function($_$jscomp$603$$,$props$jscomp$23$$,$f$jscomp$428$$,$options__$1$jscomp$40$$){return $malli$core$_instrument_f$$($APP.$cljs$core$_deref$$(this.$schema$),$props$jscomp$23$$,$f$jscomp$428$$,$options__$1$jscomp$40$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$436$$,$writer$jscomp$125$$,$opts$jscomp$194$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$125$$,$opts$jscomp$194$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_op_QMARK_$arity$1$=function(){return $malli$core$_regex_op_QMARK_$$($APP.$cljs$core$_deref$$(this.$schema$))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_validator$arity$1$=function(){return $malli$core$_regex_validator$$($APP.$cljs$core$_deref$$(this.$schema$))};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_explainer$arity$2$=function($_$jscomp$606$$,$path$jscomp$87$$){return $malli$core$_regex_explainer$$($APP.$cljs$core$_deref$$(this.$schema$),$path$jscomp$87$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_transformer$arity$4$=function($_$jscomp$609$$,$transformer$jscomp$32$$,$method$jscomp$32$$,$options__$1$jscomp$41$$){return $malli$core$_regex_transformer$$($APP.$cljs$core$_deref$$(this.$schema$),$transformer$jscomp$32$$,$method$jscomp$32$$,$options__$1$jscomp$41$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_min_max$arity$2$=function($_$jscomp$610$$,$nested_QMARK_$jscomp$3$$){return $malli$core$_regex_min_max$$($APP.$cljs$core$_deref$$(this.$schema$),$nested_QMARK_$jscomp$3$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33839$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$DistributiveSchema$_distributive_schema_QMARK_$arity$1$=function(){return $malli$core$_distributive_schema_QMARK_$$(this.$schema$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$DistributiveSchema$_distribute_to_children$arity$3$=function($_$jscomp$612$$,$f$jscomp$429$$,$options__$1$jscomp$42$$){return $malli$core$_distribute_to_children$$(this.$schema$,$f$jscomp$429$$,$options__$1$jscomp$42$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33840$jscomp$1$$,$meta33839__$1$$){return new $malli$core$t_malli$0core33838$$(this.form,this.options,this.$map__33823$,this.forms,this.$meta33828$,this.$properties$,this.$childs$,this.$schema$,this.children,this.min,this.$type_properties$,this.fn,this.parent,this.type,this.cache,this.max,this.$vec__33831$,this.$p__33822$,$meta33839__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){return $malli$core$_validator$$($APP.$cljs$core$_deref$$(this.$schema$))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$437$$,$transformer$jscomp$33$$,$method$jscomp$33$$,$options__$1$jscomp$43$$){return $malli$core$_parent_children_transformer$$(this,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$_deref$$(this.$schema$)],null),$transformer$jscomp$33$$,$method$jscomp$33$$,$options__$1$jscomp$43$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($children__$1$jscomp$15_this$$jscomp$438$$,$walker$jscomp$26$$,$path$jscomp$88$$,$options__$1$jscomp$44$$){$children__$1$jscomp$15_this$$jscomp$438$$=$APP.$cljs$core$truth_$$(this.$childs$)?$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$(this.children,0,this.$childs$):this.children;return $APP.$cljs$core$truth_$$($malli$core$_accept$$($walker$jscomp$26$$,this,$path$jscomp$88$$,$options__$1$jscomp$44$$))?$malli$core$_outer$$($walker$jscomp$26$$,
this,$path$jscomp$88$$,$malli$core$_inner_indexed$$($walker$jscomp$26$$,$path$jscomp$88$$,$children__$1$jscomp$15_this$$jscomp$438$$,$options__$1$jscomp$44$$),$options__$1$jscomp$44$$):null};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($_$jscomp$620$$,$path$jscomp$89$$){return $malli$core$_explainer$$($APP.$cljs$core$_deref$$(this.$schema$),$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$89$$,$cljs$cst$474$malli_DOT_core_SLASH_in$$))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$624$$,$key$jscomp$233$$,$default$$jscomp$32$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$474$malli_DOT_core_SLASH_in$$,$key$jscomp$233$$)?$APP.$cljs$core$_deref$$(this.$schema$):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.children,$key$jscomp$233$$,$default$$jscomp$32$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($G__33843__$jscomp$625$$,$G__33845_key$jscomp$234$$,$value$jscomp$263$$){$G__33843__$jscomp$625$$=this.type;var $G__33844$$=this.$properties$;$G__33845_key$jscomp$234$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.children,$G__33845_key$jscomp$234$$,$value$jscomp$263$$);return $malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$03$$?$malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$03$$($G__33843__$jscomp$625$$,
$G__33844$$,$G__33845_key$jscomp$234$$):$malli$core$into_schema$$($G__33843__$jscomp$625$$,$G__33844$$,$G__33845_key$jscomp$234$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33827$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33829$$,$meta33828__$1$$){return new $malli$core$t_malli$0core33827$$(this.$p__33822$,this.$map__33823$,this.type,this.min,this.max,this.$childs$,this.$type_properties$,this.fn,$meta33828__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33828$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return this.type};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return this.$type_properties$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($parent$jscomp$98_vec__33831$jscomp$2$$,$properties$jscomp$77$$,$children$jscomp$85$$,$options$jscomp$216$$){var $self__$jscomp$1924$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($self__$jscomp$1924$$.type,$properties$jscomp$77$$,$children$jscomp$85$$,$self__$jscomp$1924$$.min,$self__$jscomp$1924$$.max);$parent$jscomp$98_vec__33831$jscomp$2$$=function(){var $G__33835$$=$APP.$cljs$core$vec$$($children$jscomp$85$$);
return $self__$jscomp$1924$$.fn.$cljs$core$IFn$_invoke$arity$3$?$self__$jscomp$1924$$.fn.$cljs$core$IFn$_invoke$arity$3$($properties$jscomp$77$$,$G__33835$$,$options$jscomp$216$$):$self__$jscomp$1924$$.fn($properties$jscomp$77$$,$G__33835$$,$options$jscomp$216$$)}();var $children__$1$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($parent$jscomp$98_vec__33831$jscomp$2$$,0,null),$forms$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($parent$jscomp$98_vec__33831$jscomp$2$$,
1,null),$schema$jscomp$53$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($parent$jscomp$98_vec__33831$jscomp$2$$,2,null);return new $malli$core$t_malli$0core33838$$(new $APP.$cljs$core$Delay$$(function(){return $malli$core$_create_form$$($self__$jscomp$1924$$.type,$properties$jscomp$77$$,$forms$jscomp$6$$,$options$jscomp$216$$)}),$options$jscomp$216$$,$self__$jscomp$1924$$.$map__33823$,$forms$jscomp$6$$,$self__$jscomp$1924$$.$meta33828$,$properties$jscomp$77$$,$self__$jscomp$1924$$.$childs$,
new $APP.$cljs$core$Delay$$(function(){return $APP.$cljs$core$force$$($schema$jscomp$53$$)}),$children__$1$jscomp$16$$,$self__$jscomp$1924$$.min,$self__$jscomp$1924$$.$type_properties$,$self__$jscomp$1924$$.fn,this,$self__$jscomp$1924$$.type,$malli$core$_create_cache$$(),$self__$jscomp$1924$$.max,$parent$jscomp$98_vec__33831$jscomp$2$$,$self__$jscomp$1924$$.$p__33822$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$439$$,$writer$jscomp$126$$,$opts$jscomp$195$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$126$$,$opts$jscomp$195$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33873$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33875$$,$meta33874__$1$$){return new $malli$core$t_malli$0core33873$$(this.form,this.options,this.$re_min_max$,this.$properties$,this.$re_explainer$,this.children,this.min,this.$re_parser$,this.parent,this.$re_unparser$,this.type,this.$map__33857$,this.$map__33858$,this.$meta33862$,this.cache,this.$re_transformer$,this.max,this.$p__33856$,this.$re_validator$,$meta33874__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33874$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){return $malli$impl$regex$validator$$($malli$core$_regex_validator$$(this))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$441$$,$transformer$jscomp$35$$,$method$jscomp$35$$,$options__$1$jscomp$45$$){return $malli$core$regex_transformer$$(this,$transformer$jscomp$35$$,$method$jscomp$35$$,$options__$1$jscomp$45$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$442$$,$walker$jscomp$27$$,$path$jscomp$91$$,$options__$1$jscomp$46$$){return $malli$core$_walk_indexed$$(this,$walker$jscomp$27$$,$path$jscomp$91$$,$options__$1$jscomp$46$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return this.children};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$444$$,$path$jscomp$92$$){return $malli$impl$regex$explainer$$(this,$path$jscomp$92$$,$malli$core$_regex_explainer$$(this,$path$jscomp$92$$))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($_$jscomp$638$$,$key$jscomp$235$$,$default$$jscomp$33$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.children,$key$jscomp$235$$,$default$$jscomp$33$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$446$$,$key$jscomp$236$$,$value$jscomp$264$$){return $malli$core$_set_assoc_children$$(this,$key$jscomp$236$$,$value$jscomp$264$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_op_QMARK_$arity$1$=function(){return!0};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_validator$arity$1$=function(){var $G__33892$$=this.$properties$,$G__33893$$=$malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$core$_regex_validator$$,this.children);return this.$re_validator$.$cljs$core$IFn$_invoke$arity$2$?this.$re_validator$.$cljs$core$IFn$_invoke$arity$2$($G__33892$$,$G__33893$$):this.$re_validator$($G__33892$$,$G__33893$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_explainer$arity$2$=function($G__33898__$jscomp$641$$,$path$jscomp$93$$){$G__33898__$jscomp$641$$=this.$properties$;var $G__33899$$=$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($i$jscomp$325$$,$child$jscomp$12$$){return $malli$core$_regex_explainer$$($child$jscomp$12$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$93$$,$i$jscomp$325$$))},this.children);return this.$re_explainer$.$cljs$core$IFn$_invoke$arity$2$?
this.$re_explainer$.$cljs$core$IFn$_invoke$arity$2$($G__33898__$jscomp$641$$,$G__33899$$):this.$re_explainer$($G__33898__$jscomp$641$$,$G__33899$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_transformer$arity$4$=function($G__33905__$jscomp$644$$,$transformer$jscomp$36$$,$method$jscomp$36$$,$options__$1$jscomp$47$$){$G__33905__$jscomp$644$$=this.$properties$;var $G__33906$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__33855_SHARP_$$){return $malli$core$_regex_transformer$$($p1__33855_SHARP_$$,$transformer$jscomp$36$$,$method$jscomp$36$$,$options__$1$jscomp$47$$)},this.children);return this.$re_transformer$.$cljs$core$IFn$_invoke$arity$2$?
this.$re_transformer$.$cljs$core$IFn$_invoke$arity$2$($G__33905__$jscomp$644$$,$G__33906$$):this.$re_transformer$($G__33905__$jscomp$644$$,$G__33906$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_min_max$arity$2$=function(){return this.$re_min_max$.$cljs$core$IFn$_invoke$arity$2$?this.$re_min_max$.$cljs$core$IFn$_invoke$arity$2$(this.$properties$,this.children):this.$re_min_max$(this.$properties$,this.children)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$447$$,$writer$jscomp$127$$,$opts$jscomp$196$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$127$$,$opts$jscomp$196$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33861$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33863$$,$meta33862__$1$$){return new $malli$core$t_malli$0core33861$$(this.$re_min_max$,this.$re_explainer$,this.min,this.$re_parser$,this.$re_unparser$,this.type,this.$map__33857$,this.$map__33858$,this.$re_transformer$,this.max,this.$p__33856$,this.$re_validator$,$meta33862__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33862$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return this.type};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($parent$jscomp$101$$,$properties$jscomp$80$$,$children$jscomp$88$$,$options$jscomp$220$$){var $parent__$1$jscomp$35$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$(this.type,$properties$jscomp$80$$,$children$jscomp$88$$,this.min,this.max);var $children__$1$jscomp$17$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__33854_SHARP_$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($p1__33854_SHARP_$$,$options$jscomp$220$$):$APP.$malli$core$schema$$($p1__33854_SHARP_$$,$options$jscomp$220$$)},$children$jscomp$88$$);return new $malli$core$t_malli$0core33873$$(new $APP.$cljs$core$Delay$$(function(){return $malli$core$_simple_form$$($parent__$1$jscomp$35$$,$properties$jscomp$80$$,$children__$1$jscomp$17$$,$malli$core$_form$$,$options$jscomp$220$$)}),$options$jscomp$220$$,this.$re_min_max$,$properties$jscomp$80$$,this.$re_explainer$,
$children__$1$jscomp$17$$,this.min,this.$re_parser$,$parent__$1$jscomp$35$$,this.$re_unparser$,this.type,this.$map__33857$,this.$map__33858$,this.$meta33862$,$malli$core$_create_cache$$(),this.$re_transformer$,this.max,this.$p__33856$,this.$re_validator$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$448$$,$writer$jscomp$128$$,$opts$jscomp$197$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$128$$,$opts$jscomp$197$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33934$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$_to_ast$arity$2$=function(){return $malli$core$_entry_ast$$(this,$malli$core$_entry_keyset$$(this.$entry_parser$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$450$$,$writer$jscomp$129$$,$opts__$1$jscomp$13$$){return $malli$core$pr_writer_schema$$(this,$writer$jscomp$129$$,$opts__$1$jscomp$13$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntrySchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntrySchema$_entries$arity$1$=function(){return $malli$core$_entry_entries$$(this.$entry_parser$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$EntrySchema$_entry_parser$arity$1$=function(){return this.$entry_parser$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_op_QMARK_$arity$1$=function(){return!0};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_validator$arity$1$=function(){var $G__33944$$=this.$properties$,$G__33945$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__33947_s$jscomp$324$$){var $k$jscomp$394$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33947_s$jscomp$324$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33947_s$jscomp$324$$,1,null);$p__33947_s$jscomp$324$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33947_s$jscomp$324$$,
2,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$394$$,$malli$core$_regex_validator$$($p__33947_s$jscomp$324$$)],null)},this.$malli$core$Schema$_children$arity$1$(null));return this.$re_validator$.$cljs$core$IFn$_invoke$arity$2$?this.$re_validator$.$cljs$core$IFn$_invoke$arity$2$($G__33944$$,$G__33945$$):this.$re_validator$($G__33944$$,$G__33945$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_explainer$arity$2$=function($G__33951_this$$jscomp$452$$,$path$jscomp$94$$){$G__33951_this$$jscomp$452$$=this.$properties$;var $G__33952$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__33953_s$jscomp$325$$){var $k$jscomp$395$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33953_s$jscomp$325$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33953_s$jscomp$325$$,1,null);$p__33953_s$jscomp$325$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33953_s$jscomp$325$$,2,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$395$$,$malli$core$_regex_explainer$$($p__33953_s$jscomp$325$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$94$$,$k$jscomp$395$$))],null)},this.$malli$core$Schema$_children$arity$1$(null));return this.$re_explainer$.$cljs$core$IFn$_invoke$arity$2$?this.$re_explainer$.$cljs$core$IFn$_invoke$arity$2$($G__33951_this$$jscomp$452$$,
$G__33952$$):this.$re_explainer$($G__33951_this$$jscomp$452$$,$G__33952$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_transformer$arity$4$=function($G__33977_this$$jscomp$455$$,$transformer$jscomp$37$$,$method$jscomp$37$$,$options__$1$jscomp$48$$){$G__33977_this$$jscomp$455$$=this.$properties$;var $G__33978$$=$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__33982_s$jscomp$328$$){var $k$jscomp$398$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33982_s$jscomp$328$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33982_s$jscomp$328$$,
1,null);$p__33982_s$jscomp$328$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__33982_s$jscomp$328$$,2,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$398$$,$malli$core$_regex_transformer$$($p__33982_s$jscomp$328$$,$transformer$jscomp$37$$,$method$jscomp$37$$,$options__$1$jscomp$48$$)],null)},this.$malli$core$Schema$_children$arity$1$(null));return this.$re_transformer$.$cljs$core$IFn$_invoke$arity$2$?this.$re_transformer$.$cljs$core$IFn$_invoke$arity$2$($G__33977_this$$jscomp$455$$,
$G__33978$$):this.$re_transformer$($G__33977_this$$jscomp$455$$,$G__33978$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$RegexSchema$_regex_min_max$arity$2$=function(){var $G__33987$$=this.$properties$,$G__33988$$=this.$malli$core$Schema$_children$arity$1$(null);return this.$re_min_max$.$cljs$core$IFn$_invoke$arity$2$?this.$re_min_max$.$cljs$core$IFn$_invoke$arity$2$($G__33987$$,$G__33988$$):this.$re_min_max$($G__33987$$,$G__33988$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33935$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Cached$_cache$arity$1$=function(){return this.cache};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33936$jscomp$1$$,$meta33935__$1$$){return new $malli$core$t_malli$0core33934$$(this.form,this.$p__33923$,this.options,this.$re_min_max$,this.$keep$,this.$properties$,this.$re_explainer$,this.children,this.min,this.$re_parser$,this.$entry_parser$,this.parent,this.$re_unparser$,this.$meta33927$,this.type,this.$map__33924$,this.cache,this.$map__33925$,this.$re_transformer$,this.max,this.$opts$,this.$re_validator$,$meta33935__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_validator$arity$1$=function(){return $malli$impl$regex$validator$$($malli$core$_regex_validator$$(this))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_options$arity$1$=function(){return this.options};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_transformer$arity$4$=function($this$$jscomp$458$$,$transformer$jscomp$38$$,$method$jscomp$38$$,$options__$1$jscomp$49$$){return $malli$core$regex_transformer$$(this,$transformer$jscomp$38$$,$method$jscomp$38$$,$options__$1$jscomp$49$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_walk$arity$4$=function($this$$jscomp$459$$,$walker$jscomp$28$$,$path$jscomp$95$$,$options__$1$jscomp$50$$){return $malli$core$_walk_entries$$(this,$walker$jscomp$28$$,$path$jscomp$95$$,$options__$1$jscomp$50$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_properties$arity$1$=function(){return this.$properties$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_children$arity$1$=function(){return $malli$core$_entry_children$$(this.$entry_parser$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_form$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.form)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_explainer$arity$2$=function($this$$jscomp$461$$,$path$jscomp$96$$){return $malli$impl$regex$explainer$$(this,$path$jscomp$96$$,$malli$core$_regex_explainer$$(this,$path$jscomp$96$$))};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Schema$_parent$arity$1$=function(){return this.parent};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_get$arity$3$=function($this$$jscomp$463$$,$key$jscomp$237$$,$default$$jscomp$34$$){return $malli$core$_get_entries$$(this,$key$jscomp$237$$,$default$$jscomp$34$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$LensSchema$_set$arity$3$=function($this$$jscomp$464$$,$key$jscomp$238$$,$value$jscomp$265$$){return $malli$core$_set_entries$$(this,$key$jscomp$238$$,$value$jscomp$265$$)};$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core33926$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_33928$$,$meta33927__$1$$){return new $malli$core$t_malli$0core33926$$(this.$p__33923$,this.$re_min_max$,this.$keep$,this.$re_explainer$,this.min,this.$re_parser$,this.$re_unparser$,this.type,this.$map__33924$,this.$map__33925$,this.$re_transformer$,this.max,this.$opts$,this.$re_validator$,$meta33927__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta33927$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$AST$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type$arity$1$=function(){return this.type};$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_type_properties$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$IntoSchema$_into_schema$arity$4$=function($parent$jscomp$105$$,$properties$jscomp$83$$,$children$jscomp$91$$,$options$jscomp$224$$){var $parent__$1$jscomp$37$$=this;$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$(this.type,$properties$jscomp$83$$,$children$jscomp$91$$,this.min,this.max);var $entry_parser$jscomp$14$$=$malli$core$_create_entry_parser$$($children$jscomp$91$$,this.$opts$,$options$jscomp$224$$);return new $malli$core$t_malli$0core33934$$(new $APP.$cljs$core$Delay$$(function(){return $malli$core$_create_entry_form$$($parent__$1$jscomp$37$$,
$properties$jscomp$83$$,$entry_parser$jscomp$14$$,$options$jscomp$224$$)}),this.$p__33923$,$options$jscomp$224$$,this.$re_min_max$,this.$keep$,$properties$jscomp$83$$,this.$re_explainer$,$children$jscomp$91$$,this.min,this.$re_parser$,$entry_parser$jscomp$14$$,$parent__$1$jscomp$37$$,this.$re_unparser$,this.$meta33927$,this.type,this.$map__33924$,$malli$core$_create_cache$$(),this.$map__33925$,this.$re_transformer$,this.max,this.$opts$,this.$re_validator$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$],null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$465$$,$writer$jscomp$130$$,$opts__$1$jscomp$14$$){return $malli$core$pr_writer_into_schema$$(this,$writer$jscomp$130$$,$opts__$1$jscomp$14$$)};
$APP.$malli$core$type$$=function $malli$core$type$$($var_args$jscomp$454$$){switch(arguments.length){case 1:return $malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $malli$core$type$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$=function($_QMARK_schema$jscomp$3$$){return $APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$3$$,null)};
$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$2$=function($_QMARK_schema$jscomp$4$$,$options$jscomp$226$$){return $malli$core$_type$$($malli$core$_parent$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$4$$,$options$jscomp$226$$):$APP.$malli$core$schema$$($_QMARK_schema$jscomp$4$$,$options$jscomp$226$$)))};$APP.$malli$core$type$$.$cljs$lang$maxFixedArity$=2;
var $malli$core$type_properties$$=function $malli$core$type_properties$$($var_args$jscomp$455$$){switch(arguments.length){case 1:return $malli$core$type_properties$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $malli$core$type_properties$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$core$type_properties$$.$cljs$core$IFn$_invoke$arity$1$=function($_QMARK_schema$jscomp$5$$){return $malli$core$type_properties$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$5$$,null)};
$malli$core$type_properties$$.$cljs$core$IFn$_invoke$arity$2$=function($_QMARK_schema$jscomp$6$$,$options$jscomp$227$$){return $malli$core$_type_properties$$($malli$core$_parent$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$6$$,$options$jscomp$227$$):$APP.$malli$core$schema$$($_QMARK_schema$jscomp$6$$,$options$jscomp$227$$)))};$malli$core$type_properties$$.$cljs$lang$maxFixedArity$=2;
$APP.$malli$core$schema$$=function $malli$core$schema$$($var_args$jscomp$458$$){switch(arguments.length){case 1:return $malli$core$schema$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$1$=function($_QMARK_schema$jscomp$11$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$11$$,null)};
$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$=function($G__35815__QMARK_schema$jscomp$12$$,$G__35816_options$jscomp$230$$){for(;;){if($malli$core$schema_QMARK_$$($G__35815__QMARK_schema$jscomp$12$$))return $G__35815__QMARK_schema$jscomp$12$$;if($malli$core$into_schema_QMARK_$$($G__35815__QMARK_schema$jscomp$12$$))return $malli$core$_into_schema$$($G__35815__QMARK_schema$jscomp$12$$,null,null,$G__35816_options$jscomp$230$$);if($APP.$cljs$core$vector_QMARK_$$($G__35815__QMARK_schema$jscomp$12$$)){var $_QMARK_p_v$jscomp$192$$=
$G__35815__QMARK_schema$jscomp$12$$,$and__5023__auto__$jscomp$inline_3574_t$jscomp$36_temp__5823__auto__$jscomp$64$$=$malli$core$_lookup_BANG_$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($_QMARK_p_v$jscomp$192$$,0),$_QMARK_p_v$jscomp$192$$,$malli$core$into_schema_QMARK_$$,!0,$G__35816_options$jscomp$230$$),$n$jscomp$200$$=$APP.$cljs$core$count$$($_QMARK_p_v$jscomp$192$$);$_QMARK_p_v$jscomp$192$$=$n$jscomp$200$$>1?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($_QMARK_p_v$jscomp$192$$,
1):null;return $_QMARK_p_v$jscomp$192$$==null||$APP.$cljs$core$map_QMARK_$$($_QMARK_p_v$jscomp$192$$)?$malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$04$$($and__5023__auto__$jscomp$inline_3574_t$jscomp$36_temp__5823__auto__$jscomp$64$$,$_QMARK_p_v$jscomp$192$$,2<$n$jscomp$200$$?$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($G__35815__QMARK_schema$jscomp$12$$,2,$n$jscomp$200$$):null,$G__35816_options$jscomp$230$$):$malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$04$$($and__5023__auto__$jscomp$inline_3574_t$jscomp$36_temp__5823__auto__$jscomp$64$$,
null,1<$n$jscomp$200$$?$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($G__35815__QMARK_schema$jscomp$12$$,1,$n$jscomp$200$$):null,$G__35816_options$jscomp$230$$)}$and__5023__auto__$jscomp$inline_3574_t$jscomp$36_temp__5823__auto__$jscomp$64$$=($and__5023__auto__$jscomp$inline_3574_t$jscomp$36_temp__5823__auto__$jscomp$64$$=$malli$core$_reference_QMARK_$$($G__35815__QMARK_schema$jscomp$12$$))?$malli$core$_lookup$$($G__35815__QMARK_schema$jscomp$12$$,$G__35816_options$jscomp$230$$):$and__5023__auto__$jscomp$inline_3574_t$jscomp$36_temp__5823__auto__$jscomp$64$$;
if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_3574_t$jscomp$36_temp__5823__auto__$jscomp$64$$))return $malli$core$_pointer$$($G__35815__QMARK_schema$jscomp$12$$,$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$inline_3574_t$jscomp$36_temp__5823__auto__$jscomp$64$$,$G__35816_options$jscomp$230$$),$G__35816_options$jscomp$230$$);$G__35815__QMARK_schema$jscomp$12$$=$malli$core$_lookup_BANG_$$($G__35815__QMARK_schema$jscomp$12$$,$G__35815__QMARK_schema$jscomp$12$$,
null,!1,$G__35816_options$jscomp$230$$)}};$APP.$malli$core$schema$$.$cljs$lang$maxFixedArity$=2;var $malli$core$form$$=function $malli$core$form$$($var_args$jscomp$459$$){switch(arguments.length){case 1:return $malli$core$form$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $malli$core$form$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$core$form$$.$cljs$core$IFn$_invoke$arity$1$=function($_QMARK_schema$jscomp$13$$){return $malli$core$form$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$13$$,null)};$malli$core$form$$.$cljs$core$IFn$_invoke$arity$2$=function($_QMARK_schema$jscomp$14$$,$options$jscomp$231$$){return $malli$core$_form$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$14$$,$options$jscomp$231$$))};$malli$core$form$$.$cljs$lang$maxFixedArity$=2;
$APP.$malli$core$properties$$=function $malli$core$properties$$($var_args$jscomp$460$$){switch(arguments.length){case 1:return $malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $malli$core$properties$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$=function($_QMARK_schema$jscomp$15$$){return $APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$15$$,null)};$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$2$=function($_QMARK_schema$jscomp$16$$,$options$jscomp$232$$){return $malli$core$_properties$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$16$$,$options$jscomp$232$$))};
$APP.$malli$core$properties$$.$cljs$lang$maxFixedArity$=2;var $malli$core$children$$=function $malli$core$children$$($var_args$jscomp$462$$){switch(arguments.length){case 1:return $malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $malli$core$children$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$=function($_QMARK_schema$jscomp$19$$){return $malli$core$children$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$19$$,null)};$malli$core$children$$.$cljs$core$IFn$_invoke$arity$2$=function($_QMARK_schema$jscomp$20_schema$jscomp$58$$,$options$jscomp$234$$){$_QMARK_schema$jscomp$20_schema$jscomp$58$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$20_schema$jscomp$58$$,$options$jscomp$234$$);return $malli$core$_children$$($_QMARK_schema$jscomp$20_schema$jscomp$58$$)};
$malli$core$children$$.$cljs$lang$maxFixedArity$=2;$APP.$JSCompiler_prototypeAlias$$=$malli$core$t_malli$0core34055$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_34057$$,$meta34056__$1$$){return new $malli$core$t_malli$0core34055$$(this.$_QMARK_schema$,this.f,this.options,$meta34056__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta34056$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Walker$_accept$arity$4$=function($_$jscomp$671$$,$s$jscomp$329$$){return $s$jscomp$329$$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Walker$_inner$arity$4$=function($this$$jscomp$466$$,$s$jscomp$330$$,$p$jscomp$80$$,$options__$1$jscomp$52$$){return $malli$core$_walk$$($s$jscomp$330$$,this,$p$jscomp$80$$,$options__$1$jscomp$52$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Walker$_outer$arity$5$=function($_$jscomp$672$$,$s$jscomp$331$$,$p$jscomp$81$$,$c$jscomp$202$$,$options__$1$jscomp$53$$){return this.f.$cljs$core$IFn$_invoke$arity$4$?this.f.$cljs$core$IFn$_invoke$arity$4$($s$jscomp$331$$,$p$jscomp$81$$,$c$jscomp$202$$,$options__$1$jscomp$53$$):this.f($s$jscomp$331$$,$p$jscomp$81$$,$c$jscomp$202$$,$options__$1$jscomp$53$$)};
var $malli$core$entries$$=function $malli$core$entries$$($var_args$jscomp$479$$){switch(arguments.length){case 1:return $malli$core$entries$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $malli$core$entries$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$core$entries$$.$cljs$core$IFn$_invoke$arity$1$=function($_QMARK_schema$jscomp$61$$){return $malli$core$entries$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$61$$,null)};
$malli$core$entries$$.$cljs$core$IFn$_invoke$arity$2$=function($_QMARK_schema$jscomp$62_temp__5825__auto__$jscomp$64$$,$options$jscomp$255$$){$_QMARK_schema$jscomp$62_temp__5825__auto__$jscomp$64$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$62_temp__5825__auto__$jscomp$64$$,$options$jscomp$255$$);return $APP.$cljs$core$truth_$$($_QMARK_schema$jscomp$62_temp__5825__auto__$jscomp$64$$)?$_QMARK_schema$jscomp$62_temp__5825__auto__$jscomp$64$$!=null&&$APP.$cljs$core$PROTOCOL_SENTINEL$$===
$_QMARK_schema$jscomp$62_temp__5825__auto__$jscomp$64$$.$malli$core$EntrySchema$$?$malli$core$_entries$$($_QMARK_schema$jscomp$62_temp__5825__auto__$jscomp$64$$):null:null};$malli$core$entries$$.$cljs$lang$maxFixedArity$=2;
var $_evaluator_35960$$=$APP.$cljs$core$memoize$$(function($options$jscomp$79$$,$fail_BANG_$$){var $eval_string_STAR_$$=new $borkdude$dynaload$LazyVar$$(function(){if(typeof sci!=="undefined"&&typeof sci.core!=="undefined"&&typeof sci.core.$eval_string_STAR_$!=="undefined")return sci.core.$eval_string_STAR_$;var $temp__5823__auto__$jscomp$43$$=$cljs$core$find$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$205$default$$,null],null),$APP.$cljs$cst$205$default$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$43$$))return $APP.$cljs$core$_val$$($temp__5823__auto__$jscomp$43$$);
throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$335$sci_DOT_core_SLASH_eval_string_STAR_$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$335$sci_DOT_core_SLASH_eval_string_STAR_$$)," never required"].join(""));}),$init$jscomp$51$$=new $borkdude$dynaload$LazyVar$$(function(){if(typeof sci!=="undefined"&&typeof sci.core!=="undefined"&&typeof sci.core.init!=="undefined")return sci.core.init;var $temp__5823__auto__$jscomp$44$$=$cljs$core$find$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$205$default$$,null],null),$APP.$cljs$cst$205$default$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$44$$))return $APP.$cljs$core$_val$$($temp__5823__auto__$jscomp$44$$);throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$336$sci_DOT_core_SLASH_init$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$336$sci_DOT_core_SLASH_init$$)," never required"].join(""));}),$fork$$=new $borkdude$dynaload$LazyVar$$(function(){if(typeof sci!==
"undefined"&&typeof sci.core!=="undefined"&&typeof sci.core.$fork$!=="undefined")return sci.core.$fork$;var $temp__5823__auto__$jscomp$45$$=$cljs$core$find$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$205$default$$,null],null),$APP.$cljs$cst$205$default$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$45$$))return $APP.$cljs$core$_val$$($temp__5823__auto__$jscomp$45$$);throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$337$sci_DOT_core_SLASH_fork$$),
" does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$337$sci_DOT_core_SLASH_fork$$)," never required"].join(""));});return function(){if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$58_and__5023__auto____$1$jscomp$18$$=$APP.$cljs$core$_deref$$($eval_string_STAR_$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$58_and__5023__auto____$1$jscomp$18$$)?($and__5023__auto__$jscomp$58_and__5023__auto____$1$jscomp$18$$=$APP.$cljs$core$_deref$$($init$jscomp$51$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$58_and__5023__auto____$1$jscomp$18$$)?
$APP.$cljs$core$_deref$$($fork$$):$and__5023__auto__$jscomp$58_and__5023__auto____$1$jscomp$18$$):$and__5023__auto__$jscomp$58_and__5023__auto____$1$jscomp$18$$}())){var $ctx$$=$init$jscomp$51$$.$cljs$core$IFn$_invoke$arity$1$?$init$jscomp$51$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$79$$):$init$jscomp$51$$($options$jscomp$79$$);$eval_string_STAR_$$.$cljs$core$IFn$_invoke$arity$2$?$eval_string_STAR_$$.$cljs$core$IFn$_invoke$arity$2$($ctx$$,"(alias 'm 'malli.core)"):$eval_string_STAR_$$($ctx$$,
"(alias 'm 'malli.core)");return function($G__25927_s$jscomp$301$$){var $G__25926$$=$fork$$.$cljs$core$IFn$_invoke$arity$1$?$fork$$.$cljs$core$IFn$_invoke$arity$1$($ctx$$):$fork$$($ctx$$);$G__25927_s$jscomp$301$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__25927_s$jscomp$301$$);return $eval_string_STAR_$$.$cljs$core$IFn$_invoke$arity$2$?$eval_string_STAR_$$.$cljs$core$IFn$_invoke$arity$2$($G__25926$$,$G__25927_s$jscomp$301$$):$eval_string_STAR_$$($G__25926$$,$G__25927_s$jscomp$301$$)}}return $fail_BANG_$$}}),
$malli$core$default_registry$$,$m$jscomp$inline_11436$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$04$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_register_var$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$cljs$cst$663$any_QMARK_$$,$APP.$cljs$core$any_QMARK_$$),$cljs$cst$664$some_QMARK_$$,$APP.$cljs$core$some_QMARK_$$),$cljs$cst$665$number_QMARK_$$,$APP.$cljs$core$number_QMARK_$$),$cljs$cst$666$integer_QMARK_$$,$APP.$cljs$core$integer_QMARK_$$),$cljs$cst$667$int_QMARK_$$,$APP.$cljs$core$int_QMARK_$$),$cljs$cst$668$pos_int_QMARK_$$,$cljs$core$pos_int_QMARK_$$),$cljs$cst$669$neg_int_QMARK_$$,$cljs$core$neg_int_QMARK_$$),$cljs$cst$670$nat_int_QMARK_$$,$APP.$cljs$core$nat_int_QMARK_$$),$cljs$cst$671$pos_QMARK_$$,
$APP.$cljs$core$pos_QMARK_$$),$cljs$cst$672$neg_QMARK_$$,function($x$jscomp$293$$){return $x$jscomp$293$$<0}),$cljs$cst$673$float_QMARK_$$,$cljs$core$float_QMARK_$$),$cljs$cst$674$double_QMARK_$$,$cljs$core$double_QMARK_$$),$cljs$cst$675$boolean_QMARK_$$,$APP.$cljs$core$boolean_QMARK_$$),$cljs$cst$676$string_QMARK_$$,$APP.$cljs$core$string_QMARK_$$),$cljs$cst$677$ident_QMARK_$$,$cljs$core$ident_QMARK_$$),$cljs$cst$678$simple_ident_QMARK_$$,$cljs$core$simple_ident_QMARK_$$),$cljs$cst$679$qualified_ident_QMARK_$$,
$cljs$core$qualified_ident_QMARK_$$),$cljs$cst$680$keyword_QMARK_$$,$cljs$core$keyword_QMARK_$$),$cljs$cst$681$simple_keyword_QMARK_$$,$cljs$core$simple_keyword_QMARK_$$),$cljs$cst$682$qualified_keyword_QMARK_$$,$cljs$core$qualified_keyword_QMARK_$$),$cljs$cst$683$symbol_QMARK_$$,$cljs$core$symbol_QMARK_$$),$cljs$cst$684$simple_symbol_QMARK_$$,$cljs$core$simple_symbol_QMARK_$$),$cljs$cst$685$qualified_symbol_QMARK_$$,$cljs$core$qualified_symbol_QMARK_$$),$cljs$cst$686$uuid_QMARK_$$,$APP.$cljs$core$uuid_QMARK_$$),
$cljs$cst$687$uri_QMARK_$$,$cljs$core$uri_QMARK_$$),$cljs$cst$688$inst_QMARK_$$,$cljs$core$inst_QMARK_$$),$cljs$cst$689$seqable_QMARK_$$,$APP.$cljs$core$seqable_QMARK_$$),$cljs$cst$690$indexed_QMARK_$$,$cljs$core$indexed_QMARK_$$),$cljs$cst$691$map_QMARK_$$,$APP.$cljs$core$map_QMARK_$$),$cljs$cst$692$vector_QMARK_$$,$APP.$cljs$core$vector_QMARK_$$),$cljs$cst$693$list_QMARK_$$,$APP.$cljs$core$list_QMARK_$$),$cljs$cst$694$seq_QMARK_$$,$APP.$cljs$core$seq_QMARK_$$),$cljs$cst$695$char_QMARK_$$,$cljs$core$char_QMARK_$$),
$cljs$cst$696$set_QMARK_$$,$APP.$cljs$core$set_QMARK_$$),$cljs$cst$697$nil_QMARK_$$,$APP.$cljs$core$nil_QMARK_$$),$cljs$cst$698$false_QMARK_$$,$cljs$core$false_QMARK_$$),$cljs$cst$699$true_QMARK_$$,$APP.$cljs$core$true_QMARK_$$),$cljs$cst$700$zero_QMARK_$$,$cljs$core$zero_QMARK_$$),$cljs$cst$701$coll_QMARK_$$,$APP.$cljs$core$coll_QMARK_$$),$cljs$cst$702$associative_QMARK_$$,$APP.$cljs$core$associative_QMARK_$$),$cljs$cst$703$sequential_QMARK_$$,$APP.$cljs$core$sequential_QMARK_$$),$cljs$cst$704$ifn_QMARK_$$,
$cljs$core$ifn_QMARK_$$),$cljs$cst$705$fn_QMARK_$$,$APP.$cljs$core$fn_QMARK_$$),$cljs$cst$706$empty_QMARK_$$,$APP.$cljs$core$empty_QMARK_$$,function($x$jscomp$794$$){return $APP.$cljs$core$seqable_QMARK_$$($x$jscomp$794$$)&&$APP.$cljs$core$empty_QMARK_$$($x$jscomp$794$$)}),$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$APP.$cljs$core$type$$(RegExp("")),new $malli$core$t_malli$0core33239$$(!0,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],
null))]),$APP.$cljs$core$reduce_kv$$($APP.$cljs$core$assoc$$,null,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$malli$core$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__34230$$){var $k$jscomp$400$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34230$$,0,null),$v$jscomp$193$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34230$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$k$jscomp$400$$,$malli$core$_simple_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$k$jscomp$400$$,$cljs$cst$416$from_ast$$,$malli$core$_from_value_ast$$,$cljs$cst$414$to_ast$$,$malli$core$_to_value_ast$$,$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,1,$APP.$cljs$cst$411$compile$$,function($_$jscomp$675$$,$p__34234$$){var $child$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34234$$,0,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$351$pred$$,$malli$core$_safe_pred$$(function($p1__34229_SHARP_$$){return $v$jscomp$193$$.$cljs$core$IFn$_invoke$arity$2$?$v$jscomp$193$$.$cljs$core$IFn$_invoke$arity$2$($p1__34229_SHARP_$$,$child$jscomp$13$$):$v$jscomp$193$$($p1__34229_SHARP_$$,$child$jscomp$13$$)})],null)}],null))],null)},new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$707$_GT_$$,$APP.$cljs$core$_GT_$$,$cljs$cst$708$_GT__EQ_$$,$cljs$core$_GT__EQ_$$,$cljs$cst$709$_LT_$$,$APP.$cljs$core$_LT_$$,$cljs$cst$710$_LT__EQ_$$,
$cljs$core$_LT__EQ_$$,$cljs$cst$711$_EQ_$$,$APP.$cljs$core$_EQ_$$,$cljs$cst$712$not_EQ_$$,$APP.$cljs$core$not_EQ_$$],null)))),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$423$qualified_symbol$$,$cljs$cst$345$double$$,$cljs$cst$344$int$$,$cljs$cst$420$float$$,$APP.$cljs$cst$219$symbol$$,$cljs$cst$422$qualified_keyword$$,$cljs$cst$419$some$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$197$nil$$,$cljs$cst$424$uuid$$,$APP.$cljs$cst$421$boolean$$,$APP.$cljs$cst$418$any$$],
[$malli$core$_simple_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$423$qualified_symbol$$,$APP.$cljs$cst$351$pred$$,$cljs$core$qualified_symbol_QMARK_$$],null)),$malli$core$_simple_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$345$double$$,$APP.$cljs$cst$351$pred$$,$cljs$core$double_QMARK_$$,$cljs$cst$413$property_pred$$,$malli$core$_min_max_pred$$(null)],null)),$malli$core$_simple_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$cljs$cst$344$int$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$int_QMARK_$$,$cljs$cst$413$property_pred$$,$malli$core$_min_max_pred$$(null)],null)),$malli$core$_simple_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$420$float$$,$APP.$cljs$cst$351$pred$$,$cljs$core$float_QMARK_$$,$cljs$cst$413$property_pred$$,$malli$core$_min_max_pred$$(null)],null)),$malli$core$_simple_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$219$symbol$$,$APP.$cljs$cst$351$pred$$,$cljs$core$symbol_QMARK_$$],null)),$malli$core$_simple_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$422$qualified_keyword$$,$APP.$cljs$cst$351$pred$$,$cljs$core$qualified_keyword_QMARK_$$,$cljs$cst$413$property_pred$$,function($properties$jscomp$15$$){var $temp__5825__auto__$jscomp$60$$=function(){var $G__32168__$1$$=$properties$jscomp$15$$==null?null:$APP.$cljs$cst$394$namespace$$.$cljs$core$IFn$_invoke$arity$1$($properties$jscomp$15$$);
return $G__32168__$1$$==null?null:$APP.$cljs$core$name$$($G__32168__$1$$)}();return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$60$$)?function($x$jscomp$733$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$namespace$$($x$jscomp$733$$),$temp__5825__auto__$jscomp$60$$)}:null}],null)),$malli$core$_simple_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$419$some$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$some_QMARK_$$],
null)),$malli$core$_simple_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$string_QMARK_$$,$cljs$cst$413$property_pred$$,$malli$core$_min_max_pred$$($APP.$cljs$core$count$$)],null)),$malli$core$_simple_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$221$keyword$$,$APP.$cljs$cst$351$pred$$,$cljs$core$keyword_QMARK_$$],null)),$malli$core$_simple_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$cljs$cst$197$nil$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$nil_QMARK_$$],null)),$malli$core$_simple_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$424$uuid$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$uuid_QMARK_$$],null)),$malli$core$_simple_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$421$boolean$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$boolean_QMARK_$$],null)),
$malli$core$_simple_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$418$any$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$any_QMARK_$$],null))]),new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$cljs$cst$713$_PLUS_$$,$malli$core$_sequence_schema$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$630$re_explainer$$,$cljs$cst$631$re_parser$$,$cljs$cst$632$re_unparser$$,$APP.$cljs$cst$139$type$$,$cljs$cst$628$child_bounds$$,$cljs$cst$633$re_transformer$$,
$cljs$cst$629$re_validator$$,$cljs$cst$634$re_min_max$$,$cljs$cst$642$keep$$],[function($_$jscomp$676_child$jscomp$14$$,$p__34258$$){$_$jscomp$676_child$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34258$$,0,null);return $malli$impl$regex$cat_explainer$$.$cljs$core$IFn$_invoke$arity$variadic$($_$jscomp$676_child$jscomp$14$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$impl$regex$_STAR__explainer$$($_$jscomp$676_child$jscomp$14$$)]))},function($_$jscomp$677_child$jscomp$15$$,
$p__34262$$){$_$jscomp$677_child$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34262$$,0,null);return $malli$impl$regex$_PLUS__parser$$($_$jscomp$677_child$jscomp$15$$)},function($_$jscomp$678_child$jscomp$16$$,$p__34266$$){$_$jscomp$678_child$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34266$$,0,null);return $malli$impl$regex$_PLUS__unparser$$($_$jscomp$678_child$jscomp$16$$)},$cljs$cst$713$_PLUS_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,1],null),function($_$jscomp$679_child$jscomp$17$$,$p__34273$$){$_$jscomp$679_child$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34273$$,0,null);return $malli$impl$regex$cat_transformer$$.$cljs$core$IFn$_invoke$arity$variadic$($_$jscomp$679_child$jscomp$17$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$impl$regex$_STAR__transformer$$($_$jscomp$679_child$jscomp$17$$)]))},function($_$jscomp$680_child$jscomp$18$$,
$p__34288$$){$_$jscomp$680_child$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34288$$,0,null);return $malli$impl$regex$cat_validator$$.$cljs$core$IFn$_invoke$arity$variadic$($_$jscomp$680_child$jscomp$18$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$impl$regex$_STAR__validator$$($_$jscomp$680_child$jscomp$18$$)]))},function($_$jscomp$681_child$jscomp$19$$,$p__34298$$){$_$jscomp$681_child$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34298$$,
0,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$338$min$$,$APP.$cljs$cst$338$min$$.$cljs$core$IFn$_invoke$arity$1$($malli$core$_regex_min_max$$($_$jscomp$681_child$jscomp$19$$,!0))],null)},!0])),$cljs$cst$714$_STAR_$$,$malli$core$_sequence_schema$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$630$re_explainer$$,$cljs$cst$631$re_parser$$,$cljs$cst$632$re_unparser$$,$APP.$cljs$cst$139$type$$,$cljs$cst$628$child_bounds$$,$cljs$cst$633$re_transformer$$,$cljs$cst$629$re_validator$$,
$cljs$cst$634$re_min_max$$,$cljs$cst$642$keep$$],[function($_$jscomp$682_child$jscomp$20$$,$p__34302$$){$_$jscomp$682_child$jscomp$20$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34302$$,0,null);return $malli$impl$regex$_STAR__explainer$$($_$jscomp$682_child$jscomp$20$$)},function($_$jscomp$683_child$jscomp$21$$,$p__34306$$){$_$jscomp$683_child$jscomp$21$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34306$$,0,null);return $malli$impl$regex$_STAR__parser$$($_$jscomp$683_child$jscomp$21$$)},
function($_$jscomp$684_child$jscomp$22$$,$p__34310$$){$_$jscomp$684_child$jscomp$22$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34310$$,0,null);return $malli$impl$regex$_STAR__unparser$$($_$jscomp$684_child$jscomp$22$$)},$cljs$cst$714$_STAR_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,1],null),function($_$jscomp$685_child$jscomp$23$$,$p__34316$$){$_$jscomp$685_child$jscomp$23$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34316$$,
0,null);return $malli$impl$regex$_STAR__transformer$$($_$jscomp$685_child$jscomp$23$$)},function($_$jscomp$686_child$jscomp$24$$,$p__34320$$){$_$jscomp$686_child$jscomp$24$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34320$$,0,null);return $malli$impl$regex$_STAR__validator$$($_$jscomp$686_child$jscomp$24$$)},function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$338$min$$,0],null)},!0])),$cljs$cst$715$_QMARK_$$,$malli$core$_sequence_schema$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$630$re_explainer$$,
$cljs$cst$631$re_parser$$,$cljs$cst$632$re_unparser$$,$APP.$cljs$cst$139$type$$,$cljs$cst$628$child_bounds$$,$cljs$cst$633$re_transformer$$,$cljs$cst$629$re_validator$$,$cljs$cst$634$re_min_max$$,$cljs$cst$642$keep$$],[function($_$jscomp$688_child$jscomp$25$$,$p__34325$$){$_$jscomp$688_child$jscomp$25$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34325$$,0,null);return $malli$impl$regex$alt_explainer$$.$cljs$core$IFn$_invoke$arity$variadic$($_$jscomp$688_child$jscomp$25$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$impl$regex$cat_explainer$$.$cljs$core$IFn$_invoke$arity$0$()]))},
function($_$jscomp$689_child$jscomp$26$$,$p__34329$$){$_$jscomp$689_child$jscomp$26$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34329$$,0,null);return $malli$impl$regex$alt_parser$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_$jscomp$689_child$jscomp$26$$,$malli$impl$regex$pure_parser$$()]))},function($_$jscomp$690_child$jscomp$27$$,$p__34333$$){$_$jscomp$690_child$jscomp$27$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34333$$,
0,null);return $malli$impl$regex$alt_unparser$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_$jscomp$690_child$jscomp$27$$,$malli$impl$regex$pure_unparser$$]))},$cljs$cst$715$_QMARK_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,1],null),function($_$jscomp$691_child$jscomp$28$$,$p__34337$$){$_$jscomp$691_child$jscomp$28$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34337$$,
0,null);return $malli$impl$regex$alt_transformer$$.$cljs$core$IFn$_invoke$arity$variadic$($_$jscomp$691_child$jscomp$28$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$impl$regex$cat_transformer$$.$cljs$core$IFn$_invoke$arity$0$()]))},function($_$jscomp$692_child$jscomp$29$$,$p__34341$$){$_$jscomp$692_child$jscomp$29$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34341$$,0,null);return $malli$impl$regex$alt_validator$$.$cljs$core$IFn$_invoke$arity$variadic$($_$jscomp$692_child$jscomp$29$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$impl$regex$cat_validator$$.$cljs$core$IFn$_invoke$arity$0$()]))},function($_$jscomp$693_child$jscomp$30$$,$p__34345$$){$_$jscomp$693_child$jscomp$30$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34345$$,0,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,0,$APP.$cljs$cst$339$max$$,$APP.$cljs$cst$339$max$$.$cljs$core$IFn$_invoke$arity$1$($malli$core$_regex_min_max$$($_$jscomp$693_child$jscomp$30$$,
!0))],null)},!0])),$APP.$cljs$cst$716$repeat$$,$malli$core$_sequence_schema$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$630$re_explainer$$,$cljs$cst$631$re_parser$$,$cljs$cst$632$re_unparser$$,$APP.$cljs$cst$139$type$$,$cljs$cst$628$child_bounds$$,$cljs$cst$633$re_transformer$$,$cljs$cst$629$re_validator$$,$cljs$cst$634$re_min_max$$,$cljs$cst$642$keep$$],[function($min$jscomp$40_p__34352$$,$child$jscomp$31_p__34353$$){var $map__34354__$1_max$jscomp$40$$=$APP.$cljs$core$__destructure_map$$($min$jscomp$40_p__34352$$);
$min$jscomp$40_p__34352$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__34354__$1_max$jscomp$40$$,$APP.$cljs$cst$338$min$$,0);$map__34354__$1_max$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__34354__$1_max$jscomp$40$$,$APP.$cljs$cst$339$max$$,Infinity);$child$jscomp$31_p__34353$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$31_p__34353$$,0,null);return $malli$impl$regex$repeat_explainer$$($min$jscomp$40_p__34352$$,$map__34354__$1_max$jscomp$40$$,
$child$jscomp$31_p__34353$$)},function($min$jscomp$41_p__34358$$,$child$jscomp$32_p__34359$$){var $map__34360__$1_max$jscomp$41$$=$APP.$cljs$core$__destructure_map$$($min$jscomp$41_p__34358$$);$min$jscomp$41_p__34358$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__34360__$1_max$jscomp$41$$,$APP.$cljs$cst$338$min$$,0);$map__34360__$1_max$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__34360__$1_max$jscomp$41$$,$APP.$cljs$cst$339$max$$,Infinity);$child$jscomp$32_p__34359$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$32_p__34359$$,0,null);return $malli$impl$regex$repeat_parser$$($min$jscomp$41_p__34358$$,$map__34360__$1_max$jscomp$41$$,$child$jscomp$32_p__34359$$)},function($min$jscomp$42_p__34364$$,$child$jscomp$33_p__34365$$){var $map__34366__$1_max$jscomp$42$$=$APP.$cljs$core$__destructure_map$$($min$jscomp$42_p__34364$$);$min$jscomp$42_p__34364$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__34366__$1_max$jscomp$42$$,$APP.$cljs$cst$338$min$$,
0);$map__34366__$1_max$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__34366__$1_max$jscomp$42$$,$APP.$cljs$cst$339$max$$,Infinity);$child$jscomp$33_p__34365$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$33_p__34365$$,0,null);return $malli$impl$regex$repeat_unparser$$($min$jscomp$42_p__34364$$,$map__34366__$1_max$jscomp$42$$,$child$jscomp$33_p__34365$$)},$APP.$cljs$cst$716$repeat$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,
1,$APP.$cljs$cst$339$max$$,1],null),function($min$jscomp$43_p__34370$$,$child$jscomp$34_p__34371$$){var $map__34372__$1_max$jscomp$43$$=$APP.$cljs$core$__destructure_map$$($min$jscomp$43_p__34370$$);$min$jscomp$43_p__34370$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__34372__$1_max$jscomp$43$$,$APP.$cljs$cst$338$min$$,0);$map__34372__$1_max$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__34372__$1_max$jscomp$43$$,$APP.$cljs$cst$339$max$$,Infinity);$child$jscomp$34_p__34371$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$34_p__34371$$,0,null);return $malli$impl$regex$repeat_transformer$$($min$jscomp$43_p__34370$$,$map__34372__$1_max$jscomp$43$$,$child$jscomp$34_p__34371$$)},function($min$jscomp$44_p__34376$$,$child$jscomp$35_p__34377$$){var $map__34378__$1_max$jscomp$44$$=$APP.$cljs$core$__destructure_map$$($min$jscomp$44_p__34376$$);$min$jscomp$44_p__34376$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__34378__$1_max$jscomp$44$$,
$APP.$cljs$cst$338$min$$,0);$map__34378__$1_max$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__34378__$1_max$jscomp$44$$,$APP.$cljs$cst$339$max$$,Infinity);$child$jscomp$35_p__34377$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$35_p__34377$$,0,null);return $malli$impl$regex$repeat_validator$$($min$jscomp$44_p__34376$$,$map__34378__$1_max$jscomp$44$$,$child$jscomp$35_p__34377$$)},function($props$jscomp$24$$,$child$jscomp$36_p__34382$$){$child$jscomp$36_p__34382$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$36_p__34382$$,0,null);return $malli$core$_re_min_max$$($cljs$core$_STAR_$$,$props$jscomp$24$$,$child$jscomp$36_p__34382$$)},!0])),$APP.$cljs$cst$594$cat$$,$malli$core$_sequence_schema$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$630$re_explainer$$,$cljs$cst$631$re_parser$$,$cljs$cst$632$re_unparser$$,$APP.$cljs$cst$139$type$$,$cljs$cst$628$child_bounds$$,$cljs$cst$633$re_transformer$$,$cljs$cst$629$re_validator$$,
$cljs$cst$634$re_min_max$$,$cljs$cst$642$keep$$],[function($_$jscomp$694$$,$children$jscomp$96$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$cat_explainer$$,$children$jscomp$96$$)},function($_$jscomp$695$$,$children$jscomp$97$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$cat_parser$$,$children$jscomp$97$$)},function($_$jscomp$696$$,$children$jscomp$98$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$cat_unparser$$,
$children$jscomp$98$$)},$APP.$cljs$cst$594$cat$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,function($_$jscomp$697$$,$children$jscomp$99$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$cat_transformer$$,$children$jscomp$99$$)},function($_$jscomp$698$$,$children$jscomp$100$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$cat_validator$$,$children$jscomp$100$$)},function($_$jscomp$699$$,$children$jscomp$101$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$core$_re_min_max$$,
$APP.$cljs$core$_PLUS_$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,0,$APP.$cljs$cst$339$max$$,0],null),$children$jscomp$101$$)},!0])),$APP.$cljs$cst$717$alt$$,$malli$core$_sequence_schema$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$630$re_explainer$$,$cljs$cst$631$re_parser$$,$cljs$cst$632$re_unparser$$,$APP.$cljs$cst$139$type$$,$cljs$cst$628$child_bounds$$,$cljs$cst$633$re_transformer$$,$cljs$cst$629$re_validator$$,$cljs$cst$634$re_min_max$$,$cljs$cst$642$keep$$],
[function($_$jscomp$700$$,$children$jscomp$102$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$alt_explainer$$,$children$jscomp$102$$)},function($_$jscomp$701$$,$children$jscomp$103$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$alt_parser$$,$children$jscomp$103$$)},function($_$jscomp$702$$,$children$jscomp$104$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$alt_unparser$$,$children$jscomp$104$$)},
$APP.$cljs$cst$717$alt$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$338$min$$,1],null),function($_$jscomp$703$$,$children$jscomp$105$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$alt_transformer$$,$children$jscomp$105$$)},function($_$jscomp$704$$,$children$jscomp$106$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$alt_validator$$,$children$jscomp$106$$)},function($_$jscomp$705$$,$children$jscomp$107$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_re_alt_min_max$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,0],null),$children$jscomp$107$$)},!0])),$cljs$cst$595$catn$$,$malli$core$_sequence_entry_schema$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$630$re_explainer$$,$cljs$cst$631$re_parser$$,$cljs$cst$632$re_unparser$$,$APP.$cljs$cst$139$type$$,$cljs$cst$628$child_bounds$$,$cljs$cst$633$re_transformer$$,$cljs$cst$629$re_validator$$,$cljs$cst$634$re_min_max$$,$cljs$cst$642$keep$$],[function($_$jscomp$706$$,$children$jscomp$108$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$cat_explainer$$,
$children$jscomp$108$$)},function($_$jscomp$707$$,$children$jscomp$109$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($malli$impl$regex$catn_parser$$,$malli$core$tags$$,$children$jscomp$109$$)},function($_$jscomp$708$$,$children$jscomp$110$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($malli$impl$regex$catn_unparser$$,$malli$core$tags_QMARK_$$,$children$jscomp$110$$)},$cljs$cst$595$catn$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,function($_$jscomp$709$$,$children$jscomp$111$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$cat_transformer$$,
$children$jscomp$111$$)},function($_$jscomp$710$$,$children$jscomp$112$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$cat_validator$$,$children$jscomp$112$$)},function($_$jscomp$711$$,$children$jscomp$113$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$core$_re_min_max$$,$APP.$cljs$core$_PLUS_$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,0,
$APP.$cljs$cst$339$max$$,0],null),$malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$last$$,$children$jscomp$113$$))},!1])),$cljs$cst$718$altn$$,$malli$core$_sequence_entry_schema$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$630$re_explainer$$,$cljs$cst$631$re_parser$$,$cljs$cst$632$re_unparser$$,$APP.$cljs$cst$139$type$$,$cljs$cst$628$child_bounds$$,$cljs$cst$633$re_transformer$$,$cljs$cst$629$re_validator$$,$cljs$cst$634$re_min_max$$,$cljs$cst$642$keep$$],
[function($_$jscomp$712$$,$children$jscomp$114$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$alt_explainer$$,$children$jscomp$114$$)},function($_$jscomp$713$$,$children$jscomp$115$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($malli$impl$regex$altn_parser$$,$malli$core$tag$$,$children$jscomp$115$$)},function($_$jscomp$714$$,$children$jscomp$116$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($malli$impl$regex$altn_unparser$$,
$malli$core$tag_QMARK_$$,$children$jscomp$116$$)},$cljs$cst$718$altn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$338$min$$,1],null),function($_$jscomp$715$$,$children$jscomp$117$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$alt_transformer$$,$children$jscomp$117$$)},function($_$jscomp$716$$,$children$jscomp$118$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$impl$regex$alt_validator$$,$children$jscomp$118$$)},function($_$jscomp$717$$,
$children$jscomp$119$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($malli$core$_re_alt_min_max$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,0],null),$malli$impl$util$_vmap$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$last$$,$children$jscomp$119$$))},!1]))],null),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$499$enum$$,$APP.$cljs$cst$298$schema$$,$cljs$cst$615$__GT_$$,$APP.$cljs$cst$516$fn$$,$cljs$cst$438$orn$$,$cljs$cst$719$seqable$$,
$cljs$cst$550$ref$$,$APP.$cljs$cst$522$maybe$$,$cljs$cst$720$sequential$$,$APP.$cljs$cst$433$or$$,$cljs$cst$512$re$$,$cljs$cst$444$not$$,$APP.$cljs$cst$498$tuple$$,$APP.$cljs$cst$200$vector$$,$cljs$cst$605$function$$,$cljs$cst$562$_EQ__GT_$$,$cljs$cst$463$map_of$$,$cljs$cst$531$multi$$,$APP.$cljs$cst$429$and$$,$cljs$cst$412$malli_DOT_core_SLASH_schema$$,$cljs$cst$721$every$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$202$map$$],[new $malli$core$t_malli$0core33210$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null)),$malli$core$_schema_schema$$(null),$malli$core$_proxy_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$615$__GT_$$,$APP.$cljs$cst$516$fn$$,function($p__33847$$,$c$jscomp$201$$,$o$jscomp$164$$){var $map__33848__$1$$=$APP.$cljs$core$__destructure_map$$($p__33847$$),$guard$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33848__$1$$,$cljs$cst$565$guard$$);
$malli$core$_check_children_BANG_$cljs$0core$0IFn$0_invoke$0arity$05$$($cljs$cst$615$__GT_$$,$map__33848__$1$$,$c$jscomp$201$$,1,null);var $c__$1$jscomp$1$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__33846_SHARP_$$){return $APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($p1__33846_SHARP_$$,$o$jscomp$164$$):$APP.$malli$core$schema$$($p1__33846_SHARP_$$,$o$jscomp$164$$)},$c$jscomp$201$$);return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$c__$1$jscomp$1$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($malli$core$_form$$,$c__$1$jscomp$1$$),new $APP.$cljs$core$Delay$$(function(){var $G__33849$jscomp$inline_3572_cc$jscomp$2$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$594$cat$$],
null),$APP.$cljs$core$pop$$($c__$1$jscomp$1$$)),$APP.$cljs$core$peek$$($c__$1$jscomp$1$$)],null);$G__33849$jscomp$inline_3572_cc$jscomp$2$$=$APP.$cljs$core$truth_$$($guard$jscomp$4$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__33849$jscomp$inline_3572_cc$jscomp$2$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$guard$jscomp$4$$],null)):$G__33849$jscomp$inline_3572_cc$jscomp$2$$;var $G__33851$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($map__33848__$1$$,
$cljs$cst$565$guard$$);return $malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$04$$?$malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$04$$($cljs$cst$562$_EQ__GT_$$,$G__33851$$,$G__33849$jscomp$inline_3572_cc$jscomp$2$$,$o$jscomp$164$$):$malli$core$into_schema$$($cljs$cst$562$_EQ__GT_$$,$G__33851$$,$G__33849$jscomp$inline_3572_cc$jscomp$2$$,$o$jscomp$164$$)})],null)}],null)),new $malli$core$t_malli$0core33358$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,
$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null)),new $malli$core$t_malli$0core32486$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null)),$malli$core$_collection_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$719$seqable$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$seqable_QMARK_$$],null)),$malli$core$_ref_schema$cljs$0core$0IFn$0_invoke$0arity$01$$(null),new $malli$core$t_malli$0core33506$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null)),$malli$core$_collection_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$720$sequential$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$sequential_QMARK_$$],null)),new $malli$core$t_malli$0core32402$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null)),new $malli$core$t_malli$0core33239$$(!1,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null)),new $malli$core$t_malli$0core32589$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null)),new $malli$core$t_malli$0core33129$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null)),$malli$core$_collection_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$vector_QMARK_$$,$APP.$cljs$cst$489$empty$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null)),new $malli$core$t_malli$0core33802$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null)),new $malli$core$t_malli$0core33759$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],
null)),new $malli$core$t_malli$0core32939$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null)),new $malli$core$t_malli$0core33658$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$371$naked_keys$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null)),new $malli$core$t_malli$0core32315$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],null)),$malli$core$_schema_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$561$raw$$,!0],null)),$malli$core$_collection_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$721$every$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$seqable_QMARK_$$,$cljs$cst$492$bounded$$,!0],null)),$malli$core$_collection_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$set_QMARK_$$,$APP.$cljs$cst$489$empty$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$cst$297$in$$,function($_$jscomp$718$$,$x$jscomp$795$$){return $x$jscomp$795$$}],null)),new $malli$core$t_malli$0core32750$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$371$naked_keys$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$417$malli_DOT_core_SLASH_into_schema$$],
null))])])),$_QMARK_registry$jscomp$inline_11438$$=$malli$registry$composite_registry$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $malli$registry$t_malli$0registry24964$$($m$jscomp$inline_11436$$,$m$jscomp$inline_11436$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),new $malli$registry$t_malli$0registry25109$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)]));$APP.$cljs$core$reset_BANG_$$($malli$registry$registry_STAR_$$,$malli$registry$registry$$($_QMARK_registry$jscomp$inline_11438$$));
$malli$core$default_registry$$=$malli$registry$registry$$(new $malli$registry$t_malli$0registry25009$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$));$APP.$JSCompiler_prototypeAlias$$=$malli$util$t_malli$0util34488$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_34490$$,$meta34489__$1$$){return new $malli$util$t_malli$0util34488$$(this.$_QMARK_schema$,this.f,this.options,this.result,$meta34489__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta34489$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Walker$_accept$arity$4$=function($_$jscomp$721_or__5025__auto__$jscomp$inline_3589$$,$JSCompiler_inline_result$jscomp$435_s$jscomp$339$$,$path$jscomp$97$$,$options__$1$jscomp$55$$){$_$jscomp$721_or__5025__auto__$jscomp$inline_3589$$=$APP.$cljs$core$_deref$$(this.result);$JSCompiler_inline_result$jscomp$435_s$jscomp$339$$=$APP.$cljs$core$truth_$$($_$jscomp$721_or__5025__auto__$jscomp$inline_3589$$)?$_$jscomp$721_or__5025__auto__$jscomp$inline_3589$$:$APP.$cljs$core$reset_BANG_$$(this.result,
this.f.$cljs$core$IFn$_invoke$arity$3$?this.f.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$435_s$jscomp$339$$,$path$jscomp$97$$,$options__$1$jscomp$55$$):this.f($JSCompiler_inline_result$jscomp$435_s$jscomp$339$$,$path$jscomp$97$$,$options__$1$jscomp$55$$));return $APP.$cljs$core$not$$($JSCompiler_inline_result$jscomp$435_s$jscomp$339$$)};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Walker$_inner$arity$4$=function($this$$jscomp$467$$,$s$jscomp$340$$,$path$jscomp$98$$,$options__$1$jscomp$56$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$(this.result))?null:$malli$core$_walk$$($s$jscomp$340$$,this,$path$jscomp$98$$,$options__$1$jscomp$56$$)};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Walker$_outer$arity$5$=function(){return null};
var $malli$util$merge$$=function $malli$util$merge$$($var_args$jscomp$494$$){switch(arguments.length){case 2:return $malli$util$merge$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $malli$util$merge$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$util$merge$$.$cljs$core$IFn$_invoke$arity$2$=function($_QMARK_schema1$jscomp$2$$,$_QMARK_schema2$jscomp$2$$){return $malli$util$merge$$.$cljs$core$IFn$_invoke$arity$3$($_QMARK_schema1$jscomp$2$$,$_QMARK_schema2$jscomp$2$$,null)};
$malli$util$merge$$.$cljs$core$IFn$_invoke$arity$3$=function($_QMARK_schema1$jscomp$3_can_distribute_QMARK__p$jscomp$83$$,$_QMARK_schema2$jscomp$3_children$jscomp$120_map__34523__$1$$,$options$jscomp$272$$){function $tear$$($t$jscomp$45$$,$s$jscomp$341$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$202$map$$,$t$jscomp$45$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$s$jscomp$341$$],null):$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$341$$)],null),$malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$341$$))}function $bear$$($p1$jscomp$8$$,$p2$jscomp$8$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($p1$jscomp$8$$)?$p2$jscomp$8$$:$p1$jscomp$8$$)?$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1$jscomp$8$$,
$p2$jscomp$8$$])):$APP.$cljs$core$truth_$$($p1$jscomp$8$$)?$p1$jscomp$8$$:$p2$jscomp$8$$}var $s1$jscomp$15$$=$APP.$cljs$core$truth_$$($_QMARK_schema1$jscomp$3_can_distribute_QMARK__p$jscomp$83$$)?$malli$core$deref_all$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema1$jscomp$3_can_distribute_QMARK__p$jscomp$83$$,$options$jscomp$272$$)):null,$s2$jscomp$12$$=$APP.$cljs$core$truth_$$($_QMARK_schema2$jscomp$3_children$jscomp$120_map__34523__$1$$)?
$malli$core$deref_all$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema2$jscomp$3_children$jscomp$120_map__34523__$1$$,$options$jscomp$272$$)):null,$t1$$=$APP.$cljs$core$truth_$$($s1$jscomp$15$$)?$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($s1$jscomp$15$$):null,$t2$$=$APP.$cljs$core$truth_$$($s2$jscomp$12$$)?$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($s2$jscomp$12$$):null;$_QMARK_schema1$jscomp$3_can_distribute_QMARK__p$jscomp$83$$=
!$APP.$cljs$core$contains_QMARK_$$($options$jscomp$272$$,$cljs$cst$730$merge_default$$)&&!$APP.$cljs$core$contains_QMARK_$$($options$jscomp$272$$,$cljs$cst$731$merge_required$$);$_QMARK_schema2$jscomp$3_children$jscomp$120_map__34523__$1$$=$APP.$cljs$core$__destructure_map$$($options$jscomp$272$$);var $merge_default$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($_QMARK_schema2$jscomp$3_children$jscomp$120_map__34523__$1$$,$cljs$cst$730$merge_default$$,function($_$jscomp$723$$,$s2__$1$$){return $s2__$1$$}),
$merge_required$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($_QMARK_schema2$jscomp$3_children$jscomp$120_map__34523__$1$$,$cljs$cst$731$merge_required$$,function($_$jscomp$724$$,$r2$$){return $r2$$});if($s1$jscomp$15$$==null)return $s2$jscomp$12$$;if($s2$jscomp$12$$==null)return $s1$jscomp$15$$;if($APP.$cljs$core$truth_$$($_QMARK_schema1$jscomp$3_can_distribute_QMARK__p$jscomp$83$$?$malli$core$_distributive_schema_QMARK_$$($s1$jscomp$15$$):$_QMARK_schema1$jscomp$3_can_distribute_QMARK__p$jscomp$83$$))return $malli$core$_distribute_to_children$$($s1$jscomp$15$$,
function($s$jscomp$342$$){return $malli$util$merge$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$342$$,$s2$jscomp$12$$,$options$jscomp$272$$)},$options$jscomp$272$$);if($APP.$cljs$core$truth_$$($_QMARK_schema1$jscomp$3_can_distribute_QMARK__p$jscomp$83$$?$malli$core$_distributive_schema_QMARK_$$($s2$jscomp$12$$):$_QMARK_schema1$jscomp$3_can_distribute_QMARK__p$jscomp$83$$))return $malli$core$_distribute_to_children$$($s2$jscomp$12$$,function($s$jscomp$343$$){return $malli$util$merge$$.$cljs$core$IFn$_invoke$arity$3$($s1$jscomp$15$$,
$s$jscomp$343$$,$options$jscomp$272$$)},$options$jscomp$272$$);if($APP.$cljs$core$not$$(function(){var $and__5023__auto__$jscomp$99_fexpr__34546$jscomp$inline_3596_fexpr__34557$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$429$and$$,null,$APP.$cljs$cst$202$map$$,null],null),null);$and__5023__auto__$jscomp$99_fexpr__34546$jscomp$inline_3596_fexpr__34557$$=$and__5023__auto__$jscomp$99_fexpr__34546$jscomp$inline_3596_fexpr__34557$$.$cljs$core$IFn$_invoke$arity$1$?
$and__5023__auto__$jscomp$99_fexpr__34546$jscomp$inline_3596_fexpr__34557$$.$cljs$core$IFn$_invoke$arity$1$($t1$$):$and__5023__auto__$jscomp$99_fexpr__34546$jscomp$inline_3596_fexpr__34557$$($t1$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$99_fexpr__34546$jscomp$inline_3596_fexpr__34557$$)?($and__5023__auto__$jscomp$99_fexpr__34546$jscomp$inline_3596_fexpr__34557$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$429$and$$,
null,$APP.$cljs$cst$202$map$$,null],null),null),$and__5023__auto__$jscomp$99_fexpr__34546$jscomp$inline_3596_fexpr__34557$$.$cljs$core$IFn$_invoke$arity$1$?$and__5023__auto__$jscomp$99_fexpr__34546$jscomp$inline_3596_fexpr__34557$$.$cljs$core$IFn$_invoke$arity$1$($t2$$):$and__5023__auto__$jscomp$99_fexpr__34546$jscomp$inline_3596_fexpr__34557$$($t2$$)):$and__5023__auto__$jscomp$99_fexpr__34546$jscomp$inline_3596_fexpr__34557$$}()))return $merge_default$$.$cljs$core$IFn$_invoke$arity$3$?$merge_default$$.$cljs$core$IFn$_invoke$arity$3$($s1$jscomp$15$$,
$s2$jscomp$12$$,$options$jscomp$272$$):$merge_default$$($s1$jscomp$15$$,$s2$jscomp$12$$,$options$jscomp$272$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($t1$$,$APP.$cljs$cst$202$map$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($t2$$,$APP.$cljs$cst$202$map$$)){$_QMARK_schema1$jscomp$3_can_distribute_QMARK__p$jscomp$83$$=$bear$$($malli$core$_properties$$($s1$jscomp$15$$),$malli$core$_properties$$($s2$jscomp$12$$));var $ks$jscomp$29$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$);
$_QMARK_schema2$jscomp$3_children$jscomp$120_map__34523__$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($form$jscomp$104$$,$p__34559$$){var $k2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34559$$,0,null);if($APP.$cljs$core$truth_$$(function(){var $fexpr__34565$$=$APP.$cljs$core$_deref$$($ks$jscomp$29$$);return $fexpr__34565$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__34565$$.$cljs$core$IFn$_invoke$arity$1$($k2$$):$fexpr__34565$$($k2$$)}()))return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc_SINGLEQUOTE_$jscomp$3$$,
$G__34480$jscomp$inline_11451_p__34566_required$jscomp$inline_11450$$){var $JSCompiler_temp$jscomp$10682_k$jscomp$inline_11445_k$jscomp$inline_14133_k1$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__34480$jscomp$inline_11451_p__34566_required$jscomp$inline_11450$$,0,null),$JSCompiler_temp_const$jscomp$10680$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10682_k$jscomp$inline_11445_k$jscomp$inline_14133_k1$jscomp$4$$,
$k2$$)){$JSCompiler_temp$jscomp$10682_k$jscomp$inline_11445_k$jscomp$inline_14133_k1$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__34480$jscomp$inline_11451_p__34566_required$jscomp$inline_11450$$,0,null);var $_QMARK_p1$jscomp$inline_11446_p$jscomp$inline_11453$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__34480$jscomp$inline_11451_p__34566_required$jscomp$inline_11450$$,1,null),$_QMARK_p$jscomp$inline_14134_s1$jscomp$inline_11447$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__34480$jscomp$inline_11451_p__34566_required$jscomp$inline_11450$$,
2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34559$$,0,null);var $_QMARK_p2$jscomp$inline_11448$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34559$$,1,null),$p__34464$jscomp$inline_14132_s$jscomp$inline_14135_s2$jscomp$inline_11449$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34559$$,2,null);$G__34480$jscomp$inline_11451_p__34566_required$jscomp$inline_11450$$=$malli$util$_required_map_entry_QMARK_$$($G__34480$jscomp$inline_11451_p__34566_required$jscomp$inline_11450$$);
var $G__34481$jscomp$inline_11452$$=$malli$util$_required_map_entry_QMARK_$$($p__34559$$);$G__34480$jscomp$inline_11451_p__34566_required$jscomp$inline_11450$$=$merge_required$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$merge_required$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($G__34480$jscomp$inline_11451_p__34566_required$jscomp$inline_11450$$,$G__34481$jscomp$inline_11452$$):$merge_required$jscomp$1$$($G__34480$jscomp$inline_11451_p__34566_required$jscomp$inline_11450$$,$G__34481$jscomp$inline_11452$$);
$_QMARK_p1$jscomp$inline_11446_p$jscomp$inline_11453$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_QMARK_p1$jscomp$inline_11446_p$jscomp$inline_11453$$,$_QMARK_p2$jscomp$inline_11448$$]));$p__34464$jscomp$inline_14132_s$jscomp$inline_14135_s2$jscomp$inline_11449$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$10682_k$jscomp$inline_11445_k$jscomp$inline_14133_k1$jscomp$4$$,
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($_QMARK_p1$jscomp$inline_11446_p$jscomp$inline_11453$$,$APP.$cljs$cst$450$optional$$,$APP.$cljs$core$not$$($G__34480$jscomp$inline_11451_p__34566_required$jscomp$inline_11450$$)),$malli$util$merge$$.$cljs$core$IFn$_invoke$arity$3$?$malli$util$merge$$.$cljs$core$IFn$_invoke$arity$3$($_QMARK_p$jscomp$inline_14134_s1$jscomp$inline_11447$$,$p__34464$jscomp$inline_14132_s$jscomp$inline_14135_s2$jscomp$inline_11449$$,$options$jscomp$272$$):$malli$util$merge$$($_QMARK_p$jscomp$inline_14134_s1$jscomp$inline_11447$$,
$p__34464$jscomp$inline_14132_s$jscomp$inline_14135_s2$jscomp$inline_11449$$,$options$jscomp$272$$)],null);$JSCompiler_temp$jscomp$10682_k$jscomp$inline_11445_k$jscomp$inline_14133_k1$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34464$jscomp$inline_14132_s$jscomp$inline_14135_s2$jscomp$inline_11449$$,0,null);$_QMARK_p$jscomp$inline_14134_s1$jscomp$inline_11447$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34464$jscomp$inline_14132_s$jscomp$inline_14135_s2$jscomp$inline_11449$$,
1,null);$p__34464$jscomp$inline_14132_s$jscomp$inline_14135_s2$jscomp$inline_11449$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34464$jscomp$inline_14132_s$jscomp$inline_14135_s2$jscomp$inline_11449$$,2,null);$JSCompiler_temp$jscomp$10682_k$jscomp$inline_11445_k$jscomp$inline_14133_k1$jscomp$4$$=$APP.$cljs$core$not$$($p__34464$jscomp$inline_14132_s$jscomp$inline_14135_s2$jscomp$inline_11449$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$JSCompiler_temp$jscomp$10682_k$jscomp$inline_11445_k$jscomp$inline_14133_k1$jscomp$4$$,$_QMARK_p$jscomp$inline_14134_s1$jscomp$inline_11447$$],null):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($_QMARK_p$jscomp$inline_14134_s1$jscomp$inline_11447$$)?$APP.$cljs$cst$450$optional$$.$cljs$core$IFn$_invoke$arity$1$($_QMARK_p$jscomp$inline_14134_s1$jscomp$inline_11447$$)===!1&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($_QMARK_p$jscomp$inline_14134_s1$jscomp$inline_11447$$)):
$_QMARK_p$jscomp$inline_14134_s1$jscomp$inline_11447$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$10682_k$jscomp$inline_11445_k$jscomp$inline_14133_k1$jscomp$4$$,$p__34464$jscomp$inline_14132_s$jscomp$inline_14135_s2$jscomp$inline_11449$$],null):$APP.$cljs$core$not$$($APP.$cljs$core$seq$$($_QMARK_p$jscomp$inline_14134_s1$jscomp$inline_11447$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$JSCompiler_temp$jscomp$10682_k$jscomp$inline_11445_k$jscomp$inline_14133_k1$jscomp$4$$,$p__34464$jscomp$inline_14132_s$jscomp$inline_14135_s2$jscomp$inline_11449$$],null):$APP.$cljs$cst$450$optional$$.$cljs$core$IFn$_invoke$arity$1$($_QMARK_p$jscomp$inline_14134_s1$jscomp$inline_11447$$)===!1?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$10682_k$jscomp$inline_11445_k$jscomp$inline_14133_k1$jscomp$4$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_p$jscomp$inline_14134_s1$jscomp$inline_11447$$,
$APP.$cljs$cst$450$optional$$),$p__34464$jscomp$inline_14132_s$jscomp$inline_14135_s2$jscomp$inline_11449$$],null):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$10682_k$jscomp$inline_11445_k$jscomp$inline_14133_k1$jscomp$4$$,$_QMARK_p$jscomp$inline_14134_s1$jscomp$inline_11447$$,$p__34464$jscomp$inline_14132_s$jscomp$inline_14135_s2$jscomp$inline_11449$$],null)}else $JSCompiler_temp$jscomp$10682_k$jscomp$inline_11445_k$jscomp$inline_14133_k1$jscomp$4$$=
$G__34480$jscomp$inline_11451_p__34566_required$jscomp$inline_11450$$;return $JSCompiler_temp_const$jscomp$10680$$.call($APP.$cljs$core$conj$$,$acc_SINGLEQUOTE_$jscomp$3$$,$JSCompiler_temp$jscomp$10682_k$jscomp$inline_11445_k$jscomp$inline_14133_k1$jscomp$4$$)},$APP.$cljs$core$PersistentVector$EMPTY$$,$form$jscomp$104$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($ks$jscomp$29$$,$APP.$cljs$core$conj$$,$k2$$);return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$104$$,
$p__34559$$)},$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($malli$core$_children$$($s1$jscomp$15$$),$malli$core$_children$$($s2$jscomp$12$$)));return $malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$cst$202$map$$,$_QMARK_schema1$jscomp$3_can_distribute_QMARK__p$jscomp$83$$,$_QMARK_schema2$jscomp$3_children$jscomp$120_map__34523__$1$$,$options$jscomp$272$$)}return function($first__34538_p__34533$$,$first__34541_p__34534$$){var $first__34538__$1_seq__34537$$=
$APP.$cljs$core$seq$$($first__34538_p__34533$$);$first__34538_p__34533$$=$APP.$cljs$core$first$$($first__34538__$1_seq__34537$$);var $seq__34537__$1_seq__34537__$2$$=$APP.$cljs$core$next$$($first__34538__$1_seq__34537$$);$first__34538__$1_seq__34537$$=$APP.$cljs$core$first$$($seq__34537__$1_seq__34537__$2$$);$seq__34537__$1_seq__34537__$2$$=$APP.$cljs$core$next$$($seq__34537__$1_seq__34537__$2$$);var $first__34541__$1_seq__34540$$=$APP.$cljs$core$seq$$($first__34541_p__34534$$);$first__34541_p__34534$$=
$APP.$cljs$core$first$$($first__34541__$1_seq__34540$$);var $seq__34540__$1_seq__34540__$2$$=$APP.$cljs$core$next$$($first__34541__$1_seq__34540$$);$first__34541__$1_seq__34540$$=$APP.$cljs$core$first$$($seq__34540__$1_seq__34540__$2$$);$seq__34540__$1_seq__34540__$2$$=$APP.$cljs$core$next$$($seq__34540__$1_seq__34540__$2$$);return $malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$cst$429$and$$,$bear$$($first__34538_p__34533$$,$first__34541_p__34534$$),$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$malli$util$merge$$.$cljs$core$IFn$_invoke$arity$3$($first__34538__$1_seq__34537$$,$first__34541__$1_seq__34540$$,$options$jscomp$272$$)],null),$seq__34537__$1_seq__34537__$2$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$seq__34540__$1_seq__34540__$2$$])),$options$jscomp$272$$)}($tear$$($t1$$,$s1$jscomp$15$$),$tear$$($t2$$,$s2$jscomp$12$$))};$malli$util$merge$$.$cljs$lang$maxFixedArity$=3;
var $malli$util$union$$=function $malli$util$union$$($var_args$jscomp$495$$){switch(arguments.length){case 2:return $malli$util$union$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $malli$util$union$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$util$union$$.$cljs$core$IFn$_invoke$arity$2$=function($_QMARK_schema1$jscomp$4$$,$_QMARK_schema2$jscomp$4$$){return $malli$util$union$$.$cljs$core$IFn$_invoke$arity$3$($_QMARK_schema1$jscomp$4$$,$_QMARK_schema2$jscomp$4$$,null)};
$malli$util$union$$.$cljs$core$IFn$_invoke$arity$3$=function($_QMARK_schema1$jscomp$5$$,$_QMARK_schema2$jscomp$5$$,$options$jscomp$273$$){return $malli$util$merge$$.$cljs$core$IFn$_invoke$arity$3$($_QMARK_schema1$jscomp$5$$,$_QMARK_schema2$jscomp$5$$,$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$273$$,$cljs$cst$730$merge_default$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$identity$$,
function($s1$jscomp$16$$,$s2$jscomp$13$$,$options__$1$jscomp$57$$){var $JSCompiler_inline_result$jscomp$10679$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($malli$core$form$$.$cljs$core$IFn$_invoke$arity$2$($s1$jscomp$16$$,null),$malli$core$form$$.$cljs$core$IFn$_invoke$arity$2$($s2$jscomp$13$$,null));return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10679$$)?$s1$jscomp$16$$:$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,$s1$jscomp$16$$,$s2$jscomp$13$$],null),$options__$1$jscomp$57$$)})),$cljs$cst$731$merge_required$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$identity$$,function($r1$jscomp$1$$,$r2$jscomp$1$$){return $APP.$cljs$core$truth_$$($r1$jscomp$1$$)?$r2$jscomp$1$$:$r1$jscomp$1$$})))};$malli$util$union$$.$cljs$lang$maxFixedArity$=3;
var $malli$util$select_keys$$=function $malli$util$select_keys$$($var_args$jscomp$506$$){switch(arguments.length){case 2:return $malli$util$select_keys$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $malli$util$select_keys$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$util$select_keys$$.$cljs$core$IFn$_invoke$arity$2$=function($_QMARK_schema$jscomp$103$$,$keys$jscomp$29$$){return $malli$util$select_keys$$.$cljs$core$IFn$_invoke$arity$3$($_QMARK_schema$jscomp$103$$,$keys$jscomp$29$$,null)};
$malli$util$select_keys$$.$cljs$core$IFn$_invoke$arity$3$=function($_QMARK_schema$jscomp$104$$,$keys$jscomp$30$$,$options$jscomp$284$$){var $key_set$jscomp$2$$=$APP.$cljs$core$set$$($keys$jscomp$30$$);return $malli$util$transform_entries$cljs$0core$0IFn$0_invoke$0arity$03$$($_QMARK_schema$jscomp$104$$,function($p1__34791_SHARP_$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($k$jscomp$406_p__34797$$){$k$jscomp$406_p__34797$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($k$jscomp$406_p__34797$$,
0,null);return $key_set$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$key_set$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$406_p__34797$$):$key_set$jscomp$2$$($k$jscomp$406_p__34797$$)},$p1__34791_SHARP_$$)},$options$jscomp$284$$)};$malli$util$select_keys$$.$cljs$lang$maxFixedArity$=3;
var $malli$util$dissoc$$=function $malli$util$dissoc$$($var_args$jscomp$508$$){switch(arguments.length){case 2:return $malli$util$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $malli$util$dissoc$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$malli$util$dissoc$$.$cljs$core$IFn$_invoke$arity$2$=function($_QMARK_schema$jscomp$107$$,$key$jscomp$243$$){return $malli$util$dissoc$$.$cljs$core$IFn$_invoke$arity$3$($_QMARK_schema$jscomp$107$$,$key$jscomp$243$$,null)};
$malli$util$dissoc$$.$cljs$core$IFn$_invoke$arity$3$=function($_QMARK_schema$jscomp$108$$,$key$jscomp$244$$,$options$jscomp$286$$){return $malli$util$transform_entries$cljs$0core$0IFn$0_invoke$0arity$03$$($_QMARK_schema$jscomp$108$$,function($p1__34813_SHARP_$$){return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($k$jscomp$409_p__34817$$){$k$jscomp$409_p__34817$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($k$jscomp$409_p__34817$$,0,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$244$$,
$k$jscomp$409_p__34817$$)},$p1__34813_SHARP_$$)},$options$jscomp$286$$)};$malli$util$dissoc$$.$cljs$lang$maxFixedArity$=3;var $app$common$schema$registry$registry$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$app$common$schema$registry$default_registry$$=$malli$registry$composite_registry$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$malli$core$default_registry$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$735$merge$$,$malli$util$_merge$$(),$APP.$cljs$cst$736$union$$,$malli$util$_union$$(),
$cljs$cst$737$select_keys$$,$malli$core$_proxy_schema$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$cljs$cst$737$select_keys$$,$cljs$cst$614$childs$$,1,$APP.$cljs$cst$338$min$$,2,$APP.$cljs$cst$339$max$$,2,$APP.$cljs$cst$516$fn$$,function($_$jscomp$730$$,$children$jscomp$122$$,$options$jscomp$293$$){var $children__$1$jscomp$19$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($children$jscomp$122$$,0,$APP.$malli$core$schema$$,$options$jscomp$293$$);return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$children__$1$jscomp$19$$,$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($children__$1$jscomp$19$$,0,$malli$core$_form$$),new $APP.$cljs$core$Delay$$(function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$APP.$cljs$core$count$$($children__$1$jscomp$19$$))){var $G__34893$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($children__$1$jscomp$19$$,0),$G__34894$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($children__$1$jscomp$19$$,
1);return $malli$util$select_keys$$.$cljs$core$IFn$_invoke$arity$3$?$malli$util$select_keys$$.$cljs$core$IFn$_invoke$arity$3$($G__34893$$,$G__34894$$,$options$jscomp$293$$):$malli$util$select_keys$$($G__34893$$,$G__34894$$,$options$jscomp$293$$)}return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($malli$util$select_keys$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($children__$1$jscomp$19$$,$options$jscomp$293$$))})],null)}],null))],null),new $malli$registry$t_malli$0registry25073$$($app$common$schema$registry$registry$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)]));var $lambdaisland$uri$platform$hex_digit$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([0,7,1,4,15,13,6,3,12,2,11,9,5,14,10,8],"0714FD63C2B95EA8".split(""));var $lambdaisland$uri$normalize$character_classes$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$738$fragment$$,$cljs$cst$739$authority$$,$cljs$cst$740$pchar$$,$cljs$cst$741$unreserved$$,$cljs$cst$742$sub_delims$$,$cljs$cst$743$gen_delims$$,$APP.$cljs$cst$744$host$$,$cljs$cst$745$reserved$$,$APP.$cljs$cst$746$alpha$$,$APP.$cljs$cst$747$query$$,$cljs$cst$748$scheme$$,$cljs$cst$749$digit$$],[$APP.$cljs$core$re_pattern$$("[^a-zA-Z0-9\\-\\._~!\\$\x26'\\(\\)\\*\\+,;\x3d:@\\/]"),
$APP.$cljs$core$re_pattern$$("[^a-zA-Z0-9\\-\\._~!\\$\x26'\\(\\)\\*\\+,;\x3d:@\\/\\?]"),$APP.$cljs$core$re_pattern$$("[^a-zA-Z0-9\\-\\._~!\\$\x26'\\(\\)\\*\\+,;\x3d:@]"),$APP.$cljs$core$re_pattern$$("[^a-zA-Z0-9\\-\\._~!\\$\x26'\\(\\)\\*\\+,;\x3d:@]"),$APP.$cljs$core$re_pattern$$("[^a-zA-Z0-9\\-\\._~]"),$APP.$cljs$core$re_pattern$$("[^!\\$\x26'\\(\\)\\*\\+,;\x3d]"),$APP.$cljs$core$re_pattern$$("[^:\\/\\?#\\[\\]@]"),$APP.$cljs$core$re_pattern$$("[^a-zA-Z0-9\\-\\._~!\\$\x26'\\(\\)\\*\\+,;\x3d\\[:\\]]"),
$APP.$cljs$core$re_pattern$$("[^:\\/\\?#\\[\\]@!\\$\x26'\\(\\)\\*\\+,;\x3d]"),$APP.$cljs$core$re_pattern$$("[^a-zA-Z]"),$APP.$cljs$core$re_pattern$$("[^a-zA-Z0-9\\-\\._~:@\\/\\?]"),$APP.$cljs$core$re_pattern$$("[^a-zA-Z0-9\\-\\+\\.]"),$APP.$cljs$core$re_pattern$$("[^0-9]")]);var $lambdaisland$uri$uri_regex$$=/^(([^:\/?#]+):)?(\/\/([^\/?#\\]*))?([^?#]*)?(\?([^#]*))?(#(.*))?$/,$lambdaisland$uri$authority_regex$$=/^(([^:]*)(:(.*))?@)?(\[[0-9a-fA-F:]+\]|[^:]*)(:(\d*))?$/;$APP.$JSCompiler_prototypeAlias$$=$lambdaisland$uri$URI$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.toString=function(){var $fragment$jscomp$inline_3628_map__31156__$1$jscomp$inline_3620$$=$APP.$cljs$core$__destructure_map$$(this),$G__31157__$1$jscomp$inline_3630_scheme$jscomp$inline_3621$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fragment$jscomp$inline_3628_map__31156__$1$jscomp$inline_3620$$,$cljs$cst$748$scheme$$),$G__31143__$2$jscomp$inline_11468_user$jscomp$inline_3622$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fragment$jscomp$inline_3628_map__31156__$1$jscomp$inline_3620$$,
$cljs$cst$750$user$$),$G__31143__$1$jscomp$inline_11467_password$jscomp$inline_3623$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fragment$jscomp$inline_3628_map__31156__$1$jscomp$inline_3620$$,$APP.$cljs$cst$751$password$$),$G__31143__$3$jscomp$inline_11469_host$jscomp$inline_3624$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fragment$jscomp$inline_3628_map__31156__$1$jscomp$inline_3620$$,$APP.$cljs$cst$744$host$$),$authority$jscomp$inline_3629_port$jscomp$inline_3625$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fragment$jscomp$inline_3628_map__31156__$1$jscomp$inline_3620$$,
$cljs$cst$752$port$$),$G__31157__$3$jscomp$inline_3631_path$jscomp$inline_3626$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fragment$jscomp$inline_3628_map__31156__$1$jscomp$inline_3620$$,$APP.$cljs$cst$296$path$$),$G__31157__$4$jscomp$inline_3632_query$jscomp$inline_3627$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fragment$jscomp$inline_3628_map__31156__$1$jscomp$inline_3620$$,$APP.$cljs$cst$747$query$$);$fragment$jscomp$inline_3628_map__31156__$1$jscomp$inline_3620$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fragment$jscomp$inline_3628_map__31156__$1$jscomp$inline_3620$$,
$APP.$cljs$cst$738$fragment$$);$APP.$cljs$core$truth_$$($G__31143__$3$jscomp$inline_11469_host$jscomp$inline_3624$$)?($G__31143__$1$jscomp$inline_11467_password$jscomp$inline_3623$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__31143__$2$jscomp$inline_11468_user$jscomp$inline_3622$$)?$G__31143__$1$jscomp$inline_11467_password$jscomp$inline_3623$$:$G__31143__$2$jscomp$inline_11468_user$jscomp$inline_3622$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__31143__$2$jscomp$inline_11468_user$jscomp$inline_3622$$),
":",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__31143__$1$jscomp$inline_11467_password$jscomp$inline_3623$$)].join(""):$G__31143__$2$jscomp$inline_11468_user$jscomp$inline_3622$$,$G__31143__$2$jscomp$inline_11468_user$jscomp$inline_3622$$=$APP.$cljs$core$truth_$$($G__31143__$2$jscomp$inline_11468_user$jscomp$inline_3622$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__31143__$1$jscomp$inline_11467_password$jscomp$inline_3623$$),"@"].join(""):$G__31143__$1$jscomp$inline_11467_password$jscomp$inline_3623$$,
$G__31143__$3$jscomp$inline_11469_host$jscomp$inline_3624$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__31143__$2$jscomp$inline_11468_user$jscomp$inline_3622$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__31143__$3$jscomp$inline_11469_host$jscomp$inline_3624$$)].join(""),$authority$jscomp$inline_3629_port$jscomp$inline_3625$$=$APP.$cljs$core$truth_$$($authority$jscomp$inline_3629_port$jscomp$inline_3625$$)?[$G__31143__$3$jscomp$inline_11469_host$jscomp$inline_3624$$,":",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($authority$jscomp$inline_3629_port$jscomp$inline_3625$$)].join(""):$G__31143__$3$jscomp$inline_11469_host$jscomp$inline_3624$$):$authority$jscomp$inline_3629_port$jscomp$inline_3625$$=null;$G__31157__$1$jscomp$inline_3630_scheme$jscomp$inline_3621$$=$APP.$cljs$core$truth_$$($G__31157__$1$jscomp$inline_3630_scheme$jscomp$inline_3621$$)?["",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__31157__$1$jscomp$inline_3630_scheme$jscomp$inline_3621$$),
":"].join(""):"";$G__31157__$3$jscomp$inline_3631_path$jscomp$inline_3626$$=[$APP.$cljs$core$truth_$$($authority$jscomp$inline_3629_port$jscomp$inline_3625$$)?[$G__31157__$1$jscomp$inline_3630_scheme$jscomp$inline_3621$$,"//",$authority$jscomp$inline_3629_port$jscomp$inline_3625$$].join(""):$G__31157__$1$jscomp$inline_3630_scheme$jscomp$inline_3621$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__31157__$3$jscomp$inline_3631_path$jscomp$inline_3626$$)].join("");$G__31157__$4$jscomp$inline_3632_query$jscomp$inline_3627$$=
$APP.$cljs$core$truth_$$($G__31157__$4$jscomp$inline_3632_query$jscomp$inline_3627$$)?[$G__31157__$3$jscomp$inline_3631_path$jscomp$inline_3626$$,"?",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__31157__$4$jscomp$inline_3632_query$jscomp$inline_3627$$)].join(""):$G__31157__$3$jscomp$inline_3631_path$jscomp$inline_3626$$;return $APP.$cljs$core$truth_$$($fragment$jscomp$inline_3628_map__31156__$1$jscomp$inline_3620$$)?[$G__31157__$4$jscomp$inline_3632_query$jscomp$inline_3627$$,"#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($fragment$jscomp$inline_3628_map__31156__$1$jscomp$inline_3620$$)].join(""):
$G__31157__$4$jscomp$inline_3632_query$jscomp$inline_3627$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$4$$,$k__5324__auto__$jscomp$4$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$4$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$4$$,$k31161$$,$else__5326__auto__$jscomp$4$$){switch($k31161$$ instanceof $APP.$cljs$core$Keyword$$?$k31161$$.$fqn$:null){case "scheme":return this.scheme;case "user":return this.$user$;case "password":return this.password;case "host":return this.host;case "port":return this.port;case "path":return this.path;case "query":return this.query;case "fragment":return this.$fragment$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,
$k31161$$,$else__5326__auto__$jscomp$4$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$4$$,$f__5344__auto__$jscomp$4$$,$init__5345__auto__$jscomp$4$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$4$$,$p__31178_v__5348__auto__$jscomp$4$$){var $k__5347__auto__$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31178_v__5348__auto__$jscomp$4$$,0,null);$p__31178_v__5348__auto__$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__31178_v__5348__auto__$jscomp$4$$,
1,null);return $f__5344__auto__$jscomp$4$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$4$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$4$$,$k__5347__auto__$jscomp$4$$,$p__31178_v__5348__auto__$jscomp$4$$):$f__5344__auto__$jscomp$4$$($ret__5346__auto__$jscomp$4$$,$k__5347__auto__$jscomp$4$$,$p__31178_v__5348__auto__$jscomp$4$$)},$init__5345__auto__$jscomp$4$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$4$$,$writer__5339__auto__$jscomp$4$$,$opts__5340__auto__$jscomp$4$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$4$$,function($keyval__5342__auto__$jscomp$4$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$4$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$4$$,$keyval__5342__auto__$jscomp$4$$)},"#lambdaisland.uri.URI{",
", ","}",$opts__5340__auto__$jscomp$4$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$748$scheme$$,this.scheme],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$750$user$$,this.$user$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$751$password$$,this.password],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$744$host$$,this.host],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$752$port$$,this.port],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$296$path$$,this.path],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$747$query$$,this.query],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$738$fragment$$,this.$fragment$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,8,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$748$scheme$$,$cljs$cst$750$user$$,$APP.$cljs$cst$751$password$$,$APP.$cljs$cst$744$host$$,$cljs$cst$752$port$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$747$query$$,$APP.$cljs$cst$738$fragment$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):
$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $lambdaisland$uri$URI$$(this.scheme,this.$user$,this.password,this.host,this.port,this.path,this.query,this.$fragment$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 8+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$30_h__5134__auto____$1$jscomp$30$$=this.$__hash$;return $h__5134__auto__$jscomp$30_h__5134__auto____$1$jscomp$30$$!=null?$h__5134__auto__$jscomp$30_h__5134__auto____$1$jscomp$30$$:this.$__hash$=$h__5134__auto__$jscomp$30_h__5134__auto____$1$jscomp$30$$=-701916260^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this31162$$,$other31163$$){return $other31163$$!=null&&this.constructor===$other31163$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.scheme,$other31163$$.scheme)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$user$,$other31163$$.$user$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.password,$other31163$$.password)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.host,
$other31163$$.host)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.port,$other31163$$.port)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.path,$other31163$$.path)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.query,$other31163$$.query)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$fragment$,$other31163$$.$fragment$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other31163$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$4$$,$k__5334__auto__$jscomp$4$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$751$password$$,null,$APP.$cljs$cst$738$fragment$$,null,$cljs$cst$752$port$$,null,$APP.$cljs$cst$744$host$$,null,$APP.$cljs$cst$747$query$$,null,$cljs$cst$750$user$$,null,$cljs$cst$748$scheme$$,
null],null),null),$k__5334__auto__$jscomp$4$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),this.$__meta$),$k__5334__auto__$jscomp$4$$):new $lambdaisland$uri$URI$$(this.scheme,this.$user$,this.password,this.host,this.port,this.path,this.query,this.$fragment$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,
$k__5334__auto__$jscomp$4$$)),null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$4$$,$k31161$jscomp$1$$){switch($k31161$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k31161$jscomp$1$$.$fqn$:null){case "scheme":case "user":case "password":case "host":case "port":case "path":case "query":case "fragment":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k31161$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$4$$,$k__5332__auto__$jscomp$4$$,$G__31160$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$748$scheme$$,$k__5332__auto__$jscomp$4$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$748$scheme$$,$k__5332__auto__$jscomp$4$$))?new $lambdaisland$uri$URI$$($G__31160$jscomp$1$$,
this.$user$,this.password,this.host,this.port,this.path,this.query,this.$fragment$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$750$user$$,$k__5332__auto__$jscomp$4$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$750$user$$,$k__5332__auto__$jscomp$4$$))?new $lambdaisland$uri$URI$$(this.scheme,$G__31160$jscomp$1$$,this.password,
this.host,this.port,this.path,this.query,this.$fragment$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$751$password$$,$k__5332__auto__$jscomp$4$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$751$password$$,$k__5332__auto__$jscomp$4$$))?new $lambdaisland$uri$URI$$(this.scheme,this.$user$,$G__31160$jscomp$1$$,
this.host,this.port,this.path,this.query,this.$fragment$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$744$host$$,$k__5332__auto__$jscomp$4$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$744$host$$,$k__5332__auto__$jscomp$4$$))?new $lambdaisland$uri$URI$$(this.scheme,this.$user$,this.password,$G__31160$jscomp$1$$,
this.port,this.path,this.query,this.$fragment$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$752$port$$,$k__5332__auto__$jscomp$4$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$752$port$$,$k__5332__auto__$jscomp$4$$))?new $lambdaisland$uri$URI$$(this.scheme,this.$user$,this.password,this.host,$G__31160$jscomp$1$$,this.path,
this.query,this.$fragment$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,$k__5332__auto__$jscomp$4$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$296$path$$,$k__5332__auto__$jscomp$4$$))?new $lambdaisland$uri$URI$$(this.scheme,this.$user$,this.password,this.host,this.port,$G__31160$jscomp$1$$,this.query,
this.$fragment$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$747$query$$,$k__5332__auto__$jscomp$4$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$747$query$$,$k__5332__auto__$jscomp$4$$))?new $lambdaisland$uri$URI$$(this.scheme,this.$user$,this.password,this.host,this.port,this.path,$G__31160$jscomp$1$$,this.$fragment$,
this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$738$fragment$$,$k__5332__auto__$jscomp$4$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$738$fragment$$,$k__5332__auto__$jscomp$4$$))?new $lambdaisland$uri$URI$$(this.scheme,this.$user$,this.password,this.host,this.port,this.path,this.query,$G__31160$jscomp$1$$,
this.$__meta$,this.$__extmap$,null):new $lambdaisland$uri$URI$$(this.scheme,this.$user$,this.password,this.host,this.port,this.path,this.query,this.$fragment$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$4$$,$G__31160$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$748$scheme$$,this.scheme,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$750$user$$,this.$user$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$751$password$$,this.password,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$744$host$$,
this.host,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$752$port$$,this.port,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$296$path$$,this.path,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$747$query$$,this.query,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$738$fragment$$,this.$fragment$,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$4$$,$G__31160$jscomp$2$$){return new $lambdaisland$uri$URI$$(this.scheme,this.$user$,this.password,this.host,this.port,this.path,this.query,this.$fragment$,$G__31160$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$4$$,$entry__5329__auto__$jscomp$4$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$4$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$4$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$4$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$4$$)};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$23$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$2024$$,$args31166$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args31166$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($kw$jscomp$3$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this,$kw$jscomp$3$$)};
$APP.$lambdaisland$uri$join$$=function $lambdaisland$uri$join$$($var_args$jscomp$518$$){for(var $args__5755__auto__$jscomp$60$$=[],$len__5749__auto___31417$$=arguments.length,$i__5750__auto___31418$$=0;;)if($i__5750__auto___31418$$<$len__5749__auto___31417$$)$args__5755__auto__$jscomp$60$$.push(arguments[$i__5750__auto___31418$$]),$i__5750__auto___31418$$+=1;else break;return $lambdaisland$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$60$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$60$$.slice(0),
0,null):null)};$APP.$lambdaisland$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$=function($uris$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($lambdaisland$uri$join_STAR_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($lambdaisland$uri$uri$$,$uris$$))};$APP.$lambdaisland$uri$join$$.$cljs$lang$maxFixedArity$=0;$APP.$lambdaisland$uri$join$$.$cljs$lang$applyTo$=function($seq31260$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq31260$$))};
$lambdaisland$uri$URI$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$lambdaisland$uri$URI$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($JSCompiler_temp_const$jscomp$10650_this$$jscomp$470$$,$writer$jscomp$131$$){$JSCompiler_temp_const$jscomp$10650_this$$jscomp$470$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$765$lambdaisland_SLASH_uri$$);var $JSCompiler_inline_result$jscomp$10651_objs$jscomp$inline_11473_sb$jscomp$inline_11475$$=$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.toString()]);var $opts$jscomp$inline_11474$$=
$cljs$core$pr_opts$$();$APP.$cljs$core$empty_QMARK_$$($JSCompiler_inline_result$jscomp$10651_objs$jscomp$inline_11473_sb$jscomp$inline_11475$$)?$JSCompiler_inline_result$jscomp$10651_objs$jscomp$inline_11473_sb$jscomp$inline_11475$$="\n":($JSCompiler_inline_result$jscomp$10651_objs$jscomp$inline_11473_sb$jscomp$inline_11475$$=$cljs$core$pr_sb_with_opts$$($JSCompiler_inline_result$jscomp$10651_objs$jscomp$inline_11473_sb$jscomp$inline_11475$$,$opts$jscomp$inline_11474$$),$JSCompiler_inline_result$jscomp$10651_objs$jscomp$inline_11473_sb$jscomp$inline_11475$$.append("\n"),
$JSCompiler_inline_result$jscomp$10651_objs$jscomp$inline_11473_sb$jscomp$inline_11475$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10651_objs$jscomp$inline_11473_sb$jscomp$inline_11475$$));return $cljs$core$write_all$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($writer$jscomp$131$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["#",$JSCompiler_temp_const$jscomp$10650_this$$jscomp$470$$," ",$JSCompiler_inline_result$jscomp$10651_objs$jscomp$inline_11473_sb$jscomp$inline_11475$$]))};
$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$cljs$cst$765$lambdaisland_SLASH_uri$$,$lambdaisland$uri$parse$$]);var $app$common$uri$percent_encode$$;
$APP.$app$common$uri$join$$=function(){function $app$common$uri$join$$($var_args$jscomp$522$$){var $G__32952__i_param32898$jscomp$1$$=null;if(arguments.length>0){$G__32952__i_param32898$jscomp$1$$=0;for(var $G__32952__a$$=Array(arguments.length-0);$G__32952__i_param32898$jscomp$1$$<$G__32952__a$$.length;)$G__32952__a$$[$G__32952__i_param32898$jscomp$1$$]=arguments[$G__32952__i_param32898$jscomp$1$$+0],++$G__32952__i_param32898$jscomp$1$$;$G__32952__i_param32898$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__32952__a$$,
0,null)}return $app$common$uri$join__delegate$$.call(this,$G__32952__i_param32898$jscomp$1$$)}function $app$common$uri$join__delegate$$($param32898$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$lambdaisland$uri$join$$,$param32898$$)}$app$common$uri$join$$.$cljs$lang$maxFixedArity$=0;$app$common$uri$join$$.$cljs$lang$applyTo$=function($arglist__32953_param32898$jscomp$2$$){$arglist__32953_param32898$jscomp$2$$=$APP.$cljs$core$seq$$($arglist__32953_param32898$jscomp$2$$);return $app$common$uri$join__delegate$$($arglist__32953_param32898$jscomp$2$$)};
$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$=$app$common$uri$join__delegate$$;return $app$common$uri$join$$}();
$app$common$uri$percent_encode$$=function(){var $app$common$uri$percent_encode$$=null;$app$common$uri$percent_encode$$=function($param32903$jscomp$1$$,$param32904$jscomp$1$$){switch(arguments.length){case 1:return $lambdaisland$uri$normalize$percent_encode$cljs$0core$0IFn$0_invoke$0arity$01$$($param32903$jscomp$1$$);case 2:return $lambdaisland$uri$normalize$percent_encode$cljs$0core$0IFn$0_invoke$0arity$02$$($param32903$jscomp$1$$,$param32904$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);
};$app$common$uri$percent_encode$$.$cljs$core$IFn$_invoke$arity$1$=function($param32902$$){return $lambdaisland$uri$normalize$percent_encode$cljs$0core$0IFn$0_invoke$0arity$01$$($param32902$$)};$app$common$uri$percent_encode$$.$cljs$core$IFn$_invoke$arity$2$=function($param32903$$,$param32904$$){return $lambdaisland$uri$normalize$percent_encode$cljs$0core$0IFn$0_invoke$0arity$02$$($param32903$$,$param32904$$)};return $app$common$uri$percent_encode$$}();
$lambdaisland$uri$URI$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$lambdaisland$uri$URI$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$471$$,$writer$jscomp$132$$){return $cljs$core$write_all$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($writer$jscomp$132$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$765$lambdaisland_SLASH_uri$$)," ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.toString()]))]))};var $app$common$encoding_impl$$={},$$jscomp$scope$624255649$0$hexMap$$=[];for(let $i$jscomp$339$$=0;$i$jscomp$339$$<256;$i$jscomp$339$$++)$$jscomp$scope$624255649$0$hexMap$$[$i$jscomp$339$$]=($i$jscomp$339$$+256).toString(16).substr(1);
(function($ALPHABET$$){function $decodeUnsafe$$($it4_source$jscomp$22$$){if(typeof $it4_source$jscomp$22$$!=="string")throw new TypeError("Expected String");if($it4_source$jscomp$22$$.length===0)return new Uint8Array;var $psz_vch$$=0,$j$jscomp$99_zeroes$jscomp$1$$=0;let $length$jscomp$34$$=0;for(;$it4_source$jscomp$22$$[$psz_vch$$]===$LEADER$$;)$j$jscomp$99_zeroes$jscomp$1$$++,$psz_vch$$++;let $size$jscomp$46$$=($it4_source$jscomp$22$$.length-$psz_vch$$)*$FACTOR$$+1>>>0,$b256$$=new Uint8Array($size$jscomp$46$$);
for(;$it4_source$jscomp$22$$[$psz_vch$$];){let $carry$jscomp$2$$=$BASE_MAP$$[$it4_source$jscomp$22$$.charCodeAt($psz_vch$$)];if($carry$jscomp$2$$===255)return;let $i$jscomp$336$$=0;for(let $it3$$=$size$jscomp$46$$-1;($carry$jscomp$2$$!==0||$i$jscomp$336$$<$length$jscomp$34$$)&&$it3$$!==-1;$it3$$--,$i$jscomp$336$$++)$carry$jscomp$2$$+=$BASE$$*$b256$$[$it3$$]>>>0,$b256$$[$it3$$]=$carry$jscomp$2$$%256>>>0,$carry$jscomp$2$$=$carry$jscomp$2$$/256>>>0;if($carry$jscomp$2$$!==0)throw Error("Non-zero carry");
$length$jscomp$34$$=$i$jscomp$336$$;$psz_vch$$++}for($it4_source$jscomp$22$$=$size$jscomp$46$$-$length$jscomp$34$$;$it4_source$jscomp$22$$!==$size$jscomp$46$$&&$b256$$[$it4_source$jscomp$22$$]===0;)$it4_source$jscomp$22$$++;for($psz_vch$$=new Uint8Array($j$jscomp$99_zeroes$jscomp$1$$+($size$jscomp$46$$-$it4_source$jscomp$22$$));$it4_source$jscomp$22$$!==$size$jscomp$46$$;)$psz_vch$$[$j$jscomp$99_zeroes$jscomp$1$$++]=$b256$$[$it4_source$jscomp$22$$++];return $psz_vch$$}if($ALPHABET$$.length>=255)throw new TypeError("Alphabet too long");
let $BASE_MAP$$=new Uint8Array(256);for(var $i$jscomp$334_j$jscomp$98$$=0;$i$jscomp$334_j$jscomp$98$$<$BASE_MAP$$.length;$i$jscomp$334_j$jscomp$98$$++)$BASE_MAP$$[$i$jscomp$334_j$jscomp$98$$]=255;for($i$jscomp$334_j$jscomp$98$$=0;$i$jscomp$334_j$jscomp$98$$<$ALPHABET$$.length;$i$jscomp$334_j$jscomp$98$$++){let $x$jscomp$799$$=$ALPHABET$$.charAt($i$jscomp$334_j$jscomp$98$$),$xc$$=$x$jscomp$799$$.charCodeAt(0);if($BASE_MAP$$[$xc$$]!==255)throw new TypeError($x$jscomp$799$$+" is ambiguous");$BASE_MAP$$[$xc$$]=
$i$jscomp$334_j$jscomp$98$$}let $BASE$$=$ALPHABET$$.length,$LEADER$$=$ALPHABET$$.charAt(0),$FACTOR$$=Math.log($BASE$$)/Math.log(256),$iFACTOR$$=Math.log(256)/Math.log($BASE$$);return{encode:function($it2_source$jscomp$21$$){$it2_source$jscomp$21$$ instanceof Uint8Array||(ArrayBuffer.isView($it2_source$jscomp$21$$)?$it2_source$jscomp$21$$=new Uint8Array($it2_source$jscomp$21$$.buffer,$it2_source$jscomp$21$$.byteOffset,$it2_source$jscomp$21$$.byteLength):Array.isArray($it2_source$jscomp$21$$)&&($it2_source$jscomp$21$$=
Uint8Array.from($it2_source$jscomp$21$$)));if(!($it2_source$jscomp$21$$ instanceof Uint8Array))throw new TypeError("Expected Uint8Array");if($it2_source$jscomp$21$$.length===0)return"";var $str$jscomp$76_zeroes$$=0;let $length$jscomp$33$$=0,$pbegin$$=0,$pend$$=$it2_source$jscomp$21$$.length;for(;$pbegin$$!==$pend$$&&$it2_source$jscomp$21$$[$pbegin$$]===0;)$pbegin$$++,$str$jscomp$76_zeroes$$++;let $size$jscomp$45$$=($pend$$-$pbegin$$)*$iFACTOR$$+1>>>0,$b58$$=new Uint8Array($size$jscomp$45$$);for(;$pbegin$$!==
$pend$$;){let $carry$jscomp$1$$=$it2_source$jscomp$21$$[$pbegin$$],$i$jscomp$335$$=0;for(let $it1$$=$size$jscomp$45$$-1;($carry$jscomp$1$$!==0||$i$jscomp$335$$<$length$jscomp$33$$)&&$it1$$!==-1;$it1$$--,$i$jscomp$335$$++)$carry$jscomp$1$$+=256*$b58$$[$it1$$]>>>0,$b58$$[$it1$$]=$carry$jscomp$1$$%$BASE$$>>>0,$carry$jscomp$1$$=$carry$jscomp$1$$/$BASE$$>>>0;if($carry$jscomp$1$$!==0)throw Error("Non-zero carry");$length$jscomp$33$$=$i$jscomp$335$$;$pbegin$$++}for($it2_source$jscomp$21$$=$size$jscomp$45$$-
$length$jscomp$33$$;$it2_source$jscomp$21$$!==$size$jscomp$45$$&&$b58$$[$it2_source$jscomp$21$$]===0;)$it2_source$jscomp$21$$++;for($str$jscomp$76_zeroes$$=$LEADER$$.repeat($str$jscomp$76_zeroes$$);$it2_source$jscomp$21$$<$size$jscomp$45$$;++$it2_source$jscomp$21$$)$str$jscomp$76_zeroes$$+=$ALPHABET$$.charAt($b58$$[$it2_source$jscomp$21$$]);return $str$jscomp$76_zeroes$$},$decodeUnsafe$:$decodeUnsafe$$,decode:function($buffer$jscomp$26_string$jscomp$8$$){if($buffer$jscomp$26_string$jscomp$8$$=$decodeUnsafe$$($buffer$jscomp$26_string$jscomp$8$$))return $buffer$jscomp$26_string$jscomp$8$$;
throw Error("Non-base"+$BASE$$+" character");}}})("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789");var $$jscomp$scope$m1561621495$1$fill$$=(()=>{if(typeof $APP.$goog$global$$.crypto!=="undefined"&&typeof $APP.$goog$global$$.crypto.getRandomValues!=="undefined")return $buf$jscomp$10$$=>{$APP.$goog$global$$.crypto.getRandomValues($buf$jscomp$10$$);return $buf$jscomp$10$$};if(typeof require==="function"){const $randomBytes$$=require("crypto").randomBytes;return $buf$jscomp$11$$=>{const $bytes$jscomp$7$$=$randomBytes$$($buf$jscomp$11$$.length);$buf$jscomp$11$$.set($bytes$jscomp$7$$);return $buf$jscomp$11$$}}console.warn("No SRNG available, switching back to Math.random.");
return $buf$jscomp$12$$=>{for(let $i$jscomp$341$$=0,$r$jscomp$57$$;$i$jscomp$341$$<$buf$jscomp$12$$.length;$i$jscomp$341$$++)($i$jscomp$341$$&3)===0&&($r$jscomp$57$$=Math.random()*4294967296),$buf$jscomp$12$$[$i$jscomp$341$$]=$r$jscomp$57$$>>>(($i$jscomp$341$$&3)<<3)&255;return $buf$jscomp$12$$}})(),$$jscomp$scope$m1561621495$6$tmpBuff$$=new ArrayBuffer(8),$$jscomp$scope$m1561621495$7$tmpView$$=new DataView($$jscomp$scope$m1561621495$6$tmpBuff$$),$$jscomp$scope$m1561621495$8$tmpInt8$$=new Uint8Array($$jscomp$scope$m1561621495$6$tmpBuff$$);
(function(){const $buff$$=new ArrayBuffer(8),$int8$$=new Uint8Array($buff$$),$view$jscomp$8$$=new DataView($buff$$);return function(){var $msb_tss$$=BigInt.asUintN(64,""+(Date.now()-16409952E5));$msb_tss$$=0n|$$jscomp$scope$m1561621495$9$nextLong$$()&0xffffffff00000000n|$msb_tss$$&4294967295n;$$jscomp$scope$m1561621495$4$setBigUint64$$($view$jscomp$8$$,0,$msb_tss$$);return $app$common$encoding_impl$$.$toBase62$($int8$$)}})();
(function(){const $arr$jscomp$144$$=new Uint8Array(16);return function(){$$jscomp$scope$m1561621495$1$fill$$($arr$jscomp$144$$);$arr$jscomp$144$$[6]=$arr$jscomp$144$$[6]&15|64;$arr$jscomp$144$$[8]=$arr$jscomp$144$$[8]&63|128;return $$jscomp$scope$624255649$2$bufferToHex$$($arr$jscomp$144$$)}})();
var $app$common$uuid_impl$v8$$=function(){function $factory$jscomp$2$$(){for(;;){let $ts$jscomp$5$$=BigInt.asUintN(64,""+(Date.now()-16409952E5));if($ts$jscomp$5$$-$lastTs$$<0)$lastRd$$=$lastRd$$&3840n|$$jscomp$scope$m1561621495$9$nextLong$$()&0xfffffffffffff0ffn,$countCs$$=0n;else{if($lastTs$$===$ts$jscomp$5$$)if($countCs$$<16383n)$lastCs$$=$lastCs$$+1n&16383n,$countCs$$++;else continue;else $lastTs$$=$ts$jscomp$5$$,$lastCs$$=$$jscomp$scope$m1561621495$9$nextLong$$()&16383n,$countCs$$=0;return $create$jscomp$1$$($ts$jscomp$5$$,
$lastRd$$,$lastCs$$)}}}function $create$jscomp$1$$($lsb_ts$jscomp$4$$,$lastRd$jscomp$1$$,$lastCs$jscomp$1$$){$lsb_ts$jscomp$4$$=0x8000000000000000n|$lsb_ts$jscomp$4$$<<14n&0x3fffffffffffc000n|$lastCs$jscomp$1$$;$$jscomp$scope$m1561621495$4$setBigUint64$$($view$jscomp$9$$,0,32768n|$lastRd$jscomp$1$$&0xffffffffffff0fffn);$$jscomp$scope$m1561621495$4$setBigUint64$$($view$jscomp$9$$,8,$lsb_ts$jscomp$4$$);return $$jscomp$scope$624255649$2$bufferToHex$$($int8$jscomp$1$$)}const $buff$jscomp$1$$=new ArrayBuffer(16),
$int8$jscomp$1$$=new Uint8Array($buff$jscomp$1$$),$view$jscomp$9$$=new DataView($buff$jscomp$1$$);let $countCs$$=0n,$lastRd$$=0n,$lastCs$$=0n,$lastTs$$=0n;$lastRd$$=$$jscomp$scope$m1561621495$9$nextLong$$()&0xfffffffffffff0ffn;$lastCs$$=$$jscomp$scope$m1561621495$9$nextLong$$()&16383n;$factory$jscomp$2$$.create=$create$jscomp$1$$;$factory$jscomp$2$$.fromArray=$u8data$$=>{$int8$jscomp$1$$.set($u8data$$);return $$jscomp$scope$624255649$2$bufferToHex$$($int8$jscomp$1$$)};$factory$jscomp$2$$.$fromUnsignedParts$=
($a$jscomp$256$$,$b$jscomp$212$$,$c$jscomp$207$$,$d$jscomp$138$$)=>{$view$jscomp$9$$.setUint32(0,$a$jscomp$256$$);$view$jscomp$9$$.setUint32(4,$b$jscomp$212$$);$view$jscomp$9$$.setUint32(8,$c$jscomp$207$$);$view$jscomp$9$$.setUint32(12,$d$jscomp$138$$);return $$jscomp$scope$624255649$2$bufferToHex$$($int8$jscomp$1$$)};$factory$jscomp$2$$.$getUnsignedParts$=$result$jscomp$100_uuid$jscomp$7$$=>{let $rest$jscomp$inline_3663$$;$int8$jscomp$1$$[0]=($rest$jscomp$inline_3663$$=parseInt($result$jscomp$100_uuid$jscomp$7$$.slice(0,
8),16))>>>24;$int8$jscomp$1$$[1]=$rest$jscomp$inline_3663$$>>>16&255;$int8$jscomp$1$$[2]=$rest$jscomp$inline_3663$$>>>8&255;$int8$jscomp$1$$[3]=$rest$jscomp$inline_3663$$&255;$int8$jscomp$1$$[4]=($rest$jscomp$inline_3663$$=parseInt($result$jscomp$100_uuid$jscomp$7$$.slice(9,13),16))>>>8;$int8$jscomp$1$$[5]=$rest$jscomp$inline_3663$$&255;$int8$jscomp$1$$[6]=($rest$jscomp$inline_3663$$=parseInt($result$jscomp$100_uuid$jscomp$7$$.slice(14,18),16))>>>8;$int8$jscomp$1$$[7]=$rest$jscomp$inline_3663$$&255;
$int8$jscomp$1$$[8]=($rest$jscomp$inline_3663$$=parseInt($result$jscomp$100_uuid$jscomp$7$$.slice(19,23),16))>>>8;$int8$jscomp$1$$[9]=$rest$jscomp$inline_3663$$&255;$int8$jscomp$1$$[10]=($rest$jscomp$inline_3663$$=parseInt($result$jscomp$100_uuid$jscomp$7$$.slice(24,36),16))/1099511627776&255;$int8$jscomp$1$$[11]=$rest$jscomp$inline_3663$$/4294967296&255;$int8$jscomp$1$$[12]=$rest$jscomp$inline_3663$$>>>24&255;$int8$jscomp$1$$[13]=$rest$jscomp$inline_3663$$>>>16&255;$int8$jscomp$1$$[14]=$rest$jscomp$inline_3663$$>>>
8&255;$int8$jscomp$1$$[15]=$rest$jscomp$inline_3663$$&255;$result$jscomp$100_uuid$jscomp$7$$=new Uint32Array(4);$result$jscomp$100_uuid$jscomp$7$$[0]=$view$jscomp$9$$.getUint32(0);$result$jscomp$100_uuid$jscomp$7$$[1]=$view$jscomp$9$$.getUint32(4);$result$jscomp$100_uuid$jscomp$7$$[2]=$view$jscomp$9$$.getUint32(8);$result$jscomp$100_uuid$jscomp$7$$[3]=$view$jscomp$9$$.getUint32(12);return $result$jscomp$100_uuid$jscomp$7$$};return $factory$jscomp$2$$}();var $app$common$uuid$regex$$;$app$common$uuid$regex$$=/^[0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F]-[0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F]-[0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F]-[0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F]-[0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F]$/;$APP.$app$common$uuid$zero$$=$APP.$cljs$core$uuid$$("00000000-0000-0000-0000-000000000000");for(var $clojure$test$$={},$clojure$test$check$$={},$arr$jscomp$inline_3665$$=[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,
null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,
null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],$i_31200$jscomp$inline_3666$$=$arr$jscomp$inline_3665$$[0]=0;;)if($i_31200$jscomp$inline_3666$$<256)$arr$jscomp$inline_3665$$[$i_31200$jscomp$inline_3666$$]=
$arr$jscomp$inline_3665$$[$i_31200$jscomp$inline_3666$$>>1]+($i_31200$jscomp$inline_3666$$&1),$i_31200$jscomp$inline_3666$$+=1;else break;var $clojure$test$check$random$longs$ONE$$=$module$contents$goog$math$Long_ONE_$$;var $clojure$test$check$random$doubles$double_unit$$;a:{for(var $i$jscomp$inline_3668$$=53,$x$jscomp$inline_3669$$=1;;){if($i$jscomp$inline_3668$$===0){$clojure$test$check$random$doubles$double_unit$$=$x$jscomp$inline_3669$$;break a}var $G__31259$jscomp$inline_3670$$=$x$jscomp$inline_3669$$/2;--$i$jscomp$inline_3668$$;$x$jscomp$inline_3669$$=$G__31259$jscomp$inline_3670$$}$clojure$test$check$random$doubles$double_unit$$=void 0}
var $clojure$test$check$random$doubles$big_double_unit$$=$clojure$test$check$random$doubles$double_unit$$*4294967296;var $clojure$test$check$random$mix_64_const_1$$=$module$contents$goog$math$Long_Long$fromString$$("bf58476d1ce4e5b9",16),$clojure$test$check$random$mix_64_const_2$$=$module$contents$goog$math$Long_Long$fromString$$("94d049bb133111eb",16),$clojure$test$check$random$mix_gamma_const_1$$=$module$contents$goog$math$Long_Long$fromString$$("ff51afd7ed558ccd",16),$clojure$test$check$random$mix_gamma_const_2$$=$module$contents$goog$math$Long_Long$fromString$$("c4ceb9fe1a85ec53",16),$clojure$test$check$random$mix_gamma_const_3$$=
$module$contents$goog$math$Long_Long$fromString$$("aaaaaaaaaaaaaaaa",16);$clojure$test$check$random$JavaUtilSplittableRandom$$.prototype.$clojure$test$check$random$IRandom$rand_long$arity$1$=function(){return $clojure$test$check$random$mix_64$$(this.state.add(this.gamma))};
$clojure$test$check$random$JavaUtilSplittableRandom$$.prototype.$clojure$test$check$random$IRandom$rand_double$arity$1$=function(){var $long$$jscomp$inline_3691_x$jscomp$inline_3692$$=this.$clojure$test$check$random$IRandom$rand_long$arity$1$(null);$long$$jscomp$inline_3691_x$jscomp$inline_3692$$=$JSCompiler_StaticMethods_shiftRightUnsigned$$($long$$jscomp$inline_3691_x$jscomp$inline_3692$$,11);return $clojure$test$check$random$doubles$double_unit$$*($long$$jscomp$inline_3691_x$jscomp$inline_3692$$.$low_$>>>
0)+$clojure$test$check$random$doubles$big_double_unit$$*$long$$jscomp$inline_3691_x$jscomp$inline_3692$$.$high_$};
$clojure$test$check$random$JavaUtilSplittableRandom$$.prototype.$clojure$test$check$random$IRandom$split$arity$1$=function(){var $state_SINGLEQUOTE_$$=this.gamma.add(this.state),$state_SINGLEQUOTE__SINGLEQUOTE_$$=this.gamma.add($state_SINGLEQUOTE_$$),$gamma_SINGLEQUOTE_$$=$clojure$test$check$random$mix_gamma$$($state_SINGLEQUOTE__SINGLEQUOTE_$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $clojure$test$check$random$JavaUtilSplittableRandom$$(this.gamma,
$state_SINGLEQUOTE__SINGLEQUOTE_$$),new $clojure$test$check$random$JavaUtilSplittableRandom$$($gamma_SINGLEQUOTE_$$,$clojure$test$check$random$mix_64$$($state_SINGLEQUOTE_$$))],null)};
$clojure$test$check$random$JavaUtilSplittableRandom$$.prototype.$clojure$test$check$random$IRandom$split_n$arity$2$=function($n_dec_this$$jscomp$476$$,$G__31371_n$jscomp$207_ret$jscomp$67$$){switch($G__31371_n$jscomp$207_ret$jscomp$67$$){case 0:return $APP.$cljs$core$PersistentVector$EMPTY$$;case 1:return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this],null);default:$n_dec_this$$jscomp$476$$=$G__31371_n$jscomp$207_ret$jscomp$67$$-1;var $G__31370_state_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1_state__$1$$=
this.state;for($G__31371_n$jscomp$207_ret$jscomp$67$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($n_dec_this$$jscomp$476$$,$APP.$cljs$core$count$$($G__31371_n$jscomp$207_ret$jscomp$67$$)))return $APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__31371_n$jscomp$207_ret$jscomp$67$$,new $clojure$test$check$random$JavaUtilSplittableRandom$$(this.gamma,$G__31370_state_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1_state__$1$$)));
var $new_rng_state_SINGLEQUOTE_$jscomp$1$$=this.gamma.add($G__31370_state_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1_state__$1$$);$G__31370_state_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1_state__$1$$=this.gamma.add($new_rng_state_SINGLEQUOTE_$jscomp$1$$);var $gamma_SINGLEQUOTE_$jscomp$1$$=$clojure$test$check$random$mix_gamma$$($G__31370_state_SINGLEQUOTE__SINGLEQUOTE_$jscomp$1_state__$1$$);$new_rng_state_SINGLEQUOTE_$jscomp$1$$=new $clojure$test$check$random$JavaUtilSplittableRandom$$($gamma_SINGLEQUOTE_$jscomp$1$$,
$clojure$test$check$random$mix_64$$($new_rng_state_SINGLEQUOTE_$jscomp$1$$));$G__31371_n$jscomp$207_ret$jscomp$67$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__31371_n$jscomp$207_ret$jscomp$67$$,$new_rng_state_SINGLEQUOTE_$jscomp$1$$)}}};
var $clojure$test$check$random$golden_gamma$$=$module$contents$goog$math$Long_Long$fromString$$("9e3779b97f4a7c15",16),$clojure$test$check$random$next_rng$$=function(){var $a$jscomp$259$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$769$state$$,$clojure$test$check$random$make_java_util_splittable_random$$((new Date).valueOf())],null));return function(){return $cljs$cst$770$returned$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$259$$,
function($map__31329__$1_p__31326_r1$jscomp$2_state$jscomp$10$$){$map__31329__$1_p__31326_r1$jscomp$2_state$jscomp$10$$=$APP.$cljs$core$__destructure_map$$($map__31329__$1_p__31326_r1$jscomp$2_state$jscomp$10$$);$map__31329__$1_p__31326_r1$jscomp$2_state$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__31329__$1_p__31326_r1$jscomp$2_state$jscomp$10$$,$APP.$cljs$cst$769$state$$);var $r2$jscomp$2_vec__31330$$=$clojure$test$check$random$split$$($map__31329__$1_p__31326_r1$jscomp$2_state$jscomp$10$$);
$map__31329__$1_p__31326_r1$jscomp$2_state$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r2$jscomp$2_vec__31330$$,0,null);$r2$jscomp$2_vec__31330$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r2$jscomp$2_vec__31330$$,1,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$769$state$$,$map__31329__$1_p__31326_r1$jscomp$2_state$jscomp$10$$,$cljs$cst$770$returned$$,$r2$jscomp$2_vec__31330$$],null)}))}}();$clojure$test$check$rose_tree$RoseTree$$.prototype.$cljs$core$IIndexed$_nth$arity$2$=function($this$$jscomp$477$$,$i$jscomp$343$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$343$$,0))return this.root;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$343$$,1))return this.children;throw Error("Index out of bounds in rose tree");};
$clojure$test$check$rose_tree$RoseTree$$.prototype.$cljs$core$IIndexed$_nth$arity$3$=function($this$$jscomp$478$$,$i$jscomp$344$$,$not_found$jscomp$65$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$344$$,0)?this.root:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$344$$,1)?this.children:$not_found$jscomp$65$$};
var $clojure$test$check$rose_tree$exclude_nth$$=function $clojure$test$check$rose_tree$exclude_nth$$($n$jscomp$208$$,$coll$jscomp$982$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $G__31328$jscomp$inline_3697_temp__5825__auto__$jscomp$67$$=$APP.$cljs$core$seq$$($coll$jscomp$982$$);if($G__31328$jscomp$inline_3697_temp__5825__auto__$jscomp$67$$)if($n$jscomp$208$$===0)var $JSCompiler_temp$jscomp$465_JSCompiler_temp$jscomp$466_JSCompiler_temp_const$jscomp$467$$=$APP.$cljs$core$rest$$($coll$jscomp$982$$);
else{$JSCompiler_temp$jscomp$465_JSCompiler_temp$jscomp$466_JSCompiler_temp_const$jscomp$467$$=$APP.$cljs$core$first$$($G__31328$jscomp$inline_3697_temp__5825__auto__$jscomp$67$$);var $G__31327$jscomp$inline_3696_JSCompiler_inline_result$jscomp$468$$=$n$jscomp$208$$-1;$G__31328$jscomp$inline_3697_temp__5825__auto__$jscomp$67$$=$APP.$cljs$core$rest$$($G__31328$jscomp$inline_3697_temp__5825__auto__$jscomp$67$$);$G__31327$jscomp$inline_3696_JSCompiler_inline_result$jscomp$468$$=$clojure$test$check$rose_tree$exclude_nth$$.$cljs$core$IFn$_invoke$arity$2$?
$clojure$test$check$rose_tree$exclude_nth$$.$cljs$core$IFn$_invoke$arity$2$($G__31327$jscomp$inline_3696_JSCompiler_inline_result$jscomp$468$$,$G__31328$jscomp$inline_3697_temp__5825__auto__$jscomp$67$$):$clojure$test$check$rose_tree$exclude_nth$$($G__31327$jscomp$inline_3696_JSCompiler_inline_result$jscomp$468$$,$G__31328$jscomp$inline_3697_temp__5825__auto__$jscomp$67$$);$JSCompiler_temp$jscomp$465_JSCompiler_temp$jscomp$466_JSCompiler_temp_const$jscomp$467$$=$APP.$cljs$core$cons$$($JSCompiler_temp$jscomp$465_JSCompiler_temp$jscomp$466_JSCompiler_temp_const$jscomp$467$$,
$G__31327$jscomp$inline_3696_JSCompiler_inline_result$jscomp$468$$)}else $JSCompiler_temp$jscomp$465_JSCompiler_temp$jscomp$466_JSCompiler_temp_const$jscomp$467$$=null;return $JSCompiler_temp$jscomp$465_JSCompiler_temp$jscomp$466_JSCompiler_temp_const$jscomp$467$$},null,null)},$clojure$test$check$rose_tree$join$$=function $clojure$test$check$rose_tree$join$$($rose$jscomp$2$$){var $outer_root$$=$rose$jscomp$2$$.root,$inner_children$$=$outer_root$$.children;return $clojure$test$check$rose_tree$make_rose$$($outer_root$$.root,
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$rose_tree$join$$,$rose$jscomp$2$$.children),$inner_children$$))},$clojure$test$check$rose_tree$fmap$$=function $clojure$test$check$rose_tree$fmap$$($f$jscomp$452$$,$rose$jscomp$3$$){return $clojure$test$check$rose_tree$make_rose$$(function(){var $G__31340$$=$rose$jscomp$3$$.root;return $f$jscomp$452$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$452$$.$cljs$core$IFn$_invoke$arity$1$($G__31340$$):
$f$jscomp$452$$($G__31340$$)}(),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__31338_SHARP_$$){return $clojure$test$check$rose_tree$fmap$$.$cljs$core$IFn$_invoke$arity$2$?$clojure$test$check$rose_tree$fmap$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$452$$,$p1__31338_SHARP_$$):$clojure$test$check$rose_tree$fmap$$($f$jscomp$452$$,$p1__31338_SHARP_$$)},$rose$jscomp$3$$.children))},$clojure$test$check$rose_tree$filter$$=function $clojure$test$check$rose_tree$filter$$($pred$jscomp$35$$,
$rose$jscomp$4$$){return $clojure$test$check$rose_tree$make_rose$$($rose$jscomp$4$$.root,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__31349_SHARP_$$){return $clojure$test$check$rose_tree$filter$$.$cljs$core$IFn$_invoke$arity$2$?$clojure$test$check$rose_tree$filter$$.$cljs$core$IFn$_invoke$arity$2$($pred$jscomp$35$$,$p1__31349_SHARP_$$):$clojure$test$check$rose_tree$filter$$($pred$jscomp$35$$,$p1__31349_SHARP_$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($G__31356_p1__31353_SHARP_$$){$G__31356_p1__31353_SHARP_$$=
$G__31356_p1__31353_SHARP_$$.root;return $pred$jscomp$35$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$35$$.$cljs$core$IFn$_invoke$arity$1$($G__31356_p1__31353_SHARP_$$):$pred$jscomp$35$$($G__31356_p1__31353_SHARP_$$)},$rose$jscomp$4$$.children)))},$clojure$test$check$rose_tree$zip$$=function $clojure$test$check$rose_tree$zip$$($f$jscomp$453$$,$roses$jscomp$1$$){return $clojure$test$check$rose_tree$make_rose$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$453$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$rose_tree$root$$,
$roses$jscomp$1$$)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__31381_SHARP_$$){return $clojure$test$check$rose_tree$zip$$.$cljs$core$IFn$_invoke$arity$2$?$clojure$test$check$rose_tree$zip$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$453$$,$p1__31381_SHARP_$$):$clojure$test$check$rose_tree$zip$$($f$jscomp$453$$,$p1__31381_SHARP_$$)},$clojure$test$check$rose_tree$permutations$$($roses$jscomp$1$$)))},$clojure$test$check$rose_tree$shrink$$=function $clojure$test$check$rose_tree$shrink$$($f$jscomp$454$$,
$roses$jscomp$3$$){return $APP.$cljs$core$seq$$($roses$jscomp$3$$)?$clojure$test$check$rose_tree$make_rose$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$454$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$rose_tree$root$$,$roses$jscomp$3$$)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__31388_SHARP_$$){return $clojure$test$check$rose_tree$shrink$$.$cljs$core$IFn$_invoke$arity$2$?$clojure$test$check$rose_tree$shrink$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$454$$,
$p1__31388_SHARP_$$):$clojure$test$check$rose_tree$shrink$$($f$jscomp$454$$,$p1__31388_SHARP_$$)},$clojure$test$check$rose_tree$remove$$($APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(Infinity,$roses$jscomp$3$$)))):$clojure$test$check$rose_tree$make_rose$$($f$jscomp$454$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$454$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$454$$(),$APP.$cljs$core$PersistentVector$EMPTY$$)};var $clojure$test$check$generators$$={};$APP.$JSCompiler_prototypeAlias$$=$clojure$test$check$generators$Generator$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$5$$,$k__5324__auto__$jscomp$5$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$5$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$5$$,$k32639$$,$else__5326__auto__$jscomp$5$$){switch($k32639$$ instanceof $APP.$cljs$core$Keyword$$?$k32639$$.$fqn$:null){case "gen":return this.$gen$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k32639$$,$else__5326__auto__$jscomp$5$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$5$$,$f__5344__auto__$jscomp$5$$,$init__5345__auto__$jscomp$5$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$5$$,$p__32651_v__5348__auto__$jscomp$5$$){var $k__5347__auto__$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32651_v__5348__auto__$jscomp$5$$,0,null);$p__32651_v__5348__auto__$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32651_v__5348__auto__$jscomp$5$$,
1,null);return $f__5344__auto__$jscomp$5$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$5$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$5$$,$k__5347__auto__$jscomp$5$$,$p__32651_v__5348__auto__$jscomp$5$$):$f__5344__auto__$jscomp$5$$($ret__5346__auto__$jscomp$5$$,$k__5347__auto__$jscomp$5$$,$p__32651_v__5348__auto__$jscomp$5$$)},$init__5345__auto__$jscomp$5$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$5$$,$writer__5339__auto__$jscomp$5$$,$opts__5340__auto__$jscomp$5$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$5$$,function($keyval__5342__auto__$jscomp$5$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$5$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$5$$,$keyval__5342__auto__$jscomp$5$$)},"#clojure.test.check.generators.Generator{",
", ","}",$opts__5340__auto__$jscomp$5$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$573$gen$$,this.$gen$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,1,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$573$gen$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $clojure$test$check$generators$Generator$$(this.$gen$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 1+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$31_h__5134__auto____$1$jscomp$31$$=this.$__hash$;return $h__5134__auto__$jscomp$31_h__5134__auto____$1$jscomp$31$$!=null?$h__5134__auto__$jscomp$31_h__5134__auto____$1$jscomp$31$$:this.$__hash$=$h__5134__auto__$jscomp$31_h__5134__auto____$1$jscomp$31$$=236843149^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this32640$$,$other32641$$){return $other32641$$!=null&&this.constructor===$other32641$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$gen$,$other32641$$.$gen$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other32641$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$5$$,$k__5334__auto__$jscomp$5$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$573$gen$$,null],null),null),$k__5334__auto__$jscomp$5$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$5$$):new $clojure$test$check$generators$Generator$$(this.$gen$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$5$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$5$$,$k32639$jscomp$1$$){switch($k32639$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k32639$jscomp$1$$.$fqn$:null){case "gen":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k32639$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$5$$,$k__5332__auto__$jscomp$5$$,$G__32638$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$573$gen$$,$k__5332__auto__$jscomp$5$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$573$gen$$,$k__5332__auto__$jscomp$5$$))?new $clojure$test$check$generators$Generator$$($G__32638$jscomp$1$$,
this.$__meta$,this.$__extmap$,null):new $clojure$test$check$generators$Generator$$(this.$gen$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$5$$,$G__32638$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$573$gen$$,this.$gen$,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$5$$,$G__32638$jscomp$2$$){return new $clojure$test$check$generators$Generator$$(this.$gen$,$G__32638$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$5$$,$entry__5329__auto__$jscomp$5$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$5$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$5$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$5$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$5$$)};
var $clojure$test$check$generators$int_rose_tree$$=function $clojure$test$check$generators$int_rose_tree$$($value$jscomp$299$$){return $clojure$test$check$rose_tree$make_rose$$($value$jscomp$299$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$generators$int_rose_tree$$,$clojure$test$check$generators$shrink_int$$($value$jscomp$299$$)))},$clojure$test$check$generators$default_such_that_opts$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$772$ex_fn$$,function($map__32883__$1_p__32882$$){$map__32883__$1_p__32882$$=
$APP.$cljs$core$__destructure_map$$($map__32883__$1_p__32882$$);var $max_tries$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__32883__$1_p__32882$$,$cljs$cst$773$max_tries$$);return $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$(["Couldn't satisfy such-that predicate after ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($max_tries$jscomp$1$$)," tries."].join(""),$map__32883__$1_p__32882$$)},$cljs$cst$773$max_tries$$,10],null),$clojure$test$check$generators$such_that$$=
function $clojure$test$check$generators$such_that$$($var_args$jscomp$529$$){switch(arguments.length){case 2:return $clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$2$=function($pred$jscomp$37$$,$gen$jscomp$6$$){return $clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$3$($pred$jscomp$37$$,$gen$jscomp$6$$,10)};
$clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$3$=function($pred$jscomp$38$$,$gen$jscomp$7$$,$JSCompiler_temp$jscomp$474_max_tries_or_opts$$){if($APP.$cljs$core$integer_QMARK_$$($JSCompiler_temp$jscomp$474_max_tries_or_opts$$))$JSCompiler_temp$jscomp$474_max_tries_or_opts$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$773$max_tries$$,$JSCompiler_temp$jscomp$474_max_tries_or_opts$$],null);else if(!$APP.$cljs$core$map_QMARK_$$($JSCompiler_temp$jscomp$474_max_tries_or_opts$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Bad argument to such-that!",
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$774$max_tries_or_opts$$,$JSCompiler_temp$jscomp$474_max_tries_or_opts$$],null));var $opts__$1$jscomp$15$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$clojure$test$check$generators$default_such_that_opts$$,$JSCompiler_temp$jscomp$474_max_tries_or_opts$$]));return $clojure$test$check$generators$make_gen$$(function($rand_seed$$,$size$jscomp$58$$){return $clojure$test$check$generators$such_that_helper$$($pred$jscomp$38$$,
$gen$jscomp$7$$,$opts__$1$jscomp$15$$,$rand_seed$$,$size$jscomp$58$$)})};$clojure$test$check$generators$such_that$$.$cljs$lang$maxFixedArity$=3;
var $clojure$test$check$generators$boolean$0$$=$clojure$test$check$generators$elements$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[!1,!0],null)),$clojure$test$check$generators$tuple$$=function $clojure$test$check$generators$tuple$$($var_args$jscomp$530$$){for(var $args__5755__auto__$jscomp$62$$=[],$len__5749__auto___33377$$=arguments.length,$i__5750__auto___33378$$=0;;)if($i__5750__auto___33378$$<$len__5749__auto___33377$$)$args__5755__auto__$jscomp$62$$.push(arguments[$i__5750__auto___33378$$]),
$i__5750__auto___33378$$+=1;else break;return $clojure$test$check$generators$tuple$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$62$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$62$$.slice(0),0,null):null)};
$clojure$test$check$generators$tuple$$.$cljs$core$IFn$_invoke$arity$variadic$=function($generators$jscomp$1$$){return $clojure$test$check$generators$gen_fmap$$(function($roses$jscomp$7$$){return $clojure$test$check$rose_tree$zip$$($APP.$cljs$core$vector$$,$roses$jscomp$7$$)},$clojure$test$check$generators$gen_tuple$$($generators$jscomp$1$$))};$clojure$test$check$generators$tuple$$.$cljs$lang$maxFixedArity$=0;$clojure$test$check$generators$tuple$$.$cljs$lang$applyTo$=function($seq32897$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq32897$$))};
var $clojure$test$check$generators$nat$$=$clojure$test$check$generators$sized$$(function($size$jscomp$59$$){return $clojure$test$check$generators$choose$$(0,$size$jscomp$59$$)}),$clojure$test$check$generators$small_integer$$=$clojure$test$check$generators$sized$$(function($size$jscomp$60$$){return $clojure$test$check$generators$choose$$(-$size$jscomp$60$$,$size$jscomp$60$$)}),$clojure$test$check$generators$neg_int$$=$clojure$test$check$generators$fmap$$(function($p1__32907_SHARP_$$){return-1*$p1__32907_SHARP_$$},
$clojure$test$check$generators$nat$$);$clojure$test$check$generators$fmap$$($APP.$cljs$core$inc$$,$clojure$test$check$generators$nat$$);$clojure$test$check$generators$fmap$$($APP.$cljs$core$dec$$,$clojure$test$check$generators$neg_int$$);
var $clojure$test$check$generators$vector$$=function $clojure$test$check$generators$vector$$($var_args$jscomp$531$$){switch(arguments.length){case 1:return $clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$1$=function($generator$jscomp$10$$){return $clojure$test$check$generators$gen_bind$$($clojure$test$check$generators$sized$$(function($p1__32908_SHARP_$$){return $clojure$test$check$generators$choose$$(0,$p1__32908_SHARP_$$)}),function($num_elements_rose$$){return $clojure$test$check$generators$gen_fmap$$(function($roses$jscomp$8$$){return $clojure$test$check$rose_tree$shrink_vector$$($APP.$cljs$core$vector$$,$roses$jscomp$8$$)},
$clojure$test$check$generators$gen_tuple$$($APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($num_elements_rose$$.root,$generator$jscomp$10$$)))})};$clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$2$=function($generator$jscomp$11$$,$num_elements$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$generators$tuple$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($num_elements$$,$generator$jscomp$11$$))};
$clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$3$=function($generator$jscomp$12$$,$min_elements$$,$max_elements$$){return $clojure$test$check$generators$gen_bind$$($clojure$test$check$generators$choose$$($min_elements$$,$max_elements$$),function($num_elements_rose$jscomp$1$$){return $clojure$test$check$generators$gen_fmap$$(function($roses$jscomp$9$$){return $clojure$test$check$rose_tree$filter$$(function($v$jscomp$206$$){return $APP.$cljs$core$count$$($v$jscomp$206$$)>=$min_elements$$&&
$APP.$cljs$core$count$$($v$jscomp$206$$)<=$max_elements$$},$clojure$test$check$rose_tree$shrink_vector$$($APP.$cljs$core$vector$$,$roses$jscomp$9$$))},$clojure$test$check$generators$gen_tuple$$($APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($num_elements_rose$jscomp$1$$.root,$generator$jscomp$12$$)))})};$clojure$test$check$generators$vector$$.$cljs$lang$maxFixedArity$=3;
var $clojure$test$check$generators$set$$=function $clojure$test$check$generators$set$$($var_args$jscomp$538$$){switch(arguments.length){case 1:return $clojure$test$check$generators$set$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $clojure$test$check$generators$set$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$clojure$test$check$generators$set$$.$cljs$core$IFn$_invoke$arity$1$=function($gen$jscomp$21$$){return $clojure$test$check$generators$set$$.$cljs$core$IFn$_invoke$arity$2$($gen$jscomp$21$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$clojure$test$check$generators$set$$.$cljs$core$IFn$_invoke$arity$2$=function($gen$jscomp$22$$,$opts$jscomp$209$$){return $clojure$test$check$generators$coll_distinct_by$$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$identity$$,!1,!1,$gen$jscomp$22$$,$opts$jscomp$209$$)};
$clojure$test$check$generators$set$$.$cljs$lang$maxFixedArity$=2;
var $clojure$test$check$generators$map$$=function $clojure$test$check$generators$map$$($var_args$jscomp$540$$){switch(arguments.length){case 2:return $clojure$test$check$generators$map$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $clojure$test$check$generators$map$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$clojure$test$check$generators$map$$.$cljs$core$IFn$_invoke$arity$2$=function($key_gen$$,$val_gen$$){return $clojure$test$check$generators$map$$.$cljs$core$IFn$_invoke$arity$3$($key_gen$$,$val_gen$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$clojure$test$check$generators$map$$.$cljs$core$IFn$_invoke$arity$3$=function($key_gen$jscomp$1$$,$val_gen$jscomp$1$$,$opts$jscomp$211$$){return $clojure$test$check$generators$coll_distinct_by$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$first$$,!1,!1,$clojure$test$check$generators$tuple$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$key_gen$jscomp$1$$,$val_gen$jscomp$1$$])),$opts$jscomp$211$$)};
$clojure$test$check$generators$map$$.$cljs$lang$maxFixedArity$=3;
var $clojure$test$check$generators$gen_raw_long$$=$clojure$test$check$generators$make_gen$$(function($rnd$jscomp$11_x$jscomp$inline_3717$$){$rnd$jscomp$11_x$jscomp$inline_3717$$=$clojure$test$check$random$rand_long$$($rnd$jscomp$11_x$jscomp$inline_3717$$);return $clojure$test$check$rose_tree$make_rose$$($rnd$jscomp$11_x$jscomp$inline_3717$$,$APP.$cljs$core$PersistentVector$EMPTY$$)}),$clojure$test$check$generators$MAX_INTEGER$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$_STAR_$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$(53,
2))-1,$clojure$test$check$generators$MIN_INTEGER$$=-$clojure$test$check$generators$MAX_INTEGER$$,$clojure$test$check$generators$large_integer$$=$clojure$test$check$generators$large_integer_STAR_$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$clojure$test$check$generators$POS_INFINITY$$=Number.POSITIVE_INFINITY,$clojure$test$check$generators$NEG_INFINITY$$=Number.NEGATIVE_INFINITY,$clojure$test$check$generators$MAX_POS_VALUE$$=Number.MAX_VALUE,$clojure$test$check$generators$MIN_NEG_VALUE$$=-$clojure$test$check$generators$MAX_POS_VALUE$$,
$clojure$test$check$generators$NAN$$=Number.NaN,$clojure$test$check$generators$uniform_integer$$=function $clojure$test$check$generators$uniform_integer$$($bit_count$jscomp$2$$){return $bit_count$jscomp$2$$<=32?$clojure$test$check$generators$choose$$(0,function(){switch($APP.$cljs$core$fix$$($bit_count$jscomp$2$$)){case 32:return 4294967295;case 31:return 2147483647;default:return(1<<$bit_count$jscomp$2$$)-1}}()):$clojure$test$check$generators$fmap$$(function($lower$jscomp$3_p__33058$$){var $upper$jscomp$3$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lower$jscomp$3_p__33058$$,0,null);$lower$jscomp$3_p__33058$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lower$jscomp$3_p__33058$$,1,null);return $upper$jscomp$3$$*4294967296+$lower$jscomp$3_p__33058$$},$clojure$test$check$generators$tuple$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([function(){var $G__33062$$=$bit_count$jscomp$2$$-32;return $clojure$test$check$generators$uniform_integer$$.$cljs$core$IFn$_invoke$arity$1$?
$clojure$test$check$generators$uniform_integer$$.$cljs$core$IFn$_invoke$arity$1$($G__33062$$):$clojure$test$check$generators$uniform_integer$$($G__33062$$)}(),$clojure$test$check$generators$uniform_integer$$.$cljs$core$IFn$_invoke$arity$1$?$clojure$test$check$generators$uniform_integer$$.$cljs$core$IFn$_invoke$arity$1$(32):$clojure$test$check$generators$uniform_integer$$(32)])))},$clojure$test$check$generators$backwards_shrinking_significand$$=$clojure$test$check$generators$fmap$$(function($n$jscomp$213_n__$1$jscomp$6$$){for(var $out$jscomp$17$$=
0,$G__33515_out_shifter$$=4503599627370496;;){if($n$jscomp$213_n__$1$jscomp$6$$<1)return $out$jscomp$17$$*$G__33515_out_shifter$$;var $G__33514$$=$n$jscomp$213_n__$1$jscomp$6$$/2;$G__33515_out_shifter$$/=2;$out$jscomp$17$$=$out$jscomp$17$$*2+($n$jscomp$213_n__$1$jscomp$6$$&1);$n$jscomp$213_n__$1$jscomp$6$$=$G__33514$$}},$clojure$test$check$generators$sized$$(function($size$jscomp$63$$){return $clojure$test$check$generators$gen_bind$$($clojure$test$check$generators$choose$$(0,$size$jscomp$63$$<52?
$size$jscomp$63$$:52),function($rose$jscomp$16$$){return $clojure$test$check$generators$uniform_integer$$($rose$jscomp$16$$.root)})})),$clojure$test$check$generators$block_bounds$$=function $clojure$test$check$generators$block_bounds$$($exp$jscomp$2_low$jscomp$10$$,$G__33091$jscomp$inline_3719_high$jscomp$10_sign$jscomp$3_vec__33087$$){return $G__33091$jscomp$inline_3719_high$jscomp$10_sign$jscomp$3_vec__33087$$<0?($G__33091$jscomp$inline_3719_high$jscomp$10_sign$jscomp$3_vec__33087$$=-$G__33091$jscomp$inline_3719_high$jscomp$10_sign$jscomp$3_vec__33087$$,
$G__33091$jscomp$inline_3719_high$jscomp$10_sign$jscomp$3_vec__33087$$=$clojure$test$check$generators$block_bounds$$.$cljs$core$IFn$_invoke$arity$2$?$clojure$test$check$generators$block_bounds$$.$cljs$core$IFn$_invoke$arity$2$($exp$jscomp$2_low$jscomp$10$$,$G__33091$jscomp$inline_3719_high$jscomp$10_sign$jscomp$3_vec__33087$$):$clojure$test$check$generators$block_bounds$$($exp$jscomp$2_low$jscomp$10$$,$G__33091$jscomp$inline_3719_high$jscomp$10_sign$jscomp$3_vec__33087$$),$exp$jscomp$2_low$jscomp$10$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__33091$jscomp$inline_3719_high$jscomp$10_sign$jscomp$3_vec__33087$$,0,null),$G__33091$jscomp$inline_3719_high$jscomp$10_sign$jscomp$3_vec__33087$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__33091$jscomp$inline_3719_high$jscomp$10_sign$jscomp$3_vec__33087$$,1,null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[-$G__33091$jscomp$inline_3719_high$jscomp$10_sign$jscomp$3_vec__33087$$,
-$exp$jscomp$2_low$jscomp$10$$],null)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(-1023,$exp$jscomp$2_low$jscomp$10$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,2.225073858507201E-308],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1*Math.pow(2,$exp$jscomp$2_low$jscomp$10$$),0xfffffffffffff*Math.pow(2,$exp$jscomp$2_low$jscomp$10$$-51)],null)},$clojure$test$check$generators$double$0$$=
$clojure$test$check$generators$double_STAR_$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$clojure$test$check$generators$char$0$$=$clojure$test$check$generators$fmap$$($APP.$cljs$core$char$0$$,$clojure$test$check$generators$choose$$(0,255)),$clojure$test$check$generators$char_ascii$$=$clojure$test$check$generators$fmap$$($APP.$cljs$core$char$0$$,$clojure$test$check$generators$choose$$(32,126)),$clojure$test$check$generators$char_alphanumeric$$=$clojure$test$check$generators$fmap$$($APP.$cljs$core$char$0$$,
$clojure$test$check$generators$one_of$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$clojure$test$check$generators$choose$$(48,57),$clojure$test$check$generators$choose$$(65,90),$clojure$test$check$generators$choose$$(97,122)],null))),$clojure$test$check$generators$char_alpha$$=$clojure$test$check$generators$fmap$$($APP.$cljs$core$char$0$$,$clojure$test$check$generators$one_of$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$clojure$test$check$generators$choose$$(65,90),$clojure$test$check$generators$choose$$(97,122)],null))),$clojure$test$check$generators$char_symbol_special$$=$clojure$test$check$generators$elements$$(new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"*+!-_?.".split(""),null)),$clojure$test$check$generators$char_symbol_noninitial$$=$clojure$test$check$generators$frequency$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[14,$clojure$test$check$generators$char_alphanumeric$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[7,$clojure$test$check$generators$char_symbol_special$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,$clojure$test$check$generators$return$0$$(":")],null)],null)),$clojure$test$check$generators$char_symbol_initial$$=
$clojure$test$check$generators$frequency$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[2,$clojure$test$check$generators$char_alpha$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,$clojure$test$check$generators$char_symbol_special$$],null)],null)),$clojure$test$check$generators$string$$=$clojure$test$check$generators$fmap$$($APP.$clojure$string$join$$,
$clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$1$($clojure$test$check$generators$char$0$$)),$clojure$test$check$generators$string_ascii$$=$clojure$test$check$generators$fmap$$($APP.$clojure$string$join$$,$clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$1$($clojure$test$check$generators$char_ascii$$)),$clojure$test$check$generators$string_alphanumeric$$=$clojure$test$check$generators$fmap$$($APP.$clojure$string$join$$,$clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$1$($clojure$test$check$generators$char_alphanumeric$$)),
$clojure$test$check$generators$symbol_name_or_namespace$$=$clojure$test$check$generators$fmap$$(function($cs$jscomp$1_p__33155$$){var $c$jscomp$211_s$jscomp$365$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cs$jscomp$1_p__33155$$,0,null);$cs$jscomp$1_p__33155$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cs$jscomp$1_p__33155$$,1,null);$c$jscomp$211_s$jscomp$365$$=$APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$cons$$($c$jscomp$211_s$jscomp$365$$,
$cs$jscomp$1_p__33155$$));return $APP.$clojure$string$replace$$($APP.$clojure$string$replace$$($c$jscomp$211_s$jscomp$365$$,/:{2,}/,":"),/:$/,"")},$clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$2$(function($d$jscomp$143_p__33159_vec__33163$$){var $JSCompiler_inline_result$jscomp$inline_11503_and__5023__auto____$1$jscomp$inline_11504_c$jscomp$212$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($d$jscomp$143_p__33159_vec__33163$$,0,null);$d$jscomp$143_p__33159_vec__33163$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($d$jscomp$143_p__33159_vec__33163$$,1,null);$d$jscomp$143_p__33159_vec__33163$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($d$jscomp$143_p__33159_vec__33163$$,0,null);$JSCompiler_inline_result$jscomp$inline_11503_and__5023__auto____$1$jscomp$inline_11504_c$jscomp$212$$=$APP.$cljs$core$truth_$$($d$jscomp$143_p__33159_vec__33163$$)?($JSCompiler_inline_result$jscomp$inline_11503_and__5023__auto____$1$jscomp$inline_11504_c$jscomp$212$$=
"+"===$JSCompiler_inline_result$jscomp$inline_11503_and__5023__auto____$1$jscomp$inline_11504_c$jscomp$212$$||"-"===$JSCompiler_inline_result$jscomp$inline_11503_and__5023__auto____$1$jscomp$inline_11504_c$jscomp$212$$)?!/[^0-9]/.test($d$jscomp$143_p__33159_vec__33163$$):$JSCompiler_inline_result$jscomp$inline_11503_and__5023__auto____$1$jscomp$inline_11504_c$jscomp$212$$:$d$jscomp$143_p__33159_vec__33163$$;return!$APP.$cljs$core$boolean$0$$($JSCompiler_inline_result$jscomp$inline_11503_and__5023__auto____$1$jscomp$inline_11504_c$jscomp$212$$)},
$clojure$test$check$generators$tuple$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$clojure$test$check$generators$char_symbol_initial$$,$clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$1$($clojure$test$check$generators$char_symbol_noninitial$$)])))),$clojure$test$check$generators$keyword$$=$clojure$test$check$generators$resize_symbolish_generator$$($clojure$test$check$generators$fmap$$($APP.$cljs$core$keyword$$,$clojure$test$check$generators$symbol_name_or_namespace$$)),
$clojure$test$check$generators$keyword_ns$$=$clojure$test$check$generators$resize_symbolish_generator$$($clojure$test$check$generators$fmap$$(function($name$jscomp$127_p__33180$$){var $ns$jscomp$27$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$127_p__33180$$,0,null);$name$jscomp$127_p__33180$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$127_p__33180$$,1,null);return $APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$($ns$jscomp$27$$,$name$jscomp$127_p__33180$$)},
$clojure$test$check$generators$tuple$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$clojure$test$check$generators$symbol_name_or_namespace$$,$clojure$test$check$generators$symbol_name_or_namespace$$])))),$clojure$test$check$generators$symbol$$=$clojure$test$check$generators$frequency$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[100,$clojure$test$check$generators$resize_symbolish_generator$$($clojure$test$check$generators$fmap$$($APP.$cljs$core$symbol$$,$clojure$test$check$generators$symbol_name_or_namespace$$))],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,$clojure$test$check$generators$return$0$$($APP.$cljs$cst$220$_SLASH_$$)],null)],null)),$clojure$test$check$generators$symbol_ns$$=$clojure$test$check$generators$resize_symbolish_generator$$($clojure$test$check$generators$fmap$$(function($name$jscomp$128_p__33200$$){var $ns$jscomp$28$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$128_p__33200$$,0,null);$name$jscomp$128_p__33200$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$128_p__33200$$,1,null);return $APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$($ns$jscomp$28$$,$name$jscomp$128_p__33200$$)},$clojure$test$check$generators$tuple$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$clojure$test$check$generators$symbol_name_or_namespace$$,
$clojure$test$check$generators$symbol_name_or_namespace$$])))),$clojure$test$check$generators$ratio$$=$clojure$test$check$generators$fmap$$(function($b$jscomp$215_p__33204$$){var $a$jscomp$260$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$215_p__33204$$,0,null);$b$jscomp$215_p__33204$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$215_p__33204$$,1,null);return $a$jscomp$260$$/$b$jscomp$215_p__33204$$},$clojure$test$check$generators$tuple$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$clojure$test$check$generators$small_integer$$,
$clojure$test$check$generators$fmap$$($APP.$cljs$core$inc$$,$clojure$test$check$generators$nat$$)]))),$clojure$test$check$generators$uuid$$=function($gen$jscomp$9$$){return $clojure$test$check$generators$gen_fmap$$(function($rose$jscomp$13$$){return $clojure$test$check$rose_tree$make_rose$$($rose$jscomp$13$$.root,$APP.$cljs$core$PersistentVector$EMPTY$$)},$gen$jscomp$9$$)}($clojure$test$check$generators$fmap$$(function($nibbles$$){function $hex$jscomp$1$$($idx$jscomp$52$$){return($nibbles$$.$cljs$core$IFn$_invoke$arity$1$?
$nibbles$$.$cljs$core$IFn$_invoke$arity$1$($idx$jscomp$52$$):$nibbles$$($idx$jscomp$52$$)).toString(16)}var $rhex$$=((($nibbles$$.$cljs$core$IFn$_invoke$arity$1$?$nibbles$$.$cljs$core$IFn$_invoke$arity$1$(15):$nibbles$$(15))&3)+8).toString(16);return $APP.$cljs$core$uuid$$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(0)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(1)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(2)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(3)),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(4)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(5)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(6)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(7)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(8)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(9)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(10)),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(11)),"-4",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(12)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(13)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(14)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($rhex$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(16)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(17)),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(18)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(19)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(20)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(21)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(22)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(23)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(24)),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(25)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(26)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(27)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(28)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(29)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($hex$jscomp$1$$(30))].join(""))},$clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$generators$choose$$(0,
15),31)));$clojure$test$check$generators$base_simple_type$$($clojure$test$check$generators$double$0$$,$clojure$test$check$generators$char$0$$,$clojure$test$check$generators$string$$);var $clojure$test$check$generators$simple_type_printable$$=$clojure$test$check$generators$base_simple_type$$($clojure$test$check$generators$double$0$$,$clojure$test$check$generators$char_ascii$$,$clojure$test$check$generators$string_ascii$$);
$clojure$test$check$generators$base_simple_type$$($clojure$test$check$generators$double_STAR_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$779$NaN_QMARK_$$,!1],null)),$clojure$test$check$generators$char$0$$,$clojure$test$check$generators$string$$);$clojure$test$check$generators$base_simple_type$$($clojure$test$check$generators$double_STAR_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$779$NaN_QMARK_$$,!1],null)),$clojure$test$check$generators$char_ascii$$,$clojure$test$check$generators$string_ascii$$);
var $log2_33598$$=Math.log(2),$clojure$test$check$generators$random_pseudofactoring$$=function $clojure$test$check$generators$random_pseudofactoring$$($n$jscomp$214$$,$r2$jscomp$6_rng$jscomp$49_vec__33215$$){if($n$jscomp$214$$<=2)return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$n$jscomp$214$$],null);var $log_n1_x$jscomp$inline_11507$$=Math.log($n$jscomp$214$$);$r2$jscomp$6_rng$jscomp$49_vec__33215$$=$clojure$test$check$random$split$$($r2$jscomp$6_rng$jscomp$49_vec__33215$$);
var $n2_r1$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r2$jscomp$6_rng$jscomp$49_vec__33215$$,0,null);$r2$jscomp$6_rng$jscomp$49_vec__33215$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r2$jscomp$6_rng$jscomp$49_vec__33215$$,1,null);$log_n1_x$jscomp$inline_11507$$=Math.exp($clojure$test$check$random$rand_double$$($n2_r1$jscomp$6$$)*($log_n1_x$jscomp$inline_11507$$-$log2_33598$$)+$log2_33598$$);$log_n1_x$jscomp$inline_11507$$=$APP.$cljs$core$fix$$($log_n1_x$jscomp$inline_11507$$);
$n2_r1$jscomp$6$$=$APP.$cljs$core$quot$$($n$jscomp$214$$,$log_n1_x$jscomp$inline_11507$$);return 1<$log_n1_x$jscomp$inline_11507$$&&1<$n2_r1$jscomp$6$$?$APP.$cljs$core$cons$$($log_n1_x$jscomp$inline_11507$$,$clojure$test$check$generators$random_pseudofactoring$$.$cljs$core$IFn$_invoke$arity$2$?$clojure$test$check$generators$random_pseudofactoring$$.$cljs$core$IFn$_invoke$arity$2$($n2_r1$jscomp$6$$,$r2$jscomp$6_rng$jscomp$49_vec__33215$$):$clojure$test$check$generators$random_pseudofactoring$$($n2_r1$jscomp$6$$,
$r2$jscomp$6_rng$jscomp$49_vec__33215$$)):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$n$jscomp$214$$],null)},$clojure$test$check$generators$any_printable$$=$clojure$test$check$generators$recursive_gen$$(function($inner_type$$){return $clojure$test$check$generators$one_of$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$1$($inner_type$$),
$clojure$test$check$generators$list$$($inner_type$$),$clojure$test$check$generators$set$$.$cljs$core$IFn$_invoke$arity$1$($clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$generators$hashable_QMARK_$$,$inner_type$$)),$clojure$test$check$generators$scale$$(function($p1__33213_SHARP_$$){return $APP.$cljs$core$quot$$($p1__33213_SHARP_$$,2)},$clojure$test$check$generators$map$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$generators$hashable_QMARK_$$,
$inner_type$$),$inner_type$$))],null))},$clojure$test$check$generators$simple_type_printable$$);$cljs$spec$gen$alpha$LazyVar$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){if(this.$cached$!=null)return this.$cached$;var $x$jscomp$822$$=this.f.$cljs$core$IFn$_invoke$arity$0$?this.f.$cljs$core$IFn$_invoke$arity$0$():this.f();$x$jscomp$822$$!=null&&(this.$cached$=$x$jscomp$822$$);return $x$jscomp$822$$};
var $g__15767__auto___33330$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$list$$!=="undefined")return $clojure$test$check$generators$list$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$786$clojure_DOT_test_DOT_check_DOT_generators_SLASH_list$$)," does not exist, ",
$APP.$cljs$core$namespace$$($cljs$cst$786$clojure_DOT_test_DOT_check_DOT_generators_SLASH_list$$)," never required"].join(""));}),$g__15767__auto___33342$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$map$$!=="undefined")return $clojure$test$check$generators$map$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$787$clojure_DOT_test_DOT_check_DOT_generators_SLASH_map$$),
" does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$787$clojure_DOT_test_DOT_check_DOT_generators_SLASH_map$$)," never required"].join(""));}),$g__15767__auto___33367$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$set$$!=="undefined")return $clojure$test$check$generators$set$$;throw Error(["Var ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$789$clojure_DOT_test_DOT_check_DOT_generators_SLASH_set$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$789$clojure_DOT_test_DOT_check_DOT_generators_SLASH_set$$)," never required"].join(""));}),$g__15767__auto___33374$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!==
"undefined"&&typeof $clojure$test$check$generators$vector$$!=="undefined")return $clojure$test$check$generators$vector$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$790$clojure_DOT_test_DOT_check_DOT_generators_SLASH_vector$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$790$clojure_DOT_test_DOT_check_DOT_generators_SLASH_vector$$)," never required"].join(""));}),$g__15767__auto___33392$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!==
"undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$fmap$$!=="undefined")return $clojure$test$check$generators$fmap$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$792$clojure_DOT_test_DOT_check_DOT_generators_SLASH_fmap$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$792$clojure_DOT_test_DOT_check_DOT_generators_SLASH_fmap$$),
" never required"].join(""));}),$g__15767__auto___33400$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$elements$$!=="undefined")return $clojure$test$check$generators$elements$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$793$clojure_DOT_test_DOT_check_DOT_generators_SLASH_elements$$),
" does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$793$clojure_DOT_test_DOT_check_DOT_generators_SLASH_elements$$)," never required"].join(""));}),$g__15767__auto___33427$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$one_of$$!=="undefined")return $clojure$test$check$generators$one_of$$;
throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$796$clojure_DOT_test_DOT_check_DOT_generators_SLASH_one_of$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$796$clojure_DOT_test_DOT_check_DOT_generators_SLASH_one_of$$)," never required"].join(""));}),$g__15767__auto___33446$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!==
"undefined"&&typeof $clojure$test$check$generators$such_that$$!=="undefined")return $clojure$test$check$generators$such_that$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$797$clojure_DOT_test_DOT_check_DOT_generators_SLASH_such_that$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$797$clojure_DOT_test_DOT_check_DOT_generators_SLASH_such_that$$)," never required"].join(""));}),$g__15767__auto___33474$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!==
"undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$return$0$$!=="undefined")return $clojure$test$check$generators$return$0$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$800$clojure_DOT_test_DOT_check_DOT_generators_SLASH_return$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$800$clojure_DOT_test_DOT_check_DOT_generators_SLASH_return$$),
" never required"].join(""));}),$g__15767__auto___33484$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$large_integer_STAR_$$!=="undefined")return $clojure$test$check$generators$large_integer_STAR_$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$801$clojure_DOT_test_DOT_check_DOT_generators_SLASH_large_integer_STAR_$$),
" does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$801$clojure_DOT_test_DOT_check_DOT_generators_SLASH_large_integer_STAR_$$)," never required"].join(""));}),$g__15780__auto___33530$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$any_printable$$!=="undefined")return $clojure$test$check$generators$any_printable$$;
throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$806$clojure_DOT_test_DOT_check_DOT_generators_SLASH_any_printable$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$806$clojure_DOT_test_DOT_check_DOT_generators_SLASH_any_printable$$)," never required"].join(""));}),$g__15780__auto___33536$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&
typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$boolean$0$$!=="undefined")return $clojure$test$check$generators$boolean$0$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$807$clojure_DOT_test_DOT_check_DOT_generators_SLASH_boolean$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$807$clojure_DOT_test_DOT_check_DOT_generators_SLASH_boolean$$)," never required"].join(""));}),$g__15780__auto___33547$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!==
"undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$char$0$$!=="undefined")return $clojure$test$check$generators$char$0$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$808$clojure_DOT_test_DOT_check_DOT_generators_SLASH_char$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$808$clojure_DOT_test_DOT_check_DOT_generators_SLASH_char$$),
" never required"].join(""));}),$g__15780__auto___33585$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$double$0$$!=="undefined")return $clojure$test$check$generators$double$0$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$812$clojure_DOT_test_DOT_check_DOT_generators_SLASH_double$$),
" does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$812$clojure_DOT_test_DOT_check_DOT_generators_SLASH_double$$)," never required"].join(""));}),$g__15780__auto___33605$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$keyword$$!=="undefined")return $clojure$test$check$generators$keyword$$;
throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$814$clojure_DOT_test_DOT_check_DOT_generators_SLASH_keyword$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$814$clojure_DOT_test_DOT_check_DOT_generators_SLASH_keyword$$)," never required"].join(""));}),$g__15780__auto___33610$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!==
"undefined"&&typeof $clojure$test$check$generators$keyword_ns$$!=="undefined")return $clojure$test$check$generators$keyword_ns$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$815$clojure_DOT_test_DOT_check_DOT_generators_SLASH_keyword_ns$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$815$clojure_DOT_test_DOT_check_DOT_generators_SLASH_keyword_ns$$)," never required"].join(""));}),$g__15780__auto___33614$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!==
"undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$large_integer$$!=="undefined")return $clojure$test$check$generators$large_integer$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$816$clojure_DOT_test_DOT_check_DOT_generators_SLASH_large_integer$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$816$clojure_DOT_test_DOT_check_DOT_generators_SLASH_large_integer$$),
" never required"].join(""));}),$g__15780__auto___33631$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$simple_type_printable$$!=="undefined")return $clojure$test$check$generators$simple_type_printable$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$819$clojure_DOT_test_DOT_check_DOT_generators_SLASH_simple_type_printable$$),
" does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$819$clojure_DOT_test_DOT_check_DOT_generators_SLASH_simple_type_printable$$)," never required"].join(""));}),$g__15780__auto___33647$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$string_alphanumeric$$!=="undefined")return $clojure$test$check$generators$string_alphanumeric$$;
throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$822$clojure_DOT_test_DOT_check_DOT_generators_SLASH_string_alphanumeric$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$822$clojure_DOT_test_DOT_check_DOT_generators_SLASH_string_alphanumeric$$)," never required"].join(""));}),$g__15780__auto___33657$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!==
"undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$symbol$$!=="undefined")return $clojure$test$check$generators$symbol$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$823$clojure_DOT_test_DOT_check_DOT_generators_SLASH_symbol$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$823$clojure_DOT_test_DOT_check_DOT_generators_SLASH_symbol$$)," never required"].join(""));}),$g__15780__auto___33665$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!==
"undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$symbol_ns$$!=="undefined")return $clojure$test$check$generators$symbol_ns$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$824$clojure_DOT_test_DOT_check_DOT_generators_SLASH_symbol_ns$$)," does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$824$clojure_DOT_test_DOT_check_DOT_generators_SLASH_symbol_ns$$),
" never required"].join(""));}),$g__15780__auto___33669$$=new $cljs$spec$gen$alpha$LazyVar$$(function(){if(typeof $clojure$$!=="undefined"&&typeof $clojure$test$$!=="undefined"&&typeof $clojure$test$check$$!=="undefined"&&typeof $clojure$test$check$generators$$!=="undefined"&&typeof $clojure$test$check$generators$uuid$$!=="undefined")return $clojure$test$check$generators$uuid$$;throw Error(["Var ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$825$clojure_DOT_test_DOT_check_DOT_generators_SLASH_uuid$$),
" does not exist, ",$APP.$cljs$core$namespace$$($cljs$cst$825$clojure_DOT_test_DOT_check_DOT_generators_SLASH_uuid$$)," never required"].join(""));}),$cljs$spec$gen$alpha$gen_builtins$$=new $APP.$cljs$core$Delay$$(function(){var $simple$$=$cljs$spec$gen$alpha$simple_type_printable$$();return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$core$qualified_keyword_QMARK_$$,$APP.$cljs$core$seq_QMARK_$$,$APP.$cljs$core$vector_QMARK_$$,$APP.$cljs$core$any_QMARK_$$,$APP.$cljs$core$boolean_QMARK_$$,
$cljs$core$char_QMARK_$$,$APP.$cljs$core$some_QMARK_$$,$cljs$core$inst_QMARK_$$,$cljs$core$simple_symbol_QMARK_$$,$APP.$cljs$core$sequential_QMARK_$$,$cljs$core$float_QMARK_$$,$APP.$cljs$core$set_QMARK_$$,$APP.$cljs$core$map_QMARK_$$,$APP.$cljs$core$empty_QMARK_$$,$APP.$cljs$core$string_QMARK_$$,$cljs$core$uri_QMARK_$$,$cljs$core$double_QMARK_$$,$APP.$cljs$core$int_QMARK_$$,$APP.$cljs$core$associative_QMARK_$$,$cljs$core$keyword_QMARK_$$,$cljs$core$indexed_QMARK_$$,$cljs$core$zero_QMARK_$$,$cljs$core$simple_keyword_QMARK_$$,
$cljs$core$neg_int_QMARK_$$,$APP.$cljs$core$nil_QMARK_$$,$cljs$core$ident_QMARK_$$,$cljs$core$qualified_ident_QMARK_$$,$APP.$cljs$core$true_QMARK_$$,$APP.$cljs$core$integer_QMARK_$$,$APP.$cljs$core$nat_int_QMARK_$$,$cljs$core$pos_int_QMARK_$$,$APP.$cljs$core$uuid_QMARK_$$,$cljs$core$false_QMARK_$$,$APP.$cljs$core$list_QMARK_$$,$cljs$core$simple_ident_QMARK_$$,$APP.$cljs$core$number_QMARK_$$,$cljs$core$qualified_symbol_QMARK_$$,$APP.$cljs$core$seqable_QMARK_$$,$cljs$core$symbol_QMARK_$$,$APP.$cljs$core$coll_QMARK_$$],
[$cljs$spec$gen$alpha$such_that$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$spec$gen$alpha$qualified_QMARK_$$,$cljs$spec$gen$alpha$keyword_ns$$()])),$cljs$spec$gen$alpha$list$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$])),$cljs$spec$gen$alpha$vector$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$])),
$cljs$spec$gen$alpha$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$spec$gen$alpha$return$0$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([null])),$cljs$spec$gen$alpha$any_printable$$()],null)])),$cljs$spec$gen$alpha$boolean$0$$(),$cljs$spec$gen$alpha$char$0$$(),$cljs$spec$gen$alpha$such_that$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$some_QMARK_$$,
$cljs$spec$gen$alpha$any_printable$$()])),$cljs$spec$gen$alpha$fmap$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([function($p1__33229_SHARP_$$){return new Date($p1__33229_SHARP_$$)},$cljs$spec$gen$alpha$large_integer$$()])),$cljs$spec$gen$alpha$symbol$$(),$cljs$spec$gen$alpha$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$spec$gen$alpha$list$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$])),$cljs$spec$gen$alpha$vector$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$]))],null)])),$cljs$spec$gen$alpha$double$0$$(),$cljs$spec$gen$alpha$set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$])),$cljs$spec$gen$alpha$map$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$,
$simple$$])),$cljs$spec$gen$alpha$elements$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$APP.$cljs$core$List$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$],null)])),$cljs$spec$gen$alpha$string_alphanumeric$$(),$cljs$spec$gen$alpha$fmap$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([function($p1__33228_SHARP_$$){return new $goog$Uri$$(["http://",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__33228_SHARP_$$),".com"].join(""))},$cljs$spec$gen$alpha$uuid$$()])),$cljs$spec$gen$alpha$double$0$$(),$cljs$spec$gen$alpha$large_integer$$(),$cljs$spec$gen$alpha$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$spec$gen$alpha$map$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$,
$simple$$])),$cljs$spec$gen$alpha$vector$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$]))],null)])),$cljs$spec$gen$alpha$keyword_ns$$(),$cljs$spec$gen$alpha$vector$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$])),$cljs$spec$gen$alpha$return$0$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([0])),$cljs$spec$gen$alpha$keyword$$(),
$cljs$spec$gen$alpha$large_integer_STAR_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,-1],null)])),$cljs$spec$gen$alpha$return$0$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([null])),$cljs$spec$gen$alpha$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$spec$gen$alpha$keyword_ns$$(),$cljs$spec$gen$alpha$symbol_ns$$()],null)])),$cljs$spec$gen$alpha$such_that$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$spec$gen$alpha$qualified_QMARK_$$,$cljs$spec$gen$alpha$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$spec$gen$alpha$keyword_ns$$(),$cljs$spec$gen$alpha$symbol_ns$$()],null)]))])),$cljs$spec$gen$alpha$return$0$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([!0])),$cljs$spec$gen$alpha$large_integer$$(),$cljs$spec$gen$alpha$large_integer_STAR_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$338$min$$,0],null)])),
$cljs$spec$gen$alpha$large_integer_STAR_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$338$min$$,1],null)])),$cljs$spec$gen$alpha$uuid$$(),$cljs$spec$gen$alpha$return$0$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([!1])),$cljs$spec$gen$alpha$list$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$])),
$cljs$spec$gen$alpha$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$spec$gen$alpha$keyword$$(),$cljs$spec$gen$alpha$symbol$$()],null)])),$cljs$spec$gen$alpha$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$spec$gen$alpha$large_integer$$(),$cljs$spec$gen$alpha$double$0$$()],null)])),$cljs$spec$gen$alpha$such_that$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$spec$gen$alpha$qualified_QMARK_$$,$cljs$spec$gen$alpha$symbol_ns$$()])),$cljs$spec$gen$alpha$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$spec$gen$alpha$return$0$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([null])),$cljs$spec$gen$alpha$list$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$])),$cljs$spec$gen$alpha$vector$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$])),$cljs$spec$gen$alpha$map$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$,
$simple$$])),$cljs$spec$gen$alpha$set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$])),$cljs$spec$gen$alpha$string_alphanumeric$$()],null)])),$cljs$spec$gen$alpha$symbol_ns$$(),$cljs$spec$gen$alpha$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$spec$gen$alpha$map$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$,
$simple$$])),$cljs$spec$gen$alpha$list$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$])),$cljs$spec$gen$alpha$vector$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$])),$cljs$spec$gen$alpha$set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$simple$$]))],null)]))])});var $malli$generator$nil_gen$$=$clojure$test$check$generators$return$0$$(null),$malli$generator$double_default$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$778$infinite_QMARK_$$,!1,$cljs$cst$779$NaN_QMARK_$$,!1],null),$malli$generator$_schema_generator$$=function(){var $method_table__5622__auto__$jscomp$1$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$1$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),
$method_cache__5624__auto__$jscomp$1$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$1$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$205$default$$,$cljs$cst$866$malli_DOT_generator_SLASH_default$$],
null),$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("malli.generator","-schema-generator"),function($schema$jscomp$115$$,$options$jscomp$324$$){return $APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$115$$,$options$jscomp$324$$)},
$cljs$cst$866$malli_DOT_generator_SLASH_default$$,$hierarchy__5626__auto__$jscomp$1$$,$method_table__5622__auto__$jscomp$1$$,$prefer_table__5623__auto__$jscomp$1$$,$method_cache__5624__auto__$jscomp$1$$,$cached_hierarchy__5625__auto__$jscomp$1$$)}();
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$866$malli_DOT_generator_SLASH_default$$,function($schema$jscomp$116$$,$options$jscomp$325$$){return $cljs$spec$gen$alpha$gen_for_pred$$($malli$core$validator$cljs$0core$0IFn$0_invoke$0arity$02$$($schema$jscomp$116$$,$options$jscomp$325$$))});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$706$empty_QMARK_$$,function(){return $cljs$spec$gen$alpha$gen_for_pred$$($APP.$cljs$core$empty_QMARK_$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$707$_GT_$$,function($schema$jscomp$117$$,$options$jscomp$326$$){return $malli$generator$gen_double$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$338$min$$,$malli$generator$_child$$($schema$jscomp$117$$,$options$jscomp$326$$)+1],null))});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$708$_GT__EQ_$$,function($schema$jscomp$118$$,$options$jscomp$327$$){return $malli$generator$gen_double$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$338$min$$,$malli$generator$_child$$($schema$jscomp$118$$,$options$jscomp$327$$)],null))});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$709$_LT_$$,function($schema$jscomp$119$$,$options$jscomp$328$$){return $malli$generator$gen_double$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,$malli$generator$_child$$($schema$jscomp$119$$,$options$jscomp$328$$)-1],null))});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$710$_LT__EQ_$$,function($schema$jscomp$120$$,$options$jscomp$329$$){return $malli$generator$gen_double$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,$malli$generator$_child$$($schema$jscomp$120$$,$options$jscomp$329$$)],null))});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$711$_EQ_$$,function($schema$jscomp$121$$,$options$jscomp$330$$){return $clojure$test$check$generators$return$0$$($malli$generator$_child$$($schema$jscomp$121$$,$options$jscomp$330$$))});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$712$not_EQ_$$,function($schema$jscomp$122$$,$options$jscomp$331$$){return $malli$generator$gen_such_that$$($schema$jscomp$122$$,function($p1__35390_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__35390_SHARP_$$,$malli$generator$_child$$($schema$jscomp$122$$,$options$jscomp$331$$))},$clojure$test$check$generators$any_printable$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$671$pos_QMARK_$$,function(){return $clojure$test$check$generators$one_of$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$malli$generator$gen_double$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$338$min$$,1E-5],null)),$malli$generator$gen_fmap$$($APP.$cljs$core$inc$$,$clojure$test$check$generators$nat$$)],null))});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$672$neg_QMARK_$$,function(){return $clojure$test$check$generators$one_of$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$malli$generator$gen_double$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,-1E-5],null)),$malli$generator$gen_fmap$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dec$$,$APP.$cljs$core$_$$),
$clojure$test$check$generators$nat$$)],null))});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$444$not$$,function($schema$jscomp$123$$,$options$jscomp$334$$){return $malli$generator$gen_such_that$$($schema$jscomp$123$$,$malli$core$validator$cljs$0core$0IFn$0_invoke$0arity$02$$($schema$jscomp$123$$,$options$jscomp$334$$),$cljs$spec$gen$alpha$gen_for_pred$$($APP.$cljs$core$any_QMARK_$$))});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$429$and$$,function($schema$jscomp$124$$,$options$jscomp$335$$){return $malli$generator$gen_such_that$$($schema$jscomp$124$$,$malli$core$validator$cljs$0core$0IFn$0_invoke$0arity$02$$($schema$jscomp$124$$,$options$jscomp$335$$),$malli$generator$_child_gen$$($schema$jscomp$124$$,$options$jscomp$335$$))});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$433$or$$,function($schema$jscomp$125$$,$options$jscomp$336$$){return $malli$generator$_or_gen$$($schema$jscomp$125$$,$options$jscomp$336$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$438$orn$$,function($schema$jscomp$126$$,$options$jscomp$337$$){return $malli$generator$_or_gen$$($malli$core$into_schema$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$cst$433$or$$,$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$126$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$last$$,$malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$126$$)),
$APP.$malli$core$options$cljs$0core$0IFn$0_invoke$0arity$02$$($schema$jscomp$126$$)),$options$jscomp$337$$)});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$449$malli_DOT_core_SLASH_val$$,function($schema$jscomp$127$$,$options$jscomp$338$$){return $malli$generator$_child_gen$$($schema$jscomp$127$$,$options$jscomp$338$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$202$map$$,function($schema$jscomp$128$$,$options$jscomp$339$$){return $malli$generator$_map_gen$$($schema$jscomp$128$$,$options$jscomp$339$$)});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$463$map_of$$,function($schema$jscomp$129$$,$options$jscomp$340$$){return $malli$generator$_map_of_gen$$($schema$jscomp$129$$,$options$jscomp$340$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$531$multi$$,function($schema$jscomp$130$$,$options$jscomp$341$$){return $malli$generator$_multi_gen$$($schema$jscomp$130$$,$options$jscomp$341$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$200$vector$$,function($schema$jscomp$131$$,$options$jscomp$342$$){return $malli$generator$_coll_gen$cljs$0core$0IFn$0_invoke$0arity$03$$($schema$jscomp$131$$,$APP.$cljs$core$identity$$,$options$jscomp$342$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$720$sequential$$,function($schema$jscomp$132$$,$options$jscomp$343$$){return $malli$generator$_coll_gen$cljs$0core$0IFn$0_invoke$0arity$03$$($schema$jscomp$132$$,$APP.$cljs$core$identity$$,$options$jscomp$343$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$203$set$$,function($schema$jscomp$133$$,$options$jscomp$344$$){return $malli$generator$_coll_distinct_gen$$($schema$jscomp$133$$,$options$jscomp$344$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$499$enum$$,function($schema$jscomp$134$$,$options$jscomp$345$$){return $malli$generator$gen_elements$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$134$$,$options$jscomp$345$$))});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$719$seqable$$,function($schema$jscomp$135$$,$options$jscomp$346$$){return $malli$generator$_seqable_gen$$($schema$jscomp$135$$,$options$jscomp$346$$)});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$721$every$$,function($schema$jscomp$136$$,$options$jscomp$347$$){return $malli$generator$_seqable_gen$$($schema$jscomp$136$$,$options$jscomp$347$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$522$maybe$$,function($schema$jscomp$137$$,$options$jscomp$348$$){return $malli$generator$gen_maybe$$($malli$generator$_child_gen$$($schema$jscomp$137$$,$options$jscomp$348$$))});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$498$tuple$$,function($schema$jscomp$138$$,$options$jscomp$349$$){return $malli$generator$gen_tuple$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__35418_SHARP_$$){return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__35418_SHARP_$$,$options$jscomp$349$$):$malli$generator$generator$$($p1__35418_SHARP_$$,
$options$jscomp$349$$)},$malli$core$children$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$138$$,$options$jscomp$349$$)))});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$418$any$$,function(){return $cljs$spec$gen$alpha$gen_for_pred$$($APP.$cljs$core$any_QMARK_$$)});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$419$some$$,function(){return $clojure$test$check$generators$any_printable$$});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$197$nil$$,function(){return $malli$generator$nil_gen$$});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$198$string$$,function($schema$jscomp$139$$,$options$jscomp$350$$){return $malli$generator$gen_fmap$$($APP.$clojure$string$join$$,$malli$generator$gen_vector$$($malli$generator$_min_max$$($schema$jscomp$139$$,$options$jscomp$350$$),$clojure$test$check$generators$char_alphanumeric$$))});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$344$int$$,function($schema$jscomp$140$$,$options$jscomp$351$$){return $clojure$test$check$generators$large_integer_STAR_$$($malli$generator$_min_max$$($schema$jscomp$140$$,$options$jscomp$351$$))});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$345$double$$,function($schema$jscomp$141$$,$options$jscomp$352$$){return $malli$generator$double_gen$$($schema$jscomp$141$$,$options$jscomp$352$$)});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$420$float$$,function($schema$jscomp$142$$,$options$jscomp$353$$){return $malli$generator$double_gen$$($schema$jscomp$142$$,$options$jscomp$353$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$421$boolean$$,function(){return $clojure$test$check$generators$boolean$0$$});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$221$keyword$$,function(){return $clojure$test$check$generators$keyword$$});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$219$symbol$$,function(){return $clojure$test$check$generators$symbol$$});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$422$qualified_keyword$$,function($schema$jscomp$143$$){return $malli$generator$_qualified_ident_gen$$($schema$jscomp$143$$,$APP.$cljs$core$keyword$$,$clojure$test$check$generators$keyword$$,$cljs$core$qualified_keyword_QMARK_$$,$clojure$test$check$generators$keyword_ns$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$423$qualified_symbol$$,function($schema$jscomp$144$$){return $malli$generator$_qualified_ident_gen$$($schema$jscomp$144$$,$APP.$cljs$core$symbol$$,$clojure$test$check$generators$symbol$$,$cljs$core$qualified_symbol_QMARK_$$,$clojure$test$check$generators$symbol_ns$$)});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$424$uuid$$,function(){return $clojure$test$check$generators$uuid$$});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$562$_EQ__GT_$$,function($schema$jscomp$145$$,$options$jscomp$354$$){return $malli$generator$__EQ__GT__gen$$($schema$jscomp$145$$,$options$jscomp$354$$)});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$615$__GT_$$,function($schema$jscomp$146$$,$options$jscomp$355$$){return $malli$generator$__EQ__GT__gen$$($schema$jscomp$146$$,$options$jscomp$355$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$605$function$$,function($schema$jscomp$147$$,$options$jscomp$356$$){return $malli$generator$_function_gen$$($schema$jscomp$147$$,$options$jscomp$356$$)});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$704$ifn_QMARK_$$,function(){return $clojure$test$check$generators$keyword$$});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$550$ref$$,function($schema$jscomp$148$$,$options$jscomp$357$$){return $malli$generator$_ref_gen$$($schema$jscomp$148$$,$options$jscomp$357$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$298$schema$$,function($G__35459_schema$jscomp$149$$,$options$jscomp$358$$){$G__35459_schema$jscomp$149$$=$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35459_schema$jscomp$149$$,null);return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35459_schema$jscomp$149$$,$options$jscomp$358$$):$malli$generator$generator$$($G__35459_schema$jscomp$149$$,
$options$jscomp$358$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$412$malli_DOT_core_SLASH_schema$$,function($G__35461_schema$jscomp$150$$,$options$jscomp$359$$){$G__35461_schema$jscomp$150$$=$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35461_schema$jscomp$150$$,null);return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35461_schema$jscomp$150$$,$options$jscomp$359$$):$malli$generator$generator$$($G__35461_schema$jscomp$150$$,
$options$jscomp$359$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$735$merge$$,function($G__35466_schema$jscomp$151$$,$options$jscomp$360$$){$G__35466_schema$jscomp$151$$=$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35466_schema$jscomp$151$$,null);return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35466_schema$jscomp$151$$,$options$jscomp$360$$):$malli$generator$generator$$($G__35466_schema$jscomp$151$$,
$options$jscomp$360$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$736$union$$,function($G__35470_schema$jscomp$152$$,$options$jscomp$361$$){$G__35470_schema$jscomp$152$$=$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35470_schema$jscomp$152$$,null);return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35470_schema$jscomp$152$$,$options$jscomp$361$$):$malli$generator$generator$$($G__35470_schema$jscomp$152$$,
$options$jscomp$361$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$737$select_keys$$,function($G__35472_schema$jscomp$153$$,$options$jscomp$362$$){$G__35472_schema$jscomp$153$$=$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35472_schema$jscomp$153$$,null);return $malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35472_schema$jscomp$153$$,$options$jscomp$362$$):$malli$generator$generator$$($G__35472_schema$jscomp$153$$,
$options$jscomp$362$$)});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$594$cat$$,function($schema$jscomp$154$$,$options$jscomp$363$$){return $malli$generator$_cat_gen$$($schema$jscomp$154$$,$options$jscomp$363$$)});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$595$catn$$,function($schema$jscomp$155$$,$options$jscomp$364$$){return $malli$generator$_cat_gen$$($schema$jscomp$155$$,$options$jscomp$364$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$717$alt$$,function($schema$jscomp$156$$,$options$jscomp$365$$){return $malli$generator$_alt_gen$$($schema$jscomp$156$$,$options$jscomp$365$$)});$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$718$altn$$,function($schema$jscomp$157$$,$options$jscomp$366$$){return $malli$generator$_alt_gen$$($schema$jscomp$157$$,$options$jscomp$366$$)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$715$_QMARK_$$,function($child$jscomp$inline_3750_schema$jscomp$158$$,$options$jscomp$367_temp__5827__auto__$jscomp$inline_3751$$){$child$jscomp$inline_3750_schema$jscomp$158$$=$malli$generator$_child$$($child$jscomp$inline_3750_schema$jscomp$158$$,$options$jscomp$367_temp__5827__auto__$jscomp$inline_3751$$);$options$jscomp$367_temp__5827__auto__$jscomp$inline_3751$$=$malli$generator$_not_unreachable$$($malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?
$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$inline_3750_schema$jscomp$158$$,$options$jscomp$367_temp__5827__auto__$jscomp$inline_3751$$):$malli$generator$generator$$($child$jscomp$inline_3750_schema$jscomp$158$$,$options$jscomp$367_temp__5827__auto__$jscomp$inline_3751$$));return $options$jscomp$367_temp__5827__auto__$jscomp$inline_3751$$==null?$clojure$test$check$generators$return$0$$($APP.$cljs$core$List$EMPTY$$):$APP.$cljs$core$truth_$$($malli$core$_regex_op_QMARK_$$($child$jscomp$inline_3750_schema$jscomp$158$$))?
$clojure$test$check$generators$one_of$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$options$jscomp$367_temp__5827__auto__$jscomp$inline_3751$$,$clojure$test$check$generators$return$0$$($APP.$cljs$core$List$EMPTY$$)],null)):$clojure$test$check$generators$vector$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$367_temp__5827__auto__$jscomp$inline_3751$$,0,1)});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$714$_STAR_$$,function($G__35332$jscomp$inline_3756_schema$jscomp$159$$,$options$jscomp$368$$){var $child$jscomp$inline_3755$$=$malli$generator$_child$$($G__35332$jscomp$inline_3756_schema$jscomp$159$$,$options$jscomp$368$$);$G__35332$jscomp$inline_3756_schema$jscomp$159$$=$malli$generator$gen_vector$$($malli$generator$_min_max$$($G__35332$jscomp$inline_3756_schema$jscomp$159$$,$options$jscomp$368$$),$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?
$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$inline_3755$$,$options$jscomp$368$$):$malli$generator$generator$$($child$jscomp$inline_3755$$,$options$jscomp$368$$));return $APP.$cljs$core$truth_$$($malli$core$_regex_op_QMARK_$$($child$jscomp$inline_3755$$))?$malli$generator$gen_fcat$$($G__35332$jscomp$inline_3756_schema$jscomp$159$$):$G__35332$jscomp$inline_3756_schema$jscomp$159$$});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$713$_PLUS_$$,function($G__35336$jscomp$inline_3761_schema$jscomp$160$$,$options$jscomp$369$$){var $child$jscomp$inline_3760$$=$malli$generator$_child$$($G__35336$jscomp$inline_3761_schema$jscomp$160$$,$options$jscomp$369$$);$G__35336$jscomp$inline_3761_schema$jscomp$160$$=$malli$generator$gen_vector$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($malli$generator$_min_max$$($G__35336$jscomp$inline_3761_schema$jscomp$160$$,
$options$jscomp$369$$),$APP.$cljs$cst$338$min$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$max$$,1)),$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$?$malli$generator$generator$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$inline_3760$$,$options$jscomp$369$$):$malli$generator$generator$$($child$jscomp$inline_3760$$,$options$jscomp$369$$));return $APP.$cljs$core$truth_$$($malli$core$_regex_op_QMARK_$$($child$jscomp$inline_3760$$))?$malli$generator$gen_fcat$$($G__35336$jscomp$inline_3761_schema$jscomp$160$$):
$G__35336$jscomp$inline_3761_schema$jscomp$160$$});
$malli$generator$_schema_generator$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$716$repeat$$,function($or__5025__auto__$jscomp$inline_11511_schema$jscomp$161$$,$options$jscomp$370$$){var $G__35342$jscomp$inline_11512_G__35342__$1$jscomp$inline_11513$$=$malli$generator$_coll_gen$cljs$0core$0IFn$0_invoke$0arity$03$$($or__5025__auto__$jscomp$inline_11511_schema$jscomp$161$$,$APP.$cljs$core$identity$$,$options$jscomp$370$$);$G__35342$jscomp$inline_11512_G__35342__$1$jscomp$inline_11513$$=$G__35342$jscomp$inline_11512_G__35342__$1$jscomp$inline_11513$$==
null?null:$malli$generator$_not_unreachable$$($G__35342$jscomp$inline_11512_G__35342__$1$jscomp$inline_11513$$);$or__5025__auto__$jscomp$inline_11511_schema$jscomp$161$$=$G__35342$jscomp$inline_11512_G__35342__$1$jscomp$inline_11513$$==null?null:$APP.$cljs$core$truth_$$($malli$core$_regex_op_QMARK_$$($malli$generator$_child$$($or__5025__auto__$jscomp$inline_11511_schema$jscomp$161$$,$options$jscomp$370$$)))?$malli$generator$gen_fcat$$($G__35342$jscomp$inline_11512_G__35342__$1$jscomp$inline_11513$$):
$G__35342$jscomp$inline_11512_G__35342__$1$jscomp$inline_11513$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_11511_schema$jscomp$161$$)?$or__5025__auto__$jscomp$inline_11511_schema$jscomp$161$$:$clojure$test$check$generators$return$0$$($APP.$cljs$core$List$EMPTY$$)});
$malli$generator$_generator$$._=function($schema$jscomp$162$$,$options$jscomp$371$$){return $malli$generator$_schema_generator$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$162$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$371$$,$cljs$cst$851$malli_DOT_generator_SLASH_original_generator_schema$$,$schema$jscomp$162$$))};var $app$common$schema$generators$text$$=$app$common$schema$generators$word_string$$(),$app$common$schema$generators$double$0$$=$app$common$schema$generators$small_double$$(),$app$common$schema$generators$int$0$$=$app$common$schema$generators$small_int$$(),$app$common$schema$generators$keyword$$=$clojure$test$check$generators$fmap$$($APP.$cljs$core$keyword$$,$app$common$schema$generators$word_string$$()),$app$common$schema$generators$any$$=$clojure$test$check$generators$one_of$$(new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$schema$generators$text$$,$clojure$test$check$generators$boolean$0$$,$app$common$schema$generators$double$0$$,$app$common$schema$generators$int$0$$,$app$common$schema$generators$keyword$$],null));var $prefix_35557$$=["-en-humanize-negation-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$core$random_uuid$$())].join(""),$malli$error$default_errors$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$452$malli_DOT_core_SLASH_extra_key$$,$cljs$cst$699$true_QMARK_$$,$APP.$cljs$cst$499$enum$$,$cljs$cst$423$qualified_symbol$$,$cljs$cst$687$uri_QMARK_$$,$cljs$cst$681$simple_keyword_QMARK_$$,$cljs$cst$710$_LT__EQ_$$,$cljs$cst$345$double$$,$cljs$cst$686$uuid_QMARK_$$,$cljs$cst$688$inst_QMARK_$$,
$cljs$cst$678$simple_ident_QMARK_$$,$cljs$cst$712$not_EQ_$$,$cljs$cst$667$int_QMARK_$$,$cljs$cst$697$nil_QMARK_$$,$cljs$cst$344$int$$,$cljs$cst$707$_GT_$$,$cljs$cst$673$float_QMARK_$$,$cljs$cst$704$ifn_QMARK_$$,$cljs$cst$691$map_QMARK_$$,$cljs$cst$692$vector_QMARK_$$,$cljs$cst$663$any_QMARK_$$,$cljs$cst$420$float$$,$APP.$cljs$cst$219$symbol$$,$cljs$cst$698$false_QMARK_$$,$cljs$cst$702$associative_QMARK_$$,$cljs$cst$512$re$$,$cljs$cst$677$ident_QMARK_$$,$cljs$cst$422$qualified_keyword$$,$cljs$cst$444$not$$,
$cljs$cst$695$char_QMARK_$$,$cljs$cst$669$neg_int_QMARK_$$,$APP.$cljs$cst$198$string$$,$cljs$cst$683$symbol_QMARK_$$,$cljs$cst$708$_GT__EQ_$$,$cljs$cst$693$list_QMARK_$$,$cljs$cst$879$malli_DOT_error_SLASH_misspelled_value$$,$cljs$cst$679$qualified_ident_QMARK_$$,$cljs$cst$701$coll_QMARK_$$,$cljs$cst$562$_EQ__GT_$$,$cljs$cst$680$keyword_QMARK_$$,$cljs$cst$464$malli_DOT_core_SLASH_limits$$,$cljs$cst$684$simple_symbol_QMARK_$$,$cljs$cst$706$empty_QMARK_$$,$cljs$cst$666$integer_QMARK_$$,$cljs$cst$451$malli_DOT_core_SLASH_missing_key$$,
$cljs$cst$494$malli_DOT_core_SLASH_tuple_size$$,$cljs$cst$700$zero_QMARK_$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$197$nil$$,$cljs$cst$682$qualified_keyword_QMARK_$$,$cljs$cst$676$string_QMARK_$$,$cljs$cst$299$malli_DOT_core_SLASH_end_of_input$$,$cljs$cst$685$qualified_symbol_QMARK_$$,$cljs$cst$300$malli_DOT_core_SLASH_input_remaining$$,$cljs$cst$694$seq_QMARK_$$,$cljs$cst$670$nat_int_QMARK_$$,$cljs$cst$696$set_QMARK_$$,$cljs$cst$664$some_QMARK_$$,$cljs$cst$671$pos_QMARK_$$,$cljs$cst$675$boolean_QMARK_$$,
$cljs$cst$705$fn_QMARK_$$,$cljs$cst$703$sequential_QMARK_$$,$cljs$cst$424$uuid$$,$cljs$cst$880$malli_DOT_error_SLASH_unknown$$,$cljs$cst$665$number_QMARK_$$,$cljs$cst$523$malli_DOT_core_SLASH_invalid_dispatch_value$$,$cljs$cst$674$double_QMARK_$$,$cljs$cst$689$seqable_QMARK_$$,$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$421$boolean$$,$cljs$cst$709$_LT_$$,$cljs$cst$672$neg_QMARK_$$,$cljs$cst$881$malli_DOT_error_SLASH_misspelled_key$$,$cljs$cst$315$malli_DOT_core_SLASH_invalid_type$$,$cljs$cst$668$pos_int_QMARK_$$,
$APP.$cljs$cst$418$any$$,$cljs$cst$690$indexed_QMARK_$$],[new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"disallowed key"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be true"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,function($map__35000__$1_p__34999_schema$jscomp$172$$){$map__35000__$1_p__34999_schema$jscomp$172$$=$APP.$cljs$core$__destructure_map$$($map__35000__$1_p__34999_schema$jscomp$172$$);$map__35000__$1_p__34999_schema$jscomp$172$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35000__$1_p__34999_schema$jscomp$172$$,$APP.$cljs$cst$298$schema$$);return["should be ",$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$APP.$cljs$core$count$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($map__35000__$1_p__34999_schema$jscomp$172$$)))?$malli$error$_pr_str$$($APP.$cljs$core$first$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($map__35000__$1_p__34999_schema$jscomp$172$$))):["either ",$APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($malli$error$_pr_str$$,$APP.$cljs$core$butlast$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($map__35000__$1_p__34999_schema$jscomp$172$$)))),
" or ",$malli$error$_pr_str$$($APP.$cljs$core$last$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($map__35000__$1_p__34999_schema$jscomp$172$$)))].join("")].join("")}],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a qualified symbol"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$883$en$$,"should be a uri"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a simple keyword"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,function($map__35018__$1_p__35017$$,$options$jscomp$383$$){$map__35018__$1_p__35017$$=
$APP.$cljs$core$__destructure_map$$($map__35018__$1_p__35017$$);var $schema$jscomp$173$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35018__$1_p__35017$$,$APP.$cljs$cst$298$schema$$),$value$jscomp$303$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35018__$1_p__35017$$,$APP.$cljs$cst$260$value$$),$negated$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35018__$1_p__35017$$,$cljs$cst$878$negated$$);return $APP.$cljs$core$truth_$$($negated$jscomp$4$$)?
$malli$error$_forward_negation$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$707$_GT_$$,$APP.$cljs$core$first$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$173$$))],null),$map__35018__$1_p__35017$$,$options$jscomp$383$$):typeof $value$jscomp$303$$==="number"?["should be at most ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$173$$)))].join(""):
"should be a number"}],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,$malli$error$_pred_min_max_error_fn$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$351$pred$$,$cljs$core$double_QMARK_$$,$APP.$cljs$cst$141$message$$,"should be a double"],null))],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$883$en$$,"should be a uuid"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be an inst"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a simple ident"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$884$error_SLASH_fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,function($map__35027__$1_p__35022_schema$jscomp$174$$){$map__35027__$1_p__35022_schema$jscomp$174$$=$APP.$cljs$core$__destructure_map$$($map__35027__$1_p__35022_schema$jscomp$174$$);$map__35027__$1_p__35022_schema$jscomp$174$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35027__$1_p__35022_schema$jscomp$174$$,$APP.$cljs$cst$298$schema$$);return["should not be ",$malli$error$_pr_str$$($APP.$cljs$core$first$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($map__35027__$1_p__35022_schema$jscomp$174$$)))].join("")}],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be an int"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be nil"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$883$en$$,$malli$error$_pred_min_max_error_fn$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$int_QMARK_$$,$APP.$cljs$cst$141$message$$,"should be an integer"],null))],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,function($map__35043__$1_p__35042$$,$options$jscomp$384$$){$map__35043__$1_p__35042$$=$APP.$cljs$core$__destructure_map$$($map__35043__$1_p__35042$$);
var $schema$jscomp$175$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35043__$1_p__35042$$,$APP.$cljs$cst$298$schema$$),$value$jscomp$304$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35043__$1_p__35042$$,$APP.$cljs$cst$260$value$$),$negated$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35043__$1_p__35042$$,$cljs$cst$878$negated$$);return $APP.$cljs$core$truth_$$($negated$jscomp$5$$)?$malli$error$_forward_negation$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$710$_LT__EQ_$$,$APP.$cljs$core$first$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$175$$))],null),$map__35043__$1_p__35042$$,$options$jscomp$384$$):typeof $value$jscomp$304$$==="number"?["should be larger than ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$175$$)))].join(""):"should be a number"}],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a float"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be an ifn"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$883$en$$,"should be a map"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a vector"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be any"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,$malli$error$_pred_min_max_error_fn$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$351$pred$$,$cljs$core$float_QMARK_$$,$APP.$cljs$cst$141$message$$,"should be a float"],null))],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a symbol"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be false"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be associative"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,
"should match regex"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be an ident"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a qualified keyword"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,function($map__35061__$1_p__35059$$,$options$jscomp$385$$){$map__35061__$1_p__35059$$=$APP.$cljs$core$__destructure_map$$($map__35061__$1_p__35059$$);var $schema$jscomp$176$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35061__$1_p__35059$$,$APP.$cljs$cst$298$schema$$);return $malli$error$_en_humanize_negation$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__35061__$1_p__35059$$,$APP.$cljs$cst$298$schema$$,
$APP.$cljs$core$first$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$176$$))),$options$jscomp$385$$)}],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a char"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a negative int"],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,function($JSCompiler_temp$jscomp$10692_JSCompiler_temp$jscomp$10693_map__35082__$1_negated$jscomp$6_p__35077$$){$JSCompiler_temp$jscomp$10692_JSCompiler_temp$jscomp$10693_map__35082__$1_negated$jscomp$6_p__35077$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$10692_JSCompiler_temp$jscomp$10693_map__35082__$1_negated$jscomp$6_p__35077$$);
var $map__35101_min$jscomp$56_schema$jscomp$177$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10692_JSCompiler_temp$jscomp$10693_map__35082__$1_negated$jscomp$6_p__35077$$,$APP.$cljs$cst$298$schema$$),$G__35125$jscomp$inline_11517_JSCompiler_inline_result$jscomp$10694_value$jscomp$305$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10692_JSCompiler_temp$jscomp$10693_map__35082__$1_negated$jscomp$6_p__35077$$,$APP.$cljs$cst$260$value$$);
$JSCompiler_temp$jscomp$10692_JSCompiler_temp$jscomp$10693_map__35082__$1_negated$jscomp$6_p__35077$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10692_JSCompiler_temp$jscomp$10693_map__35082__$1_negated$jscomp$6_p__35077$$,$cljs$cst$878$negated$$);$map__35101_min$jscomp$56_schema$jscomp$177$$=$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($map__35101_min$jscomp$56_schema$jscomp$177$$);var $map__35101__$1_max$jscomp$54$$=$APP.$cljs$core$__destructure_map$$($map__35101_min$jscomp$56_schema$jscomp$177$$);
$map__35101_min$jscomp$56_schema$jscomp$177$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35101__$1_max$jscomp$54$$,$APP.$cljs$cst$338$min$$);$map__35101__$1_max$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35101__$1_max$jscomp$54$$,$APP.$cljs$cst$339$max$$);if(typeof $G__35125$jscomp$inline_11517_JSCompiler_inline_result$jscomp$10694_value$jscomp$305$$!=="string")$JSCompiler_temp$jscomp$10692_JSCompiler_temp$jscomp$10693_map__35082__$1_negated$jscomp$6_p__35077$$=
"should be a string";else if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__35101_min$jscomp$56_schema$jscomp$177$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__35101_min$jscomp$56_schema$jscomp$177$$,$map__35101__$1_max$jscomp$54$$):$map__35101_min$jscomp$56_schema$jscomp$177$$))$JSCompiler_temp$jscomp$10692_JSCompiler_temp$jscomp$10693_map__35082__$1_negated$jscomp$6_p__35077$$=["should be ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__35101_min$jscomp$56_schema$jscomp$177$$),
" character",$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$map__35101_min$jscomp$56_schema$jscomp$177$$)?"s":null].join("");else{if($APP.$cljs$core$truth_$$($map__35101_min$jscomp$56_schema$jscomp$177$$)){$G__35125$jscomp$inline_11517_JSCompiler_inline_result$jscomp$10694_value$jscomp$305$$=$APP.$cljs$core$count$$($G__35125$jscomp$inline_11517_JSCompiler_inline_result$jscomp$10694_value$jscomp$305$$);var $fexpr__35124$jscomp$inline_11518$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10692_JSCompiler_temp$jscomp$10693_map__35082__$1_negated$jscomp$6_p__35077$$)?
$cljs$core$_GT__EQ_$$:$APP.$cljs$core$_LT_$$;$G__35125$jscomp$inline_11517_JSCompiler_inline_result$jscomp$10694_value$jscomp$305$$=$fexpr__35124$jscomp$inline_11518$$.$cljs$core$IFn$_invoke$arity$2$?$fexpr__35124$jscomp$inline_11518$$.$cljs$core$IFn$_invoke$arity$2$($G__35125$jscomp$inline_11517_JSCompiler_inline_result$jscomp$10694_value$jscomp$305$$,$map__35101_min$jscomp$56_schema$jscomp$177$$):$fexpr__35124$jscomp$inline_11518$$($G__35125$jscomp$inline_11517_JSCompiler_inline_result$jscomp$10694_value$jscomp$305$$,
$map__35101_min$jscomp$56_schema$jscomp$177$$)}else $G__35125$jscomp$inline_11517_JSCompiler_inline_result$jscomp$10694_value$jscomp$305$$=$map__35101_min$jscomp$56_schema$jscomp$177$$;$JSCompiler_temp$jscomp$10692_JSCompiler_temp$jscomp$10693_map__35082__$1_negated$jscomp$6_p__35077$$=$APP.$cljs$core$truth_$$($G__35125$jscomp$inline_11517_JSCompiler_inline_result$jscomp$10694_value$jscomp$305$$)?["should be at least ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__35101_min$jscomp$56_schema$jscomp$177$$),
" character",$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$map__35101_min$jscomp$56_schema$jscomp$177$$)?"s":null].join(""):$APP.$cljs$core$truth_$$($map__35101__$1_max$jscomp$54$$)?["should be at most ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__35101__$1_max$jscomp$54$$)," character",$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$map__35101__$1_max$jscomp$54$$)?"s":null].join(""):$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10692_JSCompiler_temp$jscomp$10693_map__35082__$1_negated$jscomp$6_p__35077$$)?
"should be a string":null}return $JSCompiler_temp$jscomp$10692_JSCompiler_temp$jscomp$10693_map__35082__$1_negated$jscomp$6_p__35077$$}],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a symbol"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,
function($map__35154__$1_p__35150$$,$options$jscomp$386$$){$map__35154__$1_p__35150$$=$APP.$cljs$core$__destructure_map$$($map__35154__$1_p__35150$$);var $schema$jscomp$178$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35154__$1_p__35150$$,$APP.$cljs$cst$298$schema$$),$value$jscomp$306$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35154__$1_p__35150$$,$APP.$cljs$cst$260$value$$),$negated$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35154__$1_p__35150$$,
$cljs$cst$878$negated$$);return $APP.$cljs$core$truth_$$($negated$jscomp$7$$)?$malli$error$_forward_negation$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$709$_LT_$$,$APP.$cljs$core$first$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$178$$))],null),$map__35154__$1_p__35150$$,$options$jscomp$386$$):typeof $value$jscomp$306$$==="number"?["should be at least ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$178$$)))].join(""):
"should be a number"}],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a list"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,function($likely_misspelling_of_map__35165__$1_p__35164$$){$likely_misspelling_of_map__35165__$1_p__35164$$=$APP.$cljs$core$__destructure_map$$($likely_misspelling_of_map__35165__$1_p__35164$$);
$likely_misspelling_of_map__35165__$1_p__35164$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($likely_misspelling_of_map__35165__$1_p__35164$$,$cljs$cst$885$malli_DOT_error_SLASH_likely_misspelling_of$$);return["did you mean ",$APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$(" or ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($malli$error$_pr_str$$,$APP.$cljs$core$last$$),$likely_misspelling_of_map__35165__$1_p__35164$$))].join("")}],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a qualified ident"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a coll"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a valid function"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a keyword"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,function($map__35168__$1_p__35167_value$jscomp$307$$){$map__35168__$1_p__35167_value$jscomp$307$$=
$APP.$cljs$core$__destructure_map$$($map__35168__$1_p__35167_value$jscomp$307$$);var $map__35170_min$jscomp$57_schema$jscomp$179$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35168__$1_p__35167_value$jscomp$307$$,$APP.$cljs$cst$298$schema$$);$map__35168__$1_p__35167_value$jscomp$307$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35168__$1_p__35167_value$jscomp$307$$,$APP.$cljs$cst$260$value$$);$map__35170_min$jscomp$57_schema$jscomp$179$$=$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($map__35170_min$jscomp$57_schema$jscomp$179$$);
var $map__35170__$1_max$jscomp$55$$=$APP.$cljs$core$__destructure_map$$($map__35170_min$jscomp$57_schema$jscomp$179$$);$map__35170_min$jscomp$57_schema$jscomp$179$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35170__$1_max$jscomp$55$$,$APP.$cljs$cst$338$min$$);$map__35170__$1_max$jscomp$55$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35170__$1_max$jscomp$55$$,$APP.$cljs$cst$339$max$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__35170_min$jscomp$57_schema$jscomp$179$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__35170_min$jscomp$57_schema$jscomp$179$$,$map__35170__$1_max$jscomp$55$$):$map__35170_min$jscomp$57_schema$jscomp$179$$)?["should have ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__35170_min$jscomp$57_schema$jscomp$179$$)," elements"].join(""):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__35170_min$jscomp$57_schema$jscomp$179$$)?$APP.$cljs$core$count$$($map__35168__$1_p__35167_value$jscomp$307$$)<$map__35170_min$jscomp$57_schema$jscomp$179$$:
$map__35170_min$jscomp$57_schema$jscomp$179$$)?["should have at least ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__35170_min$jscomp$57_schema$jscomp$179$$)," elements"].join(""):$APP.$cljs$core$truth_$$($map__35170__$1_max$jscomp$55$$)?["should have at most ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__35170__$1_max$jscomp$55$$)," elements"].join(""):null}],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$883$en$$,"should be a simple symbol"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be empty"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be an integer"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"missing required key"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,function($p__35177_schema$jscomp$180_size$jscomp$73$$){var $map__35178__$1_value$jscomp$308$$=$APP.$cljs$core$__destructure_map$$($p__35177_schema$jscomp$180_size$jscomp$73$$);$p__35177_schema$jscomp$180_size$jscomp$73$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35178__$1_value$jscomp$308$$,$APP.$cljs$cst$298$schema$$);$map__35178__$1_value$jscomp$308$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35178__$1_value$jscomp$308$$,$APP.$cljs$cst$260$value$$);$p__35177_schema$jscomp$180_size$jscomp$73$$=$APP.$cljs$core$count$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($p__35177_schema$jscomp$180_size$jscomp$73$$));return["invalid tuple size ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$count$$($map__35178__$1_value$jscomp$308$$)),
", expected ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__35177_schema$jscomp$180_size$jscomp$73$$)].join("")}],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be zero"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a keyword"],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be nil"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a qualified keyword"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a string"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"end of input"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a qualified symbol"],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"input remaining"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a seq"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$883$en$$,"should be a non-negative int"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a set"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be some"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be positive"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a boolean"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,
"should be a fn"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be sequential"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a uuid"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"unknown error"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a number"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"invalid dispatch value"],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a double"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be seqable"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$883$en$$,function($map__35181__$1_p__35180_schema$jscomp$181$$){$map__35181__$1_p__35180_schema$jscomp$181$$=$APP.$cljs$core$__destructure_map$$($map__35181__$1_p__35180_schema$jscomp$181$$);$map__35181__$1_p__35180_schema$jscomp$181$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35181__$1_p__35180_schema$jscomp$181$$,$APP.$cljs$cst$298$schema$$);return["should be ",$malli$error$_pr_str$$($APP.$cljs$core$first$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($map__35181__$1_p__35180_schema$jscomp$181$$)))].join("")}],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a boolean"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,function($map__35185__$1_p__35184$$,$options$jscomp$387$$){$map__35185__$1_p__35184$$=$APP.$cljs$core$__destructure_map$$($map__35185__$1_p__35184$$);
var $schema$jscomp$182$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35185__$1_p__35184$$,$APP.$cljs$cst$298$schema$$),$value$jscomp$309$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35185__$1_p__35184$$,$APP.$cljs$cst$260$value$$),$negated$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35185__$1_p__35184$$,$cljs$cst$878$negated$$);return $APP.$cljs$core$truth_$$($negated$jscomp$8$$)?$malli$error$_forward_negation$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$708$_GT__EQ_$$,$APP.$cljs$core$first$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$182$$))],null),$map__35185__$1_p__35184$$,$options$jscomp$387$$):typeof $value$jscomp$309$$==="number"?["should be smaller than ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$182$$)))].join(""):"should be a number"}],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be negative"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,function($likely_misspelling_of$jscomp$1_map__35197__$1_p__35196$$){$likely_misspelling_of$jscomp$1_map__35197__$1_p__35196$$=$APP.$cljs$core$__destructure_map$$($likely_misspelling_of$jscomp$1_map__35197__$1_p__35196$$);
$likely_misspelling_of$jscomp$1_map__35197__$1_p__35196$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($likely_misspelling_of$jscomp$1_map__35197__$1_p__35196$$,$cljs$cst$885$malli_DOT_error_SLASH_likely_misspelling_of$$);return["should be spelled ",$APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$(" or ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($malli$error$_pr_str$$,$APP.$cljs$core$last$$),$likely_misspelling_of$jscomp$1_map__35197__$1_p__35196$$))].join("")}],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"invalid type"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be a positive int"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$883$en$$,"should be any"],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$882$error_SLASH_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$883$en$$,"should be indexed"],null)],null)]);var $cljs$math$little_endian_QMARK_$$,$a$jscomp$inline_3781$$=new ArrayBuffer(4),$i$jscomp$inline_3782$$=new Uint32Array($a$jscomp$inline_3781$$),$b$jscomp$inline_3783$$=new Uint8Array($a$jscomp$inline_3781$$);$i$jscomp$inline_3782$$[0]=857870592;
var $cljs$math$HI$$=($cljs$math$little_endian_QMARK_$$=$b$jscomp$inline_3783$$[0]===0)?1:0,$cljs$math$LO$$=1-$cljs$math$HI$$,$a$jscomp$inline_3785$$=new ArrayBuffer(16),$d$jscomp$inline_3786$$=new Float64Array($a$jscomp$inline_3785$$),$b$jscomp$inline_3787$$=new Uint8Array($a$jscomp$inline_3785$$);$d$jscomp$inline_3786$$[0]=0;$d$jscomp$inline_3786$$[1]=0;$b$jscomp$inline_3787$$[$cljs$math$little_endian_QMARK_$$?15:8]=-128;$cljs$math$power_of_two$$(512);$cljs$math$power_of_two$$(-512);var $goog$i18n$DateTimeSymbols_en$$={$ERAS$:["BC","AD"],$ERANAMES$:["Before Christ","Anno Domini"],$NARROWMONTHS$:"JFMAMJJASOND".split(""),$STANDALONENARROWMONTHS$:"JFMAMJJASOND".split(""),$MONTHS$:"January February March April May June July August September October November December".split(" "),$STANDALONEMONTHS$:"January February March April May June July August September October November December".split(" "),$SHORTMONTHS$:"Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec".split(" "),$STANDALONESHORTMONTHS$:"Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec".split(" "),
$WEEKDAYS$:"Sunday Monday Tuesday Wednesday Thursday Friday Saturday".split(" "),$STANDALONEWEEKDAYS$:"Sunday Monday Tuesday Wednesday Thursday Friday Saturday".split(" "),$SHORTWEEKDAYS$:"Sun Mon Tue Wed Thu Fri Sat".split(" "),$STANDALONESHORTWEEKDAYS$:"Sun Mon Tue Wed Thu Fri Sat".split(" "),$NARROWWEEKDAYS$:"SMTWTFS".split(""),$STANDALONENARROWWEEKDAYS$:"SMTWTFS".split(""),$SHORTQUARTERS$:["Q1","Q2","Q3","Q4"],$QUARTERS$:["1st quarter","2nd quarter","3rd quarter","4th quarter"],$AMPMS$:["AM",
"PM"],$DATEFORMATS$:["EEEE, MMMM d, y","MMMM d, y","MMM d, y","M/d/yy"],$TIMEFORMATS$:["h:mm:ss a zzzz","h:mm:ss a z","h:mm:ss a","h:mm a"],$DATETIMEFORMATS$:["{1} 'at' {0}","{1} 'at' {0}","{1}, {0}","{1}, {0}"],$FIRSTDAYOFWEEK$:6,$WEEKENDRANGE$:[5,6],$FIRSTWEEKCUTOFFDAY$:5},$goog$i18n$DateTimeSymbols$$=$goog$i18n$DateTimeSymbols_en$$;$goog$i18n$DateTimeSymbols$$=$goog$i18n$DateTimeSymbols_en$$;var $goog$date$splitDateStringRegex_$$=RegExp("^((?:[-+]\\d*)?\\d{4})(?:(?:-?(\\d{2})(?:-?(\\d{2}))?)|(?:-?(\\d{3}))|(?:-?W(\\d{2})(?:-?([1-7]))?))?$"),$goog$date$splitTimeStringRegex_$$=/^(\d{2})(?::?(\d{2})(?::?(\d{2})(\.\d+)?)?)?$/,$goog$date$splitTimezoneStringRegex_$$=/Z|(?:([-+])(\d{2})(?::?(\d{2}))?)$/;
$goog$date$Interval$$.prototype.$toIsoString$=function($opt_verbose$$){var $minField$$=Math.min(this.$years$,this.$months$,this.$days$,this.$hours$,this.$minutes$,this.$seconds$),$maxField_res$jscomp$24$$=Math.max(this.$years$,this.$months$,this.$days$,this.$hours$,this.$minutes$,this.$seconds$);if($minField$$<0&&$maxField_res$jscomp$24$$>0)return null;if(!$opt_verbose$$&&$minField$$==0&&$maxField_res$jscomp$24$$==0)return"PT0S";$maxField_res$jscomp$24$$=[];$minField$$<0&&$maxField_res$jscomp$24$$.push("-");
$maxField_res$jscomp$24$$.push("P");(this.$years$||$opt_verbose$$)&&$maxField_res$jscomp$24$$.push(Math.abs(this.$years$)+"Y");(this.$months$||$opt_verbose$$)&&$maxField_res$jscomp$24$$.push(Math.abs(this.$months$)+"M");(this.$days$||$opt_verbose$$)&&$maxField_res$jscomp$24$$.push(Math.abs(this.$days$)+"D");if(this.$hours$||this.$minutes$||this.$seconds$||$opt_verbose$$)$maxField_res$jscomp$24$$.push("T"),(this.$hours$||$opt_verbose$$)&&$maxField_res$jscomp$24$$.push(Math.abs(this.$hours$)+"H"),(this.$minutes$||
$opt_verbose$$)&&$maxField_res$jscomp$24$$.push(Math.abs(this.$minutes$)+"M"),(this.$seconds$||$opt_verbose$$)&&$maxField_res$jscomp$24$$.push(Math.abs(this.$seconds$)+"S");return $maxField_res$jscomp$24$$.join("")};
$goog$date$Interval$$.prototype.equals=function($other$jscomp$129$$){return $other$jscomp$129$$.$years$==this.$years$&&$other$jscomp$129$$.$months$==this.$months$&&$other$jscomp$129$$.$days$==this.$days$&&$other$jscomp$129$$.$hours$==this.$hours$&&$other$jscomp$129$$.$minutes$==this.$minutes$&&$other$jscomp$129$$.$seconds$==this.$seconds$};$goog$date$Interval$$.prototype.clone=function(){return new $goog$date$Interval$$(this.$years$,this.$months$,this.$days$,this.$hours$,this.$minutes$,this.$seconds$)};
var $goog$date$Interval$YEARS$$="y",$goog$date$Interval$MONTHS$$="m",$goog$date$Interval$DAYS$$="d",$goog$date$Interval$HOURS$$="h",$goog$date$Interval$MINUTES$$="n",$goog$date$Interval$SECONDS$$="s";$goog$date$Interval$$.prototype.$isZero$=function(){return this.$years$==0&&this.$months$==0&&this.$days$==0&&this.$hours$==0&&this.$minutes$==0&&this.$seconds$==0};
$goog$date$Interval$$.prototype.add=function($interval$jscomp$5$$){this.$years$+=$interval$jscomp$5$$.$years$;this.$months$+=$interval$jscomp$5$$.$months$;this.$days$+=$interval$jscomp$5$$.$days$;this.$hours$+=$interval$jscomp$5$$.$hours$;this.$minutes$+=$interval$jscomp$5$$.$minutes$;this.$seconds$+=$interval$jscomp$5$$.$seconds$};$APP.$JSCompiler_prototypeAlias$$=$goog$date$Date$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$firstDayOfWeek_$=$goog$i18n$DateTimeSymbols$$.$FIRSTDAYOFWEEK$;
$APP.$JSCompiler_prototypeAlias$$.$firstWeekCutOffDay_$=$goog$i18n$DateTimeSymbols$$.$FIRSTWEEKCUTOFFDAY$;$APP.$JSCompiler_prototypeAlias$$.clone=function(){var $date$jscomp$11$$=new $goog$date$Date$$(this.$date$);$date$jscomp$11$$.$firstDayOfWeek_$=this.$firstDayOfWeek_$;$date$jscomp$11$$.$firstWeekCutOffDay_$=this.$firstWeekCutOffDay_$;return $date$jscomp$11$$};$APP.$JSCompiler_prototypeAlias$$.getFullYear=function(){return this.$date$.getFullYear()};$APP.$JSCompiler_prototypeAlias$$.getYear=function(){return this.getFullYear()};
$APP.$JSCompiler_prototypeAlias$$.getMonth=function(){return this.$date$.getMonth()};$APP.$JSCompiler_prototypeAlias$$.getDate=function(){return this.$date$.getDate()};$APP.$JSCompiler_prototypeAlias$$.getTime=function(){return this.$date$.getTime()};$APP.$JSCompiler_prototypeAlias$$.getDay=function(){return this.$date$.getDay()};$APP.$JSCompiler_prototypeAlias$$.getUTCFullYear=function(){return this.$date$.getUTCFullYear()};$APP.$JSCompiler_prototypeAlias$$.getUTCMonth=function(){return this.$date$.getUTCMonth()};
$APP.$JSCompiler_prototypeAlias$$.getUTCDate=function(){return this.$date$.getUTCDate()};$APP.$JSCompiler_prototypeAlias$$.getUTCDay=function(){return this.$date$.getDay()};$APP.$JSCompiler_prototypeAlias$$.getUTCHours=function(){return this.$date$.getUTCHours()};$APP.$JSCompiler_prototypeAlias$$.getUTCMinutes=function(){return this.$date$.getUTCMinutes()};$APP.$JSCompiler_prototypeAlias$$.getTimezoneOffset=function(){return this.$date$.getTimezoneOffset()};
$APP.$JSCompiler_prototypeAlias$$.set=function($date$jscomp$12$$){this.$date$=new Date($date$jscomp$12$$.getFullYear(),$date$jscomp$12$$.getMonth(),$date$jscomp$12$$.getDate())};$APP.$JSCompiler_prototypeAlias$$.setFullYear=function($year$jscomp$12$$){this.$date$.setFullYear($year$jscomp$12$$)};$APP.$JSCompiler_prototypeAlias$$.setYear=function($year$jscomp$13$$){this.setFullYear($year$jscomp$13$$)};$APP.$JSCompiler_prototypeAlias$$.setMonth=function($month$jscomp$8$$){this.$date$.setMonth($month$jscomp$8$$)};
$APP.$JSCompiler_prototypeAlias$$.setDate=function($date$jscomp$13$$){this.$date$.setDate($date$jscomp$13$$)};$APP.$JSCompiler_prototypeAlias$$.setTime=function($ms$jscomp$1$$){this.$date$.setTime($ms$jscomp$1$$)};$APP.$JSCompiler_prototypeAlias$$.setUTCFullYear=function($year$jscomp$14$$){this.$date$.setUTCFullYear($year$jscomp$14$$)};$APP.$JSCompiler_prototypeAlias$$.setUTCMonth=function($month$jscomp$9$$){this.$date$.setUTCMonth($month$jscomp$9$$)};
$APP.$JSCompiler_prototypeAlias$$.setUTCDate=function($date$jscomp$14$$){this.$date$.setUTCDate($date$jscomp$14$$)};
$APP.$JSCompiler_prototypeAlias$$.add=function($interval$jscomp$6_result$jscomp$113$$){if($interval$jscomp$6_result$jscomp$113$$.$years$||$interval$jscomp$6_result$jscomp$113$$.$months$){var $month$jscomp$10_yearAdjustment$$=this.getMonth()+$interval$jscomp$6_result$jscomp$113$$.$months$+$interval$jscomp$6_result$jscomp$113$$.$years$*12,$initialYear_year$jscomp$15$$=this.getYear()+Math.floor($month$jscomp$10_yearAdjustment$$/12);$month$jscomp$10_yearAdjustment$$%=12;$month$jscomp$10_yearAdjustment$$<
0&&($month$jscomp$10_yearAdjustment$$+=12);a:{switch($month$jscomp$10_yearAdjustment$$){case 1:var $JSCompiler_inline_result$jscomp$493_date$jscomp$15$$=$initialYear_year$jscomp$15$$%4!=0||$initialYear_year$jscomp$15$$%100==0&&$initialYear_year$jscomp$15$$%400!=0?28:29;break a;case 5:case 8:case 10:case 3:$JSCompiler_inline_result$jscomp$493_date$jscomp$15$$=30;break a}$JSCompiler_inline_result$jscomp$493_date$jscomp$15$$=31}$JSCompiler_inline_result$jscomp$493_date$jscomp$15$$=Math.min($JSCompiler_inline_result$jscomp$493_date$jscomp$15$$,
this.getDate());this.setDate(1);this.setFullYear($initialYear_year$jscomp$15$$);this.setMonth($month$jscomp$10_yearAdjustment$$);this.setDate($JSCompiler_inline_result$jscomp$493_date$jscomp$15$$)}$interval$jscomp$6_result$jscomp$113$$.$days$&&($initialYear_year$jscomp$15$$=this.getYear(),$month$jscomp$10_yearAdjustment$$=$initialYear_year$jscomp$15$$>=0&&$initialYear_year$jscomp$15$$<=99?-1900:0,$interval$jscomp$6_result$jscomp$113$$=new Date((new Date($initialYear_year$jscomp$15$$,this.getMonth(),
this.getDate(),12)).getTime()+$interval$jscomp$6_result$jscomp$113$$.$days$*864E5),this.setDate(1),this.setFullYear($interval$jscomp$6_result$jscomp$113$$.getFullYear()+$month$jscomp$10_yearAdjustment$$),this.setMonth($interval$jscomp$6_result$jscomp$113$$.getMonth()),this.setDate($interval$jscomp$6_result$jscomp$113$$.getDate()),$JSCompiler_StaticMethods_maybeFixDst_$$(this,$interval$jscomp$6_result$jscomp$113$$.getDate()))};
$APP.$JSCompiler_prototypeAlias$$.$toIsoString$=function($opt_verbose$jscomp$1$$){var $year$jscomp$inline_3803$$=this.getFullYear();const $sign$jscomp$inline_3804$$=$year$jscomp$inline_3803$$<0?"-":$year$jscomp$inline_3803$$>=1E4?"+":"";return[$sign$jscomp$inline_3804$$+$goog$string$padNumber$$(Math.abs($year$jscomp$inline_3803$$),$sign$jscomp$inline_3804$$?6:4),$goog$string$padNumber$$(this.getMonth()+1,2),$goog$string$padNumber$$(this.getDate(),2)].join($opt_verbose$jscomp$1$$?"-":"")+""};
$APP.$JSCompiler_prototypeAlias$$.equals=function($other$jscomp$130$$){return!(!$other$jscomp$130$$||this.getYear()!=$other$jscomp$130$$.getYear()||this.getMonth()!=$other$jscomp$130$$.getMonth()||this.getDate()!=$other$jscomp$130$$.getDate())};$APP.$JSCompiler_prototypeAlias$$.toString=function(){return this.$toIsoString$()};$APP.$JSCompiler_prototypeAlias$$.valueOf=function(){return this.$date$.valueOf()};$APP.$goog$inherits$$($goog$date$DateTime$$,$goog$date$Date$$);
$APP.$JSCompiler_prototypeAlias$$=$goog$date$DateTime$$.prototype;$APP.$JSCompiler_prototypeAlias$$.getHours=function(){return this.$date$.getHours()};$APP.$JSCompiler_prototypeAlias$$.getMinutes=function(){return this.$date$.getMinutes()};$APP.$JSCompiler_prototypeAlias$$.getSeconds=function(){return this.$date$.getSeconds()};$APP.$JSCompiler_prototypeAlias$$.getMilliseconds=function(){return this.$date$.getMilliseconds()};$APP.$JSCompiler_prototypeAlias$$.getUTCDay=function(){return this.$date$.getUTCDay()};
$APP.$JSCompiler_prototypeAlias$$.getUTCHours=function(){return this.$date$.getUTCHours()};$APP.$JSCompiler_prototypeAlias$$.getUTCMinutes=function(){return this.$date$.getUTCMinutes()};$APP.$JSCompiler_prototypeAlias$$.getUTCSeconds=function(){return this.$date$.getUTCSeconds()};$APP.$JSCompiler_prototypeAlias$$.getUTCMilliseconds=function(){return this.$date$.getUTCMilliseconds()};$APP.$JSCompiler_prototypeAlias$$.setHours=function($hours$jscomp$3$$){this.$date$.setHours($hours$jscomp$3$$)};
$APP.$JSCompiler_prototypeAlias$$.setMinutes=function($minutes$jscomp$3$$){this.$date$.setMinutes($minutes$jscomp$3$$)};$APP.$JSCompiler_prototypeAlias$$.setSeconds=function($seconds$jscomp$3$$){this.$date$.setSeconds($seconds$jscomp$3$$)};$APP.$JSCompiler_prototypeAlias$$.setMilliseconds=function($ms$jscomp$2$$){this.$date$.setMilliseconds($ms$jscomp$2$$)};$APP.$JSCompiler_prototypeAlias$$.setUTCHours=function($hours$jscomp$4$$){this.$date$.setUTCHours($hours$jscomp$4$$)};
$APP.$JSCompiler_prototypeAlias$$.setUTCMinutes=function($minutes$jscomp$4$$){this.$date$.setUTCMinutes($minutes$jscomp$4$$)};$APP.$JSCompiler_prototypeAlias$$.setUTCSeconds=function($seconds$jscomp$4$$){this.$date$.setUTCSeconds($seconds$jscomp$4$$)};$APP.$JSCompiler_prototypeAlias$$.setUTCMilliseconds=function($ms$jscomp$3$$){this.$date$.setUTCMilliseconds($ms$jscomp$3$$)};
$APP.$JSCompiler_prototypeAlias$$.add=function($interval$jscomp$7$$){$goog$date$Date$$.prototype.add.call(this,$interval$jscomp$7$$);$interval$jscomp$7$$.$hours$&&this.setUTCHours(this.$date$.getUTCHours()+$interval$jscomp$7$$.$hours$);$interval$jscomp$7$$.$minutes$&&this.setUTCMinutes(this.$date$.getUTCMinutes()+$interval$jscomp$7$$.$minutes$);$interval$jscomp$7$$.$seconds$&&this.setUTCSeconds(this.$date$.getUTCSeconds()+$interval$jscomp$7$$.$seconds$)};
$APP.$JSCompiler_prototypeAlias$$.$toIsoString$=function($opt_verbose$jscomp$3$$){var $dateString$$=$goog$date$Date$$.prototype.$toIsoString$.call(this,$opt_verbose$jscomp$3$$);return $opt_verbose$jscomp$3$$?$dateString$$+"T"+$goog$string$padNumber$$(this.getHours(),2)+":"+$goog$string$padNumber$$(this.getMinutes(),2)+":"+$goog$string$padNumber$$(this.getSeconds(),2):$dateString$$+"T"+$goog$string$padNumber$$(this.getHours(),2)+$goog$string$padNumber$$(this.getMinutes(),2)+$goog$string$padNumber$$(this.getSeconds(),
2)};$APP.$JSCompiler_prototypeAlias$$.equals=function($other$jscomp$131$$){return this.getTime()==$other$jscomp$131$$.getTime()};$APP.$JSCompiler_prototypeAlias$$.toString=function(){return this.$toIsoString$()};$APP.$JSCompiler_prototypeAlias$$.clone=function(){var $date$jscomp$19$$=new $goog$date$DateTime$$(this.$date$);$date$jscomp$19$$.$firstDayOfWeek_$=this.$firstDayOfWeek_$;$date$jscomp$19$$.$firstWeekCutOffDay_$=this.$firstWeekCutOffDay_$;return $date$jscomp$19$$};$APP.$goog$inherits$$($goog$date$UtcDateTime$$,$goog$date$DateTime$$);$APP.$JSCompiler_prototypeAlias$$=$goog$date$UtcDateTime$$.prototype;$APP.$JSCompiler_prototypeAlias$$.clone=function(){var $date$jscomp$21$$=new $goog$date$UtcDateTime$$(this.$date$);$date$jscomp$21$$.$firstDayOfWeek_$=this.$firstDayOfWeek_$;$date$jscomp$21$$.$firstWeekCutOffDay_$=this.$firstWeekCutOffDay_$;return $date$jscomp$21$$};
$APP.$JSCompiler_prototypeAlias$$.add=function($interval$jscomp$8$$){($interval$jscomp$8$$.$years$||$interval$jscomp$8$$.$months$)&&$goog$date$Date$$.prototype.add.call(this,new $goog$date$Interval$$($interval$jscomp$8$$.$years$,$interval$jscomp$8$$.$months$));this.$date$=new Date(this.$date$.getTime()+1E3*($interval$jscomp$8$$.$seconds$+60*($interval$jscomp$8$$.$minutes$+60*($interval$jscomp$8$$.$hours$+24*$interval$jscomp$8$$.$days$))))};$APP.$JSCompiler_prototypeAlias$$.getTimezoneOffset=function(){return 0};
$APP.$JSCompiler_prototypeAlias$$.getFullYear=$goog$date$DateTime$$.prototype.getUTCFullYear;$APP.$JSCompiler_prototypeAlias$$.getMonth=$goog$date$DateTime$$.prototype.getUTCMonth;$APP.$JSCompiler_prototypeAlias$$.getDate=$goog$date$DateTime$$.prototype.getUTCDate;$APP.$JSCompiler_prototypeAlias$$.getHours=$goog$date$DateTime$$.prototype.getUTCHours;$APP.$JSCompiler_prototypeAlias$$.getMinutes=$goog$date$DateTime$$.prototype.getUTCMinutes;$APP.$JSCompiler_prototypeAlias$$.getSeconds=$goog$date$DateTime$$.prototype.getUTCSeconds;
$APP.$JSCompiler_prototypeAlias$$.getMilliseconds=$goog$date$DateTime$$.prototype.getUTCMilliseconds;$APP.$JSCompiler_prototypeAlias$$.getDay=$goog$date$DateTime$$.prototype.getUTCDay;$APP.$JSCompiler_prototypeAlias$$.setFullYear=$goog$date$DateTime$$.prototype.setUTCFullYear;$APP.$JSCompiler_prototypeAlias$$.setMonth=$goog$date$DateTime$$.prototype.setUTCMonth;$APP.$JSCompiler_prototypeAlias$$.setDate=$goog$date$DateTime$$.prototype.setUTCDate;$APP.$JSCompiler_prototypeAlias$$.setHours=$goog$date$DateTime$$.prototype.setUTCHours;
$APP.$JSCompiler_prototypeAlias$$.setMinutes=$goog$date$DateTime$$.prototype.setUTCMinutes;$APP.$JSCompiler_prototypeAlias$$.setSeconds=$goog$date$DateTime$$.prototype.setUTCSeconds;$APP.$JSCompiler_prototypeAlias$$.setMilliseconds=$goog$date$DateTime$$.prototype.setUTCMilliseconds;var $malli$transform$_interceptor$$=function $malli$transform$_interceptor$$($_QMARK_interceptor$$,$schema$jscomp$188$$,$options$jscomp$398$$){if($APP.$cljs$core$fn_QMARK_$$($_QMARK_interceptor$$))return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$381$enter$$,$_QMARK_interceptor$$],null);if($APP.$cljs$core$map_QMARK_$$($_QMARK_interceptor$$)&&$APP.$cljs$core$contains_QMARK_$$($_QMARK_interceptor$$,$APP.$cljs$cst$411$compile$$)){var $compiled_temp__5825__auto__$jscomp$76$$=$cljs$cst$902$malli_DOT_transform_SLASH_compiled$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$398$$,
0),$options__$1$jscomp$61$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$398$$,$cljs$cst$902$malli_DOT_transform_SLASH_compiled$$,$compiled_temp__5825__auto__$jscomp$76$$+1);$compiled_temp__5825__auto__$jscomp$76$$>=10&&$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$903$malli_DOT_transform_SLASH_too_deep_compilation$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$904$this$$,$_QMARK_interceptor$$,$APP.$cljs$cst$298$schema$$,$schema$jscomp$188$$,
$APP.$cljs$cst$873$options$$,$options__$1$jscomp$61$$],null));$compiled_temp__5825__auto__$jscomp$76$$=function(){var $G__34928_fexpr__34932$jscomp$inline_3818$$=$APP.$cljs$cst$411$compile$$.$cljs$core$IFn$_invoke$arity$1$($_QMARK_interceptor$$);$G__34928_fexpr__34932$jscomp$inline_3818$$=$G__34928_fexpr__34932$jscomp$inline_3818$$.$cljs$core$IFn$_invoke$arity$2$?$G__34928_fexpr__34932$jscomp$inline_3818$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$188$$,$options__$1$jscomp$61$$):$G__34928_fexpr__34932$jscomp$inline_3818$$($schema$jscomp$188$$,
$options__$1$jscomp$61$$);return $malli$transform$_interceptor$$.$cljs$core$IFn$_invoke$arity$3$?$malli$transform$_interceptor$$.$cljs$core$IFn$_invoke$arity$3$($G__34928_fexpr__34932$jscomp$inline_3818$$,$schema$jscomp$188$$,$options__$1$jscomp$61$$):$malli$transform$_interceptor$$($G__34928_fexpr__34932$jscomp$inline_3818$$,$schema$jscomp$188$$,$options__$1$jscomp$61$$)}();return $APP.$cljs$core$truth_$$($compiled_temp__5825__auto__$jscomp$76$$)?$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_interceptor$$,
$APP.$cljs$cst$411$compile$$),$compiled_temp__5825__auto__$jscomp$76$$])):null}return $APP.$cljs$core$map_QMARK_$$($_QMARK_interceptor$$)&&($APP.$cljs$core$contains_QMARK_$$($_QMARK_interceptor$$,$APP.$cljs$cst$381$enter$$)||$APP.$cljs$core$contains_QMARK_$$($_QMARK_interceptor$$,$cljs$cst$382$leave$$))?$_QMARK_interceptor$$:$APP.$cljs$core$coll_QMARK_$$($_QMARK_interceptor$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(function($map__34957__$1_p__34955$$,$map__34958__$1_p__34956$$){$map__34957__$1_p__34955$$=
$APP.$cljs$core$__destructure_map$$($map__34957__$1_p__34955$$);var $enter$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34957__$1_p__34955$$,$APP.$cljs$cst$381$enter$$),$leave$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34957__$1_p__34955$$,$cljs$cst$382$leave$$);$map__34958__$1_p__34956$$=$APP.$cljs$core$__destructure_map$$($map__34958__$1_p__34956$$);var $new_enter$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34958__$1_p__34956$$,
$APP.$cljs$cst$381$enter$$),$new_leave$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34958__$1_p__34956$$,$cljs$cst$382$leave$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$381$enter$$,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($enter$jscomp$1$$)?$new_enter$$:$enter$jscomp$1$$)?function($G__34963_p1__34919_SHARP_$$){$G__34963_p1__34919_SHARP_$$=$enter$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$enter$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__34963_p1__34919_SHARP_$$):
$enter$jscomp$1$$($G__34963_p1__34919_SHARP_$$);return $new_enter$$.$cljs$core$IFn$_invoke$arity$1$?$new_enter$$.$cljs$core$IFn$_invoke$arity$1$($G__34963_p1__34919_SHARP_$$):$new_enter$$($G__34963_p1__34919_SHARP_$$)}:$APP.$cljs$core$truth_$$($enter$jscomp$1$$)?$enter$jscomp$1$$:$new_enter$$,$cljs$cst$382$leave$$,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($leave$jscomp$1$$)?$new_leave$$:$leave$jscomp$1$$)?function($G__34966_p1__34920_SHARP_$$){$G__34966_p1__34920_SHARP_$$=$new_leave$$.$cljs$core$IFn$_invoke$arity$1$?
$new_leave$$.$cljs$core$IFn$_invoke$arity$1$($G__34966_p1__34920_SHARP_$$):$new_leave$$($G__34966_p1__34920_SHARP_$$);return $leave$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$leave$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__34966_p1__34920_SHARP_$$):$leave$jscomp$1$$($G__34966_p1__34920_SHARP_$$)}:$APP.$cljs$core$truth_$$($leave$jscomp$1$$)?$leave$jscomp$1$$:$new_leave$$],null)},$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__34921_SHARP_$$){return $malli$transform$_interceptor$$.$cljs$core$IFn$_invoke$arity$3$?
$malli$transform$_interceptor$$.$cljs$core$IFn$_invoke$arity$3$($p1__34921_SHARP_$$,$schema$jscomp$188$$,$options$jscomp$398$$):$malli$transform$_interceptor$$($p1__34921_SHARP_$$,$schema$jscomp$188$$,$options$jscomp$398$$)},$_QMARK_interceptor$$)):$_QMARK_interceptor$$==null?null:$cljs$core$ifn_QMARK_$$($_QMARK_interceptor$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$381$enter$$,$_QMARK_interceptor$$],null):$malli$core$_fail_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$905$malli_DOT_transform_SLASH_invalid_transformer$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$_QMARK_interceptor$$],null))},$malli$transform$uuid_re$$=/^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$/i;$APP.$JSCompiler_prototypeAlias$$=$malli$transform$t_malli$0transform35235$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_35237$$,$meta35236__$1$$){return new $malli$transform$t_malli$0transform35235$$(this.$_QMARK_transformers$,this.$__GT_data$,this.$__GT_eval$,this.$__GT_chain$,this.$chain$,this.$chain_SINGLEQUOTE_$,$meta35236__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta35236$};$APP.$JSCompiler_prototypeAlias$$.$malli$core$Transformer$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Transformer$_transformer_chain$arity$1$=function(){return this.$chain$};
$APP.$JSCompiler_prototypeAlias$$.$malli$core$Transformer$_value_transformer$arity$4$=function($_$jscomp$780$$,$schema$jscomp$191$$,$method$jscomp$39$$,$options$jscomp$399$$){var $self__$jscomp$2070$$=this;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$74$$,$interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$){function $from$jscomp$7$$($f$jscomp$488$$){return function($G__35257_p1__35219_SHARP_$$){$G__35257_p1__35219_SHARP_$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$488$$.$cljs$core$IFn$_invoke$arity$1$?
$f$jscomp$488$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$191$$):$f$jscomp$488$$($schema$jscomp$191$$),$G__35257_p1__35219_SHARP_$$);return $G__35257_p1__35219_SHARP_$$==null?null:$self__$jscomp$2070$$.$__GT_eval$.$cljs$core$IFn$_invoke$arity$2$?$self__$jscomp$2070$$.$__GT_eval$.$cljs$core$IFn$_invoke$arity$2$($G__35257_p1__35219_SHARP_$$,$options__$1$jscomp$62$$):$self__$jscomp$2070$$.$__GT_eval$($G__35257_p1__35219_SHARP_$$,$options__$1$jscomp$62$$)}}$interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$=
$APP.$cljs$core$__destructure_map$$($interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$);$interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$,$method$jscomp$39$$);$interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$=
$APP.$cljs$core$__destructure_map$$($interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$);var $keys$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$,$cljs$cst$391$keys$$),$default$$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$,
$APP.$cljs$cst$205$default$$),$transformers$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$,$cljs$cst$908$transformers$$),$options__$1$jscomp$62$$=$APP.$cljs$core$truth_$$($options$jscomp$399$$)?$options$jscomp$399$$:$APP.$malli$core$options$cljs$0core$0IFn$0_invoke$0arity$02$$($schema$jscomp$191$$),$from_properties$$=$cljs$core$some_fn$cljs$0core$0IFn$0_invoke$0arity$02$$($from$jscomp$7$$($APP.$malli$core$properties$$),
$from$jscomp$7$$($malli$core$type_properties$$));$interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$=function(){var $or__5025__auto__$jscomp$183_or__5025__auto____$1$jscomp$23$$=$APP.$cljs$core$some$$($from_properties$$,$keys$jscomp$34$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$183_or__5025__auto____$1$jscomp$23$$))return $or__5025__auto__$jscomp$183_or__5025__auto____$1$jscomp$23$$;$or__5025__auto__$jscomp$183_or__5025__auto____$1$jscomp$23$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($transformers$jscomp$1$$,$APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$191$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$183_or__5025__auto____$1$jscomp$23$$)?$or__5025__auto__$jscomp$183_or__5025__auto____$1$jscomp$23$$:$default$$jscomp$39$$}();return $APP.$cljs$core$truth_$$($interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$)?($interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$=
$malli$transform$_interceptor$$($interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$,$schema$jscomp$191$$,$options__$1$jscomp$62$$),$acc$jscomp$74$$==null?$interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$:$malli$transform$_interceptor$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$acc$jscomp$74$$,$interceptor$jscomp$2_map__35251__$1_map__35252_map__35252__$1_p__35249_temp__5823__auto__$jscomp$74$$],
null),$schema$jscomp$191$$,$options__$1$jscomp$62$$)):$acc$jscomp$74$$},null,$self__$jscomp$2070$$.$chain_SINGLEQUOTE_$)};
var $malli$transform$transformer$$=function $malli$transform$transformer$$($var_args$jscomp$611$$){for(var $args__5755__auto__$jscomp$114$$=[],$len__5749__auto___35524$$=arguments.length,$i__5750__auto___35526$$=0;;)if($i__5750__auto___35526$$<$len__5749__auto___35524$$)$args__5755__auto__$jscomp$114$$.push(arguments[$i__5750__auto___35526$$]),$i__5750__auto___35526$$+=1;else break;return $malli$transform$transformer$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$114$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$114$$.slice(0),0,null):null)};
$malli$transform$transformer$$.$cljs$core$IFn$_invoke$arity$variadic$=function($_QMARK_transformers$jscomp$2$$){function $__GT_eval$jscomp$2$$($x$jscomp$868$$,$options$jscomp$400$$){return $APP.$cljs$core$map_QMARK_$$($x$jscomp$868$$)?$APP.$cljs$core$reduce_kv$$(function($x__$1$jscomp$23$$,$k$jscomp$441$$,$v$jscomp$221$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($x__$1$jscomp$23$$,$k$jscomp$441$$,$malli$core$eval$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$221$$,$options$jscomp$400$$))},
$x$jscomp$868$$,$x$jscomp$868$$):$malli$core$eval$cljs$0core$0IFn$0_invoke$0arity$02$$($x$jscomp$868$$,null)}function $__GT_data$jscomp$2$$($ts$jscomp$6$$,$default$$jscomp$40$$,$JSCompiler_temp$jscomp$497_name$jscomp$129$$,$key$jscomp$251$$){if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$497_name$jscomp$129$$)){var $G__35229$jscomp$inline_3823$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$251$$),$JSCompiler_temp$jscomp$497_name$jscomp$129$$],null)],null);$JSCompiler_temp$jscomp$497_name$jscomp$129$$=$cljs$core$qualified_keyword_QMARK_$$($JSCompiler_temp$jscomp$497_name$jscomp$129$$)?$G__35229$jscomp$inline_3823$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__35229$jscomp$inline_3823$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$251$$,
$APP.$cljs$core$name$$($JSCompiler_temp$jscomp$497_name$jscomp$129$$))],null))}else $JSCompiler_temp$jscomp$497_name$jscomp$129$$=null;return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$908$transformers$$,$ts$jscomp$6$$,$APP.$cljs$cst$205$default$$,$default$$jscomp$40$$,$cljs$cst$391$keys$$,$JSCompiler_temp$jscomp$497_name$jscomp$129$$],null)}var $__GT_chain$jscomp$2$$=$malli$core$_comp$$.$cljs$core$IFn$_invoke$arity$2$($malli$core$_transformer_chain$$,$malli$core$_into_transformer$$),
$chain$jscomp$2$$=$APP.$cljs$core$vec$$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__35213_SHARP_$$){return $APP.$cljs$core$map_QMARK_$$($p1__35213_SHARP_$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__35213_SHARP_$$],null):$__GT_chain$jscomp$2$$($p1__35213_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$identity$$,
$_QMARK_transformers$jscomp$2$$)]))),$chain_SINGLEQUOTE_$jscomp$2$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__35215_SHARP_$$){var $name$jscomp$130$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__35215_SHARP_$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$384$decode$$,$__GT_data$jscomp$2$$($cljs$cst$916$decoders$$.$cljs$core$IFn$_invoke$arity$1$($p1__35215_SHARP_$$),$cljs$cst$917$default_decoder$$.$cljs$core$IFn$_invoke$arity$1$($p1__35215_SHARP_$$),
$name$jscomp$130$$,"decode"),$cljs$cst$648$encode$$,$__GT_data$jscomp$2$$($cljs$cst$918$encoders$$.$cljs$core$IFn$_invoke$arity$1$($p1__35215_SHARP_$$),$cljs$cst$919$default_encoder$$.$cljs$core$IFn$_invoke$arity$1$($p1__35215_SHARP_$$),$name$jscomp$130$$,"encode")],null)},$chain$jscomp$2$$);return $APP.$cljs$core$seq$$($chain$jscomp$2$$)?new $malli$transform$t_malli$0transform35235$$($_QMARK_transformers$jscomp$2$$,$__GT_data$jscomp$2$$,$__GT_eval$jscomp$2$$,$__GT_chain$jscomp$2$$,$chain$jscomp$2$$,
$chain_SINGLEQUOTE_$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$):null};$malli$transform$transformer$$.$cljs$lang$maxFixedArity$=0;$malli$transform$transformer$$.$cljs$lang$applyTo$=function($seq35222$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq35222$$))};var $app$common$schema$default_options$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$352$registry$$,$app$common$schema$registry$default_registry$$],null),$app$common$schema$xf_COLON_map_key$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$key$$);$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$735$merge$$,$malli$util$_merge$$());
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$736$union$$,$malli$util$_union$$());
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$uuid_QMARK_$$,$cljs$cst$415$type_properties$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$936$description$$,$cljs$cst$937$decode_SLASH_string$$,$APP.$cljs$cst$938$decode_SLASH_json$$,$APP.$cljs$cst$939$title$$,$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,
$cljs$cst$941$encode_SLASH_json$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,$cljs$cst$869$gen_SLASH_gen$$,$APP.$cljs$cst$882$error_SLASH_message$$,$cljs$cst$943$encode_SLASH_string$$],["UUID formatted string",$app$common$schema$parse_uuid$$,$app$common$schema$parse_uuid$$,"uuid","uuid",$app$common$schema$encode_uuid$$,"string",$clojure$test$check$generators$fmap$$(function(){return $APP.$app$common$uuid$next$$()},$app$common$schema$generators$small_int$$()),"should be an uuid",
$app$common$schema$encode_uuid$$])],null));var $app$common$schema$email_re$$=/[a-zA-Z0-9!#$%&'*+\/=?^_`{|}~-]+(\.[a-zA-Z0-9!#$%&'*+\/=?^_`{|}~-]+)*@[a-zA-Z0-9]([a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(\.[a-zA-Z0-9]([a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*\.[a-zA-Z]{2,63}/;
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$,$APP.$cljs$cst$351$pred$$,function($s$jscomp$413$$){return typeof $s$jscomp$413$$==="string"&&$APP.$cljs$core$re_matches$$($app$common$schema$email_re$$,$s$jscomp$413$$)!=null},$cljs$cst$413$property_pred$$,function($map__40299__$1_p__40298$$){$map__40299__$1_p__40298$$=$APP.$cljs$core$__destructure_map$$($map__40299__$1_p__40298$$);
var $max$jscomp$56$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40299__$1_p__40298$$,$APP.$cljs$cst$339$max$$);return $max$jscomp$56$$!=null?function($value$jscomp$322$$){return $APP.$cljs$core$count$$($value$jscomp$322$$)<=$max$jscomp$56$$}:$APP.$cljs$core$constantly$$(!0)},$cljs$cst$415$type_properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$939$title$$,"email",$APP.$cljs$cst$936$description$$,"string with valid email address",$APP.$cljs$cst$945$error_SLASH_code$$,
"errors.invalid-email",$cljs$cst$869$gen_SLASH_gen$$,$clojure$test$check$generators$fmap$$(function($v$jscomp$212$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$212$$),"@example.net"].join("")},$clojure$test$check$generators$fmap$$($APP.$cuerdas$core$lower$$,$clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$2$(function($v$jscomp$213$$){return $APP.$cljs$core$count$$($v$jscomp$213$$)>=4},$app$common$schema$generators$word_string$$()))),$cljs$cst$937$decode_SLASH_string$$,
function($v$jscomp$232$$){var $or__5025__auto__$jscomp$194$$=$APP.$app$common$schema$parse_email$$($v$jscomp$232$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$194$$)?$or__5025__auto__$jscomp$194$$:$v$jscomp$232$$},$APP.$cljs$cst$938$decode_SLASH_json$$,function($v$jscomp$233$$){var $or__5025__auto__$jscomp$195$$=$APP.$app$common$schema$parse_email$$($v$jscomp$233$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$195$$)?$or__5025__auto__$jscomp$195$$:$v$jscomp$233$$},$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,
"string",$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,"email"],null)],null));var $app$common$schema$xf_COLON_filter_word_strings$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$string_QMARK_$$),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$empty_QMARK_$$),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$blank_QMARK_$$));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$schema$coll_schema$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,$APP.$cljs$cst$338$min$$,0,$APP.$cljs$cst$339$max$$,1,$APP.$cljs$cst$411$compile$$,function($map__40331__$1_ordered_p__40330$$,$children$jscomp$128$$){function $decode$jscomp$5$$($v$jscomp$234_v__$1$jscomp$14$$){return typeof $v$jscomp$234_v__$1$jscomp$14$$===
"string"?($v$jscomp$234_v__$1$jscomp$14$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$234_v__$1$jscomp$14$$,/[\s,]+/),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($empty_set$$,$app$common$schema$xf_COLON_filter_word_strings$$,$v$jscomp$234_v__$1$jscomp$14$$)):$APP.$cljs$core$set_QMARK_$$($v$jscomp$234_v__$1$jscomp$14$$)?$v$jscomp$234_v__$1$jscomp$14$$:$APP.$cljs$core$coll_QMARK_$$($v$jscomp$234_v__$1$jscomp$14$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($empty_set$$,
$v$jscomp$234_v__$1$jscomp$14$$):$v$jscomp$234_v__$1$jscomp$14$$}$map__40331__$1_ordered_p__40330$$=$APP.$cljs$core$__destructure_map$$($map__40331__$1_ordered_p__40330$$);var $kind$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40331__$1_ordered_p__40330$$,$APP.$cljs$cst$947$kind$$),$max$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40331__$1_ordered_p__40330$$,$APP.$cljs$cst$339$max$$),$min$jscomp$58$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40331__$1_ordered_p__40330$$,
$APP.$cljs$cst$338$min$$);$map__40331__$1_ordered_p__40330$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40331__$1_ordered_p__40330$$,$cljs$cst$948$ordered$$);var $kind__$1$$=function(){var $or__5025__auto__$jscomp$196$$=$APP.$cljs$core$last$$($children$jscomp$128$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$196$$)?$or__5025__auto__$jscomp$196$$:$kind$jscomp$17$$}(),$child_pred$$=$APP.$cljs$core$fn_QMARK_$$($kind__$1$$)?$kind__$1$$:$kind__$1$$==null?$APP.$cljs$core$any_QMARK_$$:
$app$common$schema$validator$$($kind__$1$$),$type_pred$$=$APP.$cljs$core$truth_$$($map__40331__$1_ordered_p__40330$$)?$app$common$data$ordered_set_QMARK_$$:$APP.$cljs$core$set_QMARK_$$,$pred$jscomp$45$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($max$jscomp$57$$)?$min$jscomp$58$$:$max$jscomp$57$$)?function($value$jscomp$323$$){var $and__5023__auto__$jscomp$132$$=$type_pred$$.$cljs$core$IFn$_invoke$arity$1$?$type_pred$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$323$$):$type_pred$$($value$jscomp$323$$);
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$132$$)?$APP.$cljs$core$every_QMARK_$$($child_pred$$,$value$jscomp$323$$)&&$min$jscomp$58$$<=$APP.$cljs$core$count$$($value$jscomp$323$$)&&$APP.$cljs$core$count$$($value$jscomp$323$$)<=$max$jscomp$57$$:$and__5023__auto__$jscomp$132$$}:$APP.$cljs$core$truth_$$($min$jscomp$58$$)?function($value$jscomp$324$$){var $and__5023__auto__$jscomp$133$$=$type_pred$$.$cljs$core$IFn$_invoke$arity$1$?$type_pred$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$324$$):
$type_pred$$($value$jscomp$324$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$133$$)?$APP.$cljs$core$every_QMARK_$$($child_pred$$,$value$jscomp$324$$)&&$min$jscomp$58$$<=$APP.$cljs$core$count$$($value$jscomp$324$$):$and__5023__auto__$jscomp$133$$}:$APP.$cljs$core$truth_$$($max$jscomp$57$$)?function($value$jscomp$325$$){var $and__5023__auto__$jscomp$134$$=$type_pred$$.$cljs$core$IFn$_invoke$arity$1$?$type_pred$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$325$$):$type_pred$$($value$jscomp$325$$);
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$134$$)?$APP.$cljs$core$every_QMARK_$$($child_pred$$,$value$jscomp$325$$)&&$APP.$cljs$core$count$$($value$jscomp$325$$)<=$max$jscomp$57$$:$and__5023__auto__$jscomp$134$$}:function($value$jscomp$326$$){var $and__5023__auto__$jscomp$135$$=$type_pred$$.$cljs$core$IFn$_invoke$arity$1$?$type_pred$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$326$$):$type_pred$$($value$jscomp$326$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$135$$)?
$APP.$cljs$core$every_QMARK_$$($child_pred$$,$value$jscomp$326$$):$and__5023__auto__$jscomp$135$$},$empty_set$$=$APP.$cljs$core$truth_$$($map__40331__$1_ordered_p__40330$$)?$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$PersistentHashSet$EMPTY$$,$encode_string_child$$=$app$common$schema$encoder$cljs$0core$0IFn$0_invoke$0arity$02$$($kind__$1$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$351$pred$$,$pred$jscomp$45$$,$APP.$cljs$cst$489$empty$$,
$APP.$cljs$core$PersistentHashSet$EMPTY$$,$cljs$cst$415$type_properties$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$936$description$$,$cljs$cst$949$app_DOT_common_DOT_schema_DOT_openapi_SLASH_items$$,$cljs$cst$937$decode_SLASH_string$$,$APP.$cljs$cst$938$decode_SLASH_json$$,$APP.$cljs$cst$939$title$$,$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,$cljs$cst$950$app_DOT_common_DOT_schema_DOT_openapi_SLASH_unique_items$$,$cljs$cst$941$encode_SLASH_json$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,
$cljs$cst$869$gen_SLASH_gen$$,$APP.$cljs$cst$882$error_SLASH_message$$,$cljs$cst$943$encode_SLASH_string$$],["Set of Strings",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,"string"],null),$decode$jscomp$5$$,$decode$jscomp$5$$,"set","set",!0,$APP.$cljs$core$identity$$,"array",$app$common$schema$generators$set$$($app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($kind__$1$$)),"should be a set of strings",function($o$jscomp$171$$){return $APP.$cljs$core$set_QMARK_$$($o$jscomp$171$$)?
$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($encode_string_child$$,$o$jscomp$171$$)):$o$jscomp$171$$}])],null)}])));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$schema$coll_schema$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$cljs$cst$951$app_DOT_common_DOT_schema_SLASH_vec$$,$APP.$cljs$cst$338$min$$,0,$APP.$cljs$cst$339$max$$,1,$APP.$cljs$cst$411$compile$$,function($map__40406__$1_p__40401_pred__$1$jscomp$1$$,$children$jscomp$129$$){function $decode$jscomp$6$$($v$jscomp$235_v__$1$jscomp$15$$){return typeof $v$jscomp$235_v__$1$jscomp$15$$===
"string"?($v$jscomp$235_v__$1$jscomp$15$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$235_v__$1$jscomp$15$$,/[\s,]+/),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$common$schema$xf_COLON_filter_word_strings$$,$v$jscomp$235_v__$1$jscomp$15$$)):$APP.$cljs$core$vector_QMARK_$$($v$jscomp$235_v__$1$jscomp$15$$)?$v$jscomp$235_v__$1$jscomp$15$$:$APP.$cljs$core$coll_QMARK_$$($v$jscomp$235_v__$1$jscomp$15$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,
$v$jscomp$235_v__$1$jscomp$15$$):$v$jscomp$235_v__$1$jscomp$15$$}$map__40406__$1_p__40401_pred__$1$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($map__40406__$1_p__40401_pred__$1$jscomp$1$$);var $kind$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40406__$1_p__40401_pred__$1$jscomp$1$$,$APP.$cljs$cst$947$kind$$),$max$jscomp$58$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40406__$1_p__40401_pred__$1$jscomp$1$$,$APP.$cljs$cst$339$max$$),$min$jscomp$59$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40406__$1_p__40401_pred__$1$jscomp$1$$,
$APP.$cljs$cst$338$min$$),$kind__$1$jscomp$1$$=function(){var $or__5025__auto__$jscomp$197$$=$APP.$cljs$core$last$$($children$jscomp$129$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$197$$)?$or__5025__auto__$jscomp$197$$:$kind$jscomp$18$$}(),$pred$jscomp$46$$=$APP.$cljs$core$fn_QMARK_$$($kind__$1$jscomp$1$$)?$kind__$1$jscomp$1$$:$kind__$1$jscomp$1$$==null?$APP.$cljs$core$any_QMARK_$$:$app$common$schema$validator$$($kind__$1$jscomp$1$$);$map__40406__$1_p__40401_pred__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($max$jscomp$58$$)?
$min$jscomp$59$$:$max$jscomp$58$$)?function($value$jscomp$327$$){var $size$jscomp$74$$=$APP.$cljs$core$count$$($value$jscomp$327$$);return $APP.$cljs$core$set_QMARK_$$($value$jscomp$327$$)&&$min$jscomp$59$$<=$size$jscomp$74$$&&$size$jscomp$74$$<=$max$jscomp$58$$&&$APP.$cljs$core$every_QMARK_$$($pred$jscomp$46$$,$value$jscomp$327$$)}:$APP.$cljs$core$truth_$$($min$jscomp$59$$)?function($value$jscomp$328$$){var $size$jscomp$75$$=$APP.$cljs$core$count$$($value$jscomp$328$$);return $APP.$cljs$core$set_QMARK_$$($value$jscomp$328$$)&&
$min$jscomp$59$$<=$size$jscomp$75$$&&$APP.$cljs$core$every_QMARK_$$($pred$jscomp$46$$,$value$jscomp$328$$)}:$APP.$cljs$core$truth_$$($max$jscomp$58$$)?function($value$jscomp$329$$){var $size$jscomp$76$$=$APP.$cljs$core$count$$($value$jscomp$329$$);return $APP.$cljs$core$set_QMARK_$$($value$jscomp$329$$)&&$size$jscomp$76$$<=$max$jscomp$58$$&&$APP.$cljs$core$every_QMARK_$$($pred$jscomp$46$$,$value$jscomp$329$$)}:function($value$jscomp$330$$){return $APP.$cljs$core$every_QMARK_$$($pred$jscomp$46$$,$value$jscomp$330$$)};
var $encode_string_child$jscomp$1$$=$app$common$schema$encoder$cljs$0core$0IFn$0_invoke$0arity$02$$($kind__$1$jscomp$1$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$351$pred$$,$map__40406__$1_p__40401_pred__$1$jscomp$1$$,$cljs$cst$415$type_properties$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$936$description$$,$cljs$cst$949$app_DOT_common_DOT_schema_DOT_openapi_SLASH_items$$,$cljs$cst$937$decode_SLASH_string$$,$APP.$cljs$cst$938$decode_SLASH_json$$,
$APP.$cljs$cst$939$title$$,$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,$cljs$cst$950$app_DOT_common_DOT_schema_DOT_openapi_SLASH_unique_items$$,$cljs$cst$941$encode_SLASH_json$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,$cljs$cst$869$gen_SLASH_gen$$,$APP.$cljs$cst$882$error_SLASH_message$$,$cljs$cst$943$encode_SLASH_string$$],["Set of Strings",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,"string"],null),$decode$jscomp$6$$,
$decode$jscomp$6$$,"set","set",!0,$APP.$cljs$core$identity$$,"array",$app$common$schema$generators$mcat$$(function(){return $app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($kind__$1$jscomp$1$$)},$app$common$schema$generators$int$0$$),"should be a set of strings",function($o$jscomp$172$$){return $APP.$cljs$core$vector_QMARK_$$($o$jscomp$172$$)?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($encode_string_child$jscomp$1$$,
$o$jscomp$172$$)):$o$jscomp$172$$}])],null)}])));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$952$app_DOT_common_DOT_schema_SLASH_set_of_strings$$,$APP.$cljs$cst$351$pred$$,function($p1__40441_SHARP_$$){return $APP.$cljs$core$set_QMARK_$$($p1__40441_SHARP_$$)&&$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$string_QMARK_$$,$p1__40441_SHARP_$$)},$cljs$cst$415$type_properties$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$936$description$$,$cljs$cst$949$app_DOT_common_DOT_schema_DOT_openapi_SLASH_items$$,
$cljs$cst$937$decode_SLASH_string$$,$APP.$cljs$cst$939$title$$,$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,$cljs$cst$950$app_DOT_common_DOT_schema_DOT_openapi_SLASH_unique_items$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,$cljs$cst$869$gen_SLASH_gen$$,$APP.$cljs$cst$882$error_SLASH_message$$],["Set of Strings",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,"string"],null),function($v$jscomp$236_v__$1$jscomp$16$$){$v$jscomp$236_v__$1$jscomp$16$$=
typeof $v$jscomp$236_v__$1$jscomp$16$$==="string"?$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$236_v__$1$jscomp$16$$,/[\s,]+/):$v$jscomp$236_v__$1$jscomp$16$$;return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$app$common$schema$xf_COLON_filter_word_strings$$,$v$jscomp$236_v__$1$jscomp$16$$)},"set[string]","set",!0,"array",$app$common$schema$generators$set$$($app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$198$string$$)),
"should be a set of strings"])],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$953$app_DOT_common_DOT_schema_SLASH_set_of_keywords$$,$APP.$cljs$cst$351$pred$$,function($p1__40452_SHARP_$$){return $APP.$cljs$core$set_QMARK_$$($p1__40452_SHARP_$$)&&$APP.$cljs$core$every_QMARK_$$($cljs$core$keyword_QMARK_$$,$p1__40452_SHARP_$$)},$cljs$cst$415$type_properties$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$936$description$$,$cljs$cst$949$app_DOT_common_DOT_schema_DOT_openapi_SLASH_items$$,
$cljs$cst$937$decode_SLASH_string$$,$APP.$cljs$cst$939$title$$,$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,$cljs$cst$950$app_DOT_common_DOT_schema_DOT_openapi_SLASH_unique_items$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,$cljs$cst$869$gen_SLASH_gen$$,$APP.$cljs$cst$882$error_SLASH_message$$],["Set of Strings",new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"string",$APP.$cljs$cst$954$format$$,"keyword"],null),function($v$jscomp$237_v__$1$jscomp$17$$){$v$jscomp$237_v__$1$jscomp$17$$=
typeof $v$jscomp$237_v__$1$jscomp$17$$==="string"?$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$237_v__$1$jscomp$17$$,/[\s,]+/):$v$jscomp$237_v__$1$jscomp$17$$;return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($app$common$schema$xf_COLON_filter_word_strings$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$keyword$$)),$v$jscomp$237_v__$1$jscomp$17$$)},
"set[string]","set",!0,"array",$app$common$schema$generators$set$$($app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$221$keyword$$)),"should be a set of strings"])],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$955$app_DOT_common_DOT_schema_SLASH_set_of_uuid$$,$APP.$cljs$cst$351$pred$$,function($p1__40464_SHARP_$$){return $APP.$cljs$core$set_QMARK_$$($p1__40464_SHARP_$$)&&$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$uuid_QMARK_$$,$p1__40464_SHARP_$$)},$cljs$cst$415$type_properties$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$936$description$$,
$cljs$cst$949$app_DOT_common_DOT_schema_DOT_openapi_SLASH_items$$,$cljs$cst$937$decode_SLASH_string$$,$APP.$cljs$cst$939$title$$,$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,$cljs$cst$950$app_DOT_common_DOT_schema_DOT_openapi_SLASH_unique_items$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,$cljs$cst$869$gen_SLASH_gen$$,$APP.$cljs$cst$882$error_SLASH_message$$],["Set of UUID",new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"string",
$APP.$cljs$cst$954$format$$,"uuid"],null),function($v$jscomp$238_v__$1$jscomp$18$$){$v$jscomp$238_v__$1$jscomp$18$$=typeof $v$jscomp$238_v__$1$jscomp$18$$==="string"?$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$238_v__$1$jscomp$18$$,/[\s,]+/):$v$jscomp$238_v__$1$jscomp$18$$;return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$schema$parse_uuid$$),$v$jscomp$238_v__$1$jscomp$18$$)},
"set[uuid]","set",!0,"array",$app$common$schema$generators$set$$($app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$)),"should be a set of UUID instances"])],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$956$app_DOT_common_DOT_schema_SLASH_coll_of_uuid$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$every_QMARK_$$,$APP.$cljs$core$uuid_QMARK_$$),$cljs$cst$415$type_properties$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$936$description$$,$cljs$cst$949$app_DOT_common_DOT_schema_DOT_openapi_SLASH_items$$,
$cljs$cst$937$decode_SLASH_string$$,$APP.$cljs$cst$939$title$$,$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,$cljs$cst$950$app_DOT_common_DOT_schema_DOT_openapi_SLASH_unique_items$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,$cljs$cst$869$gen_SLASH_gen$$,$APP.$cljs$cst$882$error_SLASH_message$$],["Coll of UUID",new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"string",$APP.$cljs$cst$954$format$$,"uuid"],null),function($v$jscomp$239_v__$1$jscomp$19$$){$v$jscomp$239_v__$1$jscomp$19$$=
typeof $v$jscomp$239_v__$1$jscomp$19$$==="string"?$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$239_v__$1$jscomp$19$$,/[\s,]+/):$v$jscomp$239_v__$1$jscomp$19$$;return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$schema$parse_uuid$$),$v$jscomp$239_v__$1$jscomp$19$$)},"[uuid]","array",!1,"array",$app$common$schema$generators$set$$($app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$)),
"should be a coll of UUID instances"])],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,1,$APP.$cljs$cst$411$compile$$,function($props$jscomp$40$$,$children$jscomp$130_decode$jscomp$7_format$jscomp$21$$){var $options$jscomp$406$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$last$$($children$jscomp$130_decode$jscomp$7_format$jscomp$21$$));
$children$jscomp$130_decode$jscomp$7_format$jscomp$21$$=$APP.$cljs$cst$954$format$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$40$$,"keyword");$children$jscomp$130_decode$jscomp$7_format$jscomp$21$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$130_decode$jscomp$7_format$jscomp$21$$,"keyword")?$APP.$cljs$core$keyword$$:$APP.$cljs$core$identity$$;return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$351$pred$$,function($p1__40476_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($options$jscomp$406$$,
$p1__40476_SHARP_$$)},$cljs$cst$415$type_properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$939$title$$,"enum",$cljs$cst$869$gen_SLASH_gen$$,$clojure$test$check$generators$elements$$($options$jscomp$406$$),$cljs$cst$937$decode_SLASH_string$$,$children$jscomp$130_decode$jscomp$7_format$jscomp$21$$,$APP.$cljs$cst$938$decode_SLASH_json$$,$children$jscomp$130_decode$jscomp$7_format$jscomp$21$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,"string",$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,
$APP.$cljs$cst$954$format$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$40$$,"keyword")],null)],null)}],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$,$APP.$cljs$cst$338$min$$,0,$APP.$cljs$cst$339$max$$,0,$APP.$cljs$cst$411$compile$$,function($p__40480_pred__$2$$){var $map__40481__$1$$=$APP.$cljs$core$__destructure_map$$($p__40480_pred__$2$$),$max$jscomp$59$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40481__$1$$,$APP.$cljs$cst$339$max$$),
$min$jscomp$60$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40481__$1$$,$APP.$cljs$cst$338$min$$),$pred__$1$jscomp$2$$=$min$jscomp$60$$!=null?function($v$jscomp$241$$){var $and__5023__auto__$jscomp$137$$=$APP.$cljs$core$int_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$int_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$241$$):$APP.$cljs$core$int_QMARK_$$($v$jscomp$241$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$137$$)?$v$jscomp$241$$>=$min$jscomp$60$$:
$and__5023__auto__$jscomp$137$$}:$APP.$cljs$core$int_QMARK_$$;$p__40480_pred__$2$$=$max$jscomp$59$$!=null?function($v$jscomp$242$$){var $and__5023__auto__$jscomp$138$$=$pred__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$pred__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$242$$):$pred__$1$jscomp$2$$($v$jscomp$242$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$138$$)?$max$jscomp$59$$>=$v$jscomp$242$$:$and__5023__auto__$jscomp$138$$}:$pred__$1$jscomp$2$$;var $gen$jscomp$35$$=
function(){var $or__5025__auto__$jscomp$199$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40481__$1$$,$cljs$cst$869$gen_SLASH_gen$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$199$$)?$or__5025__auto__$jscomp$199$$:$app$common$schema$generators$small_int$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$339$max$$,$max$jscomp$59$$,$APP.$cljs$cst$338$min$$,$min$jscomp$60$$]))}();return new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$351$pred$$,$p__40480_pred__$2$$,$cljs$cst$415$type_properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$939$title$$,"integer",$APP.$cljs$cst$936$description$$,"integer",$APP.$cljs$cst$882$error_SLASH_message$$,"expected to be int/long",$APP.$cljs$cst$945$error_SLASH_code$$,"errors.invalid-integer",$cljs$cst$869$gen_SLASH_gen$$,$gen$jscomp$35$$,$cljs$cst$937$decode_SLASH_string$$,$app$common$schema$parse_long$$,$APP.$cljs$cst$938$decode_SLASH_json$$,$app$common$schema$parse_long$$,
$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,"integer"],null)],null)}],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$959$app_DOT_common_DOT_schema_SLASH_double$$,$APP.$cljs$cst$411$compile$$,function($map__40490__$1_p__40488$$){$map__40490__$1_p__40488$$=$APP.$cljs$core$__destructure_map$$($map__40490__$1_p__40488$$);var $max$jscomp$60$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40490__$1_p__40488$$,$APP.$cljs$cst$339$max$$),$min$jscomp$61$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40490__$1_p__40488$$,$APP.$cljs$cst$338$min$$),$pred__$1$jscomp$3$$=$min$jscomp$61$$!=null?function($v$jscomp$244$$){var $and__5023__auto__$jscomp$139$$=$cljs$core$double_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$core$double_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$244$$):$cljs$core$double_QMARK_$$($v$jscomp$244$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$139$$)?$v$jscomp$244$$>=$min$jscomp$61$$:$and__5023__auto__$jscomp$139$$}:
$cljs$core$double_QMARK_$$;return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$351$pred$$,$max$jscomp$60$$!=null?function($v$jscomp$245$$){var $and__5023__auto__$jscomp$140$$=$pred__$1$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$pred__$1$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$245$$):$pred__$1$jscomp$3$$($v$jscomp$245$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$140$$)?$max$jscomp$60$$>=$v$jscomp$245$$:$and__5023__auto__$jscomp$140$$}:$pred__$1$jscomp$3$$,
$cljs$cst$415$type_properties$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$936$description$$,$cljs$cst$937$decode_SLASH_string$$,$APP.$cljs$cst$938$decode_SLASH_json$$,$APP.$cljs$cst$939$title$$,$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,$cljs$cst$869$gen_SLASH_gen$$,$APP.$cljs$cst$882$error_SLASH_message$$,$APP.$cljs$cst$945$error_SLASH_code$$],["double number",$app$common$schema$parse_double$$,
$app$common$schema$parse_double$$,"doble","double","number",$app$common$schema$generators$small_double$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$339$max$$,$max$jscomp$60$$,$APP.$cljs$cst$338$min$$,$min$jscomp$61$$])),"expected to be double","errors.invalid-double"])],null)}],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$960$app_DOT_common_DOT_schema_SLASH_number$$,$APP.$cljs$cst$411$compile$$,function($p__40492_pred__$2$jscomp$2$$){var $map__40493__$1$$=$APP.$cljs$core$__destructure_map$$($p__40492_pred__$2$jscomp$2$$),$max$jscomp$61$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40493__$1$$,$APP.$cljs$cst$339$max$$),$min$jscomp$62$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40493__$1$$,
$APP.$cljs$cst$338$min$$),$pred__$1$jscomp$4$$=$min$jscomp$62$$!=null?function($v$jscomp$246$$){var $and__5023__auto__$jscomp$141$$=$APP.$cljs$core$number_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$number_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$246$$):$APP.$cljs$core$number_QMARK_$$($v$jscomp$246$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$141$$)?$v$jscomp$246$$>=$min$jscomp$62$$:$and__5023__auto__$jscomp$141$$}:$APP.$cljs$core$number_QMARK_$$;$p__40492_pred__$2$jscomp$2$$=
$max$jscomp$61$$!=null?function($v$jscomp$247$$){var $and__5023__auto__$jscomp$142$$=$pred__$1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$pred__$1$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$247$$):$pred__$1$jscomp$4$$($v$jscomp$247$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$142$$)?$max$jscomp$61$$>=$v$jscomp$247$$:$and__5023__auto__$jscomp$142$$}:$pred__$1$jscomp$4$$;var $gen$jscomp$36$$=function(){var $or__5025__auto__$jscomp$201$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40493__$1$$,
$cljs$cst$869$gen_SLASH_gen$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$201$$)?$or__5025__auto__$jscomp$201$$:$app$common$schema$generators$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$schema$generators$small_int$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$339$max$$,$max$jscomp$61$$,$APP.$cljs$cst$338$min$$,$min$jscomp$62$$])),
$app$common$schema$generators$fmap$$(function($p1__40491_SHARP_$$){return $APP.$app$common$math$precision$$($p1__40491_SHARP_$$,2)},$app$common$schema$generators$small_double$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$339$max$$,$max$jscomp$61$$,$APP.$cljs$cst$338$min$$,$min$jscomp$62$$])))]))}();return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$351$pred$$,$p__40492_pred__$2$jscomp$2$$,$cljs$cst$415$type_properties$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$939$title$$,"number",$APP.$cljs$cst$936$description$$,"number",$APP.$cljs$cst$882$error_SLASH_message$$,"expected to be number",$APP.$cljs$cst$945$error_SLASH_code$$,"errors.invalid-number",$cljs$cst$869$gen_SLASH_gen$$,$gen$jscomp$36$$,$cljs$cst$937$decode_SLASH_string$$,$app$common$schema$parse_double$$,$APP.$cljs$cst$938$decode_SLASH_json$$,$app$common$schema$parse_double$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,
"number"],null)],null)}],null));$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$961$app_DOT_common_DOT_schema_SLASH_safe_int$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$339$max$$,2147483647,$APP.$cljs$cst$338$min$$,-2147483648],null)],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$962$app_DOT_common_DOT_schema_SLASH_safe_double$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$959$app_DOT_common_DOT_schema_SLASH_double$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$339$max$$,2147483647,$APP.$cljs$cst$338$min$$,-2147483648],null)],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$960$app_DOT_common_DOT_schema_SLASH_number$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$small_double$$(),$APP.$cljs$cst$339$max$$,2147483647,$APP.$cljs$cst$338$min$$,-2147483648],null)],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$boolean_QMARK_$$,$cljs$cst$415$type_properties$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$936$description$$,$cljs$cst$937$decode_SLASH_string$$,$APP.$cljs$cst$938$decode_SLASH_json$$,$APP.$cljs$cst$939$title$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,
$cljs$cst$869$gen_SLASH_gen$$,$APP.$cljs$cst$882$error_SLASH_message$$,$cljs$cst$943$encode_SLASH_string$$,$APP.$cljs$cst$945$error_SLASH_code$$],["boolean",$app$common$schema$parse_boolean$$,$app$common$schema$parse_boolean$$,"boolean","boolean",$clojure$test$check$generators$boolean$0$$,"expected boolean",$APP.$cljs$core$str$$,"errors.invalid-boolean"])],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$965$app_DOT_common_DOT_schema_SLASH_keyword$$,$APP.$cljs$cst$351$pred$$,$cljs$core$keyword_QMARK_$$,$cljs$cst$415$type_properties$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$936$description$$,$cljs$cst$937$decode_SLASH_string$$,$APP.$cljs$cst$938$decode_SLASH_json$$,$APP.$cljs$cst$939$title$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,
$cljs$cst$869$gen_SLASH_gen$$,$APP.$cljs$cst$882$error_SLASH_message$$,$cljs$cst$943$encode_SLASH_string$$,$APP.$cljs$cst$945$error_SLASH_code$$],["keyword",$app$common$schema$parse_keyword$$,$app$common$schema$parse_keyword$$,"keyword","string",$app$common$schema$generators$keyword$$,"expected keyword",function($v$jscomp$250$$){return $v$jscomp$250$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$app$common$json$write_camel_key$$($APP.$cljs$core$name$$($v$jscomp$250$$)):$v$jscomp$250$$},"errors.invalid-keyword"])],
null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$966$app_DOT_common_DOT_schema_SLASH_contains_any$$,$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,1,$APP.$cljs$cst$411$compile$$,function($pred$jscomp$50_props$jscomp$44$$,$children$jscomp$131$$){var $choices$$=$APP.$cljs$core$last$$($children$jscomp$131$$);$pred$jscomp$50_props$jscomp$44$$=$APP.$cljs$core$truth_$$($cljs$cst$967$strict$$.$cljs$core$IFn$_invoke$arity$1$($pred$jscomp$50_props$jscomp$44$$))?function($p1__40501_SHARP_$$){return $APP.$cljs$core$some$$(function($prop$jscomp$5$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__40501_SHARP_$$,
$prop$jscomp$5$$)!=null},$choices$$)}:function($p1__40502_SHARP_$$){return $APP.$cljs$core$some$$(function($prop$jscomp$6$$){return $APP.$cljs$core$contains_QMARK_$$($p1__40502_SHARP_$$,$prop$jscomp$6$$)},$choices$$)};return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$351$pred$$,$pred$jscomp$50_props$jscomp$44$$],null)}],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$968$app_DOT_common_DOT_schema_SLASH_fn$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$fn_QMARK_$$],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$969$app_DOT_common_DOT_schema_SLASH_word_string$$,$APP.$cljs$cst$351$pred$$,function($p1__40505_SHARP_$$){return typeof $p1__40505_SHARP_$$==="string"&&!$APP.$cuerdas$core$blank_QMARK_$$($p1__40505_SHARP_$$)},$cljs$cst$413$property_pred$$,$malli$core$_min_max_pred$$($APP.$cljs$core$count$$),$cljs$cst$415$type_properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$939$title$$,"string",$APP.$cljs$cst$936$description$$,"string",$APP.$cljs$cst$882$error_SLASH_message$$,"expected a non empty string",$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$word_string$$(),$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,"string",$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,"string"],null)],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$970$app_DOT_common_DOT_schema_SLASH_uri$$,$APP.$cljs$cst$351$pred$$,function($param32905$$){return $param32905$$ instanceof $lambdaisland$uri$URI$$},$cljs$cst$413$property_pred$$,function($map__40507__$1_p__40506$$){$map__40507__$1_p__40506$$=$APP.$cljs$core$__destructure_map$$($map__40507__$1_p__40506$$);var $min$jscomp$63$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40507__$1_p__40506$$,
$APP.$cljs$cst$338$min$$),$max$jscomp$62$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40507__$1_p__40506$$,$APP.$cljs$cst$339$max$$),$prefix$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40507__$1_p__40506$$,$APP.$cljs$cst$971$prefix$$);return $APP.$cljs$core$seq$$($map__40507__$1_p__40506$$)?function($value$jscomp$331_value__$1$jscomp$2$$){$value$jscomp$331_value__$1$jscomp$2$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$331_value__$1$jscomp$2$$);
var $and__5023__auto__$jscomp$143_size$jscomp$77$$=$value$jscomp$331_value__$1$jscomp$2$$.length;$and__5023__auto__$jscomp$143_size$jscomp$77$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($min$jscomp$63$$)?$max$jscomp$62$$:$min$jscomp$63$$)?$min$jscomp$63$$<=$and__5023__auto__$jscomp$143_size$jscomp$77$$&&$and__5023__auto__$jscomp$143_size$jscomp$77$$<=$max$jscomp$62$$:$APP.$cljs$core$truth_$$($min$jscomp$63$$)?$min$jscomp$63$$<=$and__5023__auto__$jscomp$143_size$jscomp$77$$:$APP.$cljs$core$truth_$$($max$jscomp$62$$)?
$and__5023__auto__$jscomp$143_size$jscomp$77$$<=$max$jscomp$62$$:null;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$143_size$jscomp$77$$)?$APP.$cljs$core$regexp_QMARK_$$($prefix$jscomp$14$$)?$APP.$cljs$core$re_seq$$($prefix$jscomp$14$$,$value$jscomp$331_value__$1$jscomp$2$$)!=null:!0:$and__5023__auto__$jscomp$143_size$jscomp$77$$}:$APP.$cljs$core$constantly$$(!0)},$cljs$cst$415$type_properties$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$936$description$$,$cljs$cst$937$decode_SLASH_string$$,
$APP.$cljs$cst$938$decode_SLASH_json$$,$APP.$cljs$cst$939$title$$,$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,$cljs$cst$941$encode_SLASH_json$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,$cljs$cst$869$gen_SLASH_gen$$,$cljs$cst$943$encode_SLASH_string$$,$APP.$cljs$cst$945$error_SLASH_code$$],["URI formatted string",$app$common$schema$decode_uri$$,$app$common$schema$decode_uri$$,"uri","uri",$APP.$cljs$core$str$$,"string",$clojure$test$check$generators$bind$$($clojure$test$check$generators$elements$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["http","https"],null)),function($scheme$jscomp$11$$){return $clojure$test$check$generators$bind$$(function(){var $$$jscomp$2_$__$1$$=$app$common$schema$generators$word_string$$();$$$jscomp$2_$__$1$$=$clojure$test$check$generators$such_that$$.$cljs$core$IFn$_invoke$arity$3$(function($x$jscomp$826$$){return $APP.$cljs$core$count$$($x$jscomp$826$$)>5},$$$jscomp$2_$__$1$$,100);return $clojure$test$check$generators$fmap$$($APP.$cuerdas$core$lower$$,$$$jscomp$2_$__$1$$)}(),
function($domain$jscomp$3$$){return $clojure$test$check$generators$bind$$($clojure$test$check$generators$elements$$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["net","com","org","app","io"],null)),function($ext_val__32629__auto__$$){$ext_val__32629__auto__$$=$APP.$app$common$uri$uri$$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($scheme$jscomp$11$$),"://",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($domain$jscomp$3$$),".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ext_val__32629__auto__$$)].join(""));
return $ext_val__32629__auto__$$ instanceof $clojure$test$check$generators$Generator$$?$ext_val__32629__auto__$$:$clojure$test$check$generators$return$0$$($ext_val__32629__auto__$$)})})}),$APP.$cljs$core$str$$,"errors.invalid-uri"])],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,$APP.$cljs$cst$351$pred$$,function($p1__40510_SHARP_$$){return typeof $p1__40510_SHARP_$$==="string"&&!$APP.$cuerdas$core$blank_QMARK_$$($p1__40510_SHARP_$$)},$cljs$cst$413$property_pred$$,function($map__40513__$1_p__40512$$){$map__40513__$1_p__40512$$=$APP.$cljs$core$__destructure_map$$($map__40513__$1_p__40512$$);
var $min$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40513__$1_p__40512$$,$APP.$cljs$cst$338$min$$),$max$jscomp$63$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40513__$1_p__40512$$,$APP.$cljs$cst$339$max$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($min$jscomp$64$$)?$min$jscomp$64$$:$max$jscomp$63$$)?function($size$jscomp$78_value$jscomp$332$$){$size$jscomp$78_value$jscomp$332$$=$APP.$cljs$core$count$$($size$jscomp$78_value$jscomp$332$$);
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($min$jscomp$64$$)?$max$jscomp$63$$:$min$jscomp$64$$)?$min$jscomp$64$$<=$size$jscomp$78_value$jscomp$332$$&&$size$jscomp$78_value$jscomp$332$$<=$max$jscomp$63$$:$APP.$cljs$core$truth_$$($min$jscomp$64$$)?$min$jscomp$64$$<=$size$jscomp$78_value$jscomp$332$$:$APP.$cljs$core$truth_$$($max$jscomp$63$$)?$size$jscomp$78_value$jscomp$332$$<=$max$jscomp$63$$:null}:$APP.$cljs$core$constantly$$(!0)},$cljs$cst$415$type_properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$939$title$$,"string",$APP.$cljs$cst$936$description$$,"not whitespace string",$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,"string",$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$word_string$$(),$APP.$cljs$cst$884$error_SLASH_fn$$,function($p__40517_value$jscomp$333$$){var $map__40518__$1_map__40519_max$jscomp$64_schema$jscomp$205$$=$APP.$cljs$core$__destructure_map$$($p__40517_value$jscomp$333$$);$p__40517_value$jscomp$333$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40518__$1_map__40519_max$jscomp$64_schema$jscomp$205$$,
$APP.$cljs$cst$260$value$$);$map__40518__$1_map__40519_max$jscomp$64_schema$jscomp$205$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40518__$1_map__40519_max$jscomp$64_schema$jscomp$205$$,$APP.$cljs$cst$298$schema$$);$map__40518__$1_map__40519_max$jscomp$64_schema$jscomp$205$$=$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($map__40518__$1_map__40519_max$jscomp$64_schema$jscomp$205$$);var $map__40519__$1_min$jscomp$65$$=$APP.$cljs$core$__destructure_map$$($map__40518__$1_map__40519_max$jscomp$64_schema$jscomp$205$$);
$map__40518__$1_map__40519_max$jscomp$64_schema$jscomp$205$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40519__$1_min$jscomp$65$$,$APP.$cljs$cst$339$max$$);$map__40519__$1_min$jscomp$65$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__40519__$1_min$jscomp$65$$,$APP.$cljs$cst$338$min$$);return typeof $p__40517_value$jscomp$333$$==="string"&&typeof $map__40518__$1_map__40519_max$jscomp$64_schema$jscomp$205$$==="number"&&$APP.$cljs$core$count$$($p__40517_value$jscomp$333$$)>
$map__40518__$1_map__40519_max$jscomp$64_schema$jscomp$205$$?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$273$code$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["errors.field-max-length",$map__40518__$1_map__40519_max$jscomp$64_schema$jscomp$205$$],null)],null):typeof $p__40517_value$jscomp$333$$==="string"&&typeof $map__40519__$1_min$jscomp$65$$==="number"&&$APP.$cljs$core$count$$($p__40517_value$jscomp$333$$)<$map__40519__$1_min$jscomp$65$$?
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$273$code$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["errors.field-min-length",$map__40519__$1_min$jscomp$65$$],null)],null):typeof $p__40517_value$jscomp$333$$==="string"&&$APP.$cuerdas$core$empty_QMARK_$$($p__40517_value$jscomp$333$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$273$code$$,"errors.field-missing"],null):typeof $p__40517_value$jscomp$333$$==="string"&&
$APP.$cuerdas$core$blank_QMARK_$$($p__40517_value$jscomp$333$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$273$code$$,"errors.field-not-all-whitespace"],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$273$code$$,"errors.invalid-text"],null)}],null)],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$973$app_DOT_common_DOT_schema_SLASH_password$$,$APP.$cljs$cst$351$pred$$,function($value$jscomp$334$$){return typeof $value$jscomp$334$$==="string"&&$APP.$cljs$core$count$$($value$jscomp$334$$)>=8&&!$APP.$cuerdas$core$blank_QMARK_$$($value$jscomp$334$$)},$cljs$cst$415$type_properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$939$title$$,
"password",$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$filter$$(function($p1__40522_SHARP_$$){return $APP.$cljs$core$count$$($p1__40522_SHARP_$$)>=8},$app$common$schema$generators$word_string$$()),$APP.$cljs$cst$945$error_SLASH_code$$,"errors.password-too-short",$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,"string",$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,"password"],null)],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$974$app_DOT_common_DOT_schema_SLASH_any$$,$malli$util$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$418$any$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$any$$])));$APP.$app$common$schema$valid_safe_number_QMARK_$$=$app$common$schema$lazy_validator$$($cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$);
$APP.$app$common$schema$valid_safe_int_QMARK_$$=$app$common$schema$lazy_validator$$($cljs$cst$961$app_DOT_common_DOT_schema_SLASH_safe_int$$);$app$common$schema$validator$$($APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$);$app$common$schema$check_fn$$($cljs$cst$961$app_DOT_common_DOT_schema_SLASH_safe_int$$);$app$common$schema$check_fn$$($cljs$cst$952$app_DOT_common_DOT_schema_SLASH_set_of_strings$$);$app$common$schema$check_fn$$($APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$);
$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,"expected valid uuid instance"]));$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$198$string$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,"expected string"]));$app$common$schema$check_fn$$($cljs$cst$956$app_DOT_common_DOT_schema_SLASH_coll_of_uuid$$);
$app$common$schema$check_fn$$($cljs$cst$955$app_DOT_common_DOT_schema_SLASH_set_of_uuid$$);$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$],null));var $cljs$spec$alpha$registry_ref$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cljs$spec$alpha$Specize$specize_STAR_$dyn_34997$$=function(){function $G__34998__2$$($_$jscomp$798$$,$form$jscomp$105$$){var $m__5372__auto__$jscomp$190_m__5374__auto__$jscomp$190$$=$cljs$spec$alpha$specize_STAR_$$[$APP.$goog$typeOf$$($_$jscomp$798$$==null?null:$_$jscomp$798$$)];if($m__5372__auto__$jscomp$190_m__5374__auto__$jscomp$190$$!=null)return $m__5372__auto__$jscomp$190_m__5374__auto__$jscomp$190$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$190_m__5374__auto__$jscomp$190$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$798$$,$form$jscomp$105$$):$m__5372__auto__$jscomp$190_m__5374__auto__$jscomp$190$$($_$jscomp$798$$,$form$jscomp$105$$);$m__5372__auto__$jscomp$190_m__5374__auto__$jscomp$190$$=$cljs$spec$alpha$specize_STAR_$$._;if($m__5372__auto__$jscomp$190_m__5374__auto__$jscomp$190$$!=null)return $m__5372__auto__$jscomp$190_m__5374__auto__$jscomp$190$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$190_m__5374__auto__$jscomp$190$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$798$$,
$form$jscomp$105$$):$m__5372__auto__$jscomp$190_m__5374__auto__$jscomp$190$$($_$jscomp$798$$,$form$jscomp$105$$);throw $APP.$cljs$core$missing_protocol$$("Specize.specize*",$_$jscomp$798$$);}function $G__34998__1$$($_$jscomp$797$$){var $m__5372__auto__$jscomp$189_m__5374__auto__$jscomp$189$$=$cljs$spec$alpha$specize_STAR_$$[$APP.$goog$typeOf$$($_$jscomp$797$$==null?null:$_$jscomp$797$$)];if($m__5372__auto__$jscomp$189_m__5374__auto__$jscomp$189$$!=null)return $m__5372__auto__$jscomp$189_m__5374__auto__$jscomp$189$$.$cljs$core$IFn$_invoke$arity$1$?
$m__5372__auto__$jscomp$189_m__5374__auto__$jscomp$189$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$797$$):$m__5372__auto__$jscomp$189_m__5374__auto__$jscomp$189$$($_$jscomp$797$$);$m__5372__auto__$jscomp$189_m__5374__auto__$jscomp$189$$=$cljs$spec$alpha$specize_STAR_$$._;if($m__5372__auto__$jscomp$189_m__5374__auto__$jscomp$189$$!=null)return $m__5372__auto__$jscomp$189_m__5374__auto__$jscomp$189$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$189_m__5374__auto__$jscomp$189$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$797$$):
$m__5372__auto__$jscomp$189_m__5374__auto__$jscomp$189$$($_$jscomp$797$$);throw $APP.$cljs$core$missing_protocol$$("Specize.specize*",$_$jscomp$797$$);}var $G__34998$$=null;$G__34998$$=function($_$jscomp$799$$,$form$jscomp$106$$){switch(arguments.length){case 1:return $G__34998__1$$.call(this,$_$jscomp$799$$);case 2:return $G__34998__2$$.call(this,$_$jscomp$799$$,$form$jscomp$106$$)}throw Error("Invalid arity: "+arguments.length);};$G__34998$$.$cljs$core$IFn$_invoke$arity$1$=$G__34998__1$$;$G__34998$$.$cljs$core$IFn$_invoke$arity$2$=
$G__34998__2$$;return $G__34998$$}(),$cljs$spec$alpha$specize_STAR_$$=function $cljs$spec$alpha$specize_STAR_$$($var_args$jscomp$636$$){switch(arguments.length){case 1:return $cljs$spec$alpha$specize_STAR_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$spec$alpha$specize_STAR_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$cljs$spec$alpha$specize_STAR_$$.$cljs$core$IFn$_invoke$arity$1$=function($_$jscomp$800$$){return $_$jscomp$800$$!=null&&$_$jscomp$800$$.$cljs$spec$alpha$Specize$specize_STAR_$arity$1$!=null?$_$jscomp$800$$.$cljs$spec$alpha$Specize$specize_STAR_$arity$1$($_$jscomp$800$$):$cljs$spec$alpha$Specize$specize_STAR_$dyn_34997$$($_$jscomp$800$$)};
$cljs$spec$alpha$specize_STAR_$$.$cljs$core$IFn$_invoke$arity$2$=function($_$jscomp$801$$,$form$jscomp$107$$){return $_$jscomp$801$$!=null&&$_$jscomp$801$$.$cljs$spec$alpha$Specize$specize_STAR_$arity$2$!=null?$_$jscomp$801$$.$cljs$spec$alpha$Specize$specize_STAR_$arity$2$($_$jscomp$801$$,$form$jscomp$107$$):$cljs$spec$alpha$Specize$specize_STAR_$dyn_34997$$($_$jscomp$801$$,$form$jscomp$107$$)};$cljs$spec$alpha$specize_STAR_$$.$cljs$lang$maxFixedArity$=2;
$APP.$cljs$core$Keyword$$.prototype.$cljs$spec$alpha$Specize$specize_STAR_$arity$1$=function(){return $cljs$spec$alpha$specize_STAR_$$($cljs$spec$alpha$reg_resolve_BANG_$$(this))};$APP.$cljs$core$Keyword$$.prototype.$cljs$spec$alpha$Specize$specize_STAR_$arity$2$=function(){return $cljs$spec$alpha$specize_STAR_$$($cljs$spec$alpha$reg_resolve_BANG_$$(this))};$APP.$cljs$core$Symbol$$.prototype.$cljs$spec$alpha$Specize$specize_STAR_$arity$1$=function(){return $cljs$spec$alpha$specize_STAR_$$($cljs$spec$alpha$reg_resolve_BANG_$$(this))};
$APP.$cljs$core$Symbol$$.prototype.$cljs$spec$alpha$Specize$specize_STAR_$arity$2$=function(){return $cljs$spec$alpha$specize_STAR_$$($cljs$spec$alpha$reg_resolve_BANG_$$(this))};$APP.$cljs$core$PersistentHashSet$$.prototype.$cljs$spec$alpha$Specize$specize_STAR_$arity$1$=function(){return $cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$04$$(this,this)};
$APP.$cljs$core$PersistentHashSet$$.prototype.$cljs$spec$alpha$Specize$specize_STAR_$arity$2$=function($s$jscomp$418$$,$form$jscomp$108$$){return $cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$108$$,this)};$cljs$core$PersistentTreeSet$$.prototype.$cljs$spec$alpha$Specize$specize_STAR_$arity$1$=function(){return $cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$04$$(this,this)};
$cljs$core$PersistentTreeSet$$.prototype.$cljs$spec$alpha$Specize$specize_STAR_$arity$2$=function($s$jscomp$420$$,$form$jscomp$109$$){return $cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$109$$,this)};
$cljs$spec$alpha$specize_STAR_$$._=function(){function $G__35006__1$$($o$jscomp$173$$){var $and__5023__auto__$jscomp$inline_3871_temp__5823__auto__$jscomp$77$$=($and__5023__auto__$jscomp$inline_3871_temp__5823__auto__$jscomp$77$$=$APP.$cljs$core$fn_QMARK_$$($o$jscomp$173$$))?$cljs$spec$alpha$fn_sym$$($o$jscomp$173$$.name):$and__5023__auto__$jscomp$inline_3871_temp__5823__auto__$jscomp$77$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_3871_temp__5823__auto__$jscomp$77$$)?$cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$04$$($and__5023__auto__$jscomp$inline_3871_temp__5823__auto__$jscomp$77$$,
$o$jscomp$173$$):$cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$04$$($cljs$cst$977$cljs_DOT_spec_DOT_alpha_SLASH_unknown$$,$o$jscomp$173$$)}var $G__35006$$=null;$G__35006$$=function($o$jscomp$175$$,$form$jscomp$111$$){switch(arguments.length){case 1:return $G__35006__1$$.call(this,$o$jscomp$175$$);case 2:return $cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$111$$,$o$jscomp$175$$)}throw Error("Invalid arity: "+arguments.length);};$G__35006$$.$cljs$core$IFn$_invoke$arity$1$=
$G__35006__1$$;$G__35006$$.$cljs$core$IFn$_invoke$arity$2$=function($o$jscomp$174$$,$form$jscomp$110$$){return $cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$110$$,$o$jscomp$174$$)};return $G__35006$$}();
$APP.$cljs$spec$alpha$specize$$=function $cljs$spec$alpha$specize$$($var_args$jscomp$637$$){switch(arguments.length){case 1:return $cljs$spec$alpha$specize$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$spec$alpha$specize$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$cljs$spec$alpha$specize$$.$cljs$core$IFn$_invoke$arity$1$=function($s$jscomp$421$$){var $or__5025__auto__$jscomp$206$$=$cljs$spec$alpha$spec_QMARK_$$($s$jscomp$421$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$206$$)?$or__5025__auto__$jscomp$206$$:$cljs$spec$alpha$specize_STAR_$$($s$jscomp$421$$)};
$APP.$cljs$spec$alpha$specize$$.$cljs$core$IFn$_invoke$arity$2$=function($s$jscomp$422$$,$form$jscomp$112$$){var $or__5025__auto__$jscomp$207$$=$cljs$spec$alpha$spec_QMARK_$$($s$jscomp$422$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$207$$)?$or__5025__auto__$jscomp$207$$:$cljs$spec$alpha$specize_STAR_$$($s$jscomp$422$$,$form$jscomp$112$$)};$APP.$cljs$spec$alpha$specize$$.$cljs$lang$maxFixedArity$=2;$APP.$JSCompiler_prototypeAlias$$=$cljs$spec$alpha$t_cljs$0spec$0alpha34071$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_34073$$,$meta34072__$1$$){return new $cljs$spec$alpha$t_cljs$0spec$0alpha34071$$(this.$keys__GT_specnames$,this.$opt$,this.$req_un$,this.$opt_un$,this.$map__34069$,this.$gfn$,this.$pred_exprs$,this.$keys_pred$,this.$argm$,this.$opt_keys$,this.$req_specs$,this.$p__34067$,this.$req$,this.id,this.$req_keys$,this.$opt_specs$,this.$k__GT_s$,this.$pred_forms$,$meta34072__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta34072$};$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Specize$specize_STAR_$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Specize$specize_STAR_$arity$2$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$conform_STAR_$arity$2$=function($_$jscomp$805_reg$jscomp$2$$,$G__35186_m$jscomp$155_ret__$2$$){if($APP.$cljs$core$truth_$$(this.$keys_pred$.$cljs$core$IFn$_invoke$arity$1$?this.$keys_pred$.$cljs$core$IFn$_invoke$arity$1$($G__35186_m$jscomp$155_ret__$2$$):this.$keys_pred$($G__35186_m$jscomp$155_ret__$2$$))){$_$jscomp$805_reg$jscomp$2$$=$APP.$cljs$core$_deref$$($cljs$spec$alpha$registry_ref$$);var $first__34094_k__$1$jscomp$15_ret__$1$jscomp$7_seq__34087$$=
$APP.$cljs$core$seq$$($G__35186_m$jscomp$155_ret__$2$$),$G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$=$APP.$cljs$core$first$$($first__34094_k__$1$jscomp$15_ret__$1$jscomp$7_seq__34087$$);$APP.$cljs$core$next$$($first__34094_k__$1$jscomp$15_ret__$1$jscomp$7_seq__34087$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$,
1,null);for($G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$=$first__34094_k__$1$jscomp$15_ret__$1$jscomp$7_seq__34087$$=$G__35186_m$jscomp$155_ret__$2$$;;){$G__35186_m$jscomp$155_ret__$2$$=$first__34094_k__$1$jscomp$15_ret__$1$jscomp$7_seq__34087$$;var $cv_sname_temp__5823__auto__$jscomp$83_vec__34092$$=$G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$;$G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$=
$APP.$cljs$core$seq$$($cv_sname_temp__5823__auto__$jscomp$83_vec__34092$$);$first__34094_k__$1$jscomp$15_ret__$1$jscomp$7_seq__34087$$=$APP.$cljs$core$first$$($G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$);var $ks__$1$jscomp$6_seq__34093__$1$$=$APP.$cljs$core$next$$($G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$);$G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$=$first__34094_k__$1$jscomp$15_ret__$1$jscomp$7_seq__34087$$;
$first__34094_k__$1$jscomp$15_ret__$1$jscomp$7_seq__34087$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$,0,null);$G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$,1,null);if($APP.$cljs$core$truth_$$($cv_sname_temp__5823__auto__$jscomp$83_vec__34092$$))if($cv_sname_temp__5823__auto__$jscomp$83_vec__34092$$=
this.$keys__GT_specnames$.$cljs$core$IFn$_invoke$arity$1$?this.$keys__GT_specnames$.$cljs$core$IFn$_invoke$arity$1$($first__34094_k__$1$jscomp$15_ret__$1$jscomp$7_seq__34087$$):this.$keys__GT_specnames$($first__34094_k__$1$jscomp$15_ret__$1$jscomp$7_seq__34087$$),$cv_sname_temp__5823__auto__$jscomp$83_vec__34092$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$805_reg$jscomp$2$$,$cv_sname_temp__5823__auto__$jscomp$83_vec__34092$$),$APP.$cljs$core$truth_$$($cv_sname_temp__5823__auto__$jscomp$83_vec__34092$$)){var $x$jscomp$inline_3882$$=
$G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$;$cv_sname_temp__5823__auto__$jscomp$83_vec__34092$$=$cljs$spec$alpha$conform_STAR_$$($APP.$cljs$spec$alpha$specize$$.$cljs$core$IFn$_invoke$arity$1$($cv_sname_temp__5823__auto__$jscomp$83_vec__34092$$),$x$jscomp$inline_3882$$);if($cljs$spec$alpha$invalid_QMARK_$$($cv_sname_temp__5823__auto__$jscomp$83_vec__34092$$))return $cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$;$G__35186_m$jscomp$155_ret__$2$$=$cv_sname_temp__5823__auto__$jscomp$83_vec__34092$$===
$G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$?$G__35186_m$jscomp$155_ret__$2$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__35186_m$jscomp$155_ret__$2$$,$first__34094_k__$1$jscomp$15_ret__$1$jscomp$7_seq__34087$$,$cv_sname_temp__5823__auto__$jscomp$83_vec__34092$$);$G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$=$ks__$1$jscomp$6_seq__34093__$1$$;$first__34094_k__$1$jscomp$15_ret__$1$jscomp$7_seq__34087$$=$G__35186_m$jscomp$155_ret__$2$$}else $G__34085__$1_G__35187_G__35189_first__34088_seq__34093_v__$1$jscomp$20_vec__34095$$=
$ks__$1$jscomp$6_seq__34093__$1$$,$first__34094_k__$1$jscomp$15_ret__$1$jscomp$7_seq__34087$$=$G__35186_m$jscomp$155_ret__$2$$;else return $G__35186_m$jscomp$155_ret__$2$$}}else return $cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$explain_STAR_$arity$5$=function($_$jscomp$807$$,$path$jscomp$128$$,$via$jscomp$6$$,$in$$jscomp$45$$,$x$jscomp$893$$){var $self__$jscomp$2077$$=this;if($APP.$cljs$core$map_QMARK_$$($x$jscomp$893$$)){var $reg$jscomp$4$$=$APP.$cljs$core$_deref$$($cljs$spec$alpha$registry_ref$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$concat$$,function(){var $temp__5825__auto__$jscomp$80$$=$APP.$cljs$core$seq$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$identity$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(function($pred$jscomp$56$$,$form$jscomp$121$$){return $APP.$cljs$core$truth_$$($pred$jscomp$56$$.$cljs$core$IFn$_invoke$arity$1$?$pred$jscomp$56$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$893$$):$pred$jscomp$56$$($x$jscomp$893$$))?null:$form$jscomp$121$$},$self__$jscomp$2077$$.$pred_exprs$,$self__$jscomp$2077$$.$pred_forms$)));return $temp__5825__auto__$jscomp$80$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__34064_SHARP_$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$296$path$$,$path$jscomp$128$$,$APP.$cljs$cst$351$pred$$,$p1__34064_SHARP_$$,$APP.$cljs$cst$108$val$$,$x$jscomp$893$$,$APP.$cljs$cst$143$via$$,$via$jscomp$6$$,$APP.$cljs$cst$297$in$$,$in$$jscomp$45$$],null)},$temp__5825__auto__$jscomp$80$$):null}(),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__34117_v$jscomp$255$$){var $k$jscomp$461$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34117_v$jscomp$255$$,0,null);$p__34117_v$jscomp$255$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34117_v$jscomp$255$$,
1,null);var $JSCompiler_temp$jscomp$506_pred$jscomp$inline_3884$$;($JSCompiler_temp$jscomp$506_pred$jscomp$inline_3884$$=!$APP.$cljs$core$contains_QMARK_$$($reg$jscomp$4$$,$self__$jscomp$2077$$.$keys__GT_specnames$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$2077$$.$keys__GT_specnames$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$461$$):$self__$jscomp$2077$$.$keys__GT_specnames$($k$jscomp$461$$)))||($JSCompiler_temp$jscomp$506_pred$jscomp$inline_3884$$=$self__$jscomp$2077$$.$keys__GT_specnames$.$cljs$core$IFn$_invoke$arity$1$?
$self__$jscomp$2077$$.$keys__GT_specnames$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$461$$):$self__$jscomp$2077$$.$keys__GT_specnames$($k$jscomp$461$$),$JSCompiler_temp$jscomp$506_pred$jscomp$inline_3884$$=!$cljs$spec$alpha$invalid_QMARK_$$($cljs$spec$alpha$dt$cljs$0core$0IFn$0_invoke$0arity$04$$($JSCompiler_temp$jscomp$506_pred$jscomp$inline_3884$$,$p__34117_v$jscomp$255$$,$k$jscomp$461$$,null)));return $JSCompiler_temp$jscomp$506_pred$jscomp$inline_3884$$?null:$cljs$spec$alpha$explain_1$$($self__$jscomp$2077$$.$keys__GT_specnames$.$cljs$core$IFn$_invoke$arity$1$?
$self__$jscomp$2077$$.$keys__GT_specnames$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$461$$):$self__$jscomp$2077$$.$keys__GT_specnames$($k$jscomp$461$$),$self__$jscomp$2077$$.$keys__GT_specnames$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$2077$$.$keys__GT_specnames$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$461$$):$self__$jscomp$2077$$.$keys__GT_specnames$($k$jscomp$461$$),$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$128$$,$k$jscomp$461$$),$via$jscomp$6$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($in$$jscomp$45$$,
$k$jscomp$461$$),$p__34117_v$jscomp$255$$)},$APP.$cljs$core$seq$$($x$jscomp$893$$)))}return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$296$path$$,$path$jscomp$128$$,$APP.$cljs$cst$351$pred$$,$cljs$cst$989$cljs_DOT_core_SLASH_map_QMARK_$$,$APP.$cljs$cst$108$val$$,$x$jscomp$893$$,$APP.$cljs$cst$143$via$$,$via$jscomp$6$$,$APP.$cljs$cst$297$in$$,$in$$jscomp$45$$],null)],null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$with_gen_STAR_$arity$2$=function($G__34135__$jscomp$809$$,$gfn__$1$$){$G__34135__$jscomp$809$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$argm$,$cljs$cst$990$gfn$$,$gfn__$1$$);return $cljs$spec$alpha$map_spec_impl$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$spec$alpha$map_spec_impl$$.$cljs$core$IFn$_invoke$arity$1$($G__34135__$jscomp$809$$):$cljs$spec$alpha$map_spec_impl$$($G__34135__$jscomp$809$$)};
$APP.$JSCompiler_prototypeAlias$$=$cljs$spec$alpha$t_cljs$0spec$0alpha34147$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_34149$$,$meta34148__$1$$){return new $cljs$spec$alpha$t_cljs$0spec$0alpha34147$$(this.form,this.$pred$,this.$gfn$,this.$cpred_QMARK_$,this.$unc$,$meta34148__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta34148$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Specize$specize_STAR_$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Specize$specize_STAR_$arity$2$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$conform_STAR_$arity$2$=function($_$jscomp$812_ret$jscomp$75$$,$x$jscomp$894$$){$_$jscomp$812_ret$jscomp$75$$=this.$pred$.$cljs$core$IFn$_invoke$arity$1$?this.$pred$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$894$$):this.$pred$($x$jscomp$894$$);return $APP.$cljs$core$truth_$$(this.$cpred_QMARK_$)?$_$jscomp$812_ret$jscomp$75$$:$APP.$cljs$core$truth_$$($_$jscomp$812_ret$jscomp$75$$)?$x$jscomp$894$$:$cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$explain_STAR_$arity$5$=function($_$jscomp$814$$,$path$jscomp$130$$,$via$jscomp$7$$,$in$$jscomp$46$$,$x$jscomp$896$$){return $cljs$spec$alpha$invalid_QMARK_$$($cljs$spec$alpha$dt$cljs$0core$0IFn$0_invoke$0arity$04$$(this.$pred$,$x$jscomp$896$$,this.form,this.$cpred_QMARK_$))?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$296$path$$,
$path$jscomp$130$$,$APP.$cljs$cst$351$pred$$,this.form,$APP.$cljs$cst$108$val$$,$x$jscomp$896$$,$APP.$cljs$cst$143$via$$,$via$jscomp$7$$,$APP.$cljs$cst$297$in$$,$in$$jscomp$46$$],null)],null):null};$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$with_gen_STAR_$arity$2$=function($_$jscomp$816$$,$gfn__$1$jscomp$1$$){return $cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$05$$(this.form,this.$pred$,$gfn__$1$jscomp$1$$,this.$cpred_QMARK_$,this.$unc$)};
var $cljs$spec$alpha$empty_coll$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1031$cljs_DOT_core_SLASH_vector_QMARK_$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$cljs$cst$1049$cljs_DOT_core_SLASH_set_QMARK_$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,$cljs$cst$1050$cljs_DOT_core_SLASH_list_QMARK_$$,$APP.$cljs$core$List$EMPTY$$,$cljs$cst$989$cljs_DOT_core_SLASH_map_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null);$APP.$JSCompiler_prototypeAlias$$=$cljs$spec$alpha$t_cljs$0spec$0alpha34417$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_34419$$,$meta34418__$1$$){return new $cljs$spec$alpha$t_cljs$0spec$0alpha34417$$(this.form,this.$max_count$,this.$check_QMARK_$,this.$gfn$,this.$gen_max$,this.$pred$,this.$cpred$,this.$conform_keys$,this.$kind_form$,this.$addcv$,this.$cfns$,this.$describe_form$,this.distinct,this.$spec$,this.$p__34414$,this.$kfn$,this.$gen_into$,this.$map__34415$,this.count,this.$min_count$,this.$opts$,this.kind,this.$conform_all$,
this.$conform_into$,$meta34418__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta34418$};$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Specize$specize_STAR_$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Specize$specize_STAR_$arity$2$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$conform_STAR_$arity$2$=function($_$jscomp$853_spec__$1$jscomp$4$$,$G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$){$_$jscomp$853_spec__$1$jscomp$4$$=$APP.$cljs$core$_deref$$(this.$spec$);if($APP.$cljs$core$not$$(this.$cpred$.$cljs$core$IFn$_invoke$arity$1$?this.$cpred$.$cljs$core$IFn$_invoke$arity$1$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$):this.$cpred$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$)))return $cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$;
if($APP.$cljs$core$truth_$$(this.$conform_all$)){var $complete_first__34442_seq__34438_vec__34420$$=this.$cfns$.$cljs$core$IFn$_invoke$arity$1$?this.$cfns$.$cljs$core$IFn$_invoke$arity$1$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$):this.$cfns$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$),$G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($complete_first__34442_seq__34438_vec__34420$$,
0,null),$G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($complete_first__34442_seq__34438_vec__34420$$,1,null);$complete_first__34442_seq__34438_vec__34420$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($complete_first__34442_seq__34438_vec__34420$$,2,null);var $ret$jscomp$87_seq__34431_seq__34431__$1_seq__34441__$1_vs__$1$$=$G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$.$cljs$core$IFn$_invoke$arity$1$?
$G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$.$cljs$core$IFn$_invoke$arity$1$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$):$G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$);$G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$=0;var $G__34426_G__34426__$1_G__35358_first__34432_seq__34441_v__$1$jscomp$21$$=$APP.$cljs$core$seq$$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$);
$G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$=$APP.$cljs$core$seq$$($G__34426_G__34426__$1_G__35358_first__34432_seq__34441_v__$1$jscomp$21$$);$APP.$cljs$core$first$$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$);$APP.$cljs$core$next$$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$);for($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$=$ret$jscomp$87_seq__34431_seq__34431__$1_seq__34441__$1_vs__$1$$;;){var $cv$jscomp$4_vec__34430_vseq__$1$$=
$G__34426_G__34426__$1_G__35358_first__34432_seq__34441_v__$1$jscomp$21$$;$ret$jscomp$87_seq__34431_seq__34431__$1_seq__34441__$1_vs__$1$$=$APP.$cljs$core$seq$$($cv$jscomp$4_vec__34430_vseq__$1$$);$G__34426_G__34426__$1_G__35358_first__34432_seq__34441_v__$1$jscomp$21$$=$APP.$cljs$core$first$$($ret$jscomp$87_seq__34431_seq__34431__$1_seq__34441__$1_vs__$1$$);$ret$jscomp$87_seq__34431_seq__34431__$1_seq__34441__$1_vs__$1$$=$APP.$cljs$core$next$$($ret$jscomp$87_seq__34431_seq__34431__$1_seq__34441__$1_vs__$1$$);
if($cv$jscomp$4_vec__34430_vseq__$1$$){$cv$jscomp$4_vec__34430_vseq__$1$$=$cljs$spec$alpha$conform_STAR_$$($_$jscomp$853_spec__$1$jscomp$4$$,$G__34426_G__34426__$1_G__35358_first__34432_seq__34441_v__$1$jscomp$21$$);if($cljs$spec$alpha$invalid_QMARK_$$($cv$jscomp$4_vec__34430_vseq__$1$$))return $cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$;$G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$=$G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$.$cljs$core$IFn$_invoke$arity$4$?
$G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$.$cljs$core$IFn$_invoke$arity$4$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$,$G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$,$G__34426_G__34426__$1_G__35358_first__34432_seq__34441_v__$1$jscomp$21$$,$cv$jscomp$4_vec__34430_vseq__$1$$):$G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$,
$G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$,$G__34426_G__34426__$1_G__35358_first__34432_seq__34441_v__$1$jscomp$21$$,$cv$jscomp$4_vec__34430_vseq__$1$$);$G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$+=1;$G__34426_G__34426__$1_G__35358_first__34432_seq__34441_v__$1$jscomp$21$$=$ret$jscomp$87_seq__34431_seq__34431__$1_seq__34441__$1_vs__$1$$}else return $complete_first__34442_seq__34438_vec__34420$$.$cljs$core$IFn$_invoke$arity$1$?$complete_first__34442_seq__34438_vec__34420$$.$cljs$core$IFn$_invoke$arity$1$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$):
$complete_first__34442_seq__34438_vec__34420$$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$)}}else if($cljs$core$indexed_QMARK_$$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$))for($G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$=$APP.$cljs$core$count$$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$)/101,$G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$=
$APP.$cljs$core$fix$$($G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$),$G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$=1>$G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$?1:$G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$,
$G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$=0;;){if($G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$>=$APP.$cljs$core$count$$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$))return $G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$;if($APP.$cljs$spec$alpha$valid_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$853_spec__$1$jscomp$4$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$,
$G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$)))$G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$+=$G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$;else return $cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$}else for($G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$=0,$G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$=
$APP.$cljs$core$seq$$($G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$),$complete_first__34442_seq__34438_vec__34420$$=$APP.$cljs$core$seq$$($G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$),$APP.$cljs$core$first$$($complete_first__34442_seq__34438_vec__34420$$),$APP.$cljs$core$next$$($complete_first__34442_seq__34438_vec__34420$$);;){$G__34426_G__34426__$1_G__35358_first__34432_seq__34441_v__$1$jscomp$21$$=
$APP.$cljs$core$seq$$($G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$);$complete_first__34442_seq__34438_vec__34420$$=$APP.$cljs$core$first$$($G__34426_G__34426__$1_G__35358_first__34432_seq__34441_v__$1$jscomp$21$$);$ret$jscomp$87_seq__34431_seq__34431__$1_seq__34441__$1_vs__$1$$=$APP.$cljs$core$next$$($G__34426_G__34426__$1_G__35358_first__34432_seq__34441_v__$1$jscomp$21$$);$G__34426_G__34426__$1_G__35358_first__34432_seq__34441_v__$1$jscomp$21$$=
$complete_first__34442_seq__34438_vec__34420$$;$cv$jscomp$4_vec__34430_vseq__$1$$=$G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$;if($cv$jscomp$4_vec__34430_vseq__$1$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$,101))return $G__35356_ret__$1$jscomp$14_ret__$2$jscomp$5_seq__34428_x$jscomp$921$$;if($APP.$cljs$spec$alpha$valid_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$853_spec__$1$jscomp$4$$,
$G__34426_G__34426__$1_G__35358_first__34432_seq__34441_v__$1$jscomp$21$$))$G__34436_G__34436__$1_G__35361_add_step$jscomp$26_vec__34440_x$jscomp$inline_11530_y__5111__auto__$jscomp$inline_3888$$=$ret$jscomp$87_seq__34431_seq__34431__$1_seq__34441__$1_vs__$1$$,$G__35357_i$jscomp$363_i__$1$jscomp$8_i__$2$jscomp$3_init$jscomp$52$$+=1;else return $cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$explain_STAR_$arity$5$=function($_$jscomp$855_or__5025__auto__$jscomp$221$$,$path$jscomp$143$$,$via$jscomp$15$$,$in$$jscomp$54$$,$x$jscomp$923$$){var $self__$jscomp$2147$$=this;$_$jscomp$855_or__5025__auto__$jscomp$221$$=$cljs$spec$alpha$coll_prob$$($x$jscomp$923$$,$self__$jscomp$2147$$.kind,$self__$jscomp$2147$$.$kind_form$,$self__$jscomp$2147$$.distinct,$self__$jscomp$2147$$.count,$self__$jscomp$2147$$.$min_count$,$self__$jscomp$2147$$.$max_count$,
$path$jscomp$143$$,$via$jscomp$15$$,$in$$jscomp$54$$);return $APP.$cljs$core$truth_$$($_$jscomp$855_or__5025__auto__$jscomp$221$$)?$_$jscomp$855_or__5025__auto__$jscomp$221$$:$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,function(){var $G__34463$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$identity$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(function($i$jscomp$365_k$jscomp$469$$,$v$jscomp$261$$){$i$jscomp$365_k$jscomp$469$$=
$self__$jscomp$2147$$.$kfn$.$cljs$core$IFn$_invoke$arity$2$?$self__$jscomp$2147$$.$kfn$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$365_k$jscomp$469$$,$v$jscomp$261$$):$self__$jscomp$2147$$.$kfn$($i$jscomp$365_k$jscomp$469$$,$v$jscomp$261$$);return $APP.$cljs$core$truth_$$($self__$jscomp$2147$$.$check_QMARK_$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$2147$$.$check_QMARK_$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$261$$):$self__$jscomp$2147$$.$check_QMARK_$($v$jscomp$261$$))?null:$cljs$spec$alpha$explain_1$$($self__$jscomp$2147$$.form,
$self__$jscomp$2147$$.$pred$,$path$jscomp$143$$,$via$jscomp$15$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($in$$jscomp$54$$,$i$jscomp$365_k$jscomp$469$$),$v$jscomp$261$$)},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$03$$(0,Number.MAX_VALUE,1),$x$jscomp$923$$)),$fexpr__34462$$=$APP.$cljs$core$truth_$$($self__$jscomp$2147$$.$conform_all$)?$APP.$cljs$core$identity$$:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$take$$,20);return $fexpr__34462$$.$cljs$core$IFn$_invoke$arity$1$?
$fexpr__34462$$.$cljs$core$IFn$_invoke$arity$1$($G__34463$$):$fexpr__34462$$($G__34463$$)}())};$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$with_gen_STAR_$arity$2$=function($_$jscomp$857$$,$gfn__$1$jscomp$7$$){return $cljs$spec$alpha$every_impl$cljs$0core$0IFn$0_invoke$0arity$04$$(this.form,this.$pred$,this.$opts$,$gfn__$1$jscomp$7$$)};
var $cljs$spec$alpha$pcat_STAR_$$=function $cljs$spec$alpha$pcat_STAR_$$($G__34506_p__34491_seq__34495_seq__34495__$1$$){var $map__34493__$1_rep_PLUS_$$=$APP.$cljs$core$__destructure_map$$($G__34506_p__34491_seq__34495_seq__34495__$1$$),$ret__$1$jscomp$16_rp_vec__34494$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34493__$1_rep_PLUS_$$,$cljs$cst$1085$ps$$);$G__34506_p__34491_seq__34495_seq__34495__$1$$=$APP.$cljs$core$seq$$($ret__$1$jscomp$16_rp_vec__34494$$);var $first__34496$$=$APP.$cljs$core$first$$($G__34506_p__34491_seq__34495_seq__34495__$1$$);
$G__34506_p__34491_seq__34495_seq__34495__$1$$=$APP.$cljs$core$next$$($G__34506_p__34491_seq__34495_seq__34495__$1$$);var $vec__34497$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34493__$1_rep_PLUS_$$,$cljs$cst$1086$ks$$),$seq__34498_seq__34498__$1$$=$APP.$cljs$core$seq$$($vec__34497$$),$first__34499$$=$APP.$cljs$core$first$$($seq__34498_seq__34498__$1$$);$seq__34498_seq__34498__$1$$=$APP.$cljs$core$next$$($seq__34498_seq__34498__$1$$);var $vec__34500$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34493__$1_rep_PLUS_$$,
$cljs$cst$1087$forms$$),$seq__34501_seq__34501__$1$$=$APP.$cljs$core$seq$$($vec__34500$$);$APP.$cljs$core$first$$($seq__34501_seq__34501__$1$$);$seq__34501_seq__34501__$1$$=$APP.$cljs$core$next$$($seq__34501_seq__34501__$1$$);var $ret$jscomp$92$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34493__$1_rep_PLUS_$$,$cljs$cst$1084$ret$$);$map__34493__$1_rep_PLUS_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34493__$1_rep_PLUS_$$,$cljs$cst$1088$rep_PLUS_$$);return $APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$identity$$,
$ret__$1$jscomp$16_rp_vec__34494$$)?$cljs$spec$alpha$accept_QMARK_$$($first__34496$$)?($ret__$1$jscomp$16_rp_vec__34494$$=$cljs$cst$1084$ret$$.$cljs$core$IFn$_invoke$arity$1$($first__34496$$),$ret__$1$jscomp$16_rp_vec__34494$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($ret$jscomp$92$$,$APP.$cljs$core$truth_$$($vec__34497$$)?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$first__34499$$,$ret__$1$jscomp$16_rp_vec__34494$$]):$ret__$1$jscomp$16_rp_vec__34494$$),$G__34506_p__34491_seq__34495_seq__34495__$1$$?
($G__34506_p__34491_seq__34495_seq__34495__$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1085$ps$$,$G__34506_p__34491_seq__34495_seq__34495__$1$$,$cljs$cst$1086$ks$$,$seq__34498_seq__34498__$1$$,$cljs$cst$1087$forms$$,$seq__34501_seq__34501__$1$$,$cljs$cst$1084$ret$$,$ret__$1$jscomp$16_rp_vec__34494$$],null),$cljs$spec$alpha$pcat_STAR_$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$spec$alpha$pcat_STAR_$$.$cljs$core$IFn$_invoke$arity$1$($G__34506_p__34491_seq__34495_seq__34495__$1$$):$cljs$spec$alpha$pcat_STAR_$$($G__34506_p__34491_seq__34495_seq__34495__$1$$)):
$cljs$spec$alpha$accept$$($ret__$1$jscomp$16_rp_vec__34494$$)):new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$,$cljs$cst$1089$cljs_DOT_spec_DOT_alpha_SLASH_pcat$$,$cljs$cst$1085$ps$$,$ret__$1$jscomp$16_rp_vec__34494$$,$cljs$cst$1084$ret$$,$ret$jscomp$92$$,$cljs$cst$1086$ks$$,$vec__34497$$,$cljs$cst$1087$forms$$,$vec__34500$$,$cljs$cst$1088$rep_PLUS_$$,$map__34493__$1_rep_PLUS_$$],null):null},$cljs$spec$alpha$accept_nil_QMARK_$$=function $cljs$spec$alpha$accept_nil_QMARK_$$($map__34590_p$jscomp$99_p1$jscomp$15_ret$jscomp$95$$){$map__34590_p$jscomp$99_p1$jscomp$15_ret$jscomp$95$$=
$cljs$spec$alpha$reg_resolve_BANG_$$($map__34590_p$jscomp$99_p1$jscomp$15_ret$jscomp$95$$);var $forms$jscomp$27_map__34590__$1$$=$APP.$cljs$core$__destructure_map$$($map__34590_p$jscomp$99_p1$jscomp$15_ret$jscomp$95$$),$and__5023__auto__$jscomp$158_op$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($forms$jscomp$27_map__34590__$1$$,$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$),$or__5025__auto__$jscomp$236_ps$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($forms$jscomp$27_map__34590__$1$$,
$cljs$cst$1085$ps$$);$map__34590_p$jscomp$99_p1$jscomp$15_ret$jscomp$95$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($forms$jscomp$27_map__34590__$1$$,$APP.$cljs$cst$1093$p1$$);var $p2$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($forms$jscomp$27_map__34590__$1$$,$APP.$cljs$cst$1091$p2$$);$forms$jscomp$27_map__34590__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($forms$jscomp$27_map__34590__$1$$,$cljs$cst$1087$forms$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1083$cljs_DOT_spec_DOT_alpha_SLASH_accept$$,
$and__5023__auto__$jscomp$158_op$jscomp$1$$))return!0;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$and__5023__auto__$jscomp$158_op$jscomp$1$$))return null;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1095$cljs_DOT_spec_DOT_alpha_SLASH_amp$$,$and__5023__auto__$jscomp$158_op$jscomp$1$$))return $and__5023__auto__$jscomp$158_op$jscomp$1$$=$cljs$spec$alpha$accept_nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$spec$alpha$accept_nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__34590_p$jscomp$99_p1$jscomp$15_ret$jscomp$95$$):
$cljs$spec$alpha$accept_nil_QMARK_$$($map__34590_p$jscomp$99_p1$jscomp$15_ret$jscomp$95$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$158_op$jscomp$1$$)?($map__34590_p$jscomp$99_p1$jscomp$15_ret$jscomp$95$$=$cljs$spec$alpha$and_preds$$($cljs$spec$alpha$preturn$$($map__34590_p$jscomp$99_p1$jscomp$15_ret$jscomp$95$$),$or__5025__auto__$jscomp$236_ps$jscomp$13$$,$APP.$cljs$core$next$$($forms$jscomp$27_map__34590__$1$$)),!$cljs$spec$alpha$invalid_QMARK_$$($map__34590_p$jscomp$99_p1$jscomp$15_ret$jscomp$95$$)):
$and__5023__auto__$jscomp$158_op$jscomp$1$$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1090$cljs_DOT_spec_DOT_alpha_SLASH_rep$$,$and__5023__auto__$jscomp$158_op$jscomp$1$$))return($or__5025__auto__$jscomp$236_ps$jscomp$13$$=$map__34590_p$jscomp$99_p1$jscomp$15_ret$jscomp$95$$===$p2$jscomp$12$$)?$or__5025__auto__$jscomp$236_ps$jscomp$13$$:$cljs$spec$alpha$accept_nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$spec$alpha$accept_nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__34590_p$jscomp$99_p1$jscomp$15_ret$jscomp$95$$):
$cljs$spec$alpha$accept_nil_QMARK_$$($map__34590_p$jscomp$99_p1$jscomp$15_ret$jscomp$95$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1089$cljs_DOT_spec_DOT_alpha_SLASH_pcat$$,$and__5023__auto__$jscomp$158_op$jscomp$1$$))return $APP.$cljs$core$every_QMARK_$$($cljs$spec$alpha$accept_nil_QMARK_$$,$or__5025__auto__$jscomp$236_ps$jscomp$13$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1097$cljs_DOT_spec_DOT_alpha_SLASH_alt$$,$and__5023__auto__$jscomp$158_op$jscomp$1$$))return $APP.$cljs$core$some$$($cljs$spec$alpha$accept_nil_QMARK_$$,
$or__5025__auto__$jscomp$236_ps$jscomp$13$$);throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$158_op$jscomp$1$$)].join(""));},$cljs$spec$alpha$preturn$$=function $cljs$spec$alpha$preturn$$($map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$){$map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$=$cljs$spec$alpha$reg_resolve_BANG_$$($map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$);var $forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$=
$APP.$cljs$core$__destructure_map$$($map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$);$map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$,$cljs$cst$1085$ps$$);var $G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$=$APP.$cljs$core$seq$$($map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$),
$first__34604_pret$jscomp$1$$=$APP.$cljs$core$first$$($G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$);$APP.$cljs$core$next$$($G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$);var $fexpr__34585$jscomp$inline_14181_or__5025__auto__$jscomp$inline_14177_vec__34605$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$,$cljs$cst$1086$ks$$),$k$jscomp$470$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fexpr__34585$jscomp$inline_14181_or__5025__auto__$jscomp$inline_14177_vec__34605$$,0,null),$op$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$,$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$);$G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$,$APP.$cljs$cst$1093$p1$$);var $ret$jscomp$96$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$,$cljs$cst$1084$ret$$);$forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$,$cljs$cst$1087$forms$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1083$cljs_DOT_spec_DOT_alpha_SLASH_accept$$,
$op$jscomp$2$$))return $ret$jscomp$96$$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$op$jscomp$2$$))return null;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1095$cljs_DOT_spec_DOT_alpha_SLASH_amp$$,$op$jscomp$2$$))return $first__34604_pret$jscomp$1$$=$cljs$spec$alpha$preturn$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$spec$alpha$preturn$$.$cljs$core$IFn$_invoke$arity$1$($G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$):
$cljs$spec$alpha$preturn$$($G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$),($fexpr__34585$jscomp$inline_14181_or__5025__auto__$jscomp$inline_14177_vec__34605$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($first__34604_pret$jscomp$1$$,$cljs$cst$1098$cljs_DOT_spec_DOT_alpha_SLASH_nil$$))?$G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$=
$fexpr__34585$jscomp$inline_14181_or__5025__auto__$jscomp$inline_14177_vec__34605$$:($G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$=$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$.$cljs$core$IFn$_invoke$arity$1$($cljs$spec$alpha$reg_resolve_BANG_$$($G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$)),
$fexpr__34585$jscomp$inline_14181_or__5025__auto__$jscomp$inline_14177_vec__34605$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$1090$cljs_DOT_spec_DOT_alpha_SLASH_rep$$,null,$cljs$cst$1089$cljs_DOT_spec_DOT_alpha_SLASH_pcat$$,null],null),null),$G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$=$fexpr__34585$jscomp$inline_14181_or__5025__auto__$jscomp$inline_14177_vec__34605$$.$cljs$core$IFn$_invoke$arity$1$?
$fexpr__34585$jscomp$inline_14181_or__5025__auto__$jscomp$inline_14177_vec__34605$$.$cljs$core$IFn$_invoke$arity$1$($G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$):$fexpr__34585$jscomp$inline_14181_or__5025__auto__$jscomp$inline_14177_vec__34605$$($G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$),
$G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$=$APP.$cljs$core$truth_$$($G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$)?$APP.$cljs$core$empty_QMARK_$$($first__34604_pret$jscomp$1$$):$G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$,
$G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$=$APP.$cljs$core$truth_$$($G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$)?$G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$:
null),$APP.$cljs$core$truth_$$($G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$)?$cljs$cst$1098$cljs_DOT_spec_DOT_alpha_SLASH_nil$$:$cljs$spec$alpha$and_preds$$($first__34604_pret$jscomp$1$$,$map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$,$forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1090$cljs_DOT_spec_DOT_alpha_SLASH_rep$$,
$op$jscomp$2$$))return $cljs$spec$alpha$add_ret$$($G__34586$jscomp$inline_14180_JSCompiler_inline_result$jscomp$14045_and__5023__auto__$jscomp$inline_14179_or__5025__auto____$1$jscomp$inline_14178_p1$jscomp$16_seq__34603$$,$ret$jscomp$96$$,$k$jscomp$470$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1089$cljs_DOT_spec_DOT_alpha_SLASH_pcat$$,$op$jscomp$2$$))return $cljs$spec$alpha$add_ret$$($first__34604_pret$jscomp$1$$,$ret$jscomp$96$$,$k$jscomp$470$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1097$cljs_DOT_spec_DOT_alpha_SLASH_alt$$,
$op$jscomp$2$$))return $forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$=$cljs$spec$alpha$filter_alt$$($map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$,$fexpr__34585$jscomp$inline_14181_or__5025__auto__$jscomp$inline_14177_vec__34605$$,$forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$,$cljs$spec$alpha$accept_nil_QMARK_$$),$map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$,
0,null),$map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$,0,null),$forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$,1,null),$forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$,
0,null),$map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$=$map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$==null?$cljs$cst$1098$cljs_DOT_spec_DOT_alpha_SLASH_nil$$:$cljs$spec$alpha$preturn$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$spec$alpha$preturn$$.$cljs$core$IFn$_invoke$arity$1$($map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$):$cljs$spec$alpha$preturn$$($map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$),$APP.$cljs$core$truth_$$($forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$)?
new $APP.$cljs$core$MapEntry$$($forms$jscomp$28_k0_map__34601__$1_vec__34612_vec__34618$$,$map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$,null):$map__34601_p$jscomp$100_p0__$1_r$jscomp$68_vec__34602_vec__34615$$;throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($op$jscomp$2$$)].join(""));},$cljs$spec$alpha$deriv$$=function $cljs$spec$alpha$deriv$$($map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$,$x$jscomp$927$$){$map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$=
$cljs$spec$alpha$reg_resolve_BANG_$$($map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$);var $map__34658__$1_temp__5825__auto__$jscomp$81$$=$APP.$cljs$core$__destructure_map$$($map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$),$forms$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34658__$1_temp__5825__auto__$jscomp$81$$,$cljs$cst$1087$forms$$),$p2$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34658__$1_temp__5825__auto__$jscomp$81$$,$APP.$cljs$cst$1091$p2$$);
$map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34658__$1_temp__5825__auto__$jscomp$81$$,$cljs$cst$1085$ps$$);var $op$jscomp$5_seq__34660$$=$APP.$cljs$core$seq$$($map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$),$first__34661$$=$APP.$cljs$core$first$$($op$jscomp$5_seq__34660$$),$seq__34660__$1$$=$APP.$cljs$core$next$$($op$jscomp$5_seq__34660$$),$ret$jscomp$100$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34658__$1_temp__5825__auto__$jscomp$81$$,
$cljs$cst$1084$ret$$);$op$jscomp$5_seq__34660$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34658__$1_temp__5825__auto__$jscomp$81$$,$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$);var $splice$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34658__$1_temp__5825__auto__$jscomp$81$$,$cljs$cst$1092$splice$$),$vec__34662$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34658__$1_temp__5825__auto__$jscomp$81$$,$cljs$cst$1086$ks$$),$amp_seq__34663$$=
$APP.$cljs$core$seq$$($vec__34662$$),$first__34664$$=$APP.$cljs$core$first$$($amp_seq__34663$$),$seq__34663__$1$$=$APP.$cljs$core$next$$($amp_seq__34663$$);$amp_seq__34663$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34658__$1_temp__5825__auto__$jscomp$81$$,$cljs$cst$1096$amp$$);var $p1$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34658__$1_temp__5825__auto__$jscomp$81$$,$APP.$cljs$cst$1093$p1$$);if($APP.$cljs$core$truth_$$($map__34658__$1_temp__5825__auto__$jscomp$81$$)){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1083$cljs_DOT_spec_DOT_alpha_SLASH_accept$$,
$op$jscomp$5_seq__34660$$))return null;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$op$jscomp$5_seq__34660$$))return $map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$=$cljs$spec$alpha$dt$cljs$0core$0IFn$0_invoke$0arity$04$$($map__34658__$1_temp__5825__auto__$jscomp$81$$,$x$jscomp$927$$,$map__34658__$1_temp__5825__auto__$jscomp$81$$,null),$cljs$spec$alpha$invalid_QMARK_$$($map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$)?null:$cljs$spec$alpha$accept$$($map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$);
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1095$cljs_DOT_spec_DOT_alpha_SLASH_amp$$,$op$jscomp$5_seq__34660$$))return $map__34658__$1_temp__5825__auto__$jscomp$81$$=$cljs$spec$alpha$deriv$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$spec$alpha$deriv$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$18$$,$x$jscomp$927$$):$cljs$spec$alpha$deriv$$($p1$jscomp$18$$,$x$jscomp$927$$),$APP.$cljs$core$truth_$$($map__34658__$1_temp__5825__auto__$jscomp$81$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1083$cljs_DOT_spec_DOT_alpha_SLASH_accept$$,
$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$.$cljs$core$IFn$_invoke$arity$1$($map__34658__$1_temp__5825__auto__$jscomp$81$$))?($map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$=$cljs$spec$alpha$and_preds$$($cljs$spec$alpha$preturn$$($map__34658__$1_temp__5825__auto__$jscomp$81$$),$map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$,$APP.$cljs$core$next$$($forms$jscomp$30$$)),$cljs$spec$alpha$invalid_QMARK_$$($map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$)?null:$cljs$spec$alpha$accept$$($map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$)):
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$,$cljs$cst$1095$cljs_DOT_spec_DOT_alpha_SLASH_amp$$,$APP.$cljs$cst$1093$p1$$,$map__34658__$1_temp__5825__auto__$jscomp$81$$,$cljs$cst$1096$amp$$,$amp_seq__34663$$,$cljs$cst$1085$ps$$,$map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$,$cljs$cst$1087$forms$$,$forms$jscomp$30$$],null):null;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1089$cljs_DOT_spec_DOT_alpha_SLASH_pcat$$,$op$jscomp$5_seq__34660$$))return $cljs$spec$alpha$alt2$$($cljs$spec$alpha$pcat_STAR_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$cljs$cst$1085$ps$$,$APP.$cljs$core$cons$$($cljs$spec$alpha$deriv$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$spec$alpha$deriv$$.$cljs$core$IFn$_invoke$arity$2$($first__34661$$,$x$jscomp$927$$):$cljs$spec$alpha$deriv$$($first__34661$$,$x$jscomp$927$$),$seq__34660__$1$$),$cljs$cst$1086$ks$$,$vec__34662$$,$cljs$cst$1087$forms$$,$forms$jscomp$30$$,$cljs$cst$1084$ret$$,$ret$jscomp$100$$],null)),$APP.$cljs$core$truth_$$($cljs$spec$alpha$accept_nil_QMARK_$$($first__34661$$))?function(){var $G__34669$$=$cljs$spec$alpha$pcat_STAR_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$cljs$cst$1085$ps$$,$seq__34660__$1$$,$cljs$cst$1086$ks$$,$seq__34663__$1$$,$cljs$cst$1087$forms$$,$APP.$cljs$core$next$$($forms$jscomp$30$$),$cljs$cst$1084$ret$$,$cljs$spec$alpha$add_ret$$($first__34661$$,$ret$jscomp$100$$,$first__34664$$)],null));return $cljs$spec$alpha$deriv$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$spec$alpha$deriv$$.$cljs$core$IFn$_invoke$arity$2$($G__34669$$,$x$jscomp$927$$):$cljs$spec$alpha$deriv$$($G__34669$$,$x$jscomp$927$$)}():null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1097$cljs_DOT_spec_DOT_alpha_SLASH_alt$$,
$op$jscomp$5_seq__34660$$))return $cljs$spec$alpha$alt_STAR_$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__34656_SHARP_$$){return $cljs$spec$alpha$deriv$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$spec$alpha$deriv$$.$cljs$core$IFn$_invoke$arity$2$($p1__34656_SHARP_$$,$x$jscomp$927$$):$cljs$spec$alpha$deriv$$($p1__34656_SHARP_$$,$x$jscomp$927$$)},$map__34658_p$jscomp$103_ret__$1$jscomp$17_vec__34659$$),$vec__34662$$,$forms$jscomp$30$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1090$cljs_DOT_spec_DOT_alpha_SLASH_rep$$,
$op$jscomp$5_seq__34660$$))return $cljs$spec$alpha$alt2$$($cljs$spec$alpha$rep_STAR_$$($cljs$spec$alpha$deriv$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$spec$alpha$deriv$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$18$$,$x$jscomp$927$$):$cljs$spec$alpha$deriv$$($p1$jscomp$18$$,$x$jscomp$927$$),$p2$jscomp$13$$,$ret$jscomp$100$$,$splice$jscomp$2$$,$forms$jscomp$30$$),$APP.$cljs$core$truth_$$($cljs$spec$alpha$accept_nil_QMARK_$$($p1$jscomp$18$$))?function(){var $G__34674$$=$cljs$spec$alpha$rep_STAR_$$($p2$jscomp$13$$,
$p2$jscomp$13$$,$cljs$spec$alpha$add_ret$$($p1$jscomp$18$$,$ret$jscomp$100$$,null),$splice$jscomp$2$$,$forms$jscomp$30$$);return $cljs$spec$alpha$deriv$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$spec$alpha$deriv$$.$cljs$core$IFn$_invoke$arity$2$($G__34674$$,$x$jscomp$927$$):$cljs$spec$alpha$deriv$$($G__34674$$,$x$jscomp$927$$)}():null);throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($op$jscomp$5_seq__34660$$)].join(""));}return null},$cljs$spec$alpha$op_explain$$=
function $cljs$spec$alpha$op_explain$$($G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$,$map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$,$path$jscomp$145$$,$via$jscomp$16$$,$in$$jscomp$55$$,$input$jscomp$57$$){function $insufficient$$($path__$1$jscomp$4$$,$form__$1$jscomp$4$$){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$296$path$$,
$path__$1$jscomp$4$$,$APP.$cljs$cst$984$reason$$,"Insufficient input",$APP.$cljs$cst$351$pred$$,$form__$1$jscomp$4$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$core$List$EMPTY$$,$APP.$cljs$cst$143$via$$,$via__$1$$,$APP.$cljs$cst$297$in$$,$in$$jscomp$55$$],null)],null)}var $form__$1$jscomp$3_form__$2_vec__34706_x$jscomp$928$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($input$jscomp$57$$,0,null);$map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$=$cljs$spec$alpha$reg_resolve_BANG_$$($map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$);
var $map__34695__$1$$=$APP.$cljs$core$__destructure_map$$($map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$),$op$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34695__$1$$,$cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$),$ps$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34695__$1$$,$cljs$cst$1085$ps$$),$ks$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34695__$1$$,$cljs$cst$1086$ks$$),$forms$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34695__$1$$,
$cljs$cst$1087$forms$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34695__$1$$,$cljs$cst$1092$splice$$);$map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34695__$1$$,$APP.$cljs$cst$1093$p1$$);var $p2$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__34695__$1$$,$APP.$cljs$cst$1091$p2$$),$via__$1$$=function(){var $temp__5823__auto__$jscomp$88$$=$cljs$spec$alpha$spec_name$$($map__34695__$1$$);
return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$88$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($via$jscomp$16$$,$temp__5823__auto__$jscomp$88$$):$via$jscomp$16$$}();if($APP.$cljs$core$truth_$$($map__34695__$1$$)){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1083$cljs_DOT_spec_DOT_alpha_SLASH_accept$$,$op$jscomp$7$$))return null;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$op$jscomp$7$$))return $APP.$cljs$core$empty_QMARK_$$($input$jscomp$57$$)?
$insufficient$$($path$jscomp$145$$,$G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$):$cljs$spec$alpha$explain_1$$($G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$,$map__34695__$1$$,$path$jscomp$145$$,$via__$1$$,$in$$jscomp$55$$,$form__$1$jscomp$3_form__$2_vec__34706_x$jscomp$928$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1095$cljs_DOT_spec_DOT_alpha_SLASH_amp$$,$op$jscomp$7$$)){if($APP.$cljs$core$empty_QMARK_$$($input$jscomp$57$$))return $APP.$cljs$core$truth_$$($cljs$spec$alpha$accept_nil_QMARK_$$($map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$))?
$cljs$spec$alpha$explain_pred_list$$($forms$jscomp$32$$,$ps$jscomp$19$$,$path$jscomp$145$$,$via__$1$$,$in$$jscomp$55$$,$cljs$spec$alpha$preturn$$($map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$)):$insufficient$$($path$jscomp$145$$,$cljs$cst$1096$amp$$.$cljs$core$IFn$_invoke$arity$1$($map__34695__$1$$));$G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$=$cljs$spec$alpha$deriv$$($map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$,$form__$1$jscomp$3_form__$2_vec__34706_x$jscomp$928$$);
if($APP.$cljs$core$truth_$$($G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$))return $cljs$spec$alpha$explain_pred_list$$($forms$jscomp$32$$,$ps$jscomp$19$$,$path$jscomp$145$$,$via__$1$$,$in$$jscomp$55$$,$cljs$spec$alpha$preturn$$($G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$));$G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$=$cljs$cst$1096$amp$$.$cljs$core$IFn$_invoke$arity$1$($map__34695__$1$$);
return $cljs$spec$alpha$op_explain$$.$cljs$core$IFn$_invoke$arity$6$?$cljs$spec$alpha$op_explain$$.$cljs$core$IFn$_invoke$arity$6$($G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$,$map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$,$path$jscomp$145$$,$via__$1$$,$in$$jscomp$55$$,$input$jscomp$57$$):$cljs$spec$alpha$op_explain$$($G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$,$map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$,
$path$jscomp$145$$,$via__$1$$,$in$$jscomp$55$$,$input$jscomp$57$$)}if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1089$cljs_DOT_spec_DOT_alpha_SLASH_pcat$$,$op$jscomp$7$$))return $map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$vector$$,$ps$jscomp$19$$,function(){var $or__5025__auto__$jscomp$238$$=$APP.$cljs$core$seq$$($ks$jscomp$51$$);return $or__5025__auto__$jscomp$238$$?$or__5025__auto__$jscomp$238$$:
$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$(null)}(),function(){var $or__5025__auto__$jscomp$239$$=$APP.$cljs$core$seq$$($forms$jscomp$32$$);return $or__5025__auto__$jscomp$239$$?$or__5025__auto__$jscomp$239$$:$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$(null)}()),$form__$1$jscomp$3_form__$2_vec__34706_x$jscomp$928$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$))?$APP.$cljs$core$first$$($map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$):
$APP.$cljs$core$first$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p__$2_p__34709$$){$p__$2_p__34709$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__$2_p__34709$$,0,null);return $cljs$spec$alpha$accept_nil_QMARK_$$($p__$2_p__34709$$)},$map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$)),$map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($form__$1$jscomp$3_form__$2_vec__34706_x$jscomp$928$$,
0,null),$G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($form__$1$jscomp$3_form__$2_vec__34706_x$jscomp$928$$,1,null),$form__$1$jscomp$3_form__$2_vec__34706_x$jscomp$928$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($form__$1$jscomp$3_form__$2_vec__34706_x$jscomp$928$$,2,null),$G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$=$APP.$cljs$core$truth_$$($G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$)?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$145$$,$G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$):$path$jscomp$145$$,$form__$1$jscomp$3_form__$2_vec__34706_x$jscomp$928$$=$APP.$cljs$core$truth_$$($form__$1$jscomp$3_form__$2_vec__34706_x$jscomp$928$$)?$form__$1$jscomp$3_form__$2_vec__34706_x$jscomp$928$$:$cljs$spec$alpha$op_describe$$($map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$),$APP.$cljs$core$empty_QMARK_$$($input$jscomp$57$$)&&
$APP.$cljs$core$not$$($map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$)?$insufficient$$($G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$,$form__$1$jscomp$3_form__$2_vec__34706_x$jscomp$928$$):$cljs$spec$alpha$op_explain$$.$cljs$core$IFn$_invoke$arity$6$?$cljs$spec$alpha$op_explain$$.$cljs$core$IFn$_invoke$arity$6$($form__$1$jscomp$3_form__$2_vec__34706_x$jscomp$928$$,$map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$,$G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$,
$via__$1$$,$in$$jscomp$55$$,$input$jscomp$57$$):$cljs$spec$alpha$op_explain$$($form__$1$jscomp$3_form__$2_vec__34706_x$jscomp$928$$,$map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$,$G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$,$via__$1$$,$in$$jscomp$55$$,$input$jscomp$57$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1097$cljs_DOT_spec_DOT_alpha_SLASH_alt$$,$op$jscomp$7$$))return $APP.$cljs$core$empty_QMARK_$$($input$jscomp$57$$)?
$insufficient$$($path$jscomp$145$$,$cljs$spec$alpha$op_describe$$($map__34695__$1$$)):$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$4$(function($G__34717_k$jscomp$474$$,$G__34715_form__$1$jscomp$5$$,$pred$jscomp$74$$){$G__34715_form__$1$jscomp$5$$=$APP.$cljs$core$truth_$$($G__34715_form__$1$jscomp$5$$)?$G__34715_form__$1$jscomp$5$$:$cljs$spec$alpha$op_describe$$($pred$jscomp$74$$);$G__34717_k$jscomp$474$$=$APP.$cljs$core$truth_$$($G__34717_k$jscomp$474$$)?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$145$$,$G__34717_k$jscomp$474$$):$path$jscomp$145$$;return $cljs$spec$alpha$op_explain$$.$cljs$core$IFn$_invoke$arity$6$?$cljs$spec$alpha$op_explain$$.$cljs$core$IFn$_invoke$arity$6$($G__34715_form__$1$jscomp$5$$,$pred$jscomp$74$$,$G__34717_k$jscomp$474$$,$via__$1$$,$in$$jscomp$55$$,$input$jscomp$57$$):$cljs$spec$alpha$op_explain$$($G__34715_form__$1$jscomp$5$$,$pred$jscomp$74$$,$G__34717_k$jscomp$474$$,$via__$1$$,$in$$jscomp$55$$,
$input$jscomp$57$$)},function(){var $or__5025__auto__$jscomp$242$$=$APP.$cljs$core$seq$$($ks$jscomp$51$$);return $or__5025__auto__$jscomp$242$$?$or__5025__auto__$jscomp$242$$:$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$(null)}(),function(){var $or__5025__auto__$jscomp$243$$=$APP.$cljs$core$seq$$($forms$jscomp$32$$);return $or__5025__auto__$jscomp$243$$?$or__5025__auto__$jscomp$243$$:$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$(null)}(),$ps$jscomp$19$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1090$cljs_DOT_spec_DOT_alpha_SLASH_rep$$,
$op$jscomp$7$$))return $G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$=$map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$===$p2$jscomp$14$$?$forms$jscomp$32$$:$cljs$spec$alpha$op_describe$$($map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$),$cljs$spec$alpha$op_explain$$.$cljs$core$IFn$_invoke$arity$6$?$cljs$spec$alpha$op_explain$$.$cljs$core$IFn$_invoke$arity$6$($G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$,
$map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$,$path$jscomp$145$$,$via__$1$$,$in$$jscomp$55$$,$input$jscomp$57$$):$cljs$spec$alpha$op_explain$$($G__34699_G__34727_form$jscomp$142_k$jscomp$473_path__$1$jscomp$3_temp__5823__auto__$jscomp$87$$,$map__34695_p$jscomp$105_p1$jscomp$20_pkfs_pred$jscomp$73$$,$path$jscomp$145$$,$via__$1$$,$in$$jscomp$55$$,$input$jscomp$57$$);throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($op$jscomp$7$$)].join(""));}return null};
$APP.$JSCompiler_prototypeAlias$$=$cljs$spec$alpha$t_cljs$0spec$0alpha34794$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_34796$$,$meta34795__$1$$){return new $cljs$spec$alpha$t_cljs$0spec$0alpha34794$$(this.re,this.$gfn$,$meta34795__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta34795$};$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Specize$specize_STAR_$arity$1$=function(){return this};
$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Specize$specize_STAR_$arity$2$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$conform_STAR_$arity$2$=function($_$jscomp$860$$,$x$jscomp$931$$){return $x$jscomp$931$$==null||$APP.$cljs$core$sequential_QMARK_$$($x$jscomp$931$$)?$cljs$spec$alpha$re_conform$$(this.re,$APP.$cljs$core$seq$$($x$jscomp$931$$)):$cljs$cst$978$cljs_DOT_spec_DOT_alpha_SLASH_invalid$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$explain_STAR_$arity$5$=function($_$jscomp$862_or__5025__auto__$jscomp$inline_3923_re$jscomp$inline_3905$$,$JSCompiler_temp$jscomp$516_path$jscomp$148$$,$via$jscomp$18$$,$in$$jscomp$57$$,$p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$){if($p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$==null||$APP.$cljs$core$sequential_QMARK_$$($p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$))a:{$_$jscomp$862_or__5025__auto__$jscomp$inline_3923_re$jscomp$inline_3905$$=
this.re;var $G__35537$jscomp$inline_3922_i__$1$jscomp$inline_3910_i__$2$jscomp$inline_3919_input$jscomp$inline_3906$$=$APP.$cljs$core$seq$$($p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$);$p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$=$APP.$cljs$core$seq$$($G__35537$jscomp$inline_3922_i__$1$jscomp$inline_3910_i__$2$jscomp$inline_3919_input$jscomp$inline_3906$$);$APP.$cljs$core$first$$($p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$);
$APP.$cljs$core$next$$($p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$);$p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$=$_$jscomp$862_or__5025__auto__$jscomp$inline_3923_re$jscomp$inline_3905$$;var $G__34780__$1$jscomp$inline_3909_G__35536$jscomp$inline_3921_data__$1$jscomp$inline_3918_vec__34788$jscomp$inline_3912$$=$G__35537$jscomp$inline_3922_i__$1$jscomp$inline_3910_i__$2$jscomp$inline_3919_input$jscomp$inline_3906$$;
for($G__35537$jscomp$inline_3922_i__$1$jscomp$inline_3910_i__$2$jscomp$inline_3919_input$jscomp$inline_3906$$=0;;){var $seq__34789$jscomp$inline_3913_seq__34789__$1$jscomp$inline_3915_xs__$1$jscomp$inline_3917$$=$APP.$cljs$core$seq$$($G__34780__$1$jscomp$inline_3909_G__35536$jscomp$inline_3921_data__$1$jscomp$inline_3918_vec__34788$jscomp$inline_3912$$),$first__34790$jscomp$inline_3914_temp__5823__auto__$jscomp$inline_3920_x__$1$jscomp$inline_3916$$=$APP.$cljs$core$first$$($seq__34789$jscomp$inline_3913_seq__34789__$1$jscomp$inline_3915_xs__$1$jscomp$inline_3917$$);
$seq__34789$jscomp$inline_3913_seq__34789__$1$jscomp$inline_3915_xs__$1$jscomp$inline_3917$$=$APP.$cljs$core$next$$($seq__34789$jscomp$inline_3913_seq__34789__$1$jscomp$inline_3915_xs__$1$jscomp$inline_3917$$);if($APP.$cljs$core$empty_QMARK_$$($G__34780__$1$jscomp$inline_3909_G__35536$jscomp$inline_3921_data__$1$jscomp$inline_3918_vec__34788$jscomp$inline_3912$$)){$JSCompiler_temp$jscomp$516_path$jscomp$148$$=$APP.$cljs$core$truth_$$($cljs$spec$alpha$accept_nil_QMARK_$$($p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$))?
null:$cljs$spec$alpha$op_explain$$($cljs$spec$alpha$op_describe$$($p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$),$p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$,$JSCompiler_temp$jscomp$516_path$jscomp$148$$,$via$jscomp$18$$,$in$$jscomp$57$$,null);break a}$first__34790$jscomp$inline_3914_temp__5823__auto__$jscomp$inline_3920_x__$1$jscomp$inline_3916$$=$cljs$spec$alpha$deriv$$($p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$,
$first__34790$jscomp$inline_3914_temp__5823__auto__$jscomp$inline_3920_x__$1$jscomp$inline_3916$$);if($APP.$cljs$core$truth_$$($first__34790$jscomp$inline_3914_temp__5823__auto__$jscomp$inline_3920_x__$1$jscomp$inline_3916$$))$G__34780__$1$jscomp$inline_3909_G__35536$jscomp$inline_3921_data__$1$jscomp$inline_3918_vec__34788$jscomp$inline_3912$$=$seq__34789$jscomp$inline_3913_seq__34789__$1$jscomp$inline_3915_xs__$1$jscomp$inline_3917$$,$G__35537$jscomp$inline_3922_i__$1$jscomp$inline_3910_i__$2$jscomp$inline_3919_input$jscomp$inline_3906$$+=
1,$p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$=$first__34790$jscomp$inline_3914_temp__5823__auto__$jscomp$inline_3920_x__$1$jscomp$inline_3916$$;else{if($cljs$spec$alpha$accept_QMARK_$$($p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$)){$JSCompiler_temp$jscomp$516_path$jscomp$148$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$975$cljs_DOT_spec_DOT_alpha_SLASH_op$$.$cljs$core$IFn$_invoke$arity$1$($p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$),
$cljs$cst$1089$cljs_DOT_spec_DOT_alpha_SLASH_pcat$$)?$cljs$spec$alpha$op_explain$$($cljs$spec$alpha$op_describe$$($p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$),$p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$,$JSCompiler_temp$jscomp$516_path$jscomp$148$$,$via$jscomp$18$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($in$$jscomp$57$$,$G__35537$jscomp$inline_3922_i__$1$jscomp$inline_3910_i__$2$jscomp$inline_3919_input$jscomp$inline_3906$$),
$APP.$cljs$core$seq$$($G__34780__$1$jscomp$inline_3909_G__35536$jscomp$inline_3921_data__$1$jscomp$inline_3918_vec__34788$jscomp$inline_3912$$)):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$296$path$$,$JSCompiler_temp$jscomp$516_path$jscomp$148$$,$APP.$cljs$cst$984$reason$$,"Extra input",$APP.$cljs$cst$351$pred$$,$cljs$spec$alpha$op_describe$$($_$jscomp$862_or__5025__auto__$jscomp$inline_3923_re$jscomp$inline_3905$$),
$APP.$cljs$cst$108$val$$,$G__34780__$1$jscomp$inline_3909_G__35536$jscomp$inline_3921_data__$1$jscomp$inline_3918_vec__34788$jscomp$inline_3912$$,$APP.$cljs$cst$143$via$$,$via$jscomp$18$$,$APP.$cljs$cst$297$in$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($in$$jscomp$57$$,$G__35537$jscomp$inline_3922_i__$1$jscomp$inline_3910_i__$2$jscomp$inline_3919_input$jscomp$inline_3906$$)],null)],null);break a}$_$jscomp$862_or__5025__auto__$jscomp$inline_3923_re$jscomp$inline_3905$$=$cljs$spec$alpha$op_explain$$($cljs$spec$alpha$op_describe$$($p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$),
$p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$,$JSCompiler_temp$jscomp$516_path$jscomp$148$$,$via$jscomp$18$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($in$$jscomp$57$$,$G__35537$jscomp$inline_3922_i__$1$jscomp$inline_3910_i__$2$jscomp$inline_3919_input$jscomp$inline_3906$$),$APP.$cljs$core$seq$$($G__34780__$1$jscomp$inline_3909_G__35536$jscomp$inline_3921_data__$1$jscomp$inline_3918_vec__34788$jscomp$inline_3912$$));$JSCompiler_temp$jscomp$516_path$jscomp$148$$=
$APP.$cljs$core$truth_$$($_$jscomp$862_or__5025__auto__$jscomp$inline_3923_re$jscomp$inline_3905$$)?$_$jscomp$862_or__5025__auto__$jscomp$inline_3923_re$jscomp$inline_3905$$:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$296$path$$,$JSCompiler_temp$jscomp$516_path$jscomp$148$$,$APP.$cljs$cst$984$reason$$,"Extra input",$APP.$cljs$cst$351$pred$$,$cljs$spec$alpha$op_describe$$($p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$),
$APP.$cljs$cst$108$val$$,$G__34780__$1$jscomp$inline_3909_G__35536$jscomp$inline_3921_data__$1$jscomp$inline_3918_vec__34788$jscomp$inline_3912$$,$APP.$cljs$cst$143$via$$,$via$jscomp$18$$,$APP.$cljs$cst$297$in$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($in$$jscomp$57$$,$G__35537$jscomp$inline_3922_i__$1$jscomp$inline_3910_i__$2$jscomp$inline_3919_input$jscomp$inline_3906$$)],null)],null);break a}}$JSCompiler_temp$jscomp$516_path$jscomp$148$$=void 0}else $JSCompiler_temp$jscomp$516_path$jscomp$148$$=
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$296$path$$,$JSCompiler_temp$jscomp$516_path$jscomp$148$$,$APP.$cljs$cst$351$pred$$,$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$List$$(null,$cljs$cst$1105$cljs_DOT_core_SLASH_fn$$,null,1,null),new $APP.$cljs$core$List$$(null,
$APP.$cljs$core$vec$$($APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$979$_PERCENT_$$,null,1,null))))),null,1,null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$List$$(null,$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$List$$(null,
$cljs$cst$1106$cljs_DOT_core_SLASH_or$$,null,1,null),new $APP.$cljs$core$List$$(null,$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$List$$(null,$cljs$cst$1107$cljs_DOT_core_SLASH_nil_QMARK_$$,null,1,null),new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$979$_PERCENT_$$,null,1,null)))),null,1,null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$List$$(null,
$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$List$$(null,$cljs$cst$1108$cljs_DOT_core_SLASH_sequential_QMARK_$$,null,1,null),new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$979$_PERCENT_$$,null,1,null)))),null,1,null)])))),null,1,null)])))),$APP.$cljs$cst$108$val$$,$p__$1$jscomp$inline_3908_p__$2$jscomp$inline_3911_seq__34782$jscomp$inline_3907_x$jscomp$933$$,$APP.$cljs$cst$143$via$$,
$via$jscomp$18$$,$APP.$cljs$cst$297$in$$,$in$$jscomp$57$$],null)],null);return $JSCompiler_temp$jscomp$516_path$jscomp$148$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$spec$alpha$Spec$with_gen_STAR_$arity$2$=function($_$jscomp$864$$,$gfn__$1$jscomp$9$$){return $cljs$spec$alpha$regex_spec_impl$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$spec$alpha$regex_spec_impl$$.$cljs$core$IFn$_invoke$arity$2$(this.re,$gfn__$1$jscomp$9$$):$cljs$spec$alpha$regex_spec_impl$$(this.re,$gfn__$1$jscomp$9$$)};
$cljs$spec$alpha$def_impl$$($cljs$cst$1119$cljs_DOT_spec_DOT_alpha_SLASH_kvs__GT_map$$,$APP.$cljs$core$list$$($cljs$cst$1120$cljs_DOT_spec_DOT_alpha_SLASH_conformer$$,$APP.$cljs$core$list$$($APP.$cljs$cst$162$fn_STAR_$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1121$p1__34845_SHARP_$$],null),$APP.$cljs$core$list$$($cljs$cst$1122$cljs_DOT_core_SLASH_zipmap$$,$APP.$cljs$core$list$$($cljs$cst$1123$cljs_DOT_core_SLASH_map$$,$cljs$cst$1124$cljs_DOT_spec_DOT_alpha_SLASH_k$$,
$cljs$cst$1121$p1__34845_SHARP_$$),$APP.$cljs$core$list$$($cljs$cst$1123$cljs_DOT_core_SLASH_map$$,$cljs$cst$1125$cljs_DOT_spec_DOT_alpha_SLASH_v$$,$cljs$cst$1121$p1__34845_SHARP_$$))),$APP.$cljs$core$list$$($APP.$cljs$cst$162$fn_STAR_$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1126$p1__34846_SHARP_$$],null),$APP.$cljs$core$list$$($cljs$cst$1123$cljs_DOT_core_SLASH_map$$,$APP.$cljs$core$list$$($cljs$cst$1105$cljs_DOT_core_SLASH_fn$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$355$k$$,$cljs$cst$57$v$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$1124$cljs_DOT_spec_DOT_alpha_SLASH_k$$,$cljs$cst$355$k$$,$cljs$cst$1125$cljs_DOT_spec_DOT_alpha_SLASH_v$$,$cljs$cst$57$v$$],null)),$cljs$cst$1126$p1__34846_SHARP_$$))),$cljs$spec$alpha$spec_impl$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$cljs$core$list$$($cljs$cst$1120$cljs_DOT_spec_DOT_alpha_SLASH_conformer$$,
$APP.$cljs$core$list$$($cljs$cst$1105$cljs_DOT_core_SLASH_fn$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$979$_PERCENT_$$],null),$APP.$cljs$core$list$$($cljs$cst$1122$cljs_DOT_core_SLASH_zipmap$$,$APP.$cljs$core$list$$($cljs$cst$1123$cljs_DOT_core_SLASH_map$$,$cljs$cst$1124$cljs_DOT_spec_DOT_alpha_SLASH_k$$,$APP.$cljs$cst$979$_PERCENT_$$),$APP.$cljs$core$list$$($cljs$cst$1123$cljs_DOT_core_SLASH_map$$,$cljs$cst$1125$cljs_DOT_spec_DOT_alpha_SLASH_v$$,
$APP.$cljs$cst$979$_PERCENT_$$))),$APP.$cljs$core$list$$($cljs$cst$1105$cljs_DOT_core_SLASH_fn$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$979$_PERCENT_$$],null),$APP.$cljs$core$list$$($cljs$cst$1123$cljs_DOT_core_SLASH_map$$,$APP.$cljs$core$list$$($cljs$cst$1105$cljs_DOT_core_SLASH_fn$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$355$k$$,$cljs$cst$57$v$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$1124$cljs_DOT_spec_DOT_alpha_SLASH_k$$,$cljs$cst$355$k$$,$cljs$cst$1125$cljs_DOT_spec_DOT_alpha_SLASH_v$$,$cljs$cst$57$v$$],null)),$APP.$cljs$cst$979$_PERCENT_$$))),function($p1__34845_SHARP_$$){return $APP.$cljs$core$zipmap$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1124$cljs_DOT_spec_DOT_alpha_SLASH_k$$,$p1__34845_SHARP_$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1125$cljs_DOT_spec_DOT_alpha_SLASH_v$$,
$p1__34845_SHARP_$$))},null,!0,function($p1__34846_SHARP_$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__34859_v$jscomp$267$$){var $k$jscomp$478$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34859_v$jscomp$267$$,0,null);$p__34859_v$jscomp$267$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__34859_v$jscomp$267$$,1,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$1124$cljs_DOT_spec_DOT_alpha_SLASH_k$$,$k$jscomp$478$$,
$cljs$cst$1125$cljs_DOT_spec_DOT_alpha_SLASH_v$$,$p__34859_v$jscomp$267$$],null)},$p1__34846_SHARP_$$)}));var $app$common$exceptions$sensitive_fields$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1134$invitation_token$$,null,$APP.$cljs$cst$1135$old_password$$,null,$APP.$cljs$cst$751$password$$,null,$APP.$cljs$cst$1136$token$$,null],null),null);var $shadow$js$shim$module$0date_fns$0format$0default$$=shadow$bridge("date-fns/format").default;var $shadow$js$shim$module$0date_fns$0formatISO$0default$$=shadow$bridge("date-fns/formatISO").default;var $shadow$js$shim$module$0date_fns$0setDefaultOptions$0default$$=shadow$bridge("date-fns/setDefaultOptions").default;var $shadow$js$shim$module$0date_fns$0differenceInMilliseconds$0default$$=shadow$bridge("date-fns/differenceInMilliseconds").default;var $shadow$js$shim$module$0date_fns$0formatDistanceToNowStrict$0default$$=shadow$bridge("date-fns/formatDistanceToNowStrict").default;var $shadow$js$shim$module$0date_fns$0add$0default$$=shadow$bridge("date-fns/add").default;var $shadow$js$shim$module$0date_fns$0sub$0default$$=shadow$bridge("date-fns/sub").default;var $shadow$js$shim$module$0date_fns$0parseISO$0default$$=shadow$bridge("date-fns/parseISO").default;var $shadow$js$shim$module$0date_fns$0locale$0ar_SA$0default$$=shadow$bridge("date-fns/locale/ar-SA").default;var $shadow$js$shim$module$0date_fns$0locale$0ca$0default$$=shadow$bridge("date-fns/locale/ca").default;var $shadow$js$shim$module$0date_fns$0locale$0cs$0default$$=shadow$bridge("date-fns/locale/cs").default;var $shadow$js$shim$module$0date_fns$0locale$0de$0default$$=shadow$bridge("date-fns/locale/de").default;var $shadow$js$shim$module$0date_fns$0locale$0el$0default$$=shadow$bridge("date-fns/locale/el").default;var $shadow$js$shim$module$0date_fns$0locale$0en_US$0default$$=shadow$bridge("date-fns/locale/en-US").default;var $shadow$js$shim$module$0date_fns$0locale$0es$0default$$=shadow$bridge("date-fns/locale/es").default;var $shadow$js$shim$module$0date_fns$0locale$0eu$0default$$=shadow$bridge("date-fns/locale/eu").default;var $shadow$js$shim$module$0date_fns$0locale$0fa_IR$0default$$=shadow$bridge("date-fns/locale/fa-IR").default;var $shadow$js$shim$module$0date_fns$0locale$0fr$0default$$=shadow$bridge("date-fns/locale/fr").default;var $shadow$js$shim$module$0date_fns$0locale$0fr_CA$0default$$=shadow$bridge("date-fns/locale/fr-CA").default;var $shadow$js$shim$module$0date_fns$0locale$0gl$0default$$=shadow$bridge("date-fns/locale/gl").default;var $shadow$js$shim$module$0date_fns$0locale$0he$0default$$=shadow$bridge("date-fns/locale/he").default;var $shadow$js$shim$module$0date_fns$0locale$0hr$0default$$=shadow$bridge("date-fns/locale/hr").default;var $shadow$js$shim$module$0date_fns$0locale$0id$0default$$=shadow$bridge("date-fns/locale/id").default;var $shadow$js$shim$module$0date_fns$0locale$0it$0default$$=shadow$bridge("date-fns/locale/it").default;var $shadow$js$shim$module$0date_fns$0locale$0ja$0default$$=shadow$bridge("date-fns/locale/ja").default;var $shadow$js$shim$module$0date_fns$0locale$0ko$0default$$=shadow$bridge("date-fns/locale/ko").default;var $shadow$js$shim$module$0date_fns$0locale$0lv$0default$$=shadow$bridge("date-fns/locale/lv").default;var $shadow$js$shim$module$0date_fns$0locale$0nb$0default$$=shadow$bridge("date-fns/locale/nb").default;var $shadow$js$shim$module$0date_fns$0locale$0nl$0default$$=shadow$bridge("date-fns/locale/nl").default;var $shadow$js$shim$module$0date_fns$0locale$0pl$0default$$=shadow$bridge("date-fns/locale/pl").default;var $shadow$js$shim$module$0date_fns$0locale$0pt$0default$$=shadow$bridge("date-fns/locale/pt").default;var $shadow$js$shim$module$0date_fns$0locale$0pt_BR$0default$$=shadow$bridge("date-fns/locale/pt-BR").default;var $shadow$js$shim$module$0date_fns$0locale$0ro$0default$$=shadow$bridge("date-fns/locale/ro").default;var $shadow$js$shim$module$0date_fns$0locale$0ru$0default$$=shadow$bridge("date-fns/locale/ru").default;var $shadow$js$shim$module$0date_fns$0locale$0tr$0default$$=shadow$bridge("date-fns/locale/tr").default;var $shadow$js$shim$module$0date_fns$0locale$0uk$0default$$=shadow$bridge("date-fns/locale/uk").default;var $shadow$js$shim$module$0date_fns$0locale$0zh_CN$0default$$=shadow$bridge("date-fns/locale/zh-CN").default;$APP.$app$common$time$format_inst$$=function $app$common$time$format_inst$$($var_args$jscomp$654$$){switch(arguments.length){case 1:return $app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$1$=function($v$jscomp$272$$){return $APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$272$$,$APP.$cljs$cst$1138$iso$$)};
$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$=function($v$jscomp$273$$,$fmt$$){if($v$jscomp$273$$!=null)switch($fmt$$ instanceof $APP.$cljs$core$Keyword$$?$fmt$$.$fqn$:null){case "iso":case "iso8601":return $shadow$js$shim$module$0date_fns$0formatISO$0default$$($v$jscomp$273$$);case "iso-date":return $shadow$js$shim$module$0date_fns$0formatISO$0default$$($v$jscomp$273$$,{representation:"date"});case "rfc1123":case "http":return $shadow$js$shim$module$0date_fns$0format$0default$$($v$jscomp$273$$,
"EEE, dd LLL yyyy HH:mm:ss 'GMT'");case "time-24-simple":return $shadow$js$shim$module$0date_fns$0format$0default$$($v$jscomp$273$$,"HH:mm");case "date-full":return $shadow$js$shim$module$0date_fns$0format$0default$$($v$jscomp$273$$,"PPP");case "localized-date":return $shadow$js$shim$module$0date_fns$0format$0default$$($v$jscomp$273$$,"PPP");case "localized-time":return $shadow$js$shim$module$0date_fns$0format$0default$$($v$jscomp$273$$,"p");case "localized-date-time":return $shadow$js$shim$module$0date_fns$0format$0default$$($v$jscomp$273$$,
"PPP . p");default:if(typeof $fmt$$==="string")return $shadow$js$shim$module$0date_fns$0format$0default$$($v$jscomp$273$$,$fmt$$);throw Error("unpexted format");}else return null};$APP.$app$common$time$format_inst$$.$cljs$lang$maxFixedArity$=2;
var $app$common$time$locales$$={fr:$shadow$js$shim$module$0date_fns$0locale$0fr$0default$$,ja:$shadow$js$shim$module$0date_fns$0locale$0ja$0default$$,el:$shadow$js$shim$module$0date_fns$0locale$0el$0default$$,hr:$shadow$js$shim$module$0date_fns$0locale$0hr$0default$$,es:$shadow$js$shim$module$0date_fns$0locale$0es$0default$$,pt:$shadow$js$shim$module$0date_fns$0locale$0pt$0default$$,pt_pt:$shadow$js$shim$module$0date_fns$0locale$0pt$0default$$,ca:$shadow$js$shim$module$0date_fns$0locale$0ca$0default$$,
ro:$shadow$js$shim$module$0date_fns$0locale$0ro$0default$$,tr:$shadow$js$shim$module$0date_fns$0locale$0tr$0default$$,cs:$shadow$js$shim$module$0date_fns$0locale$0cs$0default$$,fr_ca:$shadow$js$shim$module$0date_fns$0locale$0fr_CA$0default$$,pt_br:$shadow$js$shim$module$0date_fns$0locale$0pt_BR$0default$$,ko:$shadow$js$shim$module$0date_fns$0locale$0ko$0default$$,pl:$shadow$js$shim$module$0date_fns$0locale$0pl$0default$$,it:$shadow$js$shim$module$0date_fns$0locale$0it$0default$$,es_es:$shadow$js$shim$module$0date_fns$0locale$0es$0default$$,
ja_jp:$shadow$js$shim$module$0date_fns$0locale$0ja$0default$$,en:$shadow$js$shim$module$0date_fns$0locale$0en_US$0default$$,nl:$shadow$js$shim$module$0date_fns$0locale$0nl$0default$$,de:$shadow$js$shim$module$0date_fns$0locale$0de$0default$$,id:$shadow$js$shim$module$0date_fns$0locale$0id$0default$$,ar:$shadow$js$shim$module$0date_fns$0locale$0ar_SA$0default$$,uk:$shadow$js$shim$module$0date_fns$0locale$0uk$0default$$,nb:$shadow$js$shim$module$0date_fns$0locale$0nb$0default$$,en_us:$shadow$js$shim$module$0date_fns$0locale$0en_US$0default$$,
ru:$shadow$js$shim$module$0date_fns$0locale$0ru$0default$$,gl:$shadow$js$shim$module$0date_fns$0locale$0gl$0default$$,he:$shadow$js$shim$module$0date_fns$0locale$0he$0default$$,"zh-cn":$shadow$js$shim$module$0date_fns$0locale$0zh_CN$0default$$,fa_ir:$shadow$js$shim$module$0date_fns$0locale$0fa_IR$0default$$,nb_no:$shadow$js$shim$module$0date_fns$0locale$0nb$0default$$,lv:$shadow$js$shim$module$0date_fns$0locale$0lv$0default$$,eu:$shadow$js$shim$module$0date_fns$0locale$0eu$0default$$,fa:$shadow$js$shim$module$0date_fns$0locale$0fa_IR$0default$$};
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$,$APP.$cljs$cst$351$pred$$,$APP.$app$common$time$inst_QMARK_$$,$cljs$cst$415$type_properties$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$937$decode_SLASH_string$$,$APP.$cljs$cst$938$decode_SLASH_json$$,$APP.$cljs$cst$939$title$$,$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,
$cljs$cst$941$encode_SLASH_json$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,$cljs$cst$869$gen_SLASH_gen$$,$APP.$cljs$cst$882$error_SLASH_message$$,$cljs$cst$943$encode_SLASH_string$$],[$APP.$app$common$time$inst$$,$APP.$app$common$time$inst$$,"instant","iso",$APP.$app$common$time$format_inst$$,"string",$app$common$schema$generators$fmap$$(function($i$jscomp$372$$){return $APP.$app$common$time$minus$$($i$jscomp$372$$)},$app$common$schema$generators$small_int$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$338$min$$,
0]))),"should be an instant",$APP.$app$common$time$format_inst$$])],null));Date.prototype.$cljs$core$IEncodeJS$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;Date.prototype.$cljs$core$IEncodeJS$_clj__GT_js$arity$1$=function(){return this};var $promesa$protocols$IPromise$_fmap$dyn_35424$$;
$promesa$protocols$IPromise$_fmap$dyn_35424$$=function(){function $G__35425__3$$($it$jscomp$1$$,$f$jscomp$508$$,$executor$$){var $m__5372__auto__$jscomp$192_m__5374__auto__$jscomp$192$$=$APP.$promesa$protocols$_fmap$$[$APP.$goog$typeOf$$($it$jscomp$1$$==null?null:$it$jscomp$1$$)];if($m__5372__auto__$jscomp$192_m__5374__auto__$jscomp$192$$!=null)return $m__5372__auto__$jscomp$192_m__5374__auto__$jscomp$192$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$192_m__5374__auto__$jscomp$192$$.$cljs$core$IFn$_invoke$arity$3$($it$jscomp$1$$,$f$jscomp$508$$,
$executor$$):$m__5372__auto__$jscomp$192_m__5374__auto__$jscomp$192$$($it$jscomp$1$$,$f$jscomp$508$$,$executor$$);$m__5372__auto__$jscomp$192_m__5374__auto__$jscomp$192$$=$APP.$promesa$protocols$_fmap$$._;if($m__5372__auto__$jscomp$192_m__5374__auto__$jscomp$192$$!=null)return $m__5372__auto__$jscomp$192_m__5374__auto__$jscomp$192$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$192_m__5374__auto__$jscomp$192$$.$cljs$core$IFn$_invoke$arity$3$($it$jscomp$1$$,$f$jscomp$508$$,$executor$$):$m__5372__auto__$jscomp$192_m__5374__auto__$jscomp$192$$($it$jscomp$1$$,
$f$jscomp$508$$,$executor$$);throw $APP.$cljs$core$missing_protocol$$("IPromise.-fmap",$it$jscomp$1$$);}function $G__35425__2$$($it$$,$f$jscomp$507$$){var $m__5372__auto__$jscomp$191_m__5374__auto__$jscomp$191$$=$APP.$promesa$protocols$_fmap$$[$APP.$goog$typeOf$$($it$$==null?null:$it$$)];if($m__5372__auto__$jscomp$191_m__5374__auto__$jscomp$191$$!=null)return $m__5372__auto__$jscomp$191_m__5374__auto__$jscomp$191$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$191_m__5374__auto__$jscomp$191$$.$cljs$core$IFn$_invoke$arity$2$($it$$,
$f$jscomp$507$$):$m__5372__auto__$jscomp$191_m__5374__auto__$jscomp$191$$($it$$,$f$jscomp$507$$);$m__5372__auto__$jscomp$191_m__5374__auto__$jscomp$191$$=$APP.$promesa$protocols$_fmap$$._;if($m__5372__auto__$jscomp$191_m__5374__auto__$jscomp$191$$!=null)return $m__5372__auto__$jscomp$191_m__5374__auto__$jscomp$191$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$191_m__5374__auto__$jscomp$191$$.$cljs$core$IFn$_invoke$arity$2$($it$$,$f$jscomp$507$$):$m__5372__auto__$jscomp$191_m__5374__auto__$jscomp$191$$($it$$,
$f$jscomp$507$$);throw $APP.$cljs$core$missing_protocol$$("IPromise.-fmap",$it$$);}var $G__35425$$=null;$G__35425$$=function($it$jscomp$2$$,$f$jscomp$509$$,$executor$jscomp$1$$){switch(arguments.length){case 2:return $G__35425__2$$.call(this,$it$jscomp$2$$,$f$jscomp$509$$);case 3:return $G__35425__3$$.call(this,$it$jscomp$2$$,$f$jscomp$509$$,$executor$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$G__35425$$.$cljs$core$IFn$_invoke$arity$2$=$G__35425__2$$;$G__35425$$.$cljs$core$IFn$_invoke$arity$3$=
$G__35425__3$$;return $G__35425$$}();$APP.$promesa$protocols$_fmap$$=function $promesa$protocols$_fmap$$($var_args$jscomp$655$$){switch(arguments.length){case 2:return $promesa$protocols$_fmap$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $promesa$protocols$_fmap$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$promesa$protocols$_fmap$$.$cljs$core$IFn$_invoke$arity$2$=function($it$jscomp$3$$,$f$jscomp$510$$){return $it$jscomp$3$$!=null&&$it$jscomp$3$$.$promesa$protocols$IPromise$_fmap$arity$2$!=null?$it$jscomp$3$$.$promesa$protocols$IPromise$_fmap$arity$2$($it$jscomp$3$$,$f$jscomp$510$$):$promesa$protocols$IPromise$_fmap$dyn_35424$$($it$jscomp$3$$,$f$jscomp$510$$)};
$APP.$promesa$protocols$_fmap$$.$cljs$core$IFn$_invoke$arity$3$=function($it$jscomp$4$$,$f$jscomp$511$$,$executor$jscomp$2$$){return $it$jscomp$4$$!=null&&$it$jscomp$4$$.$promesa$protocols$IPromise$_fmap$arity$3$!=null?$it$jscomp$4$$.$promesa$protocols$IPromise$_fmap$arity$3$($it$jscomp$4$$,$f$jscomp$511$$,$executor$jscomp$2$$):$promesa$protocols$IPromise$_fmap$dyn_35424$$($it$jscomp$4$$,$f$jscomp$511$$,$executor$jscomp$2$$)};$APP.$promesa$protocols$_fmap$$.$cljs$lang$maxFixedArity$=3;
var $promesa$protocols$IPromise$_merr$dyn_35433$$=function(){function $G__35434__3$$($it$jscomp$6$$,$f$jscomp$513$$,$executor$jscomp$3$$){var $m__5372__auto__$jscomp$194_m__5374__auto__$jscomp$194$$=$promesa$protocols$_merr$$[$APP.$goog$typeOf$$($it$jscomp$6$$==null?null:$it$jscomp$6$$)];if($m__5372__auto__$jscomp$194_m__5374__auto__$jscomp$194$$!=null)return $m__5372__auto__$jscomp$194_m__5374__auto__$jscomp$194$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$194_m__5374__auto__$jscomp$194$$.$cljs$core$IFn$_invoke$arity$3$($it$jscomp$6$$,
$f$jscomp$513$$,$executor$jscomp$3$$):$m__5372__auto__$jscomp$194_m__5374__auto__$jscomp$194$$($it$jscomp$6$$,$f$jscomp$513$$,$executor$jscomp$3$$);$m__5372__auto__$jscomp$194_m__5374__auto__$jscomp$194$$=$promesa$protocols$_merr$$._;if($m__5372__auto__$jscomp$194_m__5374__auto__$jscomp$194$$!=null)return $m__5372__auto__$jscomp$194_m__5374__auto__$jscomp$194$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$194_m__5374__auto__$jscomp$194$$.$cljs$core$IFn$_invoke$arity$3$($it$jscomp$6$$,$f$jscomp$513$$,
$executor$jscomp$3$$):$m__5372__auto__$jscomp$194_m__5374__auto__$jscomp$194$$($it$jscomp$6$$,$f$jscomp$513$$,$executor$jscomp$3$$);throw $APP.$cljs$core$missing_protocol$$("IPromise.-merr",$it$jscomp$6$$);}function $G__35434__2$$($it$jscomp$5$$,$f$jscomp$512$$){var $m__5372__auto__$jscomp$193_m__5374__auto__$jscomp$193$$=$promesa$protocols$_merr$$[$APP.$goog$typeOf$$($it$jscomp$5$$==null?null:$it$jscomp$5$$)];if($m__5372__auto__$jscomp$193_m__5374__auto__$jscomp$193$$!=null)return $m__5372__auto__$jscomp$193_m__5374__auto__$jscomp$193$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$193_m__5374__auto__$jscomp$193$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$5$$,$f$jscomp$512$$):$m__5372__auto__$jscomp$193_m__5374__auto__$jscomp$193$$($it$jscomp$5$$,$f$jscomp$512$$);$m__5372__auto__$jscomp$193_m__5374__auto__$jscomp$193$$=$promesa$protocols$_merr$$._;if($m__5372__auto__$jscomp$193_m__5374__auto__$jscomp$193$$!=null)return $m__5372__auto__$jscomp$193_m__5374__auto__$jscomp$193$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$193_m__5374__auto__$jscomp$193$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$5$$,
$f$jscomp$512$$):$m__5372__auto__$jscomp$193_m__5374__auto__$jscomp$193$$($it$jscomp$5$$,$f$jscomp$512$$);throw $APP.$cljs$core$missing_protocol$$("IPromise.-merr",$it$jscomp$5$$);}var $G__35434$$=null;$G__35434$$=function($it$jscomp$7$$,$f$jscomp$514$$,$executor$jscomp$4$$){switch(arguments.length){case 2:return $G__35434__2$$.call(this,$it$jscomp$7$$,$f$jscomp$514$$);case 3:return $G__35434__3$$.call(this,$it$jscomp$7$$,$f$jscomp$514$$,$executor$jscomp$4$$)}throw Error("Invalid arity: "+arguments.length);
};$G__35434$$.$cljs$core$IFn$_invoke$arity$2$=$G__35434__2$$;$G__35434$$.$cljs$core$IFn$_invoke$arity$3$=$G__35434__3$$;return $G__35434$$}(),$promesa$protocols$_merr$$=function $promesa$protocols$_merr$$($var_args$jscomp$656$$){switch(arguments.length){case 2:return $promesa$protocols$_merr$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $promesa$protocols$_merr$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$promesa$protocols$_merr$$.$cljs$core$IFn$_invoke$arity$2$=function($it$jscomp$8$$,$f$jscomp$515$$){return $it$jscomp$8$$!=null&&$it$jscomp$8$$.$promesa$protocols$IPromise$_merr$arity$2$!=null?$it$jscomp$8$$.$promesa$protocols$IPromise$_merr$arity$2$($it$jscomp$8$$,$f$jscomp$515$$):$promesa$protocols$IPromise$_merr$dyn_35433$$($it$jscomp$8$$,$f$jscomp$515$$)};
$promesa$protocols$_merr$$.$cljs$core$IFn$_invoke$arity$3$=function($it$jscomp$9$$,$f$jscomp$516$$,$executor$jscomp$5$$){return $it$jscomp$9$$!=null&&$it$jscomp$9$$.$promesa$protocols$IPromise$_merr$arity$3$!=null?$it$jscomp$9$$.$promesa$protocols$IPromise$_merr$arity$3$($it$jscomp$9$$,$f$jscomp$516$$,$executor$jscomp$5$$):$promesa$protocols$IPromise$_merr$dyn_35433$$($it$jscomp$9$$,$f$jscomp$516$$,$executor$jscomp$5$$)};$promesa$protocols$_merr$$.$cljs$lang$maxFixedArity$=3;
var $promesa$protocols$IPromise$_mcat$dyn_35440$$=function(){function $G__35441__3$$($it$jscomp$11$$,$f$jscomp$518$$,$executor$jscomp$6$$){var $m__5372__auto__$jscomp$196_m__5374__auto__$jscomp$196$$=$promesa$protocols$_mcat$$[$APP.$goog$typeOf$$($it$jscomp$11$$==null?null:$it$jscomp$11$$)];if($m__5372__auto__$jscomp$196_m__5374__auto__$jscomp$196$$!=null)return $m__5372__auto__$jscomp$196_m__5374__auto__$jscomp$196$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$196_m__5374__auto__$jscomp$196$$.$cljs$core$IFn$_invoke$arity$3$($it$jscomp$11$$,
$f$jscomp$518$$,$executor$jscomp$6$$):$m__5372__auto__$jscomp$196_m__5374__auto__$jscomp$196$$($it$jscomp$11$$,$f$jscomp$518$$,$executor$jscomp$6$$);$m__5372__auto__$jscomp$196_m__5374__auto__$jscomp$196$$=$promesa$protocols$_mcat$$._;if($m__5372__auto__$jscomp$196_m__5374__auto__$jscomp$196$$!=null)return $m__5372__auto__$jscomp$196_m__5374__auto__$jscomp$196$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$196_m__5374__auto__$jscomp$196$$.$cljs$core$IFn$_invoke$arity$3$($it$jscomp$11$$,
$f$jscomp$518$$,$executor$jscomp$6$$):$m__5372__auto__$jscomp$196_m__5374__auto__$jscomp$196$$($it$jscomp$11$$,$f$jscomp$518$$,$executor$jscomp$6$$);throw $APP.$cljs$core$missing_protocol$$("IPromise.-mcat",$it$jscomp$11$$);}function $G__35441__2$$($it$jscomp$10$$,$f$jscomp$517$$){var $m__5372__auto__$jscomp$195_m__5374__auto__$jscomp$195$$=$promesa$protocols$_mcat$$[$APP.$goog$typeOf$$($it$jscomp$10$$==null?null:$it$jscomp$10$$)];if($m__5372__auto__$jscomp$195_m__5374__auto__$jscomp$195$$!=null)return $m__5372__auto__$jscomp$195_m__5374__auto__$jscomp$195$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$195_m__5374__auto__$jscomp$195$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$10$$,$f$jscomp$517$$):$m__5372__auto__$jscomp$195_m__5374__auto__$jscomp$195$$($it$jscomp$10$$,$f$jscomp$517$$);$m__5372__auto__$jscomp$195_m__5374__auto__$jscomp$195$$=$promesa$protocols$_mcat$$._;if($m__5372__auto__$jscomp$195_m__5374__auto__$jscomp$195$$!=null)return $m__5372__auto__$jscomp$195_m__5374__auto__$jscomp$195$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$195_m__5374__auto__$jscomp$195$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$10$$,
$f$jscomp$517$$):$m__5372__auto__$jscomp$195_m__5374__auto__$jscomp$195$$($it$jscomp$10$$,$f$jscomp$517$$);throw $APP.$cljs$core$missing_protocol$$("IPromise.-mcat",$it$jscomp$10$$);}var $G__35441$$=null;$G__35441$$=function($it$jscomp$12$$,$f$jscomp$519$$,$executor$jscomp$7$$){switch(arguments.length){case 2:return $G__35441__2$$.call(this,$it$jscomp$12$$,$f$jscomp$519$$);case 3:return $G__35441__3$$.call(this,$it$jscomp$12$$,$f$jscomp$519$$,$executor$jscomp$7$$)}throw Error("Invalid arity: "+arguments.length);
};$G__35441$$.$cljs$core$IFn$_invoke$arity$2$=$G__35441__2$$;$G__35441$$.$cljs$core$IFn$_invoke$arity$3$=$G__35441__3$$;return $G__35441$$}(),$promesa$protocols$_mcat$$=function $promesa$protocols$_mcat$$($var_args$jscomp$657$$){switch(arguments.length){case 2:return $promesa$protocols$_mcat$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $promesa$protocols$_mcat$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$promesa$protocols$_mcat$$.$cljs$core$IFn$_invoke$arity$2$=function($it$jscomp$13$$,$f$jscomp$520$$){return $it$jscomp$13$$!=null&&$it$jscomp$13$$.$promesa$protocols$IPromise$_mcat$arity$2$!=null?$it$jscomp$13$$.$promesa$protocols$IPromise$_mcat$arity$2$($it$jscomp$13$$,$f$jscomp$520$$):$promesa$protocols$IPromise$_mcat$dyn_35440$$($it$jscomp$13$$,$f$jscomp$520$$)};
$promesa$protocols$_mcat$$.$cljs$core$IFn$_invoke$arity$3$=function($it$jscomp$14$$,$f$jscomp$521$$,$executor$jscomp$8$$){return $it$jscomp$14$$!=null&&$it$jscomp$14$$.$promesa$protocols$IPromise$_mcat$arity$3$!=null?$it$jscomp$14$$.$promesa$protocols$IPromise$_mcat$arity$3$($it$jscomp$14$$,$f$jscomp$521$$,$executor$jscomp$8$$):$promesa$protocols$IPromise$_mcat$dyn_35440$$($it$jscomp$14$$,$f$jscomp$521$$,$executor$jscomp$8$$)};$promesa$protocols$_mcat$$.$cljs$lang$maxFixedArity$=3;
var $promesa$protocols$IPromise$_fnly$dyn_35456$$=function(){function $G__35457__3$$($it$jscomp$21$$,$f$jscomp$528$$,$executor$jscomp$12$$){var $m__5372__auto__$jscomp$200_m__5374__auto__$jscomp$200$$=$promesa$protocols$_fnly$$[$APP.$goog$typeOf$$($it$jscomp$21$$==null?null:$it$jscomp$21$$)];if($m__5372__auto__$jscomp$200_m__5374__auto__$jscomp$200$$!=null)return $m__5372__auto__$jscomp$200_m__5374__auto__$jscomp$200$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$200_m__5374__auto__$jscomp$200$$.$cljs$core$IFn$_invoke$arity$3$($it$jscomp$21$$,
$f$jscomp$528$$,$executor$jscomp$12$$):$m__5372__auto__$jscomp$200_m__5374__auto__$jscomp$200$$($it$jscomp$21$$,$f$jscomp$528$$,$executor$jscomp$12$$);$m__5372__auto__$jscomp$200_m__5374__auto__$jscomp$200$$=$promesa$protocols$_fnly$$._;if($m__5372__auto__$jscomp$200_m__5374__auto__$jscomp$200$$!=null)return $m__5372__auto__$jscomp$200_m__5374__auto__$jscomp$200$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$200_m__5374__auto__$jscomp$200$$.$cljs$core$IFn$_invoke$arity$3$($it$jscomp$21$$,
$f$jscomp$528$$,$executor$jscomp$12$$):$m__5372__auto__$jscomp$200_m__5374__auto__$jscomp$200$$($it$jscomp$21$$,$f$jscomp$528$$,$executor$jscomp$12$$);throw $APP.$cljs$core$missing_protocol$$("IPromise.-fnly",$it$jscomp$21$$);}function $G__35457__2$$($it$jscomp$20$$,$f$jscomp$527$$){var $m__5372__auto__$jscomp$199_m__5374__auto__$jscomp$199$$=$promesa$protocols$_fnly$$[$APP.$goog$typeOf$$($it$jscomp$20$$==null?null:$it$jscomp$20$$)];if($m__5372__auto__$jscomp$199_m__5374__auto__$jscomp$199$$!=null)return $m__5372__auto__$jscomp$199_m__5374__auto__$jscomp$199$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$199_m__5374__auto__$jscomp$199$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$20$$,$f$jscomp$527$$):$m__5372__auto__$jscomp$199_m__5374__auto__$jscomp$199$$($it$jscomp$20$$,$f$jscomp$527$$);$m__5372__auto__$jscomp$199_m__5374__auto__$jscomp$199$$=$promesa$protocols$_fnly$$._;if($m__5372__auto__$jscomp$199_m__5374__auto__$jscomp$199$$!=null)return $m__5372__auto__$jscomp$199_m__5374__auto__$jscomp$199$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$199_m__5374__auto__$jscomp$199$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$20$$,
$f$jscomp$527$$):$m__5372__auto__$jscomp$199_m__5374__auto__$jscomp$199$$($it$jscomp$20$$,$f$jscomp$527$$);throw $APP.$cljs$core$missing_protocol$$("IPromise.-fnly",$it$jscomp$20$$);}var $G__35457$$=null;$G__35457$$=function($it$jscomp$22$$,$f$jscomp$529$$,$executor$jscomp$13$$){switch(arguments.length){case 2:return $G__35457__2$$.call(this,$it$jscomp$22$$,$f$jscomp$529$$);case 3:return $G__35457__3$$.call(this,$it$jscomp$22$$,$f$jscomp$529$$,$executor$jscomp$13$$)}throw Error("Invalid arity: "+
arguments.length);};$G__35457$$.$cljs$core$IFn$_invoke$arity$2$=$G__35457__2$$;$G__35457$$.$cljs$core$IFn$_invoke$arity$3$=$G__35457__3$$;return $G__35457$$}(),$promesa$protocols$_fnly$$=function $promesa$protocols$_fnly$$($var_args$jscomp$659$$){switch(arguments.length){case 2:return $promesa$protocols$_fnly$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $promesa$protocols$_fnly$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$promesa$protocols$_fnly$$.$cljs$core$IFn$_invoke$arity$2$=function($it$jscomp$23$$,$f$jscomp$530$$){return $it$jscomp$23$$!=null&&$it$jscomp$23$$.$promesa$protocols$IPromise$_fnly$arity$2$!=null?$it$jscomp$23$$.$promesa$protocols$IPromise$_fnly$arity$2$($it$jscomp$23$$,$f$jscomp$530$$):$promesa$protocols$IPromise$_fnly$dyn_35456$$($it$jscomp$23$$,$f$jscomp$530$$)};
$promesa$protocols$_fnly$$.$cljs$core$IFn$_invoke$arity$3$=function($it$jscomp$24$$,$f$jscomp$531$$,$executor$jscomp$14$$){return $it$jscomp$24$$!=null&&$it$jscomp$24$$.$promesa$protocols$IPromise$_fnly$arity$3$!=null?$it$jscomp$24$$.$promesa$protocols$IPromise$_fnly$arity$3$($it$jscomp$24$$,$f$jscomp$531$$,$executor$jscomp$14$$):$promesa$protocols$IPromise$_fnly$dyn_35456$$($it$jscomp$24$$,$f$jscomp$531$$,$executor$jscomp$14$$)};$promesa$protocols$_fnly$$.$cljs$lang$maxFixedArity$=3;
var $promesa$protocols$IPromise$_then$dyn_35468$$=function(){function $G__35469__3$$($it$jscomp$26$$,$f$jscomp$533$$,$executor$jscomp$15$$){var $m__5372__auto__$jscomp$202_m__5374__auto__$jscomp$202$$=$promesa$protocols$_then$$[$APP.$goog$typeOf$$($it$jscomp$26$$==null?null:$it$jscomp$26$$)];if($m__5372__auto__$jscomp$202_m__5374__auto__$jscomp$202$$!=null)return $m__5372__auto__$jscomp$202_m__5374__auto__$jscomp$202$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$202_m__5374__auto__$jscomp$202$$.$cljs$core$IFn$_invoke$arity$3$($it$jscomp$26$$,
$f$jscomp$533$$,$executor$jscomp$15$$):$m__5372__auto__$jscomp$202_m__5374__auto__$jscomp$202$$($it$jscomp$26$$,$f$jscomp$533$$,$executor$jscomp$15$$);$m__5372__auto__$jscomp$202_m__5374__auto__$jscomp$202$$=$promesa$protocols$_then$$._;if($m__5372__auto__$jscomp$202_m__5374__auto__$jscomp$202$$!=null)return $m__5372__auto__$jscomp$202_m__5374__auto__$jscomp$202$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$202_m__5374__auto__$jscomp$202$$.$cljs$core$IFn$_invoke$arity$3$($it$jscomp$26$$,
$f$jscomp$533$$,$executor$jscomp$15$$):$m__5372__auto__$jscomp$202_m__5374__auto__$jscomp$202$$($it$jscomp$26$$,$f$jscomp$533$$,$executor$jscomp$15$$);throw $APP.$cljs$core$missing_protocol$$("IPromise.-then",$it$jscomp$26$$);}function $G__35469__2$$($it$jscomp$25$$,$f$jscomp$532$$){var $m__5372__auto__$jscomp$201_m__5374__auto__$jscomp$201$$=$promesa$protocols$_then$$[$APP.$goog$typeOf$$($it$jscomp$25$$==null?null:$it$jscomp$25$$)];if($m__5372__auto__$jscomp$201_m__5374__auto__$jscomp$201$$!=null)return $m__5372__auto__$jscomp$201_m__5374__auto__$jscomp$201$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$201_m__5374__auto__$jscomp$201$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$25$$,$f$jscomp$532$$):$m__5372__auto__$jscomp$201_m__5374__auto__$jscomp$201$$($it$jscomp$25$$,$f$jscomp$532$$);$m__5372__auto__$jscomp$201_m__5374__auto__$jscomp$201$$=$promesa$protocols$_then$$._;if($m__5372__auto__$jscomp$201_m__5374__auto__$jscomp$201$$!=null)return $m__5372__auto__$jscomp$201_m__5374__auto__$jscomp$201$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$201_m__5374__auto__$jscomp$201$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$25$$,
$f$jscomp$532$$):$m__5372__auto__$jscomp$201_m__5374__auto__$jscomp$201$$($it$jscomp$25$$,$f$jscomp$532$$);throw $APP.$cljs$core$missing_protocol$$("IPromise.-then",$it$jscomp$25$$);}var $G__35469$$=null;$G__35469$$=function($it$jscomp$27$$,$f$jscomp$534$$,$executor$jscomp$16$$){switch(arguments.length){case 2:return $G__35469__2$$.call(this,$it$jscomp$27$$,$f$jscomp$534$$);case 3:return $G__35469__3$$.call(this,$it$jscomp$27$$,$f$jscomp$534$$,$executor$jscomp$16$$)}throw Error("Invalid arity: "+
arguments.length);};$G__35469$$.$cljs$core$IFn$_invoke$arity$2$=$G__35469__2$$;$G__35469$$.$cljs$core$IFn$_invoke$arity$3$=$G__35469__3$$;return $G__35469$$}(),$promesa$protocols$_then$$=function $promesa$protocols$_then$$($var_args$jscomp$660$$){switch(arguments.length){case 2:return $promesa$protocols$_then$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $promesa$protocols$_then$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$promesa$protocols$_then$$.$cljs$core$IFn$_invoke$arity$2$=function($it$jscomp$28$$,$f$jscomp$535$$){return $it$jscomp$28$$!=null&&$it$jscomp$28$$.$promesa$protocols$IPromise$_then$arity$2$!=null?$it$jscomp$28$$.$promesa$protocols$IPromise$_then$arity$2$($it$jscomp$28$$,$f$jscomp$535$$):$promesa$protocols$IPromise$_then$dyn_35468$$($it$jscomp$28$$,$f$jscomp$535$$)};
$promesa$protocols$_then$$.$cljs$core$IFn$_invoke$arity$3$=function($it$jscomp$29$$,$f$jscomp$536$$,$executor$jscomp$17$$){return $it$jscomp$29$$!=null&&$it$jscomp$29$$.$promesa$protocols$IPromise$_then$arity$3$!=null?$it$jscomp$29$$.$promesa$protocols$IPromise$_then$arity$3$($it$jscomp$29$$,$f$jscomp$536$$,$executor$jscomp$17$$):$promesa$protocols$IPromise$_then$dyn_35468$$($it$jscomp$29$$,$f$jscomp$536$$,$executor$jscomp$17$$)};$promesa$protocols$_then$$.$cljs$lang$maxFixedArity$=3;var $$jscomp$scope$84173391$0$PENDING$$,$$jscomp$scope$84173391$1$RESOLVED$$,$$jscomp$scope$84173391$2$REJECTED$$,$$jscomp$scope$84173391$3$QUEUE$$,$$jscomp$scope$84173391$4$STATE$$,$$jscomp$scope$84173391$5$VALUE$$,$$jscomp$scope$84173391$6$RESOLVE_TYPE_FLATTEN$$,$$jscomp$scope$84173391$7$RESOLVE_TYPE_BIND$$,$$jscomp$scope$84173391$8$RESOLVE_TYPE_MAP$$,$$jscomp$scope$84173391$9$defaultResolveMapHandler$$,$$jscomp$scope$84173391$10$defaultResolveBindHandler$$,$$jscomp$scope$84173391$12$defaultRejectHandler$$,
$$jscomp$scope$84173391$13$CancellationError$$,$$jscomp$scope$84173391$15$nextTick$$,$$jscomp$scope$84173391$28$NULL_PROMISE$$;$$jscomp$scope$84173391$0$PENDING$$=Symbol("state/pending");$$jscomp$scope$84173391$1$RESOLVED$$=Symbol("state/resolved");$$jscomp$scope$84173391$2$REJECTED$$=Symbol("state/rejected");$$jscomp$scope$84173391$3$QUEUE$$=Symbol("queue");$$jscomp$scope$84173391$4$STATE$$=Symbol("state");$$jscomp$scope$84173391$5$VALUE$$=Symbol("value");
$$jscomp$scope$84173391$6$RESOLVE_TYPE_FLATTEN$$=Symbol("resolve-type/flatten");$$jscomp$scope$84173391$7$RESOLVE_TYPE_BIND$$=Symbol("resolve-type/bind");$$jscomp$scope$84173391$8$RESOLVE_TYPE_MAP$$=Symbol("resolve-type/map");$$jscomp$scope$84173391$9$defaultResolveMapHandler$$=$v$jscomp$288$$=>$v$jscomp$288$$;$$jscomp$scope$84173391$10$defaultResolveBindHandler$$=$v$jscomp$289$$=>$APP.$promesa$impl$promise$resolved$$($v$jscomp$289$$);
$$jscomp$scope$84173391$12$defaultRejectHandler$$=$c$jscomp$218$$=>{throw $c$jscomp$218$$;};$$jscomp$scope$84173391$13$CancellationError$$=class extends Error{};
$APP.$$jscomp$scope$84173391$14$PromiseImpl$$=class{constructor($val$jscomp$127$$){this[$$jscomp$scope$84173391$3$QUEUE$$]=[];this[$$jscomp$scope$84173391$4$STATE$$]=$$jscomp$scope$84173391$0$PENDING$$;this[$$jscomp$scope$84173391$5$VALUE$$]=void 0;$val$jscomp$127$$!==void 0&&$$jscomp$scope$84173391$27$transition$$(this,$$jscomp$scope$84173391$1$RESOLVED$$,$val$jscomp$127$$)}get state(){return this[$$jscomp$scope$84173391$4$STATE$$]}get value(){return this[$$jscomp$scope$84173391$5$VALUE$$]}then($resolve$jscomp$2$$,
$reject$$){const $deferred$jscomp$1$$=new $APP.$$jscomp$scope$84173391$14$PromiseImpl$$;this[$$jscomp$scope$84173391$3$QUEUE$$].push({type:$$jscomp$scope$84173391$6$RESOLVE_TYPE_FLATTEN$$,resolve:$resolve$jscomp$2$$??$$jscomp$scope$84173391$9$defaultResolveMapHandler$$,reject:$reject$$??$$jscomp$scope$84173391$12$defaultRejectHandler$$,complete:$$jscomp$scope$84173391$23$completeDeferredFn$$($deferred$jscomp$1$$)});$$jscomp$scope$84173391$24$process$$(this);return $deferred$jscomp$1$$}catch($reject$jscomp$1$$){return this.then(null,
$reject$jscomp$1$$)}finally($f$jscomp$538$$){this[$$jscomp$scope$84173391$3$QUEUE$$].push({type:$$jscomp$scope$84173391$6$RESOLVE_TYPE_FLATTEN$$,resolve:()=>$f$jscomp$538$$(),reject:()=>$f$jscomp$538$$(),complete:()=>null});return this}handle($fn$jscomp$16$$,$resolveType$$){$resolveType$$=$resolveType$$??$$jscomp$scope$84173391$8$RESOLVE_TYPE_MAP$$;this[$$jscomp$scope$84173391$3$QUEUE$$].push({type:$resolveType$$,resolve:$$jscomp$scope$84173391$9$defaultResolveMapHandler$$,reject:$$jscomp$scope$84173391$9$defaultResolveMapHandler$$,
complete:$fn$jscomp$16$$});$$jscomp$scope$84173391$24$process$$(this)}resolve($value$jscomp$341$$){this[$$jscomp$scope$84173391$4$STATE$$]===$$jscomp$scope$84173391$0$PENDING$$&&$$jscomp$scope$84173391$27$transition$$(this,$$jscomp$scope$84173391$1$RESOLVED$$,$value$jscomp$341$$);return null}reject($cause$jscomp$11$$){this[$$jscomp$scope$84173391$4$STATE$$]===$$jscomp$scope$84173391$0$PENDING$$&&$$jscomp$scope$84173391$27$transition$$(this,$$jscomp$scope$84173391$2$REJECTED$$,$cause$jscomp$11$$);
return null}cancel(){this.reject(new $$jscomp$scope$84173391$13$CancellationError$$("promise cancelled"))}};
$$jscomp$scope$84173391$15$nextTick$$=(()=>{if(typeof $APP.$goog$global$$.Promise==="function"){const $resolved$$=Promise.resolve(null);return function($f$jscomp$539$$,$p$jscomp$112$$){$resolved$$.then(()=>$f$jscomp$539$$($p$jscomp$112$$))}}return typeof $APP.$goog$global$$.setImmediate==="function"?$APP.$goog$global$$.setImmediate:typeof $APP.$goog$global$$.setTimeout==="function"?($f$jscomp$540$$,$p$jscomp$113$$)=>$APP.$goog$global$$.setTimeout($f$jscomp$540$$,0,$p$jscomp$113$$):($f$jscomp$541$$,
$p$jscomp$114$$)=>$f$jscomp$541$$.call(this,$p$jscomp$114$$)})();$$jscomp$scope$84173391$28$NULL_PROMISE$$=new $APP.$$jscomp$scope$84173391$14$PromiseImpl$$(null);var $promesa$exec$default_scheduler$$=new $APP.$cljs$core$Delay$$(function(){return $promesa$exec$scheduled_executor$$.$cljs$core$IFn$_invoke$arity$0$?$promesa$exec$scheduled_executor$$.$cljs$core$IFn$_invoke$arity$0$():$promesa$exec$scheduled_executor$$()}),$promesa$exec$default_executor$$=new $APP.$cljs$core$Delay$$(function(){return $promesa$exec$microtask_executor$$.$cljs$core$IFn$_invoke$arity$0$?$promesa$exec$microtask_executor$$.$cljs$core$IFn$_invoke$arity$0$():$promesa$exec$microtask_executor$$()}),
$promesa$exec$default_current_thread_executor$$=new $APP.$cljs$core$Delay$$(function(){return $promesa$exec$current_thread_executor$$.$cljs$core$IFn$_invoke$arity$0$?$promesa$exec$current_thread_executor$$.$cljs$core$IFn$_invoke$arity$0$():$promesa$exec$current_thread_executor$$()}),$promesa$exec$default_cached_executor$$=new $APP.$cljs$core$Delay$$(function(){return $promesa$exec$default_executor$$});
$promesa$exec$Scheduler$$.prototype.$promesa$protocols$IScheduler$_schedule_BANG_$arity$3$=function($_$jscomp$890$$,$ms$jscomp$11$$,$f$jscomp$557$$){var $df$$=new $APP.$$jscomp$scope$84173391$14$PromiseImpl$$,$tid$$=setTimeout(function(){try{return $APP.$promesa$protocols$_resolve_BANG_$$($df$$,$f$jscomp$557$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$557$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$557$$())}catch($e35630$$){return $APP.$promesa$protocols$_reject_BANG_$$($df$$,$e35630$$)}},$ms$jscomp$11$$);
$promesa$protocols$_fnly$$($df$$,function($___$2$jscomp$70$$,$c$jscomp$222$$){return $APP.$cljs$core$truth_$$($c$jscomp$222$$ instanceof $$jscomp$scope$84173391$13$CancellationError$$)?clearTimeout($tid$$):null});return $df$$};$promesa$exec$t_promesa$0exec35644$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_35646$$,$meta35645__$1$$){return new $promesa$exec$t_promesa$0exec35644$$($meta35645__$1$$)};$promesa$exec$t_promesa$0exec35644$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta35645$};
$promesa$exec$t_promesa$0exec35644$$.prototype.$promesa$protocols$IExecutor$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$promesa$exec$t_promesa$0exec35644$$.prototype.$promesa$protocols$IExecutor$_exec_BANG_$arity$2$=function($this$$jscomp$488$$,$f$jscomp$558$$){try{return $f$jscomp$558$$.$cljs$core$IFn$_invoke$arity$0$?$f$jscomp$558$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$558$$(),null}catch($e35648$$){return null}};
$promesa$exec$t_promesa$0exec35651$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_35653$$,$meta35652__$1$$){return new $promesa$exec$t_promesa$0exec35651$$($meta35652__$1$$)};$promesa$exec$t_promesa$0exec35651$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta35652$};$promesa$exec$t_promesa$0exec35651$$.prototype.$promesa$protocols$IExecutor$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$promesa$exec$t_promesa$0exec35651$$.prototype.$promesa$protocols$IExecutor$_exec_BANG_$arity$2$=function($this$$jscomp$491$$,$f$jscomp$561$$){return $$jscomp$scope$84173391$15$nextTick$$($f$jscomp$561$$)};var $app$common$logging$log_record$$,$app$common$logging$_STAR_default_executor_STAR_$$,$app$common$logging$reserved_props$$;$app$common$logging$log_record$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$app$common$logging$_STAR_default_executor_STAR_$$=new $APP.$cljs$core$Delay$$(function(){return $promesa$exec$microtask_executor$$()});$APP.$app$common$logging$loggers$$=new Map;
$app$common$logging$reserved_props$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1153$app_DOT_common_DOT_logging_SLASH_context$$,null,$cljs$cst$145$cause$$,null,$cljs$cst$1154$app_DOT_common_DOT_logging_SLASH_sync_QMARK_$$,null,$cljs$cst$1155$app_DOT_common_DOT_logging_SLASH_logger$$,null,$cljs$cst$1156$app_DOT_common_DOT_logging_SLASH_level$$,null],null),null);
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$(function($n$jscomp$141$$){return function($rf$jscomp$13$$){var $a$jscomp$165$$=new $cljs$core$ArrayList$$;return function(){function $G__29185__2$$($result$jscomp$56$$,$input$jscomp$34_v$jscomp$72$$){$a$jscomp$165$$.add($input$jscomp$34_v$jscomp$72$$);return $n$jscomp$141$$===$a$jscomp$165$$.size()?($input$jscomp$34_v$jscomp$72$$=$APP.$cljs$core$vec$$($a$jscomp$165$$.$arr$),$a$jscomp$165$$.clear(),$rf$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$?
$rf$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$56$$,$input$jscomp$34_v$jscomp$72$$):$rf$jscomp$13$$($result$jscomp$56$$,$input$jscomp$34_v$jscomp$72$$)):$result$jscomp$56$$}function $G__29185__1$$($JSCompiler_temp$jscomp$532_result$jscomp$55_result__$1$jscomp$1$$){if(!$APP.$cljs$core$truth_$$($a$jscomp$165$$.isEmpty())){var $v$jscomp$inline_3984$$=$APP.$cljs$core$vec$$($a$jscomp$165$$.$arr$);$a$jscomp$165$$.clear();$JSCompiler_temp$jscomp$532_result$jscomp$55_result__$1$jscomp$1$$=
$cljs$core$unreduced$$($rf$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$532_result$jscomp$55_result__$1$jscomp$1$$,$v$jscomp$inline_3984$$):$rf$jscomp$13$$($JSCompiler_temp$jscomp$532_result$jscomp$55_result__$1$jscomp$1$$,$v$jscomp$inline_3984$$))}return $rf$jscomp$13$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$13$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$532_result$jscomp$55_result__$1$jscomp$1$$):$rf$jscomp$13$$($JSCompiler_temp$jscomp$532_result$jscomp$55_result__$1$jscomp$1$$)}
function $G__29185__0$$(){return $rf$jscomp$13$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$13$$.$cljs$core$IFn$_invoke$arity$0$():$rf$jscomp$13$$()}var $G__29185$$=null;$G__29185$$=function($result$jscomp$57$$,$input$jscomp$35$$){switch(arguments.length){case 0:return $G__29185__0$$.call(this);case 1:return $G__29185__1$$.call(this,$result$jscomp$57$$);case 2:return $G__29185__2$$.call(this,$result$jscomp$57$$,$input$jscomp$35$$)}throw Error("Invalid arity: "+arguments.length);};$G__29185$$.$cljs$core$IFn$_invoke$arity$0$=
$G__29185__0$$;$G__29185$$.$cljs$core$IFn$_invoke$arity$1$=$G__29185__1$$;$G__29185$$.$cljs$core$IFn$_invoke$arity$2$=$G__29185__2$$;return $G__29185$$}()}}(2),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$vec$$),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p__42586$$){var $k$jscomp$482$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__42586$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__42586$$,1,null);return $APP.$cljs$core$contains_QMARK_$$($app$common$logging$reserved_props$$,
$k$jscomp$482$$)}));
$app$common$schema$validator$$(new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1157$app_DOT_common_DOT_logging_SLASH_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1158$app_DOT_common_DOT_logging_SLASH_props$$,$APP.$cljs$cst$418$any$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1155$app_DOT_common_DOT_logging_SLASH_logger$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1159$app_DOT_common_DOT_logging_SLASH_timestamp$$,$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$1156$app_DOT_common_DOT_logging_SLASH_level$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$499$enum$$,$APP.$cljs$cst$144$trace$$,$APP.$cljs$cst$1160$debug$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$1162$warn$$,$APP.$cljs$cst$849$error$$,$cljs$cst$1163$fatal$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1164$app_DOT_common_DOT_logging_SLASH_message$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$APP.$cljs$core$delay_QMARK_$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1165$app_DOT_common_DOT_logging_SLASH_cause$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$APP.$app$common$exceptions$exception_QMARK_$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1153$app_DOT_common_DOT_logging_SLASH_context$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,$APP.$cljs$cst$221$keyword$$,$APP.$cljs$cst$418$any$$],null)],null)],null)],null));
$cljs$core$_add_watch$$($app$common$logging$log_record$$,$cljs$cst$1167$app_DOT_common_DOT_logging_SLASH_default$$,function($_$jscomp$895_trace$$,$___$1$jscomp$596_cause$jscomp$23_data_42710$$,$___$2$jscomp$71_logger$jscomp$4_message__$1$$,$G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$){var $G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$=$APP.$cljs$core$__destructure_map$$($G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$);
$___$2$jscomp$71_logger$jscomp$4_message__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$,$cljs$cst$1155$app_DOT_common_DOT_logging_SLASH_logger$$);$G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$,
$cljs$cst$1158$app_DOT_common_DOT_logging_SLASH_props$$);var $G__42696_chunk__42619_42678_level$jscomp$37_n_42701$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$,$cljs$cst$1156$app_DOT_common_DOT_logging_SLASH_level$$);$___$1$jscomp$596_cause$jscomp$23_data_42710$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$,
$cljs$cst$1165$app_DOT_common_DOT_logging_SLASH_cause$$);$_$jscomp$895_trace$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$,$cljs$cst$1166$app_DOT_common_DOT_logging_SLASH_trace$$);var $message$jscomp$48_n_42683$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$,$cljs$cst$1164$app_DOT_common_DOT_logging_SLASH_message$$);
if($APP.$app$common$logging$enabled_QMARK_$$($___$2$jscomp$71_logger$jscomp$4_message__$1$$,$G__42696_chunk__42619_42678_level$jscomp$37_n_42701$$)){$G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$="font-weight: 600; color: "+($app$common$logging$level__GT_color$$($G__42696_chunk__42619_42678_level$jscomp$37_n_42701$$)??"");var $G__42642_42703_G__42642_42704__$1_i__42621_42680_mstyles_type_42700$$="font-weight: 300; color: "+($app$common$logging$level__GT_color$$($G__42696_chunk__42619_42678_level$jscomp$37_n_42701$$)??
""),$ts$jscomp$8_v_42684_vec__42635_42681$$=$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$time$now$$(),"kk:mm:ss.SSSS");$___$2$jscomp$71_logger$jscomp$4_message__$1$$="%c"+($app$common$logging$level__GT_name$$($G__42696_chunk__42619_42678_level$jscomp$37_n_42701$$)??"")+" "+($ts$jscomp$8_v_42684_vec__42635_42681$$??"")+" ["+($___$2$jscomp$71_logger$jscomp$4_message__$1$$??"")+"] %c"+($APP.$cljs$core$_deref$$($message$jscomp$48_n_42683$$)??"");console.group($___$2$jscomp$71_logger$jscomp$4_message__$1$$,
$G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$,$G__42642_42703_G__42642_42704__$1_i__42621_42680_mstyles_type_42700$$);$G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$=$APP.$cljs$core$seq$$($app$common$logging$get_special_props$$($G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$));
$G__42696_chunk__42619_42678_level$jscomp$37_n_42701$$=null;for($G__42642_42703_G__42642_42704__$1_i__42621_42680_mstyles_type_42700$$=$G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$=0;;)if($G__42642_42703_G__42642_42704__$1_i__42621_42680_mstyles_type_42700$$<$G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$){$ts$jscomp$8_v_42684_vec__42635_42681$$=$G__42696_chunk__42619_42678_level$jscomp$37_n_42701$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$G__42642_42703_G__42642_42704__$1_i__42621_42680_mstyles_type_42700$$);var $G__42638_42685_G__42638_42686__$1_type_42682$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ts$jscomp$8_v_42684_vec__42635_42681$$,0,null);$message$jscomp$48_n_42683$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ts$jscomp$8_v_42684_vec__42635_42681$$,1,null);$ts$jscomp$8_v_42684_vec__42635_42681$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ts$jscomp$8_v_42684_vec__42635_42681$$,2,
null);$G__42638_42685_G__42638_42686__$1_type_42682$$=$G__42638_42685_G__42638_42686__$1_type_42682$$ instanceof $APP.$cljs$core$Keyword$$?$G__42638_42685_G__42638_42686__$1_type_42682$$.$fqn$:null;switch($G__42638_42685_G__42638_42686__$1_type_42682$$){case "js":console.log($message$jscomp$48_n_42683$$,$ts$jscomp$8_v_42684_vec__42635_42681$$);break;case "error":$ts$jscomp$8_v_42684_vec__42635_42681$$ instanceof $APP.$cljs$core$ExceptionInfo$$?console.error($message$jscomp$48_n_42683$$,$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$ts$jscomp$8_v_42684_vec__42635_42681$$]))):
console.error($message$jscomp$48_n_42683$$,$ts$jscomp$8_v_42684_vec__42635_42681$$);break;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__42638_42685_G__42638_42686__$1_type_42682$$)].join(""));}$G__42642_42703_G__42642_42704__$1_i__42621_42680_mstyles_type_42700$$+=1}else if($G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$=$APP.$cljs$core$seq$$($G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$))$G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$=
$APP.$cljs$core$_chunked_first$$($G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$),$G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$=$APP.$cljs$core$_chunked_rest$$($G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$),
$G__42696_chunk__42619_42678_level$jscomp$37_n_42701$$=$G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$,$G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$=$APP.$cljs$core$count$$($G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$);else{$G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$=$APP.$cljs$core$first$$($G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$);
$G__42642_42703_G__42642_42704__$1_i__42621_42680_mstyles_type_42700$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$,0,null);$G__42696_chunk__42619_42678_level$jscomp$37_n_42701$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$,1,null);$G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$,2,null);$G__42642_42703_G__42642_42704__$1_i__42621_42680_mstyles_type_42700$$=$G__42642_42703_G__42642_42704__$1_i__42621_42680_mstyles_type_42700$$ instanceof $APP.$cljs$core$Keyword$$?$G__42642_42703_G__42642_42704__$1_i__42621_42680_mstyles_type_42700$$.$fqn$:null;switch($G__42642_42703_G__42642_42704__$1_i__42621_42680_mstyles_type_42700$$){case "js":console.log($G__42696_chunk__42619_42678_level$jscomp$37_n_42701$$,
$G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$);break;case "error":$G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$ instanceof $APP.$cljs$core$ExceptionInfo$$?console.error($G__42696_chunk__42619_42678_level$jscomp$37_n_42701$$,$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$]))):
console.error($G__42696_chunk__42619_42678_level$jscomp$37_n_42701$$,$G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$);break;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__42642_42703_G__42642_42704__$1_i__42621_42680_mstyles_type_42700$$)].join(""));}$G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$=
$APP.$cljs$core$next$$($G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$);$G__42696_chunk__42619_42678_level$jscomp$37_n_42701$$=null;$G__42697_c__5548__auto___42694_count__42620_42679_hstyles_map__42613__$1_v_42702_vec__42639_42699$$=0}$G__42642_42703_G__42642_42704__$1_i__42621_42680_mstyles_type_42700$$=0}else break;$APP.$app$common$exceptions$exception_QMARK_$$($___$1$jscomp$596_cause$jscomp$23_data_42710$$)&&
($___$1$jscomp$596_cause$jscomp$23_data_42710$$=$APP.$cljs$core$ex_data$$($___$1$jscomp$596_cause$jscomp$23_data_42710$$),$G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$=$cljs$cst$650$explain$$.$cljs$core$IFn$_invoke$arity$1$($___$1$jscomp$596_cause$jscomp$23_data_42710$$),$G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$=
$APP.$cljs$core$truth_$$($G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$)?$G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$:$app$common$exceptions$explain$$($___$1$jscomp$596_cause$jscomp$23_data_42710$$),$APP.$cljs$core$truth_$$($G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$)&&
(console.log("Explain:"),console.log($G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$)),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($___$1$jscomp$596_cause$jscomp$23_data_42710$$)?$APP.$cljs$core$not$$($G__42695_explain_42711_or__5025__auto__$jscomp$inline_11541_p__42612_props$jscomp$51_seq__42618_42677_seq__42618_42693__$1_temp__5825__auto___42692$$):$___$1$jscomp$596_cause$jscomp$23_data_42710$$)&&
(console.log("Data:"),console.log($app$common$pprint$pprint_str$$($___$1$jscomp$596_cause$jscomp$23_data_42710$$))),console.log($APP.$cljs$core$_deref$$($_$jscomp$895_trace$$)));return console.groupEnd($___$2$jscomp$71_logger$jscomp$4_message__$1$$)}return null});$APP.$app$common$flags$_STAR_current_STAR_$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$;
$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$1180$email_blacklist$$,null,$cljs$cst$1181$log_emails$$,null,$cljs$cst$1182$email_whitelist$$,null,$cljs$cst$1183$smtp_debug$$,null,$cljs$cst$1184$smtp$$,null,$cljs$cst$1185$email_verification$$,null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,12,[$cljs$cst$1168$login_with_password$$,
null,$cljs$cst$1169$login_with_google$$,null,$cljs$cst$1170$login_with_gitlab$$,null,$cljs$cst$1171$login_with_custom_sso$$,null,$APP.$cljs$cst$1172$login$$,null,$cljs$cst$1173$login_with_github$$,null,$cljs$cst$1174$oidc_registration$$,null,$cljs$cst$1175$login_with_oidc$$,null,$cljs$cst$1176$log_invitation_tokens$$,null,$APP.$cljs$cst$1177$access_tokens$$,null,$APP.$cljs$cst$1178$registration$$,null,$cljs$cst$1179$login_with_ldap$$,null],null),null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,61,[$APP.$cljs$cst$1186$subscriptions_old$$,null,$APP.$cljs$cst$1187$demo_warning$$,null,$cljs$cst$1188$backend_openapi_doc$$,null,$APP.$cljs$cst$1189$dashboard_templates_section$$,null,$APP.$cljs$cst$1190$cors$$,null,$APP.$cljs$cst$1191$token_shadow$$,null,$cljs$cst$1192$perf_logs$$,null,$APP.$cljs$cst$1193$stroke_path$$,null,$cljs$cst$1194$soft_file_schema_validation$$,null,$cljs$cst$1195$google_fonts_provider$$,null,$cljs$cst$1196$exporter_svgo$$,null,
$APP.$cljs$cst$1197$background_blur$$,null,$APP.$cljs$cst$1198$render_switch$$,null,$APP.$cljs$cst$1199$audit_log$$,null,$cljs$cst$1200$strict_session_cookies$$,null,$cljs$cst$1201$sec_fetch_metadata_middleware$$,null,$cljs$cst$1202$backend_api_doc$$,null,$cljs$cst$1203$audit_log_gc$$,null,$cljs$cst$1204$secure_session_cookies$$,null,$cljs$cst$1205$render_wasm_info$$,null,$cljs$cst$1206$soft_file_validation$$,null,$APP.$cljs$cst$1207$demo_users$$,null,$cljs$cst$1208$file_schema_validation$$,null,
$cljs$cst$1209$backend_svgo$$,null,$cljs$cst$1210$urepl_server$$,null,$cljs$cst$1211$v2_migration$$,null,$APP.$cljs$cst$1212$token_base_font_size$$,null,$APP.$cljs$cst$1213$token_color$$,null,$APP.$cljs$cst$1214$token_import_from_library$$,null,$APP.$cljs$cst$1215$webhooks$$,null,$cljs$cst$1216$rpc_rlimit$$,null,$cljs$cst$1217$audit_log_archive$$,null,$cljs$cst$1218$client_header_check_middleware$$,null,$cljs$cst$1219$redis_cache$$,null,$cljs$cst$1220$inspect_styles$$,null,$cljs$cst$1221$soft_rpc_rlimit$$,
null,$APP.$cljs$cst$1222$onboarding$$,null,$APP.$cljs$cst$1223$subscriptions$$,null,$cljs$cst$1224$token_tokenscript$$,null,$cljs$cst$1225$quotes$$,null,$cljs$cst$1226$backend_worker$$,null,$APP.$cljs$cst$1227$user_feedback$$,null,$cljs$cst$1228$rpc_climit$$,null,$cljs$cst$1229$auto_file_snapshot$$,null,$APP.$cljs$cst$1230$telemetry$$,null,$APP.$cljs$cst$1231$terms_and_privacy_checkbox$$,null,$cljs$cst$1232$nrepl_server$$,null,$APP.$cljs$cst$1233$nitrate$$,null,$cljs$cst$1234$render_wasm_dpr$$,null,
$cljs$cst$1235$audit_log_logger$$,null,$APP.$cljs$cst$1236$mcp$$,null,$APP.$cljs$cst$1237$component_thumbnails$$,null,$cljs$cst$1238$tiered_file_data_storage$$,null,$APP.$cljs$cst$1239$token_combobox$$,null,$cljs$cst$1240$file_validation$$,null,$cljs$cst$1241$soft_quotes$$,null,$cljs$cst$1242$prepl_server$$,null,$APP.$cljs$cst$1243$token_typography_row$$,null,$cljs$cst$1244$frontend_svgo$$,null,$APP.$cljs$cst$1245$hide_release_modal$$,null,$cljs$cst$1246$transit_readable_response$$,null],null),null)]));
var $app$common$flags$default$0$$=new $APP.$cljs$core$PersistentVector$$(null,24,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1247$enable_registration$$,$cljs$cst$1248$enable_login_with_password$$,$cljs$cst$1249$enable_export_file_v3$$,$cljs$cst$1250$enable_frontend_svgo$$,$cljs$cst$1251$enable_exporter_svgo$$,$cljs$cst$1252$enable_backend_svgo$$,$cljs$cst$1253$enable_backend_api_doc$$,$cljs$cst$1254$enable_backend_openapi_doc$$,$cljs$cst$1255$enable_backend_worker$$,$cljs$cst$1256$enable_secure_session_cookies$$,
$cljs$cst$1257$enable_email_verification$$,$cljs$cst$1258$enable_onboarding$$,$cljs$cst$1259$enable_dashboard_templates_section$$,$cljs$cst$1260$enable_google_fonts_provider$$,$cljs$cst$1261$enable_component_thumbnails$$,$cljs$cst$1262$enable_render_wasm_dpr$$,$cljs$cst$1263$enable_token_color$$,$cljs$cst$1264$enable_token_shadow$$,$cljs$cst$1265$enable_inspect_styles$$,$cljs$cst$1266$enable_feature_fdata_objects_map$$,$cljs$cst$1267$enable_feature_render_wasm$$,$cljs$cst$1268$enable_token_import_from_library$$,
$cljs$cst$1269$enable_render_switch$$,$cljs$cst$1270$enable_render_wasm_info$$],null);var $app$common$version$version_re$$=/^(([A-Za-z]+)\-?)?((\d+)\.(\d+)\.(\d+))(\-?((RC|DEV)(\d+)?))?(\-?(\d+))?(\-?g(\w+))?$/;var $cljs_bean$core$lookup_sentinel$$={},$cljs_bean$core$empty_map$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;$APP.$JSCompiler_prototypeAlias$$=$cljs_bean$core$TransientBean$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($G__40139__$jscomp$897$$,$k$jscomp$489$$){if(this.$editable_QMARK_$)return $G__40139__$jscomp$897$$=this.$obj$[this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$?this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$489$$):this.$key__GT_prop$($k$jscomp$489$$)],this.$recursive_QMARK_$?$cljs_bean$core$__GT_val$$($G__40139__$jscomp$897$$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform):$G__40139__$jscomp$897$$;
throw Error("lookup after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($_$jscomp$898_ret$jscomp$109$$,$k$jscomp$490$$,$not_found$jscomp$68$$){if(this.$editable_QMARK_$)return $_$jscomp$898_ret$jscomp$109$$=$APP.$module$contents$goog$object_get$$(this.$obj$,this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$?this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$490$$):this.$key__GT_prop$($k$jscomp$490$$),$not_found$jscomp$68$$),this.$recursive_QMARK_$&&$_$jscomp$898_ret$jscomp$109$$!==
$not_found$jscomp$68$$?$cljs_bean$core$__GT_val$$($_$jscomp$898_ret$jscomp$109$$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform):$_$jscomp$898_ret$jscomp$109$$;throw Error("lookup after persistent!");};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.$__cnt$==null?this.$__cnt$=$APP.$cljs$core$count$$($module$contents$goog$object_getKeys$$(this.$obj$)):this.$__cnt$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientCollection$_conj_BANG_$arity$2$=function($G__37048$jscomp$inline_4031_JSCompiler_inline_result$jscomp$539_es$jscomp$inline_4027_tcoll$jscomp$61$$,$G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$){a:{if($APP.$cljs$core$truth_$$(this.$editable_QMARK_$)){if($APP.$cljs$core$map_entry_QMARK_$$($G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$)){$G__37048$jscomp$inline_4031_JSCompiler_inline_result$jscomp$539_es$jscomp$inline_4027_tcoll$jscomp$61$$=
this.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$(null,$APP.$cljs$core$_key$$($G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$),$APP.$cljs$core$_val$$($G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$));break a}if($APP.$cljs$core$vector_QMARK_$$($G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$)){$G__37048$jscomp$inline_4031_JSCompiler_inline_result$jscomp$539_es$jscomp$inline_4027_tcoll$jscomp$61$$=this.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$(null,
$G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$.$cljs$core$IFn$_invoke$arity$1$?$G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$.$cljs$core$IFn$_invoke$arity$1$(0):$G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$(0),$G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$.$cljs$core$IFn$_invoke$arity$1$?$G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$.$cljs$core$IFn$_invoke$arity$1$(1):
$G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$(1));break a}$G__37048$jscomp$inline_4031_JSCompiler_inline_result$jscomp$539_es$jscomp$inline_4027_tcoll$jscomp$61$$=$APP.$cljs$core$seq$$($G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$);for($G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$=this;;){var $e$jscomp$inline_4030_temp__5823__auto__$jscomp$inline_4029$$=$APP.$cljs$core$first$$($G__37048$jscomp$inline_4031_JSCompiler_inline_result$jscomp$539_es$jscomp$inline_4027_tcoll$jscomp$61$$);
if($APP.$cljs$core$truth_$$($e$jscomp$inline_4030_temp__5823__auto__$jscomp$inline_4029$$))$G__37048$jscomp$inline_4031_JSCompiler_inline_result$jscomp$539_es$jscomp$inline_4027_tcoll$jscomp$61$$=$APP.$cljs$core$next$$($G__37048$jscomp$inline_4031_JSCompiler_inline_result$jscomp$539_es$jscomp$inline_4027_tcoll$jscomp$61$$),$G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$=$cljs$core$_assoc_BANG_$$($G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$,$APP.$cljs$core$_key$$($e$jscomp$inline_4030_temp__5823__auto__$jscomp$inline_4029$$),
$APP.$cljs$core$_val$$($e$jscomp$inline_4030_temp__5823__auto__$jscomp$inline_4029$$));else{$G__37048$jscomp$inline_4031_JSCompiler_inline_result$jscomp$539_es$jscomp$inline_4027_tcoll$jscomp$61$$=$G__37049$jscomp$inline_4032_o$jscomp$189_tcoll__$1$jscomp$inline_4028$$;break a}}}else throw Error("conj! after persistent!");$G__37048$jscomp$inline_4031_JSCompiler_inline_result$jscomp$539_es$jscomp$inline_4027_tcoll$jscomp$61$$=void 0}return $G__37048$jscomp$inline_4031_JSCompiler_inline_result$jscomp$539_es$jscomp$inline_4027_tcoll$jscomp$61$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientCollection$_persistent_BANG_$arity$1$=function(){if(this.$editable_QMARK_$)return this.$editable_QMARK_$=!1,new $cljs_bean$core$Bean$$(null,this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,null,this.$__cnt$,null);throw Error("persistent! called twice");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$=function($tcoll$jscomp$63$$,$k$jscomp$491$$,$v$jscomp$302$$){if(this.$editable_QMARK_$){if(!$cljs_bean$core$compatible_key_QMARK_$$($k$jscomp$491$$,this.$prop__GT_key$)||!$cljs_bean$core$compatible_value_QMARK_$$($v$jscomp$302$$,this.$recursive_QMARK_$))return $cljs$core$_assoc_BANG_$$($APP.$cljs$core$transient$0$$($cljs_bean$core$snapshot$$(this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$)),
$k$jscomp$491$$,$v$jscomp$302$$);this.$obj$[this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$?this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$491$$):this.$key__GT_prop$($k$jscomp$491$$)]=this.$recursive_QMARK_$?$cljs_bean$core$unwrap$$($v$jscomp$302$$):$v$jscomp$302$$;this.$__cnt$=null;return this}throw Error("assoc! after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientMap$_dissoc_BANG_$arity$2$=function($tcoll$jscomp$64$$,$k$jscomp$492$$){if(this.$editable_QMARK_$)return delete this.$obj$[this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$?this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$492$$):this.$key__GT_prop$($k$jscomp$492$$)],this.$__cnt$=null,this;throw Error("dissoc! after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$24$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$2216$$,$args40135$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args40135$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($G__40170_k$jscomp$493$$){if(this.$editable_QMARK_$)return $G__40170_k$jscomp$493$$=this.$obj$[this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$?this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$($G__40170_k$jscomp$493$$):this.$key__GT_prop$($G__40170_k$jscomp$493$$)],this.$recursive_QMARK_$?$cljs_bean$core$__GT_val$$($G__40170_k$jscomp$493$$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform):$G__40170_k$jscomp$493$$;
throw Error("lookup after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$494_ret$jscomp$110$$,$not_found$jscomp$69$$){if(this.$editable_QMARK_$)return $k$jscomp$494_ret$jscomp$110$$=$APP.$module$contents$goog$object_get$$(this.$obj$,this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$?this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$494_ret$jscomp$110$$):this.$key__GT_prop$($k$jscomp$494_ret$jscomp$110$$),$not_found$jscomp$69$$),this.$recursive_QMARK_$&&$k$jscomp$494_ret$jscomp$110$$!==
$not_found$jscomp$69$$?$cljs_bean$core$__GT_val$$($k$jscomp$494_ret$jscomp$110$$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform):$k$jscomp$494_ret$jscomp$110$$;throw Error("lookup after persistent!");};$cljs_bean$core$BeanIterator$$.prototype.hasNext=function(){return this.i<this.$cnt$};
$cljs_bean$core$BeanIterator$$.prototype.next=function(){var $ret$jscomp$111$$=$cljs_bean$core$indexed_entry$$(this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,this.$arr$,this.i);this.i+=1;return $ret$jscomp$111$$};$APP.$JSCompiler_prototypeAlias$$=$cljs_bean$core$BeanSeq$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$134$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$134$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__40735$$=null;$G__40735$$=function($x$jscomp$954$$,$start$jscomp$162$$){switch(arguments.length){case 1:return $cljs_bean$from$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$954$$,0);case 2:return $cljs_bean$from$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$954$$,$start$jscomp$162$$)}throw Error("Invalid arity: "+arguments.length);};$G__40735$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$952$$){return $cljs_bean$from$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$952$$,0)};$G__40735$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$953$$,$start$jscomp$161$$){return $cljs_bean$from$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$953$$,$start$jscomp$161$$)};return $G__40735$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__40737__1$$($x$jscomp$955$$){return $cljs_bean$from$cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$955$$,$APP.$cljs$core$count$$(this))}var $G__40737$$=null;$G__40737$$=function($x$jscomp$957$$,$start$jscomp$164$$){switch(arguments.length){case 1:return $G__40737__1$$.call(this,$x$jscomp$957$$);case 2:return $cljs_bean$from$cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$957$$,
$start$jscomp$164$$)}throw Error("Invalid arity: "+arguments.length);};$G__40737$$.$cljs$core$IFn$_invoke$arity$1$=$G__40737__1$$;$G__40737$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$956$$,$start$jscomp$163$$){return $cljs_bean$from$cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$956$$,$start$jscomp$163$$)};return $G__40737$$}();
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($_$jscomp$904_i__$1$jscomp$11$$,$n$jscomp$240$$){$_$jscomp$904_i__$1$jscomp$11$$=$n$jscomp$240$$+this.i;if(0<=$_$jscomp$904_i__$1$jscomp$11$$&&$_$jscomp$904_i__$1$jscomp$11$$<this.$arr$.length)return $cljs_bean$core$indexed_entry$$(this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,this.$arr$,$_$jscomp$904_i__$1$jscomp$11$$);throw Error("Index out of bounds");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($_$jscomp$905_i__$1$jscomp$12$$,$n$jscomp$241$$,$not_found$jscomp$70$$){$_$jscomp$905_i__$1$jscomp$12$$=$n$jscomp$241$$+this.i;return 0<=$_$jscomp$905_i__$1$jscomp$12$$&&$_$jscomp$905_i__$1$jscomp$12$$<this.$arr$.length?$cljs_bean$core$indexed_entry$$(this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,this.$arr$,$_$jscomp$905_i__$1$jscomp$12$$):$not_found$jscomp$70$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$1003$$,$writer$jscomp$133$$,$opts$jscomp$233$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$133$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$233$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs_bean$core$BeanSeq$$(this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,this.$arr$,this.i,this.$meta$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return this.i+1<this.$arr$.length?new $cljs_bean$core$BeanSeq$$(this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,this.$arr$,this.i+1,null):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){var $y__5111__auto__$jscomp$22$$=this.$arr$.length-this.i;return 0>$y__5111__auto__$jscomp$22$$?0:$y__5111__auto__$jscomp$22$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$1005$$,$other$jscomp$135$$){return $cljs_bean$from$cljs$core$equiv_sequential$$(this,$other$jscomp$135$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$1006$$,$f$jscomp$567$$){return $cljs_bean$from$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$f$jscomp$567$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$1007$$,$f$jscomp$568$$,$start$jscomp$165$$){return $cljs_bean$from$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$f$jscomp$568$$,$start$jscomp$165$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return $cljs_bean$core$indexed_entry$$(this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,this.$arr$,this.i)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){return this.i+1<this.$arr$.length?new $cljs_bean$core$BeanSeq$$(this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,this.$arr$,this.i+1,null):$APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$1008$$,$new_meta$jscomp$32$$){return $new_meta$jscomp$32$$===this.$meta$?this:new $cljs_bean$core$BeanSeq$$(this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,this.$arr$,this.i,$new_meta$jscomp$32$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$1009$$,$o$jscomp$190$$){return $APP.$cljs$core$cons$$($o$jscomp$190$$,this)};$APP.$JSCompiler_prototypeAlias$$=$cljs_bean$core$Bean$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$_find$arity$2$=function($_$jscomp$913_v$jscomp$303$$,$k$jscomp$495$$){$_$jscomp$913_v$jscomp$303$$=$APP.$module$contents$goog$object_get$$(this.$obj$,this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$?this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$495$$):this.$key__GT_prop$($k$jscomp$495$$),$cljs_bean$core$lookup_sentinel$$);return $_$jscomp$913_v$jscomp$303$$===$cljs_bean$core$lookup_sentinel$$?null:new $APP.$cljs$core$MapEntry$$($k$jscomp$495$$,
this.$recursive_QMARK_$?$cljs_bean$core$__GT_val$$($_$jscomp$913_v$jscomp$303$$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform):$_$jscomp$913_v$jscomp$303$$,null)};$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$136$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$136$$)};$APP.$JSCompiler_prototypeAlias$$.keys=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$keys$$(this))};
$APP.$JSCompiler_prototypeAlias$$.entries=function(){return $APP.$cljs$core$es6_entries_iterator$$($APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.values=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$vals$$(this))};$APP.$JSCompiler_prototypeAlias$$.has=function($k$jscomp$496$$){return $APP.$cljs$core$contains_QMARK_$$(this,$k$jscomp$496$$)};
$APP.$JSCompiler_prototypeAlias$$.get=function($k$jscomp$497$$,$not_found$jscomp$71$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$497$$,$not_found$jscomp$71$$)};
$APP.$JSCompiler_prototypeAlias$$.forEach=function($f$jscomp$569$$){for(var $G__40779_seq__40260_seq__40260__$1_temp__5825__auto__$jscomp$85$$=$APP.$cljs$core$seq$$(this),$c__5548__auto__$jscomp$9_chunk__40261_vec__40281$$=null,$G__40781_count__40262$$=0,$i__40263$$=0;;)if($i__40263$$<$G__40781_count__40262$$){var $v$jscomp$304_vec__40278$$=$c__5548__auto__$jscomp$9_chunk__40261_vec__40281$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__40263$$),$G__40780_k$jscomp$498$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$304_vec__40278$$,
0,null);$v$jscomp$304_vec__40278$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$304_vec__40278$$,1,null);$f$jscomp$569$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$569$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$304_vec__40278$$,$G__40780_k$jscomp$498$$):$f$jscomp$569$$($v$jscomp$304_vec__40278$$,$G__40780_k$jscomp$498$$);$i__40263$$+=1}else if($G__40779_seq__40260_seq__40260__$1_temp__5825__auto__$jscomp$85$$=$APP.$cljs$core$seq$$($G__40779_seq__40260_seq__40260__$1_temp__5825__auto__$jscomp$85$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__40779_seq__40260_seq__40260__$1_temp__5825__auto__$jscomp$85$$)?
($c__5548__auto__$jscomp$9_chunk__40261_vec__40281$$=$APP.$cljs$core$_chunked_first$$($G__40779_seq__40260_seq__40260__$1_temp__5825__auto__$jscomp$85$$),$G__40779_seq__40260_seq__40260__$1_temp__5825__auto__$jscomp$85$$=$APP.$cljs$core$_chunked_rest$$($G__40779_seq__40260_seq__40260__$1_temp__5825__auto__$jscomp$85$$),$G__40780_k$jscomp$498$$=$c__5548__auto__$jscomp$9_chunk__40261_vec__40281$$,$G__40781_count__40262$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$9_chunk__40261_vec__40281$$),$c__5548__auto__$jscomp$9_chunk__40261_vec__40281$$=
$G__40780_k$jscomp$498$$):($c__5548__auto__$jscomp$9_chunk__40261_vec__40281$$=$APP.$cljs$core$first$$($G__40779_seq__40260_seq__40260__$1_temp__5825__auto__$jscomp$85$$),$G__40780_k$jscomp$498$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$9_chunk__40261_vec__40281$$,0,null),$v$jscomp$304_vec__40278$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$9_chunk__40261_vec__40281$$,1,null),$f$jscomp$569$$.$cljs$core$IFn$_invoke$arity$2$?
$f$jscomp$569$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$304_vec__40278$$,$G__40780_k$jscomp$498$$):$f$jscomp$569$$($v$jscomp$304_vec__40278$$,$G__40780_k$jscomp$498$$),$G__40779_seq__40260_seq__40260__$1_temp__5825__auto__$jscomp$85$$=$APP.$cljs$core$next$$($G__40779_seq__40260_seq__40260__$1_temp__5825__auto__$jscomp$85$$),$c__5548__auto__$jscomp$9_chunk__40261_vec__40281$$=null,$G__40781_count__40262$$=0),$i__40263$$=0;else return null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($G__40285__$jscomp$914$$,$k$jscomp$499$$){$G__40285__$jscomp$914$$=this.$obj$[this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$?this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$499$$):this.$key__GT_prop$($k$jscomp$499$$)];return this.$recursive_QMARK_$?$cljs_bean$core$__GT_val$$($G__40285__$jscomp$914$$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform):$G__40285__$jscomp$914$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($_$jscomp$915_ret$jscomp$112$$,$k$jscomp$500$$,$not_found$jscomp$72$$){$_$jscomp$915_ret$jscomp$112$$=$APP.$module$contents$goog$object_get$$(this.$obj$,this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$?this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$500$$):this.$key__GT_prop$($k$jscomp$500$$),$not_found$jscomp$72$$);return this.$recursive_QMARK_$&&$_$jscomp$915_ret$jscomp$112$$!==$not_found$jscomp$72$$?
$cljs_bean$core$__GT_val$$($_$jscomp$915_ret$jscomp$112$$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform):$_$jscomp$915_ret$jscomp$112$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($_$jscomp$916_x$jscomp$958$$,$f$jscomp$570$$,$init$jscomp$55$$){var $self__$jscomp$2255$$=this;try{var $result$jscomp$120$$=$APP.$cljs$core$volatile_BANG_$$($init$jscomp$55$$);$module$contents$goog$object_forEach$$($self__$jscomp$2255$$.$obj$,function($G__40295$jscomp$inline_11556_v$jscomp$305$$,$G__40294$jscomp$inline_11555_k$jscomp$501$$){var $JSCompiler_temp_const$jscomp$10704_r$jscomp$70$$=$result$jscomp$120$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$;
var $G__40293$jscomp$inline_11554_JSCompiler_inline_result$jscomp$10706$$=$result$jscomp$120$$.$cljs$core$IDeref$_deref$arity$1$(null);$G__40294$jscomp$inline_11555_k$jscomp$501$$=$self__$jscomp$2255$$.$prop__GT_key$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$2255$$.$prop__GT_key$.$cljs$core$IFn$_invoke$arity$1$($G__40294$jscomp$inline_11555_k$jscomp$501$$):$self__$jscomp$2255$$.$prop__GT_key$($G__40294$jscomp$inline_11555_k$jscomp$501$$);$G__40295$jscomp$inline_11556_v$jscomp$305$$=$self__$jscomp$2255$$.$recursive_QMARK_$?
$cljs_bean$core$__GT_val$$($G__40295$jscomp$inline_11556_v$jscomp$305$$,$self__$jscomp$2255$$.$prop__GT_key$,$self__$jscomp$2255$$.$key__GT_prop$,$self__$jscomp$2255$$.transform):$G__40295$jscomp$inline_11556_v$jscomp$305$$;$G__40293$jscomp$inline_11554_JSCompiler_inline_result$jscomp$10706$$=$f$jscomp$570$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$570$$.$cljs$core$IFn$_invoke$arity$3$($G__40293$jscomp$inline_11554_JSCompiler_inline_result$jscomp$10706$$,$G__40294$jscomp$inline_11555_k$jscomp$501$$,
$G__40295$jscomp$inline_11556_v$jscomp$305$$):$f$jscomp$570$$($G__40293$jscomp$inline_11554_JSCompiler_inline_result$jscomp$10706$$,$G__40294$jscomp$inline_11555_k$jscomp$501$$,$G__40295$jscomp$inline_11556_v$jscomp$305$$);$JSCompiler_temp_const$jscomp$10704_r$jscomp$70$$=$JSCompiler_temp_const$jscomp$10704_r$jscomp$70$$.call($result$jscomp$120$$,null,$G__40293$jscomp$inline_11554_JSCompiler_inline_result$jscomp$10706$$);if($cljs$core$reduced_QMARK_$$($JSCompiler_temp_const$jscomp$10704_r$jscomp$70$$))throw $JSCompiler_temp_const$jscomp$10704_r$jscomp$70$$;
return null});return $APP.$cljs$core$_deref$$($result$jscomp$120$$)}catch($e40290$$){$_$jscomp$916_x$jscomp$958$$=$e40290$$;if($cljs$core$reduced_QMARK_$$($_$jscomp$916_x$jscomp$958$$))return $APP.$cljs$core$_deref$$($_$jscomp$916_x$jscomp$958$$);throw $_$jscomp$916_x$jscomp$958$$;}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$1017$$,$writer$jscomp$134$$,$opts$jscomp$234$$){return $cljs$core$print_map$$(this,$APP.$cljs$core$pr_writer$$,$writer$jscomp$134$$,$opts$jscomp$234$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){this.$__arr$==null&&(this.$__arr$=$module$contents$goog$object_getKeys$$(this.$obj$));return new $cljs_bean$core$BeanIterator$$(this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,this.$__arr$,this.$cljs$core$ICounted$_count$arity$1$(null))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs_bean$core$Bean$$(this.$meta$,this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,this.$__arr$,this.$__cnt$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.$__cnt$==null?(this.$__arr$==null&&(this.$__arr$=$module$contents$goog$object_getKeys$$(this.$obj$)),this.$__cnt$=this.$__arr$.length):this.$__cnt$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$33_h__5134__auto____$1$jscomp$33$$=this.$__hash$;return $h__5134__auto__$jscomp$33_h__5134__auto____$1$jscomp$33$$!=null?$h__5134__auto__$jscomp$33_h__5134__auto____$1$jscomp$33$$:this.$__hash$=$h__5134__auto__$jscomp$33_h__5134__auto____$1$jscomp$33$$=$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$1020$$,$other$jscomp$137$$){return $APP.$cljs$core$equiv_map$$(this,$other$jscomp$137$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEditableCollection$_as_transient$arity$1$=function(){return new $cljs_bean$core$TransientBean$$($module$contents$goog$object_clone$$(this.$obj$),this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,this.$__cnt$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return new $cljs_bean$core$Bean$$(this.$meta$,{},this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,[],0,null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$1021$$,$f$jscomp$571$$){return $cljs$core$_reduce$$(this.$cljs$core$ISeqable$_seq$arity$1$(null),$f$jscomp$571$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$1022$$,$f$jscomp$572$$,$start$jscomp$166$$){return this.$cljs$core$IKVReduce$_kv_reduce$arity$3$(null,function($r$jscomp$71$$,$G__40335_k$jscomp$502$$,$v$jscomp$306$$){$G__40335_k$jscomp$502$$=new $APP.$cljs$core$MapEntry$$($G__40335_k$jscomp$502$$,$v$jscomp$306$$,null);return $f$jscomp$572$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$572$$.$cljs$core$IFn$_invoke$arity$2$($r$jscomp$71$$,$G__40335_k$jscomp$502$$):
$f$jscomp$572$$($r$jscomp$71$$,$G__40335_k$jscomp$502$$)},$start$jscomp$166$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($JSCompiler_temp_const$jscomp$549__$jscomp$922$$,$k$jscomp$503$$){$JSCompiler_temp_const$jscomp$549__$jscomp$922$$=this.$meta$;var $G__40344$jscomp$inline_4034$$=$module$contents$goog$object_clone$$(this.$obj$);delete $G__40344$jscomp$inline_4034$$[this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$?this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$503$$):this.$key__GT_prop$($k$jscomp$503$$)];return new $cljs_bean$core$Bean$$($JSCompiler_temp_const$jscomp$549__$jscomp$922$$,
$G__40344$jscomp$inline_4034$$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,null,null,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($JSCompiler_temp_const$jscomp$10708__$jscomp$923$$,$JSCompiler_temp$jscomp$10707_k$jscomp$504$$,$v$jscomp$307$$){if($cljs_bean$core$compatible_key_QMARK_$$($JSCompiler_temp$jscomp$10707_k$jscomp$504$$,this.$prop__GT_key$)&&$cljs_bean$core$compatible_value_QMARK_$$($v$jscomp$307$$,this.$recursive_QMARK_$)){$JSCompiler_temp_const$jscomp$10708__$jscomp$923$$=this.$meta$;var $G__40345$jscomp$inline_11558$$=$module$contents$goog$object_clone$$(this.$obj$);
$G__40345$jscomp$inline_11558$$[this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$?this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10707_k$jscomp$504$$):this.$key__GT_prop$($JSCompiler_temp$jscomp$10707_k$jscomp$504$$)]=this.$recursive_QMARK_$?$cljs_bean$core$unwrap$$($v$jscomp$307$$):$v$jscomp$307$$;$JSCompiler_temp$jscomp$10707_k$jscomp$504$$=new $cljs_bean$core$Bean$$($JSCompiler_temp_const$jscomp$10708__$jscomp$923$$,$G__40345$jscomp$inline_11558$$,this.$prop__GT_key$,
this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,null,null,null)}else $JSCompiler_temp$jscomp$10707_k$jscomp$504$$=$APP.$cljs$core$_assoc$$($APP.$cljs$core$with_meta$$($cljs_bean$core$snapshot$$(this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$),this.$meta$),$JSCompiler_temp$jscomp$10707_k$jscomp$504$$,$v$jscomp$307$$);return $JSCompiler_temp$jscomp$10707_k$jscomp$504$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($coll$jscomp$1023$$,$k$jscomp$505$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$505$$,$cljs_bean$core$lookup_sentinel$$)!==$cljs_bean$core$lookup_sentinel$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){this.$__arr$==null&&(this.$__arr$=$module$contents$goog$object_getKeys$$(this.$obj$));return this.$__arr$.length>0?new $cljs_bean$core$BeanSeq$$(this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,this.$__arr$,0,null):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$1024$$,$new_meta$jscomp$33$$){return $new_meta$jscomp$33$$===this.$meta$?this:new $cljs_bean$core$Bean$$($new_meta$jscomp$33$$,this.$obj$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$recursive_QMARK_$,this.$__arr$,this.$__cnt$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($G__37051$jscomp$inline_4041_JSCompiler_inline_result$jscomp$540_coll$jscomp$1025_ret$jscomp$inline_4038$$,$G__37052$jscomp$inline_4042_entry$jscomp$23_es$jscomp$inline_4039$$){a:if($APP.$cljs$core$vector_QMARK_$$($G__37052$jscomp$inline_4042_entry$jscomp$23_es$jscomp$inline_4039$$))$G__37051$jscomp$inline_4041_JSCompiler_inline_result$jscomp$540_coll$jscomp$1025_ret$jscomp$inline_4038$$=this.$cljs$core$IAssociative$_assoc$arity$3$(null,
$APP.$cljs$core$_nth$$($G__37052$jscomp$inline_4042_entry$jscomp$23_es$jscomp$inline_4039$$,0),$APP.$cljs$core$_nth$$($G__37052$jscomp$inline_4042_entry$jscomp$23_es$jscomp$inline_4039$$,1));else{$G__37051$jscomp$inline_4041_JSCompiler_inline_result$jscomp$540_coll$jscomp$1025_ret$jscomp$inline_4038$$=this;for($G__37052$jscomp$inline_4042_entry$jscomp$23_es$jscomp$inline_4039$$=$APP.$cljs$core$seq$$($G__37052$jscomp$inline_4042_entry$jscomp$23_es$jscomp$inline_4039$$);;){if($G__37052$jscomp$inline_4042_entry$jscomp$23_es$jscomp$inline_4039$$==
null)break a;var $e$jscomp$inline_4040$$=$APP.$cljs$core$first$$($G__37052$jscomp$inline_4042_entry$jscomp$23_es$jscomp$inline_4039$$);if($APP.$cljs$core$vector_QMARK_$$($e$jscomp$inline_4040$$))$G__37051$jscomp$inline_4041_JSCompiler_inline_result$jscomp$540_coll$jscomp$1025_ret$jscomp$inline_4038$$=$APP.$cljs$core$_assoc$$($G__37051$jscomp$inline_4041_JSCompiler_inline_result$jscomp$540_coll$jscomp$1025_ret$jscomp$inline_4038$$,$APP.$cljs$core$_nth$$($e$jscomp$inline_4040$$,0),$APP.$cljs$core$_nth$$($e$jscomp$inline_4040$$,
1)),$G__37052$jscomp$inline_4042_entry$jscomp$23_es$jscomp$inline_4039$$=$APP.$cljs$core$next$$($G__37052$jscomp$inline_4042_entry$jscomp$23_es$jscomp$inline_4039$$);else throw Error("conj on a map takes map entries or seqables of map entries");}$G__37051$jscomp$inline_4041_JSCompiler_inline_result$jscomp$540_coll$jscomp$1025_ret$jscomp$inline_4038$$=void 0}return $G__37051$jscomp$inline_4041_JSCompiler_inline_result$jscomp$540_coll$jscomp$1025_ret$jscomp$inline_4038$$};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$25$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$2274$$,$args40246$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args40246$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($G__40399_k$jscomp$506$$){$G__40399_k$jscomp$506$$=this.$obj$[this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$?this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$($G__40399_k$jscomp$506$$):this.$key__GT_prop$($G__40399_k$jscomp$506$$)];return this.$recursive_QMARK_$?$cljs_bean$core$__GT_val$$($G__40399_k$jscomp$506$$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform):$G__40399_k$jscomp$506$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$507_ret$jscomp$113$$,$not_found$jscomp$73$$){$k$jscomp$507_ret$jscomp$113$$=$APP.$module$contents$goog$object_get$$(this.$obj$,this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$?this.$key__GT_prop$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$507_ret$jscomp$113$$):this.$key__GT_prop$($k$jscomp$507_ret$jscomp$113$$),$not_found$jscomp$73$$);return this.$recursive_QMARK_$&&$k$jscomp$507_ret$jscomp$113$$!==$not_found$jscomp$73$$?
$cljs_bean$core$__GT_val$$($k$jscomp$507_ret$jscomp$113$$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform):$k$jscomp$507_ret$jscomp$113$$};$APP.$JSCompiler_prototypeAlias$$=$cljs_bean$core$TransientArrayVector$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientCollection$_conj_BANG_$arity$2$=function($tcoll$jscomp$65$$,$o$jscomp$191$$){if(this.$editable_QMARK_$)return $cljs_bean$core$compatible_value_QMARK_$$($o$jscomp$191$$,!0)?(this.$arr$.push($cljs_bean$core$unwrap$$($o$jscomp$191$$)),this):$cljs$core$_conj_BANG_$$($APP.$cljs$core$transient$0$$($cljs_bean$core$snapshot_arr$$(this.$arr$)),$o$jscomp$191$$);throw Error("conj! after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientCollection$_persistent_BANG_$arity$1$=function(){if(this.$editable_QMARK_$)return this.$editable_QMARK_$=!1,new $cljs_bean$core$ArrayVector$$(null,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$arr$,null);throw Error("persistent! called twice");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$=function($JSCompiler_inline_result$jscomp$541_tcoll$jscomp$66$$,$key$jscomp$255$$,$val$jscomp$133$$){if(typeof $key$jscomp$255$$==="number")$JSCompiler_inline_result$jscomp$541_tcoll$jscomp$66$$=this.$cljs$core$ITransientVector$_assoc_n_BANG_$arity$3$(null,$key$jscomp$255$$,$val$jscomp$133$$);else throw Error([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$("TransientArrayVector"),"'s key for assoc! must be a number."].join(""));
return $JSCompiler_inline_result$jscomp$541_tcoll$jscomp$66$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientVector$_assoc_n_BANG_$arity$3$=function($tcoll$jscomp$67$$,$n$jscomp$242$$,$val$jscomp$134$$){if(this.$editable_QMARK_$){if($cljs_bean$core$compatible_value_QMARK_$$($val$jscomp$134$$,!0)){if(0<=$n$jscomp$242$$&&$n$jscomp$242$$<this.$arr$.length)return this.$arr$[$n$jscomp$242$$]=$cljs_bean$core$unwrap$$($val$jscomp$134$$),this;if($n$jscomp$242$$===this.$arr$.length)return this.$cljs$core$ITransientCollection$_conj_BANG_$arity$2$(null,$val$jscomp$134$$);
throw Error(["Index ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$242$$)," out of bounds for TransientArrayVector of length",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.$arr$.length)].join(""));}return $cljs$core$_assoc_n_BANG_$$($APP.$cljs$core$transient$0$$($cljs_bean$core$snapshot_arr$$(this.$arr$)),$n$jscomp$242$$,$val$jscomp$134$$)}throw Error("assoc! after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){if(this.$editable_QMARK_$)return this.$arr$.length;throw Error("count after persistent!");};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($_$jscomp$929$$,$n$jscomp$243$$){if(this.$editable_QMARK_$)return $cljs_bean$core$__GT_val$$(this.$arr$[$n$jscomp$243$$],this.$prop__GT_key$,this.$key__GT_prop$,this.transform);throw Error("nth after persistent!");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($coll$jscomp$1026$$,$n$jscomp$244$$,$not_found$jscomp$74$$){return 0<=$n$jscomp$244$$&&$n$jscomp$244$$<this.$arr$.length?this.$cljs$core$IIndexed$_nth$arity$2$(null,$n$jscomp$244$$):$not_found$jscomp$74$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($coll$jscomp$1027$$,$k$jscomp$508$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$508$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($coll$jscomp$1028$$,$k$jscomp$509$$,$not_found$jscomp$75$$){return typeof $k$jscomp$509$$==="number"?this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$509$$,$not_found$jscomp$75$$):$not_found$jscomp$75$$};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$26$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$2288$$,$args40440$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args40440$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$510$$){return this.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$510$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$511$$,$not_found$jscomp$76$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$511$$,$not_found$jscomp$76$$)};$cljs_bean$core$ArrayVectorIterator$$.prototype.hasNext=function(){return this.i<this.$cnt$};
$cljs_bean$core$ArrayVectorIterator$$.prototype.next=function(){var $ret$jscomp$114$$=$cljs_bean$core$__GT_val$$(this.$arr$[this.i],this.$prop__GT_key$,this.$key__GT_prop$,this.transform);this.i+=1;return $ret$jscomp$114$$};$APP.$JSCompiler_prototypeAlias$$=$cljs_bean$core$ArrayVectorSeq$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$138$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$138$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__40803$$=null;$G__40803$$=function($x$jscomp$961$$,$start$jscomp$168$$){switch(arguments.length){case 1:return $cljs_bean$from$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$961$$,0);case 2:return $cljs_bean$from$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$961$$,$start$jscomp$168$$)}throw Error("Invalid arity: "+arguments.length);};$G__40803$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$959$$){return $cljs_bean$from$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$959$$,0)};$G__40803$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$960$$,$start$jscomp$167$$){return $cljs_bean$from$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$960$$,$start$jscomp$167$$)};return $G__40803$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){function $G__40804__1$$($x$jscomp$962$$){return $cljs_bean$from$cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$962$$,$APP.$cljs$core$count$$(this))}var $G__40804$$=null;$G__40804$$=function($x$jscomp$964$$,$start$jscomp$170$$){switch(arguments.length){case 1:return $G__40804__1$$.call(this,$x$jscomp$964$$);case 2:return $cljs_bean$from$cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$964$$,
$start$jscomp$170$$)}throw Error("Invalid arity: "+arguments.length);};$G__40804$$.$cljs$core$IFn$_invoke$arity$1$=$G__40804__1$$;$G__40804$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$963$$,$start$jscomp$169$$){return $cljs_bean$from$cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$963$$,$start$jscomp$169$$)};return $G__40804$$}();
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($_$jscomp$932_i__$1$jscomp$13$$,$n$jscomp$245$$){$_$jscomp$932_i__$1$jscomp$13$$=$n$jscomp$245$$+this.i;if(0<=$_$jscomp$932_i__$1$jscomp$13$$&&$_$jscomp$932_i__$1$jscomp$13$$<this.$arr$.length)return $cljs_bean$core$__GT_val$$(this.$arr$[$_$jscomp$932_i__$1$jscomp$13$$],this.$prop__GT_key$,this.$key__GT_prop$,this.transform);throw Error("Index out of bounds");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($_$jscomp$933_i__$1$jscomp$14$$,$n$jscomp$246$$,$not_found$jscomp$77$$){$_$jscomp$933_i__$1$jscomp$14$$=$n$jscomp$246$$+this.i;return 0<=$_$jscomp$933_i__$1$jscomp$14$$&&$_$jscomp$933_i__$1$jscomp$14$$<this.$arr$.length?$cljs_bean$core$__GT_val$$(this.$arr$[$_$jscomp$933_i__$1$jscomp$14$$],this.$prop__GT_key$,this.$key__GT_prop$,this.transform):$not_found$jscomp$77$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$1036$$,$writer$jscomp$135$$,$opts$jscomp$235$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$135$$,$APP.$cljs$core$pr_writer$$,"("," ",")",$opts$jscomp$235$$,this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs_bean$core$ArrayVectorSeq$$(this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$arr$,this.i,this.$meta$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return this.i+1<this.$arr$.length?new $cljs_bean$core$ArrayVectorSeq$$(this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$arr$,this.i+1,null):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){var $y__5111__auto__$jscomp$23$$=this.$arr$.length-this.i;return 0>$y__5111__auto__$jscomp$23$$?0:$y__5111__auto__$jscomp$23$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$1038$$,$other$jscomp$139$$){return $cljs_bean$from$cljs$core$equiv_sequential$$(this,$other$jscomp$139$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($coll$jscomp$1039$$,$f$jscomp$573$$){return $cljs_bean$from$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$f$jscomp$573$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($coll$jscomp$1040$$,$f$jscomp$574$$,$start$jscomp$171$$){return $cljs_bean$from$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$f$jscomp$574$$,$start$jscomp$171$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return $cljs_bean$core$__GT_val$$(this.$arr$[this.i],this.$prop__GT_key$,this.$key__GT_prop$,this.transform)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){return this.i+1<this.$arr$.length?new $cljs_bean$core$ArrayVectorSeq$$(this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$arr$,this.i+1,null):$APP.$cljs$core$List$EMPTY$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$1041$$,$new_meta$jscomp$34$$){return $new_meta$jscomp$34$$===this.$meta$?this:new $cljs_bean$core$ArrayVectorSeq$$(this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$arr$,this.i,$new_meta$jscomp$34$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$1042$$,$o$jscomp$192$$){return $APP.$cljs$core$cons$$($o$jscomp$192$$,this)};$APP.$JSCompiler_prototypeAlias$$=$cljs_bean$core$ArrayVector$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$_find$arity$2$=function($coll$jscomp$1043$$,$n$jscomp$247$$){return 0<=$n$jscomp$247$$&&$n$jscomp$247$$<this.$arr$.length?new $APP.$cljs$core$MapEntry$$($n$jscomp$247$$,$cljs_bean$core$__GT_val$$(this.$arr$[$n$jscomp$247$$],this.$prop__GT_key$,this.$key__GT_prop$,this.transform),null):null};$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$140$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$140$$)};
$APP.$JSCompiler_prototypeAlias$$.indexOf=function(){var $G__40810$$=null;$G__40810$$=function($x$jscomp$967$$,$start$jscomp$173$$){switch(arguments.length){case 1:return $cljs_bean$from$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$967$$,0);case 2:return $cljs_bean$from$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$967$$,$start$jscomp$173$$)}throw Error("Invalid arity: "+arguments.length);};$G__40810$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$965$$){return $cljs_bean$from$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,
$x$jscomp$965$$,0)};$G__40810$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$966$$,$start$jscomp$172$$){return $cljs_bean$from$cljs$core$_indexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$966$$,$start$jscomp$172$$)};return $G__40810$$}();
$APP.$JSCompiler_prototypeAlias$$.lastIndexOf=function(){var $G__40813$$=null;$G__40813$$=function($x$jscomp$970$$,$start$jscomp$175$$){switch(arguments.length){case 1:return $cljs_bean$from$cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$970$$,$APP.$cljs$core$count$$(this));case 2:return $cljs_bean$from$cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$970$$,$start$jscomp$175$$)}throw Error("Invalid arity: "+arguments.length);};$G__40813$$.$cljs$core$IFn$_invoke$arity$1$=
function($x$jscomp$968$$){return $cljs_bean$from$cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$968$$,$APP.$cljs$core$count$$(this))};$G__40813$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$969$$,$start$jscomp$174$$){return $cljs_bean$from$cljs$core$_lastIndexOf$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$x$jscomp$969$$,$start$jscomp$174$$)};return $G__40813$$}();
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($coll$jscomp$1049$$,$k$jscomp$512$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$512$$,null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($coll$jscomp$1050$$,$k$jscomp$513$$,$not_found$jscomp$78$$){return typeof $k$jscomp$513$$==="number"?this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$513$$,$not_found$jscomp$78$$):$not_found$jscomp$78$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($i$jscomp$382_v$jscomp$308$$,$f$jscomp$575$$,$init$jscomp$56_len$jscomp$62$$){$i$jscomp$382_v$jscomp$308$$=0;for(var $G__40514$jscomp$inline_11563_G__40819$jscomp$inline_11566_init__$1$jscomp$10_init__$2$jscomp$inline_11561_init__$3$jscomp$inline_11562$$=$init$jscomp$56_len$jscomp$62$$;;)if($i$jscomp$382_v$jscomp$308$$<this.$arr$.length){$init$jscomp$56_len$jscomp$62$$=this.$arr$.length;var $G__40821_init__$2$jscomp$10_j$jscomp$inline_11560$$;
a:{for($G__40821_init__$2$jscomp$10_j$jscomp$inline_11560$$=0;;)if($G__40821_init__$2$jscomp$10_j$jscomp$inline_11560$$<$init$jscomp$56_len$jscomp$62$$){var $G__40515$jscomp$inline_11564$$=$G__40821_init__$2$jscomp$10_j$jscomp$inline_11560$$+$i$jscomp$382_v$jscomp$308$$,$G__40516$jscomp$inline_11565$$=$cljs_bean$core$__GT_val$$(this.$arr$[$G__40821_init__$2$jscomp$10_j$jscomp$inline_11560$$],this.$prop__GT_key$,this.$key__GT_prop$,this.transform);$G__40514$jscomp$inline_11563_G__40819$jscomp$inline_11566_init__$1$jscomp$10_init__$2$jscomp$inline_11561_init__$3$jscomp$inline_11562$$=
$f$jscomp$575$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$575$$.$cljs$core$IFn$_invoke$arity$3$($G__40514$jscomp$inline_11563_G__40819$jscomp$inline_11566_init__$1$jscomp$10_init__$2$jscomp$inline_11561_init__$3$jscomp$inline_11562$$,$G__40515$jscomp$inline_11564$$,$G__40516$jscomp$inline_11565$$):$f$jscomp$575$$($G__40514$jscomp$inline_11563_G__40819$jscomp$inline_11566_init__$1$jscomp$10_init__$2$jscomp$inline_11561_init__$3$jscomp$inline_11562$$,$G__40515$jscomp$inline_11564$$,$G__40516$jscomp$inline_11565$$);
if($cljs$core$reduced_QMARK_$$($G__40514$jscomp$inline_11563_G__40819$jscomp$inline_11566_init__$1$jscomp$10_init__$2$jscomp$inline_11561_init__$3$jscomp$inline_11562$$)){$G__40821_init__$2$jscomp$10_j$jscomp$inline_11560$$=$G__40514$jscomp$inline_11563_G__40819$jscomp$inline_11566_init__$1$jscomp$10_init__$2$jscomp$inline_11561_init__$3$jscomp$inline_11562$$;break a}$G__40821_init__$2$jscomp$10_j$jscomp$inline_11560$$+=1}else{$G__40821_init__$2$jscomp$10_j$jscomp$inline_11560$$=$G__40514$jscomp$inline_11563_G__40819$jscomp$inline_11566_init__$1$jscomp$10_init__$2$jscomp$inline_11561_init__$3$jscomp$inline_11562$$;
break a}$G__40821_init__$2$jscomp$10_j$jscomp$inline_11560$$=void 0}if($cljs$core$reduced_QMARK_$$($G__40821_init__$2$jscomp$10_j$jscomp$inline_11560$$))return $APP.$cljs$core$_deref$$($G__40821_init__$2$jscomp$10_j$jscomp$inline_11560$$);$i$jscomp$382_v$jscomp$308$$+=$init$jscomp$56_len$jscomp$62$$;$G__40514$jscomp$inline_11563_G__40819$jscomp$inline_11566_init__$1$jscomp$10_init__$2$jscomp$inline_11561_init__$3$jscomp$inline_11562$$=$G__40821_init__$2$jscomp$10_j$jscomp$inline_11560$$}else return $G__40514$jscomp$inline_11563_G__40819$jscomp$inline_11566_init__$1$jscomp$10_init__$2$jscomp$inline_11561_init__$3$jscomp$inline_11562$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($coll$jscomp$1051$$,$n$jscomp$248$$){if(0<=$n$jscomp$248$$&&$n$jscomp$248$$<this.$arr$.length)return $cljs_bean$core$__GT_val$$(this.$arr$[$n$jscomp$248$$],this.$prop__GT_key$,this.$key__GT_prop$,this.transform);throw Error(["No item ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$248$$)," in vector of length ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.$arr$.length)].join(""));};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($coll$jscomp$1052$$,$n$jscomp$249$$,$not_found$jscomp$79$$){return 0<=$n$jscomp$249$$&&$n$jscomp$249$$<this.$arr$.length?$cljs_bean$core$__GT_val$$(this.$arr$[$n$jscomp$249$$],this.$prop__GT_key$,this.$key__GT_prop$,this.transform):$not_found$jscomp$79$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$1053$$,$writer$jscomp$136$$,$opts$jscomp$236$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$136$$,$APP.$cljs$core$pr_writer$$,"["," ","]",$opts$jscomp$236$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IVector$_assoc_n$arity$3$=function($coll$jscomp$1054_new_arr$jscomp$10$$,$n$jscomp$250$$,$val$jscomp$135$$){if(0<=$n$jscomp$250$$&&$n$jscomp$250$$<this.$arr$.length)return $cljs_bean$core$compatible_value_QMARK_$$($val$jscomp$135$$,!0)?($coll$jscomp$1054_new_arr$jscomp$10$$=$APP.$cljs$core$aclone$$(this.$arr$),$coll$jscomp$1054_new_arr$jscomp$10$$[$n$jscomp$250$$]=$cljs_bean$core$unwrap$$($val$jscomp$135$$),new $cljs_bean$core$ArrayVector$$(this.$meta$,
this.$prop__GT_key$,this.$key__GT_prop$,this.transform,$coll$jscomp$1054_new_arr$jscomp$10$$,null)):$cljs$core$_assoc_n$$($cljs_bean$core$snapshot_arr$$(this.$arr$),$n$jscomp$250$$,$val$jscomp$135$$);if($n$jscomp$250$$===this.$arr$.length)return this.$cljs$core$ICollection$_conj$arity$2$(null,$val$jscomp$135$$);throw Error(["Index ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$250$$)," out of bounds  [0,",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.$arr$.length),
"]"].join(""));};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $cljs_bean$core$ArrayVectorIterator$$(this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$arr$,this.$arr$.length)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs_bean$core$ArrayVector$$(this.$meta$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$arr$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.$arr$.length};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_peek$arity$1$=function(){return this.$arr$.length>0?this.$cljs$core$IIndexed$_nth$arity$2$(null,this.$arr$.length-1):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_pop$arity$1$=function(){if(this.$arr$.length===0)throw Error("Can't pop empty vector");if(1===this.$arr$.length)return this.$cljs$core$IEmptyableCollection$_empty$arity$1$(null);var $new_arr$jscomp$11$$=$APP.$cljs$core$aclone$$(this.$arr$);return new $cljs_bean$core$ArrayVector$$(this.$meta$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,$new_arr$jscomp$11$$.slice(0,$new_arr$jscomp$11$$.length-1),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReversible$_rseq$arity$1$=function(){return this.$arr$.length>0?new $APP.$cljs$core$RSeq$$(this,this.$arr$.length-1,null):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$34_h__5134__auto____$1$jscomp$34$$=this.$__hash$;return $h__5134__auto__$jscomp$34_h__5134__auto____$1$jscomp$34$$!=null?$h__5134__auto__$jscomp$34_h__5134__auto____$1$jscomp$34$$:this.$__hash$=$h__5134__auto__$jscomp$34_h__5134__auto____$1$jscomp$34$$=$cljs$core$hash_ordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($JSCompiler_inline_result$jscomp$542_coll$jscomp$1061_me_iter$jscomp$inline_4061$$,$other$jscomp$141_you_iter$jscomp$inline_4062$$){a:if($other$jscomp$141_you_iter$jscomp$inline_4062$$ instanceof $cljs_bean$core$ArrayVector$$)if(this.$arr$.length===$APP.$cljs$core$count$$($other$jscomp$141_you_iter$jscomp$inline_4062$$)){$JSCompiler_inline_result$jscomp$542_coll$jscomp$1061_me_iter$jscomp$inline_4061$$=this.$cljs$core$IIterable$_iterator$arity$1$(null);
for($other$jscomp$141_you_iter$jscomp$inline_4062$$=$APP.$cljs$core$_iterator$$($other$jscomp$141_you_iter$jscomp$inline_4062$$);;){if($JSCompiler_inline_result$jscomp$542_coll$jscomp$1061_me_iter$jscomp$inline_4061$$.hasNext()){var $x$jscomp$inline_4063$$=$JSCompiler_inline_result$jscomp$542_coll$jscomp$1061_me_iter$jscomp$inline_4061$$.next(),$y$jscomp$inline_4064$$=$other$jscomp$141_you_iter$jscomp$inline_4062$$.next();if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$inline_4063$$,
$y$jscomp$inline_4064$$))continue;else{$JSCompiler_inline_result$jscomp$542_coll$jscomp$1061_me_iter$jscomp$inline_4061$$=!1;break a}}else{$JSCompiler_inline_result$jscomp$542_coll$jscomp$1061_me_iter$jscomp$inline_4061$$=!0;break a}break}$JSCompiler_inline_result$jscomp$542_coll$jscomp$1061_me_iter$jscomp$inline_4061$$=void 0}else $JSCompiler_inline_result$jscomp$542_coll$jscomp$1061_me_iter$jscomp$inline_4061$$=!1;else $JSCompiler_inline_result$jscomp$542_coll$jscomp$1061_me_iter$jscomp$inline_4061$$=
$cljs_bean$from$cljs$core$equiv_sequential$$(this,$other$jscomp$141_you_iter$jscomp$inline_4062$$);return $JSCompiler_inline_result$jscomp$542_coll$jscomp$1061_me_iter$jscomp$inline_4061$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEditableCollection$_as_transient$arity$1$=function(){return new $cljs_bean$core$TransientArrayVector$$($APP.$cljs$core$aclone$$(this.$arr$),this.$prop__GT_key$,this.$key__GT_prop$,this.transform)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return new $cljs_bean$core$ArrayVector$$(this.$meta$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,[],null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($v$jscomp$309$$,$f$jscomp$576$$){return $cljs_bean$from$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$f$jscomp$576$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($v$jscomp$310$$,$f$jscomp$577$$,$init$jscomp$57$$){return $cljs_bean$from$cljs$core$ci_reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(this,$f$jscomp$577$$,$init$jscomp$57$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($JSCompiler_inline_result$jscomp$544_coll$jscomp$1064$$,$k$jscomp$514$$,$v$jscomp$311$$){if(typeof $k$jscomp$514$$==="number")$JSCompiler_inline_result$jscomp$544_coll$jscomp$1064$$=this.$cljs$core$IVector$_assoc_n$arity$3$(null,$k$jscomp$514$$,$v$jscomp$311$$);else throw Error("Vector's key for assoc must be a number.");return $JSCompiler_inline_result$jscomp$544_coll$jscomp$1064$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($coll$jscomp$1065$$,$k$jscomp$515$$){return $APP.$cljs$core$integer_QMARK_$$($k$jscomp$515$$)?0<=$k$jscomp$515$$&&$k$jscomp$515$$<this.$arr$.length:!1};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return this.$arr$.length>0?new $cljs_bean$core$ArrayVectorSeq$$(this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$arr$,0,null):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($coll$jscomp$1067$$,$new_meta$jscomp$35$$){return $new_meta$jscomp$35$$===this.$meta$?this:new $cljs_bean$core$ArrayVector$$($new_meta$jscomp$35$$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,this.$arr$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($_$jscomp$943_new_arr$jscomp$12$$,$o$jscomp$193$$){return $cljs_bean$core$compatible_value_QMARK_$$($o$jscomp$193$$,!0)?($_$jscomp$943_new_arr$jscomp$12$$=$APP.$cljs$core$aclone$$(this.$arr$),$_$jscomp$943_new_arr$jscomp$12$$[$_$jscomp$943_new_arr$jscomp$12$$.length]=$cljs_bean$core$unwrap$$($o$jscomp$193$$),new $cljs_bean$core$ArrayVector$$(this.$meta$,this.$prop__GT_key$,this.$key__GT_prop$,this.transform,$_$jscomp$943_new_arr$jscomp$12$$,
null)):$APP.$cljs$core$_conj$$($cljs_bean$core$snapshot_arr$$(this.$arr$),$o$jscomp$193$$)};$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$27$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};
$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$2349$$,$args40504$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args40504$$)))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$516$$){return this.$cljs$core$IIndexed$_nth$arity$2$(null,$k$jscomp$516$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$517$$,$not_found$jscomp$80$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$517$$,$not_found$jscomp$80$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IComparable$_compare$arity$2$=function($x$jscomp$971_xl$jscomp$inline_4072$$,$JSCompiler_temp$jscomp$10700_JSCompiler_temp$jscomp$10701_JSCompiler_temp$jscomp$10702_y$jscomp$298$$){if($APP.$cljs$core$vector_QMARK_$$($JSCompiler_temp$jscomp$10700_JSCompiler_temp$jscomp$10701_JSCompiler_temp$jscomp$10702_y$jscomp$298$$)){$x$jscomp$971_xl$jscomp$inline_4072$$=$APP.$cljs$core$count$$(this);var $n$jscomp$inline_11571_yl$jscomp$inline_4073$$=$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$10700_JSCompiler_temp$jscomp$10701_JSCompiler_temp$jscomp$10702_y$jscomp$298$$);
if($x$jscomp$971_xl$jscomp$inline_4072$$<$n$jscomp$inline_11571_yl$jscomp$inline_4073$$)$JSCompiler_temp$jscomp$10700_JSCompiler_temp$jscomp$10701_JSCompiler_temp$jscomp$10702_y$jscomp$298$$=-1;else if($x$jscomp$971_xl$jscomp$inline_4072$$>$n$jscomp$inline_11571_yl$jscomp$inline_4073$$)$JSCompiler_temp$jscomp$10700_JSCompiler_temp$jscomp$10701_JSCompiler_temp$jscomp$10702_y$jscomp$298$$=1;else if($x$jscomp$971_xl$jscomp$inline_4072$$===0)$JSCompiler_temp$jscomp$10700_JSCompiler_temp$jscomp$10701_JSCompiler_temp$jscomp$10702_y$jscomp$298$$=
0;else a:{for($n$jscomp$inline_11571_yl$jscomp$inline_4073$$=0;;){var $d$jscomp$inline_11572$$=$APP.$cljs$core$compare$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$n$jscomp$inline_11571_yl$jscomp$inline_4073$$),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$10700_JSCompiler_temp$jscomp$10701_JSCompiler_temp$jscomp$10702_y$jscomp$298$$,$n$jscomp$inline_11571_yl$jscomp$inline_4073$$));if($d$jscomp$inline_11572$$===0&&$n$jscomp$inline_11571_yl$jscomp$inline_4073$$+
1<$x$jscomp$971_xl$jscomp$inline_4072$$)$n$jscomp$inline_11571_yl$jscomp$inline_4073$$+=1;else{$JSCompiler_temp$jscomp$10700_JSCompiler_temp$jscomp$10701_JSCompiler_temp$jscomp$10702_y$jscomp$298$$=$d$jscomp$inline_11572$$;break a}}$JSCompiler_temp$jscomp$10700_JSCompiler_temp$jscomp$10701_JSCompiler_temp$jscomp$10702_y$jscomp$298$$=void 0}return $JSCompiler_temp$jscomp$10700_JSCompiler_temp$jscomp$10701_JSCompiler_temp$jscomp$10702_y$jscomp$298$$}throw Error(["Cannot compare ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this),
" to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10700_JSCompiler_temp$jscomp$10701_JSCompiler_temp$jscomp$10702_y$jscomp$298$$)].join(""));};$APP.$app$util$object$merge_BANG_$$=function $app$util$object$merge_BANG_$$($var_args$jscomp$688$$){switch(arguments.length){case 2:return $app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$89$$=[],$len__5749__auto___41160$$=arguments.length,$i__5750__auto___41161$$=0;;)if($i__5750__auto___41161$$<$len__5749__auto___41160$$)$args_arr__5774__auto__$jscomp$89$$.push(arguments[$i__5750__auto___41161$$]),$i__5750__auto___41161$$+=
1;else break;return $app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$89$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$89$$.slice(2),0,null):null)}};$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$=function($a$jscomp$296$$,$b$jscomp$223$$){return Object.assign($a$jscomp$296$$,$b$jscomp$223$$)};
$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($a$jscomp$297$$,$b$jscomp$224$$,$more$jscomp$39$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$util$object$merge_BANG_$$,$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$297$$,$b$jscomp$224$$),$more$jscomp$39$$)};
$APP.$app$util$object$merge_BANG_$$.$cljs$lang$applyTo$=function($G__41057_seq41055$$){var $G__41056$$=$APP.$cljs$core$first$$($G__41057_seq41055$$),$seq41055__$1_seq41055__$2$$=$APP.$cljs$core$next$$($G__41057_seq41055$$);$G__41057_seq41055$$=$APP.$cljs$core$first$$($seq41055__$1_seq41055__$2$$);$seq41055__$1_seq41055__$2$$=$APP.$cljs$core$next$$($seq41055__$1_seq41055__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__41056$$,$G__41057_seq41055$$,$seq41055__$1_seq41055__$2$$)};
$APP.$app$util$object$merge_BANG_$$.$cljs$lang$maxFixedArity$=2;$APP.$app$util$object$type_symbol$$=Symbol["for"]("penpot.reify:type");$APP.$app$util$object$Proxy$$=function(){function $Proxy$jscomp$1$$(){return $konstructor__40952__auto__$$(this)}var $konstructor__40952__auto__$$=$APP.$cljs$core$constantly$$(null);$Proxy$jscomp$1$$.prototype=Object.create(Object.prototype);$Proxy$jscomp$1$$.prototype.constructor=$konstructor__40952__auto__$$;return $Proxy$jscomp$1$$}();$APP.$app$util$avatars$generate$$=$APP.$cljs$core$memoize$$(function($color$jscomp$2_color__$1_p__42945$$){var $map__42946__$1_size$jscomp$79$$=$APP.$cljs$core$__destructure_map$$($color$jscomp$2_color__$1_p__42945$$),$letters_name$jscomp$140_parts$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__42946__$1_size$jscomp$79$$,$APP.$cljs$cst$725$name$$);$color$jscomp$2_color__$1_p__42945$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__42946__$1_size$jscomp$79$$,$APP.$cljs$cst$1298$color$$);
$map__42946__$1_size$jscomp$79$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__42946__$1_size$jscomp$79$$,$APP.$cljs$cst$874$size$$,128);$letters_name$jscomp$140_parts$jscomp$17$$=$cuerdas$core$words$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cuerdas$core$upper$$($letters_name$jscomp$140_parts$jscomp$17$$));$letters_name$jscomp$140_parts$jscomp$17$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($letters_name$jscomp$140_parts$jscomp$17$$))?$APP.$cljs$core$ffirst$$($letters_name$jscomp$140_parts$jscomp$17$$):
[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ffirst$$($letters_name$jscomp$140_parts$jscomp$17$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$second$$($letters_name$jscomp$140_parts$jscomp$17$$)))].join("");var $canvas$$=document.createElement("canvas"),$context$jscomp$6$$=$canvas$$.getContext("2d"),$text_color$$=$APP.$cljs$core$truth_$$($color$jscomp$2_color__$1_p__42945$$)?"#2e3434":"#fff";$color$jscomp$2_color__$1_p__42945$$=
$APP.$cljs$core$truth_$$($color$jscomp$2_color__$1_p__42945$$)?$color$jscomp$2_color__$1_p__42945$$:"#000000";$APP.$app$util$object$set_BANG_$$($canvas$$,"width",$map__42946__$1_size$jscomp$79$$);$APP.$app$util$object$set_BANG_$$($canvas$$,"height",$map__42946__$1_size$jscomp$79$$);$APP.$app$util$object$set_BANG_$$($context$jscomp$6$$,"fillStyle",$color$jscomp$2_color__$1_p__42945$$);$context$jscomp$6$$.fillRect(0,0,$map__42946__$1_size$jscomp$79$$,$map__42946__$1_size$jscomp$79$$);$APP.$app$util$object$set_BANG_$$($context$jscomp$6$$,
"font",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__42946__$1_size$jscomp$79$$/2),"px Arial"].join(""));$APP.$app$util$object$set_BANG_$$($context$jscomp$6$$,"textAlign","center");$APP.$app$util$object$set_BANG_$$($context$jscomp$6$$,"fillStyle",$text_color$$);$context$jscomp$6$$.fillText($letters_name$jscomp$140_parts$jscomp$17$$,$map__42946__$1_size$jscomp$79$$/2,$map__42946__$1_size$jscomp$79$$/1.5);return $canvas$$.toDataURL()});$promesa$impl$extend_promise_BANG_$$(Promise);$APP.$JSCompiler_prototypeAlias$$=$APP.$$jscomp$scope$84173391$14$PromiseImpl$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$IPromiseFactory$_promise$arity$1$=function(){return this};
$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$IPromise$_fmap$arity$2$=function($it$jscomp$111$$,$f$jscomp$579$$){return $APP.$JSCompiler_StaticMethods_fmap$$(this,function($p1__40101_SHARP_$$){return $f$jscomp$579$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$579$$.$cljs$core$IFn$_invoke$arity$1$($p1__40101_SHARP_$$):$f$jscomp$579$$($p1__40101_SHARP_$$)})};
$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$IPromise$_fmap$arity$3$=function($it$jscomp$112$$,$f$jscomp$580$$){return $APP.$JSCompiler_StaticMethods_fmap$$(this,function($p1__40114_SHARP_$$){return $f$jscomp$580$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$580$$.$cljs$core$IFn$_invoke$arity$1$($p1__40114_SHARP_$$):$f$jscomp$580$$($p1__40114_SHARP_$$)})};
$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$IPromise$_mcat$arity$2$=function($it$jscomp$113$$,$f$jscomp$581$$){return $JSCompiler_StaticMethods_fbind$$(this,function($p1__40115_SHARP_$$){return $f$jscomp$581$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$581$$.$cljs$core$IFn$_invoke$arity$1$($p1__40115_SHARP_$$):$f$jscomp$581$$($p1__40115_SHARP_$$)})};
$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$IPromise$_mcat$arity$3$=function($it$jscomp$114$$,$f$jscomp$582$$){return $JSCompiler_StaticMethods_fbind$$(this,function($p1__40116_SHARP_$$){return $f$jscomp$582$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$582$$.$cljs$core$IFn$_invoke$arity$1$($p1__40116_SHARP_$$):$f$jscomp$582$$($p1__40116_SHARP_$$)})};
$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$IPromise$_merr$arity$2$=function($it$jscomp$117$$,$f$jscomp$585$$){return $JSCompiler_StaticMethods_fbind$$(this,$promesa$protocols$_promise$$,function($p1__40122_SHARP_$$){return $f$jscomp$585$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$585$$.$cljs$core$IFn$_invoke$arity$1$($p1__40122_SHARP_$$):$f$jscomp$585$$($p1__40122_SHARP_$$)})};
$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$IPromise$_merr$arity$3$=function($it$jscomp$118$$,$f$jscomp$586$$){return $JSCompiler_StaticMethods_fbind$$(this,$promesa$protocols$_promise$$,function($p1__40123_SHARP_$$){return $f$jscomp$586$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$586$$.$cljs$core$IFn$_invoke$arity$1$($p1__40123_SHARP_$$):$f$jscomp$586$$($p1__40123_SHARP_$$)})};
$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$IPromise$_fnly$arity$2$=function($it$jscomp$119$$,$f$jscomp$587$$){this.handle($f$jscomp$587$$);return this};$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$IPromise$_fnly$arity$3$=function($it$jscomp$120$$,$f$jscomp$588$$){this.handle($f$jscomp$588$$);return this};
$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$IPromise$_then$arity$2$=function($it$jscomp$121$$,$f$jscomp$589$$){return this.then(function($p1__40124_SHARP_$$){return $f$jscomp$589$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$589$$.$cljs$core$IFn$_invoke$arity$1$($p1__40124_SHARP_$$):$f$jscomp$589$$($p1__40124_SHARP_$$)})};
$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$IPromise$_then$arity$3$=function($it$jscomp$122$$,$f$jscomp$590$$){return this.then(function($p1__40125_SHARP_$$){return $f$jscomp$590$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$590$$.$cljs$core$IFn$_invoke$arity$1$($p1__40125_SHARP_$$):$f$jscomp$590$$($p1__40125_SHARP_$$)})};$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$ICompletable$_resolve_BANG_$arity$2$=function($it$jscomp$123$$,$v$jscomp$321$$){return this.resolve($v$jscomp$321$$)};
$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$ICompletable$_reject_BANG_$arity$2$=function($it$jscomp$124$$,$v$jscomp$322$$){return this.reject($v$jscomp$322$$)};$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$ICancellable$_cancelled_QMARK_$arity$1$=function(){const $value$jscomp$inline_4088$$=this[$$jscomp$scope$84173391$5$VALUE$$];return this[$$jscomp$scope$84173391$4$STATE$$]===$$jscomp$scope$84173391$2$REJECTED$$&&$value$jscomp$inline_4088$$ instanceof $$jscomp$scope$84173391$13$CancellationError$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDeref$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDeref$_deref$arity$1$=function(){var $value$jscomp$345$$=this.value;if($APP.$cljs$core$truth_$$(this[$$jscomp$scope$84173391$4$STATE$$]===$$jscomp$scope$84173391$2$REJECTED$$))throw $value$jscomp$345$$;return $value$jscomp$345$$};
$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$IState$_rejected_QMARK_$arity$1$=function(){return this[$$jscomp$scope$84173391$4$STATE$$]===$$jscomp$scope$84173391$2$REJECTED$$};$APP.$JSCompiler_prototypeAlias$$.$promesa$protocols$IState$_pending_QMARK_$arity$1$=function(){return this[$$jscomp$scope$84173391$4$STATE$$]===$$jscomp$scope$84173391$0$PENDING$$};Error.prototype.$promesa$protocols$IPromiseFactory$_promise$arity$1$=function(){return $promesa$impl$promise$rejected$$(this)};
$promesa$protocols$_promise$$._=function($v$jscomp$325$$){return $APP.$promesa$impl$promise$resolved$$($v$jscomp$325$$)};Promise.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;Promise.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($p$jscomp$122$$,$writer$jscomp$137$$){return $APP.$cljs$core$_write$$($writer$jscomp$137$$,"#\x3cjs/Promise[~]\x3e")};$APP.$$jscomp$scope$84173391$14$PromiseImpl$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$$jscomp$scope$84173391$14$PromiseImpl$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($p$jscomp$123$$,$writer$jscomp$138$$){return $APP.$cljs$core$_write$$($writer$jscomp$138$$,["#\x3cPromise[",$APP.$cljs$core$truth_$$($promesa$protocols$_pending_QMARK_$$(this))?"pending":$APP.$cljs$core$truth_$$($promesa$protocols$_cancelled_QMARK_$$(this))?"cancelled":$APP.$cljs$core$truth_$$($promesa$protocols$_rejected_QMARK_$$(this))?"rejected":"resolved",":",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$hash$$(this)),
"]\x3e"].join(""))};var $module$contents$goog$async$FreeList_FreeList$$=class{constructor($create$jscomp$2$$,$reset$$){this.$limit_$=100;this.$create_$=$create$jscomp$2$$;this.$reset_$=$reset$$;this.$occupants_$=0;this.$head_$=null}get(){let $item$jscomp$28$$;this.$occupants_$>0?(this.$occupants_$--,$item$jscomp$28$$=this.$head_$,this.$head_$=$item$jscomp$28$$.next,$item$jscomp$28$$.next=null):$item$jscomp$28$$=this.$create_$();return $item$jscomp$28$$}put($item$jscomp$29$$){this.$reset_$($item$jscomp$29$$);this.$occupants_$<
this.$limit_$&&(this.$occupants_$++,$item$jscomp$29$$.next=this.$head_$,this.$head_$=$item$jscomp$29$$)}};var $module$contents$goog$async$WorkQueue_WorkQueue$$=class{constructor(){this.$workTail_$=this.$workHead_$=null}add($fn$jscomp$17$$,$scope$jscomp$1$$){const $item$jscomp$30$$=$module$contents$goog$async$WorkQueue_WorkQueue$freelist_$$.get();$item$jscomp$30$$.set($fn$jscomp$17$$,$scope$jscomp$1$$);this.$workTail_$?this.$workTail_$.next=$item$jscomp$30$$:this.$workHead_$=$item$jscomp$30$$;this.$workTail_$=$item$jscomp$30$$}remove(){let $item$jscomp$31$$=null;this.$workHead_$&&($item$jscomp$31$$=this.$workHead_$,
this.$workHead_$=this.$workHead_$.next,this.$workHead_$||(this.$workTail_$=null),$item$jscomp$31$$.next=null);return $item$jscomp$31$$}},$module$contents$goog$async$WorkQueue_WorkQueue$freelist_$$=new $module$contents$goog$async$FreeList_FreeList$$(()=>new $module$contents$goog$async$WorkQueue_WorkItem$$,$item$jscomp$33$$=>$item$jscomp$33$$.reset()),$module$contents$goog$async$WorkQueue_WorkItem$$=class{constructor(){this.next=this.scope=this.fn=null}set($fn$jscomp$18$$,$scope$jscomp$2$$){this.fn=
$fn$jscomp$18$$;this.scope=$scope$jscomp$2$$;this.next=null}reset(){this.next=this.scope=this.fn=null}};$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Opera");var $goog$userAgent$IE$$=$module$contents$goog$labs$userAgent$browser_matchIE$$();$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Edge");
var $goog$userAgent$GECKO$$=$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Gecko")&&!($module$contents$goog$labs$userAgent$util_getNativeUserAgentString$$().toLowerCase().indexOf("webkit")!=-1&&!$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Edge"))&&!($module$contents$goog$labs$userAgent$util_matchUserAgent$$("Trident")||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("MSIE"))&&!$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Edge"),$goog$userAgent$WEBKIT$$=
$module$contents$goog$labs$userAgent$util_getNativeUserAgentString$$().toLowerCase().indexOf("webkit")!=-1&&!$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Edge");$goog$userAgent$WEBKIT$$&&$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Mobile");$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Macintosh");$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Windows");$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Linux")||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("CrOS");
$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Android");$module$contents$goog$labs$userAgent$platform_isIphone$$();$module$contents$goog$labs$userAgent$util_matchUserAgent$$("iPad");$module$contents$goog$labs$userAgent$util_matchUserAgent$$("iPod");$module$contents$goog$labs$userAgent$platform_isIos$$();$module$contents$goog$labs$userAgent$util_getNativeUserAgentString$$().toLowerCase().indexOf("kaios");try{(new self.OffscreenCanvas(0,0)).getContext("2d")}catch($ex$jscomp$inline_4091$$){};var $goog$dom$DIRECT_ATTRIBUTE_MAP_$$={cellpadding:"cellPadding",cellspacing:"cellSpacing",colspan:"colSpan",frameborder:"frameBorder",height:"height",maxlength:"maxLength",nonce:"nonce",role:"role",rowspan:"rowSpan",type:"type",usemap:"useMap",valign:"vAlign",width:"width"};$APP.$JSCompiler_prototypeAlias$$=$goog$dom$DomHelper$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$getElement$=function($element$jscomp$38$$){return $goog$dom$getElementHelper_$$(this.$document_$,$element$jscomp$38$$)};
$APP.$JSCompiler_prototypeAlias$$.$=$goog$dom$DomHelper$$.prototype.$getElement$;$APP.$JSCompiler_prototypeAlias$$.getElementsByTagName=function($tagName$jscomp$20$$,$opt_parent$jscomp$3$$){return($opt_parent$jscomp$3$$||this.$document_$).getElementsByTagName(String($tagName$jscomp$20$$))};
$APP.$JSCompiler_prototypeAlias$$.$getElementsByTagNameAndClass$=function($opt_tag$jscomp$5$$,$opt_class$jscomp$5$$,$opt_el$jscomp$6$$){return $APP.$goog$dom$getElementsByTagNameAndClass_$$(this.$document_$,$opt_tag$jscomp$5$$,$opt_class$jscomp$5$$,$opt_el$jscomp$6$$)};$APP.$JSCompiler_prototypeAlias$$.$$=$goog$dom$DomHelper$$.prototype.$getElementsByTagNameAndClass$;$APP.$JSCompiler_prototypeAlias$$.createElement=function($name$jscomp$144$$){return $goog$dom$createElement_$$(this.$document_$,$name$jscomp$144$$)};
$APP.$JSCompiler_prototypeAlias$$.createTextNode=function($content$jscomp$11$$){return this.$document_$.createTextNode(String($content$jscomp$11$$))};$APP.$JSCompiler_prototypeAlias$$.appendChild=function($parent$jscomp$113$$,$child$jscomp$43$$){$parent$jscomp$113$$.appendChild($child$jscomp$43$$)};
$APP.$JSCompiler_prototypeAlias$$.append=function($parent$jscomp$114$$,$var_args$jscomp$694$$){$goog$dom$append_$$($parent$jscomp$114$$.nodeType==9?$parent$jscomp$114$$:$parent$jscomp$114$$.ownerDocument||$parent$jscomp$114$$.document,$parent$jscomp$114$$,arguments)};$APP.$JSCompiler_prototypeAlias$$.canHaveChildren=function($node$jscomp$130$$){if($node$jscomp$130$$.nodeType!=1)return!1;switch($node$jscomp$130$$.tagName){case "APPLET":case "AREA":case "BASE":case "BR":case "COL":case "COMMAND":case "EMBED":case "FRAME":case "HR":case "IMG":case "INPUT":case "IFRAME":case "ISINDEX":case "KEYGEN":case "LINK":case "NOFRAMES":case "NOSCRIPT":case "META":case "OBJECT":case "PARAM":case "SCRIPT":case "SOURCE":case "STYLE":case "TRACK":case "WBR":return!1}return!0};
$APP.$JSCompiler_prototypeAlias$$.removeNode=$goog$dom$removeNode$$;$APP.$JSCompiler_prototypeAlias$$.getChildren=function($element$jscomp$25$$){return $element$jscomp$25$$.children!=void 0?$element$jscomp$25$$.children:Array.prototype.filter.call($element$jscomp$25$$.childNodes,function($node$jscomp$133$$){return $node$jscomp$133$$.nodeType==1})};
$APP.$JSCompiler_prototypeAlias$$.contains=function($parent$jscomp$119$$,$descendant$$){if(!$parent$jscomp$119$$||!$descendant$$)return!1;if($parent$jscomp$119$$.contains&&$descendant$$.nodeType==1)return $parent$jscomp$119$$==$descendant$$||$parent$jscomp$119$$.contains($descendant$$);if(typeof $parent$jscomp$119$$.compareDocumentPosition!="undefined")return $parent$jscomp$119$$==$descendant$$||!!($parent$jscomp$119$$.compareDocumentPosition($descendant$$)&16);for(;$descendant$$&&$parent$jscomp$119$$!=
$descendant$$;)$descendant$$=$descendant$$.parentNode;return $descendant$$==$parent$jscomp$119$$};var $goog$async$nextTick$nextTickImpl$$;var $module$contents$goog$async$run_schedule$$,$module$contents$goog$async$run_workQueueScheduled$$=!1,$module$contents$goog$async$run_workQueue$$=new $module$contents$goog$async$WorkQueue_WorkQueue$$,$module$contents$goog$async$run_run$$=($callback$jscomp$74$$,$context$jscomp$7$$)=>{$module$contents$goog$async$run_schedule$$||$module$contents$goog$async$run_initializeRunner$$();$module$contents$goog$async$run_workQueueScheduled$$||($module$contents$goog$async$run_schedule$$(),$module$contents$goog$async$run_workQueueScheduled$$=
!0);$module$contents$goog$async$run_workQueue$$.add($callback$jscomp$74$$,$context$jscomp$7$$)},$module$contents$goog$async$run_initializeRunner$$=()=>{if($APP.$goog$global$$.Promise&&$APP.$goog$global$$.Promise.resolve){const $promise$jscomp$2$$=$APP.$goog$global$$.Promise.resolve(void 0);$module$contents$goog$async$run_schedule$$=()=>{$promise$jscomp$2$$.then($module$contents$goog$async$run_run$processWorkQueue$$)}}else $module$contents$goog$async$run_schedule$$=()=>{var $cb$jscomp$inline_4108$$=
$module$contents$goog$async$run_run$processWorkQueue$$;typeof $APP.$goog$global$$.setImmediate!=="function"||$APP.$goog$global$$.Window&&$APP.$goog$global$$.Window.prototype&&!$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Edge")&&$APP.$goog$global$$.Window.prototype.setImmediate==$APP.$goog$global$$.setImmediate?($goog$async$nextTick$nextTickImpl$$||($goog$async$nextTick$nextTickImpl$$=$goog$async$nextTick$getNextTickImpl_$$()),$goog$async$nextTick$nextTickImpl$$($cb$jscomp$inline_4108$$)):
$APP.$goog$global$$.setImmediate($cb$jscomp$inline_4108$$)}},$module$contents$goog$async$run_run$processWorkQueue$$=()=>{let $item$jscomp$34$$;for(;$item$jscomp$34$$=$module$contents$goog$async$run_workQueue$$.remove();){try{$item$jscomp$34$$.fn.call($item$jscomp$34$$.scope)}catch($e$jscomp$195$$){$module$contents$goog$async$throwException_throwException$$($e$jscomp$195$$)}$module$contents$goog$async$WorkQueue_WorkQueue$freelist_$$.put($item$jscomp$34$$)}$module$contents$goog$async$run_workQueueScheduled$$=
!1};var $goog$Promise$State_$PENDING$$=0,$goog$Promise$State_$FULFILLED$$=2,$goog$Promise$State_$REJECTED$$=3;$goog$Promise$CallbackEntry_$$.prototype.reset=function(){this.context=this.$onRejected$=this.$onFulfilled$=this.$child$=null;this.$always$=!1};var $goog$Promise$freelist_$$=new $module$contents$goog$async$FreeList_FreeList$$(function(){return new $goog$Promise$CallbackEntry_$$},function($item$jscomp$35$$){$item$jscomp$35$$.reset()});
$goog$Promise$$.prototype.then=function($opt_onFulfilled$jscomp$3$$,$opt_onRejected$jscomp$3$$,$opt_context$jscomp$3$$){return $JSCompiler_StaticMethods_addChildPromise_$$(this,typeof $opt_onFulfilled$jscomp$3$$==="function"?$opt_onFulfilled$jscomp$3$$:null,typeof $opt_onRejected$jscomp$3$$==="function"?$opt_onRejected$jscomp$3$$:null,$opt_context$jscomp$3$$)};$goog$Promise$$.prototype.$goog_Thenable=!0;$APP.$JSCompiler_prototypeAlias$$=$goog$Promise$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$thenCatch$=function($onRejected$jscomp$3$$,$opt_context$jscomp$6$$){return $JSCompiler_StaticMethods_addChildPromise_$$(this,null,$onRejected$jscomp$3$$,$opt_context$jscomp$6$$)};$APP.$JSCompiler_prototypeAlias$$.catch=$goog$Promise$$.prototype.$thenCatch$;
$APP.$JSCompiler_prototypeAlias$$.cancel=function($opt_message$jscomp$13$$){if(this.$state_$==$goog$Promise$State_$PENDING$$){var $err$jscomp$7$$=new $goog$Promise$CancellationError$$($opt_message$jscomp$13$$);$module$contents$goog$async$run_run$$(function(){$JSCompiler_StaticMethods_cancelInternal_$$(this,$err$jscomp$7$$)},this)}};
$APP.$JSCompiler_prototypeAlias$$.$unblockAndFulfill_$=function($value$jscomp$351$$){this.$state_$=$goog$Promise$State_$PENDING$$;$JSCompiler_StaticMethods_resolve_$$(this,$goog$Promise$State_$FULFILLED$$,$value$jscomp$351$$)};$APP.$JSCompiler_prototypeAlias$$.$unblockAndReject_$=function($reason$jscomp$19$$){this.$state_$=$goog$Promise$State_$PENDING$$;$JSCompiler_StaticMethods_resolve_$$(this,$goog$Promise$State_$REJECTED$$,$reason$jscomp$19$$)};
$APP.$JSCompiler_prototypeAlias$$.$executeCallbacks_$=function(){for(var $entry$jscomp$30$$;$entry$jscomp$30$$=$JSCompiler_StaticMethods_popEntry_$$(this);)$JSCompiler_StaticMethods_executeCallback_$$(this,$entry$jscomp$30$$,this.$state_$,this.$result_$);this.$executing_$=!1};var $goog$Promise$handleRejection_$$=$module$contents$goog$async$throwException_throwException$$;$APP.$goog$inherits$$($goog$Promise$CancellationError$$,$module$contents$goog$debug$Error_DebugError$$);
$goog$Promise$CancellationError$$.prototype.name="cancel";/*

 Copyright 2005, 2007 Bob Ippolito. All Rights Reserved.
 Copyright The Closure Library Authors.
 SPDX-License-Identifier: MIT
*/
$APP.$JSCompiler_prototypeAlias$$=$goog$async$Deferred$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.cancel=function($opt_deepCancel$$){if(this.$fired_$)this.$result_$ instanceof $goog$async$Deferred$$&&this.$result_$.cancel();else{if(this.$parent_$){const $parent$jscomp$123$$=this.$parent_$;delete this.$parent_$;$opt_deepCancel$$?$parent$jscomp$123$$.cancel($opt_deepCancel$$):($parent$jscomp$123$$.$branches_$--,$parent$jscomp$123$$.$branches_$<=0&&$parent$jscomp$123$$.cancel())}this.$onCancelFunction_$?this.$onCancelFunction_$.call(this.$defaultScope_$,this):this.$silentlyCanceled_$=
!0;this.$fired_$||this.errback(new $goog$async$Deferred$CanceledError$$(this))}};$APP.$JSCompiler_prototypeAlias$$.$continue_$=function($isSuccess$$,$res$jscomp$26$$){this.$blocked_$=!1;$JSCompiler_StaticMethods_updateResult_$$(this,$isSuccess$$,$res$jscomp$26$$)};$APP.$JSCompiler_prototypeAlias$$.callback=function($opt_result$jscomp$3$$){$JSCompiler_StaticMethods_check_$$(this);$JSCompiler_StaticMethods_updateResult_$$(this,!0,$opt_result$jscomp$3$$)};
$APP.$JSCompiler_prototypeAlias$$.errback=function($opt_result$jscomp$4$$){$JSCompiler_StaticMethods_check_$$(this);$JSCompiler_StaticMethods_updateResult_$$(this,!1,$opt_result$jscomp$4$$)};$APP.$JSCompiler_prototypeAlias$$.addCallbacks=function($cb$jscomp$6$$,$eb$jscomp$1$$,$opt_scope$jscomp$8$$){this.$sequence_$.push([$cb$jscomp$6$$,$eb$jscomp$1$$,$opt_scope$jscomp$8$$]);this.$fired_$&&$JSCompiler_StaticMethods_fire_$$(this);return this};
$APP.$JSCompiler_prototypeAlias$$.then=function($opt_onFulfilled$jscomp$5$$,$opt_onRejected$jscomp$5$$,$opt_context$jscomp$8$$){let $reject$jscomp$13$$,$resolve$jscomp$14$$;const $promise$jscomp$12$$=new $goog$Promise$$(function($res$jscomp$28$$,$rej$$){$resolve$jscomp$14$$=$res$jscomp$28$$;$reject$jscomp$13$$=$rej$$});this.addCallbacks($resolve$jscomp$14$$,function($reason$jscomp$22$$){$reason$jscomp$22$$ instanceof $goog$async$Deferred$CanceledError$$?$promise$jscomp$12$$.cancel():$reject$jscomp$13$$($reason$jscomp$22$$);
return $goog$async$Deferred$CONVERTED_TO_PROMISE_$$},this);return $promise$jscomp$12$$.then($opt_onFulfilled$jscomp$5$$,$opt_onRejected$jscomp$5$$,$opt_context$jscomp$8$$)};$goog$async$Deferred$$.prototype.$goog_Thenable=!0;var $goog$async$Deferred$CONVERTED_TO_PROMISE_$$={};$APP.$goog$inherits$$($goog$async$Deferred$AlreadyCalledError$$,$module$contents$goog$debug$Error_DebugError$$);$goog$async$Deferred$AlreadyCalledError$$.prototype.message="Deferred has already fired";
$goog$async$Deferred$AlreadyCalledError$$.prototype.name="AlreadyCalledError";$APP.$goog$inherits$$($goog$async$Deferred$CanceledError$$,$module$contents$goog$debug$Error_DebugError$$);$goog$async$Deferred$CanceledError$$.prototype.message="Deferred was canceled";$goog$async$Deferred$CanceledError$$.prototype.name="CanceledError";$goog$async$Deferred$Error_$$.prototype.throwError=function(){delete $goog$async$Deferred$errorMap_$$[this.$id_$];throw this.$error_$;};
var $goog$async$Deferred$errorMap_$$={};$promesa$impl$extend_promise_BANG_$$($goog$async$Deferred$$);var $app$util$globals$navigator$$,$app$util$globals$FormData$$;$APP.$app$util$globals$global$$=globalThis;
$APP.$app$util$globals$window$$=function(){if(typeof $APP.$goog$global$$.window!=="undefined")return $APP.$goog$global$$.window;const $mockWindow$$=$$jscomp$scope$1087077126$0$createMockedEventEmitter$$();$mockWindow$$.matchMedia=function($query$jscomp$21$$){const $mediaObj$$=$$jscomp$scope$1087077126$0$createMockedEventEmitter$$();$mediaObj$$.matches=!1;$mediaObj$$.media=$query$jscomp$21$$;$mediaObj$$.onchange=null;return $mediaObj$$};return $mockWindow$$}();
$APP.$app$util$globals$document$$=typeof $APP.$goog$global$$.document!=="undefined"?$APP.$goog$global$$.document:$$jscomp$scope$1087077126$0$createMockedEventEmitter$$();$APP.$app$util$globals$location$$=typeof $APP.$goog$global$$.location!=="undefined"?$APP.$goog$global$$.location:$$jscomp$scope$1087077126$0$createMockedEventEmitter$$();$app$util$globals$navigator$$=typeof $APP.$goog$global$$.navigator!=="undefined"?$APP.$goog$global$$.navigator:$$jscomp$scope$1087077126$0$createMockedEventEmitter$$();
$app$util$globals$FormData$$=typeof $APP.$goog$global$$.FormData!=="undefined"?$APP.$goog$global$$.FormData:function(){};var $com$cognitect$transit$util$objectKeys$$=typeof Object.keys!="undefined"?function($obj$jscomp$132$$){return Object.keys($obj$jscomp$132$$)}:function($obj$jscomp$133$$){return $module$contents$goog$object_getKeys$$($obj$jscomp$133$$)},$com$cognitect$transit$util$isArray$$=typeof Array.isArray!="undefined"?function($obj$jscomp$134$$){return Array.isArray($obj$jscomp$134$$)}:function($obj$jscomp$135$$){return $APP.$goog$typeOf$$($obj$jscomp$135$$)==="array"};$com$cognitect$transit$caching$WriteCache$$.prototype.write=function($string$jscomp$10$$,$asMapKey$jscomp$1_entry$jscomp$31$$){return $com$cognitect$transit$caching$isCacheable$$($string$jscomp$10$$,$asMapKey$jscomp$1_entry$jscomp$31$$)?(this.$cacheSize$===4096?(this.clear(),this.$gen$=0,this.cache={}):this.$idx$===1936&&this.clear(),$asMapKey$jscomp$1_entry$jscomp$31$$=this.cache[$string$jscomp$10$$],$asMapKey$jscomp$1_entry$jscomp$31$$==null?(this.cache[$string$jscomp$10$$]=[$com$cognitect$transit$caching$idxToCode$$(this.$idx$),
this.$gen$],this.$idx$++,$string$jscomp$10$$):$asMapKey$jscomp$1_entry$jscomp$31$$[1]!=this.$gen$?($asMapKey$jscomp$1_entry$jscomp$31$$[1]=this.$gen$,$asMapKey$jscomp$1_entry$jscomp$31$$[0]=$com$cognitect$transit$caching$idxToCode$$(this.$idx$),this.$idx$++,$string$jscomp$10$$):$asMapKey$jscomp$1_entry$jscomp$31$$[0]):$string$jscomp$10$$};$com$cognitect$transit$caching$WriteCache$$.prototype.clear=function(){this.$idx$=0;this.$gen$++};
$com$cognitect$transit$caching$ReadCache$$.prototype.write=function($obj$jscomp$136$$){this.$idx$==1936&&(this.$idx$=0);this.cache[this.$idx$]=$obj$jscomp$136$$;this.$idx$++;return $obj$jscomp$136$$};$com$cognitect$transit$caching$ReadCache$$.prototype.read=function($string$jscomp$12$$){return this.cache[$string$jscomp$12$$.length===2?$string$jscomp$12$$.charCodeAt(1)-48:($string$jscomp$12$$.charCodeAt(1)-48)*44+($string$jscomp$12$$.charCodeAt(2)-48)]};
$com$cognitect$transit$caching$ReadCache$$.prototype.clear=function(){this.$idx$=0};var $com$cognitect$transit$eq$hashCodeCounter$$=1,$com$cognitect$transit$eq$stringCodeCache$$={},$com$cognitect$transit$eq$stringCodeCacheSize$$=0;var $com$cognitect$transit$types$ITERATOR$$=typeof Symbol!="undefined"?Symbol.iterator:"@@iterator";$com$cognitect$transit$types$TaggedValue$$.prototype.toString=function(){return"[TaggedValue: "+this.tag+", "+this.rep+"]"};$com$cognitect$transit$types$TaggedValue$$.prototype.equiv=function($other$jscomp$143$$){return $com$cognitect$transit$eq$equals$$(this,$other$jscomp$143$$)};$com$cognitect$transit$types$TaggedValue$$.prototype.equiv=$com$cognitect$transit$types$TaggedValue$$.prototype.equiv;
$com$cognitect$transit$types$TaggedValue$$.prototype.$com$cognitect$transit$equals$=function($other$jscomp$144$$){return $other$jscomp$144$$ instanceof $com$cognitect$transit$types$TaggedValue$$?this.tag===$other$jscomp$144$$.tag&&$com$cognitect$transit$eq$equals$$(this.rep,$other$jscomp$144$$.rep):!1};
$com$cognitect$transit$types$TaggedValue$$.prototype.$com$cognitect$transit$hashCode$=function(){this.$hashCode$===-1&&(this.$hashCode$=$com$cognitect$transit$eq$hashCombine$$($com$cognitect$transit$eq$hashCode$$(this.tag),$com$cognitect$transit$eq$hashCode$$(this.rep)));return this.$hashCode$};var $com$cognitect$transit$types$MAX_INT$$=$module$contents$goog$math$Long_Long$fromString$$("9007199254740991"),$com$cognitect$transit$types$MIN_INT$$=$module$contents$goog$math$Long_Long$fromString$$("-9007199254740991");
$module$contents$goog$math$Long_Long$$.prototype.equiv=function($other$jscomp$145$$){return $com$cognitect$transit$eq$equals$$(this,$other$jscomp$145$$)};$module$contents$goog$math$Long_Long$$.prototype.equiv=$module$contents$goog$math$Long_Long$$.prototype.equiv;$module$contents$goog$math$Long_Long$$.prototype.$com$cognitect$transit$equals$=function($other$jscomp$146$$){return $other$jscomp$146$$ instanceof $module$contents$goog$math$Long_Long$$&&this.equals($other$jscomp$146$$)};
$module$contents$goog$math$Long_Long$$.prototype.$com$cognitect$transit$hashCode$=function(){return this.$low_$};$com$cognitect$transit$types$Keyword$$.prototype.toString=function(){return":"+this.$_name$};$com$cognitect$transit$types$Keyword$$.prototype.namespace=function(){var $idx$jscomp$61$$=this.$_name$.indexOf("/");return $idx$jscomp$61$$!=-1?this.$_name$.substring(0,$idx$jscomp$61$$):null};
$com$cognitect$transit$types$Keyword$$.prototype.name=function(){var $idx$jscomp$62$$=this.$_name$.indexOf("/");return $idx$jscomp$62$$!=-1?this.$_name$.substring($idx$jscomp$62$$+1,this.$_name$.length):this.$_name$};$com$cognitect$transit$types$Keyword$$.prototype.equiv=function($other$jscomp$147$$){return $com$cognitect$transit$eq$equals$$(this,$other$jscomp$147$$)};$com$cognitect$transit$types$Keyword$$.prototype.equiv=$com$cognitect$transit$types$Keyword$$.prototype.equiv;
$com$cognitect$transit$types$Keyword$$.prototype.$com$cognitect$transit$equals$=function($other$jscomp$148$$){return $other$jscomp$148$$ instanceof $com$cognitect$transit$types$Keyword$$&&this.$_name$==$other$jscomp$148$$.$_name$};$com$cognitect$transit$types$Keyword$$.prototype.$com$cognitect$transit$hashCode$=function(){this.$hashCode$===-1&&(this.$hashCode$=$com$cognitect$transit$eq$hashCode$$(this.$_name$));return this.$hashCode$};
$com$cognitect$transit$types$Symbol$$.prototype.namespace=function(){var $idx$jscomp$63$$=this.$_name$.indexOf("/");return $idx$jscomp$63$$!=-1?this.$_name$.substring(0,$idx$jscomp$63$$):null};$com$cognitect$transit$types$Symbol$$.prototype.name=function(){var $idx$jscomp$64$$=this.$_name$.indexOf("/");return $idx$jscomp$64$$!=-1?this.$_name$.substring($idx$jscomp$64$$+1,this.$_name$.length):this.$_name$};$com$cognitect$transit$types$Symbol$$.prototype.toString=function(){return this.$_name$};
$com$cognitect$transit$types$Symbol$$.prototype.equiv=function($other$jscomp$149$$){return $com$cognitect$transit$eq$equals$$(this,$other$jscomp$149$$)};$com$cognitect$transit$types$Symbol$$.prototype.equiv=$com$cognitect$transit$types$Symbol$$.prototype.equiv;$com$cognitect$transit$types$Symbol$$.prototype.$com$cognitect$transit$equals$=function($other$jscomp$150$$){return $other$jscomp$150$$ instanceof $com$cognitect$transit$types$Symbol$$&&this.$_name$==$other$jscomp$150$$.$_name$};
$com$cognitect$transit$types$Symbol$$.prototype.$com$cognitect$transit$hashCode$=function(){this.$hashCode$===-1&&(this.$hashCode$=$com$cognitect$transit$eq$hashCode$$(this.$_name$));return this.$hashCode$};
$com$cognitect$transit$types$UUID$$.prototype.toString=function(){var $hi64$$=this.high,$lo64$$=this.low;var $s$jscomp$467$$=$com$cognitect$transit$types$hexFor$$($hi64$$,0,4)+"-";$s$jscomp$467$$+=$com$cognitect$transit$types$hexFor$$($hi64$$,4,6)+"-";$s$jscomp$467$$+=$com$cognitect$transit$types$hexFor$$($hi64$$,6,8)+"-";$s$jscomp$467$$+=$com$cognitect$transit$types$hexFor$$($lo64$$,0,2)+"-";return $s$jscomp$467$$+=$com$cognitect$transit$types$hexFor$$($lo64$$,2,8)};
$com$cognitect$transit$types$UUID$$.prototype.equiv=function($other$jscomp$151$$){return $com$cognitect$transit$eq$equals$$(this,$other$jscomp$151$$)};$com$cognitect$transit$types$UUID$$.prototype.equiv=$com$cognitect$transit$types$UUID$$.prototype.equiv;$com$cognitect$transit$types$UUID$$.prototype.$com$cognitect$transit$equals$=function($other$jscomp$152$$){return $other$jscomp$152$$ instanceof $com$cognitect$transit$types$UUID$$&&this.high.equals($other$jscomp$152$$.high)&&this.low.equals($other$jscomp$152$$.low)};
$com$cognitect$transit$types$UUID$$.prototype.$com$cognitect$transit$hashCode$=function(){this.$hashCode$===-1&&(this.$hashCode$=$com$cognitect$transit$eq$hashCode$$(this.toString()));return this.$hashCode$};Date.prototype.$com$cognitect$transit$equals$=function($other$jscomp$153$$){return $other$jscomp$153$$ instanceof Date?this.valueOf()===$other$jscomp$153$$.valueOf():!1};Date.prototype.$com$cognitect$transit$hashCode$=function(){return this.valueOf()};
$com$cognitect$transit$types$TransitArrayMapIterator$$.prototype.next=function(){if(this.$idx$<this.entries.length){var $ret$jscomp$118$$={value:this.type===0?this.entries[this.$idx$]:this.type===1?this.entries[this.$idx$+1]:[this.entries[this.$idx$],this.entries[this.$idx$+1]],done:!1};this.$idx$+=2;return $ret$jscomp$118$$}return{value:null,done:!0}};$com$cognitect$transit$types$TransitArrayMapIterator$$.prototype.next=$com$cognitect$transit$types$TransitArrayMapIterator$$.prototype.next;
$com$cognitect$transit$types$TransitArrayMapIterator$$.prototype[$com$cognitect$transit$types$ITERATOR$$]=function(){return this};
$com$cognitect$transit$types$TransitMapIterator$$.prototype.next=function(){if(this.$idx$<this.map.size){this.$bucket$!=null&&this.$bucketIdx$<this.$bucket$.length||(this.$bucket$=this.map.map[this.keys[this.$idx$]],this.$bucketIdx$=0);var $ret$jscomp$119$$={value:this.type===0?this.$bucket$[this.$bucketIdx$]:this.type===1?this.$bucket$[this.$bucketIdx$+1]:[this.$bucket$[this.$bucketIdx$],this.$bucket$[this.$bucketIdx$+1]],done:!1};this.$idx$++;this.$bucketIdx$+=2;return $ret$jscomp$119$$}return{value:null,
done:!0}};$com$cognitect$transit$types$TransitMapIterator$$.prototype.next=$com$cognitect$transit$types$TransitMapIterator$$.prototype.next;$com$cognitect$transit$types$TransitMapIterator$$.prototype[$com$cognitect$transit$types$ITERATOR$$]=function(){return this};$com$cognitect$transit$types$TransitArrayMap$$.prototype.toString=function(){return $com$cognitect$transit$types$printMap$$(this)};$com$cognitect$transit$types$TransitArrayMap$$.prototype.inspect=function(){return this.toString()};
$com$cognitect$transit$types$TransitArrayMap$$.prototype.clear=function(){this.$hashCode$=-1;this.$backingMap$?this.$backingMap$.clear():this.$_entries$=[];this.size=0};$com$cognitect$transit$types$TransitArrayMap$$.prototype.clear=$com$cognitect$transit$types$TransitArrayMap$$.prototype.clear;$com$cognitect$transit$types$TransitArrayMap$$.prototype.keys=function(){return this.$backingMap$?this.$backingMap$.keys():new $com$cognitect$transit$types$TransitArrayMapIterator$$(this.$_entries$,0)};
$com$cognitect$transit$types$TransitArrayMap$$.prototype.keys=$com$cognitect$transit$types$TransitArrayMap$$.prototype.keys;$com$cognitect$transit$types$TransitArrayMap$$.prototype.$keySet$=function(){if(this.$backingMap$)return this.$backingMap$.$keySet$();for(var $ret$jscomp$120$$=[],$i$jscomp$407$$=0,$j$jscomp$104$$=0;$j$jscomp$104$$<this.$_entries$.length;$i$jscomp$407$$++,$j$jscomp$104$$+=2)$ret$jscomp$120$$[$i$jscomp$407$$]=this.$_entries$[$j$jscomp$104$$];return $ret$jscomp$120$$};
$com$cognitect$transit$types$TransitArrayMap$$.prototype.keySet=$com$cognitect$transit$types$TransitArrayMap$$.prototype.$keySet$;$com$cognitect$transit$types$TransitArrayMap$$.prototype.entries=function(){return this.$backingMap$?this.$backingMap$.entries():new $com$cognitect$transit$types$TransitArrayMapIterator$$(this.$_entries$,2)};$com$cognitect$transit$types$TransitArrayMap$$.prototype.entries=$com$cognitect$transit$types$TransitArrayMap$$.prototype.entries;
$com$cognitect$transit$types$TransitArrayMap$$.prototype.values=function(){return this.$backingMap$?this.$backingMap$.values():new $com$cognitect$transit$types$TransitArrayMapIterator$$(this.$_entries$,1)};$com$cognitect$transit$types$TransitArrayMap$$.prototype.values=$com$cognitect$transit$types$TransitArrayMap$$.prototype.values;
$com$cognitect$transit$types$TransitArrayMap$$.prototype.forEach=function($f$jscomp$594$$){if(this.$backingMap$)this.$backingMap$.forEach($f$jscomp$594$$);else for(var $i$jscomp$408$$=0;$i$jscomp$408$$<this.$_entries$.length;$i$jscomp$408$$+=2)$f$jscomp$594$$(this.$_entries$[$i$jscomp$408$$+1],this.$_entries$[$i$jscomp$408$$])};$com$cognitect$transit$types$TransitArrayMap$$.prototype.forEach=$com$cognitect$transit$types$TransitArrayMap$$.prototype.forEach;
$com$cognitect$transit$types$TransitArrayMap$$.prototype.get=function($k$jscomp$529$$,$notFound$$){if(this.$backingMap$)return this.$backingMap$.get($k$jscomp$529$$);if($JSCompiler_StaticMethods_convert$$(this))return this.get($k$jscomp$529$$);for(var $i$jscomp$409$$=0;$i$jscomp$409$$<this.$_entries$.length;$i$jscomp$409$$+=2)if($com$cognitect$transit$eq$equals$$(this.$_entries$[$i$jscomp$409$$],$k$jscomp$529$$))return this.$_entries$[$i$jscomp$409$$+1];return $notFound$$};
$com$cognitect$transit$types$TransitArrayMap$$.prototype.get=$com$cognitect$transit$types$TransitArrayMap$$.prototype.get;
$com$cognitect$transit$types$TransitArrayMap$$.prototype.has=function($k$jscomp$530$$){if(this.$backingMap$)return this.$backingMap$.has($k$jscomp$530$$);if($JSCompiler_StaticMethods_convert$$(this))return this.has($k$jscomp$530$$);for(var $i$jscomp$410$$=0;$i$jscomp$410$$<this.$_entries$.length;$i$jscomp$410$$+=2)if($com$cognitect$transit$eq$equals$$(this.$_entries$[$i$jscomp$410$$],$k$jscomp$530$$))return!0;return!1};$com$cognitect$transit$types$TransitArrayMap$$.prototype.has=$com$cognitect$transit$types$TransitArrayMap$$.prototype.has;
$com$cognitect$transit$types$TransitArrayMap$$.prototype.set=function($k$jscomp$531$$,$v$jscomp$328$$){this.$hashCode$=-1;if(this.$backingMap$)this.$backingMap$.set($k$jscomp$531$$,$v$jscomp$328$$),this.size=this.$backingMap$.size;else{for(var $i$jscomp$411$$=0;$i$jscomp$411$$<this.$_entries$.length;$i$jscomp$411$$+=2)if($com$cognitect$transit$eq$equals$$(this.$_entries$[$i$jscomp$411$$],$k$jscomp$531$$)){this.$_entries$[$i$jscomp$411$$+1]=$v$jscomp$328$$;return}this.$_entries$.push($k$jscomp$531$$);
this.$_entries$.push($v$jscomp$328$$);this.size++;this.size>32&&(this.$backingMap$=$com$cognitect$transit$types$map$$(this.$_entries$,!1,!0),this.$_entries$=null)}};$com$cognitect$transit$types$TransitArrayMap$$.prototype.set=$com$cognitect$transit$types$TransitArrayMap$$.prototype.set;
$com$cognitect$transit$types$TransitArrayMap$$.prototype["delete"]=function($k$jscomp$532_ret$jscomp$121$$){this.$hashCode$=-1;if(this.$backingMap$)return $k$jscomp$532_ret$jscomp$121$$=this.$backingMap$.delete($k$jscomp$532_ret$jscomp$121$$),this.size=this.$backingMap$.size,$k$jscomp$532_ret$jscomp$121$$;for(var $i$jscomp$412$$=0;$i$jscomp$412$$<this.$_entries$.length;$i$jscomp$412$$+=2)if($com$cognitect$transit$eq$equals$$(this.$_entries$[$i$jscomp$412$$],$k$jscomp$532_ret$jscomp$121$$))return $k$jscomp$532_ret$jscomp$121$$=
this.$_entries$[$i$jscomp$412$$+1],this.$_entries$.splice($i$jscomp$412$$,2),this.size--,$k$jscomp$532_ret$jscomp$121$$};$com$cognitect$transit$types$TransitArrayMap$$.prototype.clone=function(){var $clone$jscomp$2$$=$com$cognitect$transit$types$map$$();this.forEach(function($v$jscomp$329$$,$k$jscomp$533$$){$clone$jscomp$2$$.set($k$jscomp$533$$,$v$jscomp$329$$)});return $clone$jscomp$2$$};$com$cognitect$transit$types$TransitArrayMap$$.prototype.clone=$com$cognitect$transit$types$TransitArrayMap$$.prototype.clone;
$com$cognitect$transit$types$TransitArrayMap$$.prototype[$com$cognitect$transit$types$ITERATOR$$]=function(){return this.entries()};$com$cognitect$transit$types$TransitArrayMap$$.prototype.$com$cognitect$transit$hashCode$=function(){if(this.$backingMap$)return this.$backingMap$.$com$cognitect$transit$hashCode$();this.$hashCode$===-1&&(this.$hashCode$=$com$cognitect$transit$eq$hashMapLike$$(this));return this.$hashCode$};
$com$cognitect$transit$types$TransitArrayMap$$.prototype.$com$cognitect$transit$equals$=function($other$jscomp$154$$){return this.$backingMap$?$com$cognitect$transit$types$mapEquals$$(this.$backingMap$,$other$jscomp$154$$):$com$cognitect$transit$types$mapEquals$$(this,$other$jscomp$154$$)};$com$cognitect$transit$types$TransitMap$$.prototype.toString=function(){return $com$cognitect$transit$types$printMap$$(this)};$com$cognitect$transit$types$TransitMap$$.prototype.inspect=function(){return this.toString()};
$com$cognitect$transit$types$TransitMap$$.prototype.clear=function(){this.$hashCode$=-1;this.map={};this.$_keys$=[];this.size=0};$com$cognitect$transit$types$TransitMap$$.prototype.clear=$com$cognitect$transit$types$TransitMap$$.prototype.clear;$com$cognitect$transit$types$TransitMap$$.prototype.$getKeys$=function(){return this.$_keys$!=null?this.$_keys$:$com$cognitect$transit$util$objectKeys$$(this.map)};
$com$cognitect$transit$types$TransitMap$$.prototype["delete"]=function($k$jscomp$534_ret$jscomp$122$$){this.$hashCode$=-1;this.$_keys$=null;for(var $code$jscomp$11$$=$com$cognitect$transit$eq$hashCode$$($k$jscomp$534_ret$jscomp$122$$),$bucket$jscomp$3$$=this.map[$code$jscomp$11$$],$i$jscomp$413$$=0;$i$jscomp$413$$<$bucket$jscomp$3$$.length;$i$jscomp$413$$+=2)if($com$cognitect$transit$eq$equals$$($k$jscomp$534_ret$jscomp$122$$,$bucket$jscomp$3$$[$i$jscomp$413$$]))return $k$jscomp$534_ret$jscomp$122$$=
$bucket$jscomp$3$$[$i$jscomp$413$$+1],$bucket$jscomp$3$$.splice($i$jscomp$413$$,2),$bucket$jscomp$3$$.length===0&&delete this.map[$code$jscomp$11$$],this.size--,$k$jscomp$534_ret$jscomp$122$$};$com$cognitect$transit$types$TransitMap$$.prototype.entries=function(){return new $com$cognitect$transit$types$TransitMapIterator$$(this,2)};$com$cognitect$transit$types$TransitMap$$.prototype.entries=$com$cognitect$transit$types$TransitMap$$.prototype.entries;
$com$cognitect$transit$types$TransitMap$$.prototype.forEach=function($callback$jscomp$77$$){for(var $ks$jscomp$54$$=this.$getKeys$(),$i$jscomp$414$$=0;$i$jscomp$414$$<$ks$jscomp$54$$.length;$i$jscomp$414$$++)for(var $bucket$jscomp$4$$=this.map[$ks$jscomp$54$$[$i$jscomp$414$$]],$j$jscomp$105$$=0;$j$jscomp$105$$<$bucket$jscomp$4$$.length;$j$jscomp$105$$+=2)$callback$jscomp$77$$($bucket$jscomp$4$$[$j$jscomp$105$$+1],$bucket$jscomp$4$$[$j$jscomp$105$$],this)};
$com$cognitect$transit$types$TransitMap$$.prototype.forEach=$com$cognitect$transit$types$TransitMap$$.prototype.forEach;
$com$cognitect$transit$types$TransitMap$$.prototype.get=function($k$jscomp$535$$,$i$jscomp$415_notFound$jscomp$1$$){var $bucket$jscomp$5_code$jscomp$12$$=$com$cognitect$transit$eq$hashCode$$($k$jscomp$535$$);$bucket$jscomp$5_code$jscomp$12$$=this.map[$bucket$jscomp$5_code$jscomp$12$$];if($bucket$jscomp$5_code$jscomp$12$$!=null)for($i$jscomp$415_notFound$jscomp$1$$=0;$i$jscomp$415_notFound$jscomp$1$$<$bucket$jscomp$5_code$jscomp$12$$.length;$i$jscomp$415_notFound$jscomp$1$$+=2){if($com$cognitect$transit$eq$equals$$($k$jscomp$535$$,
$bucket$jscomp$5_code$jscomp$12$$[$i$jscomp$415_notFound$jscomp$1$$]))return $bucket$jscomp$5_code$jscomp$12$$[$i$jscomp$415_notFound$jscomp$1$$+1]}else return $i$jscomp$415_notFound$jscomp$1$$};$com$cognitect$transit$types$TransitMap$$.prototype.get=$com$cognitect$transit$types$TransitMap$$.prototype.get;
$com$cognitect$transit$types$TransitMap$$.prototype.has=function($k$jscomp$536$$){var $bucket$jscomp$6_code$jscomp$13$$=$com$cognitect$transit$eq$hashCode$$($k$jscomp$536$$);$bucket$jscomp$6_code$jscomp$13$$=this.map[$bucket$jscomp$6_code$jscomp$13$$];if($bucket$jscomp$6_code$jscomp$13$$!=null)for(var $i$jscomp$416$$=0;$i$jscomp$416$$<$bucket$jscomp$6_code$jscomp$13$$.length;$i$jscomp$416$$+=2)if($com$cognitect$transit$eq$equals$$($k$jscomp$536$$,$bucket$jscomp$6_code$jscomp$13$$[$i$jscomp$416$$]))return!0;
return!1};$com$cognitect$transit$types$TransitMap$$.prototype.has=$com$cognitect$transit$types$TransitMap$$.prototype.has;$com$cognitect$transit$types$TransitMap$$.prototype.keys=function(){return new $com$cognitect$transit$types$TransitMapIterator$$(this,0)};$com$cognitect$transit$types$TransitMap$$.prototype.keys=$com$cognitect$transit$types$TransitMap$$.prototype.keys;
$com$cognitect$transit$types$TransitMap$$.prototype.$keySet$=function(){for(var $keys$jscomp$46$$=this.$getKeys$(),$ret$jscomp$123$$=[],$i$jscomp$417$$=0;$i$jscomp$417$$<$keys$jscomp$46$$.length;$i$jscomp$417$$++)for(var $bucket$jscomp$7$$=this.map[$keys$jscomp$46$$[$i$jscomp$417$$]],$j$jscomp$106$$=0;$j$jscomp$106$$<$bucket$jscomp$7$$.length;$j$jscomp$106$$+=2)$ret$jscomp$123$$.push($bucket$jscomp$7$$[$j$jscomp$106$$]);return $ret$jscomp$123$$};
$com$cognitect$transit$types$TransitMap$$.prototype.keySet=$com$cognitect$transit$types$TransitMap$$.prototype.$keySet$;
$com$cognitect$transit$types$TransitMap$$.prototype.set=function($k$jscomp$537$$,$v$jscomp$330$$){this.$hashCode$=-1;var $code$jscomp$14_newEntry$$=$com$cognitect$transit$eq$hashCode$$($k$jscomp$537$$),$bucket$jscomp$8$$=this.map[$code$jscomp$14_newEntry$$];if($bucket$jscomp$8$$==null)this.$_keys$&&this.$_keys$.push($code$jscomp$14_newEntry$$),this.map[$code$jscomp$14_newEntry$$]=[$k$jscomp$537$$,$v$jscomp$330$$],this.size++;else{$code$jscomp$14_newEntry$$=!0;for(var $i$jscomp$418$$=0;$i$jscomp$418$$<
$bucket$jscomp$8$$.length;$i$jscomp$418$$+=2)if($com$cognitect$transit$eq$equals$$($v$jscomp$330$$,$bucket$jscomp$8$$[$i$jscomp$418$$])){$code$jscomp$14_newEntry$$=!1;$bucket$jscomp$8$$[$i$jscomp$418$$]=$v$jscomp$330$$;break}$code$jscomp$14_newEntry$$&&($bucket$jscomp$8$$.push($k$jscomp$537$$),$bucket$jscomp$8$$.push($v$jscomp$330$$),this.size++)}};$com$cognitect$transit$types$TransitMap$$.prototype.set=$com$cognitect$transit$types$TransitMap$$.prototype.set;
$com$cognitect$transit$types$TransitMap$$.prototype.values=function(){return new $com$cognitect$transit$types$TransitMapIterator$$(this,1)};$com$cognitect$transit$types$TransitMap$$.prototype.values=$com$cognitect$transit$types$TransitMap$$.prototype.values;$com$cognitect$transit$types$TransitMap$$.prototype.clone=function(){var $clone$jscomp$3$$=$com$cognitect$transit$types$map$$();this.forEach(function($v$jscomp$331$$,$k$jscomp$538$$){$clone$jscomp$3$$.set($k$jscomp$538$$,$v$jscomp$331$$)});return $clone$jscomp$3$$};
$com$cognitect$transit$types$TransitMap$$.prototype.clone=$com$cognitect$transit$types$TransitMap$$.prototype.clone;$com$cognitect$transit$types$TransitMap$$.prototype[$com$cognitect$transit$types$ITERATOR$$]=function(){return this.entries()};$com$cognitect$transit$types$TransitMap$$.prototype.$com$cognitect$transit$hashCode$=function(){this.$hashCode$===-1&&(this.$hashCode$=$com$cognitect$transit$eq$hashMapLike$$(this));return this.$hashCode$};
$com$cognitect$transit$types$TransitMap$$.prototype.$com$cognitect$transit$equals$=function($other$jscomp$155$$){return $com$cognitect$transit$types$mapEquals$$(this,$other$jscomp$155$$)};$com$cognitect$transit$types$TransitSet$$.prototype.toString=function(){return $com$cognitect$transit$types$printSet$$(this)};$com$cognitect$transit$types$TransitSet$$.prototype.inspect=function(){return this.toString()};
$com$cognitect$transit$types$TransitSet$$.prototype.add=function($value$jscomp$358$$){this.map.set($value$jscomp$358$$,$value$jscomp$358$$);this.size=this.map.size};$com$cognitect$transit$types$TransitSet$$.prototype.add=$com$cognitect$transit$types$TransitSet$$.prototype.add;$com$cognitect$transit$types$TransitSet$$.prototype.clear=function(){this.map=new $com$cognitect$transit$types$TransitMap$$;this.size=0};$com$cognitect$transit$types$TransitSet$$.prototype.clear=$com$cognitect$transit$types$TransitSet$$.prototype.clear;
$com$cognitect$transit$types$TransitSet$$.prototype["delete"]=function($ret$jscomp$124_value$jscomp$359$$){$ret$jscomp$124_value$jscomp$359$$=this.map.delete($ret$jscomp$124_value$jscomp$359$$);this.size=this.map.size;return $ret$jscomp$124_value$jscomp$359$$};$com$cognitect$transit$types$TransitSet$$.prototype.entries=function(){return this.map.entries()};$com$cognitect$transit$types$TransitSet$$.prototype.entries=$com$cognitect$transit$types$TransitSet$$.prototype.entries;
$com$cognitect$transit$types$TransitSet$$.prototype.forEach=function($iterator$jscomp$9$$){var $self$jscomp$33$$=this;this.map.forEach(function($v$jscomp$332$$,$k$jscomp$539$$){$iterator$jscomp$9$$($k$jscomp$539$$,$self$jscomp$33$$)})};$com$cognitect$transit$types$TransitSet$$.prototype.forEach=$com$cognitect$transit$types$TransitSet$$.prototype.forEach;$com$cognitect$transit$types$TransitSet$$.prototype.has=function($value$jscomp$360$$){return this.map.has($value$jscomp$360$$)};
$com$cognitect$transit$types$TransitSet$$.prototype.has=$com$cognitect$transit$types$TransitSet$$.prototype.has;$com$cognitect$transit$types$TransitSet$$.prototype.keys=function(){return this.map.keys()};$com$cognitect$transit$types$TransitSet$$.prototype.keys=$com$cognitect$transit$types$TransitSet$$.prototype.keys;$com$cognitect$transit$types$TransitSet$$.prototype.$keySet$=function(){return this.map.$keySet$()};$com$cognitect$transit$types$TransitSet$$.prototype.keySet=$com$cognitect$transit$types$TransitSet$$.prototype.$keySet$;
$com$cognitect$transit$types$TransitSet$$.prototype.values=function(){return this.map.values()};$com$cognitect$transit$types$TransitSet$$.prototype.values=$com$cognitect$transit$types$TransitSet$$.prototype.values;$com$cognitect$transit$types$TransitSet$$.prototype.clone=function(){var $clone$jscomp$4$$=$com$cognitect$transit$types$set$$();this.forEach(function($k$jscomp$540$$){$clone$jscomp$4$$.add($k$jscomp$540$$)});return $clone$jscomp$4$$};
$com$cognitect$transit$types$TransitSet$$.prototype.clone=$com$cognitect$transit$types$TransitSet$$.prototype.clone;$com$cognitect$transit$types$TransitSet$$.prototype[$com$cognitect$transit$types$ITERATOR$$]=function(){return this.values()};
$com$cognitect$transit$types$TransitSet$$.prototype.$com$cognitect$transit$equals$=function($other$jscomp$156$$){if($other$jscomp$156$$ instanceof $com$cognitect$transit$types$TransitSet$$){if(this.size===$other$jscomp$156$$.size)return $com$cognitect$transit$eq$equals$$(this.map,$other$jscomp$156$$.map)}else return!1};$com$cognitect$transit$types$TransitSet$$.prototype.$com$cognitect$transit$hashCode$=function(){return $com$cognitect$transit$eq$hashCode$$(this.map)};$com$cognitect$transit$impl$decoder$Decoder$$.prototype.$defaults$={$handlers$:{_:function(){return null},"?":function($v$jscomp$335$$){return $v$jscomp$335$$==="t"},b:function($len$jscomp$inline_11587_str$jscomp$inline_14188_v$jscomp$336$$,$bc$jscomp$inline_14189_bytes$jscomp$inline_11588_d$jscomp$172$$){if($bc$jscomp$inline_14189_bytes$jscomp$inline_11588_d$jscomp$172$$&&$bc$jscomp$inline_14189_bytes$jscomp$inline_11588_d$jscomp$172$$.$preferBuffers$===!1||typeof $APP.$goog$global$$.$Buffer$=="undefined")if(typeof Uint8Array!=
"undefined"){if(typeof atob!="undefined")var $JSCompiler_temp$jscomp$10712_JSCompiler_temp$jscomp$10713_binary_string$jscomp$inline_11586_bs$jscomp$inline_14190$$=atob($len$jscomp$inline_11587_str$jscomp$inline_14188_v$jscomp$336$$);else{$len$jscomp$inline_11587_str$jscomp$inline_14188_v$jscomp$336$$=String($len$jscomp$inline_11587_str$jscomp$inline_14188_v$jscomp$336$$).replace(/=+$/,"");if($len$jscomp$inline_11587_str$jscomp$inline_14188_v$jscomp$336$$.length%4==1)throw Error("'atob' failed: The string to be decoded is not correctly encoded.");
$bc$jscomp$inline_14189_bytes$jscomp$inline_11588_d$jscomp$172$$=0;for(var $buffer$jscomp$inline_14191_i$jscomp$inline_11589$$,$idx$jscomp$inline_14192$$=0,$output$jscomp$inline_14193$$="";$buffer$jscomp$inline_14191_i$jscomp$inline_11589$$=$len$jscomp$inline_11587_str$jscomp$inline_14188_v$jscomp$336$$.charAt($idx$jscomp$inline_14192$$++);~$buffer$jscomp$inline_14191_i$jscomp$inline_11589$$&&($JSCompiler_temp$jscomp$10712_JSCompiler_temp$jscomp$10713_binary_string$jscomp$inline_11586_bs$jscomp$inline_14190$$=
$bc$jscomp$inline_14189_bytes$jscomp$inline_11588_d$jscomp$172$$%4?$JSCompiler_temp$jscomp$10712_JSCompiler_temp$jscomp$10713_binary_string$jscomp$inline_11586_bs$jscomp$inline_14190$$*64+$buffer$jscomp$inline_14191_i$jscomp$inline_11589$$:$buffer$jscomp$inline_14191_i$jscomp$inline_11589$$,$bc$jscomp$inline_14189_bytes$jscomp$inline_11588_d$jscomp$172$$++%4)?$output$jscomp$inline_14193$$+=String.fromCharCode(255&$JSCompiler_temp$jscomp$10712_JSCompiler_temp$jscomp$10713_binary_string$jscomp$inline_11586_bs$jscomp$inline_14190$$>>
(-2*$bc$jscomp$inline_14189_bytes$jscomp$inline_11588_d$jscomp$172$$&6)):0)$buffer$jscomp$inline_14191_i$jscomp$inline_11589$$="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\x3d".indexOf($buffer$jscomp$inline_14191_i$jscomp$inline_11589$$);$JSCompiler_temp$jscomp$10712_JSCompiler_temp$jscomp$10713_binary_string$jscomp$inline_11586_bs$jscomp$inline_14190$$=$output$jscomp$inline_14193$$}$len$jscomp$inline_11587_str$jscomp$inline_14188_v$jscomp$336$$=$JSCompiler_temp$jscomp$10712_JSCompiler_temp$jscomp$10713_binary_string$jscomp$inline_11586_bs$jscomp$inline_14190$$.length;
$bc$jscomp$inline_14189_bytes$jscomp$inline_11588_d$jscomp$172$$=new Uint8Array($len$jscomp$inline_11587_str$jscomp$inline_14188_v$jscomp$336$$);for($buffer$jscomp$inline_14191_i$jscomp$inline_11589$$=0;$buffer$jscomp$inline_14191_i$jscomp$inline_11589$$<$len$jscomp$inline_11587_str$jscomp$inline_14188_v$jscomp$336$$;$buffer$jscomp$inline_14191_i$jscomp$inline_11589$$++)$bc$jscomp$inline_14189_bytes$jscomp$inline_11588_d$jscomp$172$$[$buffer$jscomp$inline_14191_i$jscomp$inline_11589$$]=$JSCompiler_temp$jscomp$10712_JSCompiler_temp$jscomp$10713_binary_string$jscomp$inline_11586_bs$jscomp$inline_14190$$.charCodeAt($buffer$jscomp$inline_14191_i$jscomp$inline_11589$$);
$JSCompiler_temp$jscomp$10712_JSCompiler_temp$jscomp$10713_binary_string$jscomp$inline_11586_bs$jscomp$inline_14190$$=$bc$jscomp$inline_14189_bytes$jscomp$inline_11588_d$jscomp$172$$}else $JSCompiler_temp$jscomp$10712_JSCompiler_temp$jscomp$10713_binary_string$jscomp$inline_11586_bs$jscomp$inline_14190$$=$com$cognitect$transit$types$taggedValue$$("b",$len$jscomp$inline_11587_str$jscomp$inline_14188_v$jscomp$336$$);else $JSCompiler_temp$jscomp$10712_JSCompiler_temp$jscomp$10713_binary_string$jscomp$inline_11586_bs$jscomp$inline_14190$$=
new $APP.$goog$global$$.$Buffer$($len$jscomp$inline_11587_str$jscomp$inline_14188_v$jscomp$336$$,"base64");return $JSCompiler_temp$jscomp$10712_JSCompiler_temp$jscomp$10713_binary_string$jscomp$inline_11586_bs$jscomp$inline_14190$$},i:function($JSCompiler_inline_result$jscomp$569_n$jscomp$inline_4164_v$jscomp$337$$){typeof $JSCompiler_inline_result$jscomp$569_n$jscomp$inline_4164_v$jscomp$337$$==="number"||$JSCompiler_inline_result$jscomp$569_n$jscomp$inline_4164_v$jscomp$337$$ instanceof $module$contents$goog$math$Long_Long$$||
($JSCompiler_inline_result$jscomp$569_n$jscomp$inline_4164_v$jscomp$337$$=$module$contents$goog$math$Long_Long$fromString$$($JSCompiler_inline_result$jscomp$569_n$jscomp$inline_4164_v$jscomp$337$$,10),$JSCompiler_inline_result$jscomp$569_n$jscomp$inline_4164_v$jscomp$337$$=$JSCompiler_inline_result$jscomp$569_n$jscomp$inline_4164_v$jscomp$337$$.compare($com$cognitect$transit$types$MAX_INT$$)>0||$JSCompiler_inline_result$jscomp$569_n$jscomp$inline_4164_v$jscomp$337$$.compare($com$cognitect$transit$types$MIN_INT$$)<
0?$JSCompiler_inline_result$jscomp$569_n$jscomp$inline_4164_v$jscomp$337$$:$JSCompiler_StaticMethods_toNumber$$($JSCompiler_inline_result$jscomp$569_n$jscomp$inline_4164_v$jscomp$337$$));return $JSCompiler_inline_result$jscomp$569_n$jscomp$inline_4164_v$jscomp$337$$},n:function($v$jscomp$338$$){return $com$cognitect$transit$types$taggedValue$$("n",$v$jscomp$338$$)},d:function($v$jscomp$339$$){return parseFloat($v$jscomp$339$$)},f:function($v$jscomp$340$$){return $com$cognitect$transit$types$taggedValue$$("f",
$v$jscomp$340$$)},c:function($v$jscomp$341$$){return $v$jscomp$341$$},":":function($v$jscomp$342$$){return new $com$cognitect$transit$types$Keyword$$($v$jscomp$342$$)},$:function($v$jscomp$343$$){return new $com$cognitect$transit$types$Symbol$$($v$jscomp$343$$)},r:function($v$jscomp$344$$){return $com$cognitect$transit$types$taggedValue$$("r",$v$jscomp$344$$)},z:function($JSCompiler_inline_result$jscomp$572_v$jscomp$345$$){a:switch($JSCompiler_inline_result$jscomp$572_v$jscomp$345$$){case "-INF":$JSCompiler_inline_result$jscomp$572_v$jscomp$345$$=
-Infinity;break a;case "INF":$JSCompiler_inline_result$jscomp$572_v$jscomp$345$$=Infinity;break a;case "NaN":$JSCompiler_inline_result$jscomp$572_v$jscomp$345$$=NaN;break a;default:throw Error("Invalid special double value "+$JSCompiler_inline_result$jscomp$572_v$jscomp$345$$);}return $JSCompiler_inline_result$jscomp$572_v$jscomp$345$$},"'":function($v$jscomp$346$$){return $v$jscomp$346$$},m:function($s$jscomp$inline_4168_v$jscomp$347$$){$s$jscomp$inline_4168_v$jscomp$347$$=typeof $s$jscomp$inline_4168_v$jscomp$347$$===
"number"?$s$jscomp$inline_4168_v$jscomp$347$$:parseInt($s$jscomp$inline_4168_v$jscomp$347$$,10);return new Date($s$jscomp$inline_4168_v$jscomp$347$$)},t:function($v$jscomp$348$$){return new Date($v$jscomp$348$$)},u:function($s$jscomp$inline_11591_v$jscomp$349$$){$s$jscomp$inline_11591_v$jscomp$349$$=$s$jscomp$inline_11591_v$jscomp$349$$.replace(/-/g,"");var $hi32$jscomp$inline_11594$$,$off$jscomp$inline_11596$$;var $i$jscomp$inline_11597$$=$hi32$jscomp$inline_11594$$=0;for($off$jscomp$inline_11596$$=
24;$i$jscomp$inline_11597$$<8;$i$jscomp$inline_11597$$+=2,$off$jscomp$inline_11596$$-=8)$hi32$jscomp$inline_11594$$|=parseInt($s$jscomp$inline_11591_v$jscomp$349$$.substring($i$jscomp$inline_11597$$,$i$jscomp$inline_11597$$+2),16)<<$off$jscomp$inline_11596$$;var $lo32$jscomp$inline_11595$$=0;$i$jscomp$inline_11597$$=8;for($off$jscomp$inline_11596$$=24;$i$jscomp$inline_11597$$<16;$i$jscomp$inline_11597$$+=2,$off$jscomp$inline_11596$$-=8)$lo32$jscomp$inline_11595$$|=parseInt($s$jscomp$inline_11591_v$jscomp$349$$.substring($i$jscomp$inline_11597$$,
$i$jscomp$inline_11597$$+2),16)<<$off$jscomp$inline_11596$$;var $hi64$jscomp$inline_11592$$=$module$contents$goog$math$Long_Long$fromBits$$($lo32$jscomp$inline_11595$$,$hi32$jscomp$inline_11594$$);$hi32$jscomp$inline_11594$$=0;$i$jscomp$inline_11597$$=16;for($off$jscomp$inline_11596$$=24;$i$jscomp$inline_11597$$<24;$i$jscomp$inline_11597$$+=2,$off$jscomp$inline_11596$$-=8)$hi32$jscomp$inline_11594$$|=parseInt($s$jscomp$inline_11591_v$jscomp$349$$.substring($i$jscomp$inline_11597$$,$i$jscomp$inline_11597$$+
2),16)<<$off$jscomp$inline_11596$$;$lo32$jscomp$inline_11595$$=0;for($off$jscomp$inline_11596$$=$i$jscomp$inline_11597$$=24;$i$jscomp$inline_11597$$<32;$i$jscomp$inline_11597$$+=2,$off$jscomp$inline_11596$$-=8)$lo32$jscomp$inline_11595$$|=parseInt($s$jscomp$inline_11591_v$jscomp$349$$.substring($i$jscomp$inline_11597$$,$i$jscomp$inline_11597$$+2),16)<<$off$jscomp$inline_11596$$;return new $com$cognitect$transit$types$UUID$$($hi64$jscomp$inline_11592$$,$module$contents$goog$math$Long_Long$fromBits$$($lo32$jscomp$inline_11595$$,
$hi32$jscomp$inline_11594$$))},set:function($v$jscomp$350$$){return $com$cognitect$transit$types$set$$($v$jscomp$350$$)},list:function($v$jscomp$351$$){return $com$cognitect$transit$types$taggedValue$$("list",$v$jscomp$351$$)},link:function($v$jscomp$352$$){return $com$cognitect$transit$types$taggedValue$$("link",$v$jscomp$352$$)},cmap:function($v$jscomp$353$$){return $com$cognitect$transit$types$map$$($v$jscomp$353$$,!1)}},$defaultHandler$:function($c$jscomp$226$$,$val$jscomp$140$$){return $com$cognitect$transit$types$taggedValue$$($c$jscomp$226$$,
$val$jscomp$140$$)},$preferStrings$:!0,$preferBuffers$:!0};
$com$cognitect$transit$impl$decoder$Decoder$$.prototype.decode=function($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$,$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$,$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$){if($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$==null)return null;
switch(typeof $node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$){case "string":return $com$cognitect$transit$caching$isCacheable$$($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$,$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$)?($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$=$JSCompiler_StaticMethods_parseString$$(this,$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$),$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$&&
$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$.write($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$,$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$),$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$=$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$):$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$=
$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$.charAt(0)==="^"&&$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$.charAt(1)!==" "?$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$.read($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$,$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$):$JSCompiler_StaticMethods_parseString$$(this,$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$),
$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$;case "object":if($com$cognitect$transit$util$isArray$$($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$))if($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$[0]==="^ ")if(this.$mapBuilder$)if($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$.length<17&&this.$mapBuilder$.fromArray){$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$=
[];for($asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$=1;$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$<$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$.length;$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$+=2)$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$.push(this.decode($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$[$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$],
$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,!0,!1)),$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$.push(this.decode($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$[$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$+1],$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,
!1,!1));$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$=this.$mapBuilder$.fromArray($i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$,$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$)}else{$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$=this.$mapBuilder$.init($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$);
for($asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$=1;$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$<$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$.length;$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$+=2)$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$=this.$mapBuilder$.add($i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$,
this.decode($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$[$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$],$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,!0,!1),this.decode($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$[$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$+1],$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,
!1,!1),$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$);$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$=this.$mapBuilder$.finalize($i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$,$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$)}else{$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$=[];for($asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$=
1;$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$<$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$.length;$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$+=2)$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$.push(this.decode($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$[$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$],
$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,!0,!1)),$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$.push(this.decode($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$[$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$+1],$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,
!1,!1));$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$=$com$cognitect$transit$types$map$$($i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$,!1)}else $JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$=$JSCompiler_StaticMethods_decodeArray$$(this,$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$,$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,
$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$,$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$);else{$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$=$com$cognitect$transit$util$objectKeys$$($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$);var $key$jscomp$inline_4187_strKey$jscomp$inline_4193$$=$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$[0];
if(($i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$=$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$.length==1?this.decode($key$jscomp$inline_4187_strKey$jscomp$inline_4193$$,$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,!1,!1):null)&&$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$ instanceof
$com$cognitect$transit$impl$decoder$Tag$$)$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$=$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$[$key$jscomp$inline_4187_strKey$jscomp$inline_4193$$],$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$=this.$handlers$[$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$.$str$],$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$=
$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$!=null?$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$(this.decode($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$,$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,!1,!0),this):$com$cognitect$transit$types$taggedValue$$($i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$.$str$,
this.decode($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$,$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,!1,!1));else if(this.$mapBuilder$)if($asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$.length<16&&this.$mapBuilder$.fromArray){var $nodep$jscomp$inline_4191_ret$jscomp$inline_4194$$=[];for($i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$=
0;$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$<$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$.length;$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$++)$key$jscomp$inline_4187_strKey$jscomp$inline_4193$$=$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$[$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$],
$nodep$jscomp$inline_4191_ret$jscomp$inline_4194$$.push(this.decode($key$jscomp$inline_4187_strKey$jscomp$inline_4193$$,$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,!0,!1)),$nodep$jscomp$inline_4191_ret$jscomp$inline_4194$$.push(this.decode($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$[$key$jscomp$inline_4187_strKey$jscomp$inline_4193$$],$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,
!1,!1));$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$=this.$mapBuilder$.fromArray($nodep$jscomp$inline_4191_ret$jscomp$inline_4194$$,$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$)}else{$nodep$jscomp$inline_4191_ret$jscomp$inline_4194$$=this.$mapBuilder$.init($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$);for($i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$=
0;$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$<$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$.length;$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$++)$key$jscomp$inline_4187_strKey$jscomp$inline_4193$$=$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$[$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$],
$nodep$jscomp$inline_4191_ret$jscomp$inline_4194$$=this.$mapBuilder$.add($nodep$jscomp$inline_4191_ret$jscomp$inline_4194$$,this.decode($key$jscomp$inline_4187_strKey$jscomp$inline_4193$$,$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,!0,!1),this.decode($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$[$key$jscomp$inline_4187_strKey$jscomp$inline_4193$$],$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,
!1,!1),$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$);$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$=this.$mapBuilder$.finalize($nodep$jscomp$inline_4191_ret$jscomp$inline_4194$$,$node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$)}else{$nodep$jscomp$inline_4191_ret$jscomp$inline_4194$$=[];for($i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$=0;$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$<
$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$.length;$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$++)$key$jscomp$inline_4187_strKey$jscomp$inline_4193$$=$asMapKey$jscomp$4_handler$jscomp$inline_4190_i$jscomp$inline_4180_ks$jscomp$inline_4186$$[$i$jscomp$inline_4192_nodep$jscomp$inline_4179_ret$jscomp$inline_4181_tag$jscomp$inline_4188_tagValue$$],$nodep$jscomp$inline_4191_ret$jscomp$inline_4194$$.push(this.decode($key$jscomp$inline_4187_strKey$jscomp$inline_4193$$,
$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,!0,!1)),$nodep$jscomp$inline_4191_ret$jscomp$inline_4194$$.push(this.decode($node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$[$key$jscomp$inline_4187_strKey$jscomp$inline_4193$$],$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$,!1,!1));$JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$=
$com$cognitect$transit$types$map$$($nodep$jscomp$inline_4191_ret$jscomp$inline_4194$$,!1)}}return $JSCompiler_inline_result$jscomp$574_JSCompiler_temp$jscomp$575_JSCompiler_temp$jscomp$576_cache$jscomp$74$$}return $node$jscomp$153_val$jscomp$inline_4174_val$jscomp$inline_4189$$};$com$cognitect$transit$impl$decoder$Decoder$$.prototype.decode=$com$cognitect$transit$impl$decoder$Decoder$$.prototype.decode;$com$cognitect$transit$impl$reader$Reader$$.prototype.read=function($ret$jscomp$128_str$jscomp$86$$){var $cache$jscomp$inline_4198$$=this.cache;$ret$jscomp$128_str$jscomp$86$$=this.$unmarshaller$.$decoder$.decode(JSON.parse($ret$jscomp$128_str$jscomp$86$$),$cache$jscomp$inline_4198$$);this.cache.clear();return $ret$jscomp$128_str$jscomp$86$$};$com$cognitect$transit$impl$reader$Reader$$.prototype.read=$com$cognitect$transit$impl$reader$Reader$$.prototype.read;var $com$cognitect$transit$handlers$ctorGuid$$=0,$rhex$jscomp$inline_4200$$=(8|3&Math.round(Math.random()*14)).toString(16),$com$cognitect$transit$handlers$ctorGuidProperty$$="transit$guid$"+($com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+
"-"+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+"-4"+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+"-"+$rhex$jscomp$inline_4200$$+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+"-"+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+
$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$()+$com$cognitect$transit$util$randHex$$());$com$cognitect$transit$handlers$NilHandler$$.prototype.tag=function(){return"_"};
$com$cognitect$transit$handlers$NilHandler$$.prototype.rep=function(){return null};$com$cognitect$transit$handlers$NilHandler$$.prototype.stringRep=function(){return"null"};$com$cognitect$transit$handlers$StringHandler$$.prototype.tag=function(){return"s"};$com$cognitect$transit$handlers$StringHandler$$.prototype.rep=function($v$jscomp$358$$){return $v$jscomp$358$$};$com$cognitect$transit$handlers$StringHandler$$.prototype.stringRep=function($v$jscomp$359$$){return $v$jscomp$359$$};
$com$cognitect$transit$handlers$NumberHandler$$.prototype.tag=function(){return"i"};$com$cognitect$transit$handlers$NumberHandler$$.prototype.rep=function($v$jscomp$361$$){return $v$jscomp$361$$};$com$cognitect$transit$handlers$NumberHandler$$.prototype.stringRep=function($v$jscomp$362$$){return $v$jscomp$362$$.toString()};$com$cognitect$transit$handlers$IntegerHandler$$.prototype.tag=function(){return"i"};$com$cognitect$transit$handlers$IntegerHandler$$.prototype.rep=function($v$jscomp$364$$){return $v$jscomp$364$$.toString()};
$com$cognitect$transit$handlers$IntegerHandler$$.prototype.stringRep=function($v$jscomp$365$$){return $v$jscomp$365$$.toString()};$com$cognitect$transit$handlers$BooleanHandler$$.prototype.tag=function(){return"?"};$com$cognitect$transit$handlers$BooleanHandler$$.prototype.rep=function($v$jscomp$367$$){return $v$jscomp$367$$};$com$cognitect$transit$handlers$BooleanHandler$$.prototype.stringRep=function($v$jscomp$368$$){return $v$jscomp$368$$.toString()};
$com$cognitect$transit$handlers$ArrayHandler$$.prototype.tag=function(){return"array"};$com$cognitect$transit$handlers$ArrayHandler$$.prototype.rep=function($v$jscomp$370$$){return $v$jscomp$370$$};$com$cognitect$transit$handlers$ArrayHandler$$.prototype.stringRep=function(){return null};$com$cognitect$transit$handlers$MapHandler$$.prototype.tag=function(){return"map"};$com$cognitect$transit$handlers$MapHandler$$.prototype.rep=function($v$jscomp$373$$){return $v$jscomp$373$$};
$com$cognitect$transit$handlers$MapHandler$$.prototype.stringRep=function(){return null};$com$cognitect$transit$handlers$VerboseDateHandler$$.prototype.tag=function(){return"t"};
$com$cognitect$transit$handlers$VerboseDateHandler$$.prototype.rep=function($v$jscomp$376$$){return $v$jscomp$376$$.getUTCFullYear()+"-"+$com$cognitect$transit$handlers$padZeros$$($v$jscomp$376$$.getUTCMonth()+1,2)+"-"+$com$cognitect$transit$handlers$padZeros$$($v$jscomp$376$$.getUTCDate(),2)+"T"+$com$cognitect$transit$handlers$padZeros$$($v$jscomp$376$$.getUTCHours(),2)+":"+$com$cognitect$transit$handlers$padZeros$$($v$jscomp$376$$.getUTCMinutes(),2)+":"+$com$cognitect$transit$handlers$padZeros$$($v$jscomp$376$$.getUTCSeconds(),
2)+"."+$com$cognitect$transit$handlers$padZeros$$($v$jscomp$376$$.getUTCMilliseconds(),3)+"Z"};$com$cognitect$transit$handlers$VerboseDateHandler$$.prototype.stringRep=function($v$jscomp$377$$,$h$jscomp$116$$){return $h$jscomp$116$$.rep($v$jscomp$377$$)};$com$cognitect$transit$handlers$DateHandler$$.prototype.tag=function(){return"m"};$com$cognitect$transit$handlers$DateHandler$$.prototype.rep=function($v$jscomp$379$$){return $v$jscomp$379$$.valueOf()};
$com$cognitect$transit$handlers$DateHandler$$.prototype.stringRep=function($v$jscomp$380$$){return $v$jscomp$380$$.valueOf().toString()};$com$cognitect$transit$handlers$DateHandler$$.prototype.getVerboseHandler=function(){return new $com$cognitect$transit$handlers$VerboseDateHandler$$};$com$cognitect$transit$handlers$UUIDHandler$$.prototype.tag=function(){return"u"};$com$cognitect$transit$handlers$UUIDHandler$$.prototype.rep=function($v$jscomp$383$$){return $v$jscomp$383$$.toString()};
$com$cognitect$transit$handlers$UUIDHandler$$.prototype.stringRep=function($v$jscomp$384$$){return $v$jscomp$384$$.toString()};$com$cognitect$transit$handlers$KeywordHandler$$.prototype.tag=function(){return":"};$com$cognitect$transit$handlers$KeywordHandler$$.prototype.rep=function($v$jscomp$386$$){return $v$jscomp$386$$.$_name$};$com$cognitect$transit$handlers$KeywordHandler$$.prototype.stringRep=function($v$jscomp$387$$,$h$jscomp$117$$){return $h$jscomp$117$$.rep($v$jscomp$387$$)};
$com$cognitect$transit$handlers$SymbolHandler$$.prototype.tag=function(){return"$"};$com$cognitect$transit$handlers$SymbolHandler$$.prototype.rep=function($v$jscomp$389$$){return $v$jscomp$389$$.$_name$};$com$cognitect$transit$handlers$SymbolHandler$$.prototype.stringRep=function($v$jscomp$390$$,$h$jscomp$118$$){return $h$jscomp$118$$.rep($v$jscomp$390$$)};$com$cognitect$transit$handlers$TaggedHandler$$.prototype.tag=function($v$jscomp$391$$){return $v$jscomp$391$$.tag};
$com$cognitect$transit$handlers$TaggedHandler$$.prototype.rep=function($v$jscomp$392$$){return $v$jscomp$392$$.rep};$com$cognitect$transit$handlers$TaggedHandler$$.prototype.stringRep=function(){return null};$com$cognitect$transit$handlers$TransitSetHandler$$.prototype.tag=function(){return"set"};
$com$cognitect$transit$handlers$TransitSetHandler$$.prototype.rep=function($v$jscomp$395$$){var $arr$jscomp$166$$=[];$v$jscomp$395$$.forEach(function($key$jscomp$267$$){$arr$jscomp$166$$.push($key$jscomp$267$$)});return $com$cognitect$transit$types$taggedValue$$("array",$arr$jscomp$166$$)};$com$cognitect$transit$handlers$TransitSetHandler$$.prototype.stringRep=function(){return null};$com$cognitect$transit$handlers$TransitArrayMapHandler$$.prototype.tag=function(){return"map"};
$com$cognitect$transit$handlers$TransitArrayMapHandler$$.prototype.rep=function($v$jscomp$398$$){return $v$jscomp$398$$};$com$cognitect$transit$handlers$TransitArrayMapHandler$$.prototype.stringRep=function(){return null};$com$cognitect$transit$handlers$TransitMapHandler$$.prototype.tag=function(){return"map"};$com$cognitect$transit$handlers$TransitMapHandler$$.prototype.rep=function($v$jscomp$401$$){return $v$jscomp$401$$};$com$cognitect$transit$handlers$TransitMapHandler$$.prototype.stringRep=function(){return null};
$com$cognitect$transit$handlers$BufferHandler$$.prototype.tag=function(){return"b"};$com$cognitect$transit$handlers$BufferHandler$$.prototype.rep=function($v$jscomp$404$$){return $v$jscomp$404$$.toString("base64")};$com$cognitect$transit$handlers$BufferHandler$$.prototype.stringRep=function(){return null};$com$cognitect$transit$handlers$Uint8ArrayHandler$$.prototype.tag=function(){return"b"};
$com$cognitect$transit$handlers$Uint8ArrayHandler$$.prototype.rep=function($str$jscomp$inline_11600_v$jscomp$407$$){for(var $JSCompiler_inline_result$jscomp$567_block$jscomp$inline_11601$$,$charCode$jscomp$inline_11602_index$jscomp$inline_4203$$=0,$idx$jscomp$inline_11603_length$jscomp$inline_4204$$=$str$jscomp$inline_11600_v$jscomp$407$$.length,$map$jscomp$inline_11604_result$jscomp$inline_4205$$="",$output$jscomp$inline_11605_slice$jscomp$inline_4206$$;$charCode$jscomp$inline_11602_index$jscomp$inline_4203$$<
$idx$jscomp$inline_11603_length$jscomp$inline_4204$$;)$output$jscomp$inline_11605_slice$jscomp$inline_4206$$=$str$jscomp$inline_11600_v$jscomp$407$$.subarray($charCode$jscomp$inline_11602_index$jscomp$inline_4203$$,Math.min($charCode$jscomp$inline_11602_index$jscomp$inline_4203$$+32768,$idx$jscomp$inline_11603_length$jscomp$inline_4204$$)),$map$jscomp$inline_11604_result$jscomp$inline_4205$$+=String.fromCharCode.apply(null,$output$jscomp$inline_11605_slice$jscomp$inline_4206$$),$charCode$jscomp$inline_11602_index$jscomp$inline_4203$$+=
32768;if(typeof btoa!="undefined")$JSCompiler_inline_result$jscomp$567_block$jscomp$inline_11601$$=btoa($map$jscomp$inline_11604_result$jscomp$inline_4205$$);else{$str$jscomp$inline_11600_v$jscomp$407$$=String($map$jscomp$inline_11604_result$jscomp$inline_4205$$);$idx$jscomp$inline_11603_length$jscomp$inline_4204$$=0;$map$jscomp$inline_11604_result$jscomp$inline_4205$$="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\x3d";for($output$jscomp$inline_11605_slice$jscomp$inline_4206$$=
"";$str$jscomp$inline_11600_v$jscomp$407$$.charAt($idx$jscomp$inline_11603_length$jscomp$inline_4204$$|0)||($map$jscomp$inline_11604_result$jscomp$inline_4205$$="\x3d",$idx$jscomp$inline_11603_length$jscomp$inline_4204$$%1);$output$jscomp$inline_11605_slice$jscomp$inline_4206$$+=$map$jscomp$inline_11604_result$jscomp$inline_4205$$.charAt(63&$JSCompiler_inline_result$jscomp$567_block$jscomp$inline_11601$$>>8-$idx$jscomp$inline_11603_length$jscomp$inline_4204$$%1*8)){$charCode$jscomp$inline_11602_index$jscomp$inline_4203$$=
$str$jscomp$inline_11600_v$jscomp$407$$.charCodeAt($idx$jscomp$inline_11603_length$jscomp$inline_4204$$+=.75);if($charCode$jscomp$inline_11602_index$jscomp$inline_4203$$>255)throw Error("'btoa' failed: The string to be encoded contains characters outside of the Latin1 range.");$JSCompiler_inline_result$jscomp$567_block$jscomp$inline_11601$$=$JSCompiler_inline_result$jscomp$567_block$jscomp$inline_11601$$<<8|$charCode$jscomp$inline_11602_index$jscomp$inline_4203$$}$JSCompiler_inline_result$jscomp$567_block$jscomp$inline_11601$$=
$output$jscomp$inline_11605_slice$jscomp$inline_4206$$}return $JSCompiler_inline_result$jscomp$567_block$jscomp$inline_11601$$};$com$cognitect$transit$handlers$Uint8ArrayHandler$$.prototype.stringRep=function(){return null};
$com$cognitect$transit$handlers$Handlers$$.prototype.get=function($ctor$jscomp$4_h$jscomp$125$$){$ctor$jscomp$4_h$jscomp$125$$=typeof $ctor$jscomp$4_h$jscomp$125$$==="string"?this.$handlers$[$ctor$jscomp$4_h$jscomp$125$$]:this.$handlers$[$com$cognitect$transit$handlers$typeTag$$($ctor$jscomp$4_h$jscomp$125$$)];return $ctor$jscomp$4_h$jscomp$125$$!=null?$ctor$jscomp$4_h$jscomp$125$$:this.$handlers$["default"]};$com$cognitect$transit$handlers$Handlers$$.prototype.get=$com$cognitect$transit$handlers$Handlers$$.prototype.get;
$com$cognitect$transit$handlers$Handlers$$.prototype.set=function($ctor$jscomp$5$$,$handler$jscomp$14$$){var $JSCompiler_temp$jscomp$578$$;if($JSCompiler_temp$jscomp$578$$=typeof $ctor$jscomp$5$$==="string")a:{switch($ctor$jscomp$5$$){case "null":case "string":case "boolean":case "number":case "array":case "map":$JSCompiler_temp$jscomp$578$$=!1;break a}$JSCompiler_temp$jscomp$578$$=!0}$JSCompiler_temp$jscomp$578$$?this.$handlers$[$ctor$jscomp$5$$]=$handler$jscomp$14$$:this.$handlers$[$com$cognitect$transit$handlers$typeTag$$($ctor$jscomp$5$$)]=
$handler$jscomp$14$$};$com$cognitect$transit$impl$writer$JSONMarshaller$$.prototype.handler=function($obj$jscomp$139_tag$jscomp$39$$){var $h$jscomp$126$$=this.$handlers$.get($obj$jscomp$139_tag$jscomp$39$$==null?null:$obj$jscomp$139_tag$jscomp$39$$.constructor);return $h$jscomp$126$$!=null?$h$jscomp$126$$:($obj$jscomp$139_tag$jscomp$39$$=$obj$jscomp$139_tag$jscomp$39$$&&$obj$jscomp$139_tag$jscomp$39$$.transitTag)?this.$handlers$.get($obj$jscomp$139_tag$jscomp$39$$):null};
$com$cognitect$transit$impl$writer$Writer$$.prototype.$marshaller$=function(){return this.$_marshaller$};$com$cognitect$transit$impl$writer$Writer$$.prototype.marshaller=$com$cognitect$transit$impl$writer$Writer$$.prototype.$marshaller$;
$com$cognitect$transit$impl$writer$Writer$$.prototype.write=function($JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$,$asMapKey$jscomp$19_name$jscomp$inline_11616_opts$jscomp$245$$){var $em$jscomp$inline_4247_ropts$$=$asMapKey$jscomp$19_name$jscomp$inline_11616_opts$jscomp$245$$||{};$asMapKey$jscomp$19_name$jscomp$inline_11616_opts$jscomp$245$$=$em$jscomp$inline_4247_ropts$$.asMapKey||!1;var $cache$jscomp$95_err$jscomp$inline_11617$$=this.$_marshaller$.$verbose$?
!1:this.cache;if($em$jscomp$inline_4247_ropts$$.marshalTop===!1)$JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$=$com$cognitect$transit$impl$writer$marshal$$(this.$_marshaller$,$JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$,$asMapKey$jscomp$19_name$jscomp$inline_11616_opts$jscomp$245$$,$cache$jscomp$95_err$jscomp$inline_11617$$);else{$em$jscomp$inline_4247_ropts$$=this.$_marshaller$;var $JSCompiler_temp_const$jscomp$10718$$=
JSON,$JSCompiler_temp_const$jscomp$10717$$=$JSCompiler_temp_const$jscomp$10718$$.stringify,$JSCompiler_temp_const$jscomp$10716$$=$com$cognitect$transit$impl$writer$marshal$$;var $h$jscomp$inline_11615$$=$em$jscomp$inline_4247_ropts$$.handler($JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$)||($em$jscomp$inline_4247_ropts$$.$handlerForForeign$?$em$jscomp$inline_4247_ropts$$.$handlerForForeign$($JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$,
$em$jscomp$inline_4247_ropts$$.$handlers$):null);if($h$jscomp$inline_11615$$!=null)$JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$=$h$jscomp$inline_11615$$.tag($JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$).length===1?$com$cognitect$transit$types$taggedValue$$("'",$JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$):$JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$;
else throw $asMapKey$jscomp$19_name$jscomp$inline_11616_opts$jscomp$245$$=($JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$==null?null:$JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$.constructor).name,$cache$jscomp$95_err$jscomp$inline_11617$$=Error("Cannot write "+$asMapKey$jscomp$19_name$jscomp$inline_11616_opts$jscomp$245$$),$cache$jscomp$95_err$jscomp$inline_11617$$.data={$obj$:$JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$,
type:$asMapKey$jscomp$19_name$jscomp$inline_11616_opts$jscomp$245$$},$cache$jscomp$95_err$jscomp$inline_11617$$;$JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$=$JSCompiler_temp_const$jscomp$10717$$.call($JSCompiler_temp_const$jscomp$10718$$,$JSCompiler_temp_const$jscomp$10716$$($em$jscomp$inline_4247_ropts$$,$JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$,$asMapKey$jscomp$19_name$jscomp$inline_11616_opts$jscomp$245$$,
$cache$jscomp$95_err$jscomp$inline_11617$$))}this.cache!=null&&this.cache.clear();return $JSCompiler_inline_result$jscomp$10719_JSCompiler_temp$jscomp$585_obj$jscomp$147_ret$jscomp$134$$};$com$cognitect$transit$impl$writer$Writer$$.prototype.write=$com$cognitect$transit$impl$writer$Writer$$.prototype.write;$com$cognitect$transit$impl$writer$Writer$$.prototype.register=function($type$jscomp$238$$,$handler$jscomp$16$$){this.$_marshaller$.$handlers$.set($type$jscomp$238$$,$handler$jscomp$16$$)};
$com$cognitect$transit$impl$writer$Writer$$.prototype.register=$com$cognitect$transit$impl$writer$Writer$$.prototype.register;$cljs$core$UUID$$.prototype.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$501$$,$other$jscomp$158$$){return $other$jscomp$158$$ instanceof $cljs$core$UUID$$?this.uuid===$other$jscomp$158$$.uuid:$other$jscomp$158$$ instanceof $com$cognitect$transit$types$UUID$$?this.uuid===$other$jscomp$158$$.toString():!1};$cljs$core$UUID$$.prototype.$cljs$core$IComparable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$cljs$core$UUID$$.prototype.$cljs$core$IComparable$_compare$arity$2$=function($this$$jscomp$502$$,$other$jscomp$159$$){if($other$jscomp$159$$ instanceof $cljs$core$UUID$$||$other$jscomp$159$$ instanceof $com$cognitect$transit$types$UUID$$)return $APP.$cljs$core$compare$$(this.toString(),$other$jscomp$159$$.toString());throw Error(["Cannot compare ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this)," to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$159$$)].join(""));
};$com$cognitect$transit$types$UUID$$.prototype.$cljs$core$IComparable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$com$cognitect$transit$types$UUID$$.prototype.$cljs$core$IComparable$_compare$arity$2$=function($this$$jscomp$503$$,$other$jscomp$160$$){if($other$jscomp$160$$ instanceof $cljs$core$UUID$$||$other$jscomp$160$$ instanceof $com$cognitect$transit$types$UUID$$)return $APP.$cljs$core$compare$$(this.toString(),$other$jscomp$160$$.toString());throw Error(["Cannot compare ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this)," to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$160$$)].join(""));
};$module$contents$goog$math$Long_Long$$.prototype.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$504$$,$other$jscomp$161$$){return this.equiv($other$jscomp$161$$)};$com$cognitect$transit$types$UUID$$.prototype.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$505$$,$other$jscomp$162$$){return $other$jscomp$162$$ instanceof $cljs$core$UUID$$?$other$jscomp$162$$.$cljs$core$IEquiv$_equiv$arity$2$(null,this):this.equiv($other$jscomp$162$$)};
$com$cognitect$transit$types$TaggedValue$$.prototype.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$506$$,$other$jscomp$163$$){return this.equiv($other$jscomp$163$$)};$module$contents$goog$math$Long_Long$$.prototype.$cljs$core$IHash$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$module$contents$goog$math$Long_Long$$.prototype.$cljs$core$IHash$_hash$arity$1$=function(){return $com$cognitect$transit$eq$hashCode$$(this)};$com$cognitect$transit$types$UUID$$.prototype.$cljs$core$IHash$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$com$cognitect$transit$types$UUID$$.prototype.$cljs$core$IHash$_hash$arity$1$=function(){return $APP.$cljs$core$hash$$(this.toString())};$com$cognitect$transit$types$TaggedValue$$.prototype.$cljs$core$IHash$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$com$cognitect$transit$types$TaggedValue$$.prototype.$cljs$core$IHash$_hash$arity$1$=function(){return $com$cognitect$transit$eq$hashCode$$(this)};$com$cognitect$transit$types$UUID$$.prototype.$cljs$core$IUUID$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$com$cognitect$transit$types$UUID$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$com$cognitect$transit$types$UUID$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($uuid$jscomp$13$$,$writer$jscomp$139$$){return $APP.$cljs$core$_write$$($writer$jscomp$139$$,['#uuid "',$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.toString()),'"'].join(""))};$cognitect$transit$MapBuilder$$.prototype.init=function(){return $APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cognitect$transit$MapBuilder$$.prototype.add=function($m$jscomp$165$$,$k$jscomp$551$$,$v$jscomp$418$$){return $APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($m$jscomp$165$$,$k$jscomp$551$$,$v$jscomp$418$$)};$cognitect$transit$MapBuilder$$.prototype.finalize=function($m$jscomp$166$$){return $APP.$cljs$core$_persistent_BANG_$$($m$jscomp$166$$)};
$cognitect$transit$MapBuilder$$.prototype.fromArray=function($arr$jscomp$169$$){return $APP.$cljs$core$PersistentArrayMap$fromArray$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$core$PersistentArrayMap$fromArray$$.$cljs$core$IFn$_invoke$arity$3$($arr$jscomp$169$$,!0,!0):$APP.$cljs$core$PersistentArrayMap$fromArray$$($arr$jscomp$169$$,!0,!0)};$cognitect$transit$VectorBuilder$$.prototype.init=function(){return $APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$)};
$cognitect$transit$VectorBuilder$$.prototype.add=function($v$jscomp$419$$,$x$jscomp$1007$$){return $APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$419$$,$x$jscomp$1007$$)};$cognitect$transit$VectorBuilder$$.prototype.finalize=function($v$jscomp$420$$){return $APP.$cljs$core$_persistent_BANG_$$($v$jscomp$420$$)};
$cognitect$transit$VectorBuilder$$.prototype.fromArray=function($arr$jscomp$170$$){return $APP.$cljs$core$PersistentVector$fromArray$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$PersistentVector$fromArray$$.$cljs$core$IFn$_invoke$arity$2$($arr$jscomp$170$$,!0):$APP.$cljs$core$PersistentVector$fromArray$$($arr$jscomp$170$$,!0)};$cognitect$transit$KeywordHandler$$.prototype.tag=function(){return":"};$cognitect$transit$KeywordHandler$$.prototype.rep=function($v$jscomp$428$$){return $v$jscomp$428$$.$fqn$};
$cognitect$transit$KeywordHandler$$.prototype.stringRep=function($v$jscomp$429$$){return $v$jscomp$429$$.$fqn$};$cognitect$transit$SymbolHandler$$.prototype.tag=function(){return"$"};$cognitect$transit$SymbolHandler$$.prototype.rep=function($v$jscomp$431$$){return $v$jscomp$431$$.$str$};$cognitect$transit$SymbolHandler$$.prototype.stringRep=function($v$jscomp$432$$){return $v$jscomp$432$$.$str$};$cognitect$transit$ListHandler$$.prototype.tag=function(){return"list"};
$cognitect$transit$ListHandler$$.prototype.rep=function($c__5548__auto___40367_seq__40166_40353_temp__5825__auto___40365_v$jscomp$434_x_40373$$){var $ret$jscomp$138$$=[];$c__5548__auto___40367_seq__40166_40353_temp__5825__auto___40365_v$jscomp$434_x_40373$$=$APP.$cljs$core$seq$$($c__5548__auto___40367_seq__40166_40353_temp__5825__auto___40365_v$jscomp$434_x_40373$$);for(var $G__40369_chunk__40167_40354_seq__40166_40366__$1$$=null,$G__40370_count__40168_40355$$=0,$G__40368_i__40169_40356$$=0;;)if($G__40368_i__40169_40356$$<
$G__40370_count__40168_40355$$){var $x_40359$$=$G__40369_chunk__40167_40354_seq__40166_40366__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__40368_i__40169_40356$$);$ret$jscomp$138$$.push($x_40359$$);$G__40368_i__40169_40356$$+=1}else if($c__5548__auto___40367_seq__40166_40353_temp__5825__auto___40365_v$jscomp$434_x_40373$$=$APP.$cljs$core$seq$$($c__5548__auto___40367_seq__40166_40353_temp__5825__auto___40365_v$jscomp$434_x_40373$$))$G__40369_chunk__40167_40354_seq__40166_40366__$1$$=$c__5548__auto___40367_seq__40166_40353_temp__5825__auto___40365_v$jscomp$434_x_40373$$,
$APP.$cljs$core$chunked_seq_QMARK_$$($G__40369_chunk__40167_40354_seq__40166_40366__$1$$)?($c__5548__auto___40367_seq__40166_40353_temp__5825__auto___40365_v$jscomp$434_x_40373$$=$APP.$cljs$core$_chunked_first$$($G__40369_chunk__40167_40354_seq__40166_40366__$1$$),$G__40368_i__40169_40356$$=$APP.$cljs$core$_chunked_rest$$($G__40369_chunk__40167_40354_seq__40166_40366__$1$$),$G__40369_chunk__40167_40354_seq__40166_40366__$1$$=$c__5548__auto___40367_seq__40166_40353_temp__5825__auto___40365_v$jscomp$434_x_40373$$,
$G__40370_count__40168_40355$$=$APP.$cljs$core$count$$($c__5548__auto___40367_seq__40166_40353_temp__5825__auto___40365_v$jscomp$434_x_40373$$),$c__5548__auto___40367_seq__40166_40353_temp__5825__auto___40365_v$jscomp$434_x_40373$$=$G__40368_i__40169_40356$$):($c__5548__auto___40367_seq__40166_40353_temp__5825__auto___40365_v$jscomp$434_x_40373$$=$APP.$cljs$core$first$$($G__40369_chunk__40167_40354_seq__40166_40366__$1$$),$ret$jscomp$138$$.push($c__5548__auto___40367_seq__40166_40353_temp__5825__auto___40365_v$jscomp$434_x_40373$$),
$c__5548__auto___40367_seq__40166_40353_temp__5825__auto___40365_v$jscomp$434_x_40373$$=$APP.$cljs$core$next$$($G__40369_chunk__40167_40354_seq__40166_40366__$1$$),$G__40369_chunk__40167_40354_seq__40166_40366__$1$$=null,$G__40370_count__40168_40355$$=0),$G__40368_i__40169_40356$$=0;else break;return $com$cognitect$transit$types$taggedValue$$("array",$ret$jscomp$138$$)};$cognitect$transit$ListHandler$$.prototype.stringRep=function(){return null};$cognitect$transit$MapHandler$$.prototype.tag=function(){return"map"};
$cognitect$transit$MapHandler$$.prototype.rep=function($v$jscomp$437$$){return $v$jscomp$437$$};$cognitect$transit$MapHandler$$.prototype.stringRep=function(){return null};$cognitect$transit$SetHandler$$.prototype.tag=function(){return"set"};
$cognitect$transit$SetHandler$$.prototype.rep=function($c__5548__auto___40394_seq__40176_40383_temp__5825__auto___40392_v$jscomp$440_x_40400$$){var $ret$jscomp$139$$=[];$c__5548__auto___40394_seq__40176_40383_temp__5825__auto___40392_v$jscomp$440_x_40400$$=$APP.$cljs$core$seq$$($c__5548__auto___40394_seq__40176_40383_temp__5825__auto___40392_v$jscomp$440_x_40400$$);for(var $G__40396_chunk__40178_40384_seq__40176_40393__$1$$=null,$G__40397_count__40179_40385$$=0,$G__40395_i__40180_40386$$=0;;)if($G__40395_i__40180_40386$$<
$G__40397_count__40179_40385$$){var $x_40387$$=$G__40396_chunk__40178_40384_seq__40176_40393__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__40395_i__40180_40386$$);$ret$jscomp$139$$.push($x_40387$$);$G__40395_i__40180_40386$$+=1}else if($c__5548__auto___40394_seq__40176_40383_temp__5825__auto___40392_v$jscomp$440_x_40400$$=$APP.$cljs$core$seq$$($c__5548__auto___40394_seq__40176_40383_temp__5825__auto___40392_v$jscomp$440_x_40400$$))$G__40396_chunk__40178_40384_seq__40176_40393__$1$$=$c__5548__auto___40394_seq__40176_40383_temp__5825__auto___40392_v$jscomp$440_x_40400$$,
$APP.$cljs$core$chunked_seq_QMARK_$$($G__40396_chunk__40178_40384_seq__40176_40393__$1$$)?($c__5548__auto___40394_seq__40176_40383_temp__5825__auto___40392_v$jscomp$440_x_40400$$=$APP.$cljs$core$_chunked_first$$($G__40396_chunk__40178_40384_seq__40176_40393__$1$$),$G__40395_i__40180_40386$$=$APP.$cljs$core$_chunked_rest$$($G__40396_chunk__40178_40384_seq__40176_40393__$1$$),$G__40396_chunk__40178_40384_seq__40176_40393__$1$$=$c__5548__auto___40394_seq__40176_40383_temp__5825__auto___40392_v$jscomp$440_x_40400$$,
$G__40397_count__40179_40385$$=$APP.$cljs$core$count$$($c__5548__auto___40394_seq__40176_40383_temp__5825__auto___40392_v$jscomp$440_x_40400$$),$c__5548__auto___40394_seq__40176_40383_temp__5825__auto___40392_v$jscomp$440_x_40400$$=$G__40395_i__40180_40386$$):($c__5548__auto___40394_seq__40176_40383_temp__5825__auto___40392_v$jscomp$440_x_40400$$=$APP.$cljs$core$first$$($G__40396_chunk__40178_40384_seq__40176_40393__$1$$),$ret$jscomp$139$$.push($c__5548__auto___40394_seq__40176_40383_temp__5825__auto___40392_v$jscomp$440_x_40400$$),
$c__5548__auto___40394_seq__40176_40383_temp__5825__auto___40392_v$jscomp$440_x_40400$$=$APP.$cljs$core$next$$($G__40396_chunk__40178_40384_seq__40176_40393__$1$$),$G__40396_chunk__40178_40384_seq__40176_40393__$1$$=null,$G__40397_count__40179_40385$$=0),$G__40395_i__40180_40386$$=0;else break;return $com$cognitect$transit$types$taggedValue$$("array",$ret$jscomp$139$$)};$cognitect$transit$SetHandler$$.prototype.stringRep=function(){return null};$cognitect$transit$VectorHandler$$.prototype.tag=function(){return"array"};
$cognitect$transit$VectorHandler$$.prototype.rep=function($c__5548__auto___40420_seq__40185_40408_temp__5825__auto___40417_v$jscomp$443_x_40425$$){var $ret$jscomp$140$$=[];$c__5548__auto___40420_seq__40185_40408_temp__5825__auto___40417_v$jscomp$443_x_40425$$=$APP.$cljs$core$seq$$($c__5548__auto___40420_seq__40185_40408_temp__5825__auto___40417_v$jscomp$443_x_40425$$);for(var $G__40422_chunk__40186_40409_seq__40185_40418__$1$$=null,$G__40423_count__40187_40410$$=0,$G__40421_i__40188_40411$$=0;;)if($G__40421_i__40188_40411$$<
$G__40423_count__40187_40410$$){var $x_40412$$=$G__40422_chunk__40186_40409_seq__40185_40418__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__40421_i__40188_40411$$);$ret$jscomp$140$$.push($x_40412$$);$G__40421_i__40188_40411$$+=1}else if($c__5548__auto___40420_seq__40185_40408_temp__5825__auto___40417_v$jscomp$443_x_40425$$=$APP.$cljs$core$seq$$($c__5548__auto___40420_seq__40185_40408_temp__5825__auto___40417_v$jscomp$443_x_40425$$))$G__40422_chunk__40186_40409_seq__40185_40418__$1$$=$c__5548__auto___40420_seq__40185_40408_temp__5825__auto___40417_v$jscomp$443_x_40425$$,
$APP.$cljs$core$chunked_seq_QMARK_$$($G__40422_chunk__40186_40409_seq__40185_40418__$1$$)?($c__5548__auto___40420_seq__40185_40408_temp__5825__auto___40417_v$jscomp$443_x_40425$$=$APP.$cljs$core$_chunked_first$$($G__40422_chunk__40186_40409_seq__40185_40418__$1$$),$G__40421_i__40188_40411$$=$APP.$cljs$core$_chunked_rest$$($G__40422_chunk__40186_40409_seq__40185_40418__$1$$),$G__40422_chunk__40186_40409_seq__40185_40418__$1$$=$c__5548__auto___40420_seq__40185_40408_temp__5825__auto___40417_v$jscomp$443_x_40425$$,
$G__40423_count__40187_40410$$=$APP.$cljs$core$count$$($c__5548__auto___40420_seq__40185_40408_temp__5825__auto___40417_v$jscomp$443_x_40425$$),$c__5548__auto___40420_seq__40185_40408_temp__5825__auto___40417_v$jscomp$443_x_40425$$=$G__40421_i__40188_40411$$):($c__5548__auto___40420_seq__40185_40408_temp__5825__auto___40417_v$jscomp$443_x_40425$$=$APP.$cljs$core$first$$($G__40422_chunk__40186_40409_seq__40185_40418__$1$$),$ret$jscomp$140$$.push($c__5548__auto___40420_seq__40185_40408_temp__5825__auto___40417_v$jscomp$443_x_40425$$),
$c__5548__auto___40420_seq__40185_40408_temp__5825__auto___40417_v$jscomp$443_x_40425$$=$APP.$cljs$core$next$$($G__40422_chunk__40186_40409_seq__40185_40418__$1$$),$G__40422_chunk__40186_40409_seq__40185_40418__$1$$=null,$G__40423_count__40187_40410$$=0),$G__40421_i__40188_40411$$=0;else break;return $ret$jscomp$140$$};$cognitect$transit$VectorHandler$$.prototype.stringRep=function(){return null};$cognitect$transit$UUIDHandler$$.prototype.tag=function(){return"u"};
$cognitect$transit$UUIDHandler$$.prototype.rep=function($v$jscomp$446$$){return $v$jscomp$446$$.uuid};$cognitect$transit$UUIDHandler$$.prototype.stringRep=function($v$jscomp$447$$){return this.rep($v$jscomp$447$$)};$cognitect$transit$WithMetaHandler$$.prototype.tag=function(){return"with-meta"};$cognitect$transit$WithMetaHandler$$.prototype.rep=function($v$jscomp$449$$){return $com$cognitect$transit$types$taggedValue$$("array",[$v$jscomp$449$$.value,$v$jscomp$449$$.$meta$])};
$cognitect$transit$WithMetaHandler$$.prototype.stringRep=function(){return null};$APP.$JSCompiler_prototypeAlias$$=$cognitect$transit$t_cognitect$0transit40239$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_40241$$,$meta40240__$1$$){return new $cognitect$transit$t_cognitect$0transit40239$$(this.$tag_fn$,this.$rep_fn$,this.$str_rep_fn$,this.$verbose_handler_fn$,$meta40240__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta40240$};
$APP.$JSCompiler_prototypeAlias$$.tag=function($o$jscomp$205$$){return this.$tag_fn$.$cljs$core$IFn$_invoke$arity$1$?this.$tag_fn$.$cljs$core$IFn$_invoke$arity$1$($o$jscomp$205$$):this.$tag_fn$($o$jscomp$205$$)};$APP.$JSCompiler_prototypeAlias$$.rep=function($o$jscomp$206$$){return this.$rep_fn$.$cljs$core$IFn$_invoke$arity$1$?this.$rep_fn$.$cljs$core$IFn$_invoke$arity$1$($o$jscomp$206$$):this.$rep_fn$($o$jscomp$206$$)};
$APP.$JSCompiler_prototypeAlias$$.stringRep=function($o$jscomp$207$$){return $APP.$cljs$core$truth_$$(this.$str_rep_fn$)?this.$str_rep_fn$.$cljs$core$IFn$_invoke$arity$1$?this.$str_rep_fn$.$cljs$core$IFn$_invoke$arity$1$($o$jscomp$207$$):this.$str_rep_fn$($o$jscomp$207$$):null};
$APP.$JSCompiler_prototypeAlias$$.getVerboseHandler=function(){return $APP.$cljs$core$truth_$$(this.$verbose_handler_fn$)?this.$verbose_handler_fn$.$cljs$core$IFn$_invoke$arity$0$?this.$verbose_handler_fn$.$cljs$core$IFn$_invoke$arity$0$():this.$verbose_handler_fn$():null};var $app$common$transit$write_handlers$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$app$common$transit$read_handlers$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$app$common$transit$write_handler_map$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$app$common$transit$read_handler_map$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$app$common$transit$Pointer$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.metadata};
$app$common$transit$Pointer$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_$jscomp$980$$,$meta$jscomp$77$$){return new $app$common$transit$Pointer$$(this.id,$meta$jscomp$77$$)};$app$common$transit$Pointer$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.id};
$APP.$app$common$transit$add_handlers_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,"n",$APP.$cljs$cst$1315$rfn$$,function($value$jscomp$363$$){return parseInt($value$jscomp$363$$,10)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,"u",$APP.$cljs$cst$1315$rfn$$,$cljs$core$parse_uuid$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$266$id$$,"ordered-map",$APP.$cljs$cst$1291$class$$,$linked$map$LinkedMap$$,$APP.$cljs$cst$1314$wfn$$,$APP.$cljs$core$vec$$,$APP.$cljs$cst$1315$rfn$$,function($p1__40430_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$linked$map$empty_linked_map$$,$p1__40430_SHARP_$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"ordered-set",$APP.$cljs$cst$1291$class$$,$linked$set$LinkedSet$$,$APP.$cljs$cst$1314$wfn$$,$APP.$cljs$core$vec$$,
$APP.$cljs$cst$1315$rfn$$,function($p1__40432_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$linked$set$empty_linked_set$$,$p1__40432_SHARP_$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"m",$APP.$cljs$cst$1291$class$$,Date,$APP.$cljs$cst$1315$rfn$$,function($v$jscomp$453$$){return new Date(parseInt($v$jscomp$453$$,10))},$APP.$cljs$cst$1314$wfn$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$inst_ms$$)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,"penpot/pointer",$APP.$cljs$cst$1291$class$$,$app$common$transit$Pointer$$,$APP.$cljs$cst$1315$rfn$$,function($meta$jscomp$78_p__40433$$){var $id$jscomp$39$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($meta$jscomp$78_p__40433$$,0,null);$meta$jscomp$78_p__40433$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($meta$jscomp$78_p__40433$$,1,null);return new $app$common$transit$Pointer$$($id$jscomp$39$$,
$meta$jscomp$78_p__40433$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"uri",$APP.$cljs$cst$1291$class$$,$lambdaisland$uri$URI$$,$APP.$cljs$cst$1315$rfn$$,$APP.$app$common$uri$uri$$,$APP.$cljs$cst$1314$wfn$$,$APP.$cljs$core$str$$],null)]));var $app$common$transit$date_write_handler$$,$tag_fn$jscomp$inline_4264$$=$APP.$cljs$core$constantly$$("m"),$rep_fn$jscomp$inline_4265$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$inst_ms$$);
$app$common$transit$date_write_handler$$=$cognitect$transit$write_handler$cljs$0core$0IFn$0_invoke$0arity$04$$($tag_fn$jscomp$inline_4264$$,$rep_fn$jscomp$inline_4265$$);
$APP.$app$common$transit$decode_str$$=function $app$common$transit$decode_str$$($var_args$jscomp$702$$){switch(arguments.length){case 1:return $app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$=function($data$jscomp$112$$){return $APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$112$$,null)};
$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$2$=function($data$jscomp$113$$,$opts$jscomp$251_type$jscomp$246$$){$opts$jscomp$251_type$jscomp$246$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$2$($opts$jscomp$251_type$jscomp$246$$,$cljs$cst$923$json$$);var $params$jscomp$15$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1299$handlers$$,$APP.$cljs$core$_deref$$($app$common$transit$read_handler_map$$)],null);return $cognitect$transit$reader$cljs$0core$0IFn$0_invoke$0arity$02$$($opts$jscomp$251_type$jscomp$246$$,
$params$jscomp$15$$).read($data$jscomp$113$$)};$APP.$app$common$transit$decode_str$$.$cljs$lang$maxFixedArity$=2;var $shadow$js$shim$module$0lodash$0debounce$$=shadow$bridge("lodash/debounce.js");$APP.$shadow$js$shim$module$0rxjs$$=shadow$bridge("rxjs");var $beicon$v2$operators$share$$=$APP.$shadow$js$shim$module$0rxjs$$.share,$beicon$v2$operators$if_empty$$=$APP.$shadow$js$shim$module$0rxjs$$.defaultIfEmpty,$beicon$v2$operators$merge_all$$=$APP.$shadow$js$shim$module$0rxjs$$.mergeAll,$beicon$v2$operators$take$$=$APP.$shadow$js$shim$module$0rxjs$$.take,$beicon$v2$operators$take_last$$=$APP.$shadow$js$shim$module$0rxjs$$.takeLast,$beicon$v2$operators$take_until$$=$APP.$shadow$js$shim$module$0rxjs$$.takeUntil,$beicon$v2$operators$combine_latest$$=
$APP.$shadow$js$shim$module$0rxjs$$.combineLatestWith,$beicon$v2$operators$debounce$$=$APP.$shadow$js$shim$module$0rxjs$$.debounceTime,$beicon$v2$operators$sample$$=$APP.$shadow$js$shim$module$0rxjs$$.sampleTime,$beicon$v2$operators$ignore$$=$APP.$shadow$js$shim$module$0rxjs$$.ignoreElements,$beicon$v2$operators$finalize$$=$APP.$shadow$js$shim$module$0rxjs$$.finalize,$beicon$v2$operators$buffer$$=$APP.$shadow$js$shim$module$0rxjs$$.bufferCount,$beicon$v2$operators$buffer_time$$=$APP.$shadow$js$shim$module$0rxjs$$.bufferTime,
$beicon$v2$operators$buffer_until$$=$APP.$shadow$js$shim$module$0rxjs$$.buffer,$beicon$v2$operators$delay$$=$APP.$shadow$js$shim$module$0rxjs$$.delay;var $beicon$v2$core$Observable$$,$beicon$v2$core$Subject$$,$beicon$v2$core$BehaviorSubject$$,$beicon$v2$core$Subscriber$$,$beicon$v2$core$noop$$,$beicon$v2$core$race$$;$beicon$v2$core$Observable$$=$APP.$shadow$js$shim$module$0rxjs$$.Observable;$beicon$v2$core$Subject$$=$APP.$shadow$js$shim$module$0rxjs$$.Subject;$beicon$v2$core$BehaviorSubject$$=$APP.$shadow$js$shim$module$0rxjs$$.BehaviorSubject;$beicon$v2$core$Subscriber$$=$APP.$shadow$js$shim$module$0rxjs$$.Subscriber;$beicon$v2$core$noop$$=$APP.$shadow$js$shim$module$0rxjs$$.noop;
$APP.$beicon$v2$core$timer$$=$APP.$shadow$js$shim$module$0rxjs$$.timer;$APP.$beicon$v2$core$of$$=$APP.$shadow$js$shim$module$0rxjs$$.of;$beicon$v2$core$race$$=$APP.$shadow$js$shim$module$0rxjs$$.race;$APP.$JSCompiler_prototypeAlias$$=$beicon$v2$core$Subscriber$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$28$$){switch(arguments.length-1){case 0:return this.$cljs$core$IFn$_invoke$arity$0$();default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$2395$$,$args40694$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args40694$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$0$=function(){return this.unsubscribe()};$APP.$JSCompiler_prototypeAlias$$.$beicon$v2$core$IDisposable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$beicon$v2$core$IDisposable$_dispose$arity$1$=function(){return this.unsubscribe()};$beicon$v2$core$BehaviorSubject$$.prototype.$cljs$core$IDeref$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$beicon$v2$core$BehaviorSubject$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.getValue()};var $app$util$functions$ext_debounce$$,$or__5025__auto__$jscomp$inline_4275$$=$shadow$js$shim$module$0lodash$0debounce$$.default;$app$util$functions$ext_debounce$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_4275$$)?$or__5025__auto__$jscomp$inline_4275$$:$shadow$js$shim$module$0lodash$0debounce$$;var $app$util$storage$local_storage$$;try{$app$util$storage$local_storage$$=$APP.$app$util$globals$global$$.localStorage}catch($e43591$jscomp$inline_4277$$){$app$util$storage$local_storage$$=null}var $app$util$storage$session_storage$$;try{$app$util$storage$session_storage$$=$APP.$app$util$globals$global$$.sessionStorage}catch($e43593$jscomp$inline_4279$$){$app$util$storage$session_storage$$=null}$APP.$app$util$storage$_STAR_sync_STAR_$$=!1;$APP.$JSCompiler_prototypeAlias$$=$app$util$storage$t_app$0util$0storage43623$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_43625$$,$meta43624__$1$$){return new $app$util$storage$t_app$0util$0storage43623$$(this.$last_data$,this.$curr_data$,this.$on_change$,this.$backend$,this.$watches$,this.$update_key$,this.prefix,this.$on_change_STAR_$,this.initial,$meta43624__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta43624$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDeref$_deref$arity$1$=function(){return this.$curr_data$.content};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($coll$jscomp$1071$$,$k$jscomp$556$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$556$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($_$jscomp$992$$,$k$jscomp$557$$,$not_found$jscomp$81$$){return $APP.$cljs$core$_lookup$$(this.$curr_data$.content,$k$jscomp$557$$,$not_found$jscomp$81$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReset$_reset_BANG_$arity$2$=function($oldval$jscomp$4_self$jscomp$36$$,$newval$jscomp$5$$){$oldval$jscomp$4_self$jscomp$36$$=this.$curr_data$.content;this.$curr_data$.content=$newval$jscomp$5$$;$APP.$cljs$core$truth_$$($APP.$app$util$storage$_STAR_sync_STAR_$$)?this.$on_change_STAR_$.$cljs$core$IFn$_invoke$arity$1$?this.$on_change_STAR_$.$cljs$core$IFn$_invoke$arity$1$($newval$jscomp$5$$):this.$on_change_STAR_$($newval$jscomp$5$$):this.$on_change$.$cljs$core$IFn$_invoke$arity$1$?
this.$on_change$.$cljs$core$IFn$_invoke$arity$1$($newval$jscomp$5$$):this.$on_change$($newval$jscomp$5$$);this.$watches$.size>0&&this.$cljs$core$IWatchable$_notify_watches$arity$3$(null,$oldval$jscomp$4_self$jscomp$36$$,$newval$jscomp$5$$);return $newval$jscomp$5$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$2$=function($self$jscomp$37_state$jscomp$23$$,$f$jscomp$644$$){$self$jscomp$37_state$jscomp$23$$=this.$curr_data$.content;return this.$cljs$core$IReset$_reset_BANG_$arity$2$(null,$f$jscomp$644$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$644$$.$cljs$core$IFn$_invoke$arity$1$($self$jscomp$37_state$jscomp$23$$):$f$jscomp$644$$($self$jscomp$37_state$jscomp$23$$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$3$=function($self$jscomp$38_state$jscomp$24$$,$f$jscomp$645$$,$x$jscomp$1022$$){$self$jscomp$38_state$jscomp$24$$=this.$curr_data$.content;return this.$cljs$core$IReset$_reset_BANG_$arity$2$(null,$f$jscomp$645$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$645$$.$cljs$core$IFn$_invoke$arity$2$($self$jscomp$38_state$jscomp$24$$,$x$jscomp$1022$$):$f$jscomp$645$$($self$jscomp$38_state$jscomp$24$$,$x$jscomp$1022$$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$4$=function($self$jscomp$39_state$jscomp$25$$,$f$jscomp$646$$,$x$jscomp$1023$$,$y$jscomp$301$$){$self$jscomp$39_state$jscomp$25$$=this.$curr_data$.content;return this.$cljs$core$IReset$_reset_BANG_$arity$2$(null,$f$jscomp$646$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$646$$.$cljs$core$IFn$_invoke$arity$3$($self$jscomp$39_state$jscomp$25$$,$x$jscomp$1023$$,$y$jscomp$301$$):$f$jscomp$646$$($self$jscomp$39_state$jscomp$25$$,$x$jscomp$1023$$,
$y$jscomp$301$$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$5$=function($self$jscomp$40$$,$f$jscomp$647$$,$x$jscomp$1024$$,$y$jscomp$302$$,$more$jscomp$41$$){return this.$cljs$core$IReset$_reset_BANG_$arity$2$(null,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($f$jscomp$647$$,this.$curr_data$.content,$x$jscomp$1024$$,$y$jscomp$302$$,$more$jscomp$41$$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWatchable$_notify_watches$arity$3$=function($self$jscomp$41$$,$oldval$jscomp$5$$,$newval$jscomp$6$$){var $self__$1$jscomp$13$$=this;return $okulary$util$doiter$$(this.$watches$.entries(),function($k$jscomp$558_n$jscomp$261$$){var $f$jscomp$648$$=$k$jscomp$558_n$jscomp$261$$[1];$k$jscomp$558_n$jscomp$261$$=$k$jscomp$558_n$jscomp$261$$[0];return $f$jscomp$648$$.$cljs$core$IFn$_invoke$arity$4$?$f$jscomp$648$$.$cljs$core$IFn$_invoke$arity$4$($k$jscomp$558_n$jscomp$261$$,
$self__$1$jscomp$13$$,$oldval$jscomp$5$$,$newval$jscomp$6$$):$f$jscomp$648$$($k$jscomp$558_n$jscomp$261$$,$self__$1$jscomp$13$$,$oldval$jscomp$5$$,$newval$jscomp$6$$)})};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWatchable$_add_watch$arity$3$=function($self$jscomp$42$$,$key$jscomp$272$$,$f$jscomp$649$$){this.$watches$.set($key$jscomp$272$$,$f$jscomp$649$$);return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWatchable$_remove_watch$arity$2$=function($_$jscomp$993$$,$key$jscomp$273$$){return this.$watches$.delete($key$jscomp$273$$)};
$APP.$app$util$storage$global$$=$app$util$storage$create_storage$$($app$util$storage$local_storage$$,"penpot-global");$APP.$app$util$storage$user$$=$app$util$storage$create_storage$$($app$util$storage$local_storage$$,"penpot-user");$APP.$app$util$storage$storage$$=$app$util$storage$create_storage$$($app$util$storage$local_storage$$,"penpot");$APP.$app$util$storage$session$$=$app$util$storage$create_storage$$($app$util$storage$session_storage$$,"penpot");
(function(){function $on_before_unload$$(){var $_STAR_sync_STAR__orig_val__43655$$=$APP.$app$util$storage$_STAR_sync_STAR_$$;$APP.$app$util$storage$_STAR_sync_STAR_$$=!0;try{return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$global$$,$APP.$cljs$core$assoc$$,$cljs$cst$1338$app_DOT_util_DOT_storage_SLASH_last_refresh$$,$APP.$app$common$time$now$$()),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,
$cljs$cst$1338$app_DOT_util_DOT_storage_SLASH_last_refresh$$,$APP.$app$common$time$now$$())}finally{$APP.$app$util$storage$_STAR_sync_STAR_$$=$_STAR_sync_STAR__orig_val__43655$$}}$APP.$app$util$globals$window$$.addEventListener("beforeunload",$on_before_unload$$);return $on_before_unload$$})();var $app$util$timers$cancel_animation_frame$$;$APP.$JSCompiler_prototypeAlias$$=$app$util$timers$t_app$0util$0timers42504$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_42506$$,$meta42505__$1$$){return new $app$util$timers$t_app$0util$0timers42504$$(this.ms,this.$func$,this.$sem$,$meta42505__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta42505$};
$APP.$JSCompiler_prototypeAlias$$.$app$common$data$ICloseable$close_BANG_$arity$1$=function(){return clearTimeout(this.$sem$)};$APP.$JSCompiler_prototypeAlias$$.$beicon$v2$core$IDisposable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$beicon$v2$core$IDisposable$_dispose$arity$1$=function(){return clearTimeout(this.$sem$)};
$app$util$timers$t_app$0util$0timers42521$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_42523$$,$meta42522__$1$$){return new $app$util$timers$t_app$0util$0timers42521$$(this.ms,this.$func$,this.$sem$,$meta42522__$1$$)};$app$util$timers$t_app$0util$0timers42521$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta42522$};$app$util$timers$t_app$0util$0timers42521$$.prototype.$beicon$v2$core$IDisposable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$app$util$timers$t_app$0util$0timers42521$$.prototype.$beicon$v2$core$IDisposable$_dispose$arity$1$=function(){return clearInterval(this.$sem$)};var $and__5023__auto__$jscomp$inline_4290$$=typeof window!=="undefined";
if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_4290$$?window.requestIdleCallback:$and__5023__auto__$jscomp$inline_4290$$))var $app$util$timers$request_idle_callback$$=function($p1__42531_SHARP_$$){return requestIdleCallback($p1__42531_SHARP_$$,{timeout:3E4})},$app$util$timers$cancel_idle_callback$$=function($p1__42533_SHARP_$$){return cancelIdleCallback($p1__42533_SHARP_$$)};else $app$util$timers$request_idle_callback$$=function($p1__42535_SHARP_$$){return setTimeout($p1__42535_SHARP_$$,
250)},$app$util$timers$cancel_idle_callback$$=function($p1__42536_SHARP_$$){return clearTimeout($p1__42536_SHARP_$$)};$app$util$timers$t_app$0util$0timers42549$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_42551$$,$meta42550__$1$$){return new $app$util$timers$t_app$0util$0timers42549$$(this.$func$,this.$sem$,$meta42550__$1$$)};$app$util$timers$t_app$0util$0timers42549$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta42550$};
$app$util$timers$t_app$0util$0timers42549$$.prototype.$beicon$v2$core$IDisposable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$app$util$timers$t_app$0util$0timers42549$$.prototype.$beicon$v2$core$IDisposable$_dispose$arity$1$=function(){return $app$util$timers$cancel_idle_callback$$(this.$sem$)};
$APP.$app$util$timers$request_animation_frame$$=typeof globalThis!=="undefined"&&globalThis.requestAnimationFrame!=null?function($p1__42562_SHARP_$$){return globalThis.requestAnimationFrame($p1__42562_SHARP_$$)}:function($p1__42564_SHARP_$$){return setTimeout($p1__42564_SHARP_$$,16)};$app$util$timers$cancel_animation_frame$$=typeof globalThis!=="undefined"&&globalThis.cancelAnimationFrame!=null?function($p1__42574_SHARP_$$){return globalThis.cancelAnimationFrame($p1__42574_SHARP_$$)}:function($p1__42575_SHARP_$$){return clearTimeout($p1__42575_SHARP_$$)};var $date$jscomp$inline_4293$$,$flags$jscomp$inline_4296$$,$flags__$1$jscomp$inline_4297$$,$app$config$browser$$,$app$config$platform$$,$user_agent$jscomp$inline_11640$$,$app$config$oidc_name$$,$app$config$privacy_policy_uri$$,$app$config$plugins_list_uri$$,$app$config$plugins_whitelist$$,$app$config$upload_chunk_size$$,$or__5025__auto__$jscomp$inline_4299$$,$app$config$mcp_ws_uri$$,$or__5025__auto__$jscomp$inline_11651$$,$G__43821$jscomp$inline_11652$$,$or__5025__auto__$jscomp$inline_11654$$,$G__43822$jscomp$inline_11655$$;
$APP.$cljs$core$_STAR_assert_STAR_$$=!1;$date$jscomp$inline_4293$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"penpotBuildDate");$APP.$app$config$build_date$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($date$jscomp$inline_4293$$,"%buildDate%")?"unknown":$date$jscomp$inline_4293$$;$flags$jscomp$inline_4296$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$util$globals$global$$,"penpotFlags","");
$flags__$1$jscomp$inline_4297$$=$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$keyword$$),$cuerdas$core$words$cljs$0core$0IFn$0_invoke$0arity$02$$($flags$jscomp$inline_4296$$));
a:{for(var $flags__$1$jscomp$inline_11629$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$flags$default$0$$,$flags__$1$jscomp$inline_4297$$])),$result$jscomp$inline_11630$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$;;){var $item$jscomp$inline_11631$$=$APP.$cljs$core$first$$($flags__$1$jscomp$inline_11629$$);if($item$jscomp$inline_11631$$==null){$APP.$app$config$flags$$=$result$jscomp$inline_11630$$;
break a}var $sname$jscomp$inline_11632$$=$APP.$cljs$core$name$$($item$jscomp$inline_11631$$);if($APP.$cuerdas$core$starts_with_QMARK_$$($sname$jscomp$inline_11632$$,"enable-")){var $G__36981$jscomp$inline_11633$$=$APP.$cljs$core$rest$$($flags__$1$jscomp$inline_11629$$),$G__36982$jscomp$inline_11634$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$inline_11630$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($sname$jscomp$inline_11632$$,
7)));$flags__$1$jscomp$inline_11629$$=$G__36981$jscomp$inline_11633$$;$result$jscomp$inline_11630$$=$G__36982$jscomp$inline_11634$$}else if($APP.$cuerdas$core$starts_with_QMARK_$$($sname$jscomp$inline_11632$$,"disable-")){var $G__36983$jscomp$inline_11635$$=$APP.$cljs$core$rest$$($flags__$1$jscomp$inline_11629$$),$G__36984$jscomp$inline_11636$$=$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$inline_11630$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($sname$jscomp$inline_11632$$,
8)));$flags__$1$jscomp$inline_11629$$=$G__36983$jscomp$inline_11635$$;$result$jscomp$inline_11630$$=$G__36984$jscomp$inline_11636$$}else{var $G__36986$jscomp$inline_11637$$=$APP.$cljs$core$rest$$($flags__$1$jscomp$inline_11629$$),$G__36987$jscomp$inline_11638$$=$result$jscomp$inline_11630$$;$flags__$1$jscomp$inline_11629$$=$G__36986$jscomp$inline_11637$$;$result$jscomp$inline_11630$$=$G__36987$jscomp$inline_11638$$}}$APP.$app$config$flags$$=void 0}
$APP.$app$config$target$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"document")!=null?$APP.$cljs$cst$1357$browser$$:$cljs$cst$1358$webworker$$;
$app$config$browser$$=function(){function $check_safari_26_QMARK_$$(){var $and__5023__auto__$jscomp$168$$=$check_safari_QMARK_$$();return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$168$$)?$APP.$cuerdas$core$includes_QMARK_$$($user_agent$$,"version/26"):$and__5023__auto__$jscomp$168$$}function $check_safari_18_QMARK_$$(){var $and__5023__auto__$jscomp$167$$=$check_safari_QMARK_$$();return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$167$$)?$APP.$cuerdas$core$includes_QMARK_$$($user_agent$$,
"version/18"):$and__5023__auto__$jscomp$167$$}function $check_safari_17_QMARK_$$(){var $and__5023__auto__$jscomp$166$$=$check_safari_QMARK_$$();return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$166$$)?$APP.$cuerdas$core$includes_QMARK_$$($user_agent$$,"version/17"):$and__5023__auto__$jscomp$166$$}function $check_safari_16_QMARK_$$(){var $and__5023__auto__$jscomp$165$$=$check_safari_QMARK_$$();return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$165$$)?$APP.$cuerdas$core$includes_QMARK_$$($user_agent$$,
"version/16"):$and__5023__auto__$jscomp$165$$}function $check_safari_QMARK_$$(){return $APP.$cuerdas$core$includes_QMARK_$$($user_agent$$,"safari")}var $user_agent$$=$APP.$cuerdas$core$lower$$($app$util$globals$navigator$$.userAgent);return $APP.$cuerdas$core$includes_QMARK_$$($user_agent$$,"edg")?$cljs$cst$1345$edge$$:$APP.$cuerdas$core$includes_QMARK_$$($user_agent$$,"chrom")?$APP.$cljs$cst$1351$chrome$$:$APP.$cuerdas$core$includes_QMARK_$$($user_agent$$,"firefox")?$cljs$cst$1350$firefox$$:$check_safari_16_QMARK_$$()?
$APP.$cljs$cst$1347$safari_16$$:$check_safari_17_QMARK_$$()?$APP.$cljs$cst$1352$safari_17$$:$check_safari_18_QMARK_$$()?$APP.$cljs$cst$1348$safari_18$$:$check_safari_26_QMARK_$$()?$APP.$cljs$cst$1353$safari_26$$:$check_safari_QMARK_$$()?$APP.$cljs$cst$1346$safari$$:$cljs$cst$895$unknown$$}();$user_agent$jscomp$inline_11640$$=$APP.$cuerdas$core$lower$$($app$util$globals$navigator$$.userAgent);
$app$config$platform$$=$APP.$cuerdas$core$includes_QMARK_$$($user_agent$jscomp$inline_11640$$,"windows")?$cljs$cst$1355$windows$$:$APP.$cuerdas$core$includes_QMARK_$$($user_agent$jscomp$inline_11640$$,"linux")?$cljs$cst$1356$linux$$:$APP.$cuerdas$core$includes_QMARK_$$($user_agent$jscomp$inline_11640$$,"mac os")?$cljs$cst$1354$macos$$:$cljs$cst$1349$other$$;$APP.$app$config$session_id$$=$APP.$app$common$uuid$next$$();
var $data$jscomp$inline_11642$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"penpotVersion");
if($APP.$cuerdas$core$starts_with_QMARK_$$($data$jscomp$inline_11642$$,"%")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$inline_11642$$,"develop"))$APP.$app$config$version$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$1271$commit_hash$$,$cljs$cst$1272$modifier$$,$APP.$cljs$cst$1273$full$$,$cljs$cst$1274$patch$$,$cljs$cst$1275$major$$,$cljs$cst$1276$commit$$,$cljs$cst$1277$minor$$,$APP.$cljs$cst$1278$base$$,$cljs$cst$1279$branch$$,$APP.$cljs$cst$1280$main$$],[null,
null,"develop","0","0",null,"0","0.0.0","develop","0.0"]);else if(typeof $data$jscomp$inline_11642$$==="string"){var $result$jscomp$inline_11643$$=$APP.$cljs$core$re_find$$($app$common$version$version_re$$,$data$jscomp$inline_11642$$),$major$jscomp$inline_11644$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$inline_11643$$,4),$minor$jscomp$inline_11645$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$inline_11643$$,5),$patch$jscomp$inline_11646$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$inline_11643$$,
6),$base$jscomp$inline_11647$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$inline_11643$$,3),$main$jscomp$inline_11648$$=$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$3$("%s.%s",$major$jscomp$inline_11644$$,$minor$jscomp$inline_11645$$):$APP.$cuerdas$core$format$$("%s.%s",$major$jscomp$inline_11644$$,$minor$jscomp$inline_11645$$),$branch$jscomp$inline_11649$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$inline_11643$$,
2);$APP.$app$config$version$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$1271$commit_hash$$,$cljs$cst$1272$modifier$$,$APP.$cljs$cst$1273$full$$,$cljs$cst$1274$patch$$,$cljs$cst$1275$major$$,$cljs$cst$1276$commit$$,$cljs$cst$1277$minor$$,$APP.$cljs$cst$1278$base$$,$cljs$cst$1279$branch$$,$APP.$cljs$cst$1280$main$$],[$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$inline_11643$$,14),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$inline_11643$$,
8),$data$jscomp$inline_11642$$,$patch$jscomp$inline_11646$$,$major$jscomp$inline_11644$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$inline_11643$$,12),$minor$jscomp$inline_11645$$,$base$jscomp$inline_11647$$,$branch$jscomp$inline_11649$$,$main$jscomp$inline_11648$$])}else $APP.$app$config$version$$=null;$APP.$app$config$version_tag$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"penpotVersionTag");
$APP.$app$config$terms_of_service_uri$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"penpotTermsOfServiceURI");$app$config$oidc_name$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"penpotOIDCName");$app$config$privacy_policy_uri$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"penpotPrivacyPolicyURI");
$APP.$app$config$flex_help_uri$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$util$globals$global$$,"penpotGridHelpURI","https://help.penpot.app/user-guide/flexible-layouts/");$APP.$app$config$grid_help_uri$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$util$globals$global$$,"penpotGridHelpURI","https://help.penpot.app/user-guide/flexible-layouts/");
$app$config$plugins_list_uri$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$util$globals$global$$,"penpotPluginsListURI","https://penpot.app/penpothub/plugins");$app$config$plugins_whitelist$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$util$globals$global$$,"penpotPluginsWhitelist",$APP.$cljs$core$PersistentVector$EMPTY$$));
$APP.$app$config$templates_uri$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$util$globals$global$$,"penpotTemplatesURI","https://penpot.github.io/penpot-files/");$app$config$upload_chunk_size$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$util$globals$global$$,"penpotUploadChunkSize",26214400);$APP.$app$common$flags$_STAR_current_STAR_$$=$APP.$app$config$flags$$;
$or__5025__auto__$jscomp$inline_4299$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"penpotPublicURI");$APP.$app$config$public_uri$$=$app$common$uri$ensure_path_slash$$($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_4299$$)?$or__5025__auto__$jscomp$inline_4299$$:$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$location$$,"origin"));
$G__43821$jscomp$inline_11652$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"penpotMcpServerURI");$or__5025__auto__$jscomp$inline_11651$$=$G__43821$jscomp$inline_11652$$==null?null:$APP.$app$common$uri$uri$$($G__43821$jscomp$inline_11652$$);
$app$config$mcp_ws_uri$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_11651$$)?$or__5025__auto__$jscomp$inline_11651$$:$APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"mcp/ws"]));$G__43822$jscomp$inline_11655$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"penpotRasterizerURI");
$or__5025__auto__$jscomp$inline_11654$$=$G__43822$jscomp$inline_11655$$==null?null:$app$common$uri$ensure_path_slash$$($G__43822$jscomp$inline_11655$$);$APP.$app$config$rasterizer_uri$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_11654$$)?$or__5025__auto__$jscomp$inline_11654$$:$APP.$app$config$public_uri$$;
$APP.$app$config$worker_uri$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"js/worker/main.js"])),$APP.$cljs$cst$296$path$$)),"?version\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version_tag$$)].join("");
$APP.$app$config$mcp_server_url$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$uri$ensure_path_slash$$($APP.$app$config$public_uri$$),"mcp/stream"])));
$APP.$app$config$resolve_file_media$$=function $app$config$resolve_file_media$$($var_args$jscomp$739$$){switch(arguments.length){case 1:return $app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$=function($media$jscomp$1$$){return $APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$2$($media$jscomp$1$$,!1)};
$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$2$=function($id$jscomp$41_p__43912$$,$JSCompiler_temp$jscomp$591_thumbnail_QMARK_$$){var $G__43917$jscomp$inline_4305_G__43917__$1$jscomp$inline_4306_map__43913__$1_or__5025__auto__$jscomp$264$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$41_p__43912$$);$id$jscomp$41_p__43912$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__43917$jscomp$inline_4305_G__43917__$1$jscomp$inline_4306_map__43913__$1_or__5025__auto__$jscomp$264$$,
$APP.$cljs$cst$266$id$$);$G__43917$jscomp$inline_4305_G__43917__$1$jscomp$inline_4306_map__43913__$1_or__5025__auto__$jscomp$264$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__43917$jscomp$inline_4305_G__43917__$1$jscomp$inline_4306_map__43913__$1_or__5025__auto__$jscomp$264$$,$cljs$cst$1361$data_uri$$);$APP.$cljs$core$truth_$$($G__43917$jscomp$inline_4305_G__43917__$1$jscomp$inline_4306_map__43913__$1_or__5025__auto__$jscomp$264$$)?$JSCompiler_temp$jscomp$591_thumbnail_QMARK_$$=$G__43917$jscomp$inline_4305_G__43917__$1$jscomp$inline_4306_map__43913__$1_or__5025__auto__$jscomp$264$$:
($G__43917$jscomp$inline_4305_G__43917__$1$jscomp$inline_4306_map__43913__$1_or__5025__auto__$jscomp$264$$=$APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"assets/by-file-media-id/"])),$G__43917$jscomp$inline_4305_G__43917__$1$jscomp$inline_4306_map__43913__$1_or__5025__auto__$jscomp$264$$=$JSCompiler_temp$jscomp$591_thumbnail_QMARK_$$===!0?$APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__43917$jscomp$inline_4305_G__43917__$1$jscomp$inline_4306_map__43913__$1_or__5025__auto__$jscomp$264$$,
""+($id$jscomp$41_p__43912$$??"")+"/thumbnail"])):$G__43917$jscomp$inline_4305_G__43917__$1$jscomp$inline_4306_map__43913__$1_or__5025__auto__$jscomp$264$$,$JSCompiler_temp$jscomp$591_thumbnail_QMARK_$$=""+(($JSCompiler_temp$jscomp$591_thumbnail_QMARK_$$===!1?$APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__43917$jscomp$inline_4305_G__43917__$1$jscomp$inline_4306_map__43913__$1_or__5025__auto__$jscomp$264$$,""+($id$jscomp$41_p__43912$$??
"")])):$G__43917$jscomp$inline_4305_G__43917__$1$jscomp$inline_4306_map__43913__$1_or__5025__auto__$jscomp$264$$)??""));return $JSCompiler_temp$jscomp$591_thumbnail_QMARK_$$};$APP.$app$config$resolve_file_media$$.$cljs$lang$maxFixedArity$=2;var $cljs$pprint$print$$=function $cljs$pprint$print$$($var_args$jscomp$740$$){for(var $args__5755__auto__$jscomp$135$$=[],$len__5749__auto___45608$$=arguments.length,$i__5750__auto___45609$$=0;;)if($i__5750__auto___45609$$<$len__5749__auto___45608$$)$args__5755__auto__$jscomp$135$$.push(arguments[$i__5750__auto___45609$$]),$i__5750__auto___45609$$+=1;else break;return $cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$135$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$135$$.slice(0),
0,null):null)};$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$=function($more$jscomp$42$$){return $APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$print_str$$,$more$jscomp$42$$))};$cljs$pprint$print$$.$cljs$lang$maxFixedArity$=0;$cljs$pprint$print$$.$cljs$lang$applyTo$=function($seq42944$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq42944$$))};
var $cljs$pprint$pr$$=function $cljs$pprint$pr$$($var_args$jscomp$742$$){for(var $args__5755__auto__$jscomp$137$$=[],$len__5749__auto___45620$$=arguments.length,$i__5750__auto___45621$$=0;;)if($i__5750__auto___45621$$<$len__5749__auto___45620$$)$args__5755__auto__$jscomp$137$$.push(arguments[$i__5750__auto___45621$$]),$i__5750__auto___45621$$+=1;else break;return $cljs$pprint$pr$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$137$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$137$$.slice(0),
0,null):null)};$cljs$pprint$pr$$.$cljs$core$IFn$_invoke$arity$variadic$=function($more$jscomp$44$$){return $APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pr_str$$,$more$jscomp$44$$))};$cljs$pprint$pr$$.$cljs$lang$maxFixedArity$=0;$cljs$pprint$pr$$.$cljs$lang$applyTo$=function($seq42988$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq42988$$))};$APP.$JSCompiler_prototypeAlias$$=$cljs$pprint$t_cljs$0pprint43189$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_43191$$,$meta43190__$1$$){return new $cljs$pprint$t_cljs$0pprint43189$$(this.$writer$,this.$max_columns$,this.$fields$,$meta43190__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta43190$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDeref$_deref$arity$1$=function(){return this.$fields$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWriter$_flush$arity$1$=function(){return $cljs$core$_flush$$(this.$writer$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWriter$_write$arity$2$=function($expr__43197_nl_this$$jscomp$523$$,$x$jscomp$1025$$){$expr__43197_nl_this$$jscomp$523$$=$APP.$cljs$core$type$$($x$jscomp$1025$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(String,$expr__43197_nl_this$$jscomp$523$$):$APP.$cljs$core$_EQ_$$(String,$expr__43197_nl_this$$jscomp$523$$)))return $expr__43197_nl_this$$jscomp$523$$=$x$jscomp$1025$$.lastIndexOf("\n"),
$expr__43197_nl_this$$jscomp$523$$<0?$cljs$pprint$set_field$$(this,$cljs$cst$1362$cur$$,$cljs$pprint$get_field$$(this,$cljs$cst$1362$cur$$)+$APP.$cljs$core$count$$($x$jscomp$1025$$)):($cljs$pprint$set_field$$(this,$cljs$cst$1362$cur$$,$APP.$cljs$core$count$$($x$jscomp$1025$$)-$expr__43197_nl_this$$jscomp$523$$-1),$cljs$pprint$set_field$$(this,$APP.$cljs$cst$209$line$$,$cljs$pprint$get_field$$(this,$APP.$cljs$cst$209$line$$)+$APP.$cljs$core$count$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__43176_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__43176_SHARP_$$,
"\n")},$x$jscomp$1025$$)))),$APP.$cljs$core$_write$$($cljs$pprint$get_field$$(this,$APP.$cljs$cst$1278$base$$),$x$jscomp$1025$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(Number,$expr__43197_nl_this$$jscomp$523$$):$APP.$cljs$core$_EQ_$$(Number,$expr__43197_nl_this$$jscomp$523$$)))return $cljs$pprint$c_write_char$$(this,$x$jscomp$1025$$);throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expr__43197_nl_this$$jscomp$523$$)].join(""));
};$APP.$JSCompiler_prototypeAlias$$=$cljs$pprint$logical_block$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$7$$,$k__5324__auto__$jscomp$7$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$7$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$7$$,$k43218$$,$else__5326__auto__$jscomp$7$$){switch($k43218$$ instanceof $APP.$cljs$core$Keyword$$?$k43218$$.$fqn$:null){case "parent":return this.parent;case "section":return this.section;case "start-col":return this.$start_col$;case "indent":return this.$indent$;case "done-nl":return this.$done_nl$;case "intra-block-nl":return this.$intra_block_nl$;case "prefix":return this.prefix;case "per-line-prefix":return this.$per_line_prefix$;
case "suffix":return this.$suffix$;case "logical-block-callback":return this.$logical_block_callback$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k43218$$,$else__5326__auto__$jscomp$7$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$7$$,$f__5344__auto__$jscomp$7$$,$init__5345__auto__$jscomp$7$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$7$$,$p__43229_v__5348__auto__$jscomp$7$$){var $k__5347__auto__$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__43229_v__5348__auto__$jscomp$7$$,0,null);$p__43229_v__5348__auto__$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__43229_v__5348__auto__$jscomp$7$$,
1,null);return $f__5344__auto__$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$7$$,$k__5347__auto__$jscomp$7$$,$p__43229_v__5348__auto__$jscomp$7$$):$f__5344__auto__$jscomp$7$$($ret__5346__auto__$jscomp$7$$,$k__5347__auto__$jscomp$7$$,$p__43229_v__5348__auto__$jscomp$7$$)},$init__5345__auto__$jscomp$7$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$7$$,$writer__5339__auto__$jscomp$7$$,$opts__5340__auto__$jscomp$7$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$7$$,function($keyval__5342__auto__$jscomp$7$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$7$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$7$$,$keyval__5342__auto__$jscomp$7$$)},"#cljs.pprint.logical-block{",
", ","}",$opts__5340__auto__$jscomp$7$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1365$parent$$,this.parent],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1366$section$$,this.section],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1367$start_col$$,this.$start_col$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$294$indent$$,this.$indent$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1368$done_nl$$,this.$done_nl$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1369$intra_block_nl$$,
this.$intra_block_nl$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$971$prefix$$,this.prefix],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1370$per_line_prefix$$,this.$per_line_prefix$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1371$suffix$$,this.$suffix$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1372$logical_block_callback$$,this.$logical_block_callback$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,10,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1365$parent$$,$APP.$cljs$cst$1366$section$$,$cljs$cst$1367$start_col$$,$APP.$cljs$cst$294$indent$$,$cljs$cst$1368$done_nl$$,$cljs$cst$1369$intra_block_nl$$,$APP.$cljs$cst$971$prefix$$,$cljs$cst$1370$per_line_prefix$$,$APP.$cljs$cst$1371$suffix$$,$cljs$cst$1372$logical_block_callback$$],
null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$pprint$logical_block$$(this.parent,this.section,this.$start_col$,this.$indent$,this.$done_nl$,this.$intra_block_nl$,this.prefix,this.$per_line_prefix$,this.$suffix$,this.$logical_block_callback$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 10+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$35_h__5134__auto____$1$jscomp$35$$=this.$__hash$;return $h__5134__auto__$jscomp$35_h__5134__auto____$1$jscomp$35$$!=null?$h__5134__auto__$jscomp$35_h__5134__auto____$1$jscomp$35$$:this.$__hash$=$h__5134__auto__$jscomp$35_h__5134__auto____$1$jscomp$35$$=1977012399^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this43219$$,$other43220$$){return $other43220$$!=null&&this.constructor===$other43220$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.parent,$other43220$$.parent)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.section,$other43220$$.section)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$start_col$,$other43220$$.$start_col$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$indent$,
$other43220$$.$indent$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$done_nl$,$other43220$$.$done_nl$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$intra_block_nl$,$other43220$$.$intra_block_nl$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.prefix,$other43220$$.prefix)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$per_line_prefix$,$other43220$$.$per_line_prefix$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$suffix$,
$other43220$$.$suffix$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$logical_block_callback$,$other43220$$.$logical_block_callback$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other43220$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$7$$,$k__5334__auto__$jscomp$7$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,10,[$APP.$cljs$cst$1371$suffix$$,null,$APP.$cljs$cst$294$indent$$,null,$APP.$cljs$cst$1365$parent$$,null,$APP.$cljs$cst$1366$section$$,null,$cljs$cst$1368$done_nl$$,null,$cljs$cst$1367$start_col$$,null,$APP.$cljs$cst$971$prefix$$,null,
$cljs$cst$1370$per_line_prefix$$,null,$cljs$cst$1372$logical_block_callback$$,null,$cljs$cst$1369$intra_block_nl$$,null],null),null),$k__5334__auto__$jscomp$7$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),this.$__meta$),$k__5334__auto__$jscomp$7$$):new $cljs$pprint$logical_block$$(this.parent,this.section,this.$start_col$,this.$indent$,this.$done_nl$,this.$intra_block_nl$,
this.prefix,this.$per_line_prefix$,this.$suffix$,this.$logical_block_callback$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$7$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$7$$,$k43218$jscomp$1$$){switch($k43218$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k43218$jscomp$1$$.$fqn$:null){case "parent":case "section":case "start-col":case "indent":case "done-nl":case "intra-block-nl":case "prefix":case "per-line-prefix":case "suffix":case "logical-block-callback":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k43218$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$7$$,$k__5332__auto__$jscomp$7$$,$G__43217$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1365$parent$$,$k__5332__auto__$jscomp$7$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1365$parent$$,$k__5332__auto__$jscomp$7$$))?
new $cljs$pprint$logical_block$$($G__43217$jscomp$1$$,this.section,this.$start_col$,this.$indent$,this.$done_nl$,this.$intra_block_nl$,this.prefix,this.$per_line_prefix$,this.$suffix$,this.$logical_block_callback$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1366$section$$,$k__5332__auto__$jscomp$7$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1366$section$$,
$k__5332__auto__$jscomp$7$$))?new $cljs$pprint$logical_block$$(this.parent,$G__43217$jscomp$1$$,this.$start_col$,this.$indent$,this.$done_nl$,this.$intra_block_nl$,this.prefix,this.$per_line_prefix$,this.$suffix$,this.$logical_block_callback$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1367$start_col$$,$k__5332__auto__$jscomp$7$$):
$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1367$start_col$$,$k__5332__auto__$jscomp$7$$))?new $cljs$pprint$logical_block$$(this.parent,this.section,$G__43217$jscomp$1$$,this.$indent$,this.$done_nl$,this.$intra_block_nl$,this.prefix,this.$per_line_prefix$,this.$suffix$,this.$logical_block_callback$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$294$indent$$,
$k__5332__auto__$jscomp$7$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$294$indent$$,$k__5332__auto__$jscomp$7$$))?new $cljs$pprint$logical_block$$(this.parent,this.section,this.$start_col$,$G__43217$jscomp$1$$,this.$done_nl$,this.$intra_block_nl$,this.prefix,this.$per_line_prefix$,this.$suffix$,this.$logical_block_callback$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1368$done_nl$$,
$k__5332__auto__$jscomp$7$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1368$done_nl$$,$k__5332__auto__$jscomp$7$$))?new $cljs$pprint$logical_block$$(this.parent,this.section,this.$start_col$,this.$indent$,$G__43217$jscomp$1$$,this.$intra_block_nl$,this.prefix,this.$per_line_prefix$,this.$suffix$,this.$logical_block_callback$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1369$intra_block_nl$$,
$k__5332__auto__$jscomp$7$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1369$intra_block_nl$$,$k__5332__auto__$jscomp$7$$))?new $cljs$pprint$logical_block$$(this.parent,this.section,this.$start_col$,this.$indent$,this.$done_nl$,$G__43217$jscomp$1$$,this.prefix,this.$per_line_prefix$,this.$suffix$,this.$logical_block_callback$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$971$prefix$$,
$k__5332__auto__$jscomp$7$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$971$prefix$$,$k__5332__auto__$jscomp$7$$))?new $cljs$pprint$logical_block$$(this.parent,this.section,this.$start_col$,this.$indent$,this.$done_nl$,this.$intra_block_nl$,$G__43217$jscomp$1$$,this.$per_line_prefix$,this.$suffix$,this.$logical_block_callback$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1370$per_line_prefix$$,
$k__5332__auto__$jscomp$7$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1370$per_line_prefix$$,$k__5332__auto__$jscomp$7$$))?new $cljs$pprint$logical_block$$(this.parent,this.section,this.$start_col$,this.$indent$,this.$done_nl$,this.$intra_block_nl$,this.prefix,$G__43217$jscomp$1$$,this.$suffix$,this.$logical_block_callback$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1371$suffix$$,
$k__5332__auto__$jscomp$7$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1371$suffix$$,$k__5332__auto__$jscomp$7$$))?new $cljs$pprint$logical_block$$(this.parent,this.section,this.$start_col$,this.$indent$,this.$done_nl$,this.$intra_block_nl$,this.prefix,this.$per_line_prefix$,$G__43217$jscomp$1$$,this.$logical_block_callback$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1372$logical_block_callback$$,
$k__5332__auto__$jscomp$7$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1372$logical_block_callback$$,$k__5332__auto__$jscomp$7$$))?new $cljs$pprint$logical_block$$(this.parent,this.section,this.$start_col$,this.$indent$,this.$done_nl$,this.$intra_block_nl$,this.prefix,this.$per_line_prefix$,this.$suffix$,$G__43217$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $cljs$pprint$logical_block$$(this.parent,this.section,this.$start_col$,this.$indent$,this.$done_nl$,this.$intra_block_nl$,this.prefix,
this.$per_line_prefix$,this.$suffix$,this.$logical_block_callback$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$7$$,$G__43217$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1365$parent$$,this.parent,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1366$section$$,this.section,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1367$start_col$$,this.$start_col$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$294$indent$$,
this.$indent$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1368$done_nl$$,this.$done_nl$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1369$intra_block_nl$$,this.$intra_block_nl$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$971$prefix$$,this.prefix,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1370$per_line_prefix$$,this.$per_line_prefix$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1371$suffix$$,this.$suffix$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1372$logical_block_callback$$,
this.$logical_block_callback$,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$7$$,$G__43217$jscomp$2$$){return new $cljs$pprint$logical_block$$(this.parent,this.section,this.$start_col$,this.$indent$,this.$done_nl$,this.$intra_block_nl$,this.prefix,this.$per_line_prefix$,this.$suffix$,this.$logical_block_callback$,$G__43217$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$7$$,$entry__5329__auto__$jscomp$7$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$7$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$7$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$7$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$7$$)};
$APP.$JSCompiler_prototypeAlias$$=$cljs$pprint$buffer_blob$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$8$$,$k__5324__auto__$jscomp$8$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$8$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$8$$,$k43268$$,$else__5326__auto__$jscomp$8$$){switch($k43268$$ instanceof $APP.$cljs$core$Keyword$$?$k43268$$.$fqn$:null){case "type-tag":return this.$type_tag$;case "data":return this.data;case "trailing-white-space":return this.$trailing_white_space$;case "start-pos":return this.$start_pos$;case "end-pos":return this.$end_pos$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,
$k43268$$,$else__5326__auto__$jscomp$8$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$8$$,$f__5344__auto__$jscomp$8$$,$init__5345__auto__$jscomp$8$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$8$$,$p__43281_v__5348__auto__$jscomp$8$$){var $k__5347__auto__$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__43281_v__5348__auto__$jscomp$8$$,0,null);$p__43281_v__5348__auto__$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__43281_v__5348__auto__$jscomp$8$$,
1,null);return $f__5344__auto__$jscomp$8$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$8$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$8$$,$k__5347__auto__$jscomp$8$$,$p__43281_v__5348__auto__$jscomp$8$$):$f__5344__auto__$jscomp$8$$($ret__5346__auto__$jscomp$8$$,$k__5347__auto__$jscomp$8$$,$p__43281_v__5348__auto__$jscomp$8$$)},$init__5345__auto__$jscomp$8$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$8$$,$writer__5339__auto__$jscomp$8$$,$opts__5340__auto__$jscomp$8$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$8$$,function($keyval__5342__auto__$jscomp$8$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$8$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$8$$,$keyval__5342__auto__$jscomp$8$$)},"#cljs.pprint.buffer-blob{",
", ","}",$opts__5340__auto__$jscomp$8$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1383$type_tag$$,this.$type_tag$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,this.data],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1384$trailing_white_space$$,this.$trailing_white_space$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1382$start_pos$$,this.$start_pos$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1381$end_pos$$,this.$end_pos$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,5,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1383$type_tag$$,$APP.$cljs$cst$142$data$$,$cljs$cst$1384$trailing_white_space$$,$cljs$cst$1382$start_pos$$,$cljs$cst$1381$end_pos$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$pprint$buffer_blob$$(this.$type_tag$,this.data,this.$trailing_white_space$,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 5+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$36_h__5134__auto____$1$jscomp$36$$=this.$__hash$;return $h__5134__auto__$jscomp$36_h__5134__auto____$1$jscomp$36$$!=null?$h__5134__auto__$jscomp$36_h__5134__auto____$1$jscomp$36$$:this.$__hash$=$h__5134__auto__$jscomp$36_h__5134__auto____$1$jscomp$36$$=1809113693^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this43269$$,$other43270$$){return $other43270$$!=null&&this.constructor===$other43270$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$type_tag$,$other43270$$.$type_tag$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.data,$other43270$$.data)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$trailing_white_space$,$other43270$$.$trailing_white_space$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$start_pos$,
$other43270$$.$start_pos$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$end_pos$,$other43270$$.$end_pos$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other43270$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$8$$,$k__5334__auto__$jscomp$8$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1381$end_pos$$,null,$cljs$cst$1384$trailing_white_space$$,null,$cljs$cst$1383$type_tag$$,null,$cljs$cst$1382$start_pos$$,null,$APP.$cljs$cst$142$data$$,null],null),null),$k__5334__auto__$jscomp$8$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$8$$):new $cljs$pprint$buffer_blob$$(this.$type_tag$,this.data,this.$trailing_white_space$,this.$start_pos$,this.$end_pos$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$8$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$8$$,$k43268$jscomp$1$$){switch($k43268$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k43268$jscomp$1$$.$fqn$:null){case "type-tag":case "data":case "trailing-white-space":case "start-pos":case "end-pos":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k43268$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$8$$,$k__5332__auto__$jscomp$8$$,$G__43267$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1383$type_tag$$,$k__5332__auto__$jscomp$8$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1383$type_tag$$,$k__5332__auto__$jscomp$8$$))?new $cljs$pprint$buffer_blob$$($G__43267$jscomp$1$$,
this.data,this.$trailing_white_space$,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$8$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$8$$))?new $cljs$pprint$buffer_blob$$(this.$type_tag$,$G__43267$jscomp$1$$,
this.$trailing_white_space$,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1384$trailing_white_space$$,$k__5332__auto__$jscomp$8$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1384$trailing_white_space$$,$k__5332__auto__$jscomp$8$$))?new $cljs$pprint$buffer_blob$$(this.$type_tag$,this.data,
$G__43267$jscomp$1$$,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1382$start_pos$$,$k__5332__auto__$jscomp$8$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1382$start_pos$$,$k__5332__auto__$jscomp$8$$))?new $cljs$pprint$buffer_blob$$(this.$type_tag$,this.data,this.$trailing_white_space$,
$G__43267$jscomp$1$$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1381$end_pos$$,$k__5332__auto__$jscomp$8$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1381$end_pos$$,$k__5332__auto__$jscomp$8$$))?new $cljs$pprint$buffer_blob$$(this.$type_tag$,this.data,this.$trailing_white_space$,this.$start_pos$,
$G__43267$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $cljs$pprint$buffer_blob$$(this.$type_tag$,this.data,this.$trailing_white_space$,this.$start_pos$,this.$end_pos$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$8$$,$G__43267$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$1383$type_tag$$,this.$type_tag$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$142$data$$,this.data,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1384$trailing_white_space$$,this.$trailing_white_space$,
null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1382$start_pos$$,this.$start_pos$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1381$end_pos$$,this.$end_pos$,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$8$$,$G__43267$jscomp$2$$){return new $cljs$pprint$buffer_blob$$(this.$type_tag$,this.data,this.$trailing_white_space$,this.$start_pos$,this.$end_pos$,$G__43267$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$8$$,$entry__5329__auto__$jscomp$8$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$8$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$8$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$8$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$8$$)};
$APP.$JSCompiler_prototypeAlias$$=$cljs$pprint$nl_t$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$9$$,$k__5324__auto__$jscomp$9$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$9$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$9$$,$k43316$$,$else__5326__auto__$jscomp$9$$){switch($k43316$$ instanceof $APP.$cljs$core$Keyword$$?$k43316$$.$fqn$:null){case "type-tag":return this.$type_tag$;case "type":return this.type;case "logical-block":return this.$logical_block$;case "start-pos":return this.$start_pos$;case "end-pos":return this.$end_pos$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,
$k43316$$,$else__5326__auto__$jscomp$9$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$9$$,$f__5344__auto__$jscomp$9$$,$init__5345__auto__$jscomp$9$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$9$$,$p__43335_v__5348__auto__$jscomp$9$$){var $k__5347__auto__$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__43335_v__5348__auto__$jscomp$9$$,0,null);$p__43335_v__5348__auto__$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__43335_v__5348__auto__$jscomp$9$$,
1,null);return $f__5344__auto__$jscomp$9$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$9$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$9$$,$k__5347__auto__$jscomp$9$$,$p__43335_v__5348__auto__$jscomp$9$$):$f__5344__auto__$jscomp$9$$($ret__5346__auto__$jscomp$9$$,$k__5347__auto__$jscomp$9$$,$p__43335_v__5348__auto__$jscomp$9$$)},$init__5345__auto__$jscomp$9$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$9$$,$writer__5339__auto__$jscomp$9$$,$opts__5340__auto__$jscomp$9$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$9$$,function($keyval__5342__auto__$jscomp$9$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$9$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$9$$,$keyval__5342__auto__$jscomp$9$$)},"#cljs.pprint.nl-t{",
", ","}",$opts__5340__auto__$jscomp$9$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1383$type_tag$$,this.$type_tag$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,this.type],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1391$logical_block$$,this.$logical_block$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1382$start_pos$$,this.$start_pos$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1381$end_pos$$,this.$end_pos$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,5,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1383$type_tag$$,$APP.$cljs$cst$139$type$$,$cljs$cst$1391$logical_block$$,$cljs$cst$1382$start_pos$$,$cljs$cst$1381$end_pos$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$pprint$nl_t$$(this.$type_tag$,this.type,this.$logical_block$,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 5+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$37_h__5134__auto____$1$jscomp$37$$=this.$__hash$;return $h__5134__auto__$jscomp$37_h__5134__auto____$1$jscomp$37$$!=null?$h__5134__auto__$jscomp$37_h__5134__auto____$1$jscomp$37$$:this.$__hash$=$h__5134__auto__$jscomp$37_h__5134__auto____$1$jscomp$37$$=-1640656800^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this43317$$,$other43318$$){return $other43318$$!=null&&this.constructor===$other43318$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$type_tag$,$other43318$$.$type_tag$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.type,$other43318$$.type)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$logical_block$,$other43318$$.$logical_block$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$start_pos$,
$other43318$$.$start_pos$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$end_pos$,$other43318$$.$end_pos$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other43318$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$9$$,$k__5334__auto__$jscomp$9$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1381$end_pos$$,null,$APP.$cljs$cst$139$type$$,null,$cljs$cst$1391$logical_block$$,null,$cljs$cst$1383$type_tag$$,null,$cljs$cst$1382$start_pos$$,null],null),null),$k__5334__auto__$jscomp$9$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$9$$):new $cljs$pprint$nl_t$$(this.$type_tag$,this.type,this.$logical_block$,this.$start_pos$,this.$end_pos$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$9$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$9$$,$k43316$jscomp$1$$){switch($k43316$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k43316$jscomp$1$$.$fqn$:null){case "type-tag":case "type":case "logical-block":case "start-pos":case "end-pos":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k43316$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$9$$,$k__5332__auto__$jscomp$9$$,$G__43315$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1383$type_tag$$,$k__5332__auto__$jscomp$9$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1383$type_tag$$,$k__5332__auto__$jscomp$9$$))?new $cljs$pprint$nl_t$$($G__43315$jscomp$1$$,
this.type,this.$logical_block$,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$,$k__5332__auto__$jscomp$9$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$139$type$$,$k__5332__auto__$jscomp$9$$))?new $cljs$pprint$nl_t$$(this.$type_tag$,$G__43315$jscomp$1$$,this.$logical_block$,
this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1391$logical_block$$,$k__5332__auto__$jscomp$9$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1391$logical_block$$,$k__5332__auto__$jscomp$9$$))?new $cljs$pprint$nl_t$$(this.$type_tag$,this.type,$G__43315$jscomp$1$$,this.$start_pos$,this.$end_pos$,
this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1382$start_pos$$,$k__5332__auto__$jscomp$9$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1382$start_pos$$,$k__5332__auto__$jscomp$9$$))?new $cljs$pprint$nl_t$$(this.$type_tag$,this.type,this.$logical_block$,$G__43315$jscomp$1$$,this.$end_pos$,this.$__meta$,this.$__extmap$,
null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1381$end_pos$$,$k__5332__auto__$jscomp$9$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1381$end_pos$$,$k__5332__auto__$jscomp$9$$))?new $cljs$pprint$nl_t$$(this.$type_tag$,this.type,this.$logical_block$,this.$start_pos$,$G__43315$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $cljs$pprint$nl_t$$(this.$type_tag$,
this.type,this.$logical_block$,this.$start_pos$,this.$end_pos$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$9$$,$G__43315$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$1383$type_tag$$,this.$type_tag$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$139$type$$,this.type,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1391$logical_block$$,this.$logical_block$,null),
new $APP.$cljs$core$MapEntry$$($cljs$cst$1382$start_pos$$,this.$start_pos$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1381$end_pos$$,this.$end_pos$,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$9$$,$G__43315$jscomp$2$$){return new $cljs$pprint$nl_t$$(this.$type_tag$,this.type,this.$logical_block$,this.$start_pos$,this.$end_pos$,$G__43315$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$9$$,$entry__5329__auto__$jscomp$9$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$9$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$9$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$9$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$9$$)};
$APP.$JSCompiler_prototypeAlias$$=$cljs$pprint$start_block_t$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$10$$,$k__5324__auto__$jscomp$10$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$10$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$10$$,$k43372$$,$else__5326__auto__$jscomp$10$$){switch($k43372$$ instanceof $APP.$cljs$core$Keyword$$?$k43372$$.$fqn$:null){case "type-tag":return this.$type_tag$;case "logical-block":return this.$logical_block$;case "start-pos":return this.$start_pos$;case "end-pos":return this.$end_pos$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k43372$$,$else__5326__auto__$jscomp$10$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$10$$,$f__5344__auto__$jscomp$10$$,$init__5345__auto__$jscomp$10$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$10$$,$p__43382_v__5348__auto__$jscomp$10$$){var $k__5347__auto__$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__43382_v__5348__auto__$jscomp$10$$,0,null);$p__43382_v__5348__auto__$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__43382_v__5348__auto__$jscomp$10$$,
1,null);return $f__5344__auto__$jscomp$10$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$10$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$10$$,$k__5347__auto__$jscomp$10$$,$p__43382_v__5348__auto__$jscomp$10$$):$f__5344__auto__$jscomp$10$$($ret__5346__auto__$jscomp$10$$,$k__5347__auto__$jscomp$10$$,$p__43382_v__5348__auto__$jscomp$10$$)},$init__5345__auto__$jscomp$10$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$10$$,$writer__5339__auto__$jscomp$10$$,$opts__5340__auto__$jscomp$10$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$10$$,function($keyval__5342__auto__$jscomp$10$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$10$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$10$$,$keyval__5342__auto__$jscomp$10$$)},"#cljs.pprint.start-block-t{",
", ","}",$opts__5340__auto__$jscomp$10$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1383$type_tag$$,this.$type_tag$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1391$logical_block$$,this.$logical_block$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1382$start_pos$$,this.$start_pos$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1381$end_pos$$,this.$end_pos$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,4,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1383$type_tag$$,$cljs$cst$1391$logical_block$$,$cljs$cst$1382$start_pos$$,$cljs$cst$1381$end_pos$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$pprint$start_block_t$$(this.$type_tag$,this.$logical_block$,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 4+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$38_h__5134__auto____$1$jscomp$38$$=this.$__hash$;return $h__5134__auto__$jscomp$38_h__5134__auto____$1$jscomp$38$$!=null?$h__5134__auto__$jscomp$38_h__5134__auto____$1$jscomp$38$$:this.$__hash$=$h__5134__auto__$jscomp$38_h__5134__auto____$1$jscomp$38$$=-414877272^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this43373$$,$other43374$$){return $other43374$$!=null&&this.constructor===$other43374$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$type_tag$,$other43374$$.$type_tag$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$logical_block$,$other43374$$.$logical_block$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$start_pos$,$other43374$$.$start_pos$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$end_pos$,
$other43374$$.$end_pos$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other43374$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$10$$,$k__5334__auto__$jscomp$10$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1381$end_pos$$,null,$cljs$cst$1391$logical_block$$,null,$cljs$cst$1383$type_tag$$,null,$cljs$cst$1382$start_pos$$,null],null),null),$k__5334__auto__$jscomp$10$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$10$$):new $cljs$pprint$start_block_t$$(this.$type_tag$,this.$logical_block$,this.$start_pos$,this.$end_pos$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$10$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$10$$,$k43372$jscomp$1$$){switch($k43372$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k43372$jscomp$1$$.$fqn$:null){case "type-tag":case "logical-block":case "start-pos":case "end-pos":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k43372$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$10$$,$k__5332__auto__$jscomp$10$$,$G__43371$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1383$type_tag$$,$k__5332__auto__$jscomp$10$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1383$type_tag$$,$k__5332__auto__$jscomp$10$$))?
new $cljs$pprint$start_block_t$$($G__43371$jscomp$1$$,this.$logical_block$,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1391$logical_block$$,$k__5332__auto__$jscomp$10$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1391$logical_block$$,$k__5332__auto__$jscomp$10$$))?new $cljs$pprint$start_block_t$$(this.$type_tag$,
$G__43371$jscomp$1$$,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1382$start_pos$$,$k__5332__auto__$jscomp$10$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1382$start_pos$$,$k__5332__auto__$jscomp$10$$))?new $cljs$pprint$start_block_t$$(this.$type_tag$,this.$logical_block$,$G__43371$jscomp$1$$,
this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1381$end_pos$$,$k__5332__auto__$jscomp$10$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1381$end_pos$$,$k__5332__auto__$jscomp$10$$))?new $cljs$pprint$start_block_t$$(this.$type_tag$,this.$logical_block$,this.$start_pos$,$G__43371$jscomp$1$$,this.$__meta$,
this.$__extmap$,null):new $cljs$pprint$start_block_t$$(this.$type_tag$,this.$logical_block$,this.$start_pos$,this.$end_pos$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$10$$,$G__43371$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$1383$type_tag$$,this.$type_tag$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1391$logical_block$$,this.$logical_block$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1382$start_pos$$,this.$start_pos$,
null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1381$end_pos$$,this.$end_pos$,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$10$$,$G__43371$jscomp$2$$){return new $cljs$pprint$start_block_t$$(this.$type_tag$,this.$logical_block$,this.$start_pos$,this.$end_pos$,$G__43371$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$10$$,$entry__5329__auto__$jscomp$10$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$10$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$10$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$10$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$10$$)};
$APP.$JSCompiler_prototypeAlias$$=$cljs$pprint$end_block_t$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$11$$,$k__5324__auto__$jscomp$11$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$11$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$11$$,$k43423$$,$else__5326__auto__$jscomp$11$$){switch($k43423$$ instanceof $APP.$cljs$core$Keyword$$?$k43423$$.$fqn$:null){case "type-tag":return this.$type_tag$;case "logical-block":return this.$logical_block$;case "start-pos":return this.$start_pos$;case "end-pos":return this.$end_pos$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k43423$$,$else__5326__auto__$jscomp$11$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$11$$,$f__5344__auto__$jscomp$11$$,$init__5345__auto__$jscomp$11$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$11$$,$p__43438_v__5348__auto__$jscomp$11$$){var $k__5347__auto__$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__43438_v__5348__auto__$jscomp$11$$,0,null);$p__43438_v__5348__auto__$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__43438_v__5348__auto__$jscomp$11$$,
1,null);return $f__5344__auto__$jscomp$11$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$11$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$11$$,$k__5347__auto__$jscomp$11$$,$p__43438_v__5348__auto__$jscomp$11$$):$f__5344__auto__$jscomp$11$$($ret__5346__auto__$jscomp$11$$,$k__5347__auto__$jscomp$11$$,$p__43438_v__5348__auto__$jscomp$11$$)},$init__5345__auto__$jscomp$11$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$11$$,$writer__5339__auto__$jscomp$11$$,$opts__5340__auto__$jscomp$11$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$11$$,function($keyval__5342__auto__$jscomp$11$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$11$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$11$$,$keyval__5342__auto__$jscomp$11$$)},"#cljs.pprint.end-block-t{",
", ","}",$opts__5340__auto__$jscomp$11$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1383$type_tag$$,this.$type_tag$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1391$logical_block$$,this.$logical_block$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1382$start_pos$$,this.$start_pos$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1381$end_pos$$,this.$end_pos$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,4,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1383$type_tag$$,$cljs$cst$1391$logical_block$$,$cljs$cst$1382$start_pos$$,$cljs$cst$1381$end_pos$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$pprint$end_block_t$$(this.$type_tag$,this.$logical_block$,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 4+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$39_h__5134__auto____$1$jscomp$39$$=this.$__hash$;return $h__5134__auto__$jscomp$39_h__5134__auto____$1$jscomp$39$$!=null?$h__5134__auto__$jscomp$39_h__5134__auto____$1$jscomp$39$$:this.$__hash$=$h__5134__auto__$jscomp$39_h__5134__auto____$1$jscomp$39$$=1365867980^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this43425$$,$other43426$$){return $other43426$$!=null&&this.constructor===$other43426$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$type_tag$,$other43426$$.$type_tag$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$logical_block$,$other43426$$.$logical_block$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$start_pos$,$other43426$$.$start_pos$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$end_pos$,
$other43426$$.$end_pos$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other43426$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$11$$,$k__5334__auto__$jscomp$11$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1381$end_pos$$,null,$cljs$cst$1391$logical_block$$,null,$cljs$cst$1383$type_tag$$,null,$cljs$cst$1382$start_pos$$,null],null),null),$k__5334__auto__$jscomp$11$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$11$$):new $cljs$pprint$end_block_t$$(this.$type_tag$,this.$logical_block$,this.$start_pos$,this.$end_pos$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$11$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$11$$,$k43423$jscomp$1$$){switch($k43423$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k43423$jscomp$1$$.$fqn$:null){case "type-tag":case "logical-block":case "start-pos":case "end-pos":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k43423$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$11$$,$k__5332__auto__$jscomp$11$$,$G__43422$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1383$type_tag$$,$k__5332__auto__$jscomp$11$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1383$type_tag$$,$k__5332__auto__$jscomp$11$$))?
new $cljs$pprint$end_block_t$$($G__43422$jscomp$1$$,this.$logical_block$,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1391$logical_block$$,$k__5332__auto__$jscomp$11$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1391$logical_block$$,$k__5332__auto__$jscomp$11$$))?new $cljs$pprint$end_block_t$$(this.$type_tag$,
$G__43422$jscomp$1$$,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1382$start_pos$$,$k__5332__auto__$jscomp$11$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1382$start_pos$$,$k__5332__auto__$jscomp$11$$))?new $cljs$pprint$end_block_t$$(this.$type_tag$,this.$logical_block$,$G__43422$jscomp$1$$,
this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1381$end_pos$$,$k__5332__auto__$jscomp$11$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1381$end_pos$$,$k__5332__auto__$jscomp$11$$))?new $cljs$pprint$end_block_t$$(this.$type_tag$,this.$logical_block$,this.$start_pos$,$G__43422$jscomp$1$$,this.$__meta$,this.$__extmap$,
null):new $cljs$pprint$end_block_t$$(this.$type_tag$,this.$logical_block$,this.$start_pos$,this.$end_pos$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$11$$,$G__43422$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$1383$type_tag$$,this.$type_tag$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1391$logical_block$$,this.$logical_block$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1382$start_pos$$,this.$start_pos$,
null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1381$end_pos$$,this.$end_pos$,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$11$$,$G__43422$jscomp$2$$){return new $cljs$pprint$end_block_t$$(this.$type_tag$,this.$logical_block$,this.$start_pos$,this.$end_pos$,$G__43422$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$11$$,$entry__5329__auto__$jscomp$11$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$11$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$11$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$11$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$11$$)};
$APP.$JSCompiler_prototypeAlias$$=$cljs$pprint$indent_t$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$12$$,$k__5324__auto__$jscomp$12$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$12$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$12$$,$k43473$$,$else__5326__auto__$jscomp$12$$){switch($k43473$$ instanceof $APP.$cljs$core$Keyword$$?$k43473$$.$fqn$:null){case "type-tag":return this.$type_tag$;case "logical-block":return this.$logical_block$;case "relative-to":return this.$relative_to$;case "offset":return this.offset;case "start-pos":return this.$start_pos$;case "end-pos":return this.$end_pos$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,
$k43473$$,$else__5326__auto__$jscomp$12$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$12$$,$f__5344__auto__$jscomp$12$$,$init__5345__auto__$jscomp$12$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$12$$,$p__43481_v__5348__auto__$jscomp$12$$){var $k__5347__auto__$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__43481_v__5348__auto__$jscomp$12$$,0,null);$p__43481_v__5348__auto__$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__43481_v__5348__auto__$jscomp$12$$,
1,null);return $f__5344__auto__$jscomp$12$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$12$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$12$$,$k__5347__auto__$jscomp$12$$,$p__43481_v__5348__auto__$jscomp$12$$):$f__5344__auto__$jscomp$12$$($ret__5346__auto__$jscomp$12$$,$k__5347__auto__$jscomp$12$$,$p__43481_v__5348__auto__$jscomp$12$$)},$init__5345__auto__$jscomp$12$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$12$$,$writer__5339__auto__$jscomp$12$$,$opts__5340__auto__$jscomp$12$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$12$$,function($keyval__5342__auto__$jscomp$12$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$12$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$12$$,$keyval__5342__auto__$jscomp$12$$)},"#cljs.pprint.indent-t{",
", ","}",$opts__5340__auto__$jscomp$12$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1383$type_tag$$,this.$type_tag$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1391$logical_block$$,this.$logical_block$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1396$relative_to$$,this.$relative_to$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$195$offset$$,this.offset],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1382$start_pos$$,this.$start_pos$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1381$end_pos$$,
this.$end_pos$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,6,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1383$type_tag$$,$cljs$cst$1391$logical_block$$,$APP.$cljs$cst$1396$relative_to$$,$APP.$cljs$cst$195$offset$$,$cljs$cst$1382$start_pos$$,$cljs$cst$1381$end_pos$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$pprint$indent_t$$(this.$type_tag$,this.$logical_block$,this.$relative_to$,this.offset,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 6+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$40_h__5134__auto____$1$jscomp$40$$=this.$__hash$;return $h__5134__auto__$jscomp$40_h__5134__auto____$1$jscomp$40$$!=null?$h__5134__auto__$jscomp$40_h__5134__auto____$1$jscomp$40$$:this.$__hash$=$h__5134__auto__$jscomp$40_h__5134__auto____$1$jscomp$40$$=-1602780238^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this43474$$,$other43475$$){return $other43475$$!=null&&this.constructor===$other43475$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$type_tag$,$other43475$$.$type_tag$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$logical_block$,$other43475$$.$logical_block$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$relative_to$,$other43475$$.$relative_to$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.offset,
$other43475$$.offset)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$start_pos$,$other43475$$.$start_pos$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$end_pos$,$other43475$$.$end_pos$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other43475$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$12$$,$k__5334__auto__$jscomp$12$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$195$offset$$,null,$cljs$cst$1381$end_pos$$,null,$APP.$cljs$cst$1396$relative_to$$,null,$cljs$cst$1391$logical_block$$,null,$cljs$cst$1383$type_tag$$,null,$cljs$cst$1382$start_pos$$,null],null),null),$k__5334__auto__$jscomp$12$$)?
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),this.$__meta$),$k__5334__auto__$jscomp$12$$):new $cljs$pprint$indent_t$$(this.$type_tag$,this.$logical_block$,this.$relative_to$,this.offset,this.$start_pos$,this.$end_pos$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$12$$)),
null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$12$$,$k43473$jscomp$1$$){switch($k43473$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k43473$jscomp$1$$.$fqn$:null){case "type-tag":case "logical-block":case "relative-to":case "offset":case "start-pos":case "end-pos":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k43473$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$12$$,$k__5332__auto__$jscomp$12$$,$G__43472$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1383$type_tag$$,$k__5332__auto__$jscomp$12$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1383$type_tag$$,$k__5332__auto__$jscomp$12$$))?
new $cljs$pprint$indent_t$$($G__43472$jscomp$1$$,this.$logical_block$,this.$relative_to$,this.offset,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1391$logical_block$$,$k__5332__auto__$jscomp$12$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1391$logical_block$$,$k__5332__auto__$jscomp$12$$))?
new $cljs$pprint$indent_t$$(this.$type_tag$,$G__43472$jscomp$1$$,this.$relative_to$,this.offset,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1396$relative_to$$,$k__5332__auto__$jscomp$12$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1396$relative_to$$,$k__5332__auto__$jscomp$12$$))?
new $cljs$pprint$indent_t$$(this.$type_tag$,this.$logical_block$,$G__43472$jscomp$1$$,this.offset,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$k__5332__auto__$jscomp$12$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$195$offset$$,$k__5332__auto__$jscomp$12$$))?
new $cljs$pprint$indent_t$$(this.$type_tag$,this.$logical_block$,this.$relative_to$,$G__43472$jscomp$1$$,this.$start_pos$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1382$start_pos$$,$k__5332__auto__$jscomp$12$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1382$start_pos$$,$k__5332__auto__$jscomp$12$$))?
new $cljs$pprint$indent_t$$(this.$type_tag$,this.$logical_block$,this.$relative_to$,this.offset,$G__43472$jscomp$1$$,this.$end_pos$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1381$end_pos$$,$k__5332__auto__$jscomp$12$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1381$end_pos$$,$k__5332__auto__$jscomp$12$$))?new $cljs$pprint$indent_t$$(this.$type_tag$,
this.$logical_block$,this.$relative_to$,this.offset,this.$start_pos$,$G__43472$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $cljs$pprint$indent_t$$(this.$type_tag$,this.$logical_block$,this.$relative_to$,this.offset,this.$start_pos$,this.$end_pos$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$12$$,$G__43472$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$1383$type_tag$$,this.$type_tag$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1391$logical_block$$,this.$logical_block$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1396$relative_to$$,this.$relative_to$,
null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$195$offset$$,this.offset,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1382$start_pos$$,this.$start_pos$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1381$end_pos$$,this.$end_pos$,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$12$$,$G__43472$jscomp$2$$){return new $cljs$pprint$indent_t$$(this.$type_tag$,this.$logical_block$,this.$relative_to$,this.offset,this.$start_pos$,this.$end_pos$,$G__43472$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$12$$,$entry__5329__auto__$jscomp$12$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$12$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$12$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$12$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$12$$)};
var $cljs$pprint$write_token$$=function(){var $method_table__5622__auto__$jscomp$2$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$2$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$2$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$2$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("cljs.pprint",
"write-token"),function($p1__43532_SHARP_$$,$p2__43531_SHARP_$$){return $cljs$cst$1383$type_tag$$.$cljs$core$IFn$_invoke$arity$1$($p2__43531_SHARP_$$)},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$2$$,$method_table__5622__auto__$jscomp$2$$,$prefer_table__5623__auto__$jscomp$2$$,$method_cache__5624__auto__$jscomp$2$$,$cached_hierarchy__5625__auto__$jscomp$2$$)}();
$cljs$pprint$write_token$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$1394$start_block_t$$,function($col$jscomp$19_this$$jscomp$524$$,$lb$jscomp$1_token$jscomp$30$$){var $temp__5825__auto___45722_temp__5825__auto___45724$$=$cljs$cst$1372$logical_block_callback$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($col$jscomp$19_this$$jscomp$524$$)));$APP.$cljs$core$truth_$$($temp__5825__auto___45722_temp__5825__auto___45724$$)&&($temp__5825__auto___45722_temp__5825__auto___45724$$.$cljs$core$IFn$_invoke$arity$1$?
$temp__5825__auto___45722_temp__5825__auto___45724$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1292$start$$):$temp__5825__auto___45722_temp__5825__auto___45724$$($APP.$cljs$cst$1292$start$$));$lb$jscomp$1_token$jscomp$30$$=$cljs$cst$1391$logical_block$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$1_token$jscomp$30$$);$temp__5825__auto___45722_temp__5825__auto___45724$$=$APP.$cljs$cst$971$prefix$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$1_token$jscomp$30$$);$APP.$cljs$core$truth_$$($temp__5825__auto___45722_temp__5825__auto___45724$$)&&
$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($col$jscomp$19_this$$jscomp$524$$))),$temp__5825__auto___45722_temp__5825__auto___45724$$);$col$jscomp$19_this$$jscomp$524$$=$cljs$pprint$get_column$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($col$jscomp$19_this$$jscomp$524$$))));$APP.$cljs$core$reset_BANG_$$($cljs$cst$1367$start_col$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$1_token$jscomp$30$$),
$col$jscomp$19_this$$jscomp$524$$);return $APP.$cljs$core$reset_BANG_$$($APP.$cljs$cst$294$indent$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$1_token$jscomp$30$$),$col$jscomp$19_this$$jscomp$524$$)});
$cljs$pprint$write_token$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$1395$end_block_t$$,function($this$$jscomp$525$$,$temp__5825__auto__$jscomp$90_token$jscomp$31$$){var $temp__5825__auto___45726$$=$cljs$cst$1372$logical_block_callback$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$525$$)));$APP.$cljs$core$truth_$$($temp__5825__auto___45726$$)&&($temp__5825__auto___45726$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5825__auto___45726$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1293$end$$):
$temp__5825__auto___45726$$($APP.$cljs$cst$1293$end$$));$temp__5825__auto__$jscomp$90_token$jscomp$31$$=$APP.$cljs$cst$1371$suffix$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1391$logical_block$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto__$jscomp$90_token$jscomp$31$$));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$90_token$jscomp$31$$)?$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$525$$))),
$temp__5825__auto__$jscomp$90_token$jscomp$31$$):null});
$cljs$pprint$write_token$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$1399$indent_t$$,function($JSCompiler_inline_result$jscomp$605_this$$jscomp$526$$,$expr__43553$jscomp$inline_4333_token$jscomp$32$$){var $lb$jscomp$2$$=$cljs$cst$1391$logical_block$$.$cljs$core$IFn$_invoke$arity$1$($expr__43553$jscomp$inline_4333_token$jscomp$32$$),$JSCompiler_temp_const$jscomp$604$$=$APP.$cljs$cst$294$indent$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$2$$),$JSCompiler_temp_const$jscomp$603$$=$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($expr__43553$jscomp$inline_4333_token$jscomp$32$$);
$expr__43553$jscomp$inline_4333_token$jscomp$32$$=$APP.$cljs$cst$1396$relative_to$$.$cljs$core$IFn$_invoke$arity$1$($expr__43553$jscomp$inline_4333_token$jscomp$32$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1400$block$$,$expr__43553$jscomp$inline_4333_token$jscomp$32$$):$APP.$cljs$core$_EQ_$$($APP.$cljs$cst$1400$block$$,$expr__43553$jscomp$inline_4333_token$jscomp$32$$)))$JSCompiler_inline_result$jscomp$605_this$$jscomp$526$$=
$APP.$cljs$core$deref$$($cljs$cst$1367$start_col$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$2$$));else if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1401$current$$,$expr__43553$jscomp$inline_4333_token$jscomp$32$$):$APP.$cljs$core$_EQ_$$($cljs$cst$1401$current$$,$expr__43553$jscomp$inline_4333_token$jscomp$32$$)))$JSCompiler_inline_result$jscomp$605_this$$jscomp$526$$=$cljs$pprint$get_column$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($JSCompiler_inline_result$jscomp$605_this$$jscomp$526$$))));
else throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expr__43553$jscomp$inline_4333_token$jscomp$32$$)].join(""));return $APP.$cljs$core$reset_BANG_$$($JSCompiler_temp_const$jscomp$604$$,$JSCompiler_temp_const$jscomp$603$$+$JSCompiler_inline_result$jscomp$605_this$$jscomp$526$$)});
$cljs$pprint$write_token$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$1390$buffer_blob$$,function($this$$jscomp$527$$,$token$jscomp$33$$){return $APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$527$$))),$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$33$$))});
$cljs$pprint$write_token$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$1393$nl_t$$,function($this$$jscomp$528$$,$temp__5823__auto___45728_token$jscomp$34$$){var $JSCompiler_inline_result$jscomp$606_and__5023__auto__$jscomp$inline_4336_or__5025__auto__$jscomp$inline_4335$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($temp__5823__auto___45728_token$jscomp$34$$),$cljs$cst$1402$mandatory$$);$JSCompiler_inline_result$jscomp$606_and__5023__auto__$jscomp$inline_4336_or__5025__auto__$jscomp$inline_4335$$||
($JSCompiler_inline_result$jscomp$606_and__5023__auto__$jscomp$inline_4336_or__5025__auto__$jscomp$inline_4335$$=($JSCompiler_inline_result$jscomp$606_and__5023__auto__$jscomp$inline_4336_or__5025__auto__$jscomp$inline_4335$$=!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($temp__5823__auto___45728_token$jscomp$34$$),$APP.$cljs$cst$1403$fill$$))?$APP.$cljs$core$deref$$($cljs$cst$1368$done_nl$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1391$logical_block$$.$cljs$core$IFn$_invoke$arity$1$($temp__5823__auto___45728_token$jscomp$34$$))):
$JSCompiler_inline_result$jscomp$606_and__5023__auto__$jscomp$inline_4336_or__5025__auto__$jscomp$inline_4335$$);$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$606_and__5023__auto__$jscomp$inline_4336_or__5025__auto__$jscomp$inline_4335$$)?$cljs$pprint$emit_nl$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$pprint$emit_nl$$.$cljs$core$IFn$_invoke$arity$2$($this$$jscomp$528$$,$temp__5823__auto___45728_token$jscomp$34$$):$cljs$pprint$emit_nl$$($this$$jscomp$528$$,$temp__5823__auto___45728_token$jscomp$34$$):
($temp__5823__auto___45728_token$jscomp$34$$=$cljs$cst$1384$trailing_white_space$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$528$$))),$APP.$cljs$core$truth_$$($temp__5823__auto___45728_token$jscomp$34$$)&&$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($this$$jscomp$528$$))),$temp__5823__auto___45728_token$jscomp$34$$));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$($this$$jscomp$528$$),
$APP.$cljs$core$assoc$$,$cljs$cst$1384$trailing_white_space$$,null)});
var $cljs$pprint$emit_nl_QMARK_$$=function(){var $method_table__5622__auto__$jscomp$3$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$3$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$3$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$3$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("cljs.pprint",
"emit-nl?"),function($t$jscomp$57$$){return $APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($t$jscomp$57$$)},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$3$$,$method_table__5622__auto__$jscomp$3$$,$prefer_table__5623__auto__$jscomp$3$$,$method_cache__5624__auto__$jscomp$3$$,$cached_hierarchy__5625__auto__$jscomp$3$$)}();
$cljs$pprint$emit_nl_QMARK_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$287$linear$$,function($lb$jscomp$5_newl$$,$this$$jscomp$533$$,$section$jscomp$4$$){$lb$jscomp$5_newl$$=$cljs$cst$1391$logical_block$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$5_newl$$);return $cljs$pprint$linear_nl_QMARK_$$($this$$jscomp$533$$,$lb$jscomp$5_newl$$,$section$jscomp$4$$)});
$cljs$pprint$emit_nl_QMARK_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$288$miser$$,function($lb$jscomp$6_newl$jscomp$1$$,$this$$jscomp$534$$,$section$jscomp$5$$){$lb$jscomp$6_newl$jscomp$1$$=$cljs$cst$1391$logical_block$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$6_newl$jscomp$1$$);return $cljs$pprint$miser_nl_QMARK_$$($this$$jscomp$534$$,$lb$jscomp$6_newl$jscomp$1$$,$section$jscomp$5$$)});
$cljs$pprint$emit_nl_QMARK_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$1403$fill$$,function($lb$jscomp$7_newl$jscomp$2$$,$this$$jscomp$535$$,$section$jscomp$6$$,$or__5025__auto____$1$jscomp$33_subsection$$){$lb$jscomp$7_newl$jscomp$2$$=$cljs$cst$1391$logical_block$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$7_newl$jscomp$2$$);var $or__5025__auto__$jscomp$267$$=$APP.$cljs$core$deref$$($cljs$cst$1369$intra_block_nl$$.$cljs$core$IFn$_invoke$arity$1$($lb$jscomp$7_newl$jscomp$2$$));
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$267$$)?$or__5025__auto__$jscomp$267$$:($or__5025__auto____$1$jscomp$33_subsection$$=!$cljs$pprint$tokens_fit_QMARK_$$($this$$jscomp$535$$,$or__5025__auto____$1$jscomp$33_subsection$$))?$or__5025__auto____$1$jscomp$33_subsection$$:$cljs$pprint$miser_nl_QMARK_$$($this$$jscomp$535$$,$lb$jscomp$7_newl$jscomp$2$$,$section$jscomp$6$$)});$cljs$pprint$emit_nl_QMARK_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$1402$mandatory$$,function(){return!0});
var $cljs$pprint$write_token_string$$=function $cljs$pprint$write_token_string$$($JSCompiler_temp$jscomp$10727_this$$jscomp$537$$,$a$jscomp$315_section$jscomp$9_tokens$jscomp$3$$){var $remainder$jscomp$4_vec__43626_vec__43629$$=$cljs$pprint$split_at_newline$$($a$jscomp$315_section$jscomp$9_tokens$jscomp$3$$);$a$jscomp$315_section$jscomp$9_tokens$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($remainder$jscomp$4_vec__43626_vec__43629$$,0,null);var $JSCompiler_temp$jscomp$608_b$jscomp$243_rem2$jscomp$inline_11666_result$jscomp$135$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($remainder$jscomp$4_vec__43626_vec__43629$$,1,null);$APP.$cljs$core$truth_$$($a$jscomp$315_section$jscomp$9_tokens$jscomp$3$$)&&$cljs$pprint$write_tokens$$($JSCompiler_temp$jscomp$10727_this$$jscomp$537$$,$a$jscomp$315_section$jscomp$9_tokens$jscomp$3$$,!1);if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$608_b$jscomp$243_rem2$jscomp$inline_11666_result$jscomp$135$$)){$remainder$jscomp$4_vec__43626_vec__43629$$=$cljs$pprint$get_section$$($JSCompiler_temp$jscomp$608_b$jscomp$243_rem2$jscomp$inline_11666_result$jscomp$135$$);
$a$jscomp$315_section$jscomp$9_tokens$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($remainder$jscomp$4_vec__43626_vec__43629$$,0,null);$remainder$jscomp$4_vec__43626_vec__43629$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($remainder$jscomp$4_vec__43626_vec__43629$$,1,null);var $newl$jscomp$3$$=$APP.$cljs$core$first$$($JSCompiler_temp$jscomp$608_b$jscomp$243_rem2$jscomp$inline_11666_result$jscomp$135$$),$do_nl$$=$cljs$pprint$emit_nl_QMARK_$$.$cljs$core$IFn$_invoke$arity$4$($newl$jscomp$3$$,
$JSCompiler_temp$jscomp$10727_this$$jscomp$537$$,$a$jscomp$315_section$jscomp$9_tokens$jscomp$3$$,$cljs$pprint$get_sub_section$$($JSCompiler_temp$jscomp$608_b$jscomp$243_rem2$jscomp$inline_11666_result$jscomp$135$$));$APP.$cljs$core$truth_$$($do_nl$$)&&($cljs$pprint$emit_nl$$($JSCompiler_temp$jscomp$10727_this$$jscomp$537$$,$newl$jscomp$3$$),$JSCompiler_temp$jscomp$608_b$jscomp$243_rem2$jscomp$inline_11666_result$jscomp$135$$=$APP.$cljs$core$next$$($JSCompiler_temp$jscomp$608_b$jscomp$243_rem2$jscomp$inline_11666_result$jscomp$135$$));
$cljs$pprint$tokens_fit_QMARK_$$($JSCompiler_temp$jscomp$10727_this$$jscomp$537$$,$JSCompiler_temp$jscomp$608_b$jscomp$243_rem2$jscomp$inline_11666_result$jscomp$135$$)?$JSCompiler_temp$jscomp$10727_this$$jscomp$537$$=$JSCompiler_temp$jscomp$608_b$jscomp$243_rem2$jscomp$inline_11666_result$jscomp$135$$:($JSCompiler_temp$jscomp$608_b$jscomp$243_rem2$jscomp$inline_11666_result$jscomp$135$$=$cljs$pprint$write_token_string$$.$cljs$core$IFn$_invoke$arity$2$?$cljs$pprint$write_token_string$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10727_this$$jscomp$537$$,
$a$jscomp$315_section$jscomp$9_tokens$jscomp$3$$):$cljs$pprint$write_token_string$$($JSCompiler_temp$jscomp$10727_this$$jscomp$537$$,$a$jscomp$315_section$jscomp$9_tokens$jscomp$3$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$608_b$jscomp$243_rem2$jscomp$inline_11666_result$jscomp$135$$,$a$jscomp$315_section$jscomp$9_tokens$jscomp$3$$)?($cljs$pprint$write_tokens$$($JSCompiler_temp$jscomp$10727_this$$jscomp$537$$,$a$jscomp$315_section$jscomp$9_tokens$jscomp$3$$,
!1),$JSCompiler_temp$jscomp$10727_this$$jscomp$537$$=$remainder$jscomp$4_vec__43626_vec__43629$$):$JSCompiler_temp$jscomp$10727_this$$jscomp$537$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$608_b$jscomp$243_rem2$jscomp$inline_11666_result$jscomp$135$$,$remainder$jscomp$4_vec__43626_vec__43629$$)));return $JSCompiler_temp$jscomp$10727_this$$jscomp$537$$}return null};
$APP.$JSCompiler_prototypeAlias$$=$cljs$pprint$t_cljs$0pprint43666$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_43668$$,$meta43667__$1$$){return new $cljs$pprint$t_cljs$0pprint43666$$(this.$writer$,this.$max_columns$,this.$miser_width$,this.lb,this.$fields$,$meta43667__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta43667$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDeref$_deref$arity$1$=function(){return this.$fields$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWriter$_write$arity$2$=function($expr__43674_oldpos$jscomp$inline_4354_this$$jscomp$544_white_space$$,$JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$){$expr__43674_oldpos$jscomp$inline_4354_this$$jscomp$544_white_space$$=$APP.$cljs$core$type$$($JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(String,$expr__43674_oldpos$jscomp$inline_4354_this$$jscomp$544_white_space$$):$APP.$cljs$core$_EQ_$$(String,$expr__43674_oldpos$jscomp$inline_4354_this$$jscomp$544_white_space$$))){var $newpos$jscomp$1_newpos$jscomp$inline_4355_s0$$=$cljs$pprint$write_initial_lines$$(this,$JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$);$JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$=
$newpos$jscomp$1_newpos$jscomp$inline_4355_s0$$.replace(/\s+$/,"");$expr__43674_oldpos$jscomp$inline_4354_this$$jscomp$544_white_space$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($newpos$jscomp$1_newpos$jscomp$inline_4355_s0$$,$JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$.length);var $mode$jscomp$20_oldpos$jscomp$1$$=$APP.$cljs$cst$320$mode$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$(this)));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$20_oldpos$jscomp$1$$,
$cljs$cst$1407$writing$$))return $cljs$pprint$write_white_space$$(this),$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$(this))),$JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$(this),$APP.$cljs$core$assoc$$,$cljs$cst$1384$trailing_white_space$$,$expr__43674_oldpos$jscomp$inline_4354_this$$jscomp$544_white_space$$);
$mode$jscomp$20_oldpos$jscomp$1$$=$APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$(this)));$newpos$jscomp$1_newpos$jscomp$inline_4355_s0$$=$mode$jscomp$20_oldpos$jscomp$1$$+$APP.$cljs$core$count$$($newpos$jscomp$1_newpos$jscomp$inline_4355_s0$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$(this),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1406$pos$$,$newpos$jscomp$1_newpos$jscomp$inline_4355_s0$$);return $cljs$pprint$add_to_buffer$$(this,
new $cljs$pprint$buffer_blob$$($cljs$cst$1390$buffer_blob$$,$JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$,$expr__43674_oldpos$jscomp$inline_4354_this$$jscomp$544_white_space$$,$mode$jscomp$20_oldpos$jscomp$1$$,$newpos$jscomp$1_newpos$jscomp$inline_4355_s0$$,null,null,null))}if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(Number,$expr__43674_oldpos$jscomp$inline_4354_this$$jscomp$544_white_space$$):
$APP.$cljs$core$_EQ_$$(Number,$expr__43674_oldpos$jscomp$inline_4354_this$$jscomp$544_white_space$$)))return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$320$mode$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$(this))),$cljs$cst$1407$writing$$)?($cljs$pprint$write_white_space$$(this),$JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$=$APP.$cljs$core$_write$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$(this))),
$JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$,"\n")?$JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$=$cljs$pprint$write_initial_lines$$(this,"\n"):($expr__43674_oldpos$jscomp$inline_4354_this$$jscomp$544_white_space$$=$APP.$cljs$cst$1406$pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$(this))),
$newpos$jscomp$1_newpos$jscomp$inline_4355_s0$$=$expr__43674_oldpos$jscomp$inline_4354_this$$jscomp$544_white_space$$+1,$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$(this),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1406$pos$$,$newpos$jscomp$1_newpos$jscomp$inline_4355_s0$$),$JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$=$APP.$cljs$core$char$0$$($JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$),
$JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$=$cljs$pprint$add_to_buffer$$(this,new $cljs$pprint$buffer_blob$$($cljs$cst$1390$buffer_blob$$,$JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$,null,$expr__43674_oldpos$jscomp$inline_4354_this$$jscomp$544_white_space$$,$newpos$jscomp$1_newpos$jscomp$inline_4355_s0$$,null,null,null))),$JSCompiler_inline_result$jscomp$609_data$jscomp$inline_11668_s$jscomp$488_x$jscomp$1026$$;
throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expr__43674_oldpos$jscomp$inline_4354_this$$jscomp$544_white_space$$)].join(""));};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWriter$_flush$arity$1$=function(){this.$cljs$pprint$IPrettyFlush$_ppflush$arity$1$(null);return $cljs$core$_flush$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$(this))))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$pprint$IPrettyFlush$_ppflush$arity$1$=function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$320$mode$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$(this))),$cljs$cst$1405$buffering$$)?($cljs$pprint$write_tokens$$(this,$APP.$cljs$cst$194$buffer$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$(this))),!0),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_deref$$(this),
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$194$buffer$$,$APP.$cljs$core$PersistentVector$EMPTY$$)):$cljs$pprint$write_white_space$$(this)};
var $cljs$pprint$_STAR_print_pretty_STAR_$$=!0,$cljs$pprint$_STAR_print_pprint_dispatch_STAR_$$=null,$cljs$pprint$_STAR_print_right_margin_STAR_$$=72,$cljs$pprint$_STAR_print_miser_width_STAR_$$=40,$cljs$pprint$_STAR_print_lines_STAR_$$=null,$cljs$pprint$_STAR_print_circle_STAR_$$=null,$cljs$pprint$_STAR_print_suppress_namespaces_STAR_$$=null,$cljs$pprint$_STAR_print_radix_STAR_$$=null,$cljs$pprint$_STAR_print_base_STAR_$$=10,$cljs$pprint$_STAR_current_level_STAR_$$=0,$cljs$pprint$_STAR_current_length_STAR_$$=
null,$cljs$pprint$write$$=function $cljs$pprint$write$$($var_args$jscomp$745$$){for(var $args__5755__auto__$jscomp$139$$=[],$len__5749__auto___45795$$=arguments.length,$i__5750__auto___45796$$=0;;)if($i__5750__auto___45796$$<$len__5749__auto___45795$$)$args__5755__auto__$jscomp$139$$.push(arguments[$i__5750__auto___45796$$]),$i__5750__auto___45796$$+=1;else break;return $cljs$pprint$write$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args__5755__auto__$jscomp$139$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$139$$.slice(1),
0,null):null)};
$cljs$pprint$write$$.$cljs$core$IFn$_invoke$arity$variadic$=function($object$jscomp$12$$,$_STAR_print_base_STAR__orig_val__43745_kw_args$$){var $_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1416$stream$$,!0],null),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$hash_map$$,$_STAR_print_base_STAR__orig_val__43745_kw_args$$)]));
$_STAR_print_base_STAR__orig_val__43745_kw_args$$=$cljs$pprint$_STAR_print_base_STAR_$$;var $_STAR_print_circle_STAR__orig_val__43746$$=$cljs$pprint$_STAR_print_circle_STAR_$$,$_STAR_print_length_STAR__orig_val__43747$$=$cljs$core$_STAR_print_length_STAR_$$,$_STAR_print_level_STAR__orig_val__43748$$=$cljs$core$_STAR_print_level_STAR_$$,$_STAR_print_lines_STAR__orig_val__43749$$=$cljs$pprint$_STAR_print_lines_STAR_$$,$_STAR_print_miser_width_STAR__orig_val__43750$$=$cljs$pprint$_STAR_print_miser_width_STAR_$$,
$_STAR_print_pprint_dispatch_STAR__orig_val__43751$$=$cljs$pprint$_STAR_print_pprint_dispatch_STAR_$$,$_STAR_print_pretty_STAR__orig_val__43752$$=$cljs$pprint$_STAR_print_pretty_STAR_$$,$_STAR_print_radix_STAR__orig_val__43753$$=$cljs$pprint$_STAR_print_radix_STAR_$$,$_STAR_print_readably_STAR__orig_val__43754$$=$cljs$core$_STAR_print_readably_STAR_$$,$_STAR_print_right_margin_STAR__orig_val__43755$$=$cljs$pprint$_STAR_print_right_margin_STAR_$$,$_STAR_print_suppress_namespaces_STAR__orig_val__43756$$=
$cljs$pprint$_STAR_print_suppress_namespaces_STAR_$$,$_STAR_print_base_STAR__temp_val__43757$$=$APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$2$($_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$,$cljs$pprint$_STAR_print_base_STAR_$$),$_STAR_print_circle_STAR__temp_val__43758$$=$APP.$cljs$cst$1417$circle$$.$cljs$core$IFn$_invoke$arity$2$($_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$,$cljs$pprint$_STAR_print_circle_STAR_$$),$_STAR_print_length_STAR__temp_val__43759$$=
$APP.$cljs$cst$255$length$$.$cljs$core$IFn$_invoke$arity$2$($_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$,$cljs$core$_STAR_print_length_STAR_$$),$_STAR_print_level_STAR__temp_val__43760$$=$APP.$cljs$cst$284$level$$.$cljs$core$IFn$_invoke$arity$2$($_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$,$cljs$core$_STAR_print_level_STAR_$$),$_STAR_print_lines_STAR__temp_val__43761$$=$cljs$cst$1418$lines$$.$cljs$core$IFn$_invoke$arity$2$($_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$,
$cljs$pprint$_STAR_print_lines_STAR_$$),$_STAR_print_miser_width_STAR__temp_val__43762$$=$cljs$cst$1411$miser_width$$.$cljs$core$IFn$_invoke$arity$2$($_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$,$cljs$pprint$_STAR_print_miser_width_STAR_$$),$_STAR_print_pprint_dispatch_STAR__temp_val__43763$$=$cljs$cst$532$dispatch$$.$cljs$core$IFn$_invoke$arity$2$($_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$,$cljs$pprint$_STAR_print_pprint_dispatch_STAR_$$),$_STAR_print_pretty_STAR__temp_val__43764$$=
$cljs$cst$1419$pretty$$.$cljs$core$IFn$_invoke$arity$2$($_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$,$cljs$pprint$_STAR_print_pretty_STAR_$$),$_STAR_print_radix_STAR__temp_val__43765$$=$cljs$cst$1420$radix$$.$cljs$core$IFn$_invoke$arity$2$($_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$,$cljs$pprint$_STAR_print_radix_STAR_$$),$_STAR_print_readably_STAR__temp_val__43766$$=$cljs$cst$1$readably$$.$cljs$core$IFn$_invoke$arity$2$($_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$,
$cljs$core$_STAR_print_readably_STAR_$$),$_STAR_print_right_margin_STAR__temp_val__43767$$=$cljs$cst$1421$right_margin$$.$cljs$core$IFn$_invoke$arity$2$($_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$,$cljs$pprint$_STAR_print_right_margin_STAR_$$),$_STAR_print_suppress_namespaces_STAR__temp_val__43768$$=$cljs$cst$1422$suppress_namespaces$$.$cljs$core$IFn$_invoke$arity$2$($_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$,$cljs$pprint$_STAR_print_suppress_namespaces_STAR_$$);$cljs$pprint$_STAR_print_base_STAR_$$=
$_STAR_print_base_STAR__temp_val__43757$$;$cljs$pprint$_STAR_print_circle_STAR_$$=$_STAR_print_circle_STAR__temp_val__43758$$;$cljs$core$_STAR_print_length_STAR_$$=$_STAR_print_length_STAR__temp_val__43759$$;$cljs$core$_STAR_print_level_STAR_$$=$_STAR_print_level_STAR__temp_val__43760$$;$cljs$pprint$_STAR_print_lines_STAR_$$=$_STAR_print_lines_STAR__temp_val__43761$$;$cljs$pprint$_STAR_print_miser_width_STAR_$$=$_STAR_print_miser_width_STAR__temp_val__43762$$;$cljs$pprint$_STAR_print_pprint_dispatch_STAR_$$=
$_STAR_print_pprint_dispatch_STAR__temp_val__43763$$;$cljs$pprint$_STAR_print_pretty_STAR_$$=$_STAR_print_pretty_STAR__temp_val__43764$$;$cljs$pprint$_STAR_print_radix_STAR_$$=$_STAR_print_radix_STAR__temp_val__43765$$;$cljs$core$_STAR_print_readably_STAR_$$=$_STAR_print_readably_STAR__temp_val__43766$$;$cljs$pprint$_STAR_print_right_margin_STAR_$$=$_STAR_print_right_margin_STAR__temp_val__43767$$;$cljs$pprint$_STAR_print_suppress_namespaces_STAR_$$=$_STAR_print_suppress_namespaces_STAR__temp_val__43768$$;
try{var $sb$jscomp$22$$=new $APP.$goog$string$StringBuffer$$,$optval$$=$APP.$cljs$core$contains_QMARK_$$($_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$,$APP.$cljs$cst$1416$stream$$)?$APP.$cljs$cst$1416$stream$$.$cljs$core$IFn$_invoke$arity$1$($_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$):!0,$base_writer$jscomp$1$$=$optval$$===!0||$optval$$==null?new $cljs$core$StringBufferWriter$$($sb$jscomp$22$$):$optval$$;if($APP.$cljs$core$truth_$$($cljs$pprint$_STAR_print_pretty_STAR_$$)){var $_STAR_out_STAR__orig_val__43780_45804_new_writer__42837__auto___45801$$=
$APP.$cljs$core$not$$($cljs$pprint$pretty_writer_QMARK_$$($base_writer$jscomp$1$$));$_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$=$cljs$core$_STAR_out_STAR_$$;$cljs$core$_STAR_out_STAR_$$=$_STAR_out_STAR__orig_val__43780_45804_new_writer__42837__auto___45801$$?$cljs$pprint$pretty_writer$$($base_writer$jscomp$1$$):$base_writer$jscomp$1$$;try{$cljs$pprint$write_out$$($object$jscomp$12$$),$cljs$pprint$_ppflush$$()}finally{$cljs$core$_STAR_out_STAR_$$=$_STAR_out_STAR__orig_val__43778_45802_options$jscomp$413$$}}else{$_STAR_out_STAR__orig_val__43780_45804_new_writer__42837__auto___45801$$=
$cljs$core$_STAR_out_STAR_$$;$cljs$core$_STAR_out_STAR_$$=$base_writer$jscomp$1$$;try{$cljs$pprint$pr$$.call(null,$object$jscomp$12$$)}finally{$cljs$core$_STAR_out_STAR_$$=$_STAR_out_STAR__orig_val__43780_45804_new_writer__42837__auto___45801$$}}$optval$$===!0&&$cljs$core$string_print$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$22$$));return $optval$$==null?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$22$$):null}finally{$cljs$pprint$_STAR_print_suppress_namespaces_STAR_$$=
$_STAR_print_suppress_namespaces_STAR__orig_val__43756$$,$cljs$pprint$_STAR_print_right_margin_STAR_$$=$_STAR_print_right_margin_STAR__orig_val__43755$$,$cljs$core$_STAR_print_readably_STAR_$$=$_STAR_print_readably_STAR__orig_val__43754$$,$cljs$pprint$_STAR_print_radix_STAR_$$=$_STAR_print_radix_STAR__orig_val__43753$$,$cljs$pprint$_STAR_print_pretty_STAR_$$=$_STAR_print_pretty_STAR__orig_val__43752$$,$cljs$pprint$_STAR_print_pprint_dispatch_STAR_$$=$_STAR_print_pprint_dispatch_STAR__orig_val__43751$$,
$cljs$pprint$_STAR_print_miser_width_STAR_$$=$_STAR_print_miser_width_STAR__orig_val__43750$$,$cljs$pprint$_STAR_print_lines_STAR_$$=$_STAR_print_lines_STAR__orig_val__43749$$,$cljs$core$_STAR_print_level_STAR_$$=$_STAR_print_level_STAR__orig_val__43748$$,$cljs$core$_STAR_print_length_STAR_$$=$_STAR_print_length_STAR__orig_val__43747$$,$cljs$pprint$_STAR_print_circle_STAR_$$=$_STAR_print_circle_STAR__orig_val__43746$$,$cljs$pprint$_STAR_print_base_STAR_$$=$_STAR_print_base_STAR__orig_val__43745_kw_args$$}};
$cljs$pprint$write$$.$cljs$lang$maxFixedArity$=1;$cljs$pprint$write$$.$cljs$lang$applyTo$=function($seq43738_seq43738__$1$$){var $G__43739$$=$APP.$cljs$core$first$$($seq43738_seq43738__$1$$);$seq43738_seq43738__$1$$=$APP.$cljs$core$next$$($seq43738_seq43738__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__43739$$,$seq43738_seq43738__$1$$)};
var $cljs$pprint$pprint$$=function $cljs$pprint$pprint$$($var_args$jscomp$746$$){switch(arguments.length){case 1:return $cljs$pprint$pprint$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $cljs$pprint$pprint$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$cljs$pprint$pprint$$.$cljs$core$IFn$_invoke$arity$1$=function($object$jscomp$13$$){var $sb$jscomp$23$$=new $APP.$goog$string$StringBuffer$$,$_STAR_out_STAR__orig_val__43811$$=$cljs$core$_STAR_out_STAR_$$;$cljs$core$_STAR_out_STAR_$$=new $cljs$core$StringBufferWriter$$($sb$jscomp$23$$);try{return $cljs$pprint$pprint$$.$cljs$core$IFn$_invoke$arity$2$($object$jscomp$13$$,$cljs$core$_STAR_out_STAR_$$),$cljs$core$string_print$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$23$$))}finally{$cljs$core$_STAR_out_STAR_$$=
$_STAR_out_STAR__orig_val__43811$$}};
$cljs$pprint$pprint$$.$cljs$core$IFn$_invoke$arity$2$=function($object$jscomp$14$$,$_STAR_print_pretty_STAR__orig_val__43818_45807_writer$jscomp$148$$){var $new_writer__42837__auto__$$=$APP.$cljs$core$not$$($cljs$pprint$pretty_writer_QMARK_$$($_STAR_print_pretty_STAR__orig_val__43818_45807_writer$jscomp$148$$)),$_STAR_out_STAR__orig_val__43815$$=$cljs$core$_STAR_out_STAR_$$;$cljs$core$_STAR_out_STAR_$$=$new_writer__42837__auto__$$?$cljs$pprint$pretty_writer$$($_STAR_print_pretty_STAR__orig_val__43818_45807_writer$jscomp$148$$):$_STAR_print_pretty_STAR__orig_val__43818_45807_writer$jscomp$148$$;
try{$_STAR_print_pretty_STAR__orig_val__43818_45807_writer$jscomp$148$$=$cljs$pprint$_STAR_print_pretty_STAR_$$;$cljs$pprint$_STAR_print_pretty_STAR_$$=!0;try{$cljs$pprint$write_out$$($object$jscomp$14$$)}finally{$cljs$pprint$_STAR_print_pretty_STAR_$$=$_STAR_print_pretty_STAR__orig_val__43818_45807_writer$jscomp$148$$}$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$cljs$pprint$get_column$$($cljs$core$_STAR_out_STAR_$$))||$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"\n");return $cljs$pprint$_ppflush$$()}finally{$cljs$core$_STAR_out_STAR_$$=
$_STAR_out_STAR__orig_val__43815$$}};$cljs$pprint$pprint$$.$cljs$lang$maxFixedArity$=2;var $cljs$pprint$_STAR_format_str_STAR_$$=null;$APP.$JSCompiler_prototypeAlias$$=$cljs$pprint$arg_navigator$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$13$$,$k__5324__auto__$jscomp$13$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$13$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$13$$,$k43857$$,$else__5326__auto__$jscomp$13$$){switch($k43857$$ instanceof $APP.$cljs$core$Keyword$$?$k43857$$.$fqn$:null){case "seq":return this.$seq$;case "rest":return this.$rest$;case "pos":return this.pos;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k43857$$,$else__5326__auto__$jscomp$13$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$13$$,$f__5344__auto__$jscomp$13$$,$init__5345__auto__$jscomp$13$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$13$$,$p__43876_v__5348__auto__$jscomp$13$$){var $k__5347__auto__$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__43876_v__5348__auto__$jscomp$13$$,0,null);$p__43876_v__5348__auto__$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__43876_v__5348__auto__$jscomp$13$$,
1,null);return $f__5344__auto__$jscomp$13$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$13$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$13$$,$k__5347__auto__$jscomp$13$$,$p__43876_v__5348__auto__$jscomp$13$$):$f__5344__auto__$jscomp$13$$($ret__5346__auto__$jscomp$13$$,$k__5347__auto__$jscomp$13$$,$p__43876_v__5348__auto__$jscomp$13$$)},$init__5345__auto__$jscomp$13$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$13$$,$writer__5339__auto__$jscomp$13$$,$opts__5340__auto__$jscomp$13$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$13$$,function($keyval__5342__auto__$jscomp$13$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$13$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$13$$,$keyval__5342__auto__$jscomp$13$$)},"#cljs.pprint.arg-navigator{",
", ","}",$opts__5340__auto__$jscomp$13$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1425$seq$$,this.$seq$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1426$rest$$,this.$rest$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1406$pos$$,this.pos],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,3,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1425$seq$$,$cljs$cst$1426$rest$$,$APP.$cljs$cst$1406$pos$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$pprint$arg_navigator$$(this.$seq$,this.$rest$,this.pos,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 3+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$41_h__5134__auto____$1$jscomp$41$$=this.$__hash$;return $h__5134__auto__$jscomp$41_h__5134__auto____$1$jscomp$41$$!=null?$h__5134__auto__$jscomp$41_h__5134__auto____$1$jscomp$41$$:this.$__hash$=$h__5134__auto__$jscomp$41_h__5134__auto____$1$jscomp$41$$=-402038447^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this43858$$,$other43859$$){return $other43859$$!=null&&this.constructor===$other43859$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$seq$,$other43859$$.$seq$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$rest$,$other43859$$.$rest$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.pos,$other43859$$.pos)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,
$other43859$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$13$$,$k__5334__auto__$jscomp$13$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1406$pos$$,null,$cljs$cst$1425$seq$$,null,$cljs$cst$1426$rest$$,null],null),null),$k__5334__auto__$jscomp$13$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),
this.$__meta$),$k__5334__auto__$jscomp$13$$):new $cljs$pprint$arg_navigator$$(this.$seq$,this.$rest$,this.pos,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$13$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$13$$,$k43857$jscomp$1$$){switch($k43857$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k43857$jscomp$1$$.$fqn$:null){case "seq":case "rest":case "pos":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k43857$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$13$$,$k__5332__auto__$jscomp$13$$,$G__43856$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1425$seq$$,$k__5332__auto__$jscomp$13$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1425$seq$$,$k__5332__auto__$jscomp$13$$))?new $cljs$pprint$arg_navigator$$($G__43856$jscomp$1$$,
this.$rest$,this.pos,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1426$rest$$,$k__5332__auto__$jscomp$13$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1426$rest$$,$k__5332__auto__$jscomp$13$$))?new $cljs$pprint$arg_navigator$$(this.$seq$,$G__43856$jscomp$1$$,this.pos,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1406$pos$$,$k__5332__auto__$jscomp$13$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1406$pos$$,$k__5332__auto__$jscomp$13$$))?new $cljs$pprint$arg_navigator$$(this.$seq$,this.$rest$,$G__43856$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $cljs$pprint$arg_navigator$$(this.$seq$,this.$rest$,this.pos,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$13$$,
$G__43856$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$1425$seq$$,this.$seq$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1426$rest$$,this.$rest$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1406$pos$$,this.pos,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$13$$,$G__43856$jscomp$2$$){return new $cljs$pprint$arg_navigator$$(this.$seq$,this.$rest$,this.pos,$G__43856$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$13$$,$entry__5329__auto__$jscomp$13$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$13$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$13$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$13$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$13$$)};
$APP.$JSCompiler_prototypeAlias$$=$cljs$pprint$compiled_directive$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$14$$,$k__5324__auto__$jscomp$14$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$14$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$14$$,$k44038$$,$else__5326__auto__$jscomp$14$$){switch($k44038$$ instanceof $APP.$cljs$core$Keyword$$?$k44038$$.$fqn$:null){case "func":return this.$func$;case "def":return this.$def$;case "params":return this.params;case "offset":return this.offset;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k44038$$,$else__5326__auto__$jscomp$14$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$14$$,$f__5344__auto__$jscomp$14$$,$init__5345__auto__$jscomp$14$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$14$$,$p__44059_v__5348__auto__$jscomp$14$$){var $k__5347__auto__$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__44059_v__5348__auto__$jscomp$14$$,0,null);$p__44059_v__5348__auto__$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__44059_v__5348__auto__$jscomp$14$$,
1,null);return $f__5344__auto__$jscomp$14$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$14$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$14$$,$k__5347__auto__$jscomp$14$$,$p__44059_v__5348__auto__$jscomp$14$$):$f__5344__auto__$jscomp$14$$($ret__5346__auto__$jscomp$14$$,$k__5347__auto__$jscomp$14$$,$p__44059_v__5348__auto__$jscomp$14$$)},$init__5345__auto__$jscomp$14$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$14$$,$writer__5339__auto__$jscomp$14$$,$opts__5340__auto__$jscomp$14$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$14$$,function($keyval__5342__auto__$jscomp$14$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$14$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$14$$,$keyval__5342__auto__$jscomp$14$$)},"#cljs.pprint.compiled-directive{",
", ","}",$opts__5340__auto__$jscomp$14$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1428$func$$,this.$func$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1429$def$$,this.$def$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,this.params],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$195$offset$$,this.offset],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,4,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1428$func$$,$cljs$cst$1429$def$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$cst$195$offset$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$pprint$compiled_directive$$(this.$func$,this.$def$,this.params,this.offset,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 4+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$42_h__5134__auto____$1$jscomp$42$$=this.$__hash$;return $h__5134__auto__$jscomp$42_h__5134__auto____$1$jscomp$42$$!=null?$h__5134__auto__$jscomp$42_h__5134__auto____$1$jscomp$42$$:this.$__hash$=$h__5134__auto__$jscomp$42_h__5134__auto____$1$jscomp$42$$=-829256337^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this44039$$,$other44040$$){return $other44040$$!=null&&this.constructor===$other44040$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$func$,$other44040$$.$func$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$def$,$other44040$$.$def$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.params,$other44040$$.params)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.offset,
$other44040$$.offset)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other44040$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$14$$,$k__5334__auto__$jscomp$14$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$195$offset$$,null,$cljs$cst$1428$func$$,null,$APP.$cljs$cst$1430$params$$,null,$cljs$cst$1429$def$$,null],null),null),$k__5334__auto__$jscomp$14$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$14$$):new $cljs$pprint$compiled_directive$$(this.$func$,this.$def$,this.params,this.offset,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$14$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$14$$,$k44038$jscomp$1$$){switch($k44038$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k44038$jscomp$1$$.$fqn$:null){case "func":case "def":case "params":case "offset":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k44038$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$14$$,$k__5332__auto__$jscomp$14$$,$G__44037$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1428$func$$,$k__5332__auto__$jscomp$14$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1428$func$$,$k__5332__auto__$jscomp$14$$))?new $cljs$pprint$compiled_directive$$($G__44037$jscomp$1$$,
this.$def$,this.params,this.offset,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1429$def$$,$k__5332__auto__$jscomp$14$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1429$def$$,$k__5332__auto__$jscomp$14$$))?new $cljs$pprint$compiled_directive$$(this.$func$,$G__44037$jscomp$1$$,this.params,this.offset,this.$__meta$,
this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1430$params$$,$k__5332__auto__$jscomp$14$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1430$params$$,$k__5332__auto__$jscomp$14$$))?new $cljs$pprint$compiled_directive$$(this.$func$,this.$def$,$G__44037$jscomp$1$$,this.offset,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$k__5332__auto__$jscomp$14$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$195$offset$$,$k__5332__auto__$jscomp$14$$))?new $cljs$pprint$compiled_directive$$(this.$func$,this.$def$,this.params,$G__44037$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $cljs$pprint$compiled_directive$$(this.$func$,this.$def$,this.params,this.offset,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,
$k__5332__auto__$jscomp$14$$,$G__44037$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$1428$func$$,this.$func$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1429$def$$,this.$def$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1430$params$$,this.params,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$195$offset$$,
this.offset,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$14$$,$G__44037$jscomp$2$$){return new $cljs$pprint$compiled_directive$$(this.$func$,this.$def$,this.params,this.offset,$G__44037$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$14$$,$entry__5329__auto__$jscomp$14$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$14$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$14$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$14$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$14$$)};
var $cljs$pprint$special_radix_markers$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[2,"#b",8,"#o",16,"#x"],null),$cljs$pprint$english_cardinal_units$$=new $APP.$cljs$core$PersistentVector$$(null,20,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"zero one two three four five six seven eight nine ten eleven twelve thirteen fourteen fifteen sixteen seventeen eighteen nineteen".split(" "),null),$cljs$pprint$english_ordinal_units$$=new $APP.$cljs$core$PersistentVector$$(null,20,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
"zeroth first second third fourth fifth sixth seventh eighth ninth tenth eleventh twelfth thirteenth fourteenth fifteenth sixteenth seventeenth eighteenth nineteenth".split(" "),null),$cljs$pprint$english_cardinal_tens$$=new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"  twenty thirty forty fifty sixty seventy eighty ninety".split(" "),null),$cljs$pprint$english_ordinal_tens$$=new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
"  twentieth thirtieth fortieth fiftieth sixtieth seventieth eightieth ninetieth".split(" "),null),$cljs$pprint$english_scale_numbers$$=new $APP.$cljs$core$PersistentVector$$(null,22,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$," thousand million billion trillion quadrillion quintillion sextillion septillion octillion nonillion decillion undecillion duodecillion tredecillion quattuordecillion quindecillion sexdecillion septendecillion octodecillion novemdecillion vigintillion".split(" "),null),
$cljs$pprint$old_roman_table$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"I II III IIII V VI VII VIII VIIII".split(" "),null),new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"X XX XXX XXXX L LX LXX LXXX LXXXX".split(" "),null),new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
"C CC CCC CCCC D DC DCC DCCC DCCCC".split(" "),null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["M","MM","MMM"],null)],null),$cljs$pprint$new_roman_table$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"I II III IV V VI VII VIII IX".split(" "),null),new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
"X XX XXX XL L LX LXX LXXX XC".split(" "),null),new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"C CC CCC CD D DC DCC DCCC CM".split(" "),null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["M","MM","MMM"],null)],null),$cljs$pprint$special_chars$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[8,"Backspace",9,"Tab",10,"Newline",13,"Return",32,"Space"],null);
$cljs$pprint$t_cljs$0pprint44851$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_44853$$,$meta44852__$1$$){return new $cljs$pprint$t_cljs$0pprint44851$$(this.$writer$,$meta44852__$1$$)};$cljs$pprint$t_cljs$0pprint44851$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta44852$};$cljs$pprint$t_cljs$0pprint44851$$.prototype.$cljs$core$IWriter$_flush$arity$1$=function(){return $cljs$core$_flush$$(this.$writer$)};
$cljs$pprint$t_cljs$0pprint44851$$.prototype.$cljs$core$IWriter$_write$arity$2$=function($expr__44858_this$$jscomp$553$$,$x$jscomp$1031$$){$expr__44858_this$$jscomp$553$$=$APP.$cljs$core$type$$($x$jscomp$1031$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(String,$expr__44858_this$$jscomp$553$$):$APP.$cljs$core$_EQ_$$(String,$expr__44858_this$$jscomp$553$$)))return $APP.$cljs$core$_write$$(this.$writer$,$clojure$string$lower_case$$($x$jscomp$1031$$));
if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(Number,$expr__44858_this$$jscomp$553$$):$APP.$cljs$core$_EQ_$$(Number,$expr__44858_this$$jscomp$553$$)))return $APP.$cljs$core$_write$$(this.$writer$,$clojure$string$lower_case$$($APP.$cljs$core$char$0$$($x$jscomp$1031$$)));throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expr__44858_this$$jscomp$553$$)].join(""));};
$cljs$pprint$t_cljs$0pprint44871$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_44873$$,$meta44872__$1$$){return new $cljs$pprint$t_cljs$0pprint44871$$(this.$writer$,$meta44872__$1$$)};$cljs$pprint$t_cljs$0pprint44871$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta44872$};$cljs$pprint$t_cljs$0pprint44871$$.prototype.$cljs$core$IWriter$_flush$arity$1$=function(){return $cljs$core$_flush$$(this.$writer$)};
$cljs$pprint$t_cljs$0pprint44871$$.prototype.$cljs$core$IWriter$_write$arity$2$=function($expr__44877_this$$jscomp$554$$,$x$jscomp$1032$$){$expr__44877_this$$jscomp$554$$=$APP.$cljs$core$type$$($x$jscomp$1032$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(String,$expr__44877_this$$jscomp$554$$):$APP.$cljs$core$_EQ_$$(String,$expr__44877_this$$jscomp$554$$)))return $APP.$cljs$core$_write$$(this.$writer$,$APP.$clojure$string$upper_case$$($x$jscomp$1032$$));
if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(Number,$expr__44877_this$$jscomp$554$$):$APP.$cljs$core$_EQ_$$(Number,$expr__44877_this$$jscomp$554$$)))return $APP.$cljs$core$_write$$(this.$writer$,$APP.$clojure$string$upper_case$$($APP.$cljs$core$char$0$$($x$jscomp$1032$$)));throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expr__44877_this$$jscomp$554$$)].join(""));
};$cljs$pprint$t_cljs$0pprint44886$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_44888$$,$meta44887__$1$$){return new $cljs$pprint$t_cljs$0pprint44886$$(this.$writer$,this.$last_was_whitespace_QMARK_$,$meta44887__$1$$)};$cljs$pprint$t_cljs$0pprint44886$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta44887$};$cljs$pprint$t_cljs$0pprint44886$$.prototype.$cljs$core$IWriter$_flush$arity$1$=function(){return $cljs$core$_flush$$(this.$writer$)};
$cljs$pprint$t_cljs$0pprint44886$$.prototype.$cljs$core$IWriter$_write$arity$2$=function($expr__44893_mod_c_this$$jscomp$555$$,$c$jscomp$242_x$jscomp$1033$$){$expr__44893_mod_c_this$$jscomp$555$$=$APP.$cljs$core$type$$($c$jscomp$242_x$jscomp$1033$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(String,$expr__44893_mod_c_this$$jscomp$555$$):$APP.$cljs$core$_EQ_$$(String,$expr__44893_mod_c_this$$jscomp$555$$)))return $APP.$cljs$core$_write$$(this.$writer$,
$cljs$pprint$capitalize_string$$($c$jscomp$242_x$jscomp$1033$$.toLowerCase(),$APP.$cljs$core$_deref$$(this.$last_was_whitespace_QMARK_$))),$c$jscomp$242_x$jscomp$1033$$.length>0?$APP.$cljs$core$reset_BANG_$$(this.$last_was_whitespace_QMARK_$,$goog$string$internal$isEmptyOrWhitespace$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($c$jscomp$242_x$jscomp$1033$$,$APP.$cljs$core$count$$($c$jscomp$242_x$jscomp$1033$$)-1))):null;if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(Number,$expr__44893_mod_c_this$$jscomp$555$$):$APP.$cljs$core$_EQ_$$(Number,$expr__44893_mod_c_this$$jscomp$555$$)))return $c$jscomp$242_x$jscomp$1033$$=$APP.$cljs$core$char$0$$($c$jscomp$242_x$jscomp$1033$$),$expr__44893_mod_c_this$$jscomp$555$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$(this.$last_was_whitespace_QMARK_$))?$APP.$clojure$string$upper_case$$($c$jscomp$242_x$jscomp$1033$$):$c$jscomp$242_x$jscomp$1033$$,$APP.$cljs$core$_write$$(this.$writer$,
$expr__44893_mod_c_this$$jscomp$555$$),$APP.$cljs$core$reset_BANG_$$(this.$last_was_whitespace_QMARK_$,$goog$string$internal$isEmptyOrWhitespace$$($c$jscomp$242_x$jscomp$1033$$));throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expr__44893_mod_c_this$$jscomp$555$$)].join(""));};
$cljs$pprint$t_cljs$0pprint44899$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_44901$$,$meta44900__$1$$){return new $cljs$pprint$t_cljs$0pprint44899$$(this.$writer$,this.$capped$,$meta44900__$1$$)};$cljs$pprint$t_cljs$0pprint44899$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta44900$};$cljs$pprint$t_cljs$0pprint44899$$.prototype.$cljs$core$IWriter$_flush$arity$1$=function(){return $cljs$core$_flush$$(this.$writer$)};
$cljs$pprint$t_cljs$0pprint44899$$.prototype.$cljs$core$IWriter$_write$arity$2$=function($and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$,$c$jscomp$243_s$jscomp$496_x$jscomp$1034$$){$and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$=$APP.$cljs$core$type$$($c$jscomp$243_s$jscomp$496_x$jscomp$1034$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(String,
$and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$):$APP.$cljs$core$_EQ_$$(String,$and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$)))return $c$jscomp$243_s$jscomp$496_x$jscomp$1034$$=$clojure$string$lower_case$$($c$jscomp$243_s$jscomp$496_x$jscomp$1034$$),$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$(this.$capped$))?($and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$=
RegExp("\\S","g").exec($c$jscomp$243_s$jscomp$496_x$jscomp$1034$$),$and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$)?$and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$.index:$and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$,$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$)?
($APP.$cljs$core$_write$$(this.$writer$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($c$jscomp$243_s$jscomp$496_x$jscomp$1034$$,0,$and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$),$APP.$clojure$string$upper_case$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($c$jscomp$243_s$jscomp$496_x$jscomp$1034$$,$and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$)),$clojure$string$lower_case$$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$243_s$jscomp$496_x$jscomp$1034$$,
$and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$+1))].join("")),$APP.$cljs$core$reset_BANG_$$(this.$capped$,!0)):$APP.$cljs$core$_write$$(this.$writer$,$c$jscomp$243_s$jscomp$496_x$jscomp$1034$$)):$APP.$cljs$core$_write$$(this.$writer$,$clojure$string$lower_case$$($c$jscomp$243_s$jscomp$496_x$jscomp$1034$$));if($APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(Number,
$and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$):$APP.$cljs$core$_EQ_$$(Number,$and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$)))return $c$jscomp$243_s$jscomp$496_x$jscomp$1034$$=$APP.$cljs$core$char$0$$($c$jscomp$243_s$jscomp$496_x$jscomp$1034$$),$and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$=$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$(this.$capped$)),
$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$?$goog$string$isUnicodeChar$$($c$jscomp$243_s$jscomp$496_x$jscomp$1034$$):$and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$)?($APP.$cljs$core$reset_BANG_$$(this.$capped$,!0),$APP.$cljs$core$_write$$(this.$writer$,$APP.$clojure$string$upper_case$$($c$jscomp$243_s$jscomp$496_x$jscomp$1034$$))):$APP.$cljs$core$_write$$(this.$writer$,
$clojure$string$lower_case$$($c$jscomp$243_s$jscomp$496_x$jscomp$1034$$));throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$inline_11706_expr__44907_m$jscomp$179_offset$jscomp$48_this$$jscomp$556$$)].join(""));};
var $cljs$pprint$directive_table$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$("ASDBOXRPCFEG$%\x26|~\nT*?()[;]{}\x3c\x3e^W_I".split(""),[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"A",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1437$mincol$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,Number],null),$cljs$cst$1438$colinc$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,Number],null),$cljs$cst$1436$minpad$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,Number],null),$cljs$cst$1439$padchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[" ",String],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1432$colon$$,null,
$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return function($p1__44947_SHARP_$$,$p2__44948_SHARP_$$){return $cljs$pprint$format_ascii$$($cljs$core$print_str$$,$p1__44947_SHARP_$$,$p2__44948_SHARP_$$)}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"S",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1437$mincol$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,Number],null),$cljs$cst$1438$colinc$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,Number],null),$cljs$cst$1436$minpad$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,Number],null),$cljs$cst$1439$padchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[" ",
String],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return function($p1__44950_SHARP_$$,$p2__44951_SHARP_$$){return $cljs$pprint$format_ascii$$($APP.$cljs$core$pr_str$$,$p1__44950_SHARP_$$,$p2__44951_SHARP_$$)}}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"D",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1437$mincol$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,Number],null),$cljs$cst$1439$padchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[" ",String],null),$cljs$cst$1441$commachar$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[",",String],null),$cljs$cst$1440$commainterval$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[3,Number],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$cljs$cst$1469$generator_fn$$,function(){return function($p1__44954_SHARP_$$,$p2__44955_SHARP_$$){return $cljs$pprint$format_integer$$(10,$p1__44954_SHARP_$$,$p2__44955_SHARP_$$)}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"B",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1437$mincol$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,Number],null),$cljs$cst$1439$padchar$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[" ",String],null),$cljs$cst$1441$commachar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[",",String],null),$cljs$cst$1440$commainterval$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[3,Number],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return function($p1__44957_SHARP_$$,$p2__44958_SHARP_$$){return $cljs$pprint$format_integer$$(2,$p1__44957_SHARP_$$,$p2__44958_SHARP_$$)}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"O",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$cljs$cst$1437$mincol$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,Number],null),$cljs$cst$1439$padchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[" ",String],null),$cljs$cst$1441$commachar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[",",String],null),$cljs$cst$1440$commainterval$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[3,Number],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return function($p1__44962_SHARP_$$,$p2__44963_SHARP_$$){return $cljs$pprint$format_integer$$(8,$p1__44962_SHARP_$$,$p2__44963_SHARP_$$)}}],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"X",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1437$mincol$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,Number],null),$cljs$cst$1439$padchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[" ",String],null),$cljs$cst$1441$commachar$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[",",String],null),$cljs$cst$1440$commainterval$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[3,Number],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$cljs$cst$1469$generator_fn$$,function(){return function($p1__44965_SHARP_$$,$p2__44966_SHARP_$$){return $cljs$pprint$format_integer$$(16,$p1__44965_SHARP_$$,$p2__44966_SHARP_$$)}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"R",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1278$base$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null),$cljs$cst$1437$mincol$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,Number],null),$cljs$cst$1439$padchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[" ",String],null),$cljs$cst$1441$commachar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[",",String],null),$cljs$cst$1440$commainterval$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[3,Number],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function($params$jscomp$54$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$first$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$54$$)))?
function($p1__44968_SHARP_$$,$p2__44969_SHARP_$$){return $cljs$pprint$format_integer$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($p1__44968_SHARP_$$),$p1__44968_SHARP_$$,$p2__44969_SHARP_$$)}:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$191$$=$cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$54$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$191$$)?$APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$54$$):$and__5023__auto__$jscomp$191$$}())?
function($p1__44971_SHARP_$$,$p2__44972_SHARP_$$){return $cljs$pprint$format_roman$$($cljs$pprint$old_roman_table$$,$p2__44972_SHARP_$$)}:$APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$54$$))?function($p1__44974_SHARP_$$,$p2__44975_SHARP_$$){return $cljs$pprint$format_roman$$($cljs$pprint$new_roman_table$$,$p2__44975_SHARP_$$)}:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$54$$))?function($navigator__$1$jscomp$inline_4441_p1__44977_SHARP__vec__44472$jscomp$inline_4439$$,
$arg$jscomp$inline_4440_not_teens_45871$jscomp$inline_4447_p2__44978_SHARP_$$){$navigator__$1$jscomp$inline_4441_p1__44977_SHARP__vec__44472$jscomp$inline_4439$$=$cljs$pprint$next_arg$$($arg$jscomp$inline_4440_not_teens_45871$jscomp$inline_4447_p2__44978_SHARP_$$);$arg$jscomp$inline_4440_not_teens_45871$jscomp$inline_4447_p2__44978_SHARP_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$inline_4441_p1__44977_SHARP__vec__44472$jscomp$inline_4439$$,0,null);$navigator__$1$jscomp$inline_4441_p1__44977_SHARP__vec__44472$jscomp$inline_4439$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$inline_4441_p1__44977_SHARP__vec__44472$jscomp$inline_4439$$,1,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$arg$jscomp$inline_4440_not_teens_45871$jscomp$inline_4447_p2__44978_SHARP_$$))$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["zeroth"]));else{var $hundreds$jscomp$inline_11709_parts_45866$jscomp$inline_4442_tail_str_45869$jscomp$inline_4445$$=
$cljs$pprint$remainders$$(1E3,$arg$jscomp$inline_4440_not_teens_45871$jscomp$inline_4447_p2__44978_SHARP_$$<0?-$arg$jscomp$inline_4440_not_teens_45871$jscomp$inline_4447_p2__44978_SHARP_$$:$arg$jscomp$inline_4440_not_teens_45871$jscomp$inline_4447_p2__44978_SHARP_$$);if($APP.$cljs$core$count$$($hundreds$jscomp$inline_11709_parts_45866$jscomp$inline_4442_tail_str_45869$jscomp$inline_4445$$)<=$APP.$cljs$core$count$$($cljs$pprint$english_scale_numbers$$)){var $head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$=
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$pprint$format_simple_cardinal$$,$APP.$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$01$$($hundreds$jscomp$inline_11709_parts_45866$jscomp$inline_4442_tail_str_45869$jscomp$inline_4445$$));$head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$=$cljs$pprint$add_english_scales$$($head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$,
1);var $num$jscomp$inline_11708_tens$jscomp$inline_11710$$=$APP.$cljs$core$last$$($hundreds$jscomp$inline_11709_parts_45866$jscomp$inline_4442_tail_str_45869$jscomp$inline_4445$$);$hundreds$jscomp$inline_11709_parts_45866$jscomp$inline_4442_tail_str_45869$jscomp$inline_4445$$=$APP.$cljs$core$quot$$($num$jscomp$inline_11708_tens$jscomp$inline_11710$$,100);$num$jscomp$inline_11708_tens$jscomp$inline_11710$$=$APP.$cljs$core$rem$$($num$jscomp$inline_11708_tens$jscomp$inline_11710$$,100);var $JSCompiler_temp_const$jscomp$inline_11711$$=
$hundreds$jscomp$inline_11709_parts_45866$jscomp$inline_4442_tail_str_45869$jscomp$inline_4445$$>0?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$pprint$english_cardinal_units$$,$hundreds$jscomp$inline_11709_parts_45866$jscomp$inline_4442_tail_str_45869$jscomp$inline_4445$$))," hundred"].join(""):null,$JSCompiler_temp_const$jscomp$inline_11712$$=$APP.$cljs$core$str$$,$JSCompiler_temp_const$jscomp$inline_11713$$=$JSCompiler_temp_const$jscomp$inline_11712$$.$cljs$core$IFn$_invoke$arity$1$;
if($num$jscomp$inline_11708_tens$jscomp$inline_11710$$>0)if($num$jscomp$inline_11708_tens$jscomp$inline_11710$$<20)var $JSCompiler_temp$jscomp$inline_11714_JSCompiler_temp$jscomp$inline_11715_ten_digit$jscomp$inline_11716$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$pprint$english_ordinal_units$$,$num$jscomp$inline_11708_tens$jscomp$inline_11710$$);else{$JSCompiler_temp$jscomp$inline_11714_JSCompiler_temp$jscomp$inline_11715_ten_digit$jscomp$inline_11716$$=$APP.$cljs$core$quot$$($num$jscomp$inline_11708_tens$jscomp$inline_11710$$,
10);var $unit_digit$jscomp$inline_11717$$=$APP.$cljs$core$rem$$($num$jscomp$inline_11708_tens$jscomp$inline_11710$$,10);$JSCompiler_temp$jscomp$inline_11714_JSCompiler_temp$jscomp$inline_11715_ten_digit$jscomp$inline_11716$$=$JSCompiler_temp$jscomp$inline_11714_JSCompiler_temp$jscomp$inline_11715_ten_digit$jscomp$inline_11716$$>0&&!($unit_digit$jscomp$inline_11717$$>0)?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$pprint$english_ordinal_tens$$,$JSCompiler_temp$jscomp$inline_11714_JSCompiler_temp$jscomp$inline_11715_ten_digit$jscomp$inline_11716$$):
[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$inline_11714_JSCompiler_temp$jscomp$inline_11715_ten_digit$jscomp$inline_11716$$>0?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$pprint$english_cardinal_tens$$,$JSCompiler_temp$jscomp$inline_11714_JSCompiler_temp$jscomp$inline_11715_ten_digit$jscomp$inline_11716$$):null),$JSCompiler_temp$jscomp$inline_11714_JSCompiler_temp$jscomp$inline_11715_ten_digit$jscomp$inline_11716$$>0&&$unit_digit$jscomp$inline_11717$$>
0?"-":null,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($unit_digit$jscomp$inline_11717$$>0?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$pprint$english_ordinal_units$$,$unit_digit$jscomp$inline_11717$$):null)].join("")}else $JSCompiler_temp$jscomp$inline_11714_JSCompiler_temp$jscomp$inline_11715_ten_digit$jscomp$inline_11716$$=$hundreds$jscomp$inline_11709_parts_45866$jscomp$inline_4442_tail_str_45869$jscomp$inline_4445$$>0?"th":null;$hundreds$jscomp$inline_11709_parts_45866$jscomp$inline_4442_tail_str_45869$jscomp$inline_4445$$=
[$JSCompiler_temp_const$jscomp$inline_11711$$,$hundreds$jscomp$inline_11709_parts_45866$jscomp$inline_4442_tail_str_45869$jscomp$inline_4445$$>0&&$num$jscomp$inline_11708_tens$jscomp$inline_11710$$>0?" ":null,$JSCompiler_temp_const$jscomp$inline_11713$$.call($JSCompiler_temp_const$jscomp$inline_11712$$,$JSCompiler_temp$jscomp$inline_11714_JSCompiler_temp$jscomp$inline_11715_ten_digit$jscomp$inline_11716$$)].join("");$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[$arg$jscomp$inline_4440_not_teens_45871$jscomp$inline_4447_p2__44978_SHARP_$$<
0?"minus ":null,$APP.$cljs$core$empty_QMARK_$$($head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$)||$APP.$cljs$core$empty_QMARK_$$($hundreds$jscomp$inline_11709_parts_45866$jscomp$inline_4442_tail_str_45869$jscomp$inline_4445$$)?$APP.$cljs$core$empty_QMARK_$$($head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$)?
$hundreds$jscomp$inline_11709_parts_45866$jscomp$inline_4442_tail_str_45869$jscomp$inline_4445$$:[$head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$,"th"].join(""):[$head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$,", ",$hundreds$jscomp$inline_11709_parts_45866$jscomp$inline_4442_tail_str_45869$jscomp$inline_4445$$].join("")].join("")]))}else $cljs$pprint$format_integer$$(10,
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1437$mincol$$,0,$cljs$cst$1439$padchar$$," ",$cljs$cst$1441$commachar$$,",",$cljs$cst$1440$commainterval$$,3,$APP.$cljs$cst$1432$colon$$,!0],null),$cljs$pprint$init_navigator$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$arg$jscomp$inline_4440_not_teens_45871$jscomp$inline_4447_p2__44978_SHARP_$$],null))),$head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$=
$APP.$cljs$core$rem$$($arg$jscomp$inline_4440_not_teens_45871$jscomp$inline_4447_p2__44978_SHARP_$$,100),$arg$jscomp$inline_4440_not_teens_45871$jscomp$inline_4447_p2__44978_SHARP_$$=11<$head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$||19>$head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$,$head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$=
$APP.$cljs$core$rem$$($head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$,10),$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$===1&&$arg$jscomp$inline_4440_not_teens_45871$jscomp$inline_4447_p2__44978_SHARP_$$?
"st":$head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$===2&&$arg$jscomp$inline_4440_not_teens_45871$jscomp$inline_4447_p2__44978_SHARP_$$?"nd":$head_str_45868$jscomp$inline_4444_low_digit_45872$jscomp$inline_4448_low_two_digits_45870$jscomp$inline_4446_parts_strs_45867$jscomp$inline_4443$$===3&&$arg$jscomp$inline_4440_not_teens_45871$jscomp$inline_4447_p2__44978_SHARP_$$?"rd":"th"]))}return $navigator__$1$jscomp$inline_4441_p1__44977_SHARP__vec__44472$jscomp$inline_4439$$}:
function($arg$jscomp$inline_4452_p1__44980_SHARP_$$,$navigator__$1$jscomp$inline_4453_p2__44981_SHARP__vec__44433$jscomp$inline_4451$$){$navigator__$1$jscomp$inline_4453_p2__44981_SHARP__vec__44433$jscomp$inline_4451$$=$cljs$pprint$next_arg$$($navigator__$1$jscomp$inline_4453_p2__44981_SHARP__vec__44433$jscomp$inline_4451$$);$arg$jscomp$inline_4452_p1__44980_SHARP_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$inline_4453_p2__44981_SHARP__vec__44433$jscomp$inline_4451$$,
0,null);$navigator__$1$jscomp$inline_4453_p2__44981_SHARP__vec__44433$jscomp$inline_4451$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$inline_4453_p2__44981_SHARP__vec__44433$jscomp$inline_4451$$,1,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$arg$jscomp$inline_4452_p1__44980_SHARP_$$))$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["zero"]));else{var $full_str_45857$jscomp$inline_4456_parts_45855$jscomp$inline_4454_parts_strs_45856$jscomp$inline_4455$$=
$cljs$pprint$remainders$$(1E3,$arg$jscomp$inline_4452_p1__44980_SHARP_$$<0?-$arg$jscomp$inline_4452_p1__44980_SHARP_$$:$arg$jscomp$inline_4452_p1__44980_SHARP_$$);$APP.$cljs$core$count$$($full_str_45857$jscomp$inline_4456_parts_45855$jscomp$inline_4454_parts_strs_45856$jscomp$inline_4455$$)<=$APP.$cljs$core$count$$($cljs$pprint$english_scale_numbers$$)?($full_str_45857$jscomp$inline_4456_parts_45855$jscomp$inline_4454_parts_strs_45856$jscomp$inline_4455$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$pprint$format_simple_cardinal$$,
$full_str_45857$jscomp$inline_4456_parts_45855$jscomp$inline_4454_parts_strs_45856$jscomp$inline_4455$$),$full_str_45857$jscomp$inline_4456_parts_45855$jscomp$inline_4454_parts_strs_45856$jscomp$inline_4455$$=$cljs$pprint$add_english_scales$$($full_str_45857$jscomp$inline_4456_parts_45855$jscomp$inline_4454_parts_strs_45856$jscomp$inline_4455$$,0),$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[$arg$jscomp$inline_4452_p1__44980_SHARP_$$<
0?"minus ":null,$full_str_45857$jscomp$inline_4456_parts_45855$jscomp$inline_4454_parts_strs_45856$jscomp$inline_4455$$].join("")]))):$cljs$pprint$format_integer$$(10,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1437$mincol$$,0,$cljs$cst$1439$padchar$$," ",$cljs$cst$1441$commachar$$,",",$cljs$cst$1440$commainterval$$,3,$APP.$cljs$cst$1432$colon$$,!0],null),$cljs$pprint$init_navigator$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$arg$jscomp$inline_4452_p1__44980_SHARP_$$],
null)))}return $navigator__$1$jscomp$inline_4453_p2__44981_SHARP__vec__44433$jscomp$inline_4451$$}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"P",$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,null],null),null),$cljs$cst$1468$bracket_info$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return function($params__$1$jscomp$5_strs$jscomp$1$$,$arg$jscomp$27_navigator$jscomp$36_navigator__$1$jscomp$22$$){$arg$jscomp$27_navigator$jscomp$36_navigator__$1$jscomp$22$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$5_strs$jscomp$1$$))?$cljs$pprint$relative_reposition$$($arg$jscomp$27_navigator$jscomp$36_navigator__$1$jscomp$22$$,-1):$arg$jscomp$27_navigator$jscomp$36_navigator__$1$jscomp$22$$;
$params__$1$jscomp$5_strs$jscomp$1$$=$APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$5_strs$jscomp$1$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["y","ies"],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["","s"],null);var $navigator__$2$jscomp$5_vec__45012$$=$cljs$pprint$next_arg$$($arg$jscomp$27_navigator$jscomp$36_navigator__$1$jscomp$22$$);
$arg$jscomp$27_navigator$jscomp$36_navigator__$1$jscomp$22$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$2$jscomp$5_vec__45012$$,0,null);$navigator__$2$jscomp$5_vec__45012$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$2$jscomp$5_vec__45012$$,1,null);$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($arg$jscomp$27_navigator$jscomp$36_navigator__$1$jscomp$22$$,
1)?$APP.$cljs$core$first$$($params__$1$jscomp$5_strs$jscomp$1$$):$APP.$cljs$core$second$$($params__$1$jscomp$5_strs$jscomp$1$$)]));return $navigator__$2$jscomp$5_vec__45012$$}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"C",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1442$char_format$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,String],null)],null),$APP.$cljs$cst$1467$flags$$,
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function($params$jscomp$56$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$56$$))?$cljs$pprint$pretty_character$$:$APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$56$$))?
$cljs$pprint$readable_character$$:$cljs$pprint$plain_character$$}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"F",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1446$w$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null),$cljs$cst$1447$d$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null),$cljs$cst$733$k$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,Number],null),$cljs$cst$1448$overflowchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,String],null),$cljs$cst$1439$padchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[" ",String],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$1433$at$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return $cljs$pprint$fixed_float$$}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"E",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$cljs$cst$1446$w$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null),$cljs$cst$1447$d$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null),$cljs$cst$1449$e$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null),$cljs$cst$733$k$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,Number],null),$cljs$cst$1448$overflowchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,
String],null),$cljs$cst$1439$padchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[" ",String],null),$cljs$cst$1450$exponentchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,String],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1433$at$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$cljs$cst$1469$generator_fn$$,function(){return $cljs$pprint$exponential_float$$}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"G",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$cljs$cst$1446$w$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null),$cljs$cst$1447$d$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],
null),$cljs$cst$1449$e$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null),$cljs$cst$733$k$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,Number],null),$cljs$cst$1448$overflowchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,String],null),$cljs$cst$1439$padchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[" ",String],null),$cljs$cst$1450$exponentchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,String],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1433$at$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return $cljs$pprint$general_float$$}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$cljs$cst$1466$directive$$,"$",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1447$d$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[2,Number],null),$cljs$cst$1451$n$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,Number],null),$cljs$cst$1446$w$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,Number],null),
$cljs$cst$1439$padchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[" ",String],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return $cljs$pprint$dollar_float$$}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"%",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1080$count$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,Number],null)],null),$APP.$cljs$cst$1467$flags$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return function($n__5616__auto___46041_params__$1$jscomp$6$$,
$arg_navigator$jscomp$5$$){$n__5616__auto___46041_params__$1$jscomp$6$$=$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($n__5616__auto___46041_params__$1$jscomp$6$$);for(var $i_46042$$=0;;)if($i_46042$$<$n__5616__auto___46041_params__$1$jscomp$6$$)$cljs$pprint$prn$$(),$i_46042$$+=1;else break;return $arg_navigator$jscomp$5$$}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"\x26",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1080$count$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,Number],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1419$pretty$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return function($cnt_46044_n__5616__auto___46045_params__$1$jscomp$7$$,$arg_navigator$jscomp$6$$){$cnt_46044_n__5616__auto___46045_params__$1$jscomp$7$$=
$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($cnt_46044_n__5616__auto___46045_params__$1$jscomp$7$$);$cnt_46044_n__5616__auto___46045_params__$1$jscomp$7$$>0&&(($cljs$core$_STAR_out_STAR_$$!=null?$cljs$core$_STAR_out_STAR_$$.$cljs$lang$protocol_mask$partition0$$&32768||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$cljs$core$_STAR_out_STAR_$$.$cljs$core$IDeref$$||($cljs$core$_STAR_out_STAR_$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IDeref$$,
$cljs$core$_STAR_out_STAR_$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IDeref$$,$cljs$core$_STAR_out_STAR_$$))?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$cljs$pprint$get_column$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($cljs$core$_STAR_out_STAR_$$)))))||$cljs$pprint$prn$$():$cljs$pprint$prn$$());--$cnt_46044_n__5616__auto___46045_params__$1$jscomp$7$$;for(var $i_46046$$=0;;)if($i_46046$$<$cnt_46044_n__5616__auto___46045_params__$1$jscomp$7$$)$cljs$pprint$prn$$(),
$i_46046$$+=1;else break;return $arg_navigator$jscomp$6$$}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"|",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1080$count$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,Number],null)],null),$APP.$cljs$cst$1467$flags$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$cljs$cst$1469$generator_fn$$,function(){return function($n__5616__auto___46048_params__$1$jscomp$8$$,$arg_navigator$jscomp$7$$){$n__5616__auto___46048_params__$1$jscomp$8$$=$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($n__5616__auto___46048_params__$1$jscomp$8$$);for(var $i_46049$$=0;;)if($i_46049$$<$n__5616__auto___46048_params__$1$jscomp$8$$)$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["\f"])),$i_46049$$+=
1;else break;return $arg_navigator$jscomp$7$$}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"~",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1451$n$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,Number],null)],null),$APP.$cljs$cst$1467$flags$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,
function(){return function($n$jscomp$269_params__$1$jscomp$9$$,$arg_navigator$jscomp$8$$){$n$jscomp$269_params__$1$jscomp$9$$=$cljs$cst$1451$n$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$269_params__$1$jscomp$9$$);$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($n$jscomp$269_params__$1$jscomp$9$$,
"~"))]));return $arg_navigator$jscomp$8$$}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"\n",$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return function($params__$1$jscomp$10$$,
$arg_navigator$jscomp$9$$){$APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$10$$))&&$cljs$pprint$prn$$();return $arg_navigator$jscomp$9$$}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"T",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$1465$colnum$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,Number],null),$cljs$cst$1438$colinc$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,Number],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$1433$at$$,null,$cljs$cst$1419$pretty$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function($params$jscomp$66$$){return $APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$66$$))?
function($colinc_46010$jscomp$inline_4462_p1__44986_SHARP_$$,$p2__44987_SHARP_$$){var $colrel_46009$jscomp$inline_4461_space_count_46013$jscomp$inline_4465$$=$cljs$cst$1465$colnum$$.$cljs$core$IFn$_invoke$arity$1$($colinc_46010$jscomp$inline_4462_p1__44986_SHARP_$$);$colinc_46010$jscomp$inline_4462_p1__44986_SHARP_$$=$cljs$cst$1438$colinc$$.$cljs$core$IFn$_invoke$arity$1$($colinc_46010$jscomp$inline_4462_p1__44986_SHARP_$$);var $offset_46012$jscomp$inline_4464_start_col_46011$jscomp$inline_4463$$=
$colrel_46009$jscomp$inline_4461_space_count_46013$jscomp$inline_4465$$+$cljs$pprint$get_column$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($cljs$core$_STAR_out_STAR_$$))));$offset_46012$jscomp$inline_4464_start_col_46011$jscomp$inline_4463$$=$colinc_46010$jscomp$inline_4462_p1__44986_SHARP_$$>0?$APP.$cljs$core$rem$$($offset_46012$jscomp$inline_4464_start_col_46011$jscomp$inline_4463$$,$colinc_46010$jscomp$inline_4462_p1__44986_SHARP_$$):
0;$colrel_46009$jscomp$inline_4461_space_count_46013$jscomp$inline_4465$$+=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$offset_46012$jscomp$inline_4464_start_col_46011$jscomp$inline_4463$$)?0:$colinc_46010$jscomp$inline_4462_p1__44986_SHARP_$$-$offset_46012$jscomp$inline_4464_start_col_46011$jscomp$inline_4463$$;$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($colrel_46009$jscomp$inline_4461_space_count_46013$jscomp$inline_4465$$," "))]));return $p2__44987_SHARP_$$}:function($colinc_46002$jscomp$inline_4470_p1__44989_SHARP_$$,$p2__44991_SHARP_$$){var $colnum_46001$jscomp$inline_4469_space_count_46004$jscomp$inline_4472$$=$cljs$cst$1465$colnum$$.$cljs$core$IFn$_invoke$arity$1$($colinc_46002$jscomp$inline_4470_p1__44989_SHARP_$$);$colinc_46002$jscomp$inline_4470_p1__44989_SHARP_$$=$cljs$cst$1438$colinc$$.$cljs$core$IFn$_invoke$arity$1$($colinc_46002$jscomp$inline_4470_p1__44989_SHARP_$$);
var $current_46003$jscomp$inline_4471$$=$cljs$pprint$get_column$$($APP.$cljs$cst$1278$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($cljs$core$_STAR_out_STAR_$$))));$colnum_46001$jscomp$inline_4469_space_count_46004$jscomp$inline_4472$$=$current_46003$jscomp$inline_4471$$<$colnum_46001$jscomp$inline_4469_space_count_46004$jscomp$inline_4472$$?$colnum_46001$jscomp$inline_4469_space_count_46004$jscomp$inline_4472$$-$current_46003$jscomp$inline_4471$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($colinc_46002$jscomp$inline_4470_p1__44989_SHARP_$$,
0)?0:$colinc_46002$jscomp$inline_4470_p1__44989_SHARP_$$-$APP.$cljs$core$rem$$($current_46003$jscomp$inline_4471$$-$colnum_46001$jscomp$inline_4469_space_count_46004$jscomp$inline_4472$$,$colinc_46002$jscomp$inline_4470_p1__44989_SHARP_$$);$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($colnum_46001$jscomp$inline_4469_space_count_46004$jscomp$inline_4472$$,
" "))]));return $p2__44991_SHARP_$$}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"*",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1451$n$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,Number],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,
null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return function($params__$1$jscomp$11$$,$navigator$jscomp$37$$){var $n$jscomp$270$$=$cljs$cst$1451$n$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$11$$);return $APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$11$$))?$cljs$pprint$absolute_reposition$$($navigator$jscomp$37$$,$n$jscomp$270$$):$cljs$pprint$relative_reposition$$($navigator$jscomp$37$$,
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$11$$))?-$n$jscomp$270$$:$n$jscomp$270$$)}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"?",$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1433$at$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$cljs$cst$1469$generator_fn$$,function($params$jscomp$68$$){return $APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$68$$))?function($params__$1$jscomp$12$$,$navigator$jscomp$38_subformat$$){var $navigator__$1$jscomp$23_vec__45027$$=$cljs$pprint$get_format_arg$$($navigator$jscomp$38_subformat$$);$navigator$jscomp$38_subformat$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$23_vec__45027$$,0,null);$navigator__$1$jscomp$23_vec__45027$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$23_vec__45027$$,1,null);return $cljs$pprint$execute_sub_format$$($navigator$jscomp$38_subformat$$,$navigator__$1$jscomp$23_vec__45027$$,$cljs$cst$1445$base_args$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$12$$))}:function($params__$1$jscomp$13$$,$navigator$jscomp$39_subformat$jscomp$1$$){var $navigator__$1$jscomp$24_sub_navigator_subargs_vec__45034$$=$cljs$pprint$get_format_arg$$($navigator$jscomp$39_subformat$jscomp$1$$);
$navigator$jscomp$39_subformat$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$24_sub_navigator_subargs_vec__45034$$,0,null);$navigator__$1$jscomp$24_sub_navigator_subargs_vec__45034$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$1$jscomp$24_sub_navigator_subargs_vec__45034$$,1,null);var $navigator__$2$jscomp$6_vec__45037$$=$cljs$pprint$next_arg$$($navigator__$1$jscomp$24_sub_navigator_subargs_vec__45034$$);$navigator__$1$jscomp$24_sub_navigator_subargs_vec__45034$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$2$jscomp$6_vec__45037$$,0,null);$navigator__$2$jscomp$6_vec__45037$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator__$2$jscomp$6_vec__45037$$,1,null);$navigator__$1$jscomp$24_sub_navigator_subargs_vec__45034$$=$cljs$pprint$init_navigator$$($navigator__$1$jscomp$24_sub_navigator_subargs_vec__45034$$);$cljs$pprint$execute_sub_format$$($navigator$jscomp$39_subformat$jscomp$1$$,$navigator__$1$jscomp$24_sub_navigator_subargs_vec__45034$$,
$cljs$cst$1445$base_args$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$13$$));return $navigator__$2$jscomp$6_vec__45037$$}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"(",$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,null],null),
null),$cljs$cst$1468$bracket_info$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$258$right$$,")",$cljs$cst$1470$allows_separator$$,null,$cljs$cst$225$else$$,null],null),$cljs$cst$1469$generator_fn$$,function($params$jscomp$69$$){var $mod_case_writer$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$192$$=$cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$69$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$192$$)?$APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$69$$):
$and__5023__auto__$jscomp$192$$}())?$cljs$pprint$upcase_writer$$:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$69$$))?$cljs$pprint$capitalize_word_writer$$:$APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$69$$))?$cljs$pprint$init_cap_writer$$:$cljs$pprint$downcase_writer$$;return function($p1__44993_SHARP_$$,$p2__44994_SHARP_$$){var $clause$jscomp$inline_4477$$=$APP.$cljs$core$first$$($cljs$cst$1453$clauses$$.$cljs$core$IFn$_invoke$arity$1$($p1__44993_SHARP_$$)),
$_STAR_out_STAR__orig_val__44914$jscomp$inline_4478$$=$cljs$core$_STAR_out_STAR_$$;$cljs$core$_STAR_out_STAR_$$=$mod_case_writer$$.$cljs$core$IFn$_invoke$arity$1$?$mod_case_writer$$.$cljs$core$IFn$_invoke$arity$1$($cljs$core$_STAR_out_STAR_$$):$mod_case_writer$$($cljs$core$_STAR_out_STAR_$$);try{var $JSCompiler_inline_result$jscomp$635$$=$cljs$pprint$execute_sub_format$$($clause$jscomp$inline_4477$$,$p2__44994_SHARP_$$,$cljs$cst$1445$base_args$$.$cljs$core$IFn$_invoke$arity$1$($p1__44993_SHARP_$$))}finally{$cljs$core$_STAR_out_STAR_$$=
$_STAR_out_STAR__orig_val__44914$jscomp$inline_4478$$}return $JSCompiler_inline_result$jscomp$635$$}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,")",$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1467$flags$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return null}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$cljs$cst$1466$directive$$,"[",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1452$selector$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null],null),null),$cljs$cst$1468$bracket_info$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$258$right$$,"]",$cljs$cst$1470$allows_separator$$,!0,$cljs$cst$225$else$$,$cljs$cst$1471$last$$],null),$cljs$cst$1469$generator_fn$$,function($params$jscomp$71$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$71$$))?$cljs$pprint$boolean_conditional$$:$APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$71$$))?$cljs$pprint$check_arg_conditional$$:$cljs$pprint$choice_conditional$$}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,";",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$1457$min_remaining$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null),$cljs$cst$1458$max_columns$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1432$colon$$,null],null),null),$cljs$cst$1468$bracket_info$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1472$separator$$,!0],null),$cljs$cst$1469$generator_fn$$,function(){return null}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"]",$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1467$flags$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,$cljs$cst$1468$bracket_info$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return null}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"{",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1454$max_iterations$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,null],null),null),$cljs$cst$1468$bracket_info$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$258$right$$,"}",$cljs$cst$1470$allows_separator$$,!1],null),$cljs$cst$1469$generator_fn$$,function($params$jscomp$74$$){var $JSCompiler_inline_result$jscomp$640_and__5023__auto__$jscomp$inline_4480$$=$cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$74$$);$JSCompiler_inline_result$jscomp$640_and__5023__auto__$jscomp$inline_4480$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$640_and__5023__auto__$jscomp$inline_4480$$)?$APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$74$$):$JSCompiler_inline_result$jscomp$640_and__5023__auto__$jscomp$inline_4480$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$640_and__5023__auto__$jscomp$inline_4480$$)?$cljs$pprint$iterate_main_sublists$$:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$74$$))?
$cljs$pprint$iterate_list_of_sublists$$:$APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$74$$))?$cljs$pprint$iterate_main_list$$:$cljs$pprint$iterate_sublist$$}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"}",$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1432$colon$$,
null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return null}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"\x3c",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1437$mincol$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,Number],null),$cljs$cst$1438$colinc$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1,Number],null),$cljs$cst$1436$minpad$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,Number],null),$cljs$cst$1439$padchar$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[" ",String],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1432$colon$$,null,
$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,null,$cljs$cst$1419$pretty$$,null],null),null),$cljs$cst$1468$bracket_info$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$258$right$$,"\x3e",$cljs$cst$1470$allows_separator$$,!0,$cljs$cst$225$else$$,$cljs$cst$1320$first$$],null),$cljs$cst$1469$generator_fn$$,function(){return $cljs$pprint$logical_block_or_justify$$}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"\x3e",$APP.$cljs$cst$1430$params$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1432$colon$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return null}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"^",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,
[$cljs$cst$1473$arg1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null),$cljs$cst$1474$arg2$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null),$cljs$cst$1475$arg3$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,Number],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1432$colon$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return function($params__$1$jscomp$14$$,$navigator$jscomp$40$$){var $arg1$jscomp$5$$=$cljs$cst$1473$arg1$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$14$$),$arg2$jscomp$4$$=$cljs$cst$1474$arg2$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$14$$),$arg3$jscomp$2$$=$cljs$cst$1475$arg3$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$14$$),
$exit$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$14$$))?$cljs$cst$1444$colon_up_arrow$$:$cljs$cst$1443$up_arrow$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($arg1$jscomp$5$$)?$APP.$cljs$core$truth_$$($arg2$jscomp$4$$)?$arg3$jscomp$2$$:$arg2$jscomp$4$$:$arg1$jscomp$5$$)?$arg1$jscomp$5$$<=$arg2$jscomp$4$$&&$arg2$jscomp$4$$<=$arg3$jscomp$2$$?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$exit$$,$navigator$jscomp$40$$],null):$navigator$jscomp$40$$:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($arg1$jscomp$5$$)?$arg2$jscomp$4$$:$arg1$jscomp$5$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($arg1$jscomp$5$$,$arg2$jscomp$4$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$exit$$,$navigator$jscomp$40$$],null):$navigator$jscomp$40$$:$APP.$cljs$core$truth_$$($arg1$jscomp$5$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($arg1$jscomp$5$$,
0)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$exit$$,$navigator$jscomp$40$$],null):$navigator$jscomp$40$$:($APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$14$$))?$APP.$cljs$core$empty_QMARK_$$($cljs$cst$1426$rest$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1445$base_args$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$14$$))):$APP.$cljs$core$empty_QMARK_$$($cljs$cst$1426$rest$$.$cljs$core$IFn$_invoke$arity$1$($navigator$jscomp$40$$)))?
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$exit$$,$navigator$jscomp$40$$],null):$navigator$jscomp$40$$}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1466$directive$$,"W",$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,
null,$cljs$cst$1419$pretty$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function($params$jscomp$79$$){if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$286$$=$cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$79$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$286$$)?$or__5025__auto__$jscomp$286$$:$APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$79$$)}())){var $bindings$jscomp$2$$=
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($cljs$cst$1433$at$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$79$$))?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$284$level$$,null,$APP.$cljs$cst$255$length$$,null],null):$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1432$colon$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$79$$))?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1419$pretty$$,!0],null):$APP.$cljs$core$PersistentVector$EMPTY$$);return function($arg$jscomp$28_params__$1$jscomp$15$$,$navigator$jscomp$41_navigator__$1$jscomp$25_vec__45065$$){$navigator$jscomp$41_navigator__$1$jscomp$25_vec__45065$$=$cljs$pprint$next_arg$$($navigator$jscomp$41_navigator__$1$jscomp$25_vec__45065$$);$arg$jscomp$28_params__$1$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$41_navigator__$1$jscomp$25_vec__45065$$,
0,null);$navigator$jscomp$41_navigator__$1$jscomp$25_vec__45065$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$41_navigator__$1$jscomp$25_vec__45065$$,1,null);return $APP.$cljs$core$truth_$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($cljs$pprint$write$$,$arg$jscomp$28_params__$1$jscomp$15$$,$bindings$jscomp$2$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1443$up_arrow$$,$navigator$jscomp$41_navigator__$1$jscomp$25_vec__45065$$],
null):$navigator$jscomp$41_navigator__$1$jscomp$25_vec__45065$$}}return function($arg$jscomp$29_params__$1$jscomp$16$$,$navigator$jscomp$42_navigator__$1$jscomp$26_vec__45069$$){$navigator$jscomp$42_navigator__$1$jscomp$26_vec__45069$$=$cljs$pprint$next_arg$$($navigator$jscomp$42_navigator__$1$jscomp$26_vec__45069$$);$arg$jscomp$29_params__$1$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$42_navigator__$1$jscomp$26_vec__45069$$,0,null);$navigator$jscomp$42_navigator__$1$jscomp$26_vec__45069$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($navigator$jscomp$42_navigator__$1$jscomp$26_vec__45069$$,1,null);return $APP.$cljs$core$truth_$$($cljs$pprint$write_out$$($arg$jscomp$29_params__$1$jscomp$16$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1443$up_arrow$$,$navigator$jscomp$42_navigator__$1$jscomp$26_vec__45069$$],null):$navigator$jscomp$42_navigator__$1$jscomp$26_vec__45069$$}}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$cljs$cst$1466$directive$$,"_",$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1432$colon$$,null,$cljs$cst$1433$at$$,null,$cljs$cst$259$both$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,function(){return $cljs$pprint$conditional_newline$$}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$cljs$cst$1466$directive$$,"I",$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1451$n$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,Number],null)],null),$APP.$cljs$cst$1467$flags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1432$colon$$,null],null),null),$cljs$cst$1468$bracket_info$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$cst$1469$generator_fn$$,
function(){return $cljs$pprint$set_indent$$}],null)]),$cljs$pprint$param_pattern$$=/^([vV]|#|('.)|([+-]?\d+)|(?=,))/,$cljs$pprint$special_params$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$1435$remaining_arg_count$$,null,$cljs$cst$1434$parameter_from_args$$,null],null),null),$cljs$pprint$flag_defs$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[":",$APP.$cljs$cst$1432$colon$$,"@",$cljs$cst$1433$at$$],null),$cljs$pprint$needs_pretty$$=
function $cljs$pprint$needs_pretty$$($format$jscomp$24_format__$1$$){for(;;){if($APP.$cljs$core$empty_QMARK_$$($format$jscomp$24_format__$1$$))return!1;var $JSCompiler_inline_result$jscomp$645_or__5025__auto__$jscomp$inline_4491_or__5025__auto____$1$jscomp$inline_4492$$=$cljs$cst$1419$pretty$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1467$flags$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$1429$def$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($format$jscomp$24_format__$1$$))));$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$645_or__5025__auto__$jscomp$inline_4491_or__5025__auto____$1$jscomp$inline_4492$$)||
($JSCompiler_inline_result$jscomp$645_or__5025__auto__$jscomp$inline_4491_or__5025__auto____$1$jscomp$inline_4492$$=$APP.$cljs$core$some$$($cljs$pprint$needs_pretty$$,$APP.$cljs$core$first$$($cljs$cst$1453$clauses$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($format$jscomp$24_format__$1$$))))),$JSCompiler_inline_result$jscomp$645_or__5025__auto__$jscomp$inline_4491_or__5025__auto____$1$jscomp$inline_4492$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$645_or__5025__auto__$jscomp$inline_4491_or__5025__auto____$1$jscomp$inline_4492$$)?
$JSCompiler_inline_result$jscomp$645_or__5025__auto__$jscomp$inline_4491_or__5025__auto____$1$jscomp$inline_4492$$:$APP.$cljs$core$some$$($cljs$pprint$needs_pretty$$,$APP.$cljs$core$first$$($cljs$cst$225$else$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($format$jscomp$24_format__$1$$))))));if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$645_or__5025__auto__$jscomp$inline_4491_or__5025__auto____$1$jscomp$inline_4492$$))return!0;
$format$jscomp$24_format__$1$$=$APP.$cljs$core$next$$($format$jscomp$24_format__$1$$)}},$cljs$pprint$cached_compile$$=$APP.$cljs$core$memoize$$($cljs$pprint$compile_format$$),$cljs$pprint$reader_macros$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$167$quote$$,"'",$APP.$cljs$cst$166$var$$,"#'",$APP.$cljs$cst$248$clojure_DOT_core_SLASH_deref$$,"@",$APP.$cljs$cst$234$clojure_DOT_core_SLASH_unquote$$,"~",$cljs$cst$282$cljs_DOT_core_SLASH_deref$$,"@",$cljs$cst$283$cljs_DOT_core_SLASH_unquote$$,
"~"],null);
(function(){var $cf__42926__auto__$$=$cljs$pprint$cached_compile$$("~\x3c[~;~@{~w~^, ~:_~}~;]~:\x3e");return function(){function $G__46117$$($var_args$jscomp$749$$){var $G__46119__i_args__42927__auto__$jscomp$1$$=null;if(arguments.length>0){$G__46119__i_args__42927__auto__$jscomp$1$$=0;for(var $G__46119__a$$=Array(arguments.length-0);$G__46119__i_args__42927__auto__$jscomp$1$$<$G__46119__a$$.length;)$G__46119__a$$[$G__46119__i_args__42927__auto__$jscomp$1$$]=arguments[$G__46119__i_args__42927__auto__$jscomp$1$$+0],
++$G__46119__i_args__42927__auto__$jscomp$1$$;$G__46119__i_args__42927__auto__$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__46119__a$$,0,null)}return $G__46117__delegate$$.call(this,$G__46119__i_args__42927__auto__$jscomp$1$$)}function $G__46117__delegate$$($args__42927__auto___navigator__42928__auto__$$){$args__42927__auto___navigator__42928__auto__$$=$cljs$pprint$init_navigator$$($args__42927__auto___navigator__42928__auto__$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$$,
$args__42927__auto___navigator__42928__auto__$$)}$G__46117$$.$cljs$lang$maxFixedArity$=0;$G__46117$$.$cljs$lang$applyTo$=function($arglist__46120_args__42927__auto__$jscomp$2$$){$arglist__46120_args__42927__auto__$jscomp$2$$=$APP.$cljs$core$seq$$($arglist__46120_args__42927__auto__$jscomp$2$$);return $G__46117__delegate$$($arglist__46120_args__42927__auto__$jscomp$2$$)};$G__46117$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46117__delegate$$;return $G__46117$$}()})();
var $cljs$pprint$pprint_set$$=function(){var $cf__42926__auto__$jscomp$1$$=$cljs$pprint$cached_compile$$("~\x3c#{~;~@{~w~^ ~:_~}~;}~:\x3e");return function(){function $G__46137$$($var_args$jscomp$750$$){var $G__46138__i_args__42927__auto__$jscomp$4$$=null;if(arguments.length>0){$G__46138__i_args__42927__auto__$jscomp$4$$=0;for(var $G__46138__a$$=Array(arguments.length-0);$G__46138__i_args__42927__auto__$jscomp$4$$<$G__46138__a$$.length;)$G__46138__a$$[$G__46138__i_args__42927__auto__$jscomp$4$$]=
arguments[$G__46138__i_args__42927__auto__$jscomp$4$$+0],++$G__46138__i_args__42927__auto__$jscomp$4$$;$G__46138__i_args__42927__auto__$jscomp$4$$=new $APP.$cljs$core$IndexedSeq$$($G__46138__a$$,0,null)}return $G__46137__delegate$$.call(this,$G__46138__i_args__42927__auto__$jscomp$4$$)}function $G__46137__delegate$$($args__42927__auto__$jscomp$3_navigator__42928__auto__$jscomp$1$$){$args__42927__auto__$jscomp$3_navigator__42928__auto__$jscomp$1$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$3_navigator__42928__auto__$jscomp$1$$);
return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$1$$,$args__42927__auto__$jscomp$3_navigator__42928__auto__$jscomp$1$$)}$G__46137$$.$cljs$lang$maxFixedArity$=0;$G__46137$$.$cljs$lang$applyTo$=function($arglist__46139_args__42927__auto__$jscomp$5$$){$arglist__46139_args__42927__auto__$jscomp$5$$=$APP.$cljs$core$seq$$($arglist__46139_args__42927__auto__$jscomp$5$$);return $G__46137__delegate$$($arglist__46139_args__42927__auto__$jscomp$5$$)};$G__46137$$.$cljs$core$IFn$_invoke$arity$variadic$=
$G__46137__delegate$$;return $G__46137$$}()}(),$cljs$pprint$type_map$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,["core$future_call","Future","core$promise","Promise"],null),$cljs$pprint$pprint_pqueue$$=function(){var $cf__42926__auto__$jscomp$2$$=$cljs$pprint$cached_compile$$("~\x3c\x3c-(~;~@{~w~^ ~_~}~;)-\x3c~:\x3e");return function(){function $G__46146$$($var_args$jscomp$751$$){var $G__46147__i_args__42927__auto__$jscomp$7$$=null;if(arguments.length>0){$G__46147__i_args__42927__auto__$jscomp$7$$=
0;for(var $G__46147__a$$=Array(arguments.length-0);$G__46147__i_args__42927__auto__$jscomp$7$$<$G__46147__a$$.length;)$G__46147__a$$[$G__46147__i_args__42927__auto__$jscomp$7$$]=arguments[$G__46147__i_args__42927__auto__$jscomp$7$$+0],++$G__46147__i_args__42927__auto__$jscomp$7$$;$G__46147__i_args__42927__auto__$jscomp$7$$=new $APP.$cljs$core$IndexedSeq$$($G__46147__a$$,0,null)}return $G__46146__delegate$$.call(this,$G__46147__i_args__42927__auto__$jscomp$7$$)}function $G__46146__delegate$$($args__42927__auto__$jscomp$6_navigator__42928__auto__$jscomp$2$$){$args__42927__auto__$jscomp$6_navigator__42928__auto__$jscomp$2$$=
$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$6_navigator__42928__auto__$jscomp$2$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$2$$,$args__42927__auto__$jscomp$6_navigator__42928__auto__$jscomp$2$$)}$G__46146$$.$cljs$lang$maxFixedArity$=0;$G__46146$$.$cljs$lang$applyTo$=function($arglist__46148_args__42927__auto__$jscomp$8$$){$arglist__46148_args__42927__auto__$jscomp$8$$=$APP.$cljs$core$seq$$($arglist__46148_args__42927__auto__$jscomp$8$$);
return $G__46146__delegate$$($arglist__46148_args__42927__auto__$jscomp$8$$)};$G__46146$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46146__delegate$$;return $G__46146$$}()}(),$cljs$pprint$simple_dispatch$$,$method_table__5622__auto__$jscomp$inline_11732$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$inline_11733$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),
$method_cache__5624__auto__$jscomp$inline_11734$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$inline_11735$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$inline_11736$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?
$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());
$cljs$pprint$simple_dispatch$$=new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("cljs.pprint","simple-dispatch"),$cljs$pprint$type_dispatcher$$,$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$inline_11736$$,$method_table__5622__auto__$jscomp$inline_11732$$,$prefer_table__5623__auto__$jscomp$inline_11733$$,$method_cache__5624__auto__$jscomp$inline_11734$$,$cached_hierarchy__5625__auto__$jscomp$inline_11735$$);
$cljs$core$_add_method$$($cljs$pprint$simple_dispatch$$,$APP.$cljs$cst$201$list$$,function($G__46107$jscomp$inline_4501_alis$jscomp$2$$){if($APP.$cljs$core$not$$($cljs$pprint$pprint_reader_macro$$($G__46107$jscomp$inline_4501_alis$jscomp$2$$)))if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"#");else{var $_STAR_current_level_STAR__orig_val__45218_46101$jscomp$inline_4497$$=$cljs$pprint$_STAR_current_level_STAR_$$,$_STAR_current_length_STAR__orig_val__45219_46102$jscomp$inline_4498$$=
$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$("(",")");for(var $length_count45222_46105$jscomp$inline_4499$$=0,$alis_46106__$1$jscomp$inline_4500$$=$APP.$cljs$core$seq$$($G__46107$jscomp$inline_4501_alis$jscomp$2$$);;){if($APP.$cljs$core$not$$($cljs$core$_STAR_print_length_STAR_$$)||$length_count45222_46105$jscomp$inline_4499$$<$cljs$core$_STAR_print_length_STAR_$$){if($alis_46106__$1$jscomp$inline_4500$$&&
($cljs$pprint$write_out$$($APP.$cljs$core$first$$($alis_46106__$1$jscomp$inline_4500$$)),$APP.$cljs$core$next$$($alis_46106__$1$jscomp$inline_4500$$))){$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$," ");$cljs$pprint$pprint_newline$$($APP.$cljs$cst$287$linear$$);$G__46107$jscomp$inline_4501_alis$jscomp$2$$=$length_count45222_46105$jscomp$inline_4499$$+1;var $G__46108$jscomp$inline_4502$$=$APP.$cljs$core$next$$($alis_46106__$1$jscomp$inline_4500$$);$length_count45222_46105$jscomp$inline_4499$$=
$G__46107$jscomp$inline_4501_alis$jscomp$2$$;$alis_46106__$1$jscomp$inline_4500$$=$G__46108$jscomp$inline_4502$$;continue}}else $APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"...");break}$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=$_STAR_current_length_STAR__orig_val__45219_46102$jscomp$inline_4498$$,$cljs$pprint$_STAR_current_level_STAR_$$=$_STAR_current_level_STAR__orig_val__45218_46101$jscomp$inline_4497$$}}return null});
$cljs$core$_add_method$$($cljs$pprint$simple_dispatch$$,$APP.$cljs$cst$200$vector$$,$cljs$pprint$pprint_vector$$);$cljs$core$_add_method$$($cljs$pprint$simple_dispatch$$,$APP.$cljs$cst$202$map$$,$cljs$pprint$pprint_map$$);$cljs$core$_add_method$$($cljs$pprint$simple_dispatch$$,$APP.$cljs$cst$203$set$$,$cljs$pprint$pprint_set$$);$cljs$core$_add_method$$($cljs$pprint$simple_dispatch$$,null,function(){return $APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([null])))});
$cljs$core$_add_method$$($cljs$pprint$simple_dispatch$$,$APP.$cljs$cst$205$default$$,$cljs$pprint$pprint_simple_default$$);$cljs$pprint$_STAR_print_pprint_dispatch_STAR_$$=$cljs$pprint$simple_dispatch$$;
var $cljs$pprint$pprint_hold_first$$=function(){var $cf__42926__auto__$jscomp$19$$=$cljs$pprint$cached_compile$$("~:\x3c~w~^ ~@_~w~^ ~_~@{~w~^ ~_~}~:\x3e");return function(){function $G__46217$$($var_args$jscomp$762$$){var $G__46218__i_args__42927__auto__$jscomp$40$$=null;if(arguments.length>0){$G__46218__i_args__42927__auto__$jscomp$40$$=0;for(var $G__46218__a$$=Array(arguments.length-0);$G__46218__i_args__42927__auto__$jscomp$40$$<$G__46218__a$$.length;)$G__46218__a$$[$G__46218__i_args__42927__auto__$jscomp$40$$]=
arguments[$G__46218__i_args__42927__auto__$jscomp$40$$+0],++$G__46218__i_args__42927__auto__$jscomp$40$$;$G__46218__i_args__42927__auto__$jscomp$40$$=new $APP.$cljs$core$IndexedSeq$$($G__46218__a$$,0,null)}return $G__46217__delegate$$.call(this,$G__46218__i_args__42927__auto__$jscomp$40$$)}function $G__46217__delegate$$($args__42927__auto__$jscomp$39_navigator__42928__auto__$jscomp$13$$){$args__42927__auto__$jscomp$39_navigator__42928__auto__$jscomp$13$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$39_navigator__42928__auto__$jscomp$13$$);
return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$19$$,$args__42927__auto__$jscomp$39_navigator__42928__auto__$jscomp$13$$)}$G__46217$$.$cljs$lang$maxFixedArity$=0;$G__46217$$.$cljs$lang$applyTo$=function($arglist__46219_args__42927__auto__$jscomp$41$$){$arglist__46219_args__42927__auto__$jscomp$41$$=$APP.$cljs$core$seq$$($arglist__46219_args__42927__auto__$jscomp$41$$);return $G__46217__delegate$$($arglist__46219_args__42927__auto__$jscomp$41$$)};$G__46217$$.$cljs$core$IFn$_invoke$arity$variadic$=
$G__46217__delegate$$;return $G__46217$$}()}(),$cljs$pprint$pprint_if$$=function(){var $cf__42926__auto__$jscomp$29$$=$cljs$pprint$cached_compile$$("~:\x3c~1I~w~^ ~@_~w~@{ ~_~w~}~:\x3e");return function(){function $G__46276$$($var_args$jscomp$772$$){var $G__46277__i_args__42927__auto__$jscomp$70$$=null;if(arguments.length>0){$G__46277__i_args__42927__auto__$jscomp$70$$=0;for(var $G__46277__a$$=Array(arguments.length-0);$G__46277__i_args__42927__auto__$jscomp$70$$<$G__46277__a$$.length;)$G__46277__a$$[$G__46277__i_args__42927__auto__$jscomp$70$$]=
arguments[$G__46277__i_args__42927__auto__$jscomp$70$$+0],++$G__46277__i_args__42927__auto__$jscomp$70$$;$G__46277__i_args__42927__auto__$jscomp$70$$=new $APP.$cljs$core$IndexedSeq$$($G__46277__a$$,0,null)}return $G__46276__delegate$$.call(this,$G__46277__i_args__42927__auto__$jscomp$70$$)}function $G__46276__delegate$$($args__42927__auto__$jscomp$69_navigator__42928__auto__$jscomp$23$$){$args__42927__auto__$jscomp$69_navigator__42928__auto__$jscomp$23$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$69_navigator__42928__auto__$jscomp$23$$);
return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$29$$,$args__42927__auto__$jscomp$69_navigator__42928__auto__$jscomp$23$$)}$G__46276$$.$cljs$lang$maxFixedArity$=0;$G__46276$$.$cljs$lang$applyTo$=function($arglist__46278_args__42927__auto__$jscomp$71$$){$arglist__46278_args__42927__auto__$jscomp$71$$=$APP.$cljs$core$seq$$($arglist__46278_args__42927__auto__$jscomp$71$$);return $G__46276__delegate$$($arglist__46278_args__42927__auto__$jscomp$71$$)};$G__46276$$.$cljs$core$IFn$_invoke$arity$variadic$=
$G__46276__delegate$$;return $G__46276$$}()}(),$cljs$pprint$_STAR_symbol_map_STAR_$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$cljs$pprint$_STAR_code_table_STAR_$$=function($amap$jscomp$1$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$identity$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([function(){return function $cljs$pprint$two_forms_$_iter__45438$$($s__45439$$){return new $APP.$cljs$core$LazySeq$$(null,
function(){for(;;){var $s__45439__$2_temp__5825__auto__$jscomp$98$$=$APP.$cljs$core$seq$$($s__45439$$);if($s__45439__$2_temp__5825__auto__$jscomp$98$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__45439__$2_temp__5825__auto__$jscomp$98$$)){var $JSCompiler_inline_result$jscomp$648_c__5501__auto__$jscomp$10$$=$APP.$cljs$core$_chunked_first$$($s__45439__$2_temp__5825__auto__$jscomp$98$$),$size__5502__auto__$jscomp$10$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$648_c__5501__auto__$jscomp$10$$),
$b__45441_x$jscomp$1035$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$10$$);a:{for(var $i__45440$jscomp$inline_4504$$=0;;)if($i__45440$jscomp$inline_4504$$<$size__5502__auto__$jscomp$10$$){var $x$jscomp$inline_11764_x$jscomp$inline_4505$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$648_c__5501__auto__$jscomp$10$$,$i__45440$jscomp$inline_4504$$),$b$jscomp$inline_11763$$=$b__45441_x$jscomp$1035$$;$x$jscomp$inline_11764_x$jscomp$inline_4505$$=new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$x$jscomp$inline_11764_x$jscomp$inline_4505$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$name$$($APP.$cljs$core$first$$($x$jscomp$inline_11764_x$jscomp$inline_4505$$))),$APP.$cljs$core$second$$($x$jscomp$inline_11764_x$jscomp$inline_4505$$)],null)],null);$b$jscomp$inline_11763$$.add($x$jscomp$inline_11764_x$jscomp$inline_4505$$);
$i__45440$jscomp$inline_4504$$+=1}else{$JSCompiler_inline_result$jscomp$648_c__5501__auto__$jscomp$10$$=!0;break a}$JSCompiler_inline_result$jscomp$648_c__5501__auto__$jscomp$10$$=void 0}return $JSCompiler_inline_result$jscomp$648_c__5501__auto__$jscomp$10$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__45441_x$jscomp$1035$$),$cljs$pprint$two_forms_$_iter__45438$$($APP.$cljs$core$_chunked_rest$$($s__45439__$2_temp__5825__auto__$jscomp$98$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__45441_x$jscomp$1035$$),
null)}$b__45441_x$jscomp$1035$$=$APP.$cljs$core$first$$($s__45439__$2_temp__5825__auto__$jscomp$98$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__45441_x$jscomp$1035$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$name$$($APP.$cljs$core$first$$($b__45441_x$jscomp$1035$$))),$APP.$cljs$core$second$$($b__45441_x$jscomp$1035$$)],
null)],null),$cljs$pprint$two_forms_$_iter__45438$$($APP.$cljs$core$rest$$($s__45439__$2_temp__5825__auto__$jscomp$98$$)))}return null}},null,null)}($amap$jscomp$1$$)}()])))}(function($amap$jscomp$2$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__45447_SHARP_$$){var $s$jscomp$503$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__45447_SHARP_$$,0,null),$f$jscomp$661$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__45447_SHARP_$$,1,null);var $JSCompiler_inline_result$jscomp$649_or__5025__auto__$jscomp$inline_4507$$=$APP.$cljs$core$namespace$$($s$jscomp$503$$);$JSCompiler_inline_result$jscomp$649_or__5025__auto__$jscomp$inline_4507$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$649_or__5025__auto__$jscomp$inline_4507$$)?$JSCompiler_inline_result$jscomp$649_or__5025__auto__$jscomp$inline_4507$$:$APP.$cljs$core$special_symbol_QMARK_$$($s$jscomp$503$$);
return $APP.$cljs$core$not$$($JSCompiler_inline_result$jscomp$649_or__5025__auto__$jscomp$inline_4507$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("clojure.core",$APP.$cljs$core$name$$($s$jscomp$503$$)),$f$jscomp$661$$],null):$p1__45447_SHARP_$$},$amap$jscomp$2$$))}($APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$165$_DOT_$$,$APP.$cljs$cst$162$fn_STAR_$$,$cljs$cst$1486$when_first$$,
$cljs$cst$157$if$$,$cljs$cst$1487$condp$$,$cljs$cst$1488$_DOT__DOT_$$,$cljs$cst$1489$defmacro$$,$cljs$cst$1490$defn$$,$cljs$cst$1491$loop$$,$cljs$cst$1492$struct$$,$cljs$cst$1493$doseq$$,$cljs$cst$1494$if_not$$,$cljs$cst$1495$when_not$$,$cljs$cst$170$def$$,$cljs$cst$1496$when$$,$cljs$cst$1497$with_open$$,$cljs$cst$1498$with_local_vars$$,$cljs$cst$1499$defonce$$,$cljs$cst$1500$when_let$$,$cljs$cst$6$ns$$,$cljs$cst$1501$dotimes$$,$cljs$cst$1502$cond$$,$cljs$cst$1503$let$$,$APP.$cljs$cst$28$fn$$,$cljs$cst$1504$defn_$$,
$cljs$cst$1505$locking$$,$cljs$cst$1506$__GT_$$,$cljs$cst$1507$if_let$$,$cljs$cst$1508$binding$$,$cljs$cst$1509$struct_map$$],[$cljs$pprint$pprint_hold_first$$,function($_STAR_symbol_map_STAR__orig_val__45420_alis$jscomp$10$$){var $args$jscomp$225$$=$APP.$cljs$core$second$$($_STAR_symbol_map_STAR__orig_val__45420_alis$jscomp$10$$),$nlis$$=$APP.$cljs$core$first$$($APP.$cljs$core$rest$$($APP.$cljs$core$rest$$($_STAR_symbol_map_STAR__orig_val__45420_alis$jscomp$10$$)));if($APP.$cljs$core$vector_QMARK_$$($args$jscomp$225$$)){$_STAR_symbol_map_STAR__orig_val__45420_alis$jscomp$10$$=
$cljs$pprint$_STAR_symbol_map_STAR_$$;$cljs$pprint$_STAR_symbol_map_STAR_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($args$jscomp$225$$))?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$APP.$cljs$core$first$$($args$jscomp$225$$),"%"]):$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(function($p1__45415_SHARP_$$,$p2__45416_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__45415_SHARP_$$,["%",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p2__45416_SHARP_$$)].join("")],null)},$args$jscomp$225$$,$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$(1,$APP.$cljs$core$count$$($args$jscomp$225$$)+1)));try{return function(){var $cf__42926__auto__$jscomp$31$$=$cljs$pprint$cached_compile$$("~\x3c#(~;~@{~w~^ ~_~}~;)~:\x3e");return function(){function $G__46311$$($var_args$jscomp$774$$){var $G__46312__i_args__42927__auto__$jscomp$76$$=
null;if(arguments.length>0){$G__46312__i_args__42927__auto__$jscomp$76$$=0;for(var $G__46312__a$$=Array(arguments.length-0);$G__46312__i_args__42927__auto__$jscomp$76$$<$G__46312__a$$.length;)$G__46312__a$$[$G__46312__i_args__42927__auto__$jscomp$76$$]=arguments[$G__46312__i_args__42927__auto__$jscomp$76$$+0],++$G__46312__i_args__42927__auto__$jscomp$76$$;$G__46312__i_args__42927__auto__$jscomp$76$$=new $APP.$cljs$core$IndexedSeq$$($G__46312__a$$,0,null)}return $G__46311__delegate$$.call(this,$G__46312__i_args__42927__auto__$jscomp$76$$)}
function $G__46311__delegate$$($args__42927__auto__$jscomp$75_navigator__42928__auto__$jscomp$25$$){$args__42927__auto__$jscomp$75_navigator__42928__auto__$jscomp$25$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$75_navigator__42928__auto__$jscomp$25$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$31$$,$args__42927__auto__$jscomp$75_navigator__42928__auto__$jscomp$25$$)}$G__46311$$.$cljs$lang$maxFixedArity$=0;$G__46311$$.$cljs$lang$applyTo$=
function($arglist__46313_args__42927__auto__$jscomp$77$$){$arglist__46313_args__42927__auto__$jscomp$77$$=$APP.$cljs$core$seq$$($arglist__46313_args__42927__auto__$jscomp$77$$);return $G__46311__delegate$$($arglist__46313_args__42927__auto__$jscomp$77$$)};$G__46311$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46311__delegate$$;return $G__46311$$}()}()($nlis$$)}finally{$cljs$pprint$_STAR_symbol_map_STAR_$$=$_STAR_symbol_map_STAR__orig_val__45420_alis$jscomp$10$$}}else return $cljs$pprint$pprint_simple_code_list$$($_STAR_symbol_map_STAR__orig_val__45420_alis$jscomp$10$$)},
$cljs$pprint$pprint_let$$,$cljs$pprint$pprint_if$$,function($G__46309__STAR_current_level_STAR__orig_val__45409_46305_alis$jscomp$9$$){if($APP.$cljs$core$count$$($G__46309__STAR_current_level_STAR__orig_val__45409_46305_alis$jscomp$9$$)>3){if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"#");else{var $_STAR_current_level_STAR__orig_val__45400_46294$$=$cljs$pprint$_STAR_current_level_STAR_$$,$_STAR_current_length_STAR__orig_val__45401_46295$$=
$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$("(",")");$cljs$pprint$pprint_indent$$($APP.$cljs$cst$1400$block$$,1);$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $cf__42926__auto__$jscomp$30$$=$cljs$pprint$cached_compile$$("~w ~@_~w ~@_~w ~_");return function(){function $G__46298$$($var_args$jscomp$773$$){var $G__46299__i_args__42927__auto__$jscomp$73$$=null;if(arguments.length>
0){$G__46299__i_args__42927__auto__$jscomp$73$$=0;for(var $G__46299__a$$=Array(arguments.length-0);$G__46299__i_args__42927__auto__$jscomp$73$$<$G__46299__a$$.length;)$G__46299__a$$[$G__46299__i_args__42927__auto__$jscomp$73$$]=arguments[$G__46299__i_args__42927__auto__$jscomp$73$$+0],++$G__46299__i_args__42927__auto__$jscomp$73$$;$G__46299__i_args__42927__auto__$jscomp$73$$=new $APP.$cljs$core$IndexedSeq$$($G__46299__a$$,0,null)}return $G__46298__delegate$$.call(this,$G__46299__i_args__42927__auto__$jscomp$73$$)}
function $G__46298__delegate$$($args__42927__auto__$jscomp$72_navigator__42928__auto__$jscomp$24$$){$args__42927__auto__$jscomp$72_navigator__42928__auto__$jscomp$24$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$72_navigator__42928__auto__$jscomp$24$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$30$$,$args__42927__auto__$jscomp$72_navigator__42928__auto__$jscomp$24$$)}$G__46298$$.$cljs$lang$maxFixedArity$=0;$G__46298$$.$cljs$lang$applyTo$=
function($arglist__46300_args__42927__auto__$jscomp$74$$){$arglist__46300_args__42927__auto__$jscomp$74$$=$APP.$cljs$core$seq$$($arglist__46300_args__42927__auto__$jscomp$74$$);return $G__46298__delegate$$($arglist__46300_args__42927__auto__$jscomp$74$$)};$G__46298$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46298__delegate$$;return $G__46298$$}()}(),$G__46309__STAR_current_level_STAR__orig_val__45409_46305_alis$jscomp$9$$);for(var $length_count45405_46301$$=0,$alis_46302__$1$$=$APP.$cljs$core$seq$$($APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$(3,
$G__46309__STAR_current_level_STAR__orig_val__45409_46305_alis$jscomp$9$$));;){if($APP.$cljs$core$not$$($cljs$core$_STAR_print_length_STAR_$$)||$length_count45405_46301$$<$cljs$core$_STAR_print_length_STAR_$$){if($alis_46302__$1$$){if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"#");else{$G__46309__STAR_current_level_STAR__orig_val__45409_46305_alis$jscomp$9$$=$cljs$pprint$_STAR_current_level_STAR_$$;var $_STAR_current_length_STAR__orig_val__45410_46306$$=
$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$(null,null),$cljs$pprint$write_out$$($APP.$cljs$core$first$$($alis_46302__$1$$)),$APP.$cljs$core$next$$($alis_46302__$1$$)&&($APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$," "),$cljs$pprint$pprint_newline$$($cljs$cst$288$miser$$),$cljs$pprint$write_out$$($APP.$cljs$core$second$$($alis_46302__$1$$))),$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=
$_STAR_current_length_STAR__orig_val__45410_46306$$,$cljs$pprint$_STAR_current_level_STAR_$$=$G__46309__STAR_current_level_STAR__orig_val__45409_46305_alis$jscomp$9$$}}if($APP.$cljs$core$next$$($APP.$cljs$core$rest$$($alis_46302__$1$$))){$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$," ");$cljs$pprint$pprint_newline$$($APP.$cljs$cst$287$linear$$);$G__46309__STAR_current_level_STAR__orig_val__45409_46305_alis$jscomp$9$$=$length_count45405_46301$$+1;var $G__46310$$=$APP.$cljs$core$next$$($APP.$cljs$core$rest$$($alis_46302__$1$$));
$length_count45405_46301$$=$G__46309__STAR_current_level_STAR__orig_val__45409_46305_alis$jscomp$9$$;$alis_46302__$1$$=$G__46310$$;continue}}}else $APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"...");break}$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=$_STAR_current_length_STAR__orig_val__45401_46295$$,$cljs$pprint$_STAR_current_level_STAR_$$=$_STAR_current_level_STAR__orig_val__45400_46294$$}}return null}return $cljs$pprint$pprint_simple_code_list$$($G__46309__STAR_current_level_STAR__orig_val__45409_46305_alis$jscomp$9$$)},
$cljs$pprint$pprint_hold_first$$,$cljs$pprint$pprint_defn$$,$cljs$pprint$pprint_defn$$,$cljs$pprint$pprint_let$$,$cljs$pprint$pprint_hold_first$$,$cljs$pprint$pprint_let$$,$cljs$pprint$pprint_if$$,$cljs$pprint$pprint_if$$,$cljs$pprint$pprint_hold_first$$,$cljs$pprint$pprint_if$$,$cljs$pprint$pprint_let$$,$cljs$pprint$pprint_let$$,$cljs$pprint$pprint_hold_first$$,$cljs$pprint$pprint_let$$,function($alis$jscomp$3_first__45345_references_46213__$1$$){if($APP.$cljs$core$next$$($alis$jscomp$3_first__45345_references_46213__$1$$)){var $first__45345__$1_references_46215__$2_seq__45344$$=
$APP.$cljs$core$seq$$($alis$jscomp$3_first__45345_references_46213__$1$$);$alis$jscomp$3_first__45345_references_46213__$1$$=$APP.$cljs$core$first$$($first__45345__$1_references_46215__$2_seq__45344$$);var $doc_str_seq__45344__$1_seq__45344__$2$$=$APP.$cljs$core$next$$($first__45345__$1_references_46215__$2_seq__45344$$);$first__45345__$1_references_46215__$2_seq__45344$$=$APP.$cljs$core$first$$($doc_str_seq__45344__$1_seq__45344__$2$$);$doc_str_seq__45344__$1_seq__45344__$2$$=$APP.$cljs$core$next$$($doc_str_seq__45344__$1_seq__45344__$2$$);
var $_STAR_current_level_STAR__orig_val__45352_46196_stuff__$1_vec__45346_vec__45349$$=typeof $APP.$cljs$core$first$$($doc_str_seq__45344__$1_seq__45344__$2$$)==="string"?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($doc_str_seq__45344__$1_seq__45344__$2$$),$APP.$cljs$core$next$$($doc_str_seq__45344__$1_seq__45344__$2$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,
$doc_str_seq__45344__$1_seq__45344__$2$$],null);$doc_str_seq__45344__$1_seq__45344__$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_STAR_current_level_STAR__orig_val__45352_46196_stuff__$1_vec__45346_vec__45349$$,0,null);$_STAR_current_level_STAR__orig_val__45352_46196_stuff__$1_vec__45346_vec__45349$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_STAR_current_level_STAR__orig_val__45352_46196_stuff__$1_vec__45346_vec__45349$$,1,null);$_STAR_current_level_STAR__orig_val__45352_46196_stuff__$1_vec__45346_vec__45349$$=
$APP.$cljs$core$map_QMARK_$$($APP.$cljs$core$first$$($_STAR_current_level_STAR__orig_val__45352_46196_stuff__$1_vec__45346_vec__45349$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($_STAR_current_level_STAR__orig_val__45352_46196_stuff__$1_vec__45346_vec__45349$$),$APP.$cljs$core$next$$($_STAR_current_level_STAR__orig_val__45352_46196_stuff__$1_vec__45346_vec__45349$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$_STAR_current_level_STAR__orig_val__45352_46196_stuff__$1_vec__45346_vec__45349$$],null);var $attr_map$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_STAR_current_level_STAR__orig_val__45352_46196_stuff__$1_vec__45346_vec__45349$$,0,null),$references$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_STAR_current_level_STAR__orig_val__45352_46196_stuff__$1_vec__45346_vec__45349$$,1,null);if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,
"#");else{$_STAR_current_level_STAR__orig_val__45352_46196_stuff__$1_vec__45346_vec__45349$$=$cljs$pprint$_STAR_current_level_STAR_$$;var $_STAR_current_length_STAR__orig_val__45353_46197$$=$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$("(",")");(function(){var $cf__42926__auto__$jscomp$16$$=$cljs$pprint$cached_compile$$("~w ~1I~@_~w");return function(){function $G__46200$$($var_args$jscomp$759$$){var $G__46201__i_args__42927__auto__$jscomp$31$$=
null;if(arguments.length>0){$G__46201__i_args__42927__auto__$jscomp$31$$=0;for(var $G__46201__a$$=Array(arguments.length-0);$G__46201__i_args__42927__auto__$jscomp$31$$<$G__46201__a$$.length;)$G__46201__a$$[$G__46201__i_args__42927__auto__$jscomp$31$$]=arguments[$G__46201__i_args__42927__auto__$jscomp$31$$+0],++$G__46201__i_args__42927__auto__$jscomp$31$$;$G__46201__i_args__42927__auto__$jscomp$31$$=new $APP.$cljs$core$IndexedSeq$$($G__46201__a$$,0,null)}return $G__46200__delegate$$.call(this,$G__46201__i_args__42927__auto__$jscomp$31$$)}
function $G__46200__delegate$$($args__42927__auto__$jscomp$30_navigator__42928__auto__$jscomp$10$$){$args__42927__auto__$jscomp$30_navigator__42928__auto__$jscomp$10$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$30_navigator__42928__auto__$jscomp$10$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$16$$,$args__42927__auto__$jscomp$30_navigator__42928__auto__$jscomp$10$$)}$G__46200$$.$cljs$lang$maxFixedArity$=0;$G__46200$$.$cljs$lang$applyTo$=
function($arglist__46202_args__42927__auto__$jscomp$32$$){$arglist__46202_args__42927__auto__$jscomp$32$$=$APP.$cljs$core$seq$$($arglist__46202_args__42927__auto__$jscomp$32$$);return $G__46200__delegate$$($arglist__46202_args__42927__auto__$jscomp$32$$)};$G__46200$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46200__delegate$$;return $G__46200$$}()})()($alis$jscomp$3_first__45345_references_46213__$1$$,$first__45345__$1_references_46215__$2_seq__45344$$);$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($doc_str_seq__45344__$1_seq__45344__$2$$)?
$doc_str_seq__45344__$1_seq__45344__$2$$:$APP.$cljs$core$truth_$$($attr_map$$)?$attr_map$$:$APP.$cljs$core$seq$$($references$$))&&function(){var $cf__42926__auto__$jscomp$17$$=$cljs$pprint$cached_compile$$("~@:_");return function(){function $G__46206$$($var_args$jscomp$760$$){var $G__46207__i_args__42927__auto__$jscomp$34$$=null;if(arguments.length>0){$G__46207__i_args__42927__auto__$jscomp$34$$=0;for(var $G__46207__a$$=Array(arguments.length-0);$G__46207__i_args__42927__auto__$jscomp$34$$<$G__46207__a$$.length;)$G__46207__a$$[$G__46207__i_args__42927__auto__$jscomp$34$$]=
arguments[$G__46207__i_args__42927__auto__$jscomp$34$$+0],++$G__46207__i_args__42927__auto__$jscomp$34$$;$G__46207__i_args__42927__auto__$jscomp$34$$=new $APP.$cljs$core$IndexedSeq$$($G__46207__a$$,0,null)}return $G__46206__delegate$$.call(this,$G__46207__i_args__42927__auto__$jscomp$34$$)}function $G__46206__delegate$$($args__42927__auto__$jscomp$33_navigator__42928__auto__$jscomp$11$$){$args__42927__auto__$jscomp$33_navigator__42928__auto__$jscomp$11$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$33_navigator__42928__auto__$jscomp$11$$);
return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$17$$,$args__42927__auto__$jscomp$33_navigator__42928__auto__$jscomp$11$$)}$G__46206$$.$cljs$lang$maxFixedArity$=0;$G__46206$$.$cljs$lang$applyTo$=function($arglist__46208_args__42927__auto__$jscomp$35$$){$arglist__46208_args__42927__auto__$jscomp$35$$=$APP.$cljs$core$seq$$($arglist__46208_args__42927__auto__$jscomp$35$$);return $G__46206__delegate$$($arglist__46208_args__42927__auto__$jscomp$35$$)};$G__46206$$.$cljs$core$IFn$_invoke$arity$variadic$=
$G__46206__delegate$$;return $G__46206$$}()}()();$APP.$cljs$core$truth_$$($doc_str_seq__45344__$1_seq__45344__$2$$)&&$cljs$pprint$cl_format$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(!0,'"~a"~:[~;~:@_~]',$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$doc_str_seq__45344__$1_seq__45344__$2$$,$APP.$cljs$core$truth_$$($attr_map$$)?$attr_map$$:$APP.$cljs$core$seq$$($references$$)]));$APP.$cljs$core$truth_$$($attr_map$$)&&function(){var $cf__42926__auto__$jscomp$18$$=$cljs$pprint$cached_compile$$("~w~:[~;~:@_~]");
return function(){function $G__46210$$($var_args$jscomp$761$$){var $G__46211__i_args__42927__auto__$jscomp$37$$=null;if(arguments.length>0){$G__46211__i_args__42927__auto__$jscomp$37$$=0;for(var $G__46211__a$$=Array(arguments.length-0);$G__46211__i_args__42927__auto__$jscomp$37$$<$G__46211__a$$.length;)$G__46211__a$$[$G__46211__i_args__42927__auto__$jscomp$37$$]=arguments[$G__46211__i_args__42927__auto__$jscomp$37$$+0],++$G__46211__i_args__42927__auto__$jscomp$37$$;$G__46211__i_args__42927__auto__$jscomp$37$$=
new $APP.$cljs$core$IndexedSeq$$($G__46211__a$$,0,null)}return $G__46210__delegate$$.call(this,$G__46211__i_args__42927__auto__$jscomp$37$$)}function $G__46210__delegate$$($args__42927__auto__$jscomp$36_navigator__42928__auto__$jscomp$12$$){$args__42927__auto__$jscomp$36_navigator__42928__auto__$jscomp$12$$=$cljs$pprint$init_navigator$$($args__42927__auto__$jscomp$36_navigator__42928__auto__$jscomp$12$$);return $cljs$pprint$execute_format$cljs$0core$0IFn$0_invoke$0arity$02$$($cf__42926__auto__$jscomp$18$$,
$args__42927__auto__$jscomp$36_navigator__42928__auto__$jscomp$12$$)}$G__46210$$.$cljs$lang$maxFixedArity$=0;$G__46210$$.$cljs$lang$applyTo$=function($arglist__46212_args__42927__auto__$jscomp$38$$){$arglist__46212_args__42927__auto__$jscomp$38$$=$APP.$cljs$core$seq$$($arglist__46212_args__42927__auto__$jscomp$38$$);return $G__46210__delegate$$($arglist__46212_args__42927__auto__$jscomp$38$$)};$G__46210$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__46210__delegate$$;return $G__46210$$}()}()($attr_map$$,
$APP.$cljs$core$seq$$($references$$));for($alis$jscomp$3_first__45345_references_46213__$1$$=$references$$;;){$cljs$pprint$pprint_ns_reference$$($APP.$cljs$core$first$$($alis$jscomp$3_first__45345_references_46213__$1$$));var $temp__5825__auto___46214$$=$APP.$cljs$core$next$$($alis$jscomp$3_first__45345_references_46213__$1$$);if($temp__5825__auto___46214$$)$first__45345__$1_references_46215__$2_seq__45344$$=$temp__5825__auto___46214$$,$cljs$pprint$pprint_newline$$($APP.$cljs$cst$287$linear$$),$alis$jscomp$3_first__45345_references_46213__$1$$=
$first__45345__$1_references_46215__$2_seq__45344$$;else break}$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=$_STAR_current_length_STAR__orig_val__45353_46197$$,$cljs$pprint$_STAR_current_level_STAR_$$=$_STAR_current_level_STAR__orig_val__45352_46196_stuff__$1_vec__45346_vec__45349$$}}return null}return $cljs$pprint$write_out$$($alis$jscomp$3_first__45345_references_46213__$1$$)},$cljs$pprint$pprint_let$$,function($G__46292__STAR_current_level_STAR__orig_val__45389_46287_alis$jscomp$8$$){if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,
"#");else{var $_STAR_current_level_STAR__orig_val__45383_46280$$=$cljs$pprint$_STAR_current_level_STAR_$$,$_STAR_current_length_STAR__orig_val__45384_46281$$=$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$("(",")");$cljs$pprint$pprint_indent$$($APP.$cljs$cst$1400$block$$,1);$cljs$pprint$write_out$$($APP.$cljs$core$first$$($G__46292__STAR_current_level_STAR__orig_val__45389_46287_alis$jscomp$8$$));
if($APP.$cljs$core$next$$($G__46292__STAR_current_level_STAR__orig_val__45389_46287_alis$jscomp$8$$)){$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$," ");$cljs$pprint$pprint_newline$$($APP.$cljs$cst$287$linear$$);for(var $length_count45387_46285$$=0,$alis_46286__$1$$=$APP.$cljs$core$next$$($G__46292__STAR_current_level_STAR__orig_val__45389_46287_alis$jscomp$8$$);;){if($APP.$cljs$core$not$$($cljs$core$_STAR_print_length_STAR_$$)||$length_count45387_46285$$<$cljs$core$_STAR_print_length_STAR_$$){if($alis_46286__$1$$){if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,
"#");else{$G__46292__STAR_current_level_STAR__orig_val__45389_46287_alis$jscomp$8$$=$cljs$pprint$_STAR_current_level_STAR_$$;var $_STAR_current_length_STAR__orig_val__45390_46288$$=$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$(null,null),$cljs$pprint$write_out$$($APP.$cljs$core$first$$($alis_46286__$1$$)),$APP.$cljs$core$next$$($alis_46286__$1$$)&&($APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,
" "),$cljs$pprint$pprint_newline$$($cljs$cst$288$miser$$),$cljs$pprint$write_out$$($APP.$cljs$core$second$$($alis_46286__$1$$))),$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=$_STAR_current_length_STAR__orig_val__45390_46288$$,$cljs$pprint$_STAR_current_level_STAR_$$=$G__46292__STAR_current_level_STAR__orig_val__45389_46287_alis$jscomp$8$$}}if($APP.$cljs$core$next$$($APP.$cljs$core$rest$$($alis_46286__$1$$))){$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$," ");
$cljs$pprint$pprint_newline$$($APP.$cljs$cst$287$linear$$);$G__46292__STAR_current_level_STAR__orig_val__45389_46287_alis$jscomp$8$$=$length_count45387_46285$$+1;var $G__46293$$=$APP.$cljs$core$next$$($APP.$cljs$core$rest$$($alis_46286__$1$$));$length_count45387_46285$$=$G__46292__STAR_current_level_STAR__orig_val__45389_46287_alis$jscomp$8$$;$alis_46286__$1$$=$G__46293$$;continue}}}else $APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"...");break}}$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=
$_STAR_current_length_STAR__orig_val__45384_46281$$,$cljs$pprint$_STAR_current_level_STAR_$$=$_STAR_current_level_STAR__orig_val__45383_46280$$}}return null},$cljs$pprint$pprint_let$$,$cljs$pprint$pprint_defn$$,$cljs$pprint$pprint_defn$$,$cljs$pprint$pprint_hold_first$$,$cljs$pprint$pprint_hold_first$$,$cljs$pprint$pprint_let$$,$cljs$pprint$pprint_let$$,$cljs$pprint$pprint_hold_first$$]))),$cljs$pprint$code_dispatch$$,$method_table__5622__auto__$jscomp$inline_11766$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),
$prefer_table__5623__auto__$jscomp$inline_11767$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$inline_11768$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$inline_11769$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$inline_11770$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());
$cljs$pprint$code_dispatch$$=new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("cljs.pprint","code-dispatch"),$cljs$pprint$type_dispatcher$$,$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$inline_11770$$,$method_table__5622__auto__$jscomp$inline_11766$$,$prefer_table__5623__auto__$jscomp$inline_11767$$,$method_cache__5624__auto__$jscomp$inline_11768$$,$cached_hierarchy__5625__auto__$jscomp$inline_11769$$);
$cljs$core$_add_method$$($cljs$pprint$code_dispatch$$,$APP.$cljs$cst$201$list$$,function($alis$jscomp$12$$){if($APP.$cljs$core$not$$($cljs$pprint$pprint_reader_macro$$($alis$jscomp$12$$))){var $temp__5823__auto__$jscomp$95$$=$cljs$pprint$_STAR_code_table_STAR_$$.call(null,$APP.$cljs$core$first$$($alis$jscomp$12$$));return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$95$$)?$temp__5823__auto__$jscomp$95$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5823__auto__$jscomp$95$$.$cljs$core$IFn$_invoke$arity$1$($alis$jscomp$12$$):
$temp__5823__auto__$jscomp$95$$($alis$jscomp$12$$):$cljs$pprint$pprint_simple_code_list$$($alis$jscomp$12$$)}return null});
$cljs$core$_add_method$$($cljs$pprint$code_dispatch$$,$APP.$cljs$cst$219$symbol$$,function($sym$jscomp$24$$){var $temp__5823__auto__$jscomp$96$$=$sym$jscomp$24$$.$cljs$core$IFn$_invoke$arity$1$?$sym$jscomp$24$$.$cljs$core$IFn$_invoke$arity$1$($cljs$pprint$_STAR_symbol_map_STAR_$$):$sym$jscomp$24$$($cljs$pprint$_STAR_symbol_map_STAR_$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$96$$)?$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$temp__5823__auto__$jscomp$96$$])):
$APP.$cljs$core$truth_$$($cljs$pprint$_STAR_print_suppress_namespaces_STAR_$$)?$cljs$pprint$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$name$$($sym$jscomp$24$$)])):$cljs$pprint$pr$$.call(null,$sym$jscomp$24$$)});$cljs$core$_add_method$$($cljs$pprint$code_dispatch$$,$APP.$cljs$cst$200$vector$$,$cljs$pprint$pprint_vector$$);$cljs$core$_add_method$$($cljs$pprint$code_dispatch$$,$APP.$cljs$cst$202$map$$,$cljs$pprint$pprint_map$$);
$cljs$core$_add_method$$($cljs$pprint$code_dispatch$$,$APP.$cljs$cst$203$set$$,$cljs$pprint$pprint_set$$);$cljs$core$_add_method$$($cljs$pprint$code_dispatch$$,$APP.$cljs$cst$1484$queue$$,$cljs$pprint$pprint_pqueue$$);
$cljs$core$_add_method$$($cljs$pprint$code_dispatch$$,$cljs$cst$1485$deref$$,function($o$jscomp$212$$){var $JSCompiler_temp_const$jscomp$10734_prefix$jscomp$31$$=$APP.$cljs$core$str$$,$JSCompiler_temp_const$jscomp$10733__STAR_current_level_STAR__orig_val__45264_46142$$=$JSCompiler_temp_const$jscomp$10734_prefix$jscomp$31$$.$cljs$core$IFn$_invoke$arity$1$,$_STAR_current_length_STAR__orig_val__45265_46143_name$jscomp$inline_11796$$=$APP.$cljs$core$type$$($o$jscomp$212$$).name;var $or__5025__auto__$jscomp$inline_11797_temp__5825__auto__$jscomp$inline_11798$$=
$APP.$cljs$core$re_find$$(/^[^$]+\$[^$]+/,$_STAR_current_length_STAR__orig_val__45265_46143_name$jscomp$inline_11796$$);$or__5025__auto__$jscomp$inline_11797_temp__5825__auto__$jscomp$inline_11798$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_11797_temp__5825__auto__$jscomp$inline_11798$$)?$cljs$pprint$type_map$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$pprint$type_map$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$inline_11797_temp__5825__auto__$jscomp$inline_11798$$):$cljs$pprint$type_map$$($or__5025__auto__$jscomp$inline_11797_temp__5825__auto__$jscomp$inline_11798$$):
null;$JSCompiler_temp_const$jscomp$10734_prefix$jscomp$31$$=["#\x3c",$JSCompiler_temp_const$jscomp$10733__STAR_current_level_STAR__orig_val__45264_46142$$.call($JSCompiler_temp_const$jscomp$10734_prefix$jscomp$31$$,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_11797_temp__5825__auto__$jscomp$inline_11798$$)?$or__5025__auto__$jscomp$inline_11797_temp__5825__auto__$jscomp$inline_11798$$:$_STAR_current_length_STAR__orig_val__45265_46143_name$jscomp$inline_11796$$),"@",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($goog$getUid$$($o$jscomp$212$$)),
": "].join("");if($APP.$cljs$core$truth_$$($cljs$pprint$level_exceeded$$()))$APP.$cljs$core$_write$$($cljs$core$_STAR_out_STAR_$$,"#");else{$JSCompiler_temp_const$jscomp$10733__STAR_current_level_STAR__orig_val__45264_46142$$=$cljs$pprint$_STAR_current_level_STAR_$$;$_STAR_current_length_STAR__orig_val__45265_46143_name$jscomp$inline_11796$$=$cljs$pprint$_STAR_current_length_STAR_$$;$cljs$pprint$_STAR_current_level_STAR_$$+=1;$cljs$pprint$_STAR_current_length_STAR_$$=0;try{$cljs$pprint$start_block$$($JSCompiler_temp_const$jscomp$10734_prefix$jscomp$31$$,
"\x3e");$cljs$pprint$pprint_indent$$($APP.$cljs$cst$1400$block$$,-($JSCompiler_temp_const$jscomp$10734_prefix$jscomp$31$$.length-2));$cljs$pprint$pprint_newline$$($APP.$cljs$cst$287$linear$$);var $and__5023__auto__$jscomp$inline_4509$$=$o$jscomp$212$$!=null?$o$jscomp$212$$.$cljs$lang$protocol_mask$partition1$$&1||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$o$jscomp$212$$.$cljs$core$IPending$$?!0:$o$jscomp$212$$.$cljs$lang$protocol_mask$partition1$$?!1:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IPending$$,
$o$jscomp$212$$):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IPending$$,$o$jscomp$212$$);var $JSCompiler_inline_result$jscomp$650$$=$and__5023__auto__$jscomp$inline_4509$$?!$cljs$core$_realized_QMARK_$$($o$jscomp$212$$):$and__5023__auto__$jscomp$inline_4509$$;$cljs$pprint$write_out$$($JSCompiler_inline_result$jscomp$650$$?$cljs$cst$1483$not_delivered$$:$APP.$cljs$core$_deref$$($o$jscomp$212$$));$cljs$pprint$end_block$$()}finally{$cljs$pprint$_STAR_current_length_STAR_$$=$_STAR_current_length_STAR__orig_val__45265_46143_name$jscomp$inline_11796$$,
$cljs$pprint$_STAR_current_level_STAR_$$=$JSCompiler_temp_const$jscomp$10733__STAR_current_level_STAR__orig_val__45264_46142$$}}return null});$cljs$core$_add_method$$($cljs$pprint$code_dispatch$$,null,$cljs$pprint$pr$$);$cljs$core$_add_method$$($cljs$pprint$code_dispatch$$,$APP.$cljs$cst$205$default$$,$cljs$pprint$pprint_simple_default$$);$cljs$pprint$_STAR_print_pprint_dispatch_STAR_$$=$cljs$pprint$simple_dispatch$$;$APP.$JSCompiler_prototypeAlias$$=$app$common$geom$point$Point$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this$$jscomp$563$$,$f__42602__auto__$$,$init__42603__auto__$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__42604__auto__$$,$p__45695_v__42605__auto__$$){var $key_45685$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45695_v__42605__auto__$$,0,null);$p__45695_v__42605__auto__$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45695_v__42605__auto__$$,1,
null);return $f__42602__auto__$$.$cljs$core$IFn$_invoke$arity$3$?$f__42602__auto__$$.$cljs$core$IFn$_invoke$arity$3$($ret__42604__auto__$$,$key_45685$$,$p__45695_v__42605__auto__$$):$f__42602__auto__$$($ret__42604__auto__$$,$key_45685$$,$p__45695_v__42605__auto__$$)},$init__42603__auto__$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$564$$,$other$jscomp$168$$){return this===$other$jscomp$168$$||$other$jscomp$168$$!=null&&this.constructor===$other$jscomp$168$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.x,$other$jscomp$168$$.x)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.y,$other$jscomp$168$$.y)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$$extmap$,$other$jscomp$168$$.$$extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__42526__auto___h__42526__auto____$1$$=this.$$hash$;return $h__42526__auto___h__42526__auto____$1$$!=null?$h__42526__auto___h__42526__auto____$1$$:this.$$hash$=$h__42526__auto___h__42526__auto____$1$$=74812275^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this$$jscomp$566$$,$val_45686$$){return $APP.$cljs$core$vector_QMARK_$$($val_45686$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($val_45686$$,0),$APP.$cljs$core$_nth$$($val_45686$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$val_45686$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2+$APP.$cljs$core$count$$(this.$$extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1510$x$$,this.x,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1511$y$$,this.y,null)],null),this.$$extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $app$common$geom$point$Point$$(this.x,this.y,this.$$meta$,this.$$extmap$,this.$$hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$572$$,$writer__42713__auto__$$,$opts__42714__auto__$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__42713__auto__$$,function($keyval__42716__auto__$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__42713__auto__$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__42714__auto__$$,$keyval__42716__auto__$$)},"#app.common.geom.point.Point{",", ","}",$opts__42714__auto__$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,this.x],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1511$y$$,this.y],null)],null),this.$$extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,2,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1511$y$$],null),$APP.$cljs$core$truth_$$(this.$$extmap$)?$APP.$cljs$core$_iterator$$(this.$$extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$=function($this$$jscomp$574$$,$key_45685$jscomp$1$$,$val_45686$jscomp$1$$){switch($key_45685$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$key_45685$jscomp$1$$.$fqn$:null){case "x":this.x=$val_45686$jscomp$1$$;break;case "y":this.y=$val_45686$jscomp$1$$;break;default:this.$$extmap$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$$extmap$,$key_45685$jscomp$1$$,$val_45686$jscomp$1$$)}return this};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this$$jscomp$575$$,$val_45686$jscomp$2$$){return new $app$common$geom$point$Point$$(this.x,this.y,$val_45686$jscomp$2$$,this.$$extmap$,this.$$hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this$$jscomp$576$$,$key_45685$jscomp$2$$){switch($key_45685$jscomp$2$$ instanceof $APP.$cljs$core$Keyword$$?$key_45685$jscomp$2$$.$fqn$:null){case "x":case "y":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$$extmap$,$key_45685$jscomp$2$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this$$jscomp$577$$,$key_45685$jscomp$3$$,$val_45686$jscomp$3$$){switch($key_45685$jscomp$3$$ instanceof $APP.$cljs$core$Keyword$$?$key_45685$jscomp$3$$.$fqn$:null){case "x":return new $app$common$geom$point$Point$$($val_45686$jscomp$3$$,this.y,this.$$meta$,this.$$extmap$,null);case "y":return new $app$common$geom$point$Point$$(this.x,$val_45686$jscomp$3$$,this.$$meta$,this.$$extmap$,null);default:return new $app$common$geom$point$Point$$(this.x,
this.y,this.$$meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$$extmap$,$key_45685$jscomp$3$$,$val_45686$jscomp$3$$),null)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($extmap1__42599__auto___this$$jscomp$578$$,$extmap2__42600__auto___key_45685$jscomp$4$$){switch($extmap2__42600__auto___key_45685$jscomp$4$$ instanceof $APP.$cljs$core$Keyword$$?$extmap2__42600__auto___key_45685$jscomp$4$$.$fqn$:null){case "x":case "y":return this.$cljs$core$IAssociative$_assoc$arity$3$(null,$extmap2__42600__auto___key_45685$jscomp$4$$,null);default:return $extmap1__42599__auto___this$$jscomp$578$$=this.$$extmap$,
$extmap2__42600__auto___key_45685$jscomp$4$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($extmap1__42599__auto___this$$jscomp$578$$,$extmap2__42600__auto___key_45685$jscomp$4$$),$extmap1__42599__auto___this$$jscomp$578$$===$extmap2__42600__auto___key_45685$jscomp$4$$?this:new $app$common$geom$point$Point$$(this.x,this.y,this.$$meta$,$APP.$cljs$core$not_empty$$($extmap2__42600__auto___key_45685$jscomp$4$$),null)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this$$jscomp$579$$,$k__42595__auto__$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__42595__auto__$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this$$jscomp$580$$,$key_45685$jscomp$5$$,$else__42596__auto__$$){switch($key_45685$jscomp$5$$ instanceof $APP.$cljs$core$Keyword$$?$key_45685$jscomp$5$$.$fqn$:null){case "x":return this.x;case "y":return this.y;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$$extmap$,$key_45685$jscomp$5$$,$else__42596__auto__$$)}};
var $app$common$geom$point$schema_COLON_point_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"PointAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1511$y$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null)],null);$app$common$schema$validator$$($app$common$geom$point$schema_COLON_point_attrs$$);
var $app$common$geom$point$valid_point_QMARK_$$=$app$common$schema$validator$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$common$geom$point$point_QMARK_$$],null),$app$common$geom$point$schema_COLON_point_attrs$$],null));
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$1518$app_DOT_common_DOT_geom_DOT_point_SLASH_point$$,$APP.$cljs$cst$351$pred$$,$app$common$geom$point$valid_point_QMARK_$$,$cljs$cst$415$type_properties$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$936$description$$,$cljs$cst$937$decode_SLASH_string$$,$APP.$cljs$cst$938$decode_SLASH_json$$,$APP.$cljs$cst$939$title$$,$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,
$cljs$cst$941$encode_SLASH_json$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,$cljs$cst$869$gen_SLASH_gen$$,$APP.$cljs$cst$882$error_SLASH_message$$,$cljs$cst$943$encode_SLASH_string$$],["Point",$app$common$geom$point$decode_point$$,$app$common$geom$point$decode_point$$,"point","point",function($p$jscomp$134$$){return $app$common$geom$point$point_QMARK_$$($p$jscomp$134$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$p$jscomp$134$$):
$p$jscomp$134$$},"string",$app$common$schema$generators$fmap$$(function($p1__45715_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$point$pos__GT_Point$$,$p1__45715_SHARP_$$)},$app$common$schema$generators$tuple$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$schema$generators$small_int$$(),$app$common$schema$generators$small_int$$()]))),"expected a valid point",function($p$jscomp$133$$){return $app$common$geom$point$point_QMARK_$$($p$jscomp$133$$)?
""+($p$jscomp$133$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$133$$,$APP.$cljs$cst$1510$x$$)??"")+","+($p$jscomp$133$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$133$$,$APP.$cljs$cst$1511$y$$)??""):$p$jscomp$133$$}])],null));
$APP.$app$common$geom$point$point$$=function $app$common$geom$point$point$$($var_args$jscomp$776$$){switch(arguments.length){case 0:return $app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$app$common$geom$point$pos__GT_Point$$(0,0)};
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$=function($v$jscomp$469$$){if($app$common$geom$point$point_QMARK_$$($v$jscomp$469$$))return $v$jscomp$469$$;if(typeof $v$jscomp$469$$==="number")return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$469$$,$v$jscomp$469$$);var $and__5023__auto__$jscomp$inline_4515_map__45718__$1$jscomp$inline_4512$$=$APP.$cljs$core$__destructure_map$$($v$jscomp$469$$),$and__5023__auto____$1$jscomp$inline_4516_x$jscomp$inline_4513$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$inline_4515_map__45718__$1$jscomp$inline_4512$$,$APP.$cljs$cst$1510$x$$);var $JSCompiler_inline_result$jscomp$651_y$jscomp$inline_4514$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$inline_4515_map__45718__$1$jscomp$inline_4512$$,$APP.$cljs$cst$1511$y$$);($and__5023__auto__$jscomp$inline_4515_map__45718__$1$jscomp$inline_4512$$=$APP.$cljs$core$map_QMARK_$$($and__5023__auto__$jscomp$inline_4515_map__45718__$1$jscomp$inline_4512$$))?
($and__5023__auto____$1$jscomp$inline_4516_x$jscomp$inline_4513$$=$APP.$app$common$math$finite_QMARK_$$($and__5023__auto____$1$jscomp$inline_4516_x$jscomp$inline_4513$$),$JSCompiler_inline_result$jscomp$651_y$jscomp$inline_4514$$=$APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$inline_4516_x$jscomp$inline_4513$$)?$APP.$app$common$math$finite_QMARK_$$($JSCompiler_inline_result$jscomp$651_y$jscomp$inline_4514$$):$and__5023__auto____$1$jscomp$inline_4516_x$jscomp$inline_4513$$):$JSCompiler_inline_result$jscomp$651_y$jscomp$inline_4514$$=
$and__5023__auto__$jscomp$inline_4515_map__45718__$1$jscomp$inline_4512$$;if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$651_y$jscomp$inline_4514$$))return $APP.$app$common$geom$point$pos__GT_Point$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$469$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$469$$));throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("invalid arguments (on pointer constructor)",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$275$hint$$,"invalid arguments (on pointer constructor)",$APP.$cljs$cst$260$value$$,$v$jscomp$469$$],null),null])),null);};$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$1042$$,$y$jscomp$308$$){return $APP.$app$common$geom$point$pos__GT_Point$$($x$jscomp$1042$$,$y$jscomp$308$$)};$APP.$app$common$geom$point$point$$.$cljs$lang$maxFixedArity$=2;
$cljs$pprint$simple_dispatch$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$app$common$geom$point$Point$$,function($obj$jscomp$155$$){return $APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$obj$jscomp$155$$]))});
$APP.$app$common$transit$add_handlers_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"point",$APP.$cljs$cst$1291$class$$,$app$common$geom$point$Point$$,$APP.$cljs$cst$1314$wfn$$,function($p1__45873_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$p1__45873_SHARP_$$)},$APP.$cljs$cst$1315$rfn$$,$app$common$geom$point$map__GT_Point$$],
null)]));$APP.$JSCompiler_prototypeAlias$$=$app$common$geom$rect$Rect$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this$$jscomp$581$$,$f__42602__auto__$jscomp$1$$,$init__42603__auto__$jscomp$1$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__42604__auto__$jscomp$1$$,$p__45940_v__42605__auto__$jscomp$1$$){var $key_45905$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45940_v__42605__auto__$jscomp$1$$,0,null);$p__45940_v__42605__auto__$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45940_v__42605__auto__$jscomp$1$$,
1,null);return $f__42602__auto__$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$?$f__42602__auto__$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$($ret__42604__auto__$jscomp$1$$,$key_45905$$,$p__45940_v__42605__auto__$jscomp$1$$):$f__42602__auto__$jscomp$1$$($ret__42604__auto__$jscomp$1$$,$key_45905$$,$p__45940_v__42605__auto__$jscomp$1$$)},$init__42603__auto__$jscomp$1$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$582$$,$other$jscomp$170$$){return this===$other$jscomp$170$$||$other$jscomp$170$$!=null&&this.constructor===$other$jscomp$170$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.x,$other$jscomp$170$$.x)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.y,$other$jscomp$170$$.y)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.width,$other$jscomp$170$$.width)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.height,
$other$jscomp$170$$.height)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.x1,$other$jscomp$170$$.x1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.y1,$other$jscomp$170$$.y1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.x2,$other$jscomp$170$$.x2)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.y2,$other$jscomp$170$$.y2)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$$extmap$,$other$jscomp$170$$.$$extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__42526__auto__$jscomp$1_h__42526__auto____$1$jscomp$1$$=this.$$hash$;return $h__42526__auto__$jscomp$1_h__42526__auto____$1$jscomp$1$$!=null?$h__42526__auto__$jscomp$1_h__42526__auto____$1$jscomp$1$$:this.$$hash$=$h__42526__auto__$jscomp$1_h__42526__auto____$1$jscomp$1$$=647966571^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this$$jscomp$584$$,$val_45906$$){return $APP.$cljs$core$vector_QMARK_$$($val_45906$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($val_45906$$,0),$APP.$cljs$core$_nth$$($val_45906$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$val_45906$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 8+$APP.$cljs$core$count$$(this.$$extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1510$x$$,this.x,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1511$y$$,this.y,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$290$width$$,this.width,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1522$height$$,
this.height,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1523$x1$$,this.x1,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1524$y1$$,this.y1,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1525$x2$$,this.x2,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1526$y2$$,this.y2,null)],null),this.$$extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$$meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $app$common$geom$rect$Rect$$(this.x,this.y,this.width,this.height,this.x1,this.y1,this.x2,this.y2,this.$$meta$,this.$$extmap$,this.$$hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$590$$,$writer__42713__auto__$jscomp$1$$,$opts__42714__auto__$jscomp$1$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__42713__auto__$jscomp$1$$,function($keyval__42716__auto__$jscomp$1$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__42713__auto__$jscomp$1$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__42714__auto__$jscomp$1$$,$keyval__42716__auto__$jscomp$1$$)},"#app.common.geom.rect.Rect{",
", ","}",$opts__42714__auto__$jscomp$1$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,this.x],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1511$y$$,this.y],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$,this.width],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1522$height$$,this.height],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1523$x1$$,this.x1],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1524$y1$$,this.y1],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1525$x2$$,this.x2],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1526$y2$$,this.y2],null)],null),this.$$extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,8,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1523$x1$$,$APP.$cljs$cst$1524$y1$$,$APP.$cljs$cst$1525$x2$$,$APP.$cljs$cst$1526$y2$$],null),$APP.$cljs$core$truth_$$(this.$$extmap$)?$APP.$cljs$core$_iterator$$(this.$$extmap$):
$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$=function($this$$jscomp$592$$,$key_45905$jscomp$1$$,$val_45906$jscomp$1$$){switch($key_45905$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$key_45905$jscomp$1$$.$fqn$:null){case "x":this.x=$val_45906$jscomp$1$$;break;case "y":this.y=$val_45906$jscomp$1$$;break;case "width":this.width=$val_45906$jscomp$1$$;break;case "height":this.height=$val_45906$jscomp$1$$;break;case "x1":this.x1=$val_45906$jscomp$1$$;break;
case "y1":this.y1=$val_45906$jscomp$1$$;break;case "x2":this.x2=$val_45906$jscomp$1$$;break;case "y2":this.y2=$val_45906$jscomp$1$$;break;default:this.$$extmap$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$$extmap$,$key_45905$jscomp$1$$,$val_45906$jscomp$1$$)}return this};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this$$jscomp$593$$,$val_45906$jscomp$2$$){return new $app$common$geom$rect$Rect$$(this.x,this.y,this.width,this.height,this.x1,this.y1,this.x2,this.y2,$val_45906$jscomp$2$$,this.$$extmap$,this.$$hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this$$jscomp$594$$,$key_45905$jscomp$2$$){switch($key_45905$jscomp$2$$ instanceof $APP.$cljs$core$Keyword$$?$key_45905$jscomp$2$$.$fqn$:null){case "x":case "y":case "width":case "height":case "x1":case "y1":case "x2":case "y2":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$$extmap$,$key_45905$jscomp$2$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this$$jscomp$595$$,$key_45905$jscomp$3$$,$val_45906$jscomp$3$$){switch($key_45905$jscomp$3$$ instanceof $APP.$cljs$core$Keyword$$?$key_45905$jscomp$3$$.$fqn$:null){case "x":return new $app$common$geom$rect$Rect$$($val_45906$jscomp$3$$,this.y,this.width,this.height,this.x1,this.y1,this.x2,this.y2,this.$$meta$,this.$$extmap$,null);case "y":return new $app$common$geom$rect$Rect$$(this.x,$val_45906$jscomp$3$$,this.width,
this.height,this.x1,this.y1,this.x2,this.y2,this.$$meta$,this.$$extmap$,null);case "width":return new $app$common$geom$rect$Rect$$(this.x,this.y,$val_45906$jscomp$3$$,this.height,this.x1,this.y1,this.x2,this.y2,this.$$meta$,this.$$extmap$,null);case "height":return new $app$common$geom$rect$Rect$$(this.x,this.y,this.width,$val_45906$jscomp$3$$,this.x1,this.y1,this.x2,this.y2,this.$$meta$,this.$$extmap$,null);case "x1":return new $app$common$geom$rect$Rect$$(this.x,this.y,this.width,this.height,$val_45906$jscomp$3$$,
this.y1,this.x2,this.y2,this.$$meta$,this.$$extmap$,null);case "y1":return new $app$common$geom$rect$Rect$$(this.x,this.y,this.width,this.height,this.x1,$val_45906$jscomp$3$$,this.x2,this.y2,this.$$meta$,this.$$extmap$,null);case "x2":return new $app$common$geom$rect$Rect$$(this.x,this.y,this.width,this.height,this.x1,this.y1,$val_45906$jscomp$3$$,this.y2,this.$$meta$,this.$$extmap$,null);case "y2":return new $app$common$geom$rect$Rect$$(this.x,this.y,this.width,this.height,this.x1,this.y1,this.x2,
$val_45906$jscomp$3$$,this.$$meta$,this.$$extmap$,null);default:return new $app$common$geom$rect$Rect$$(this.x,this.y,this.width,this.height,this.x1,this.y1,this.x2,this.y2,this.$$meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$$extmap$,$key_45905$jscomp$3$$,$val_45906$jscomp$3$$),null)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($extmap1__42599__auto__$jscomp$1_this$$jscomp$596$$,$extmap2__42600__auto__$jscomp$1_key_45905$jscomp$4$$){switch($extmap2__42600__auto__$jscomp$1_key_45905$jscomp$4$$ instanceof $APP.$cljs$core$Keyword$$?$extmap2__42600__auto__$jscomp$1_key_45905$jscomp$4$$.$fqn$:null){case "x":case "y":case "width":case "height":case "x1":case "y1":case "x2":case "y2":return this.$cljs$core$IAssociative$_assoc$arity$3$(null,$extmap2__42600__auto__$jscomp$1_key_45905$jscomp$4$$,
null);default:return $extmap1__42599__auto__$jscomp$1_this$$jscomp$596$$=this.$$extmap$,$extmap2__42600__auto__$jscomp$1_key_45905$jscomp$4$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($extmap1__42599__auto__$jscomp$1_this$$jscomp$596$$,$extmap2__42600__auto__$jscomp$1_key_45905$jscomp$4$$),$extmap1__42599__auto__$jscomp$1_this$$jscomp$596$$===$extmap2__42600__auto__$jscomp$1_key_45905$jscomp$4$$?this:new $app$common$geom$rect$Rect$$(this.x,this.y,this.width,this.height,this.x1,this.y1,
this.x2,this.y2,this.$$meta$,$APP.$cljs$core$not_empty$$($extmap2__42600__auto__$jscomp$1_key_45905$jscomp$4$$),null)}};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this$$jscomp$597$$,$k__42595__auto__$jscomp$1$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__42595__auto__$jscomp$1$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this$$jscomp$598$$,$key_45905$jscomp$5$$,$else__42596__auto__$jscomp$1$$){switch($key_45905$jscomp$5$$ instanceof $APP.$cljs$core$Keyword$$?$key_45905$jscomp$5$$.$fqn$:null){case "x":return this.x;case "y":return this.y;case "width":return this.width;case "height":return this.height;case "x1":return this.x1;case "y1":return this.y1;case "x2":return this.x2;case "y2":return this.y2;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$$extmap$,
$key_45905$jscomp$5$$,$else__42596__auto__$jscomp$1$$)}};
$APP.$app$common$transit$add_handlers_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"rect",$APP.$cljs$cst$1291$class$$,$app$common$geom$rect$Rect$$,$APP.$cljs$cst$1314$wfn$$,function($p1__46000_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$p1__46000_SHARP_$$)},$APP.$cljs$cst$1315$rfn$$,$app$common$geom$rect$map__GT_Rect$$],
null)]));
$APP.$app$common$geom$rect$make_rect$$=function $app$common$geom$rect$make_rect$$($var_args$jscomp$781$$){switch(arguments.length){case 0:return $app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 4:return $app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],
arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$(0,0,.01,.01)};
$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$1$=function($data$jscomp$117_x$jscomp$1058$$){if($app$common$geom$rect$rect_QMARK_$$($data$jscomp$117_x$jscomp$1058$$))return $data$jscomp$117_x$jscomp$1058$$;var $height$jscomp$30_map__46018__$1$$=$APP.$cljs$core$__destructure_map$$($data$jscomp$117_x$jscomp$1058$$);$data$jscomp$117_x$jscomp$1058$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$30_map__46018__$1$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$324$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$30_map__46018__$1$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$30_map__46018__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$30_map__46018__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$30_map__46018__$1$$,$APP.$cljs$cst$1522$height$$);return $APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$117_x$jscomp$1058$$,
0),$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($y$jscomp$324$$,0),$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($width$jscomp$39$$,.01),$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$30_map__46018__$1$$,.01))};
$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$2$=function($p1$jscomp$40_yp1$$,$p2$jscomp$30_yp2$$){var $xp1$$=$p1$jscomp$40_yp1$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$40_yp1$$,$APP.$cljs$cst$1510$x$$);$p1$jscomp$40_yp1$$=$p1$jscomp$40_yp1$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$40_yp1$$,$APP.$cljs$cst$1511$y$$);var $xp2$$=$p2$jscomp$30_yp2$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$30_yp2$$,
$APP.$cljs$cst$1510$x$$);$p2$jscomp$30_yp2$$=$p2$jscomp$30_yp2$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$30_yp2$$,$APP.$cljs$cst$1511$y$$);var $x1$jscomp$11$$=Math.min($xp1$$,$xp2$$),$y1$jscomp$11$$=Math.min($p1$jscomp$40_yp1$$,$p2$jscomp$30_yp2$$);return $APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($x1$jscomp$11$$,$y1$jscomp$11$$,Math.max($xp1$$,$xp2$$)-$x1$jscomp$11$$,Math.max($p1$jscomp$40_yp1$$,$p2$jscomp$30_yp2$$)-$y1$jscomp$11$$)};
$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$=function($x$jscomp$1059$$,$y$jscomp$325$$,$w$jscomp$20_width$jscomp$40$$,$h$jscomp$131_height$jscomp$31$$){return $app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$04$$($x$jscomp$1059$$,$y$jscomp$325$$,$w$jscomp$20_width$jscomp$40$$,$h$jscomp$131_height$jscomp$31$$)?($w$jscomp$20_width$jscomp$40$$=Math.max($w$jscomp$20_width$jscomp$40$$,.01),$h$jscomp$131_height$jscomp$31$$=Math.max($h$jscomp$131_height$jscomp$31$$,.01),
new $app$common$geom$rect$Rect$$($x$jscomp$1059$$,$y$jscomp$325$$,$w$jscomp$20_width$jscomp$40$$,$h$jscomp$131_height$jscomp$31$$,$x$jscomp$1059$$,$y$jscomp$325$$,$x$jscomp$1059$$+$w$jscomp$20_width$jscomp$40$$,$y$jscomp$325$$+$h$jscomp$131_height$jscomp$31$$,null,null,null)):$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$0$()};$APP.$app$common$geom$rect$make_rect$$.$cljs$lang$maxFixedArity$=4;
var $app$common$geom$rect$schema_COLON_rect_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"RectAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1511$y$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1522$height$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1523$x1$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1524$y1$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1525$x2$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1526$y2$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null)],null),$app$common$geom$rect$schema_COLON_rect$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$882$error_SLASH_message$$,"errors.invalid-rect",$cljs$cst$869$gen_SLASH_gen$$,
$app$common$schema$generators$fmap$$(function($p1__46026_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$rect$make_rect$$,$p1__46026_SHARP_$$)},$app$common$schema$generators$tuple$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$schema$generators$small_double$$(),$app$common$schema$generators$small_double$$(),$app$common$schema$generators$small_double$$(),$app$common$schema$generators$small_double$$()]))),
$APP.$cljs$cst$938$decode_SLASH_json$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$382$leave$$,function($o$jscomp$214$$){return $APP.$cljs$core$map_QMARK_$$($o$jscomp$214$$)?$app$common$geom$rect$map__GT_Rect$$($o$jscomp$214$$):$o$jscomp$214$$}],null),$cljs$cst$941$encode_SLASH_json$$,function($o$jscomp$215$$){return $app$common$geom$rect$rect_QMARK_$$($o$jscomp$215$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$o$jscomp$215$$):
$o$jscomp$215$$}],null),$app$common$geom$rect$schema_COLON_rect_attrs$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$common$geom$rect$rect_QMARK_$$],null)],null);$app$common$schema$validator$$($app$common$geom$rect$schema_COLON_rect$$);$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$1533$app_DOT_common_DOT_geom_DOT_rect_SLASH_rect$$,$app$common$geom$rect$schema_COLON_rect$$);
var $app$common$geom$rect$empty_rect$$=$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$(0,0,.01,.01),$app$common$geom$rect$xf_keep_x$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__46092_SHARP_$$){return $p1__46092_SHARP_$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__46092_SHARP_$$,$APP.$cljs$cst$1510$x$$)}),$app$common$geom$rect$xf_keep_y$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__46094_SHARP_$$){return $p1__46094_SHARP_$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__46094_SHARP_$$,$APP.$cljs$cst$1511$y$$)}),$app$common$geom$rect$xf_keep_x2$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__46096_SHARP_$$){return $p1__46096_SHARP_$$?.x2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__46096_SHARP_$$,$APP.$cljs$cst$1525$x2$$)}),$app$common$geom$rect$xf_keep_y2$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__46098_SHARP_$$){return $p1__46098_SHARP_$$?.y2??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__46098_SHARP_$$,$APP.$cljs$cst$1526$y2$$)});var $app$common$media$image_types$$;$APP.$app$common$media$font_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,["font/woff2",null,"font/ttf",null,"font/otf",null,"font/woff",null],null),null);$app$common$media$image_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,["image/gif",null,"image/png",null,"image/svg+xml",null,"image/webp",null,"image/jpeg",null],null),null);$APP.$promesa$core$then$$=function $promesa$core$then$$($var_args$jscomp$787$$){switch(arguments.length){case 2:return $promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $promesa$core$then$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$=function($p$jscomp$150$$,$f$jscomp$667$$){return $promesa$protocols$_then$$($promesa$protocols$_promise$$($p$jscomp$150$$),$f$jscomp$667$$)};$APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$3$=function($p$jscomp$151$$,$f$jscomp$668$$,$executor$jscomp$30$$){return $promesa$protocols$_then$$($promesa$protocols$_promise$$($p$jscomp$151$$),$f$jscomp$668$$,$executor$jscomp$30$$)};$APP.$promesa$core$then$$.$cljs$lang$maxFixedArity$=3;
var $promesa$core$delay$$=function $promesa$core$delay$$($var_args$jscomp$811$$){switch(arguments.length){case 1:return $promesa$core$delay$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $promesa$core$delay$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $promesa$core$delay$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$promesa$core$delay$$.$cljs$core$IFn$_invoke$arity$1$=function($t$jscomp$63$$){return $promesa$core$delay$$.$cljs$core$IFn$_invoke$arity$3$($t$jscomp$63$$,null,$APP.$cljs$cst$205$default$$)};$promesa$core$delay$$.$cljs$core$IFn$_invoke$arity$2$=function($t$jscomp$64$$,$v$jscomp$485$$){return $promesa$core$delay$$.$cljs$core$IFn$_invoke$arity$3$($t$jscomp$64$$,$v$jscomp$485$$,$APP.$cljs$cst$205$default$$)};
$promesa$core$delay$$.$cljs$core$IFn$_invoke$arity$3$=function($t$jscomp$65$$,$v$jscomp$486$$,$scheduler$jscomp$5$$){var $d$jscomp$202$$=new $APP.$$jscomp$scope$84173391$14$PromiseImpl$$;$promesa$exec$schedule_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($scheduler$jscomp$5$$,$t$jscomp$65$$,function(){return $APP.$promesa$protocols$_resolve_BANG_$$($d$jscomp$202$$,$v$jscomp$486$$)});return $d$jscomp$202$$};$promesa$core$delay$$.$cljs$lang$maxFixedArity$=3;$APP.$app$common$logging$loggers$$.set("app.util.webapi",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));var $app$util$webapi$webkit_datauri_fix_re$$=/^(data:image\/\w+)(,\s*image\/\w+)?(;base64.*)$/;$APP.$JSCompiler_prototypeAlias$$=$okulary$core$Atom$$.prototype;$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$172$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$172$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($o$jscomp$219$$,$other$jscomp$173$$){return this===$other$jscomp$173$$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDeref$_deref$arity$1$=function(){return this.state};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReset$_reset_BANG_$arity$2$=function($oldval$jscomp$6_self$jscomp$44$$,$newval$jscomp$7$$){$oldval$jscomp$6_self$jscomp$44$$=this.state;this.state=$newval$jscomp$7$$;this.$watches$.size>0&&this.$cljs$core$IWatchable$_notify_watches$arity$3$(null,$oldval$jscomp$6_self$jscomp$44$$,$newval$jscomp$7$$);return $newval$jscomp$7$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$2$=function($self$jscomp$45$$,$f$jscomp$710$$){return this.$cljs$core$IReset$_reset_BANG_$arity$2$(null,$f$jscomp$710$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$710$$.$cljs$core$IFn$_invoke$arity$1$(this.state):$f$jscomp$710$$(this.state))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$3$=function($self$jscomp$46$$,$f$jscomp$711$$,$x$jscomp$1067$$){return this.$cljs$core$IReset$_reset_BANG_$arity$2$(null,$f$jscomp$711$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$711$$.$cljs$core$IFn$_invoke$arity$2$(this.state,$x$jscomp$1067$$):$f$jscomp$711$$(this.state,$x$jscomp$1067$$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$4$=function($self$jscomp$47$$,$f$jscomp$712$$,$x$jscomp$1068$$,$y$jscomp$333$$){return this.$cljs$core$IReset$_reset_BANG_$arity$2$(null,$f$jscomp$712$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$712$$.$cljs$core$IFn$_invoke$arity$3$(this.state,$x$jscomp$1068$$,$y$jscomp$333$$):$f$jscomp$712$$(this.state,$x$jscomp$1068$$,$y$jscomp$333$$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$5$=function($self$jscomp$48$$,$f$jscomp$713$$,$x$jscomp$1069$$,$y$jscomp$334$$,$more$jscomp$46$$){return this.$cljs$core$IReset$_reset_BANG_$arity$2$(null,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($f$jscomp$713$$,this.state,$x$jscomp$1069$$,$y$jscomp$334$$,$more$jscomp$46$$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWatchable$_notify_watches$arity$3$=function($self$jscomp$49$$,$oldval$jscomp$7$$,$newval$jscomp$8$$){var $self__$1$jscomp$20$$=this;return $okulary$util$doiter$$(this.$watches$.entries(),function($k$jscomp$571_n$jscomp$271$$){var $f$jscomp$714$$=$k$jscomp$571_n$jscomp$271$$[1];$k$jscomp$571_n$jscomp$271$$=$k$jscomp$571_n$jscomp$271$$[0];return $f$jscomp$714$$.$cljs$core$IFn$_invoke$arity$4$?$f$jscomp$714$$.$cljs$core$IFn$_invoke$arity$4$($k$jscomp$571_n$jscomp$271$$,
$self__$1$jscomp$20$$,$oldval$jscomp$7$$,$newval$jscomp$8$$):$f$jscomp$714$$($k$jscomp$571_n$jscomp$271$$,$self__$1$jscomp$20$$,$oldval$jscomp$7$$,$newval$jscomp$8$$)})};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWatchable$_add_watch$arity$3$=function($self$jscomp$50$$,$key$jscomp$276$$,$f$jscomp$715$$){this.$watches$.set($key$jscomp$276$$,$f$jscomp$715$$);return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWatchable$_remove_watch$arity$2$=function($self$jscomp$51$$,$key$jscomp$277$$){return this.$watches$.delete($key$jscomp$277$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $goog$getUid$$(this)};var $okulary$core$EMPTY$$=Symbol("empty");
$okulary$core$DerivedAtom$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){var $source__$1$$=$APP.$cljs$core$_deref$$(this.source);if(this.$srccache$===$source__$1$$&&this.cache!==$okulary$core$EMPTY$$)return this.cache;var $result$jscomp$139_selector_fn$$=this.$selector$;$result$jscomp$139_selector_fn$$=$result$jscomp$139_selector_fn$$.$cljs$core$IFn$_invoke$arity$1$?$result$jscomp$139_selector_fn$$.$cljs$core$IFn$_invoke$arity$1$($source__$1$$):$result$jscomp$139_selector_fn$$($source__$1$$);
this.$srccache$=$source__$1$$;return this.cache=$result$jscomp$139_selector_fn$$};
$okulary$core$DerivedAtom$$.prototype.$cljs$core$IWatchable$_add_watch$arity$3$=function($self$jscomp$54$$,$key$jscomp$278$$,$cb$jscomp$7$$){var $self__$jscomp$2641$$=this,$self__$1$jscomp$25$$=this;$self__$jscomp$2641$$.$watches$.set($key$jscomp$278$$,$cb$jscomp$7$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$2641$$.$watches$.size,1)&&$APP.$cljs$core$add_watch$$($self__$jscomp$2641$$.source,$self__$jscomp$2641$$.id,function($_$jscomp$1028_equals_fn$$,$___$1$jscomp$663_selector_fn$jscomp$1$$,
$old_source_value$$,$new_source_value$$){if($old_source_value$$===$new_source_value$$)return null;$_$jscomp$1028_equals_fn$$=$self__$jscomp$2641$$.$equals_QMARK_$;$___$1$jscomp$663_selector_fn$jscomp$1$$=$self__$jscomp$2641$$.$selector$;var $new_value$jscomp$6$$=$___$1$jscomp$663_selector_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$___$1$jscomp$663_selector_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($new_source_value$$):$___$1$jscomp$663_selector_fn$jscomp$1$$($new_source_value$$),$old_value$jscomp$2$$=
$___$1$jscomp$663_selector_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$___$1$jscomp$663_selector_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($old_source_value$$):$___$1$jscomp$663_selector_fn$jscomp$1$$($old_source_value$$);$self__$jscomp$2641$$.$srccache$=$new_source_value$$;$self__$jscomp$2641$$.cache=$new_value$jscomp$6$$;return($_$jscomp$1028_equals_fn$$.$cljs$core$IFn$_invoke$arity$2$?$_$jscomp$1028_equals_fn$$.$cljs$core$IFn$_invoke$arity$2$($new_value$jscomp$6$$,$old_value$jscomp$2$$):
$_$jscomp$1028_equals_fn$$($new_value$jscomp$6$$,$old_value$jscomp$2$$))?null:$okulary$util$doiter$$($self__$jscomp$2641$$.$watches$.entries(),function($k$jscomp$572_n$jscomp$272$$){var $f$jscomp$716$$=$k$jscomp$572_n$jscomp$272$$[1];$k$jscomp$572_n$jscomp$272$$=$k$jscomp$572_n$jscomp$272$$[0];return $f$jscomp$716$$.$cljs$core$IFn$_invoke$arity$4$?$f$jscomp$716$$.$cljs$core$IFn$_invoke$arity$4$($k$jscomp$572_n$jscomp$272$$,$self__$1$jscomp$25$$,$old_value$jscomp$2$$,$new_value$jscomp$6$$):$f$jscomp$716$$($k$jscomp$572_n$jscomp$272$$,
$self__$1$jscomp$25$$,$old_value$jscomp$2$$,$new_value$jscomp$6$$)})});return $self__$1$jscomp$25$$};$okulary$core$DerivedAtom$$.prototype.$cljs$core$IWatchable$_remove_watch$arity$2$=function($self$jscomp$55$$,$key$jscomp$279$$){this.$watches$.delete($key$jscomp$279$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$watches$.size,0)&&$APP.$cljs$core$remove_watch$$(this.source,this.id);return this};$APP.$potok$v2$core$DataEvent$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$potok$v2$core$DataEvent$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return this.t};$APP.$potok$v2$core$DataEvent$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.o};
$APP.$potok$v2$core$data_event$$=function $potok$v2$core$data_event$$($var_args$jscomp$821$$){switch(arguments.length){case 1:return $potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$=function($t$jscomp$70$$){return new $APP.$potok$v2$core$DataEvent$$($t$jscomp$70$$,null)};$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$=function($t$jscomp$71$$,$o$jscomp$223$$){return new $APP.$potok$v2$core$DataEvent$$($t$jscomp$71$$,$o$jscomp$223$$)};$APP.$potok$v2$core$data_event$$.$cljs$lang$maxFixedArity$=2;
var $potok$v2$core$resolve$$=function(){var $method_table__5622__auto__$jscomp$6$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$6$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$6$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$6$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("potok.v2.core",
"resolve"),function($type$jscomp$257$$){return $type$jscomp$257$$},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$6$$,$method_table__5622__auto__$jscomp$6$$,$prefer_table__5623__auto__$jscomp$6$$,$method_cache__5624__auto__$jscomp$6$$,$cached_hierarchy__5625__auto__$jscomp$6$$)}();
$potok$v2$core$resolve$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function($type$jscomp$258$$,$params$jscomp$86$$){return $APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$258$$,$params$jscomp$86$$)});$potok$v2$core$UpdateEvent$$["function"]=!0;
$potok$v2$core$update$$["function"]=function($func$jscomp$23$$,$state$jscomp$42$$){return $func$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$?$func$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$42$$):$func$jscomp$23$$($state$jscomp$42$$)};
var $potok$v2$core$handle_error$$,$method_table__5622__auto__$jscomp$inline_11813$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$inline_11814$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$inline_11815$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$inline_11816$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$inline_11817$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());
$potok$v2$core$handle_error$$=new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("potok.v2.core","handle-error"),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$inline_11817$$,$method_table__5622__auto__$jscomp$inline_11813$$,$prefer_table__5623__auto__$jscomp$inline_11814$$,$method_cache__5624__auto__$jscomp$inline_11815$$,$cached_hierarchy__5625__auto__$jscomp$inline_11816$$);
$potok$v2$core$handle_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function($error$jscomp$35$$){console.warn("Using default error handler, consider using your own!");return console.error($error$jscomp$35$$)});
var $potok$v2$core$emit_BANG_$$=function $potok$v2$core$emit_BANG_$$($var_args$jscomp$824$$){switch(arguments.length){case 2:return $potok$v2$core$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$93$$=[],$len__5749__auto___44140$$=arguments.length,$i__5750__auto___44141$$=0;;)if($i__5750__auto___44141$$<$len__5749__auto___44140$$)$args_arr__5774__auto__$jscomp$93$$.push(arguments[$i__5750__auto___44141$$]),$i__5750__auto___44141$$+=
1;else break;return $potok$v2$core$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$93$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$93$$.slice(2),0,null):null)}};$potok$v2$core$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$2$=function($store$$,$event$jscomp$18$$){return $store$$.next($event$jscomp$18$$)};
$potok$v2$core$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($store$jscomp$1$$,$event$jscomp$19$$,$more$jscomp$47$$){return $APP.$cljs$core$run_BANG_$$(function($p1__43953_SHARP_$$){return $store$jscomp$1$$.next($p1__43953_SHARP_$$)},$APP.$cljs$core$cons$$($event$jscomp$19$$,$more$jscomp$47$$))};
$potok$v2$core$emit_BANG_$$.$cljs$lang$applyTo$=function($G__43961_seq43959$$){var $G__43960$$=$APP.$cljs$core$first$$($G__43961_seq43959$$),$seq43959__$1_seq43959__$2$$=$APP.$cljs$core$next$$($G__43961_seq43959$$);$G__43961_seq43959$$=$APP.$cljs$core$first$$($seq43959__$1_seq43959__$2$$);$seq43959__$1_seq43959__$2$$=$APP.$cljs$core$next$$($seq43959__$1_seq43959__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__43960$$,$G__43961_seq43959$$,$seq43959__$1_seq43959__$2$$)};
$potok$v2$core$emit_BANG_$$.$cljs$lang$maxFixedArity$=2;var $goog$Disposable$MonitoringMode$OFF$$=0,$goog$Disposable$instances_$$={};$goog$Disposable$$.prototype.$disposed_$=!1;$goog$Disposable$$.prototype.$isDisposed$=function(){return this.$disposed_$};
$goog$Disposable$$.prototype.dispose=function(){if(!this.$disposed_$&&(this.$disposed_$=!0,this.$disposeInternal$(),0!=$goog$Disposable$MonitoringMode$OFF$$)){var $uid$jscomp$1$$=$goog$getUid$$(this);if(0!=$goog$Disposable$MonitoringMode$OFF$$&&this.$onDisposeCallbacks_$&&this.$onDisposeCallbacks_$.length>0)throw Error(this+" did not empty its onDisposeCallbacks queue. This probably means it overrode dispose() or disposeInternal() without calling the superclass' method.");delete $goog$Disposable$instances_$$[$uid$jscomp$1$$]}};
$goog$Disposable$$.prototype.$disposeInternal$=function(){if(this.$onDisposeCallbacks_$)for(;this.$onDisposeCallbacks_$.length;)this.$onDisposeCallbacks_$.shift()()};$goog$events$EventId$$.prototype.toString=function(){return this.id};$APP.$goog$events$Event$$.prototype.stopPropagation=function(){this.$propagationStopped_$=!0};$APP.$goog$events$Event$$.prototype.preventDefault=function(){this.defaultPrevented=!0};var $goog$events$BrowserFeature$PASSIVE_EVENTS$$=function(){if(!$APP.$goog$global$$.addEventListener||!Object.defineProperty)return!1;var $passive$$=!1,$options$jscomp$417$$=Object.defineProperty({},"passive",{get:function(){$passive$$=!0}});try{const $nullFunction$$=()=>{};$APP.$goog$global$$.addEventListener("test",$nullFunction$$,$options$jscomp$417$$);$APP.$goog$global$$.removeEventListener("test",$nullFunction$$,$options$jscomp$417$$)}catch($e$jscomp$239$$){}return $passive$$}();$APP.$goog$inherits$$($APP.$goog$events$BrowserEvent$$,$APP.$goog$events$Event$$);var $goog$events$BrowserEvent$IE_POINTER_TYPE_MAP$$={2:"touch",3:"pen",4:"mouse"};
$APP.$goog$events$BrowserEvent$$.prototype.init=function($e$jscomp$240$$,$opt_currentTarget$jscomp$1_relatedTarget$$){var $type$jscomp$262$$=this.type=$e$jscomp$240$$.type,$relevantTouch$$=$e$jscomp$240$$.changedTouches&&$e$jscomp$240$$.changedTouches.length?$e$jscomp$240$$.changedTouches[0]:null;this.target=$e$jscomp$240$$.target||$e$jscomp$240$$.srcElement;this.currentTarget=$opt_currentTarget$jscomp$1_relatedTarget$$;if($opt_currentTarget$jscomp$1_relatedTarget$$=$e$jscomp$240$$.relatedTarget){if($goog$userAgent$GECKO$$){a:{try{$goog$reflect$sinkValue$$($opt_currentTarget$jscomp$1_relatedTarget$$.nodeName);
var $JSCompiler_inline_result$jscomp$57$$=!0;break a}catch($e$jscomp$inline_4556$$){}$JSCompiler_inline_result$jscomp$57$$=!1}$JSCompiler_inline_result$jscomp$57$$||($opt_currentTarget$jscomp$1_relatedTarget$$=null)}}else $type$jscomp$262$$=="mouseover"?$opt_currentTarget$jscomp$1_relatedTarget$$=$e$jscomp$240$$.fromElement:$type$jscomp$262$$=="mouseout"&&($opt_currentTarget$jscomp$1_relatedTarget$$=$e$jscomp$240$$.toElement);this.relatedTarget=$opt_currentTarget$jscomp$1_relatedTarget$$;$relevantTouch$$?
(this.clientX=$relevantTouch$$.clientX!==void 0?$relevantTouch$$.clientX:$relevantTouch$$.pageX,this.clientY=$relevantTouch$$.clientY!==void 0?$relevantTouch$$.clientY:$relevantTouch$$.pageY,this.screenX=$relevantTouch$$.screenX||0,this.screenY=$relevantTouch$$.screenY||0):(this.offsetX=$goog$userAgent$WEBKIT$$||$e$jscomp$240$$.offsetX!==void 0?$e$jscomp$240$$.offsetX:$e$jscomp$240$$.layerX,this.offsetY=$goog$userAgent$WEBKIT$$||$e$jscomp$240$$.offsetY!==void 0?$e$jscomp$240$$.offsetY:$e$jscomp$240$$.layerY,
this.clientX=$e$jscomp$240$$.clientX!==void 0?$e$jscomp$240$$.clientX:$e$jscomp$240$$.pageX,this.clientY=$e$jscomp$240$$.clientY!==void 0?$e$jscomp$240$$.clientY:$e$jscomp$240$$.pageY,this.screenX=$e$jscomp$240$$.screenX||0,this.screenY=$e$jscomp$240$$.screenY||0);this.button=$e$jscomp$240$$.button;this.keyCode=$e$jscomp$240$$.keyCode||0;this.key=$e$jscomp$240$$.key||"";this.charCode=$e$jscomp$240$$.charCode||($type$jscomp$262$$=="keypress"?$e$jscomp$240$$.keyCode:0);this.ctrlKey=$e$jscomp$240$$.ctrlKey;
this.altKey=$e$jscomp$240$$.altKey;this.shiftKey=$e$jscomp$240$$.shiftKey;this.metaKey=$e$jscomp$240$$.metaKey;this.pointerId=$e$jscomp$240$$.pointerId||0;this.pointerType=typeof $e$jscomp$240$$.pointerType==="string"?$e$jscomp$240$$.pointerType:$goog$events$BrowserEvent$IE_POINTER_TYPE_MAP$$[$e$jscomp$240$$.pointerType]||"";this.state=$e$jscomp$240$$.state;this.$event_$=$e$jscomp$240$$;$e$jscomp$240$$.defaultPrevented&&$APP.$goog$events$BrowserEvent$$.$superClass_$.preventDefault.call(this)};
$APP.$goog$events$BrowserEvent$$.prototype.stopPropagation=function(){$APP.$goog$events$BrowserEvent$$.$superClass_$.stopPropagation.call(this);this.$event_$.stopPropagation?this.$event_$.stopPropagation():this.$event_$.cancelBubble=!0};
$APP.$goog$events$BrowserEvent$$.prototype.preventDefault=function(){$APP.$goog$events$BrowserEvent$$.$superClass_$.preventDefault.call(this);var $be$jscomp$1$$=this.$event_$;$be$jscomp$1$$.preventDefault?$be$jscomp$1$$.preventDefault():$be$jscomp$1$$.returnValue=!1};$APP.$goog$events$BrowserEvent$$.prototype.getBrowserEvent=function(){return this.$event_$};var $app$util$dom$focus_element_46800$$;$APP.$goog$events$BrowserEvent$$.prototype.$cljs$core$IDeref$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$goog$events$BrowserEvent$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.getBrowserEvent()};$APP.$app$common$logging$loggers$$.set("app.util.dom",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));
$APP.$app$util$dom$get_target_val$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_value$$,$APP.$app$util$dom$get_target$$);
$APP.$app$util$dom$get_target_scroll$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$(function($event$jscomp$28$$){return $event$jscomp$28$$!=null?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1558$scroll_height$$,$event$jscomp$28$$.scrollHeight,$APP.$cljs$cst$1559$scroll_left$$,$event$jscomp$28$$.scrollLeft,$cljs$cst$1560$scroll_top$$,$event$jscomp$28$$.scrollTop,$APP.$cljs$cst$1561$scroll_width$$,$event$jscomp$28$$.scrollWidth],null):null},$APP.$app$util$dom$get_target$$);
$APP.$app$util$dom$fullscreen_events$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["fullscreenchange","mozfullscreenchange","MSFullscreenChange","webkitfullscreenchange"],null);
$APP.$app$util$dom$reload_current_window$$=function $app$util$dom$reload_current_window$$($var_args$jscomp$840$$){switch(arguments.length){case 0:return $app$util$dom$reload_current_window$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $app$util$dom$reload_current_window$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$util$dom$reload_current_window$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$app$util$globals$location$$.reload()};$APP.$app$util$dom$reload_current_window$$.$cljs$core$IFn$_invoke$arity$1$=function($force_QMARK_$$){return $APP.$app$util$globals$location$$.reload($force_QMARK_$$)};$APP.$app$util$dom$reload_current_window$$.$cljs$lang$maxFixedArity$=1;
$potok$v2$core$resolve$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$1567$app_DOT_util_DOT_dom_SLASH_focus_element$$,function($_$jscomp$1041$$,$p__46797$$){var $map__46798__$1$$=$APP.$cljs$core$__destructure_map$$($p__46797$$),$name$jscomp$161$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__46798__$1$$,$APP.$cljs$cst$725$name$$);typeof $app$util$dom$focus_element_46800$$==="undefined"&&($app$util$dom$focus_element_46800$$=function($_$jscomp$1042$$,$p__46797$jscomp$1$$,$map__46798$jscomp$1$$,
$name$jscomp$162$$,$meta46801$$){this.$_$=$_$jscomp$1042$$;this.$p__46797$=$p__46797$jscomp$1$$;this.$map__46798$=$map__46798$jscomp$1$$;this.name=$name$jscomp$162$$;this.$meta46801$=$meta46801$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$util$dom$focus_element_46800$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$util$dom$focus_element_46800$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$1567$app_DOT_util_DOT_dom_SLASH_focus_element$$},
$app$util$dom$focus_element_46800$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_46802$$,$meta46801__$1$$){return new $app$util$dom$focus_element_46800$$(this.$_$,this.$p__46797$,this.$map__46798$,this.name,$meta46801__$1$$)},$app$util$dom$focus_element_46800$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta46801$},$app$util$dom$focus_element_46800$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$util$dom$focus_element_46800$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=
function(){return $APP.$app$util$dom$focus_BANG_$$($APP.$goog$dom$getElement$$(this.name))});return new $app$util$dom$focus_element_46800$$($_$jscomp$1041$$,$p__46797$$,$map__46798__$1$$,$name$jscomp$161$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)});var $app$util$cache$cache$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$app$util$cache$pending$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $shadow$js$shim$module$0react$$=shadow$bridge("react");shadow$bridge("tdigest");var $shadow$js$shim$module$0react_dom$$=shadow$bridge("react-dom");var $shadow$js$shim$module$0react_dom$0client$$=shadow$bridge("react-dom/client");var $shadow$js$shim$module$0react$0jsx_runtime$$=shadow$bridge("react/jsx-runtime");$goog$module$$=$goog$module$$||{};$APP.$goog$inherits$$($goog$module$BaseModule$$,$goog$Disposable$$);$goog$module$BaseModule$$.prototype.initialize=function(){};$goog$module$ModuleLoadCallback$$.prototype.$execute$=function($context$jscomp$20$$){this.$fn_$&&(this.$fn_$.call(this.$handler_$||null,$context$jscomp$20$$),this.$fn_$=this.$handler_$=null)};$goog$module$ModuleLoadCallback$$.prototype.abort=function(){this.$handler_$=this.$fn_$=null};$APP.$goog$inherits$$($goog$module$ModuleInfo$$,$goog$Disposable$$);$APP.$JSCompiler_prototypeAlias$$=$goog$module$ModuleInfo$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$uris_$=null;$APP.$JSCompiler_prototypeAlias$$.$moduleConstructor_$=$goog$module$BaseModule$$;$APP.$JSCompiler_prototypeAlias$$.$module_$=null;$APP.$JSCompiler_prototypeAlias$$.$getUris$=function(){this.$uris_$||(this.$uris_$=[]);return this.$uris_$};
$APP.$JSCompiler_prototypeAlias$$.$registerCallback$=function($fn$jscomp$30$$,$opt_handler$jscomp$2$$){this.$registerCallback_$(this.$onloadCallbacks_$,$fn$jscomp$30$$,$opt_handler$jscomp$2$$)};$APP.$JSCompiler_prototypeAlias$$.$registerCallback_$=function($callbacks$jscomp$1$$,$fn$jscomp$32$$,$opt_handler$jscomp$4$$){$callbacks$jscomp$1$$.push(new $goog$module$ModuleLoadCallback$$($fn$jscomp$32$$,$opt_handler$jscomp$4$$))};$APP.$JSCompiler_prototypeAlias$$.isLoaded=function(){return!!this.$module_$};
$APP.$JSCompiler_prototypeAlias$$.$onLoad$=function($contextProvider$$){var $errors$jscomp$12_module$jscomp$3$$=new this.$moduleConstructor_$;$errors$jscomp$12_module$jscomp$3$$.initialize($contextProvider$$());this.$module_$=$errors$jscomp$12_module$jscomp$3$$;$errors$jscomp$12_module$jscomp$3$$=($errors$jscomp$12_module$jscomp$3$$=!!$JSCompiler_StaticMethods_callCallbacks_$$(this.$earlyOnloadCallbacks_$,$contextProvider$$()))||!!$JSCompiler_StaticMethods_callCallbacks_$$(this.$onloadCallbacks_$,
$contextProvider$$());$errors$jscomp$12_module$jscomp$3$$||(this.$onErrorCallbacks_$.length=0);return $errors$jscomp$12_module$jscomp$3$$};
$APP.$JSCompiler_prototypeAlias$$.$onError$=function($cause$jscomp$27_result$jscomp$143$$){($cause$jscomp$27_result$jscomp$143$$=$JSCompiler_StaticMethods_callCallbacks_$$(this.$onErrorCallbacks_$,$cause$jscomp$27_result$jscomp$143$$))&&$APP.$goog$global$$.setTimeout($goog$functions$error$$("Module errback failures: "+$cause$jscomp$27_result$jscomp$143$$),0);this.$earlyOnloadCallbacks_$.length=0;this.$onloadCallbacks_$.length=0};
$APP.$JSCompiler_prototypeAlias$$.$disposeInternal$=function(){$goog$module$ModuleInfo$$.$superClass_$.$disposeInternal$.call(this);$module$contents$goog$dispose_dispose$$(this.$module_$)};$goog$loader$AbstractModuleManager$$.prototype.isActive=function(){return!1};$goog$loader$AbstractModuleManager$$.prototype.$isUserActive$=function(){return!1};$goog$loader$AbstractModuleManager$$.prototype.$registerCallback$=function(){};var $module$contents$goog$loader$activeModuleManager_moduleManager$$=null,$module$contents$goog$loader$activeModuleManager_getDefault$$=null,$module$contents$goog$loader$activeModuleManager_configureFunctions$$=[];var $goog$log$log$classdecl$var0$$=class{constructor($name$jscomp$163$$,$value$jscomp$375$$){this.name=$name$jscomp$163$$;this.value=$value$jscomp$375$$}toString(){return this.name}},$goog$log$log$classdecl$var0$OFF$$=new $goog$log$log$classdecl$var0$$("OFF",Infinity),$goog$log$log$classdecl$var0$SEVERE$$=new $goog$log$log$classdecl$var0$$("SEVERE",1E3),$goog$log$log$classdecl$var0$WARNING$$=new $goog$log$log$classdecl$var0$$("WARNING",900),$goog$log$log$classdecl$var0$INFO$$=new $goog$log$log$classdecl$var0$$("INFO",
800),$goog$log$log$classdecl$var0$CONFIG$$=new $goog$log$log$classdecl$var0$$("CONFIG",700),$goog$log$log$classdecl$var0$FINE$$=new $goog$log$log$classdecl$var0$$("FINE",500),$goog$log$log$classdecl$var2$$=class{constructor(){this.$capacity_$=0;this.clear()}clear(){this.$buffer_$=Array(this.$capacity_$);this.$curIndex_$=-1;this.$isFull_$=!1}},$goog$log$log$classdecl$var2$instance_$$,$goog$log$log$classdecl$var3$$=class{constructor($level$jscomp$43$$,$msg$jscomp$10$$,$loggerName$jscomp$1$$){this.reset($level$jscomp$43$$||
$goog$log$log$classdecl$var0$OFF$$,$msg$jscomp$10$$,$loggerName$jscomp$1$$,void 0,void 0)}reset($level$jscomp$44$$,$msg$jscomp$11$$,$loggerName$jscomp$2$$,$time$jscomp$1$$){$time$jscomp$1$$||Date.now()}},$goog$log$log$classdecl$var4$$=class{constructor($name$jscomp$166$$,$parent$jscomp$127$$=null){this.level=null;this.$handlers$=[];this.parent=$parent$jscomp$127$$||null;this.children=[];this.$logger$={$getName$:()=>$name$jscomp$166$$}}publish($logRecord$$){let $target$jscomp$114$$=this;for(;$target$jscomp$114$$;)$target$jscomp$114$$.$handlers$.forEach($handler$jscomp$20$$=>
{$handler$jscomp$20$$($logRecord$$)}),$target$jscomp$114$$=$target$jscomp$114$$.parent}},$goog$log$log$classdecl$var5$$=class{constructor(){this.entries={};const $rootLogRegistryEntry$$=new $goog$log$log$classdecl$var4$$("");$rootLogRegistryEntry$$.level=$goog$log$log$classdecl$var0$CONFIG$$;this.entries[""]=$rootLogRegistryEntry$$}},$goog$log$log$classdecl$var5$instance_$$;var $module$contents$goog$module$ModuleLoadFailure_ModuleLoadFailure$$=class{constructor($type$jscomp$266$$,$status$jscomp$1$$){this.type=$type$jscomp$266$$;this.status=$status$jscomp$1$$}toString(){return`${$JSCompiler_StaticMethods_getReadableError_$$(this)} (${this.status!=void 0?this.status:"?"})`}};$goog$module$$.$ModuleLoadFailure$=$module$contents$goog$module$ModuleLoadFailure_ModuleLoadFailure$$;
$goog$module$$.$ModuleLoadFailure$.$Type$={$UNAUTHORIZED$:0,$CONSECUTIVE_FAILURES$:1,TIMEOUT:2,$OLD_CODE_GONE$:3,$INIT_ERROR$:4};$APP.$goog$inherits$$($goog$module$ModuleManager$$,$goog$loader$AbstractModuleManager$$);$APP.$goog$inherits$$($goog$module$ModuleManager$ModuleFailureError$$,$module$contents$goog$debug$Error_DebugError$$);$APP.$JSCompiler_prototypeAlias$$=$goog$module$ModuleManager$$.prototype;$APP.$JSCompiler_prototypeAlias$$.isActive=function(){return this.$loadingModuleIds_$.length>0};$APP.$JSCompiler_prototypeAlias$$.$isUserActive$=function(){return this.$userInitiatedLoadingModuleIds_$.length>0};
$APP.$JSCompiler_prototypeAlias$$.$loadModules_$=function($ids$jscomp$3_loadFn$$,$delay$jscomp$4_opt_isRetry$$,$opt_forceReload$$){$delay$jscomp$4_opt_isRetry$$||(this.$consecutiveFailures_$=0);var $idsToLoadImmediately$$=$JSCompiler_StaticMethods_processModulesForLoad_$$(this,$ids$jscomp$3_loadFn$$);$goog$log$fine$$(this.$logger_$,"Loading module(s): "+$idsToLoadImmediately$$);this.$concurrentLoadingEnabled_$?$module$contents$goog$array_extend$$(this.$loadingModuleIds_$,$idsToLoadImmediately$$):
this.$loadingModuleIds_$=$idsToLoadImmediately$$;this.$requestedLoadingModuleIds_$=this.$batchModeEnabled_$?$ids$jscomp$3_loadFn$$:$module$contents$goog$array_toArray$$($idsToLoadImmediately$$);$JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$$(this);if($idsToLoadImmediately$$.length!==0){this.$requestedModuleIds_$.push.apply(this.$requestedModuleIds_$,$idsToLoadImmediately$$);if(Object.keys(this.$extraEdges_$).length>0&&!this.$loader_$.$supportsExtraEdges$)throw Error("Extra edges are not supported by the module loader.");
$ids$jscomp$3_loadFn$$=$goog$bind$$(this.$loader_$.$loadModules$,this.$loader_$,$module$contents$goog$array_toArray$$($idsToLoadImmediately$$),this.$moduleInfoMap$,{$extraEdges$:this.$extraEdges_$,$forceReload$:!!$opt_forceReload$$,$onError$:$status$jscomp$2_status$jscomp$inline_4575$$=>{var $requestedLoadingModuleIds$jscomp$inline_4573$$=this.$requestedLoadingModuleIds_$;$status$jscomp$2_status$jscomp$inline_4575$$=$status$jscomp$2_status$jscomp$inline_4575$$!=null?$status$jscomp$2_status$jscomp$inline_4575$$:
void 0;this.$consecutiveFailures_$++;this.$requestedLoadingModuleIds_$=$requestedLoadingModuleIds$jscomp$inline_4573$$;$idsToLoadImmediately$$.forEach($APP.$goog$partial$$($module$contents$goog$array_remove$$,this.$requestedModuleIds_$),this);$status$jscomp$2_status$jscomp$inline_4575$$==401?($goog$log$info$$(this.$logger_$,"Module loading unauthorized"),$JSCompiler_StaticMethods_dispatchModuleLoadFailed_$$(this,new $goog$module$$.$ModuleLoadFailure$($goog$module$$.$ModuleLoadFailure$.$Type$.$UNAUTHORIZED$,
$status$jscomp$2_status$jscomp$inline_4575$$)),this.$requestedModuleIdsQueue_$.length=0):$status$jscomp$2_status$jscomp$inline_4575$$==410?($JSCompiler_StaticMethods_requeueBatchOrDispatchFailure_$$(this,new $goog$module$$.$ModuleLoadFailure$($goog$module$$.$ModuleLoadFailure$.$Type$.$OLD_CODE_GONE$,$status$jscomp$2_status$jscomp$inline_4575$$)),$JSCompiler_StaticMethods_loadNextModules_$$(this)):this.$consecutiveFailures_$>=3?($goog$log$info$$(this.$logger_$,"Aborting after failure to load: "+this.$loadingModuleIds_$),
$JSCompiler_StaticMethods_requeueBatchOrDispatchFailure_$$(this,new $goog$module$$.$ModuleLoadFailure$($goog$module$$.$ModuleLoadFailure$.$Type$.$CONSECUTIVE_FAILURES$,$status$jscomp$2_status$jscomp$inline_4575$$)),$JSCompiler_StaticMethods_loadNextModules_$$(this)):($goog$log$info$$(this.$logger_$,"Retrying after failure to load: "+this.$loadingModuleIds_$),this.$loadModules_$(this.$requestedLoadingModuleIds_$,!0,$status$jscomp$2_status$jscomp$inline_4575$$==8001))},$onTimeout$:$goog$bind$$(this.$handleLoadTimeout_$,
this)});($delay$jscomp$4_opt_isRetry$$=Math.pow(this.$consecutiveFailures_$,2)*5E3)?$APP.$goog$global$$.setTimeout($ids$jscomp$3_loadFn$$,$delay$jscomp$4_opt_isRetry$$):$ids$jscomp$3_loadFn$$()}};
$APP.$JSCompiler_prototypeAlias$$.load=function($moduleId$jscomp$4$$,$JSCompiler_StaticMethods_addCallback$self$jscomp$inline_11823_opt_userInitiated$jscomp$5$$){var $uniqueIds$jscomp$inline_4580$$=[];$module$contents$goog$array_removeDuplicates$$([$moduleId$jscomp$4$$],$uniqueIds$jscomp$inline_4580$$);for(var $cb$jscomp$inline_11824_idsToLoad$jscomp$inline_4581$$=[],$deferredMap$jscomp$inline_4582$$={},$i$jscomp$inline_4583$$=0;$i$jscomp$inline_4583$$<$uniqueIds$jscomp$inline_4580$$.length;$i$jscomp$inline_4583$$++){var $id$jscomp$inline_4584$$=
$uniqueIds$jscomp$inline_4580$$[$i$jscomp$inline_4583$$],$moduleInfo$jscomp$inline_4585$$=this.$moduleInfoMap$[$id$jscomp$inline_4584$$];if(!$moduleInfo$jscomp$inline_4585$$)throw Error("Unknown module: "+$id$jscomp$inline_4584$$);var $d$jscomp$inline_4586$$=new $goog$async$Deferred$$;$deferredMap$jscomp$inline_4582$$[$id$jscomp$inline_4584$$]=$d$jscomp$inline_4586$$;$moduleInfo$jscomp$inline_4585$$.isLoaded()?$d$jscomp$inline_4586$$.callback(this.$moduleContext_$):($JSCompiler_StaticMethods_registerModuleLoadCallbacks_$$(this,
$id$jscomp$inline_4584$$,$moduleInfo$jscomp$inline_4585$$,!!$JSCompiler_StaticMethods_addCallback$self$jscomp$inline_11823_opt_userInitiated$jscomp$5$$,$d$jscomp$inline_4586$$),$JSCompiler_StaticMethods_isModuleLoading$$(this,$id$jscomp$inline_4584$$)||$cb$jscomp$inline_11824_idsToLoad$jscomp$inline_4581$$.push($id$jscomp$inline_4584$$))}$cb$jscomp$inline_11824_idsToLoad$jscomp$inline_4581$$.length>0&&(this.$concurrentLoadingEnabled_$?($JSCompiler_StaticMethods_addCallback$self$jscomp$inline_11823_opt_userInitiated$jscomp$5$$=
this.$initialModulesLoaded_$,$cb$jscomp$inline_11824_idsToLoad$jscomp$inline_4581$$=$goog$bind$$(this.$loadModules_$,this,$cb$jscomp$inline_11824_idsToLoad$jscomp$inline_4581$$),$JSCompiler_StaticMethods_addCallback$self$jscomp$inline_11823_opt_userInitiated$jscomp$5$$.addCallbacks($cb$jscomp$inline_11824_idsToLoad$jscomp$inline_4581$$,null,void 0)):this.$loadingModuleIds_$.length===0?this.$loadModules_$($cb$jscomp$inline_11824_idsToLoad$jscomp$inline_4581$$):(this.$requestedModuleIdsQueue_$.push($cb$jscomp$inline_11824_idsToLoad$jscomp$inline_4581$$),
$JSCompiler_StaticMethods_dispatchActiveIdleChangeIfNeeded_$$(this)));return $deferredMap$jscomp$inline_4582$$[$moduleId$jscomp$4$$]};$APP.$JSCompiler_prototypeAlias$$.$handleLoadTimeout_$=function(){$goog$log$info$$(this.$logger_$,"Aborting after timeout: "+this.$loadingModuleIds_$);$JSCompiler_StaticMethods_requeueBatchOrDispatchFailure_$$(this,new $goog$module$$.$ModuleLoadFailure$($goog$module$$.$ModuleLoadFailure$.$Type$.TIMEOUT));$JSCompiler_StaticMethods_loadNextModules_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$registerCallback$=function($types$jscomp$3$$,$fn$jscomp$43$$){Array.isArray($types$jscomp$3$$)||($types$jscomp$3$$=[$types$jscomp$3$$]);for(var $i$jscomp$448$$=0;$i$jscomp$448$$<$types$jscomp$3$$.length;$i$jscomp$448$$++)this.$registerCallback_$($types$jscomp$3$$[$i$jscomp$448$$],$fn$jscomp$43$$)};
$APP.$JSCompiler_prototypeAlias$$.$registerCallback_$=function($type$jscomp$267$$,$fn$jscomp$44$$){var $callbackMap$$=this.$callbackMap_$;$callbackMap$$[$type$jscomp$267$$]||($callbackMap$$[$type$jscomp$267$$]=[]);$callbackMap$$[$type$jscomp$267$$].push($fn$jscomp$44$$)};$APP.$JSCompiler_prototypeAlias$$.$executeCallbacks_$=function($type$jscomp$268$$){for(var $callbacks$jscomp$3$$=this.$callbackMap_$[$type$jscomp$268$$],$i$jscomp$449$$=0;$callbacks$jscomp$3$$&&$i$jscomp$449$$<$callbacks$jscomp$3$$.length;$i$jscomp$449$$++)$callbacks$jscomp$3$$[$i$jscomp$449$$]($type$jscomp$268$$)};
$APP.$JSCompiler_prototypeAlias$$.dispose=function(){$module$contents$goog$disposeAll_disposeAll$$($module$contents$goog$object_getValues$$(this.$moduleInfoMap$),this.$baseModuleInfo_$);this.$moduleInfoMap$={};this.$loadingModuleIds_$=[];this.$requestedLoadingModuleIds_$=[];this.$userInitiatedLoadingModuleIds_$=[];this.$requestedModuleIdsQueue_$=[];this.$callbackMap_$={};this.$isDisposed_$=!0};$APP.$JSCompiler_prototypeAlias$$.$isDisposed$=function(){return this.$isDisposed_$};
$module$contents$goog$loader$activeModuleManager_getDefault$$=function(){return new $goog$module$ModuleManager$$};var $goog$events$Listenable$IMPLEMENTED_BY_PROP$$="closure_listenable_"+(Math.random()*1E6|0);var $goog$events$ListenableKey$counter_$$=0;$goog$events$ListenerMap$$.prototype.add=function($listenerArray_type$jscomp$277$$,$listener$jscomp$75_listenerObj$$,$callOnce$$,$opt_useCapture$jscomp$15$$,$opt_listenerScope$jscomp$4$$){var $typeStr$$=$listenerArray_type$jscomp$277$$.toString();$listenerArray_type$jscomp$277$$=this.$listeners$[$typeStr$$];$listenerArray_type$jscomp$277$$||($listenerArray_type$jscomp$277$$=this.$listeners$[$typeStr$$]=[],this.$typeCount_$++);var $index$jscomp$144$$=$goog$events$ListenerMap$findListenerIndex_$$($listenerArray_type$jscomp$277$$,
$listener$jscomp$75_listenerObj$$,$opt_useCapture$jscomp$15$$,$opt_listenerScope$jscomp$4$$);$index$jscomp$144$$>-1?($listener$jscomp$75_listenerObj$$=$listenerArray_type$jscomp$277$$[$index$jscomp$144$$],$callOnce$$||($listener$jscomp$75_listenerObj$$.$callOnce$=!1)):($listener$jscomp$75_listenerObj$$=new $goog$events$Listener$$($listener$jscomp$75_listenerObj$$,this.src,$typeStr$$,!!$opt_useCapture$jscomp$15$$,$opt_listenerScope$jscomp$4$$),$listener$jscomp$75_listenerObj$$.$callOnce$=$callOnce$$,
$listenerArray_type$jscomp$277$$.push($listener$jscomp$75_listenerObj$$));return $listener$jscomp$75_listenerObj$$};
$goog$events$ListenerMap$$.prototype.remove=function($type$jscomp$278_typeStr$jscomp$1$$,$index$jscomp$145_listener$jscomp$76$$,$opt_useCapture$jscomp$16$$,$opt_listenerScope$jscomp$5$$){$type$jscomp$278_typeStr$jscomp$1$$=$type$jscomp$278_typeStr$jscomp$1$$.toString();if(!($type$jscomp$278_typeStr$jscomp$1$$ in this.$listeners$))return!1;var $listenerArray$jscomp$1$$=this.$listeners$[$type$jscomp$278_typeStr$jscomp$1$$];$index$jscomp$145_listener$jscomp$76$$=$goog$events$ListenerMap$findListenerIndex_$$($listenerArray$jscomp$1$$,
$index$jscomp$145_listener$jscomp$76$$,$opt_useCapture$jscomp$16$$,$opt_listenerScope$jscomp$5$$);return $index$jscomp$145_listener$jscomp$76$$>-1?($JSCompiler_StaticMethods_markAsRemoved$$($listenerArray$jscomp$1$$[$index$jscomp$145_listener$jscomp$76$$]),Array.prototype.splice.call($listenerArray$jscomp$1$$,$index$jscomp$145_listener$jscomp$76$$,1),$listenerArray$jscomp$1$$.length==0&&(delete this.$listeners$[$type$jscomp$278_typeStr$jscomp$1$$],this.$typeCount_$--),!0):!1};
$goog$events$ListenerMap$$.prototype.$removeAll$=function(){var $count$jscomp$64$$=0,$type$jscomp$280$$;for($type$jscomp$280$$ in this.$listeners$){for(var $listenerArray$jscomp$2$$=this.$listeners$[$type$jscomp$280$$],$i$jscomp$450$$=0;$i$jscomp$450$$<$listenerArray$jscomp$2$$.length;$i$jscomp$450$$++)++$count$jscomp$64$$,$JSCompiler_StaticMethods_markAsRemoved$$($listenerArray$jscomp$2$$[$i$jscomp$450$$]);delete this.$listeners$[$type$jscomp$280$$];this.$typeCount_$--}};
$goog$events$ListenerMap$$.prototype.$getListener$=function($listenerArray$jscomp$4_type$jscomp$282$$,$listener$jscomp$78$$,$capture$jscomp$5$$,$opt_listenerScope$jscomp$6$$){$listenerArray$jscomp$4_type$jscomp$282$$=this.$listeners$[$listenerArray$jscomp$4_type$jscomp$282$$.toString()];var $i$jscomp$452$$=-1;$listenerArray$jscomp$4_type$jscomp$282$$&&($i$jscomp$452$$=$goog$events$ListenerMap$findListenerIndex_$$($listenerArray$jscomp$4_type$jscomp$282$$,$listener$jscomp$78$$,$capture$jscomp$5$$,
$opt_listenerScope$jscomp$6$$));return $i$jscomp$452$$>-1?$listenerArray$jscomp$4_type$jscomp$282$$[$i$jscomp$452$$]:null};var $goog$events$LISTENER_MAP_PROP_$$="closure_lm_"+(Math.random()*1E6|0),$goog$events$onStringMap_$$={},$goog$events$listenerCountEstimate_$$=0,$goog$events$LISTENER_WRAPPER_PROP_$$="__closure_events_fn_"+(Math.random()*1E9>>>0);$APP.$goog$inherits$$($goog$events$EventHandler$$,$goog$Disposable$$);var $goog$events$EventHandler$typeArray_$$=[];$APP.$JSCompiler_prototypeAlias$$=$goog$events$EventHandler$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$listen$=function($src$jscomp$26$$,$type$jscomp$295_type$jscomp$inline_4597$$,$opt_fn$$,$opt_options$jscomp$98$$){Array.isArray($type$jscomp$295_type$jscomp$inline_4597$$)||($type$jscomp$295_type$jscomp$inline_4597$$&&($goog$events$EventHandler$typeArray_$$[0]=$type$jscomp$295_type$jscomp$inline_4597$$.toString()),$type$jscomp$295_type$jscomp$inline_4597$$=$goog$events$EventHandler$typeArray_$$);for(var $i$jscomp$inline_4601$$=0;$i$jscomp$inline_4601$$<$type$jscomp$295_type$jscomp$inline_4597$$.length;$i$jscomp$inline_4601$$++){var $listenerObj$jscomp$inline_4602$$=
$APP.$goog$events$listen$$($src$jscomp$26$$,$type$jscomp$295_type$jscomp$inline_4597$$[$i$jscomp$inline_4601$$],$opt_fn$$||this.handleEvent,$opt_options$jscomp$98$$||!1,this.$handler_$||this);if(!$listenerObj$jscomp$inline_4602$$)break;this.$keys_$[$listenerObj$jscomp$inline_4602$$.key]=$listenerObj$jscomp$inline_4602$$}return this};
$APP.$JSCompiler_prototypeAlias$$.$listenOnce$=function($src$jscomp$29$$,$type$jscomp$298$$,$opt_fn$jscomp$2$$,$opt_options$jscomp$100$$){return $JSCompiler_StaticMethods_listenOnce_$$(this,$src$jscomp$29$$,$type$jscomp$298$$,$opt_fn$jscomp$2$$,$opt_options$jscomp$100$$)};
$APP.$JSCompiler_prototypeAlias$$.$unlisten$=function($listenerMap$jscomp$inline_4610_src$jscomp$35$$,$listener$jscomp$95_type$jscomp$301$$,$listener$jscomp$inline_4606_opt_fn$jscomp$4$$,$capture$jscomp$inline_4609_opt_capt$jscomp$inline_4607_opt_options$jscomp$102$$,$opt_handler$jscomp$inline_4608_opt_scope$jscomp$15$$){if(Array.isArray($listener$jscomp$95_type$jscomp$301$$))for(var $i$jscomp$462$$=0;$i$jscomp$462$$<$listener$jscomp$95_type$jscomp$301$$.length;$i$jscomp$462$$++)this.$unlisten$($listenerMap$jscomp$inline_4610_src$jscomp$35$$,
$listener$jscomp$95_type$jscomp$301$$[$i$jscomp$462$$],$listener$jscomp$inline_4606_opt_fn$jscomp$4$$,$capture$jscomp$inline_4609_opt_capt$jscomp$inline_4607_opt_options$jscomp$102$$,$opt_handler$jscomp$inline_4608_opt_scope$jscomp$15$$);else $listener$jscomp$inline_4606_opt_fn$jscomp$4$$=$listener$jscomp$inline_4606_opt_fn$jscomp$4$$||this.handleEvent,$capture$jscomp$inline_4609_opt_capt$jscomp$inline_4607_opt_options$jscomp$102$$=$goog$isObject$$($capture$jscomp$inline_4609_opt_capt$jscomp$inline_4607_opt_options$jscomp$102$$)?
!!$capture$jscomp$inline_4609_opt_capt$jscomp$inline_4607_opt_options$jscomp$102$$.capture:!!$capture$jscomp$inline_4609_opt_capt$jscomp$inline_4607_opt_options$jscomp$102$$,$opt_handler$jscomp$inline_4608_opt_scope$jscomp$15$$=$opt_handler$jscomp$inline_4608_opt_scope$jscomp$15$$||this.$handler_$||this,$listener$jscomp$inline_4606_opt_fn$jscomp$4$$=$goog$events$wrapListener$$($listener$jscomp$inline_4606_opt_fn$jscomp$4$$),$capture$jscomp$inline_4609_opt_capt$jscomp$inline_4607_opt_options$jscomp$102$$=
!!$capture$jscomp$inline_4609_opt_capt$jscomp$inline_4607_opt_options$jscomp$102$$,$listener$jscomp$95_type$jscomp$301$$=$goog$events$Listenable$isImplementedBy$$($listenerMap$jscomp$inline_4610_src$jscomp$35$$)?$listenerMap$jscomp$inline_4610_src$jscomp$35$$.$getListener$($listener$jscomp$95_type$jscomp$301$$,$listener$jscomp$inline_4606_opt_fn$jscomp$4$$,$capture$jscomp$inline_4609_opt_capt$jscomp$inline_4607_opt_options$jscomp$102$$,$opt_handler$jscomp$inline_4608_opt_scope$jscomp$15$$):$listenerMap$jscomp$inline_4610_src$jscomp$35$$?
($listenerMap$jscomp$inline_4610_src$jscomp$35$$=$goog$events$getListenerMap_$$($listenerMap$jscomp$inline_4610_src$jscomp$35$$))?$listenerMap$jscomp$inline_4610_src$jscomp$35$$.$getListener$($listener$jscomp$95_type$jscomp$301$$,$listener$jscomp$inline_4606_opt_fn$jscomp$4$$,$capture$jscomp$inline_4609_opt_capt$jscomp$inline_4607_opt_options$jscomp$102$$,$opt_handler$jscomp$inline_4608_opt_scope$jscomp$15$$):null:null,$listener$jscomp$95_type$jscomp$301$$&&($APP.$goog$events$unlistenByKey$$($listener$jscomp$95_type$jscomp$301$$),
delete this.$keys_$[$listener$jscomp$95_type$jscomp$301$$.key])};$APP.$JSCompiler_prototypeAlias$$.$removeAll$=function(){$module$contents$goog$object_forEach$$(this.$keys_$,function($listenerObj$jscomp$8$$,$key$jscomp$288$$){this.$keys_$.hasOwnProperty($key$jscomp$288$$)&&$APP.$goog$events$unlistenByKey$$($listenerObj$jscomp$8$$)},this);this.$keys_$={}};$APP.$JSCompiler_prototypeAlias$$.$disposeInternal$=function(){$goog$events$EventHandler$$.$superClass_$.$disposeInternal$.call(this);this.$removeAll$()};
$APP.$JSCompiler_prototypeAlias$$.handleEvent=function(){throw Error("EventHandler.handleEvent not implemented");};$APP.$goog$inherits$$($APP.$goog$events$EventTarget$$,$goog$Disposable$$);$APP.$goog$events$EventTarget$$.prototype[$goog$events$Listenable$IMPLEMENTED_BY_PROP$$]=!0;$APP.$JSCompiler_prototypeAlias$$=$APP.$goog$events$EventTarget$$.prototype;$APP.$JSCompiler_prototypeAlias$$.addEventListener=function($type$jscomp$302$$,$handler$jscomp$23$$,$opt_capture$jscomp$3$$,$opt_handlerScope$$){$APP.$goog$events$listen$$(this,$type$jscomp$302$$,$handler$jscomp$23$$,$opt_capture$jscomp$3$$,$opt_handlerScope$$)};
$APP.$JSCompiler_prototypeAlias$$.removeEventListener=function($type$jscomp$303$$,$handler$jscomp$24$$,$opt_capture$jscomp$4$$,$opt_handlerScope$jscomp$1$$){$APP.$goog$events$unlisten$$(this,$type$jscomp$303$$,$handler$jscomp$24$$,$opt_capture$jscomp$4$$,$opt_handlerScope$jscomp$1$$)};
$APP.$JSCompiler_prototypeAlias$$.dispatchEvent=function($e$jscomp$256_e$jscomp$inline_4615$$){var $ancestorsTree_opt_ancestorsTree$jscomp$inline_4616$$,$ancestor_target$jscomp$inline_4614$$=this.$parentEventTarget_$;if($ancestor_target$jscomp$inline_4614$$)for($ancestorsTree_opt_ancestorsTree$jscomp$inline_4616$$=[];$ancestor_target$jscomp$inline_4614$$;$ancestor_target$jscomp$inline_4614$$=$ancestor_target$jscomp$inline_4614$$.$parentEventTarget_$)$ancestorsTree_opt_ancestorsTree$jscomp$inline_4616$$.push($ancestor_target$jscomp$inline_4614$$);
$ancestor_target$jscomp$inline_4614$$=this.$actualEventTarget_$;var $type$jscomp$inline_4617$$=$e$jscomp$256_e$jscomp$inline_4615$$.type||$e$jscomp$256_e$jscomp$inline_4615$$;if(typeof $e$jscomp$256_e$jscomp$inline_4615$$==="string")$e$jscomp$256_e$jscomp$inline_4615$$=new $APP.$goog$events$Event$$($e$jscomp$256_e$jscomp$inline_4615$$,$ancestor_target$jscomp$inline_4614$$);else if($e$jscomp$256_e$jscomp$inline_4615$$ instanceof $APP.$goog$events$Event$$)$e$jscomp$256_e$jscomp$inline_4615$$.target=
$e$jscomp$256_e$jscomp$inline_4615$$.target||$ancestor_target$jscomp$inline_4614$$;else{var $oldEvent$jscomp$inline_4618_rv$jscomp$inline_4619$$=$e$jscomp$256_e$jscomp$inline_4615$$;$e$jscomp$256_e$jscomp$inline_4615$$=new $APP.$goog$events$Event$$($type$jscomp$inline_4617$$,$ancestor_target$jscomp$inline_4614$$);$module$contents$goog$object_extend$$($e$jscomp$256_e$jscomp$inline_4615$$,$oldEvent$jscomp$inline_4618_rv$jscomp$inline_4619$$)}$oldEvent$jscomp$inline_4618_rv$jscomp$inline_4619$$=!0;if($ancestorsTree_opt_ancestorsTree$jscomp$inline_4616$$)for(var $i$jscomp$inline_4621$$=
$ancestorsTree_opt_ancestorsTree$jscomp$inline_4616$$.length-1;!$e$jscomp$256_e$jscomp$inline_4615$$.$propagationStopped_$&&$i$jscomp$inline_4621$$>=0;$i$jscomp$inline_4621$$--){var $currentTarget$jscomp$inline_4620$$=$e$jscomp$256_e$jscomp$inline_4615$$.currentTarget=$ancestorsTree_opt_ancestorsTree$jscomp$inline_4616$$[$i$jscomp$inline_4621$$];$oldEvent$jscomp$inline_4618_rv$jscomp$inline_4619$$=$JSCompiler_StaticMethods_fireListeners$$($currentTarget$jscomp$inline_4620$$,$type$jscomp$inline_4617$$,
!0,$e$jscomp$256_e$jscomp$inline_4615$$)&&$oldEvent$jscomp$inline_4618_rv$jscomp$inline_4619$$}$e$jscomp$256_e$jscomp$inline_4615$$.$propagationStopped_$||($currentTarget$jscomp$inline_4620$$=$e$jscomp$256_e$jscomp$inline_4615$$.currentTarget=$ancestor_target$jscomp$inline_4614$$,$oldEvent$jscomp$inline_4618_rv$jscomp$inline_4619$$=$JSCompiler_StaticMethods_fireListeners$$($currentTarget$jscomp$inline_4620$$,$type$jscomp$inline_4617$$,!0,$e$jscomp$256_e$jscomp$inline_4615$$)&&$oldEvent$jscomp$inline_4618_rv$jscomp$inline_4619$$,
$e$jscomp$256_e$jscomp$inline_4615$$.$propagationStopped_$||($oldEvent$jscomp$inline_4618_rv$jscomp$inline_4619$$=$JSCompiler_StaticMethods_fireListeners$$($currentTarget$jscomp$inline_4620$$,$type$jscomp$inline_4617$$,!1,$e$jscomp$256_e$jscomp$inline_4615$$)&&$oldEvent$jscomp$inline_4618_rv$jscomp$inline_4619$$));if($ancestorsTree_opt_ancestorsTree$jscomp$inline_4616$$)for($i$jscomp$inline_4621$$=0;!$e$jscomp$256_e$jscomp$inline_4615$$.$propagationStopped_$&&$i$jscomp$inline_4621$$<$ancestorsTree_opt_ancestorsTree$jscomp$inline_4616$$.length;$i$jscomp$inline_4621$$++)$currentTarget$jscomp$inline_4620$$=
$e$jscomp$256_e$jscomp$inline_4615$$.currentTarget=$ancestorsTree_opt_ancestorsTree$jscomp$inline_4616$$[$i$jscomp$inline_4621$$],$oldEvent$jscomp$inline_4618_rv$jscomp$inline_4619$$=$JSCompiler_StaticMethods_fireListeners$$($currentTarget$jscomp$inline_4620$$,$type$jscomp$inline_4617$$,!1,$e$jscomp$256_e$jscomp$inline_4615$$)&&$oldEvent$jscomp$inline_4618_rv$jscomp$inline_4619$$;return $oldEvent$jscomp$inline_4618_rv$jscomp$inline_4619$$};
$APP.$JSCompiler_prototypeAlias$$.$disposeInternal$=function(){$APP.$goog$events$EventTarget$$.$superClass_$.$disposeInternal$.call(this);this.$eventTargetListeners_$&&this.$eventTargetListeners_$.$removeAll$();this.$parentEventTarget_$=null};
$APP.$JSCompiler_prototypeAlias$$.$listen$=function($type$jscomp$304$$,$listener$jscomp$97$$,$opt_useCapture$jscomp$18$$,$opt_listenerScope$jscomp$8$$){return this.$eventTargetListeners_$.add(String($type$jscomp$304$$),$listener$jscomp$97$$,!1,$opt_useCapture$jscomp$18$$,$opt_listenerScope$jscomp$8$$)};
$APP.$JSCompiler_prototypeAlias$$.$listenOnce$=function($type$jscomp$305$$,$listener$jscomp$98$$,$opt_useCapture$jscomp$19$$,$opt_listenerScope$jscomp$9$$){return this.$eventTargetListeners_$.add(String($type$jscomp$305$$),$listener$jscomp$98$$,!0,$opt_useCapture$jscomp$19$$,$opt_listenerScope$jscomp$9$$)};
$APP.$JSCompiler_prototypeAlias$$.$unlisten$=function($type$jscomp$306$$,$listener$jscomp$99$$,$opt_useCapture$jscomp$20$$,$opt_listenerScope$jscomp$10$$){this.$eventTargetListeners_$.remove(String($type$jscomp$306$$),$listener$jscomp$99$$,$opt_useCapture$jscomp$20$$,$opt_listenerScope$jscomp$10$$)};
$APP.$JSCompiler_prototypeAlias$$.$getListener$=function($type$jscomp$309$$,$listener$jscomp$101$$,$capture$jscomp$19$$,$opt_listenerScope$jscomp$11$$){return this.$eventTargetListeners_$.$getListener$(String($type$jscomp$309$$),$listener$jscomp$101$$,$capture$jscomp$19$$,$opt_listenerScope$jscomp$11$$)};$APP.$goog$inherits$$($goog$net$BulkLoaderHelper$$,$goog$Disposable$$);$goog$net$BulkLoaderHelper$$.prototype.$getUris$=function(){return this.$uris_$};$goog$net$BulkLoaderHelper$$.prototype.$getResponseTexts$=function(){return this.$responseTexts_$};$goog$net$BulkLoaderHelper$$.prototype.$disposeInternal$=function(){$goog$net$BulkLoaderHelper$$.$superClass_$.$disposeInternal$.call(this);this.$responseTexts_$=this.$uris_$=null};$goog$net$XmlHttpFactory$$.prototype.$cachedOptions_$=null;var $goog$net$XmlHttp$factory_$$;$APP.$goog$inherits$$($goog$net$DefaultXmlHttpFactory$$,$goog$net$XmlHttpFactory$$);$goog$net$XmlHttp$factory_$$=new $goog$net$DefaultXmlHttpFactory$$;$APP.$goog$inherits$$($goog$net$XhrIo$$,$APP.$goog$events$EventTarget$$);var $goog$net$XhrIo$ResponseType$DEFAULT$$="";$goog$net$XhrIo$$.prototype.$logger_$=$goog$log$getLogger$$("goog.net.XhrIo");var $goog$net$XhrIo$HTTP_SCHEME_PATTERN$$=/^https?$/i,$goog$net$XhrIo$METHODS_WITH_FORM_DATA$$=["POST","PUT"];$APP.$JSCompiler_prototypeAlias$$=$goog$net$XhrIo$$.prototype;$APP.$JSCompiler_prototypeAlias$$.setTrustToken=function($trustToken$$){this.$trustToken_$=$trustToken$$};
$APP.$JSCompiler_prototypeAlias$$.send=function($content$jscomp$15_url$jscomp$70$$,$method$jscomp$42_opt_method$jscomp$1$$,$headers_opt_content$jscomp$2$$,$contentTypeKey_opt_headers$jscomp$1$$){if(this.$xhr_$)throw Error("[goog.net.XhrIo] Object is active with another request\x3d"+this.$lastUri_$+"; newUri\x3d"+$content$jscomp$15_url$jscomp$70$$);$method$jscomp$42_opt_method$jscomp$1$$=$method$jscomp$42_opt_method$jscomp$1$$?$method$jscomp$42_opt_method$jscomp$1$$.toUpperCase():"GET";this.$lastUri_$=
$content$jscomp$15_url$jscomp$70$$;this.$lastError_$="";this.$lastMethod_$=$method$jscomp$42_opt_method$jscomp$1$$;this.$errorDispatched_$=!1;this.$active_$=!0;this.$xhr_$=this.$xmlHttpFactory_$?$JSCompiler_StaticMethods_createInstance$$(this.$xmlHttpFactory_$):$JSCompiler_StaticMethods_createInstance$$($goog$net$XmlHttp$factory_$$);this.$xhrOptions_$=this.$xmlHttpFactory_$?$JSCompiler_StaticMethods_getOptions$$(this.$xmlHttpFactory_$):$JSCompiler_StaticMethods_getOptions$$($goog$net$XmlHttp$factory_$$);
this.$xhr_$.onreadystatechange=$goog$bind$$(this.$onReadyStateChange_$,this);this.$progressEventsEnabled_$&&"onprogress"in this.$xhr_$&&(this.$xhr_$.onprogress=$goog$bind$$(function($e$jscomp$261$$){this.$onProgressHandler_$($e$jscomp$261$$,!0)},this),this.$xhr_$.upload&&(this.$xhr_$.upload.onprogress=$goog$bind$$(this.$onProgressHandler_$,this)));try{$goog$log$fine$$(this.$logger_$,$JSCompiler_StaticMethods_formatMsg_$$(this,"Opening Xhr")),this.$inOpen_$=!0,this.$xhr_$.open($method$jscomp$42_opt_method$jscomp$1$$,
String($content$jscomp$15_url$jscomp$70$$),!0),this.$inOpen_$=!1}catch($err$jscomp$28$$){$goog$log$fine$$(this.$logger_$,$JSCompiler_StaticMethods_formatMsg_$$(this,"Error opening Xhr: "+$err$jscomp$28$$.message));this.$error_$(5,$err$jscomp$28$$);return}$content$jscomp$15_url$jscomp$70$$=$headers_opt_content$jscomp$2$$||"";$headers_opt_content$jscomp$2$$=new Map(this.headers);if($contentTypeKey_opt_headers$jscomp$1$$)if(Object.getPrototypeOf($contentTypeKey_opt_headers$jscomp$1$$)===Object.prototype)for(var $contentIsFormData_key$jscomp$291$$ in $contentTypeKey_opt_headers$jscomp$1$$)$headers_opt_content$jscomp$2$$.set($contentIsFormData_key$jscomp$291$$,
$contentTypeKey_opt_headers$jscomp$1$$[$contentIsFormData_key$jscomp$291$$]);else if(typeof $contentTypeKey_opt_headers$jscomp$1$$.keys==="function"&&typeof $contentTypeKey_opt_headers$jscomp$1$$.get==="function")for(const $key$jscomp$292$$ of $contentTypeKey_opt_headers$jscomp$1$$.keys())$headers_opt_content$jscomp$2$$.set($key$jscomp$292$$,$contentTypeKey_opt_headers$jscomp$1$$.get($key$jscomp$292$$));else throw Error("Unknown input type for opt_headers: "+String($contentTypeKey_opt_headers$jscomp$1$$));
$contentTypeKey_opt_headers$jscomp$1$$=Array.from($headers_opt_content$jscomp$2$$.keys()).find($header$jscomp$5$$=>"content-type"==$header$jscomp$5$$.toLowerCase());$contentIsFormData_key$jscomp$291$$=$APP.$goog$global$$.FormData&&$content$jscomp$15_url$jscomp$70$$ instanceof $APP.$goog$global$$.FormData;!($module$contents$goog$array_indexOf$$($goog$net$XhrIo$METHODS_WITH_FORM_DATA$$,$method$jscomp$42_opt_method$jscomp$1$$)>=0)||$contentTypeKey_opt_headers$jscomp$1$$||$contentIsFormData_key$jscomp$291$$||
$headers_opt_content$jscomp$2$$.set("Content-Type","application/x-www-form-urlencoded;charset\x3dutf-8");for(const [$key$jscomp$293$$,$value$jscomp$380$$]of $headers_opt_content$jscomp$2$$)this.$xhr_$.setRequestHeader($key$jscomp$293$$,$value$jscomp$380$$);this.$responseType_$&&(this.$xhr_$.responseType=this.$responseType_$);"withCredentials"in this.$xhr_$&&this.$xhr_$.withCredentials!==this.$withCredentials_$&&(this.$xhr_$.withCredentials=this.$withCredentials_$);if("setTrustToken"in this.$xhr_$&&
this.$trustToken_$)try{this.$xhr_$.setTrustToken(this.$trustToken_$)}catch($err$jscomp$29$$){$goog$log$fine$$(this.$logger_$,$JSCompiler_StaticMethods_formatMsg_$$(this,"Error SetTrustToken: "+$err$jscomp$29$$.message))}try{$JSCompiler_StaticMethods_cleanUpTimeoutTimer_$$(this),this.$timeoutInterval_$>0&&(this.$useXhr2Timeout_$=$goog$net$XhrIo$shouldUseXhr2Timeout_$$(this.$xhr_$),$goog$log$fine$$(this.$logger_$,$JSCompiler_StaticMethods_formatMsg_$$(this,"Will abort after "+this.$timeoutInterval_$+
"ms if incomplete, xhr2 "+this.$useXhr2Timeout_$)),this.$useXhr2Timeout_$?(this.$xhr_$.timeout=this.$timeoutInterval_$,this.$xhr_$.ontimeout=$goog$bind$$(this.$timeout_$,this)):this.$timeoutId_$=$goog$Timer$callOnce$$(this.$timeout_$,this.$timeoutInterval_$,this)),$goog$log$fine$$(this.$logger_$,$JSCompiler_StaticMethods_formatMsg_$$(this,"Sending request")),this.$inSend_$=!0,this.$xhr_$.send($content$jscomp$15_url$jscomp$70$$),this.$inSend_$=!1}catch($err$jscomp$30$$){$goog$log$fine$$(this.$logger_$,
$JSCompiler_StaticMethods_formatMsg_$$(this,"Send error: "+$err$jscomp$30$$.message)),this.$error_$(5,$err$jscomp$30$$)}};$APP.$JSCompiler_prototypeAlias$$.$timeout_$=function(){typeof $goog$$!="undefined"&&this.$xhr_$&&(this.$lastError_$="Timed out after "+this.$timeoutInterval_$+"ms, aborting",$goog$log$fine$$(this.$logger_$,$JSCompiler_StaticMethods_formatMsg_$$(this,this.$lastError_$)),this.dispatchEvent("timeout"),this.abort(8))};
$APP.$JSCompiler_prototypeAlias$$.$error_$=function($errorCode$jscomp$1$$,$err$jscomp$31$$){this.$active_$=!1;this.$xhr_$&&(this.$inAbort_$=!0,this.$xhr_$.abort(),this.$inAbort_$=!1);this.$lastError_$=$err$jscomp$31$$;$JSCompiler_StaticMethods_dispatchErrors_$$(this);$JSCompiler_StaticMethods_cleanUpXhr_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.abort=function(){this.$xhr_$&&this.$active_$&&($goog$log$fine$$(this.$logger_$,$JSCompiler_StaticMethods_formatMsg_$$(this,"Aborting")),this.$active_$=!1,this.$inAbort_$=!0,this.$xhr_$.abort(),this.$inAbort_$=!1,this.dispatchEvent("complete"),this.dispatchEvent("abort"),$JSCompiler_StaticMethods_cleanUpXhr_$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$disposeInternal$=function(){this.$xhr_$&&(this.$active_$&&(this.$active_$=!1,this.$inAbort_$=!0,this.$xhr_$.abort(),this.$inAbort_$=!1),$JSCompiler_StaticMethods_cleanUpXhr_$$(this,!0));$goog$net$XhrIo$$.$superClass_$.$disposeInternal$.call(this)};$APP.$JSCompiler_prototypeAlias$$.$onReadyStateChange_$=function(){this.$isDisposed$()||(this.$inOpen_$||this.$inSend_$||this.$inAbort_$?$JSCompiler_StaticMethods_onReadyStateChangeHelper_$$(this):this.$onReadyStateChangeEntryPoint_$())};
$APP.$JSCompiler_prototypeAlias$$.$onReadyStateChangeEntryPoint_$=function(){$JSCompiler_StaticMethods_onReadyStateChangeHelper_$$(this)};$APP.$JSCompiler_prototypeAlias$$.$onProgressHandler_$=function($e$jscomp$262$$,$opt_isDownload$$){this.dispatchEvent($goog$net$XhrIo$buildProgressEvent_$$($e$jscomp$262$$,"progress"));this.dispatchEvent($goog$net$XhrIo$buildProgressEvent_$$($e$jscomp$262$$,$opt_isDownload$$?"downloadprogress":"uploadprogress"))};$APP.$JSCompiler_prototypeAlias$$.isActive=function(){return!!this.$xhr_$};
$APP.$JSCompiler_prototypeAlias$$.getResponseHeader=function($key$jscomp$294_value$jscomp$381$$){if(this.$xhr_$&&$JSCompiler_StaticMethods_getReadyState$$(this)==4)return $key$jscomp$294_value$jscomp$381$$=this.$xhr_$.getResponseHeader($key$jscomp$294_value$jscomp$381$$),$key$jscomp$294_value$jscomp$381$$===null?void 0:$key$jscomp$294_value$jscomp$381$$};
$APP.$JSCompiler_prototypeAlias$$.getAllResponseHeaders=function(){return this.$xhr_$&&$JSCompiler_StaticMethods_getReadyState$$(this)>=2?this.$xhr_$.getAllResponseHeaders()||"":""};$APP.$goog$inherits$$($goog$net$BulkLoader$$,$APP.$goog$events$EventTarget$$);$APP.$JSCompiler_prototypeAlias$$=$goog$net$BulkLoader$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$logger_$=$goog$log$getLogger$$("goog.net.BulkLoader");$APP.$JSCompiler_prototypeAlias$$.$getResponseTexts$=function(){return this.$helper_$.$getResponseTexts$()};
$APP.$JSCompiler_prototypeAlias$$.load=function(){const $eventHandler$$=this.$eventHandler_$,$uris$jscomp$4$$=this.$helper_$.$getUris$();$goog$log$info$$(this.$logger_$,"Starting load of code with "+$uris$jscomp$4$$.length+" uris.");for(let $i$jscomp$469$$=0;$i$jscomp$469$$<$uris$jscomp$4$$.length;$i$jscomp$469$$++){const $xhrIo$$=new $goog$net$XhrIo$$;$eventHandler$$.$listen$($xhrIo$$,"complete",$goog$bind$$(this.$handleEvent_$,this,$i$jscomp$469$$));$xhrIo$$.send($uris$jscomp$4$$[$i$jscomp$469$$])}};
$APP.$JSCompiler_prototypeAlias$$.$handleEvent_$=function($id$jscomp$79$$,$e$jscomp$271_xhrIo$jscomp$1$$){$goog$log$info$$(this.$logger_$,'Received event "'+$e$jscomp$271_xhrIo$jscomp$1$$.type+'" for id '+$id$jscomp$79$$+" with uri "+this.$helper_$.$uris_$[$id$jscomp$79$$]);$e$jscomp$271_xhrIo$jscomp$1$$=$e$jscomp$271_xhrIo$jscomp$1$$.target;$JSCompiler_StaticMethods_isSuccess$$($e$jscomp$271_xhrIo$jscomp$1$$)?this.$handleSuccess_$($id$jscomp$79$$,$e$jscomp$271_xhrIo$jscomp$1$$):this.$handleError_$($id$jscomp$79$$,
$e$jscomp$271_xhrIo$jscomp$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$handleSuccess_$=function($JSCompiler_inline_result$jscomp$675_id$jscomp$80_responseTexts$jscomp$inline_4650$$,$xhrIo$jscomp$2$$){var $JSCompiler_StaticMethods_isLoadComplete$self$jscomp$inline_4649_JSCompiler_temp_const$jscomp$685_i$jscomp$inline_4651$$=this.$helper_$;try{var $JSCompiler_inline_result$jscomp$686$$=$xhrIo$jscomp$2$$.$xhr_$?$xhrIo$jscomp$2$$.$xhr_$.responseText:""}catch($e$jscomp$inline_4643$$){$goog$log$fine$$($xhrIo$jscomp$2$$.$logger_$,"Can not get responseText: "+
$e$jscomp$inline_4643$$.message),$JSCompiler_inline_result$jscomp$686$$=""}$JSCompiler_StaticMethods_isLoadComplete$self$jscomp$inline_4649_JSCompiler_temp_const$jscomp$685_i$jscomp$inline_4651$$.$responseTexts_$[$JSCompiler_inline_result$jscomp$675_id$jscomp$80_responseTexts$jscomp$inline_4650$$]=$JSCompiler_inline_result$jscomp$686$$;a:if($JSCompiler_StaticMethods_isLoadComplete$self$jscomp$inline_4649_JSCompiler_temp_const$jscomp$685_i$jscomp$inline_4651$$=this.$helper_$,$JSCompiler_inline_result$jscomp$675_id$jscomp$80_responseTexts$jscomp$inline_4650$$=
$JSCompiler_StaticMethods_isLoadComplete$self$jscomp$inline_4649_JSCompiler_temp_const$jscomp$685_i$jscomp$inline_4651$$.$responseTexts_$,$JSCompiler_inline_result$jscomp$675_id$jscomp$80_responseTexts$jscomp$inline_4650$$.length==$JSCompiler_StaticMethods_isLoadComplete$self$jscomp$inline_4649_JSCompiler_temp_const$jscomp$685_i$jscomp$inline_4651$$.$uris_$.length){for($JSCompiler_StaticMethods_isLoadComplete$self$jscomp$inline_4649_JSCompiler_temp_const$jscomp$685_i$jscomp$inline_4651$$=0;$JSCompiler_StaticMethods_isLoadComplete$self$jscomp$inline_4649_JSCompiler_temp_const$jscomp$685_i$jscomp$inline_4651$$<
$JSCompiler_inline_result$jscomp$675_id$jscomp$80_responseTexts$jscomp$inline_4650$$.length;$JSCompiler_StaticMethods_isLoadComplete$self$jscomp$inline_4649_JSCompiler_temp_const$jscomp$685_i$jscomp$inline_4651$$++)if($JSCompiler_inline_result$jscomp$675_id$jscomp$80_responseTexts$jscomp$inline_4650$$[$JSCompiler_StaticMethods_isLoadComplete$self$jscomp$inline_4649_JSCompiler_temp_const$jscomp$685_i$jscomp$inline_4651$$]==null){$JSCompiler_inline_result$jscomp$675_id$jscomp$80_responseTexts$jscomp$inline_4650$$=
!1;break a}$JSCompiler_inline_result$jscomp$675_id$jscomp$80_responseTexts$jscomp$inline_4650$$=!0}else $JSCompiler_inline_result$jscomp$675_id$jscomp$80_responseTexts$jscomp$inline_4650$$=!1;$JSCompiler_inline_result$jscomp$675_id$jscomp$80_responseTexts$jscomp$inline_4650$$&&($goog$log$info$$(this.$logger_$,"All uris loaded."),this.dispatchEvent("success"));$xhrIo$jscomp$2$$.dispose()};
$APP.$JSCompiler_prototypeAlias$$.$handleError_$=function($id$jscomp$81$$,$xhrIo$jscomp$3$$){this.dispatchEvent(new $goog$net$BulkLoader$LoadErrorEvent$$($JSCompiler_StaticMethods_getStatus$$($xhrIo$jscomp$3$$)));$xhrIo$jscomp$3$$.dispose()};$APP.$JSCompiler_prototypeAlias$$.$disposeInternal$=function(){$goog$net$BulkLoader$$.$superClass_$.$disposeInternal$.call(this);this.$eventHandler_$.dispose();this.$eventHandler_$=null;this.$helper_$.dispose();this.$helper_$=null};
$APP.$goog$inherits$$($goog$net$BulkLoader$LoadErrorEvent$$,$APP.$goog$events$Event$$);var $goog$net$jsloader$scriptsToLoad_$$=[],$goog$net$jsloader$ErrorCode$LOAD_ERROR$$=0,$goog$net$jsloader$ErrorCode$TIMEOUT$$=1;$APP.$goog$inherits$$($goog$net$jsloader$Error$$,$module$contents$goog$debug$Error_DebugError$$);$module$contents$goog$labs$userAgent$browser_matchFirefox$$();$module$contents$goog$labs$userAgent$platform_isIphone$$()||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("iPod");$module$contents$goog$labs$userAgent$util_matchUserAgent$$("iPad");
!$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Android")||$module$contents$goog$labs$userAgent$browser_matchChrome$$()||$module$contents$goog$labs$userAgent$browser_matchFirefox$$()||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Opera")||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Silk");var $goog$userAgent$product$CHROME$$=$module$contents$goog$labs$userAgent$browser_matchChrome$$();
!$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Safari")||$module$contents$goog$labs$userAgent$browser_matchChrome$$()||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Coast")||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Opera")||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Edge")||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Edg/")||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("OPR")||$module$contents$goog$labs$userAgent$browser_matchFirefox$$()||
$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Silk")||$module$contents$goog$labs$userAgent$util_matchUserAgent$$("Android")||$module$contents$goog$labs$userAgent$platform_isIos$$();$APP.$goog$inherits$$($module$contents$goog$module$ModuleLoader_ModuleLoader$$,$APP.$goog$events$EventTarget$$);$APP.$JSCompiler_prototypeAlias$$=$module$contents$goog$module$ModuleLoader_ModuleLoader$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$logger$=$goog$log$getLogger$$("goog.module.ModuleLoader");$APP.$JSCompiler_prototypeAlias$$.$debugMode_$=!1;$APP.$JSCompiler_prototypeAlias$$.$sourceUrlInjection_$=!1;$APP.$JSCompiler_prototypeAlias$$.$useScriptTags_$=!1;
$APP.$JSCompiler_prototypeAlias$$.$loadModules$=function($ids$jscomp$7$$,$loadStatus_moduleInfoMap$jscomp$1$$,{$onError$:$onError_prefetchedModuleLoadStatus_successFunctions$$,$onSuccess$:$i$jscomp$470_onSuccess$$}={}){if(this.$hasPrefetched_$&&!this.$useScriptTags_$&&$ids$jscomp$7$$.length>1)throw Error("Modules prefetching is only supported in batch mode when using script tags.");var $JSCompiler_temp$jscomp$688_currentId_trustedRequestUris$jscomp$inline_4667$$;if(!($JSCompiler_temp$jscomp$688_currentId_trustedRequestUris$jscomp$inline_4667$$=
this.$loadingModulesStatus_$[$ids$jscomp$7$$]))if($ids$jscomp$7$$){$JSCompiler_temp$jscomp$688_currentId_trustedRequestUris$jscomp$inline_4667$$=[];for(var $i$jscomp$inline_4668_prefetchedModuleLoadStatus$jscomp$1$$=0;$i$jscomp$inline_4668_prefetchedModuleLoadStatus$jscomp$1$$<$ids$jscomp$7$$.length;$i$jscomp$inline_4668_prefetchedModuleLoadStatus$jscomp$1$$++)$module$contents$goog$array_extend$$($JSCompiler_temp$jscomp$688_currentId_trustedRequestUris$jscomp$inline_4667$$,$loadStatus_moduleInfoMap$jscomp$1$$[$ids$jscomp$7$$[$i$jscomp$inline_4668_prefetchedModuleLoadStatus$jscomp$1$$]].$getUris$());
$JSCompiler_temp$jscomp$688_currentId_trustedRequestUris$jscomp$inline_4667$$=new $module$contents$goog$module$ModuleLoader_ModuleLoader$LoadStatus$$($JSCompiler_temp$jscomp$688_currentId_trustedRequestUris$jscomp$inline_4667$$)}else $JSCompiler_temp$jscomp$688_currentId_trustedRequestUris$jscomp$inline_4667$$=new $module$contents$goog$module$ModuleLoader_ModuleLoader$LoadStatus$$([]);$loadStatus_moduleInfoMap$jscomp$1$$=$JSCompiler_temp$jscomp$688_currentId_trustedRequestUris$jscomp$inline_4667$$;
$loadStatus_moduleInfoMap$jscomp$1$$.$loadRequested$=!0;$loadStatus_moduleInfoMap$jscomp$1$$.$successFn$=$loadStatus_moduleInfoMap$jscomp$1$$.$successFn$&&$i$jscomp$470_onSuccess$$?$goog$functions$sequence$$($loadStatus_moduleInfoMap$jscomp$1$$.$successFn$,$i$jscomp$470_onSuccess$$):$i$jscomp$470_onSuccess$$||$loadStatus_moduleInfoMap$jscomp$1$$.$successFn$;$loadStatus_moduleInfoMap$jscomp$1$$.$errorFn$=$onError_prefetchedModuleLoadStatus_successFunctions$$||null;if(this.$useScriptTags_$){if($ids$jscomp$7$$.length>
1){$onError_prefetchedModuleLoadStatus_successFunctions$$=[];for($i$jscomp$470_onSuccess$$=0;$i$jscomp$470_onSuccess$$<$ids$jscomp$7$$.length;$i$jscomp$470_onSuccess$$++)if($JSCompiler_temp$jscomp$688_currentId_trustedRequestUris$jscomp$inline_4667$$=$ids$jscomp$7$$[$i$jscomp$470_onSuccess$$],$i$jscomp$inline_4668_prefetchedModuleLoadStatus$jscomp$1$$=this.$loadingModulesStatus_$[[$JSCompiler_temp$jscomp$688_currentId_trustedRequestUris$jscomp$inline_4667$$]])$i$jscomp$inline_4668_prefetchedModuleLoadStatus$jscomp$1$$.$successFn$&&
$onError_prefetchedModuleLoadStatus_successFunctions$$.push($i$jscomp$inline_4668_prefetchedModuleLoadStatus$jscomp$1$$.$successFn$),delete this.$loadingModulesStatus_$[[$JSCompiler_temp$jscomp$688_currentId_trustedRequestUris$jscomp$inline_4667$$]];$loadStatus_moduleInfoMap$jscomp$1$$.$successFn$&&$onError_prefetchedModuleLoadStatus_successFunctions$$.push($loadStatus_moduleInfoMap$jscomp$1$$.$successFn$);$onError_prefetchedModuleLoadStatus_successFunctions$$.length>0&&($loadStatus_moduleInfoMap$jscomp$1$$.$successFn$=
$goog$functions$sequence$$.apply(null,$onError_prefetchedModuleLoadStatus_successFunctions$$))}this.$loadingModulesStatus_$[$ids$jscomp$7$$]=$loadStatus_moduleInfoMap$jscomp$1$$;$JSCompiler_StaticMethods_downloadModules_$$(this,$ids$jscomp$7$$)}else($onError_prefetchedModuleLoadStatus_successFunctions$$=this.$loadingModulesStatus_$[$ids$jscomp$7$$])?$onError_prefetchedModuleLoadStatus_successFunctions$$.$responseTexts$!=null&&$JSCompiler_StaticMethods_evaluateCode_$$(this,$ids$jscomp$7$$):(this.$loadingModulesStatus_$[$ids$jscomp$7$$]=
$loadStatus_moduleInfoMap$jscomp$1$$,$JSCompiler_StaticMethods_downloadModules_$$(this,$ids$jscomp$7$$))};
$APP.$JSCompiler_prototypeAlias$$.$handleSuccess_$=function($bulkLoader$$,$moduleIds$jscomp$4$$){$goog$log$info$$(this.$logger$,"Code loaded for module(s): "+$moduleIds$jscomp$4$$);const $loadStatus$jscomp$2$$=this.$loadingModulesStatus_$[$moduleIds$jscomp$4$$];$loadStatus$jscomp$2$$.$responseTexts$=$bulkLoader$$.$getResponseTexts$();$loadStatus$jscomp$2$$.$loadRequested$&&$JSCompiler_StaticMethods_evaluateCode_$$(this,$moduleIds$jscomp$4$$);$goog$Timer$callOnce$$($bulkLoader$$.dispose,5,$bulkLoader$$)};
$APP.$JSCompiler_prototypeAlias$$.$handleError_$=function($bulkLoader$jscomp$2$$,$moduleIds$jscomp$5$$,$event$jscomp$39$$){const $loadStatus$jscomp$6$$=this.$loadingModulesStatus_$[$moduleIds$jscomp$5$$];$loadStatus$jscomp$6$$&&(delete this.$loadingModulesStatus_$[$moduleIds$jscomp$5$$],$JSCompiler_StaticMethods_handleErrorHelper_$$(this,$moduleIds$jscomp$5$$,$loadStatus$jscomp$6$$.$errorFn$,$event$jscomp$39$$.status));$goog$Timer$callOnce$$($bulkLoader$jscomp$2$$.dispose,5,$bulkLoader$jscomp$2$$)};
var $module$contents$goog$module$ModuleLoader_ModuleLoader$EventType$EVALUATE_CODE$$=new $goog$events$EventId$$("evaluateCode$0"),$module$contents$goog$module$ModuleLoader_ModuleLoader$EventType$REQUEST_SUCCESS$$=new $goog$events$EventId$$("requestSuccess$1"),$module$contents$goog$module$ModuleLoader_ModuleLoader$EventType$REQUEST_ERROR$$=new $goog$events$EventId$$("requestError$2");$APP.$goog$inherits$$($module$contents$goog$module$ModuleLoader_ModuleLoader$EvaluateCodeEvent$$,$APP.$goog$events$Event$$);
$APP.$goog$inherits$$($module$contents$goog$module$ModuleLoader_ModuleLoader$RequestSuccessEvent$$,$APP.$goog$events$Event$$);$APP.$goog$inherits$$($module$contents$goog$module$ModuleLoader_ModuleLoader$RequestErrorEvent$$,$APP.$goog$events$Event$$);var $module$contents$shadow$loader_ml$$=new $module$contents$goog$module$ModuleLoader_ModuleLoader$$;$module$contents$shadow$loader_ml$$.$sourceUrlInjection_$=!0;
!$module$contents$goog$loader$activeModuleManager_moduleManager$$&&$module$contents$goog$loader$activeModuleManager_getDefault$$&&($module$contents$goog$loader$activeModuleManager_moduleManager$$=$module$contents$goog$loader$activeModuleManager_getDefault$$(),$module$contents$goog$loader$activeModuleManager_configureFunctions$$.forEach($configureFn$jscomp$inline_14206$$=>{$configureFn$jscomp$inline_14206$$($module$contents$goog$loader$activeModuleManager_moduleManager$$)}),$module$contents$goog$loader$activeModuleManager_configureFunctions$$=
[]);$module$contents$goog$loader$activeModuleManager_moduleManager$$.$loader_$=$module$contents$shadow$loader_ml$$;var $rumext$v2$browser_context_QMARK_$$,$rumext$v2$useLayoutEffect$$,$rumext$v2$useCallback$$,$rumext$v2$adapt_sym$$,$rumext$v2$noop$$;$rumext$v2$browser_context_QMARK_$$=typeof window!=="undefined";$APP.$rumext$v2$Fragment$$=$shadow$js$shim$module$0react$$.Fragment;$APP.$rumext$v2$Suspense$$=$shadow$js$shim$module$0react$$.Suspense;$cljs$core$UUID$$.prototype.$cljs$core$INamed$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$cljs$core$UUID$$.prototype.$cljs$core$INamed$_name$arity$1$=function(){return""+this};
$cljs$core$UUID$$.prototype.$cljs$core$INamed$_namespace$arity$1$=function(){return""};$APP.$rumext$v2$jsx$$=$shadow$js$shim$module$0react$0jsx_runtime$$.jsx;$APP.$rumext$v2$jsxs$$=$shadow$js$shim$module$0react$0jsx_runtime$$.jsxs;$APP.$rumext$v2$forward_ref$$=$shadow$js$shim$module$0react$$.forwardRef;$APP.$rumext$v2$portal$$=$shadow$js$shim$module$0react_dom$$.createPortal;$APP.$rumext$v2$create_root$$=$shadow$js$shim$module$0react_dom$0client$$.createRoot;$APP.$rumext$v2$lazy$$=$shadow$js$shim$module$0react$$.lazy;
$APP.$rumext$v2$create_context$$=$shadow$js$shim$module$0react$$.createContext;$APP.$rumext$v2$useRef$$=$shadow$js$shim$module$0react$$.useRef;$APP.$rumext$v2$useState$$=$shadow$js$shim$module$0react$$.useState;$APP.$rumext$v2$useEffect$$=$shadow$js$shim$module$0react$$.useEffect;$rumext$v2$useLayoutEffect$$=$shadow$js$shim$module$0react$$.useLayoutEffect;$APP.$rumext$v2$useMemo$$=$shadow$js$shim$module$0react$$.useMemo;$rumext$v2$useCallback$$=$shadow$js$shim$module$0react$$.useCallback;
$rumext$v2$adapt_sym$$=Symbol("rumext:adapt-fn");$cljs$core$UUID$$.prototype[$rumext$v2$adapt_sym$$]=function($o$jscomp$229$$){return $o$jscomp$229$$.uuid};$APP.$cljs$core$Keyword$$.prototype[$rumext$v2$adapt_sym$$]=function($o$jscomp$230$$){return $o$jscomp$230$$.toString()};$APP.$cljs$core$Symbol$$.prototype[$rumext$v2$adapt_sym$$]=function($o$jscomp$231$$){return $o$jscomp$231$$.toString()};$APP.$rumext$v2$use_ref$$=$shadow$js$shim$module$0react$$.useRef;$APP.$rumext$v2$use_ctx$$=$shadow$js$shim$module$0react$$.useContext;
$APP.$rumext$v2$use_id$$=$shadow$js$shim$module$0react$$.useId;$rumext$v2$noop$$=$APP.$cljs$core$constantly$$(null);$APP.$JSCompiler_prototypeAlias$$=$rumext$v2$State$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReset$_reset_BANG_$arity$2$=function($_$jscomp$1046$$,$value__$1$jscomp$3$$){return this.$update_fn$($value__$1$jscomp$3$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$2$=function($self$jscomp$67$$,$f$jscomp$734$$){return this.$update_fn$($f$jscomp$734$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$3$=function($self$jscomp$68$$,$f$jscomp$735$$,$x$jscomp$1084$$){return this.$update_fn$(function($p1__44909_SHARP_$$){return $f$jscomp$735$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$735$$.$cljs$core$IFn$_invoke$arity$2$($p1__44909_SHARP_$$,$x$jscomp$1084$$):$f$jscomp$735$$($p1__44909_SHARP_$$,$x$jscomp$1084$$)})};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$4$=function($self$jscomp$69$$,$f$jscomp$736$$,$x$jscomp$1085$$,$y$jscomp$342$$){return this.$update_fn$(function($p1__44910_SHARP_$$){return $f$jscomp$736$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$736$$.$cljs$core$IFn$_invoke$arity$3$($p1__44910_SHARP_$$,$x$jscomp$1085$$,$y$jscomp$342$$):$f$jscomp$736$$($p1__44910_SHARP_$$,$x$jscomp$1085$$,$y$jscomp$342$$)})};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$5$=function($self$jscomp$70$$,$f$jscomp$737$$,$x$jscomp$1086$$,$y$jscomp$343$$,$more$jscomp$48$$){return this.$update_fn$(function($p1__44911_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($f$jscomp$737$$,$p1__44911_SHARP_$$,$x$jscomp$1086$$,$y$jscomp$343$$,$more$jscomp$48$$)})};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDeref$_deref$arity$1$=function(){return this.value};
$APP.$rumext$v2$create_element$$=$shadow$js$shim$module$0react$$.createElement;$APP.$rumext$v2$memo_SINGLEQUOTE_$$=$shadow$js$shim$module$0react$$.memo;var $app$util$perf$longtask_observer_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$app$util$perf$stall_timer_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$app$util$perf$current_op_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$app$util$globals$FormData$$.prototype.$app$util$http$IBodyData$_get_body_data$arity$1$=function(){return this};$app$util$globals$FormData$$.prototype.$app$util$http$IBodyData$_update_headers$arity$2$=function($_$jscomp$1054$$,$headers$jscomp$3$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($headers$jscomp$3$$,"content-type",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Content-Type"]))};$app$util$http$_get_body_data$$._=function($it$jscomp$136$$){return $it$jscomp$136$$};
$app$util$http$_update_headers$$._=function($_$jscomp$1055$$,$headers$jscomp$4$$){return $headers$jscomp$4$$};var $app$util$http$network_averages$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$APP.$app$util$http$t_app$0util$0http45214$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_45216$$,$meta45215__$1$$){return new $APP.$app$util$http$t_app$0util$0http45214$$(this.data,$meta45215__$1$$)};
$APP.$app$util$http$t_app$0util$0http45214$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta45215$};$APP.$app$util$http$t_app$0util$0http45214$$.prototype.$app$util$http$IBodyData$_get_body_data$arity$1$=function(){return $APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$(this.data,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$1589$json_verbose$$],null))};
$APP.$app$util$http$t_app$0util$0http45214$$.prototype.$app$util$http$IBodyData$_update_headers$arity$2$=function($_$jscomp$1057$$,$headers$jscomp$7$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($headers$jscomp$7$$,"content-type","application/transit+json")};
var $app$util$http$fetch_data_uri$$=function $app$util$http$fetch_data_uri$$($var_args$jscomp$861$$){switch(arguments.length){case 1:return $app$util$http$fetch_data_uri$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$util$http$fetch_data_uri$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$util$http$fetch_data_uri$$.$cljs$core$IFn$_invoke$arity$1$=function($uri$jscomp$64$$){return $app$util$http$fetch_data_uri$$.$cljs$core$IFn$_invoke$arity$2$($uri$jscomp$64$$,!1)};
$app$util$http$fetch_data_uri$$.$cljs$core$IFn$_invoke$arity$2$=function($uri$jscomp$65$$,$throw_err_QMARK_$$){var $request_str$$=$app$util$cache$with_cache$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$uri$jscomp$65$$,$cljs$cst$1568$max_age$$,144E5],null),$APP.$beicon$v2$core$map$$(function($p1__45242_SHARP_$$){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$uri$jscomp$65$$],[$p1__45242_SHARP_$$])},$APP.$beicon$v2$core$mapcat$$($APP.$app$util$webapi$read_file_as_data_url$$,
$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1581$body$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($resp$$){if($APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($resp$$)<200||$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($resp$$)>=300)throw Error("Error fetching data uri",{cause:$APP.$cljs$core$clj__GT_js$$($resp$$)});return null},$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$1297$get$$,
$APP.$cljs$cst$1579$uri$$,$uri$jscomp$65$$,$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$1591$blob$$,$APP.$cljs$cst$1582$omit_default_headers$$,!0],null)))))));return $APP.$cljs$core$not$$($throw_err_QMARK_$$)?$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$empty$$()},$request_str$$):$request_str$$};$app$util$http$fetch_data_uri$$.$cljs$lang$maxFixedArity$=2;var $app$common$types$team$valid_roles$$,$app$common$types$team$permissions_for_role$$;$app$common$types$team$valid_roles$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1592$viewer$$,null,$cljs$cst$1593$admin$$,null,$APP.$cljs$cst$1594$editor$$,null,$cljs$cst$1595$owner$$,null],null),null);
$app$common$types$team$permissions_for_role$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1592$viewer$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1596$can_edit$$,!1,$APP.$cljs$cst$1597$is_admin$$,!1,$APP.$cljs$cst$1598$is_owner$$,!1],null),$APP.$cljs$cst$1594$editor$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1596$can_edit$$,!0,$APP.$cljs$cst$1597$is_admin$$,!1,$APP.$cljs$cst$1598$is_owner$$,!1],null),$cljs$cst$1593$admin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1596$can_edit$$,!0,$APP.$cljs$cst$1597$is_admin$$,!0,$APP.$cljs$cst$1598$is_owner$$,!1],null),$cljs$cst$1595$owner$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1596$can_edit$$,!0,$APP.$cljs$cst$1597$is_admin$$,!0,$APP.$cljs$cst$1598$is_owner$$,!0],null)],null);
$APP.$app$common$types$team$schema_COLON_team_name$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,250],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$945$error_SLASH_code$$,"errors.team-name-invalid-chars"],null),function($s$jscomp$510$$){return $APP.$cljs$core$not$$($APP.$cljs$core$re_find$$(/[.:\/]/,$s$jscomp$510$$))}],null)],null);var $app$common$geom$matrix$base$$;$APP.$JSCompiler_prototypeAlias$$=$app$common$geom$matrix$Matrix$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$app$common$geom$matrix$format_precision$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$geom$matrix$format_precision$$.$cljs$core$IFn$_invoke$arity$2$(this,6):$APP.$app$common$geom$matrix$format_precision$$(this,6)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this$$jscomp$611$$,$f__42602__auto__$jscomp$2$$,$init__42603__auto__$jscomp$2$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__42604__auto__$jscomp$2$$,$p__45950_v__42605__auto__$jscomp$2$$){var $key_45913$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45950_v__42605__auto__$jscomp$2$$,0,null);$p__45950_v__42605__auto__$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45950_v__42605__auto__$jscomp$2$$,
1,null);return $f__42602__auto__$jscomp$2$$.$cljs$core$IFn$_invoke$arity$3$?$f__42602__auto__$jscomp$2$$.$cljs$core$IFn$_invoke$arity$3$($ret__42604__auto__$jscomp$2$$,$key_45913$$,$p__45950_v__42605__auto__$jscomp$2$$):$f__42602__auto__$jscomp$2$$($ret__42604__auto__$jscomp$2$$,$key_45913$$,$p__45950_v__42605__auto__$jscomp$2$$)},$init__42603__auto__$jscomp$2$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$612$$,$other$jscomp$174$$){return this===$other$jscomp$174$$||$other$jscomp$174$$!=null&&this.constructor===$other$jscomp$174$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.a,$other$jscomp$174$$.a)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.b,$other$jscomp$174$$.b)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.c,$other$jscomp$174$$.c)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.d,
$other$jscomp$174$$.d)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.e,$other$jscomp$174$$.e)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.f,$other$jscomp$174$$.f)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$$extmap$,$other$jscomp$174$$.$$extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__42526__auto__$jscomp$2_h__42526__auto____$1$jscomp$2$$=this.$$hash$;return $h__42526__auto__$jscomp$2_h__42526__auto____$1$jscomp$2$$!=null?$h__42526__auto__$jscomp$2_h__42526__auto____$1$jscomp$2$$:this.$$hash$=$h__42526__auto__$jscomp$2_h__42526__auto____$1$jscomp$2$$=-814985099^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this$$jscomp$614$$,$val_45914$$){return $APP.$cljs$core$vector_QMARK_$$($val_45914$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($val_45914$$,0),$APP.$cljs$core$_nth$$($val_45914$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$val_45914$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 6+$APP.$cljs$core$count$$(this.$$extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1519$a$$,this.a,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1520$b$$,this.b,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1521$c$$,this.c,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1447$d$$,
this.d,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1449$e$$,this.e,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$598$f$$,this.f,null)],null),this.$$extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$$meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $app$common$geom$matrix$Matrix$$(this.a,this.b,this.c,this.d,this.e,this.f,this.$$meta$,this.$$extmap$,this.$$hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$620$$,$writer__42713__auto__$jscomp$2$$,$opts__42714__auto__$jscomp$2$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__42713__auto__$jscomp$2$$,function($keyval__42716__auto__$jscomp$2$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__42713__auto__$jscomp$2$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__42714__auto__$jscomp$2$$,$keyval__42716__auto__$jscomp$2$$)},"#app.common.geom.matrix.Matrix{",
", ","}",$opts__42714__auto__$jscomp$2$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1519$a$$,this.a],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1520$b$$,this.b],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1521$c$$,this.c],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1447$d$$,this.d],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1449$e$$,this.e],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$598$f$$,this.f],null)],null),this.$$extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,6,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1519$a$$,$APP.$cljs$cst$1520$b$$,$cljs$cst$1521$c$$,$cljs$cst$1447$d$$,$cljs$cst$1449$e$$,$cljs$cst$598$f$$],null),$APP.$cljs$core$truth_$$(this.$$extmap$)?$APP.$cljs$core$_iterator$$(this.$$extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$=function($this$$jscomp$622$$,$key_45913$jscomp$1$$,$val_45914$jscomp$1$$){switch($key_45913$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$key_45913$jscomp$1$$.$fqn$:null){case "a":this.a=$val_45914$jscomp$1$$;break;case "b":this.b=$val_45914$jscomp$1$$;break;case "c":this.c=$val_45914$jscomp$1$$;break;case "d":this.d=$val_45914$jscomp$1$$;break;case "e":this.e=$val_45914$jscomp$1$$;break;case "f":this.f=$val_45914$jscomp$1$$;
break;default:this.$$extmap$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$$extmap$,$key_45913$jscomp$1$$,$val_45914$jscomp$1$$)}return this};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this$$jscomp$623$$,$val_45914$jscomp$2$$){return new $app$common$geom$matrix$Matrix$$(this.a,this.b,this.c,this.d,this.e,this.f,$val_45914$jscomp$2$$,this.$$extmap$,this.$$hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this$$jscomp$624$$,$key_45913$jscomp$2$$){switch($key_45913$jscomp$2$$ instanceof $APP.$cljs$core$Keyword$$?$key_45913$jscomp$2$$.$fqn$:null){case "a":case "b":case "c":case "d":case "e":case "f":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$$extmap$,$key_45913$jscomp$2$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this$$jscomp$625$$,$key_45913$jscomp$3$$,$val_45914$jscomp$3$$){switch($key_45913$jscomp$3$$ instanceof $APP.$cljs$core$Keyword$$?$key_45913$jscomp$3$$.$fqn$:null){case "a":return new $app$common$geom$matrix$Matrix$$($val_45914$jscomp$3$$,this.b,this.c,this.d,this.e,this.f,this.$$meta$,this.$$extmap$,null);case "b":return new $app$common$geom$matrix$Matrix$$(this.a,$val_45914$jscomp$3$$,this.c,this.d,this.e,this.f,
this.$$meta$,this.$$extmap$,null);case "c":return new $app$common$geom$matrix$Matrix$$(this.a,this.b,$val_45914$jscomp$3$$,this.d,this.e,this.f,this.$$meta$,this.$$extmap$,null);case "d":return new $app$common$geom$matrix$Matrix$$(this.a,this.b,this.c,$val_45914$jscomp$3$$,this.e,this.f,this.$$meta$,this.$$extmap$,null);case "e":return new $app$common$geom$matrix$Matrix$$(this.a,this.b,this.c,this.d,$val_45914$jscomp$3$$,this.f,this.$$meta$,this.$$extmap$,null);case "f":return new $app$common$geom$matrix$Matrix$$(this.a,
this.b,this.c,this.d,this.e,$val_45914$jscomp$3$$,this.$$meta$,this.$$extmap$,null);default:return new $app$common$geom$matrix$Matrix$$(this.a,this.b,this.c,this.d,this.e,this.f,this.$$meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$$extmap$,$key_45913$jscomp$3$$,$val_45914$jscomp$3$$),null)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($extmap1__42599__auto__$jscomp$2_this$$jscomp$626$$,$extmap2__42600__auto__$jscomp$2_key_45913$jscomp$4$$){switch($extmap2__42600__auto__$jscomp$2_key_45913$jscomp$4$$ instanceof $APP.$cljs$core$Keyword$$?$extmap2__42600__auto__$jscomp$2_key_45913$jscomp$4$$.$fqn$:null){case "a":case "b":case "c":case "d":case "e":case "f":return this.$cljs$core$IAssociative$_assoc$arity$3$(null,$extmap2__42600__auto__$jscomp$2_key_45913$jscomp$4$$,
null);default:return $extmap1__42599__auto__$jscomp$2_this$$jscomp$626$$=this.$$extmap$,$extmap2__42600__auto__$jscomp$2_key_45913$jscomp$4$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($extmap1__42599__auto__$jscomp$2_this$$jscomp$626$$,$extmap2__42600__auto__$jscomp$2_key_45913$jscomp$4$$),$extmap1__42599__auto__$jscomp$2_this$$jscomp$626$$===$extmap2__42600__auto__$jscomp$2_key_45913$jscomp$4$$?this:new $app$common$geom$matrix$Matrix$$(this.a,this.b,this.c,this.d,this.e,this.f,this.$$meta$,
$APP.$cljs$core$not_empty$$($extmap2__42600__auto__$jscomp$2_key_45913$jscomp$4$$),null)}};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this$$jscomp$627$$,$k__42595__auto__$jscomp$2$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__42595__auto__$jscomp$2$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this$$jscomp$628$$,$key_45913$jscomp$5$$,$else__42596__auto__$jscomp$2$$){switch($key_45913$jscomp$5$$ instanceof $APP.$cljs$core$Keyword$$?$key_45913$jscomp$5$$.$fqn$:null){case "a":return this.a;case "b":return this.b;case "c":return this.c;case "d":return this.d;case "e":return this.e;case "f":return this.f;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$$extmap$,$key_45913$jscomp$5$$,$else__42596__auto__$jscomp$2$$)}};
$APP.$app$common$geom$matrix$matrix$$=function $app$common$geom$matrix$matrix$$($var_args$jscomp$862$$){switch(arguments.length){case 0:return $app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$();case 6:return $app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$6$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $app$common$geom$matrix$pos__GT_Matrix$$(1,0,0,1,0,0)};$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$6$=function($a$jscomp$336$$,$b$jscomp$261$$,$c$jscomp$258$$,$d$jscomp$216$$,$e$jscomp$281$$,$f$jscomp$747$$){return $app$common$geom$matrix$pos__GT_Matrix$$($a$jscomp$336$$,$b$jscomp$261$$,$c$jscomp$258$$,$d$jscomp$216$$,$e$jscomp$281$$,$f$jscomp$747$$)};
$APP.$app$common$geom$matrix$matrix$$.$cljs$lang$maxFixedArity$=6;
var $app$common$geom$matrix$valid_matrix_QMARK_$$=$app$common$schema$validator$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$common$geom$matrix$matrix_QMARK_$$],null),new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$939$title$$,"MatrixAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1519$a$$,$cljs$cst$962$app_DOT_common_DOT_schema_SLASH_safe_double$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1520$b$$,$cljs$cst$962$app_DOT_common_DOT_schema_SLASH_safe_double$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$1521$c$$,$cljs$cst$962$app_DOT_common_DOT_schema_SLASH_safe_double$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1447$d$$,$cljs$cst$962$app_DOT_common_DOT_schema_SLASH_safe_double$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1449$e$$,$cljs$cst$962$app_DOT_common_DOT_schema_SLASH_safe_double$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$598$f$$,$cljs$cst$962$app_DOT_common_DOT_schema_SLASH_safe_double$$],null)],null)],null)),$app$common$geom$matrix$number_regex$$=/[+-]?\d*(\.\d+)?([eE][+-]?\d+)?/;
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$1603$app_DOT_common_DOT_geom_DOT_matrix_SLASH_matrix$$,$APP.$cljs$cst$351$pred$$,$app$common$geom$matrix$valid_matrix_QMARK_$$,$cljs$cst$415$type_properties$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$936$description$$,$cljs$cst$937$decode_SLASH_string$$,$APP.$cljs$cst$938$decode_SLASH_json$$,$APP.$cljs$cst$939$title$$,$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,
$cljs$cst$941$encode_SLASH_json$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,$cljs$cst$869$gen_SLASH_gen$$,$APP.$cljs$cst$882$error_SLASH_message$$,$cljs$cst$943$encode_SLASH_string$$],["Matrix instance",$app$common$geom$matrix$decode_matrix$$,$app$common$geom$matrix$decode_matrix$$,"matrix","matrix",function($o$jscomp$234$$){return $app$common$geom$matrix$matrix_QMARK_$$($o$jscomp$234$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$o$jscomp$234$$):$o$jscomp$234$$},"string",$app$common$schema$generators$fmap$$(function($p1__46031_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($app$common$geom$matrix$pos__GT_Matrix$$,$p1__46031_SHARP_$$)},$app$common$schema$generators$tuple$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$schema$generators$small_double$$(),$app$common$schema$generators$small_double$$(),$app$common$schema$generators$small_double$$(),
$app$common$schema$generators$small_double$$(),$app$common$schema$generators$small_double$$(),$app$common$schema$generators$small_double$$()]))),"expected a valid matrix instance",function($o$jscomp$233$$){return $app$common$geom$matrix$matrix_QMARK_$$($o$jscomp$233$$)?""+($o$jscomp$233$$?.a??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$233$$,$APP.$cljs$cst$1519$a$$)??"")+","+($o$jscomp$233$$?.b??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$233$$,$APP.$cljs$cst$1520$b$$)??
"")+","+($o$jscomp$233$$?.c??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$233$$,$cljs$cst$1521$c$$)??"")+","+($o$jscomp$233$$?.d??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$233$$,$cljs$cst$1447$d$$)??"")+","+($o$jscomp$233$$?.e??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$233$$,$cljs$cst$1449$e$$)??"")+","+($o$jscomp$233$$?.f??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$233$$,$cljs$cst$598$f$$)??""):$o$jscomp$233$$}])],
null));
$APP.$app$common$geom$matrix$multiply$$=function $app$common$geom$matrix$multiply$$($var_args$jscomp$863$$){switch(arguments.length){case 2:return $app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$95$$=[],$len__5749__auto___46389$$=arguments.length,$i__5750__auto___46390$$=0;;)if($i__5750__auto___46390$$<$len__5749__auto___46389$$)$args_arr__5774__auto__$jscomp$95$$.push(arguments[$i__5750__auto___46390$$]),$i__5750__auto___46390$$+=
1;else break;return $app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$95$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$95$$.slice(2),0,null):null)}};
$APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$=function($m1$jscomp$10$$,$m2$jscomp$7_m2f$jscomp$1$$){if($m1$jscomp$10$$==null&&$m2$jscomp$7_m2f$jscomp$1$$==null)return $APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$();if($m1$jscomp$10$$==null)return $m2$jscomp$7_m2f$jscomp$1$$;if($m2$jscomp$7_m2f$jscomp$1$$==null)return $m1$jscomp$10$$;var $m1a$jscomp$1$$=$m1$jscomp$10$$.a,$m1b$jscomp$1$$=$m1$jscomp$10$$.b,$m1c$jscomp$1$$=$m1$jscomp$10$$.c,$m1d$jscomp$1$$=
$m1$jscomp$10$$.d,$m2a$jscomp$1$$=$m2$jscomp$7_m2f$jscomp$1$$.a,$m2b$jscomp$1$$=$m2$jscomp$7_m2f$jscomp$1$$.b,$m2c$jscomp$1$$=$m2$jscomp$7_m2f$jscomp$1$$.c,$m2d$jscomp$1$$=$m2$jscomp$7_m2f$jscomp$1$$.d,$m2e$jscomp$1$$=$m2$jscomp$7_m2f$jscomp$1$$.e;$m2$jscomp$7_m2f$jscomp$1$$=$m2$jscomp$7_m2f$jscomp$1$$.f;return $app$common$geom$matrix$pos__GT_Matrix$$($m1a$jscomp$1$$*$m2a$jscomp$1$$+$m1c$jscomp$1$$*$m2b$jscomp$1$$,$m1b$jscomp$1$$*$m2a$jscomp$1$$+$m1d$jscomp$1$$*$m2b$jscomp$1$$,$m1a$jscomp$1$$*$m2c$jscomp$1$$+
$m1c$jscomp$1$$*$m2d$jscomp$1$$,$m1b$jscomp$1$$*$m2c$jscomp$1$$+$m1d$jscomp$1$$*$m2d$jscomp$1$$,$m1a$jscomp$1$$*$m2e$jscomp$1$$+$m1c$jscomp$1$$*$m2$jscomp$7_m2f$jscomp$1$$+$m1$jscomp$10$$.e,$m1b$jscomp$1$$*$m2e$jscomp$1$$+$m1d$jscomp$1$$*$m2$jscomp$7_m2f$jscomp$1$$+$m1$jscomp$10$$.f)};
$APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$variadic$=function($m1$jscomp$11$$,$m2$jscomp$8$$,$others$jscomp$1$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$geom$matrix$multiply_BANG_$$,$APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($m1$jscomp$11$$,$m2$jscomp$8$$),$others$jscomp$1$$)};
$APP.$app$common$geom$matrix$multiply$$.$cljs$lang$applyTo$=function($G__46070_seq46068$$){var $G__46069$$=$APP.$cljs$core$first$$($G__46070_seq46068$$),$seq46068__$1_seq46068__$2$$=$APP.$cljs$core$next$$($G__46070_seq46068$$);$G__46070_seq46068$$=$APP.$cljs$core$first$$($seq46068__$1_seq46068__$2$$);$seq46068__$1_seq46068__$2$$=$APP.$cljs$core$next$$($seq46068__$1_seq46068__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__46069$$,$G__46070_seq46068$$,$seq46068__$1_seq46068__$2$$)};
$APP.$app$common$geom$matrix$multiply$$.$cljs$lang$maxFixedArity$=2;$app$common$geom$matrix$base$$=$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$();
$APP.$app$common$geom$matrix$translate_matrix$$=function $app$common$geom$matrix$translate_matrix$$($var_args$jscomp$865$$){switch(arguments.length){case 1:return $app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$=function($pt$jscomp$10$$){return $app$common$geom$matrix$pos__GT_Matrix$$(1,0,0,1,$pt$jscomp$10$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$10$$,$APP.$cljs$cst$1510$x$$),$pt$jscomp$10$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$10$$,$APP.$cljs$cst$1511$y$$))};
$APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$1087$$,$y$jscomp$344$$){return $app$common$geom$matrix$pos__GT_Matrix$$(1,0,0,1,$x$jscomp$1087$$,$y$jscomp$344$$)};$APP.$app$common$geom$matrix$translate_matrix$$.$cljs$lang$maxFixedArity$=2;
var $app$common$geom$matrix$scale_matrix$$=function $app$common$geom$matrix$scale_matrix$$($var_args$jscomp$867$$){switch(arguments.length){case 2:return $app$common$geom$matrix$scale_matrix$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$geom$matrix$scale_matrix$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$common$geom$matrix$scale_matrix$$.$cljs$core$IFn$_invoke$arity$2$=function($pt$jscomp$12_sy$jscomp$8$$,$center$jscomp$3_cy$jscomp$3$$){var $sx$jscomp$9$$=$pt$jscomp$12_sy$jscomp$8$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$12_sy$jscomp$8$$,$APP.$cljs$cst$1510$x$$);$pt$jscomp$12_sy$jscomp$8$$=$pt$jscomp$12_sy$jscomp$8$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$12_sy$jscomp$8$$,$APP.$cljs$cst$1511$y$$);var $cx$jscomp$3$$=$center$jscomp$3_cy$jscomp$3$$?.x??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$3_cy$jscomp$3$$,$APP.$cljs$cst$1510$x$$);$center$jscomp$3_cy$jscomp$3$$=$center$jscomp$3_cy$jscomp$3$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$3_cy$jscomp$3$$,$APP.$cljs$cst$1511$y$$);return $app$common$geom$matrix$pos__GT_Matrix$$($sx$jscomp$9$$,0,0,$pt$jscomp$12_sy$jscomp$8$$,$cx$jscomp$3$$-$cx$jscomp$3$$*$sx$jscomp$9$$,$center$jscomp$3_cy$jscomp$3$$-$center$jscomp$3_cy$jscomp$3$$*$pt$jscomp$12_sy$jscomp$8$$)};
$app$common$geom$matrix$scale_matrix$$.$cljs$core$IFn$_invoke$arity$1$=function($pt$jscomp$13$$){return $app$common$geom$matrix$pos__GT_Matrix$$($pt$jscomp$13$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$13$$,$APP.$cljs$cst$1510$x$$),0,0,$pt$jscomp$13$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$13$$,$APP.$cljs$cst$1511$y$$),0,0)};$app$common$geom$matrix$scale_matrix$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$geom$matrix$rotate_matrix$$=function $app$common$geom$matrix$rotate_matrix$$($var_args$jscomp$868$$){switch(arguments.length){case 2:return $app$common$geom$matrix$rotate_matrix$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$geom$matrix$rotate_matrix$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$geom$matrix$rotate_matrix$$.$cljs$core$IFn$_invoke$arity$2$=function($angle$jscomp$14_c$jscomp$259$$,$cy$jscomp$4_point$jscomp$8$$){var $cx$jscomp$4$$=$cy$jscomp$4_point$jscomp$8$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cy$jscomp$4_point$jscomp$8$$,$APP.$cljs$cst$1510$x$$);$cy$jscomp$4_point$jscomp$8$$=$cy$jscomp$4_point$jscomp$8$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cy$jscomp$4_point$jscomp$8$$,$APP.$cljs$cst$1511$y$$);var $nx$$=-$cx$jscomp$4$$,
$ny$$=-$cy$jscomp$4_point$jscomp$8$$,$a$jscomp$337_s$jscomp$511$$=$APP.$goog$math$toRadians$$($angle$jscomp$14_c$jscomp$259$$);$angle$jscomp$14_c$jscomp$259$$=Math.cos($a$jscomp$337_s$jscomp$511$$);$a$jscomp$337_s$jscomp$511$$=Math.sin($a$jscomp$337_s$jscomp$511$$);var $ns$jscomp$32$$=-$a$jscomp$337_s$jscomp$511$$;return $app$common$geom$matrix$pos__GT_Matrix$$($angle$jscomp$14_c$jscomp$259$$,$a$jscomp$337_s$jscomp$511$$,$ns$jscomp$32$$,$angle$jscomp$14_c$jscomp$259$$,$angle$jscomp$14_c$jscomp$259$$*
$nx$$+$ns$jscomp$32$$*$ny$$+$cx$jscomp$4$$,$a$jscomp$337_s$jscomp$511$$*$nx$$+$angle$jscomp$14_c$jscomp$259$$*$ny$$+$cy$jscomp$4_point$jscomp$8$$)};
$APP.$app$common$geom$matrix$rotate_matrix$$.$cljs$core$IFn$_invoke$arity$1$=function($a$jscomp$338_angle$jscomp$15$$){$a$jscomp$338_angle$jscomp$15$$=$APP.$goog$math$toRadians$$($a$jscomp$338_angle$jscomp$15$$);return $app$common$geom$matrix$pos__GT_Matrix$$(Math.cos($a$jscomp$338_angle$jscomp$15$$),Math.sin($a$jscomp$338_angle$jscomp$15$$),-Math.sin($a$jscomp$338_angle$jscomp$15$$),Math.cos($a$jscomp$338_angle$jscomp$15$$),0,0)};
$APP.$app$common$geom$matrix$rotate_matrix$$.$cljs$lang$maxFixedArity$=2;
var $app$common$geom$matrix$skew_matrix$$=function $app$common$geom$matrix$skew_matrix$$($var_args$jscomp$869$$){switch(arguments.length){case 3:return $app$common$geom$matrix$skew_matrix$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 2:return $app$common$geom$matrix$skew_matrix$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$common$geom$matrix$skew_matrix$$.$cljs$core$IFn$_invoke$arity$3$=function($angle_x$$,$angle_y$$,$point$jscomp$9$$){return $APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$9$$),$app$common$geom$matrix$skew_matrix$$.$cljs$core$IFn$_invoke$arity$2$($angle_x$$,$angle_y$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$point$negate$$($point$jscomp$9$$))]))};
$app$common$geom$matrix$skew_matrix$$.$cljs$core$IFn$_invoke$arity$2$=function($angle_x$jscomp$1$$,$angle_y$jscomp$1$$){return $app$common$geom$matrix$pos__GT_Matrix$$(1,Math.tan($APP.$goog$math$toRadians$$($angle_y$jscomp$1$$)),Math.tan($APP.$goog$math$toRadians$$($angle_x$jscomp$1$$)),1,0,0)};$app$common$geom$matrix$skew_matrix$$.$cljs$lang$maxFixedArity$=3;$cljs$pprint$simple_dispatch$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$app$common$geom$matrix$Matrix$$,function($obj$jscomp$170$$){return $APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$obj$jscomp$170$$]))});
$APP.$app$common$transit$add_handlers_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"matrix",$APP.$cljs$cst$1291$class$$,$app$common$geom$matrix$Matrix$$,$APP.$cljs$cst$1314$wfn$$,function($p1__46351_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$p1__46351_SHARP_$$)},$APP.$cljs$cst$1315$rfn$$,
function($m$jscomp$195$$){return $app$common$geom$matrix$pos__GT_Matrix$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$195$$,$APP.$cljs$cst$1519$a$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$195$$,$APP.$cljs$cst$1520$b$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$195$$,$cljs$cst$1521$c$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$195$$,$cljs$cst$1447$d$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$195$$,
$cljs$cst$1449$e$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($m$jscomp$195$$,$cljs$cst$598$f$$))}],null)]));var $app$common$geom$shapes$common$xf_keep_x$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__46381_SHARP_$$){return $p1__46381_SHARP_$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__46381_SHARP_$$,$APP.$cljs$cst$1510$x$$)}),$app$common$geom$shapes$common$xf_keep_y$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__46384_SHARP_$$){return $p1__46384_SHARP_$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__46384_SHARP_$$,
$APP.$cljs$cst$1511$y$$)});$APP.$app$common$files$helpers$root_frame_QMARK_$$=function $app$common$files$helpers$root_frame_QMARK_$$($var_args$jscomp$876$$){switch(arguments.length){case 2:return $app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$1$$,$id$jscomp$94$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$94$$,$APP.$app$common$uuid$zero$$)?!1:$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$1$$,$id$jscomp$94$$))};
$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function($shape$jscomp$4$$){return $shape$jscomp$4$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$4$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$4$$,$APP.$cljs$cst$266$id$$),$APP.$app$common$uuid$zero$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$4$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$4$$,
$APP.$cljs$cst$139$type$$),$APP.$cljs$cst$1606$frame$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$4$$?.$frame_id$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$4$$,$APP.$cljs$cst$1607$frame_id$$),$APP.$app$common$uuid$zero$$)};$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$files$helpers$frame_shape_QMARK_$$=function $app$common$files$helpers$frame_shape_QMARK_$$($var_args$jscomp$877$$){switch(arguments.length){case 2:return $app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$2$$,$id$jscomp$95$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$2$$,$id$jscomp$95$$))};
$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function($shape$jscomp$5$$){return $shape$jscomp$5$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$shape$jscomp$5$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$5$$,$APP.$cljs$cst$139$type$$))};$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$files$helpers$group_shape_QMARK_$$=function $app$common$files$helpers$group_shape_QMARK_$$($var_args$jscomp$878$$){switch(arguments.length){case 2:return $app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$3$$,$id$jscomp$96$$){return $APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$3$$,$id$jscomp$96$$))};
$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function($shape$jscomp$6$$){return $shape$jscomp$6$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,$shape$jscomp$6$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$6$$,$APP.$cljs$cst$139$type$$))};$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$files$helpers$mask_shape_QMARK_$$=function $app$common$files$helpers$mask_shape_QMARK_$$($var_args$jscomp$879$$){switch(arguments.length){case 1:return $app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function($shape$jscomp$7$$){return $APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$7$$)&&$APP.$cljs$cst$1609$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$7$$)};
$APP.$app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$4$$,$id$jscomp$97$$){return $APP.$app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$4$$,$id$jscomp$97$$))};$APP.$app$common$files$helpers$mask_shape_QMARK_$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$files$helpers$text_shape_QMARK_$$=function $app$common$files$helpers$text_shape_QMARK_$$($var_args$jscomp$880$$){switch(arguments.length){case 1:return $app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function($shape$jscomp$9$$){return $shape$jscomp$9$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$shape$jscomp$9$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$9$$,$APP.$cljs$cst$139$type$$))};
$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$5$$,$id$jscomp$98$$){return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$5$$,$id$jscomp$98$$))};$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$=function $app$common$files$helpers$svg_raw_shape_QMARK_$$($var_args$jscomp$881$$){switch(arguments.length){case 2:return $app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$6$$,$id$jscomp$99$$){return $APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$6$$,$id$jscomp$99$$))};
$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function($shape$jscomp$12$$){return $shape$jscomp$12$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$svg_raw$$,$shape$jscomp$12$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$12$$,$APP.$cljs$cst$139$type$$))};$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$files$helpers$path_shape_QMARK_$$=function $app$common$files$helpers$path_shape_QMARK_$$($var_args$jscomp$882$$){switch(arguments.length){case 2:return $app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$7$$,$id$jscomp$100$$){return $APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$7$$,$id$jscomp$100$$))};
$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function($shape$jscomp$13$$){return $shape$jscomp$13$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,$shape$jscomp$13$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$13$$,$APP.$cljs$cst$139$type$$))};$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$files$helpers$get_children_ids$$=function $app$common$files$helpers$get_children_ids$$($var_args$jscomp$885$$){switch(arguments.length){case 2:return $app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$13$$,$id$jscomp$105$$){return $APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$13$$,$id$jscomp$105$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$3$=function($objects$jscomp$14$$,$id$jscomp$106$$,$map__46582__$1_p__46579$$){$map__46582__$1_p__46579$$=$APP.$cljs$core$__destructure_map$$($map__46582__$1_p__46579$$);var $ignore_children_fn$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__46582__$1_p__46579$$,$cljs$cst$1618$ignore_children_fn$$,$APP.$cljs$core$constantly$$(!1));return function $app$common$files$helpers$get_children_ids_rec$$($id__$1$$,$processed$$){if($APP.$cljs$core$contains_QMARK_$$($processed$$,
$id__$1$$))return null;var $temp__5825__auto__$jscomp$110$$=function(){var $$$jscomp$4_$__$1$jscomp$2_G__46611$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$14$$,$id__$1$$);$$$jscomp$4_$__$1$jscomp$2_G__46611$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($$$jscomp$4_$__$1$jscomp$2_G__46611$$);$$$jscomp$4_$__$1$jscomp$2_G__46611$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($ignore_children_fn$$,$$$jscomp$4_$__$1$jscomp$2_G__46611$$);return $$$jscomp$4_$__$1$jscomp$2_G__46611$$==
null?null:$APP.$cljs$core$vec$$($$$jscomp$4_$__$1$jscomp$2_G__46611$$)}();return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$110$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($temp__5825__auto__$jscomp$110$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__46574_SHARP_$$){return $app$common$files$helpers$get_children_ids_rec$$($p1__46574_SHARP_$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($processed$$,$id__$1$$))}),$temp__5825__auto__$jscomp$110$$):
null}($id$jscomp$106$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$)};$APP.$app$common$files$helpers$get_children_ids$$.$cljs$lang$maxFixedArity$=3;
var $app$common$files$helpers$get_child$$=function $app$common$files$helpers$get_child$$($objects$jscomp$18$$,$id$jscomp$110$$,$child_id$$){var $shape$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$18$$,$id$jscomp$110$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$110$$,$child_id$$)?$shape$jscomp$20$$:$APP.$cljs$core$some$$(function($p1__46648_SHARP_$$){return $app$common$files$helpers$get_child$$.$cljs$core$IFn$_invoke$arity$3$?$app$common$files$helpers$get_child$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$18$$,
$p1__46648_SHARP_$$,$child_id$$):$app$common$files$helpers$get_child$$($objects$jscomp$18$$,$p1__46648_SHARP_$$,$child_id$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$20$$))},$app$common$files$helpers$get_parent_ids_seq$$=function $app$common$files$helpers$get_parent_ids_seq$$($objects$jscomp$22$$,$shape_id$jscomp$1$$){var $parent_id$jscomp$1$$=$APP.$app$common$files$helpers$get_parent_id$$($objects$jscomp$22$$,$shape_id$jscomp$1$$);return $parent_id$jscomp$1$$!=
null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parent_id$jscomp$1$$,$shape_id$jscomp$1$$)?new $APP.$cljs$core$LazySeq$$(null,function(){return $APP.$cljs$core$cons$$($parent_id$jscomp$1$$,$app$common$files$helpers$get_parent_ids_seq$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$files$helpers$get_parent_ids_seq$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$22$$,$parent_id$jscomp$1$$):$app$common$files$helpers$get_parent_ids_seq$$($objects$jscomp$22$$,$parent_id$jscomp$1$$))},
null,null):null};$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1631$objects$$),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$vals$$),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$files$helpers$collect_shape_media_refs$$));var $app$common$types$shape$layout$schema_COLON_grid_track$$,$app$common$types$shape$layout$schema_COLON_layout_attrs$$,$app$common$types$shape$layout$layout_attrs$$,$app$common$types$shape$layout$schema_COLON_layout_child_attrs$$,$app$common$types$shape$layout$layout_child_attrs$$,$app$common$types$shape$layout$grid_cell_defaults$$;
$APP.$app$common$types$shape$layout$flex_direction_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$216$column$$,null,$APP.$cljs$cst$1661$row_reverse$$,null,$APP.$cljs$cst$1662$column_reverse$$,null,$APP.$cljs$cst$1656$row$$,null],null),null);
$APP.$app$common$types$shape$layout$grid_direction_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$216$column$$,null,$APP.$cljs$cst$1656$row$$,null],null),null);$APP.$app$common$types$shape$layout$wrap_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$896$wrap$$,null,$APP.$cljs$cst$1664$nowrap$$,null],null),null);
$APP.$app$common$types$shape$layout$justify_content_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1665$space_around$$,null,$APP.$cljs$cst$1666$space_evenly$$,null,$APP.$cljs$cst$1292$start$$,null,$APP.$cljs$cst$1667$center$$,null,$APP.$cljs$cst$1668$space_between$$,null,$APP.$cljs$cst$1293$end$$,null,$APP.$cljs$cst$1669$stretch$$,null],null),null);
$APP.$app$common$types$shape$layout$align_content_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1665$space_around$$,null,$APP.$cljs$cst$1666$space_evenly$$,null,$APP.$cljs$cst$1292$start$$,null,$APP.$cljs$cst$1667$center$$,null,$APP.$cljs$cst$1668$space_between$$,null,$APP.$cljs$cst$1293$end$$,null,$APP.$cljs$cst$1669$stretch$$,null],null),null);
$APP.$app$common$types$shape$layout$align_items_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1292$start$$,null,$APP.$cljs$cst$1667$center$$,null,$APP.$cljs$cst$1293$end$$,null,$APP.$cljs$cst$1669$stretch$$,null],null),null);
$APP.$app$common$types$shape$layout$justify_items_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1292$start$$,null,$APP.$cljs$cst$1667$center$$,null,$APP.$cljs$cst$1293$end$$,null,$APP.$cljs$cst$1669$stretch$$,null],null),null);
$APP.$app$common$types$shape$layout$grid_track_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1660$flex$$,null,$APP.$cljs$cst$1670$percent$$,null,$APP.$cljs$cst$1671$fixed$$,null,$APP.$cljs$cst$1672$auto$$,null],null),null);
$APP.$app$common$types$shape$layout$grid_position_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1673$manual$$,null,$APP.$cljs$cst$1674$area$$,null,$APP.$cljs$cst$1672$auto$$,null],null),null);
$APP.$app$common$types$shape$layout$grid_cell_align_self_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1292$start$$,null,$APP.$cljs$cst$1667$center$$,null,$APP.$cljs$cst$1293$end$$,null,$APP.$cljs$cst$1669$stretch$$,null,$APP.$cljs$cst$1672$auto$$,null],null),null);
$APP.$app$common$types$shape$layout$grid_cell_justify_self_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1292$start$$,null,$APP.$cljs$cst$1667$center$$,null,$APP.$cljs$cst$1293$end$$,null,$APP.$cljs$cst$1669$stretch$$,null,$APP.$cljs$cst$1672$auto$$,null],null),null);
$app$common$types$shape$layout$schema_COLON_grid_track$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"GridTrack"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,
$APP.$app$common$types$shape$layout$grid_track_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null)],null)],null);
$app$common$types$shape$layout$schema_COLON_layout_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,17,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"LayoutAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1615$layout$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1659$grid$$,null,$APP.$cljs$cst$1660$flex$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1679$layout_flex_dir$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$layout$flex_direction_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1680$layout_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1681$row_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1682$column_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1683$layout_gap_type$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1663$simple$$,null,$APP.$cljs$cst$1616$multiple$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1684$layout_wrap_type$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$layout$wrap_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1685$layout_padding_type$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1663$simple$$,null,$APP.$cljs$cst$1616$multiple$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1686$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1093$p1$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1091$p2$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1687$p3$$,
$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1688$p4$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1689$layout_justify_content$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$layout$justify_content_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1690$layout_justify_items$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$layout$justify_items_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1691$layout_align_content$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,
$APP.$app$common$types$shape$layout$align_content_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1692$layout_align_items$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$layout$align_items_types$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1693$layout_grid_dir$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$layout$grid_direction_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1694$layout_grid_rows$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,2],null),$app$common$types$shape$layout$schema_COLON_grid_track$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1695$layout_grid_columns$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,2],null),$app$common$types$shape$layout$schema_COLON_grid_track$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,5],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"GridCell"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1675$area_name$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1656$row$$,$cljs$cst$961$app_DOT_common_DOT_schema_SLASH_safe_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1657$row_span$$,$cljs$cst$961$app_DOT_common_DOT_schema_SLASH_safe_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$216$column$$,$cljs$cst$961$app_DOT_common_DOT_schema_SLASH_safe_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1658$column_span$$,$cljs$cst$961$app_DOT_common_DOT_schema_SLASH_safe_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$layout$grid_position_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1677$align_self$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$layout$grid_cell_align_self_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1678$justify_self$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,
$APP.$app$common$types$shape$layout$grid_cell_justify_self_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1614$shapes$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,1],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],null)],null)],
null)],null);$app$common$schema$check_fn$$($app$common$types$shape$layout$schema_COLON_grid_track$$);$app$common$types$shape$layout$layout_attrs$$=$app$common$schema$keys$$($app$common$types$shape$layout$schema_COLON_layout_attrs$$);$APP.$app$common$types$shape$layout$item_h_sizing_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1403$fill$$,null,$APP.$cljs$cst$1697$fix$$,null,$APP.$cljs$cst$1672$auto$$,null],null),null);
$APP.$app$common$types$shape$layout$item_v_sizing_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1403$fill$$,null,$APP.$cljs$cst$1697$fix$$,null,$APP.$cljs$cst$1672$auto$$,null],null),null);
$APP.$app$common$types$shape$layout$item_align_self_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1292$start$$,null,$APP.$cljs$cst$1667$center$$,null,$APP.$cljs$cst$1293$end$$,null,$APP.$cljs$cst$1669$stretch$$,null],null),null);
$app$common$types$shape$layout$schema_COLON_layout_child_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,13,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"LayoutChildAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1698$layout_item_margin_type$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1663$simple$$,null,$APP.$cljs$cst$1616$multiple$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1699$layout_item_margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1700$m1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1701$m2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1702$m3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1703$m4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1704$layout_item_max_h$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1705$layout_item_min_h$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1706$layout_item_max_w$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1707$layout_item_min_w$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1708$layout_item_h_sizing$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$layout$item_h_sizing_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1709$layout_item_v_sizing$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,
[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$layout$item_v_sizing_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1710$layout_item_align_self$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$layout$item_align_self_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1711$layout_item_absolute$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1712$layout_item_z_index$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null)],null);$app$common$types$shape$layout$layout_child_attrs$$=$app$common$schema$keys$$($app$common$types$shape$layout$schema_COLON_layout_child_attrs$$);
$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$=function $app$common$types$shape$layout$flex_layout_QMARK_$$($var_args$jscomp$894$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$61$$,$id$jscomp$124$$){return $APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$61$$,$id$jscomp$124$$))};
$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function($shape$jscomp$35$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$35$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$35$$))};$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$=function $app$common$types$shape$layout$grid_layout_QMARK_$$($var_args$jscomp$895$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$62$$,$id$jscomp$125$$){return $APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$62$$,$id$jscomp$125$$))};
$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function($shape$jscomp$36$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$36$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1659$grid$$,$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$36$$))};$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$types$shape$layout$any_layout_QMARK_$$=function $app$common$types$shape$layout$any_layout_QMARK_$$($var_args$jscomp$896$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$63$$,$id$jscomp$126$$){return $APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$63$$,$id$jscomp$126$$))};
$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function($layout_shape$jscomp$37$$){var $and__5023__auto__$jscomp$220$$=$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($layout_shape$jscomp$37$$);return $and__5023__auto__$jscomp$220$$?($layout_shape$jscomp$37$$=$APP.$cljs$cst$1615$layout$$.$cljs$core$IFn$_invoke$arity$1$($layout_shape$jscomp$37$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1660$flex$$,
$layout_shape$jscomp$37$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1659$grid$$,$layout_shape$jscomp$37$$)):$and__5023__auto__$jscomp$220$$};$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$types$shape$layout$fill_width_QMARK_$$=function $app$common$types$shape$layout$fill_width_QMARK_$$($var_args$jscomp$897$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$74$$,$id$jscomp$130$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1403$fill$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$74$$,$id$jscomp$130$$),$APP.$cljs$cst$1708$layout_item_h_sizing$$))};
$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function($child$jscomp$54$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$54$$))};$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$types$shape$layout$fill_height_QMARK_$$=function $app$common$types$shape$layout$fill_height_QMARK_$$($var_args$jscomp$898$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$75$$,$id$jscomp$131$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1403$fill$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$75$$,$id$jscomp$131$$),$APP.$cljs$cst$1709$layout_item_v_sizing$$))};
$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function($child$jscomp$55$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$55$$))};$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$types$shape$layout$col_QMARK_$$=function $app$common$types$shape$layout$col_QMARK_$$($var_args$jscomp$903$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$80$$,$id$jscomp$136$$){return $APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$80$$,$id$jscomp$136$$))};
$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function($layout_flex_dir_map__47852__$1_p__47851$$){$layout_flex_dir_map__47852__$1_p__47851$$=$APP.$cljs$core$__destructure_map$$($layout_flex_dir_map__47852__$1_p__47851$$);$layout_flex_dir_map__47852__$1_p__47851$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layout_flex_dir_map__47852__$1_p__47851$$,$APP.$cljs$cst$1679$layout_flex_dir$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,
$layout_flex_dir_map__47852__$1_p__47851$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1662$column_reverse$$,$layout_flex_dir_map__47852__$1_p__47851$$)};$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$types$shape$layout$position_absolute_QMARK_$$=function $app$common$types$shape$layout$position_absolute_QMARK_$$($var_args$jscomp$907$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$84$$,$id$jscomp$140$$){return $APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$84$$,$id$jscomp$140$$))};
$APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$=function($shape$jscomp$54$$){var $or__5025__auto__$jscomp$322$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$54$$);return $or__5025__auto__$jscomp$322$$?$or__5025__auto__$jscomp$322$$:$APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$54$$)};
$APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$lang$maxFixedArity$=2;$APP.$app$common$types$shape$layout$default_track_value$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1660$flex$$,$APP.$cljs$cst$260$value$$,1],null);
$app$common$types$shape$layout$grid_cell_defaults$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1657$row_span$$,1,$APP.$cljs$cst$1658$column_span$$,1,$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$1677$align_self$$,$APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$1678$justify_self$$,$APP.$cljs$cst$1672$auto$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null);
$APP.$app$common$types$shape$layout$add_grid_column$$=function $app$common$types$shape$layout$add_grid_column$$($var_args$jscomp$910$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$add_grid_column$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$common$types$shape$layout$add_grid_column$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$types$shape$layout$add_grid_column$$.$cljs$core$IFn$_invoke$arity$2$=function($parent$jscomp$142$$,$value$jscomp$392$$){return $APP.$app$common$types$shape$layout$add_grid_column$$.$cljs$core$IFn$_invoke$arity$3$($parent$jscomp$142$$,$value$jscomp$392$$,null)};
$APP.$app$common$types$shape$layout$add_grid_column$$.$cljs$core$IFn$_invoke$arity$3$=function($parent$jscomp$143$$,$value$jscomp$393$$,$index$jscomp$150$$){return $app$common$types$shape$layout$add_grid_track$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$cst$216$column$$,$parent$jscomp$143$$,$value$jscomp$393$$,$index$jscomp$150$$)};$APP.$app$common$types$shape$layout$add_grid_column$$.$cljs$lang$maxFixedArity$=3;
$APP.$app$common$types$shape$layout$add_grid_row$$=function $app$common$types$shape$layout$add_grid_row$$($var_args$jscomp$911$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$add_grid_row$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$common$types$shape$layout$add_grid_row$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$types$shape$layout$add_grid_row$$.$cljs$core$IFn$_invoke$arity$2$=function($parent$jscomp$144$$,$value$jscomp$394$$){return $APP.$app$common$types$shape$layout$add_grid_row$$.$cljs$core$IFn$_invoke$arity$3$($parent$jscomp$144$$,$value$jscomp$394$$,null)};
$APP.$app$common$types$shape$layout$add_grid_row$$.$cljs$core$IFn$_invoke$arity$3$=function($parent$jscomp$145$$,$value$jscomp$395$$,$index$jscomp$151$$){return $app$common$types$shape$layout$add_grid_track$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$cst$1656$row$$,$parent$jscomp$145$$,$value$jscomp$395$$,$index$jscomp$151$$)};$APP.$app$common$types$shape$layout$add_grid_row$$.$cljs$lang$maxFixedArity$=3;
$APP.$app$common$types$shape$layout$shapes_by_row$$=function $app$common$types$shape$layout$shapes_by_row$$($var_args$jscomp$917$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$shapes_by_row$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$common$types$shape$layout$shapes_by_row$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$types$shape$layout$shapes_by_row$$.$cljs$core$IFn$_invoke$arity$2$=function($parent$jscomp$181$$,$index$jscomp$162$$){return $APP.$app$common$types$shape$layout$shapes_by_row$$.$cljs$core$IFn$_invoke$arity$3$($parent$jscomp$181$$,$index$jscomp$162$$,!0)};
$APP.$app$common$types$shape$layout$shapes_by_row$$.$cljs$core$IFn$_invoke$arity$3$=function($parent$jscomp$182$$,$index$jscomp$163$$,$check_span_QMARK_$jscomp$2$$){return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$03$$($parent$jscomp$182$$,$index$jscomp$163$$,$check_span_QMARK_$jscomp$2$$)]))};
$APP.$app$common$types$shape$layout$shapes_by_row$$.$cljs$lang$maxFixedArity$=3;
$APP.$app$common$types$shape$layout$shapes_by_column$$=function $app$common$types$shape$layout$shapes_by_column$$($var_args$jscomp$918$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$shapes_by_column$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$common$types$shape$layout$shapes_by_column$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$types$shape$layout$shapes_by_column$$.$cljs$core$IFn$_invoke$arity$2$=function($parent$jscomp$183$$,$index$jscomp$164$$){return $APP.$app$common$types$shape$layout$shapes_by_column$$.$cljs$core$IFn$_invoke$arity$3$($parent$jscomp$183$$,$index$jscomp$164$$,!0)};
$APP.$app$common$types$shape$layout$shapes_by_column$$.$cljs$core$IFn$_invoke$arity$3$=function($parent$jscomp$184$$,$index$jscomp$165$$,$check_span_QMARK_$jscomp$3$$){return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$03$$($parent$jscomp$184$$,$index$jscomp$165$$,$check_span_QMARK_$jscomp$3$$)]))};
$APP.$app$common$types$shape$layout$shapes_by_column$$.$cljs$lang$maxFixedArity$=3;var $app$common$types$plugins$schema_COLON_string$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$298$schema$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$word_string$$()],null),$APP.$cljs$cst$198$string$$],null),$app$common$types$plugins$schema_COLON_keyword$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$298$schema$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$fmap$$($APP.$cljs$core$keyword$$,$app$common$schema$generators$word_string$$())],null),$APP.$cljs$cst$221$keyword$$],null),$app$common$types$plugins$schema_COLON_plugin_data$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$855$gen_SLASH_max$$,5,$APP.$cljs$cst$939$title$$,
"PluginsData"],null),$app$common$types$plugins$schema_COLON_keyword$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,5],null),$app$common$types$plugins$schema_COLON_string$$,$app$common$types$plugins$schema_COLON_string$$],null)],null),$app$common$types$plugins$schema_COLON_registry_entry$$=new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1720$plugin_id$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$936$description$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$744$host$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1721$icon$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1722$permissions$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$198$string$$],null)],null)],null);var $app$common$types$color$required_color_attrs$$,$app$common$types$color$hex_color_rx$$,$app$common$types$color$hex_color_generator$$,$app$common$types$color$schema_COLON_hex_color$$,$app$common$types$color$schema_COLON_plain_color$$,$app$common$types$color$schema_COLON_image_color$$,$app$common$types$color$schema_COLON_gradient_color$$,$app$common$types$color$schema_COLON_color_attrs$$,$app$common$types$color$schema_COLON_library_color_attrs$$,$app$common$types$color$schema_COLON_library_color$$,
$app$common$types$color$names$$,$app$common$types$color$hex_color_re$$,$app$common$types$color$rgb_color_re$$;$app$common$types$color$required_color_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1298$color$$,null,$APP.$cljs$cst$1724$gradient$$,null,$APP.$cljs$cst$1612$image$$,null],null),null);$app$common$types$color$hex_color_rx$$=/^#(?:[0-9a-fA-F]{3}){1,2}$/;
$app$common$types$color$hex_color_generator$$=$app$common$schema$generators$fmap$$(function(){var $g$jscomp$123$$=$cljs$core$rand_int$$(255),$b$jscomp$267$$=$cljs$core$rand_int$$(255);return["#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$core$rand_int$$(255).toString(16).padStart(2,"0")),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($g$jscomp$123$$.toString(16).padStart(2,"0")),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$267$$.toString(16).padStart(2,"0"))].join("")},
$app$common$schema$generators$int$0$$);
$app$common$types$color$schema_COLON_hex_color$$=$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$1725$app_DOT_common_DOT_types_DOT_color_SLASH_hex_color$$,$APP.$cljs$cst$351$pred$$,$app$common$types$color$hex_color_string_QMARK_$$,$cljs$cst$415$type_properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$939$title$$,"HexColor",$APP.$cljs$cst$936$description$$,"HEX Color String",
$APP.$cljs$cst$882$error_SLASH_message$$,"expected a valid HEX color",$APP.$cljs$cst$945$error_SLASH_code$$,"errors.invalid-hex-color",$cljs$cst$869$gen_SLASH_gen$$,$app$common$types$color$hex_color_generator$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,"string",$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$,"rgb"],null)],null));
$app$common$types$color$schema_COLON_plain_color$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"PlainColorAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$app$common$types$color$schema_COLON_hex_color$$],null)],null);
$APP.$app$common$types$color$schema_COLON_image$$=new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"ImageColor",$cljs$cst$462$closed$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,0,$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$int$0$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1522$height$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$338$min$$,0,$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$int$0$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1726$mtype$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$869$gen_SLASH_gen$$,$clojure$test$check$generators$elements$$($app$common$media$image_types$$)],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1727$keep_aspect_ratio$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null)],null);$app$common$schema$keys$$($APP.$app$common$types$color$schema_COLON_image$$);
$app$common$types$color$schema_COLON_image_color$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ImageColorAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1612$image$$,$APP.$app$common$types$color$schema_COLON_image$$],null)],null);
$APP.$app$common$types$color$schema_COLON_gradient$$=new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"Gradient",$cljs$cst$462$closed$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1728$radial$$,null,$APP.$cljs$cst$287$linear$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1729$start_x$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1730$start_y$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1731$end_x$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1732$end_y$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1733$stops$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,1,$cljs$cst$855$gen_SLASH_max$$,2],null),
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"GradientStop"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$app$common$types$color$schema_COLON_hex_color$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1734$opacity$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$960$app_DOT_common_DOT_schema_SLASH_number$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,0,$APP.$cljs$cst$339$max$$,1],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$195$offset$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$960$app_DOT_common_DOT_schema_SLASH_number$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,0,$APP.$cljs$cst$339$max$$,1],null)],null)],null)],null)],null)],null)],null);$app$common$schema$keys$$($APP.$app$common$types$color$schema_COLON_gradient$$);
$app$common$types$color$schema_COLON_gradient_color$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"GradientColorAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1724$gradient$$,$APP.$app$common$types$color$schema_COLON_gradient$$],null)],null);
$app$common$types$color$schema_COLON_color_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"GenericColorAttrs",$cljs$cst$462$closed$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1734$opacity$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$960$app_DOT_common_DOT_schema_SLASH_number$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,0,$APP.$cljs$cst$339$max$$,1],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1735$ref_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),
$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1736$ref_file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null);
$APP.$app$common$types$color$schema_COLON_color$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$735$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Color"],null),$app$common$types$color$schema_COLON_color_attrs$$,$malli$util$optional_keys$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$color$schema_COLON_plain_color$$),
$malli$util$optional_keys$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$color$schema_COLON_gradient_color$$),$malli$util$optional_keys$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$color$schema_COLON_image_color$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$common$types$color$has_valid_color_attrs_QMARK_$$],null)],null);
$APP.$app$common$types$color$color_attrs$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$color$required_color_attrs$$,$app$common$schema$keys$$($app$common$types$color$schema_COLON_color_attrs$$));
$app$common$types$color$schema_COLON_library_color_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"LibraryColorAttrs",$cljs$cst$462$closed$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$296$path$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1734$opacity$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$960$app_DOT_common_DOT_schema_SLASH_number$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,0,$APP.$cljs$cst$339$max$$,1],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1737$modified_at$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1738$plugin_data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$plugins$schema_COLON_plugin_data$$],null)],null);
$app$common$types$color$schema_COLON_library_color$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$735$merge$$,$app$common$types$color$schema_COLON_library_color_attrs$$,$malli$util$optional_keys$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$color$schema_COLON_plain_color$$),$malli$util$optional_keys$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$color$schema_COLON_gradient_color$$),
$malli$util$optional_keys$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$color$schema_COLON_image_color$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$common$types$color$has_valid_color_attrs_QMARK_$$],null)],null);$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$color$required_color_attrs$$,$app$common$schema$keys$$($app$common$types$color$schema_COLON_library_color_attrs$$));
$APP.$app$common$types$color$valid_color_QMARK_$$=$app$common$schema$lazy_validator$$($APP.$app$common$types$color$schema_COLON_color$$);$APP.$app$common$types$color$valid_library_color_QMARK_$$=$app$common$schema$lazy_validator$$($app$common$types$color$schema_COLON_library_color$$);
$APP.$app$common$types$color$check_color$$=$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$color$schema_COLON_color$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,"expected valid color"]));
$APP.$app$common$types$color$check_library_color$$=$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$types$color$schema_COLON_library_color$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,"expected valid color"]));
$app$common$types$color$names$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$("springgreen aqua blue olivedrab lightskyblue greenyellow ivory navajowhite cyan mediumturquoise darkslateblue lawngreen saddlebrown white silver purple gainsboro plum midnightblue magenta paleturquoise hotpink mediumorchid gold powderblue papayawhip bisque salmon forestgreen blanchedalmond grey crimson darkturquoise steelblue mediumvioletred aquamarine darkgoldenrod orange darkgray lime cornflowerblue aliceblue lightgoldenrodyellow lemonchiffon lightsalmon deepskyblue lightgreen palegoldenrod darkred violet gray goldenrod darksalmon skyblue darkviolet fuchsia lightcoral moccasin darkgreen lightyellow lavenderblush sienna burlywood ghostwhite coral linen lightslategray azure darkolivegreen floralwhite yellow beige wheat slategray darkmagenta darkcyan dodgerblue mediumseagreen darkgrey mediumblue pink mistyrose teal olive navy darkkhaki green darkblue red maroon limegreen brown seashell chocolate antiquewhite tan seagreen palevioletred rosybrown cornsilk lavender mediumpurple black snow lightseagreen palegreen deeppink dimgray blueviolet cadetblue slateblue mediumspringgreen lightpink firebrick dimgrey khaki royalblue sandybrown orangered darkslategray orchid indianred darkorchid honeydew oldlace whitesmoke mediumaquamarine lightgrey peru chartreuse lightcyan lightblue tomato mintcream peachpuff thistle lightsteelblue mediumslateblue darkslategrey turquoise slategrey indigo lightslategrey darkorange yellowgreen lightgray darkseagreen".split(" "),"#00ff7f #00ffff #0000ff #6b8e23 #87cefa #adff2f #fffff0 #ffdead #00ffff #48d1cc #483d8b #7cfc00 #8b4513 #ffffff #c0c0c0 #800080 #dcdcdc #dda0dd #191970 #ff00ff #afeeee #ff69b4 #ba55d3 #ffd700 #b0e0e6 #ffefd5 #ffe4c4 #fa8072 #228b22 #ffebcd #808080 #dc143c #00ced1 #4682b4 #c71585 #7fffd4 #b8860b #ffa500 #a9a9a9 #00ff00 #6495ed #f0f8ff #fafad2 #fffacd #ffa07a #00bfff #90ee90 #eee8aa #8b0000 #ee82ee #808080 #daa520 #e9967a #87ceeb #9400d3 #ff00ff #f08080 #ffe4b5 #006400 #ffffe0 #fff0f5 #a0522d #deb887 #f8f8ff #ff7f50 #faf0e6 #778899 #f0ffff #556b2f #fffaf0 #ffff00 #f5f5dc #f5deb3 #708090 #8b008b #008b8b #1e90ff #3cb371 #a9a9a9 #0000cd #ffc0cb #ffe4e1 #008080 #808000 #000080 #bdb76b #008000 #00008b #ff0000 #800000 #32cd32 #a52a2a #fff5ee #d2691e #faebd7 #d2b48c #2e8b57 #db7093 #bc8f8f #fff8dc #e6e6fa #9370db #000000 #fffafa #20b2aa #98fb98 #ff1493 #696969 #8a2be2 #5f9ea0 #6a5acd #00fa9a #ffb6c1 #b22222 #696969 #f0e68c #4169e1 #f4a460 #ff4500 #2f4f4f #da70d6 #cd5c5c #9932cc #f0fff0 #fdf5e6 #f5f5f5 #66cdaa #d3d3d3 #cd853f #7fff00 #e0ffff #add8e6 #ff6347 #f5fffa #ffdab9 #d8bfd8 #b0c4de #7b68ee #2f4f4f #40e0d0 #708090 #4b0082 #778899 #ff8c00 #9acd32 #d3d3d3 #8fbc8f".split(" "));
$app$common$types$color$hex_color_re$$=/#([0-9a-fA-F]{6}|[0-9a-fA-F]{3})/;$app$common$types$color$rgb_color_re$$=/(?:|rgb)\((\d{1,3})\s*,\s*(\d{1,3})\s*,\s*(\d{1,3})\)/;$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keys$$($app$common$types$color$names$$));
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__45503_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__45503_SHARP_$$,null],null)}),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$1724$gradient$$,
$APP.$cljs$cst$1734$opacity$$],null));var $WeakEqMap$$module$app$common$weak$impl_weak_map$$=class{constructor({equals:$equals$$,hash:$hash$jscomp$27$$}){this.$_equals$=$equals$$;this.$_hash$=$hash$jscomp$27$$;this.$_buckets$=new Map;this.$_fr$=new FinalizationRegistry(({hash:$hash$jscomp$28$$,token:$token$jscomp$38$$})=>{const $bucket$jscomp$10$$=this.$_buckets$.get($hash$jscomp$28$$);if($bucket$jscomp$10$$){for(var $i$jscomp$476$$=0;$i$jscomp$476$$<$bucket$jscomp$10$$.length;){const $e$jscomp$283$$=$bucket$jscomp$10$$[$i$jscomp$476$$];
$e$jscomp$283$$.$keyRef$.deref()===void 0||$e$jscomp$283$$.token===$token$jscomp$38$$?($bucket$jscomp$10$$[$i$jscomp$476$$]=$bucket$jscomp$10$$[$bucket$jscomp$10$$.length-1],$bucket$jscomp$10$$.pop()):$i$jscomp$476$$++}$bucket$jscomp$10$$.length===0&&this.$_buckets$.delete($hash$jscomp$28$$)}})}set($key$jscomp$300$$,$entry$jscomp$35_value$jscomp$401$$){if($key$jscomp$300$$===null||typeof $key$jscomp$300$$!=="object"&&typeof $key$jscomp$300$$!=="function")throw new TypeError("WeakEqMap keys must be objects (like WeakMap).");
const $hash$jscomp$30$$=this.$_hash$($key$jscomp$300$$);var $JSCompiler_inline_result$jscomp$719_b$jscomp$inline_4764$$=this.$_buckets$.get($hash$jscomp$30$$);$JSCompiler_inline_result$jscomp$719_b$jscomp$inline_4764$$||($JSCompiler_inline_result$jscomp$719_b$jscomp$inline_4764$$=[],this.$_buckets$.set($hash$jscomp$30$$,$JSCompiler_inline_result$jscomp$719_b$jscomp$inline_4764$$));var $existing_token$jscomp$39$$=$JSCompiler_StaticMethods__findEntry$$(this,$JSCompiler_inline_result$jscomp$719_b$jscomp$inline_4764$$,
$key$jscomp$300$$);if($existing_token$jscomp$39$$)return $existing_token$jscomp$39$$.value=$entry$jscomp$35_value$jscomp$401$$,this;$existing_token$jscomp$39$$=Object.create(null);$entry$jscomp$35_value$jscomp$401$$={$keyRef$:new WeakRef($key$jscomp$300$$),value:$entry$jscomp$35_value$jscomp$401$$,token:$existing_token$jscomp$39$$};$JSCompiler_inline_result$jscomp$719_b$jscomp$inline_4764$$.push($entry$jscomp$35_value$jscomp$401$$);this.$_fr$.register($key$jscomp$300$$,{hash:$hash$jscomp$30$$,token:$existing_token$jscomp$39$$},
$entry$jscomp$35_value$jscomp$401$$);return this}get($e$jscomp$285_key$jscomp$301$$){var $bucket$jscomp$13_hash$jscomp$31$$=this.$_hash$($e$jscomp$285_key$jscomp$301$$);if($bucket$jscomp$13_hash$jscomp$31$$=this.$_buckets$.get($bucket$jscomp$13_hash$jscomp$31$$))return($e$jscomp$285_key$jscomp$301$$=$JSCompiler_StaticMethods__findEntry$$(this,$bucket$jscomp$13_hash$jscomp$31$$,$e$jscomp$285_key$jscomp$301$$))?$e$jscomp$285_key$jscomp$301$$.value:void 0}has($key$jscomp$302$$){var $bucket$jscomp$14_hash$jscomp$32$$=
this.$_hash$($key$jscomp$302$$);return($bucket$jscomp$14_hash$jscomp$32$$=this.$_buckets$.get($bucket$jscomp$14_hash$jscomp$32$$))?!!$JSCompiler_StaticMethods__findEntry$$(this,$bucket$jscomp$14_hash$jscomp$32$$,$key$jscomp$302$$):!1}delete($key$jscomp$303$$){const $hash$jscomp$33$$=this.$_hash$($key$jscomp$303$$),$bucket$jscomp$15$$=this.$_buckets$.get($hash$jscomp$33$$);if(!$bucket$jscomp$15$$)return!1;let $i$jscomp$478$$=0;for(;$i$jscomp$478$$<$bucket$jscomp$15$$.length;){const $e$jscomp$286$$=
$bucket$jscomp$15$$[$i$jscomp$478$$],$k$jscomp$580$$=$e$jscomp$286$$.$keyRef$.deref();if($k$jscomp$580$$===void 0)$bucket$jscomp$15$$[$i$jscomp$478$$]=$bucket$jscomp$15$$[$bucket$jscomp$15$$.length-1],$bucket$jscomp$15$$.pop();else{if(this.$_equals$($k$jscomp$580$$,$key$jscomp$303$$))return this.$_fr$.unregister($e$jscomp$286$$),$bucket$jscomp$15$$[$i$jscomp$478$$]=$bucket$jscomp$15$$[$bucket$jscomp$15$$.length-1],$bucket$jscomp$15$$.pop(),$bucket$jscomp$15$$.length===0&&this.$_buckets$.delete($hash$jscomp$33$$),
!0;$i$jscomp$478$$++}}$bucket$jscomp$15$$.length===0&&this.$_buckets$.delete($hash$jscomp$33$$);return!1}};$APP.$module$app$common$weak$impl_weak_map$$={};$APP.$module$app$common$weak$impl_weak_map$$.$WeakEqMap$=$WeakEqMap$$module$app$common$weak$impl_weak_map$$;var $WeakValueMap$$module$app$common$weak$impl_weak_value_map$$=class{constructor(){this.$_map$=new Map;this.$_registry$=new FinalizationRegistry($token$jscomp$40$$=>{this.$_map$.delete($token$jscomp$40$$.key)})}set($key$jscomp$304$$,$value$jscomp$402$$){const $token$jscomp$41$$={key:$key$jscomp$304$$};this.$_map$.set($key$jscomp$304$$,{ref:new WeakRef($value$jscomp$402$$),token:$token$jscomp$41$$});this.$_registry$.register($value$jscomp$402$$,$token$jscomp$41$$,$token$jscomp$41$$);return this}get($key$jscomp$305$$){var $entry$jscomp$36_value$jscomp$403$$=
this.$_map$.get($key$jscomp$305$$);if($entry$jscomp$36_value$jscomp$403$$)if($entry$jscomp$36_value$jscomp$403$$=$entry$jscomp$36_value$jscomp$403$$.ref.deref(),$entry$jscomp$36_value$jscomp$403$$===void 0)this.$_map$.delete($key$jscomp$305$$);else return $entry$jscomp$36_value$jscomp$403$$}has($key$jscomp$306$$){const $entry$jscomp$37$$=this.$_map$.get($key$jscomp$306$$);return $entry$jscomp$37$$?$entry$jscomp$37$$.ref.deref()===void 0?(this.$_map$.delete($key$jscomp$306$$),!1):!0:!1}delete($key$jscomp$307$$){const $entry$jscomp$38$$=
this.$_map$.get($key$jscomp$307$$);if(!$entry$jscomp$38$$)return!1;this.$_registry$.unregister($entry$jscomp$38$$.token);return this.$_map$.delete($key$jscomp$307$$)}};$module$app$common$weak$impl_weak_value_map$$={};$module$app$common$weak$impl_weak_value_map$$.$WeakValueMap$=$WeakValueMap$$module$app$common$weak$impl_weak_value_map$$;var $app$common$weak$state$$=new WeakMap,$app$common$weak$global_counter$$=0;var $app$common$types$fills$impl$xf_COLON_take_stops$$=$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$1$(16),$app$common$types$fills$impl$xf_COLON_take_fills$$=$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$1$(8);$APP.$JSCompiler_prototypeAlias$$=$app$common$types$fills$impl$Fills$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($_$jscomp$1084$$,$i$jscomp$480$$){return $i$jscomp$480$$<this.size&&$i$jscomp$480$$>=0?$app$common$types$fills$impl$read_fill$$(this.$dbuffer$,this.$mbuffer$,$i$jscomp$480$$):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($_$jscomp$1085$$,$i$jscomp$481$$,$default$$jscomp$51$$){return $i$jscomp$481$$<this.size&&$i$jscomp$481$$>=0?$app$common$types$fills$impl$read_fill$$(this.$dbuffer$,this.$mbuffer$,$i$jscomp$481$$):$default$$jscomp$51$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$629$$,$other$jscomp$176$$){return $other$jscomp$176$$ instanceof $app$common$types$fills$impl$Fills$$?$app$common$buffer$equals_QMARK_$$($other$jscomp$176$$.$dbuffer$,this.$dbuffer$)&&$app$common$buffer$equals_QMARK_$$($other$jscomp$176$$.$mbuffer$,this.$mbuffer$):!1};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$44_h__5134__auto____$1$jscomp$44$$=this.$__hash$;return $h__5134__auto__$jscomp$44_h__5134__auto____$1$jscomp$44$$!=null?$h__5134__auto__$jscomp$44_h__5134__auto____$1$jscomp$44$$:this.$__hash$=$h__5134__auto__$jscomp$44_h__5134__auto____$1$jscomp$44$$=$cljs$core$hash_ordered_coll$$(this)};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$fills$impl$IBinaryFills$_get_image_ids$arity$1$=function(){return this.$image_ids$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.size};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){var $self__$jscomp$2686$$=this;return $self__$jscomp$2686$$.size>0?function $app$common$types$fills$impl$next_seq$$($i$jscomp$482$$){return $i$jscomp$482$$<$self__$jscomp$2686$$.size?$APP.$cljs$core$cons$$($app$common$types$fills$impl$read_fill$$($self__$jscomp$2686$$.$dbuffer$,$self__$jscomp$2686$$.$mbuffer$,$i$jscomp$482$$),new $APP.$cljs$core$LazySeq$$(null,function(){return $app$common$types$fills$impl$next_seq$$($i$jscomp$482$$+
1)},null,null)):null}(0):null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEncodeJS$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEncodeJS$_clj__GT_js$arity$1$=function(){return $APP.$cljs$core$clj__GT_js$$($APP.$cljs$core$vec$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($_STAR_print_dup_STAR__orig_val__45780_this$$jscomp$632$$,$writer$jscomp$163$$){$_STAR_print_dup_STAR__orig_val__45780_this$$jscomp$632$$=$cljs$core$_STAR_print_dup_STAR_$$;$cljs$core$_STAR_print_dup_STAR_$$=!0;try{return $APP.$cljs$core$_write$$($writer$jscomp$163$$,['#penpot/fills "',$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vec$$(this)])),
'"'].join(""))}finally{$cljs$core$_STAR_print_dup_STAR_$$=$_STAR_print_dup_STAR__orig_val__45780_this$$jscomp$632$$}};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$fills$impl$IHeapWritable$_get_byte_size$arity$1$=function(){return 4+this.size*160};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$fills$impl$IHeapWritable$_write_to$arity$3$=function($_$jscomp$1090_u32_array$$,$heap$$,$offset$jscomp$106$$){$_$jscomp$1090_u32_array$$=new Uint32Array(this.$dbuffer$.buffer,0,(4+this.size*160)/4);return $heap$$.set($_$jscomp$1090_u32_array$$,$offset$jscomp$106$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($G__45789_coll$jscomp$1078$$,$k$jscomp$581$$,$v$jscomp$514$$){if(typeof $k$jscomp$581$$==="number")return $G__45789_coll$jscomp$1078$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vec$$(this),$k$jscomp$581$$,$v$jscomp$514$$),$APP.$app$common$types$fills$impl$from_plain$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$fills$impl$from_plain$$.$cljs$core$IFn$_invoke$arity$1$($G__45789_coll$jscomp$1078$$):
$APP.$app$common$types$fills$impl$from_plain$$($G__45789_coll$jscomp$1078$$);throw Error("Vector's key for assoc must be a number.");};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($coll$jscomp$1079$$,$k$jscomp$582$$){return $APP.$cljs$core$integer_QMARK_$$($k$jscomp$582$$)?0<=$k$jscomp$582$$&&$k$jscomp$582$$<this.size:!1};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($_$jscomp$1091_index$jscomp$167$$,$f$jscomp$753$$){$_$jscomp$1091_index$jscomp$167$$=1;for(var $G__45793$jscomp$inline_4791_G__45851_result$jscomp$168_result__$1$jscomp$11$$=this.size>0?$app$common$types$fills$impl$read_fill$$(this.$dbuffer$,this.$mbuffer$,0):null;;)if($_$jscomp$1091_index$jscomp$167$$<this.size){var $G__45794$jscomp$inline_4792$$=$app$common$types$fills$impl$read_fill$$(this.$dbuffer$,this.$mbuffer$,$_$jscomp$1091_index$jscomp$167$$);
$G__45793$jscomp$inline_4791_G__45851_result$jscomp$168_result__$1$jscomp$11$$=$f$jscomp$753$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$753$$.$cljs$core$IFn$_invoke$arity$2$($G__45793$jscomp$inline_4791_G__45851_result$jscomp$168_result__$1$jscomp$11$$,$G__45794$jscomp$inline_4792$$):$f$jscomp$753$$($G__45793$jscomp$inline_4791_G__45851_result$jscomp$168_result__$1$jscomp$11$$,$G__45794$jscomp$inline_4792$$);if($cljs$core$reduced_QMARK_$$($G__45793$jscomp$inline_4791_G__45851_result$jscomp$168_result__$1$jscomp$11$$))return $APP.$cljs$core$_deref$$($G__45793$jscomp$inline_4791_G__45851_result$jscomp$168_result__$1$jscomp$11$$);
$_$jscomp$1091_index$jscomp$167$$+=1}else return $G__45793$jscomp$inline_4791_G__45851_result$jscomp$168_result__$1$jscomp$11$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($_$jscomp$1092_index$jscomp$168$$,$f$jscomp$754$$,$G__45798$jscomp$inline_4794_G__45853_result$jscomp$169_result__$1$jscomp$12_start$jscomp$189$$){for($_$jscomp$1092_index$jscomp$168$$=0;;)if($_$jscomp$1092_index$jscomp$168$$<this.size){var $G__45799$jscomp$inline_4795$$=$app$common$types$fills$impl$read_fill$$(this.$dbuffer$,this.$mbuffer$,$_$jscomp$1092_index$jscomp$168$$);$G__45798$jscomp$inline_4794_G__45853_result$jscomp$169_result__$1$jscomp$12_start$jscomp$189$$=
$f$jscomp$754$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$754$$.$cljs$core$IFn$_invoke$arity$2$($G__45798$jscomp$inline_4794_G__45853_result$jscomp$169_result__$1$jscomp$12_start$jscomp$189$$,$G__45799$jscomp$inline_4795$$):$f$jscomp$754$$($G__45798$jscomp$inline_4794_G__45853_result$jscomp$169_result__$1$jscomp$12_start$jscomp$189$$,$G__45799$jscomp$inline_4795$$);if($cljs$core$reduced_QMARK_$$($G__45798$jscomp$inline_4794_G__45853_result$jscomp$169_result__$1$jscomp$12_start$jscomp$189$$))return $APP.$cljs$core$_deref$$($G__45798$jscomp$inline_4794_G__45853_result$jscomp$169_result__$1$jscomp$12_start$jscomp$189$$);
$_$jscomp$1092_index$jscomp$168$$+=1}else return $G__45798$jscomp$inline_4794_G__45853_result$jscomp$169_result__$1$jscomp$12_start$jscomp$189$$};
$APP.$app$common$transit$add_handlers_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"penpot/fills",$APP.$cljs$cst$1291$class$$,$app$common$types$fills$impl$Fills$$,$APP.$cljs$cst$1314$wfn$$,function($fills$jscomp$1$$){return $APP.$cljs$core$vec$$($fills$jscomp$1$$)},$APP.$cljs$cst$1315$rfn$$,$APP.$app$common$types$fills$impl$from_plain$$],null)]));var $app$common$types$fills$schema_COLON_fill_attrs$$,$app$common$types$fills$fill_attrs$$,$app$common$types$fills$valid_fill_attrs$$,$app$common$types$fills$check_fill$$,$app$common$types$fills$schema_COLON_fills_as_vector$$,$app$common$types$fills$schema_COLON_fills$$;
$app$common$types$fills$schema_COLON_fill_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"FillAttrs",$cljs$cst$462$closed$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1640$fill_color_ref_file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1745$fill_color_ref_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1747$fill_opacity$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$960$app_DOT_common_DOT_schema_SLASH_number$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,0,$APP.$cljs$cst$339$max$$,1],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1746$fill_color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$app$common$types$color$schema_COLON_hex_color$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1748$fill_color_gradient$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$color$schema_COLON_gradient$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1632$fill_image$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$color$schema_COLON_image$$],null)],null);$app$common$types$fills$fill_attrs$$=$app$common$schema$keys$$($app$common$types$fills$schema_COLON_fill_attrs$$);$app$common$types$fills$valid_fill_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1746$fill_color$$,null,$APP.$cljs$cst$1748$fill_color_gradient$$,null,$APP.$cljs$cst$1632$fill_image$$,null],null),null);
$APP.$app$common$types$fills$schema_COLON_fill$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$app$common$types$fills$schema_COLON_fill_attrs$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$common$types$fills$has_valid_fill_attrs_QMARK_$$],null)],null);$app$common$types$fills$check_fill$$=$app$common$schema$check_fn$$($APP.$app$common$types$fills$schema_COLON_fill$$);
$app$common$types$fills$schema_COLON_fills_as_vector$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,2],null),$APP.$app$common$types$fills$schema_COLON_fill$$],null);
$app$common$types$fills$schema_COLON_fills$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$fills$schema_COLON_fills_as_vector$$)],null),$app$common$types$fills$schema_COLON_fills_as_vector$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$516$fn$$,$app$common$types$fills$impl$fills_QMARK_$$],null)],null);
$APP.$app$common$types$fills$update$$=function $app$common$types$fills$update$$($var_args$jscomp$920$$){for(var $args__5755__auto__$jscomp$146$$=[],$len__5749__auto___45890$$=arguments.length,$i__5750__auto___45891$$=0;;)if($i__5750__auto___45891$$<$len__5749__auto___45890$$)$args__5755__auto__$jscomp$146$$.push(arguments[$i__5750__auto___45891$$]),$i__5750__auto___45891$$+=1;else break;return $app$common$types$fills$update$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args__5755__auto__$jscomp$146$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$146$$.slice(2),0,null):null)};
$APP.$app$common$types$fills$update$$.$cljs$core$IFn$_invoke$arity$variadic$=function($fills$jscomp$6_fills__$1$jscomp$1$$,$f$jscomp$755_fills__$2$$,$args$jscomp$237$$){$fills$jscomp$6_fills__$1$jscomp$1$$=$APP.$cljs$core$vec$$($fills$jscomp$6_fills__$1$jscomp$1$$);$f$jscomp$755_fills__$2$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($f$jscomp$755_fills__$2$$,$fills$jscomp$6_fills__$1$jscomp$1$$,$args$jscomp$237$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$flags$_STAR_current_STAR_$$,
$APP.$cljs$cst$1755$frontend_binary_fills$$)?$APP.$app$common$types$fills$impl$from_plain$$($f$jscomp$755_fills__$2$$):$APP.$cljs$core$vec$$($f$jscomp$755_fills__$2$$)};$APP.$app$common$types$fills$update$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$common$types$fills$update$$.$cljs$lang$applyTo$=function($G__45845_seq45843$$){var $G__45844$$=$APP.$cljs$core$first$$($G__45845_seq45843$$),$seq45843__$1_seq45843__$2$$=$APP.$cljs$core$next$$($G__45845_seq45843$$);$G__45845_seq45843$$=$APP.$cljs$core$first$$($seq45843__$1_seq45843__$2$$);$seq45843__$1_seq45843__$2$$=$APP.$cljs$core$next$$($seq45843__$1_seq45843__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__45844$$,$G__45845_seq45843$$,$seq45843__$1_seq45843__$2$$)};var $app$common$types$text$text_typography_attrs$$,$app$common$types$text$text_decoration_attrs$$,$app$common$types$text$text_fills$$,$app$common$types$text$shape_attrs$$,$app$common$types$text$text_style_attrs$$,$app$common$types$text$default_text_fills$$,$app$common$types$text$default_paragraph_attrs$$,$app$common$types$text$compare_text_content$$,$app$common$types$text$copy_text_keys$$,$app$common$types$text$copy_attrs_keys$$;
$app$common$types$text$text_typography_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1756$typography_ref_id$$,$APP.$cljs$cst$1642$typography_ref_file$$],null);
$APP.$app$common$types$text$text_fill_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1746$fill_color$$,$APP.$cljs$cst$1747$fill_opacity$$,$APP.$cljs$cst$1745$fill_color_ref_id$$,$APP.$cljs$cst$1640$fill_color_ref_file$$,$APP.$cljs$cst$1748$fill_color_gradient$$],null);
$APP.$app$common$types$text$text_font_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$1759$font_variant_id$$,$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1762$font_style$$],null);
$APP.$app$common$types$text$text_spacing_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1765$line_height$$,$APP.$cljs$cst$1766$letter_spacing$$],null);$APP.$app$common$types$text$text_valign_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1767$vertical_align$$],null);
$app$common$types$text$text_decoration_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1768$text_decoration$$],null);$APP.$app$common$types$text$text_transform_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1769$text_transform$$],null);
$app$common$types$text$text_fills$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1634$fills$$],null);$app$common$types$text$shape_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1770$grow_type$$],null);
$APP.$app$common$types$text$paragraph_attrs$$=$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1763$text_align$$],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1764$text_direction$$],null)]));
$APP.$app$common$types$text$text_node_attrs$$=$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($app$common$types$text$text_typography_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$text_font_attrs$$,$APP.$app$common$types$text$text_spacing_attrs$$,$app$common$types$text$text_decoration_attrs$$,$APP.$app$common$types$text$text_transform_attrs$$,$app$common$types$text$text_fills$$]));
$APP.$app$common$types$text$text_all_attrs$$=$APP.$app$common$data$concat_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$types$text$shape_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$text_valign_attrs$$,$APP.$app$common$types$text$paragraph_attrs$$,$APP.$app$common$types$text$text_node_attrs$$]));
$app$common$types$text$text_style_attrs$$=$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$types$text$text_valign_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$paragraph_attrs$$,$APP.$app$common$types$text$text_node_attrs$$]));$APP.$app$common$types$text$default_root_attrs$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1767$vertical_align$$,"top"],null);
$app$common$types$text$default_text_fills$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1746$fill_color$$,"#000000",$APP.$cljs$cst$1747$fill_opacity$$,1],null)],null);$app$common$types$text$default_paragraph_attrs$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1763$text_align$$,"left",$APP.$cljs$cst$1764$text_direction$$,"ltr"],null);
$APP.$app$common$types$text$default_text_attrs$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1765$line_height$$,$APP.$cljs$cst$1762$font_style$$,$APP.$cljs$cst$1756$typography_ref_id$$,$APP.$cljs$cst$1769$text_transform$$,$APP.$cljs$cst$1763$text_align$$,$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1642$typography_ref_file$$,$APP.$cljs$cst$1764$text_direction$$,$APP.$cljs$cst$1759$font_variant_id$$,$APP.$cljs$cst$1768$text_decoration$$,
$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$cst$1758$font_family$$],["1.2","normal",null,"none","left","sourcesanspro","14","400",null,"ltr","regular","none","0","sourcesanspro"]);
$APP.$app$common$types$text$default_typography$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$select_keys$$($APP.$app$common$types$text$default_text_attrs$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$1759$font_variant_id$$,$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1762$font_style$$,$APP.$cljs$cst$1765$line_height$$,
$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$cst$1769$text_transform$$],null)),$APP.$cljs$cst$725$name$$,"Source Sans Pro Regular");
$app$common$types$text$compare_text_content$$=function $app$common$types$text$compare_text_content$$($a$jscomp$350$$,$b$jscomp$282$$,$keys$jscomp$49_p__45979$$){var $map__45980__$1$$=$APP.$cljs$core$__destructure_map$$($keys$jscomp$49_p__45979$$),$text_cb$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45980__$1$$,$cljs$cst$1771$text_cb$$),$attribute_cb$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45980__$1$$,$cljs$cst$1772$attribute_cb$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$350$$,
$b$jscomp$282$$)?$APP.$cljs$core$PersistentHashSet$EMPTY$$:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$type$$($a$jscomp$350$$),$APP.$cljs$core$type$$($b$jscomp$282$$))?new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1773$text_content_structure$$,null],null),null):$APP.$cljs$core$map_QMARK_$$($a$jscomp$350$$)?($keys$jscomp$49_p__45979$$=$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($APP.$cljs$core$keys$$($a$jscomp$350$$)),
$APP.$cljs$core$set$$($APP.$cljs$core$keys$$($b$jscomp$282$$))),$APP.$cljs$cst$302$key$$),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$87$$,$k$jscomp$583$$){var $v1$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$350$$,$k$jscomp$583$$),$v2$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$282$$,$k$jscomp$583$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$583$$,$APP.$cljs$cst$342$children$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($v1$jscomp$25$$),$APP.$cljs$core$count$$($v2$jscomp$18$$))?new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1773$text_content_structure$$,null],null),null):$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$87$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$union$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(function($p1__45976_SHARP_$$,
$p2__45977_SHARP_$$){return $app$common$types$text$compare_text_content$$.$cljs$core$IFn$_invoke$arity$3$?$app$common$types$text$compare_text_content$$.$cljs$core$IFn$_invoke$arity$3$($p1__45976_SHARP_$$,$p2__45977_SHARP_$$,$map__45980__$1$$):$app$common$types$text$compare_text_content$$($p1__45976_SHARP_$$,$p2__45977_SHARP_$$,$map__45980__$1$$)},$v1$jscomp$25$$,$v2$jscomp$18$$))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$583$$,$APP.$cljs$cst$1588$text$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($v1$jscomp$25$$,
$v2$jscomp$18$$)?$text_cb$$.$cljs$core$IFn$_invoke$arity$1$?$text_cb$$.$cljs$core$IFn$_invoke$arity$1$($acc$jscomp$87$$):$text_cb$$($acc$jscomp$87$$):$acc$jscomp$87$$:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($v1$jscomp$25$$,$v2$jscomp$18$$)&&($APP.$app$common$data$not_empty_QMARK_$$($v1$jscomp$25$$)||$APP.$app$common$data$not_empty_QMARK_$$($v2$jscomp$18$$))?$attribute_cb$$.$cljs$core$IFn$_invoke$arity$2$?$attribute_cb$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$87$$,$k$jscomp$583$$):
$attribute_cb$$($acc$jscomp$87$$,$k$jscomp$583$$):$acc$jscomp$87$$},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$keys$jscomp$49_p__45979$$)):new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1773$text_content_structure$$,null],null),null)};
$app$common$types$text$copy_text_keys$$=function $app$common$types$text$copy_text_keys$$($origin$jscomp$2$$,$destiny$$){return $APP.$cljs$core$map_QMARK_$$($origin$jscomp$2$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,function(){return function $app$common$types$text$copy_text_keys_$_iter__46014$$($s__46015$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__46015__$1$$=$s__46015$$;;){var $temp__5825__auto__$jscomp$123$$=$APP.$cljs$core$seq$$($s__46015__$1$$);
if($temp__5825__auto__$jscomp$123$$){var $s__46015__$2$$=$temp__5825__auto__$jscomp$123$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($s__46015__$2$$)){var $c__5501__auto__$jscomp$15$$=$APP.$cljs$core$_chunked_first$$($s__46015__$2$$),$size__5502__auto__$jscomp$15$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$15$$),$b__46017$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$15$$);return function(){for(var $i__46016$$=0;;)if($i__46016$$<$size__5502__auto__$jscomp$15$$){var $k$jscomp$585$$=
$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$15$$,$i__46016$$);$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$585$$,$APP.$cljs$cst$302$key$$)&&$APP.$cljs$core$chunk_append$$($b__46017$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$342$children$$,$k$jscomp$585$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$585$$,$APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(function(){return function($p1__46006_SHARP_$$,
$p2__46007_SHARP_$$){return $app$common$types$text$copy_text_keys$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$types$text$copy_text_keys$$.$cljs$core$IFn$_invoke$arity$2$($p1__46006_SHARP_$$,$p2__46007_SHARP_$$):$app$common$types$text$copy_text_keys$$($p1__46006_SHARP_$$,$p2__46007_SHARP_$$)}}($i__46016$$,$s__46015__$1$$,$k$jscomp$585$$,$c__5501__auto__$jscomp$15$$,$size__5502__auto__$jscomp$15$$,$b__46017$$,$s__46015__$2$$,$temp__5825__auto__$jscomp$123$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$2$$,
$k$jscomp$585$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($destiny$$,$k$jscomp$585$$)))],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,$k$jscomp$585$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$585$$,$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($origin$jscomp$2$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$585$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($destiny$$,$k$jscomp$585$$)],null));$i__46016$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__46017$$),$app$common$types$text$copy_text_keys_$_iter__46014$$($APP.$cljs$core$_chunked_rest$$($s__46015__$2$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__46017$$),null)}var $k$jscomp$584$$=$APP.$cljs$core$first$$($s__46015__$2$$);if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$584$$,
$APP.$cljs$cst$302$key$$))return $APP.$cljs$core$cons$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$342$children$$,$k$jscomp$584$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$584$$,$APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(function(){return function($p1__46006_SHARP_$jscomp$1$$,$p2__46007_SHARP_$jscomp$1$$){return $app$common$types$text$copy_text_keys$$.$cljs$core$IFn$_invoke$arity$2$?
$app$common$types$text$copy_text_keys$$.$cljs$core$IFn$_invoke$arity$2$($p1__46006_SHARP_$jscomp$1$$,$p2__46007_SHARP_$jscomp$1$$):$app$common$types$text$copy_text_keys$$($p1__46006_SHARP_$jscomp$1$$,$p2__46007_SHARP_$jscomp$1$$)}}($s__46015__$1$$,$k$jscomp$584$$,$s__46015__$2$$,$temp__5825__auto__$jscomp$123$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$2$$,$k$jscomp$584$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($destiny$$,$k$jscomp$584$$)))],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1588$text$$,
$k$jscomp$584$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$584$$,$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($origin$jscomp$2$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$584$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($destiny$$,$k$jscomp$584$$)],null),$app$common$types$text$copy_text_keys_$_iter__46014$$($APP.$cljs$core$rest$$($s__46015__$2$$)));
$s__46015__$1$$=$APP.$cljs$core$rest$$($s__46015__$2$$)}else return null}},null,null)}($APP.$cljs$core$keys$$($destiny$$))}()):null};
$app$common$types$text$copy_attrs_keys$$=function $app$common$types$text$copy_attrs_keys$$($content$jscomp$17$$,$attrs$jscomp$7$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,function(){return function $app$common$types$text$copy_attrs_keys_$_iter__46027$$($s__46028$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $temp__5825__auto__$jscomp$126$$=$APP.$cljs$core$seq$$($s__46028$$);if($temp__5825__auto__$jscomp$126$$){var $s__46028__$2$$=
$temp__5825__auto__$jscomp$126$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($s__46028__$2$$)){var $c__5501__auto__$jscomp$17$$=$APP.$cljs$core$_chunked_first$$($s__46028__$2$$),$size__5502__auto__$jscomp$17$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$17$$),$b__46030$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$17$$);return function(){for(var $i__46029$$=0;;)if($i__46029$$<$size__5502__auto__$jscomp$17$$){var $vec__46032$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$17$$,$i__46029$$),
$k$jscomp$589$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__46032$$,0,null),$v$jscomp$516$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__46032$$,1,null);$APP.$cljs$core$chunk_append$$($b__46030$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$342$children$$,$k$jscomp$589$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$589$$,$APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function(){return function($p1__46025_SHARP_$$){return $app$common$types$text$copy_attrs_keys$$.$cljs$core$IFn$_invoke$arity$2$?
$app$common$types$text$copy_attrs_keys$$.$cljs$core$IFn$_invoke$arity$2$($p1__46025_SHARP_$$,$attrs$jscomp$7$$):$app$common$types$text$copy_attrs_keys$$($p1__46025_SHARP_$$,$attrs$jscomp$7$$)}}($i__46029$$,$vec__46032$$,$k$jscomp$589$$,$v$jscomp$516$$,$c__5501__auto__$jscomp$17$$,$size__5502__auto__$jscomp$17$$,$b__46030$$,$s__46028__$2$$,$temp__5825__auto__$jscomp$126$$),$v$jscomp$516$$))],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$589$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$7$$,$k$jscomp$589$$,$v$jscomp$516$$)],null));$i__46029$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__46030$$),$app$common$types$text$copy_attrs_keys_$_iter__46027$$($APP.$cljs$core$_chunked_rest$$($s__46028__$2$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__46030$$),null)}var $vec__46036$$=$APP.$cljs$core$first$$($s__46028__$2$$),$k$jscomp$588$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__46036$$,
0,null),$v$jscomp$515$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__46036$$,1,null);return $APP.$cljs$core$cons$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$342$children$$,$k$jscomp$588$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$588$$,$APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function(){return function($p1__46025_SHARP_$jscomp$1$$){return $app$common$types$text$copy_attrs_keys$$.$cljs$core$IFn$_invoke$arity$2$?
$app$common$types$text$copy_attrs_keys$$.$cljs$core$IFn$_invoke$arity$2$($p1__46025_SHARP_$jscomp$1$$,$attrs$jscomp$7$$):$app$common$types$text$copy_attrs_keys$$($p1__46025_SHARP_$jscomp$1$$,$attrs$jscomp$7$$)}}($vec__46036$$,$k$jscomp$588$$,$v$jscomp$515$$,$s__46028__$2$$,$temp__5825__auto__$jscomp$126$$),$v$jscomp$515$$))],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$588$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$7$$,
$k$jscomp$588$$,$v$jscomp$515$$)],null),$app$common$types$text$copy_attrs_keys_$_iter__46027$$($APP.$cljs$core$rest$$($s__46028__$2$$)))}return null}},null,null)}($content$jscomp$17$$)}())};$APP.$JSCompiler_prototypeAlias$$=$app$common$types$modifiers$Modifiers$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$16$$,$k__5324__auto__$jscomp$16$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$16$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$16$$,$k48461$$,$else__5326__auto__$jscomp$16$$){switch($k48461$$ instanceof $APP.$cljs$core$Keyword$$?$k48461$$.$fqn$:null){case "last-order":return this.$last_order$;case "geometry-parent":return this.$geometry_parent$;case "geometry-child":return this.$geometry_child$;case "structure-parent":return this.$structure_parent$;case "structure-child":return this.$structure_child$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,
$k48461$$,$else__5326__auto__$jscomp$16$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$16$$,$f__5344__auto__$jscomp$16$$,$init__5345__auto__$jscomp$16$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$16$$,$p__48475_v__5348__auto__$jscomp$16$$){var $k__5347__auto__$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48475_v__5348__auto__$jscomp$16$$,0,null);$p__48475_v__5348__auto__$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48475_v__5348__auto__$jscomp$16$$,
1,null);return $f__5344__auto__$jscomp$16$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$16$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$16$$,$k__5347__auto__$jscomp$16$$,$p__48475_v__5348__auto__$jscomp$16$$):$f__5344__auto__$jscomp$16$$($ret__5346__auto__$jscomp$16$$,$k__5347__auto__$jscomp$16$$,$p__48475_v__5348__auto__$jscomp$16$$)},$init__5345__auto__$jscomp$16$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$16$$,$writer__5339__auto__$jscomp$16$$,$opts__5340__auto__$jscomp$16$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$16$$,function($keyval__5342__auto__$jscomp$16$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$16$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$16$$,$keyval__5342__auto__$jscomp$16$$)},"#app.common.types.modifiers.Modifiers{",
", ","}",$opts__5340__auto__$jscomp$16$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1776$last_order$$,this.$last_order$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1777$geometry_parent$$,this.$geometry_parent$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1778$geometry_child$$,this.$geometry_child$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1779$structure_parent$$,this.$structure_parent$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1780$structure_child$$,this.$structure_child$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,5,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1776$last_order$$,$APP.$cljs$cst$1777$geometry_parent$$,$cljs$cst$1778$geometry_child$$,$cljs$cst$1779$structure_parent$$,$APP.$cljs$cst$1780$structure_child$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $app$common$types$modifiers$Modifiers$$(this.$last_order$,this.$geometry_parent$,this.$geometry_child$,this.$structure_parent$,this.$structure_child$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 5+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$45_h__5134__auto____$1$jscomp$45$$=this.$__hash$;return $h__5134__auto__$jscomp$45_h__5134__auto____$1$jscomp$45$$!=null?$h__5134__auto__$jscomp$45_h__5134__auto____$1$jscomp$45$$:this.$__hash$=$h__5134__auto__$jscomp$45_h__5134__auto____$1$jscomp$45$$=1658042313^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this48462$$,$other48463$$){return $other48463$$!=null&&this.constructor===$other48463$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$last_order$,$other48463$$.$last_order$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$geometry_parent$,$other48463$$.$geometry_parent$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$geometry_child$,$other48463$$.$geometry_child$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$structure_parent$,$other48463$$.$structure_parent$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$structure_child$,$other48463$$.$structure_child$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other48463$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$16$$,$k__5334__auto__$jscomp$16$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$1778$geometry_child$$,null,$cljs$cst$1779$structure_parent$$,null,$APP.$cljs$cst$1776$last_order$$,null,$APP.$cljs$cst$1777$geometry_parent$$,null,$APP.$cljs$cst$1780$structure_child$$,null],null),null),$k__5334__auto__$jscomp$16$$)?
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),this.$__meta$),$k__5334__auto__$jscomp$16$$):new $app$common$types$modifiers$Modifiers$$(this.$last_order$,this.$geometry_parent$,this.$geometry_child$,this.$structure_parent$,this.$structure_child$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,
$k__5334__auto__$jscomp$16$$)),null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$16$$,$k48461$jscomp$1$$){switch($k48461$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k48461$jscomp$1$$.$fqn$:null){case "last-order":case "geometry-parent":case "geometry-child":case "structure-parent":case "structure-child":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k48461$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$16$$,$k__5332__auto__$jscomp$16$$,$G__48460$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1776$last_order$$,$k__5332__auto__$jscomp$16$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1776$last_order$$,$k__5332__auto__$jscomp$16$$))?
new $app$common$types$modifiers$Modifiers$$($G__48460$jscomp$1$$,this.$geometry_parent$,this.$geometry_child$,this.$structure_parent$,this.$structure_child$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1777$geometry_parent$$,$k__5332__auto__$jscomp$16$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1777$geometry_parent$$,
$k__5332__auto__$jscomp$16$$))?new $app$common$types$modifiers$Modifiers$$(this.$last_order$,$G__48460$jscomp$1$$,this.$geometry_child$,this.$structure_parent$,this.$structure_child$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1778$geometry_child$$,$k__5332__auto__$jscomp$16$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1778$geometry_child$$,
$k__5332__auto__$jscomp$16$$))?new $app$common$types$modifiers$Modifiers$$(this.$last_order$,this.$geometry_parent$,$G__48460$jscomp$1$$,this.$structure_parent$,this.$structure_child$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1779$structure_parent$$,$k__5332__auto__$jscomp$16$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$1779$structure_parent$$,
$k__5332__auto__$jscomp$16$$))?new $app$common$types$modifiers$Modifiers$$(this.$last_order$,this.$geometry_parent$,this.$geometry_child$,$G__48460$jscomp$1$$,this.$structure_child$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1780$structure_child$$,$k__5332__auto__$jscomp$16$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1780$structure_child$$,
$k__5332__auto__$jscomp$16$$))?new $app$common$types$modifiers$Modifiers$$(this.$last_order$,this.$geometry_parent$,this.$geometry_child$,this.$structure_parent$,$G__48460$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $app$common$types$modifiers$Modifiers$$(this.$last_order$,this.$geometry_parent$,this.$geometry_child$,this.$structure_parent$,this.$structure_child$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$16$$,$G__48460$jscomp$1$$),
null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1776$last_order$$,this.$last_order$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1777$geometry_parent$$,this.$geometry_parent$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1778$geometry_child$$,this.$geometry_child$,
null),new $APP.$cljs$core$MapEntry$$($cljs$cst$1779$structure_parent$$,this.$structure_parent$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1780$structure_child$$,this.$structure_child$,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$16$$,$G__48460$jscomp$2$$){return new $app$common$types$modifiers$Modifiers$$(this.$last_order$,this.$geometry_parent$,this.$geometry_child$,this.$structure_parent$,this.$structure_child$,$G__48460$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$16$$,$entry__5329__auto__$jscomp$16$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$16$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$16$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$16$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$16$$)};
$APP.$JSCompiler_prototypeAlias$$=$APP.$app$common$types$modifiers$GeometricOperation$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$17$$,$k__5324__auto__$jscomp$17$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$17$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$17$$,$k48511$$,$else__5326__auto__$jscomp$17$$){switch($k48511$$ instanceof $APP.$cljs$core$Keyword$$?$k48511$$.$fqn$:null){case "order":return this.order;case "type":return this.type;case "vector":return this.$vector$;case "origin":return this.origin;case "transform":return this.transform;case "transform-inverse":return this.$transform_inverse$;case "rotation":return this.rotation;case "center":return this.$center$;
default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k48511$$,$else__5326__auto__$jscomp$17$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$17$$,$f__5344__auto__$jscomp$17$$,$init__5345__auto__$jscomp$17$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$17$$,$p__48516_v__5348__auto__$jscomp$17$$){var $k__5347__auto__$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48516_v__5348__auto__$jscomp$17$$,0,null);$p__48516_v__5348__auto__$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48516_v__5348__auto__$jscomp$17$$,
1,null);return $f__5344__auto__$jscomp$17$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$17$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$17$$,$k__5347__auto__$jscomp$17$$,$p__48516_v__5348__auto__$jscomp$17$$):$f__5344__auto__$jscomp$17$$($ret__5346__auto__$jscomp$17$$,$k__5347__auto__$jscomp$17$$,$p__48516_v__5348__auto__$jscomp$17$$)},$init__5345__auto__$jscomp$17$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$17$$,$writer__5339__auto__$jscomp$17$$,$opts__5340__auto__$jscomp$17$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$17$$,function($keyval__5342__auto__$jscomp$17$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$17$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$17$$,$keyval__5342__auto__$jscomp$17$$)},"#app.common.types.modifiers.GeometricOperation{",
", ","}",$opts__5340__auto__$jscomp$17$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$365$order$$,this.order],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,this.type],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,this.$vector$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1786$origin$$,this.origin],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1289$transform$$,this.transform],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1787$transform_inverse$$,
this.$transform_inverse$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1788$rotation$$,this.rotation],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1667$center$$,this.$center$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,8,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$365$order$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$1289$transform$$,$APP.$cljs$cst$1787$transform_inverse$$,$APP.$cljs$cst$1788$rotation$$,$APP.$cljs$cst$1667$center$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?
$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$app$common$types$modifiers$GeometricOperation$$(this.order,this.type,this.$vector$,this.origin,this.transform,this.$transform_inverse$,this.rotation,this.$center$,this.$__meta$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 8+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$46_h__5134__auto____$1$jscomp$46$$=this.$__hash$;return $h__5134__auto__$jscomp$46_h__5134__auto____$1$jscomp$46$$!=null?$h__5134__auto__$jscomp$46_h__5134__auto____$1$jscomp$46$$:this.$__hash$=$h__5134__auto__$jscomp$46_h__5134__auto____$1$jscomp$46$$=-1819923951^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this48512$$,$other48513$$){return $other48513$$!=null&&this.constructor===$other48513$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.order,$other48513$$.order)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.type,$other48513$$.type)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$vector$,$other48513$$.$vector$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.origin,
$other48513$$.origin)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.transform,$other48513$$.transform)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$transform_inverse$,$other48513$$.$transform_inverse$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.rotation,$other48513$$.rotation)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$center$,$other48513$$.$center$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other48513$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$17$$,$k__5334__auto__$jscomp$17$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1289$transform$$,null,$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$139$type$$,null,$APP.$cljs$cst$200$vector$$,null,$APP.$cljs$cst$1667$center$$,null,$APP.$cljs$cst$1787$transform_inverse$$,null,$cljs$cst$365$order$$,
null,$APP.$cljs$cst$1786$origin$$,null],null),null),$k__5334__auto__$jscomp$17$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),this.$__meta$),$k__5334__auto__$jscomp$17$$):new $APP.$app$common$types$modifiers$GeometricOperation$$(this.order,this.type,this.$vector$,this.origin,this.transform,this.$transform_inverse$,this.rotation,this.$center$,this.$__meta$,
$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$17$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$17$$,$k48511$jscomp$1$$){switch($k48511$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k48511$jscomp$1$$.$fqn$:null){case "order":case "type":case "vector":case "origin":case "transform":case "transform-inverse":case "rotation":case "center":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k48511$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$17$$,$k__5332__auto__$jscomp$17$$,$G__48510$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$365$order$$,$k__5332__auto__$jscomp$17$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$365$order$$,$k__5332__auto__$jscomp$17$$))?new $APP.$app$common$types$modifiers$GeometricOperation$$($G__48510$jscomp$1$$,
this.type,this.$vector$,this.origin,this.transform,this.$transform_inverse$,this.rotation,this.$center$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$,$k__5332__auto__$jscomp$17$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$139$type$$,$k__5332__auto__$jscomp$17$$))?new $APP.$app$common$types$modifiers$GeometricOperation$$(this.order,
$G__48510$jscomp$1$$,this.$vector$,this.origin,this.transform,this.$transform_inverse$,this.rotation,this.$center$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$200$vector$$,$k__5332__auto__$jscomp$17$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$200$vector$$,$k__5332__auto__$jscomp$17$$))?new $APP.$app$common$types$modifiers$GeometricOperation$$(this.order,
this.type,$G__48510$jscomp$1$$,this.origin,this.transform,this.$transform_inverse$,this.rotation,this.$center$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1786$origin$$,$k__5332__auto__$jscomp$17$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1786$origin$$,$k__5332__auto__$jscomp$17$$))?new $APP.$app$common$types$modifiers$GeometricOperation$$(this.order,
this.type,this.$vector$,$G__48510$jscomp$1$$,this.transform,this.$transform_inverse$,this.rotation,this.$center$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1289$transform$$,$k__5332__auto__$jscomp$17$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1289$transform$$,$k__5332__auto__$jscomp$17$$))?new $APP.$app$common$types$modifiers$GeometricOperation$$(this.order,
this.type,this.$vector$,this.origin,$G__48510$jscomp$1$$,this.$transform_inverse$,this.rotation,this.$center$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1787$transform_inverse$$,$k__5332__auto__$jscomp$17$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1787$transform_inverse$$,$k__5332__auto__$jscomp$17$$))?
new $APP.$app$common$types$modifiers$GeometricOperation$$(this.order,this.type,this.$vector$,this.origin,this.transform,$G__48510$jscomp$1$$,this.rotation,this.$center$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1788$rotation$$,$k__5332__auto__$jscomp$17$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1788$rotation$$,
$k__5332__auto__$jscomp$17$$))?new $APP.$app$common$types$modifiers$GeometricOperation$$(this.order,this.type,this.$vector$,this.origin,this.transform,this.$transform_inverse$,$G__48510$jscomp$1$$,this.$center$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1667$center$$,$k__5332__auto__$jscomp$17$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1667$center$$,
$k__5332__auto__$jscomp$17$$))?new $APP.$app$common$types$modifiers$GeometricOperation$$(this.order,this.type,this.$vector$,this.origin,this.transform,this.$transform_inverse$,this.rotation,$G__48510$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $APP.$app$common$types$modifiers$GeometricOperation$$(this.order,this.type,this.$vector$,this.origin,this.transform,this.$transform_inverse$,this.rotation,this.$center$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,
$k__5332__auto__$jscomp$17$$,$G__48510$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$365$order$$,this.order,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$139$type$$,this.type,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$200$vector$$,this.$vector$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1786$origin$$,
this.origin,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1289$transform$$,this.transform,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1787$transform_inverse$$,this.$transform_inverse$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1788$rotation$$,this.rotation,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1667$center$$,this.$center$,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$17$$,$G__48510$jscomp$2$$){return new $APP.$app$common$types$modifiers$GeometricOperation$$(this.order,this.type,this.$vector$,this.origin,this.transform,this.$transform_inverse$,this.rotation,this.$center$,$G__48510$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$17$$,$entry__5329__auto__$jscomp$17$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$17$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$17$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$17$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$17$$)};
$APP.$JSCompiler_prototypeAlias$$=$APP.$app$common$types$modifiers$StructureOperation$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$18$$,$k__5324__auto__$jscomp$18$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$18$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$18$$,$k48553$$,$else__5326__auto__$jscomp$18$$){switch($k48553$$ instanceof $APP.$cljs$core$Keyword$$?$k48553$$.$fqn$:null){case "type":return this.type;case "property":return this.property;case "value":return this.value;case "index":return this.index;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k48553$$,$else__5326__auto__$jscomp$18$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$18$$,$f__5344__auto__$jscomp$18$$,$init__5345__auto__$jscomp$18$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$18$$,$p__48562_v__5348__auto__$jscomp$18$$){var $k__5347__auto__$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48562_v__5348__auto__$jscomp$18$$,0,null);$p__48562_v__5348__auto__$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48562_v__5348__auto__$jscomp$18$$,
1,null);return $f__5344__auto__$jscomp$18$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$18$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$18$$,$k__5347__auto__$jscomp$18$$,$p__48562_v__5348__auto__$jscomp$18$$):$f__5344__auto__$jscomp$18$$($ret__5346__auto__$jscomp$18$$,$k__5347__auto__$jscomp$18$$,$p__48562_v__5348__auto__$jscomp$18$$)},$init__5345__auto__$jscomp$18$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$18$$,$writer__5339__auto__$jscomp$18$$,$opts__5340__auto__$jscomp$18$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$18$$,function($keyval__5342__auto__$jscomp$18$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$18$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$18$$,$keyval__5342__auto__$jscomp$18$$)},"#app.common.types.modifiers.StructureOperation{",
", ","}",$opts__5340__auto__$jscomp$18$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,this.type],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$827$property$$,this.property],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,this.value],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1795$index$$,this.index],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,4,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,$cljs$cst$827$property$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1795$index$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$app$common$types$modifiers$StructureOperation$$(this.type,this.property,this.value,this.index,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 4+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$47_h__5134__auto____$1$jscomp$47$$=this.$__hash$;return $h__5134__auto__$jscomp$47_h__5134__auto____$1$jscomp$47$$!=null?$h__5134__auto__$jscomp$47_h__5134__auto____$1$jscomp$47$$:this.$__hash$=$h__5134__auto__$jscomp$47_h__5134__auto____$1$jscomp$47$$=697367287^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this48554$$,$other48555$$){return $other48555$$!=null&&this.constructor===$other48555$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.type,$other48555$$.type)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.property,$other48555$$.property)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.value,$other48555$$.value)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.index,
$other48555$$.index)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other48555$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$18$$,$k__5334__auto__$jscomp$18$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1795$index$$,null,$cljs$cst$827$property$$,null,$APP.$cljs$cst$260$value$$,null,$APP.$cljs$cst$139$type$$,null],null),null),$k__5334__auto__$jscomp$18$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$18$$):new $APP.$app$common$types$modifiers$StructureOperation$$(this.type,this.property,this.value,this.index,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$18$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$18$$,$k48553$jscomp$1$$){switch($k48553$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k48553$jscomp$1$$.$fqn$:null){case "type":case "property":case "value":case "index":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k48553$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$18$$,$k__5332__auto__$jscomp$18$$,$G__48552$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$,$k__5332__auto__$jscomp$18$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$139$type$$,$k__5332__auto__$jscomp$18$$))?
new $APP.$app$common$types$modifiers$StructureOperation$$($G__48552$jscomp$1$$,this.property,this.value,this.index,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$827$property$$,$k__5332__auto__$jscomp$18$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$827$property$$,$k__5332__auto__$jscomp$18$$))?new $APP.$app$common$types$modifiers$StructureOperation$$(this.type,
$G__48552$jscomp$1$$,this.value,this.index,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$18$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$18$$))?new $APP.$app$common$types$modifiers$StructureOperation$$(this.type,this.property,$G__48552$jscomp$1$$,
this.index,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1795$index$$,$k__5332__auto__$jscomp$18$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1795$index$$,$k__5332__auto__$jscomp$18$$))?new $APP.$app$common$types$modifiers$StructureOperation$$(this.type,this.property,this.value,$G__48552$jscomp$1$$,this.$__meta$,
this.$__extmap$,null):new $APP.$app$common$types$modifiers$StructureOperation$$(this.type,this.property,this.value,this.index,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$18$$,$G__48552$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$139$type$$,this.type,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$827$property$$,this.property,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$260$value$$,this.value,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1795$index$$,
this.index,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$18$$,$G__48552$jscomp$2$$){return new $APP.$app$common$types$modifiers$StructureOperation$$(this.type,this.property,this.value,this.index,$G__48552$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$18$$,$entry__5329__auto__$jscomp$18$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$18$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$18$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$18$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$18$$)};
$APP.$app$common$types$modifiers$maybe_add_resize$$=function $app$common$types$modifiers$maybe_add_resize$$($var_args$jscomp$927$$){switch(arguments.length){case 2:return $app$common$types$modifiers$maybe_add_resize$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$common$types$modifiers$maybe_add_resize$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$types$modifiers$maybe_add_resize$$.$cljs$core$IFn$_invoke$arity$2$=function($operations$jscomp$1$$,$op$jscomp$11$$){return $APP.$app$common$types$modifiers$maybe_add_resize$$.$cljs$core$IFn$_invoke$arity$3$($operations$jscomp$1$$,$op$jscomp$11$$,null)};
$APP.$app$common$types$modifiers$maybe_add_resize$$.$cljs$core$IFn$_invoke$arity$3$=function($G__48635_operations$jscomp$2$$,$op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$,$map__48633__$1_p__48632_precise_QMARK_$$){$map__48633__$1_p__48632_precise_QMARK_$$=$APP.$cljs$core$__destructure_map$$($map__48633__$1_p__48632_precise_QMARK_$$);$map__48633__$1_p__48632_precise_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48633__$1_p__48632_precise_QMARK_$$,$cljs$cst$1805$precise_QMARK_$$);
if($APP.$cljs$core$empty_QMARK_$$($G__48635_operations$jscomp$2$$))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$],null);var $head$jscomp$10_item$jscomp$43$$=$APP.$cljs$core$peek$$($G__48635_operations$jscomp$2$$),$op1_x$jscomp$inline_11869_type_op1$jscomp$inline_11857$$=$head$jscomp$10_item$jscomp$43$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($head$jscomp$10_item$jscomp$43$$,
$APP.$cljs$cst$139$type$$),$op1_vector$jscomp$inline_11868_op1_y$jscomp$inline_11870_transform_op1$jscomp$inline_11858$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($head$jscomp$10_item$jscomp$43$$?.transform??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($head$jscomp$10_item$jscomp$43$$,$APP.$cljs$cst$1289$transform$$),$app$common$geom$matrix$base$$),$op2_vector$jscomp$inline_11871_op2_y$jscomp$inline_11873_transform_inv_op1$jscomp$inline_11859$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($head$jscomp$10_item$jscomp$43$$?.$transform_inverse$??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($head$jscomp$10_item$jscomp$43$$,$APP.$cljs$cst$1787$transform_inverse$$),$app$common$geom$matrix$base$$),$origin_op1$jscomp$inline_11860$$=$head$jscomp$10_item$jscomp$43$$?.origin??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($head$jscomp$10_item$jscomp$43$$,$APP.$cljs$cst$1786$origin$$),$type_op2$jscomp$inline_11861$$=$op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$,
$APP.$cljs$cst$139$type$$),$transform_op2$jscomp$inline_11862$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$?.transform??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$,$APP.$cljs$cst$1289$transform$$),$app$common$geom$matrix$base$$),$transform_inv_op2$jscomp$inline_11863$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$?.$transform_inverse$??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$,$APP.$cljs$cst$1787$transform_inverse$$),$app$common$geom$matrix$base$$),$origin_op2$jscomp$inline_11864$$=$op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$?.origin??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$,$APP.$cljs$cst$1786$origin$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1799$resize$$,
$op1_x$jscomp$inline_11869_type_op1$jscomp$inline_11857$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1799$resize$$,$type_op2$jscomp$inline_11861$$)&&$app$common$geom$point$close_QMARK_$$($origin_op1$jscomp$inline_11860$$,$origin_op2$jscomp$inline_11864$$)&&$app$common$geom$matrix$close_QMARK_$$($op1_vector$jscomp$inline_11868_op1_y$jscomp$inline_11870_transform_op1$jscomp$inline_11858$$,$transform_op2$jscomp$inline_11862$$)&&$app$common$geom$matrix$close_QMARK_$$($op2_vector$jscomp$inline_11871_op2_y$jscomp$inline_11873_transform_inv_op1$jscomp$inline_11859$$,
$transform_inv_op2$jscomp$inline_11863$$)?($op1_vector$jscomp$inline_11868_op1_y$jscomp$inline_11870_transform_op1$jscomp$inline_11858$$=$head$jscomp$10_item$jscomp$43$$?.$vector$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($head$jscomp$10_item$jscomp$43$$,$APP.$cljs$cst$200$vector$$),$op1_x$jscomp$inline_11869_type_op1$jscomp$inline_11857$$=$op1_vector$jscomp$inline_11868_op1_y$jscomp$inline_11870_transform_op1$jscomp$inline_11858$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($op1_vector$jscomp$inline_11868_op1_y$jscomp$inline_11870_transform_op1$jscomp$inline_11858$$,
$APP.$cljs$cst$1510$x$$),$op1_vector$jscomp$inline_11868_op1_y$jscomp$inline_11870_transform_op1$jscomp$inline_11858$$=$op1_vector$jscomp$inline_11868_op1_y$jscomp$inline_11870_transform_op1$jscomp$inline_11858$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($op1_vector$jscomp$inline_11868_op1_y$jscomp$inline_11870_transform_op1$jscomp$inline_11858$$,$APP.$cljs$cst$1511$y$$),$op2_vector$jscomp$inline_11871_op2_y$jscomp$inline_11873_transform_inv_op1$jscomp$inline_11859$$=$op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$?.$vector$??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$,$APP.$cljs$cst$200$vector$$),$op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$=$op2_vector$jscomp$inline_11871_op2_y$jscomp$inline_11873_transform_inv_op1$jscomp$inline_11859$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($op2_vector$jscomp$inline_11871_op2_y$jscomp$inline_11873_transform_inv_op1$jscomp$inline_11859$$,$APP.$cljs$cst$1510$x$$),$op2_vector$jscomp$inline_11871_op2_y$jscomp$inline_11873_transform_inv_op1$jscomp$inline_11859$$=
$op2_vector$jscomp$inline_11871_op2_y$jscomp$inline_11873_transform_inv_op1$jscomp$inline_11859$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($op2_vector$jscomp$inline_11871_op2_y$jscomp$inline_11873_transform_inv_op1$jscomp$inline_11859$$,$APP.$cljs$cst$1511$y$$),$op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($op1_x$jscomp$inline_11869_type_op1$jscomp$inline_11857$$*$op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$,
$op1_vector$jscomp$inline_11868_op1_y$jscomp$inline_11870_transform_op1$jscomp$inline_11858$$*$op2_vector$jscomp$inline_11871_op2_y$jscomp$inline_11873_transform_inv_op1$jscomp$inline_11859$$),$head$jscomp$10_item$jscomp$43$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($head$jscomp$10_item$jscomp$43$$,$APP.$cljs$cst$200$vector$$,$op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$),$G__48635_operations$jscomp$2$$=$APP.$cljs$core$pop$$($G__48635_operations$jscomp$2$$),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__48633__$1_p__48632_precise_QMARK_$$)?
$map__48633__$1_p__48632_precise_QMARK_$$:$APP.$app$common$types$modifiers$resize_vec_QMARK_$$($head$jscomp$10_item$jscomp$43$$?.$vector$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($head$jscomp$10_item$jscomp$43$$,$APP.$cljs$cst$200$vector$$)))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48635_operations$jscomp$2$$,$head$jscomp$10_item$jscomp$43$$):$G__48635_operations$jscomp$2$$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48635_operations$jscomp$2$$,$op$jscomp$12_op2_x$jscomp$inline_11872_vector$jscomp$inline_11874$$)};
$APP.$app$common$types$modifiers$maybe_add_resize$$.$cljs$lang$maxFixedArity$=3;$APP.$app$common$types$path$helpers$segment__GT_point$$=function $app$common$types$path$helpers$segment__GT_point$$($var_args$jscomp$936$$){switch(arguments.length){case 1:return $app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$=function($segment$jscomp$1$$){return $APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$2$($segment$jscomp$1$$,$APP.$cljs$cst$1510$x$$)};
$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$2$=function($segment$jscomp$2_temp__5825__auto__$jscomp$129$$,$coord$$){$segment$jscomp$2_temp__5825__auto__$jscomp$129$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($segment$jscomp$2_temp__5825__auto__$jscomp$129$$,$APP.$cljs$cst$1430$params$$));if($APP.$cljs$core$truth_$$($segment$jscomp$2_temp__5825__auto__$jscomp$129$$))switch($coord$$ instanceof $APP.$cljs$core$Keyword$$?
$coord$$.$fqn$:null){case "c1":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($segment$jscomp$2_temp__5825__auto__$jscomp$129$$,$APP.$cljs$cst$1815$c1x$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($segment$jscomp$2_temp__5825__auto__$jscomp$129$$,$APP.$cljs$cst$1816$c1y$$));case "c2":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($segment$jscomp$2_temp__5825__auto__$jscomp$129$$,
$APP.$cljs$cst$1817$c2x$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($segment$jscomp$2_temp__5825__auto__$jscomp$129$$,$APP.$cljs$cst$1818$c2y$$));default:return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($segment$jscomp$2_temp__5825__auto__$jscomp$129$$,$APP.$cljs$cst$1510$x$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($segment$jscomp$2_temp__5825__auto__$jscomp$129$$,$APP.$cljs$cst$1511$y$$))}else return null};
$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$lang$maxFixedArity$=2;
var $app$common$types$path$helpers$command__GT_selrect$$=function $app$common$types$path$helpers$command__GT_selrect$$($var_args$jscomp$939$$){switch(arguments.length){case 1:return $app$common$types$path$helpers$command__GT_selrect$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$types$path$helpers$command__GT_selrect$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$app$common$types$path$helpers$command__GT_selrect$$.$cljs$core$IFn$_invoke$arity$1$=function($command$jscomp$1$$){return $app$common$types$path$helpers$command__GT_selrect$$.$cljs$core$IFn$_invoke$arity$2$($command$jscomp$1$$,$cljs$cst$1820$prev$$.$cljs$core$IFn$_invoke$arity$1$($command$jscomp$1$$))};
$app$common$types$path$helpers$command__GT_selrect$$.$cljs$core$IFn$_invoke$arity$2$=function($command$jscomp$2$$,$prev_point$$){var $points$jscomp$10$$=function(){var $G__46449$$=$APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($command$jscomp$2$$);switch($G__46449$$ instanceof $APP.$cljs$core$Keyword$$?$G__46449$$.$fqn$:null){case "move-to":return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($command$jscomp$2$$)],
null);case "line-to":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prev_point$$,$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($command$jscomp$2$$)],null);case "curve-to":return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prev_point$$,$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($command$jscomp$2$$)],
null),function(){var $curve$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prev_point$$,$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($command$jscomp$2$$),$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$2$($command$jscomp$2$$,$APP.$cljs$cst$1821$c1$$),$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$2$($command$jscomp$2$$,$cljs$cst$1822$c2$$)],
null);return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__46441_SHARP_$$){return $app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$02$$($curve$$,$p1__46441_SHARP_$$):$app$common$types$path$helpers$curve_values$$($curve$$,$p1__46441_SHARP_$$)},$app$common$types$path$helpers$curve_extremities$cljs$0core$0IFn$0_invoke$0arity$01$$?$app$common$types$path$helpers$curve_extremities$cljs$0core$0IFn$0_invoke$0arity$01$$($curve$$):
$app$common$types$path$helpers$curve_extremities$$($curve$$))}());default:return $APP.$cljs$core$PersistentVector$EMPTY$$}}();return $APP.$app$common$geom$rect$points__GT_rect$$($points$jscomp$10$$)};$app$common$types$path$helpers$command__GT_selrect$$.$cljs$lang$maxFixedArity$=2;var $app$common$schema$openapi$visit$$=function(){var $method_table__5622__auto__$jscomp$8$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$8$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$8$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$8$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$205$default$$,$cljs$cst$1826$app_DOT_common_DOT_schema_DOT_openapi_SLASH_default$$],null),$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():
$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.common.schema.openapi","visit"),function($name$jscomp$175$$){return $name$jscomp$175$$},$cljs$cst$1826$app_DOT_common_DOT_schema_DOT_openapi_SLASH_default$$,$hierarchy__5626__auto__$jscomp$8$$,$method_table__5622__auto__$jscomp$8$$,$prefer_table__5623__auto__$jscomp$8$$,$method_cache__5624__auto__$jscomp$8$$,$cached_hierarchy__5625__auto__$jscomp$8$$)}();
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$1826$app_DOT_common_DOT_schema_DOT_openapi_SLASH_default$$,function($_$jscomp$1098_props$jscomp$62$$,$schema$jscomp$207$$){$_$jscomp$1098_props$jscomp$62$$=$malli$core$type_properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$207$$);return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1098_props$jscomp$62$$,
$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$),$APP.$cljs$cst$954$format$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1098_props$jscomp$62$$,$cljs$cst$940$app_DOT_common_DOT_schema_DOT_openapi_SLASH_format$$),$APP.$cljs$cst$939$title$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1098_props$jscomp$62$$,$APP.$cljs$cst$939$title$$),$APP.$cljs$cst$936$description$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1098_props$jscomp$62$$,
$APP.$cljs$cst$936$description$$)],null))});$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$707$_GT_$$,function($_$jscomp$1099_value$jscomp$419$$,$___$1$jscomp$692$$,$p__46328$$){$_$jscomp$1099_value$jscomp$419$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46328$$,0,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"number",$cljs$cst$1827$exclusiveMinimum$$,$_$jscomp$1099_value$jscomp$419$$],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$708$_GT__EQ_$$,function($_$jscomp$1100_value$jscomp$420$$,$___$1$jscomp$693$$,$p__46332$$){$_$jscomp$1100_value$jscomp$420$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46332$$,0,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"number",$cljs$cst$1828$minimum$$,$_$jscomp$1100_value$jscomp$420$$],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$709$_LT_$$,function($_$jscomp$1101_value$jscomp$421$$,$___$1$jscomp$694$$,$p__46340$$){$_$jscomp$1101_value$jscomp$421$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46340$$,0,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"number",$cljs$cst$1829$exclusiveMaximum$$,$_$jscomp$1101_value$jscomp$421$$],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$710$_LT__EQ_$$,function($_$jscomp$1102_value$jscomp$422$$,$___$1$jscomp$695$$,$p__46344$$){$_$jscomp$1102_value$jscomp$422$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46344$$,0,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"number",$cljs$cst$1830$maximum$$,$_$jscomp$1102_value$jscomp$422$$],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$711$_EQ_$$,function($_$jscomp$1103_type$jscomp$325$$,$JSCompiler_temp_const$jscomp$754_schema$jscomp$208$$,$children$jscomp$139$$){var $JSCompiler_inline_result$jscomp$756_or__5025__auto__$jscomp$inline_4890_props$jscomp$63$$=$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$754_schema$jscomp$208$$);$_$jscomp$1103_type$jscomp$325$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$756_or__5025__auto__$jscomp$inline_4890_props$jscomp$63$$,
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$198$string$$);$JSCompiler_temp_const$jscomp$754_schema$jscomp$208$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_temp_const$jscomp$753$$=$APP.$cljs$cst$139$type$$;$JSCompiler_inline_result$jscomp$756_or__5025__auto__$jscomp$inline_4890_props$jscomp$63$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$756_or__5025__auto__$jscomp$inline_4890_props$jscomp$63$$,$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$);
$JSCompiler_inline_result$jscomp$756_or__5025__auto__$jscomp$inline_4890_props$jscomp$63$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$756_or__5025__auto__$jscomp$inline_4890_props$jscomp$63$$)?$JSCompiler_inline_result$jscomp$756_or__5025__auto__$jscomp$inline_4890_props$jscomp$63$$:$APP.$app$common$data$name$$($_$jscomp$1103_type$jscomp$325$$);return $JSCompiler_temp_const$jscomp$754_schema$jscomp$208$$.call($APP.$app$common$data$without_nils$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$JSCompiler_temp_const$jscomp$753$$,$JSCompiler_inline_result$jscomp$756_or__5025__auto__$jscomp$inline_4890_props$jscomp$63$$,$APP.$cljs$cst$499$enum$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$198$string$$,$_$jscomp$1103_type$jscomp$325$$)?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$name$$,$children$jscomp$139$$):$APP.$cljs$core$vec$$($children$jscomp$139$$)],null))});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$712$not_EQ_$$,function(){return $APP.$cljs$core$PersistentArrayMap$EMPTY$$});$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$516$fn$$,function(){return null});$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$966$app_DOT_common_DOT_schema_SLASH_contains_any$$,function(){return null});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$444$not$$,function($_$jscomp$1107$$,$___$1$jscomp$700$$,$children$jscomp$140$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$444$not$$,$APP.$cljs$core$last$$($children$jscomp$140$$)],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$429$and$$,function($_$jscomp$1108$$,$___$1$jscomp$701$$,$children$jscomp$141$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1831$allOf$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$not_empty$$,$children$jscomp$141$$)],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$433$or$$,function($_$jscomp$1109$$,$___$1$jscomp$702$$,$children$jscomp$142$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1832$anyOf$$,$children$jscomp$142$$],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$438$orn$$,function($_$jscomp$1110$$,$___$1$jscomp$703$$,$children$jscomp$143$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1832$anyOf$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$last$$,$children$jscomp$143$$)],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$449$malli_DOT_core_SLASH_val$$,function($_$jscomp$1111$$,$___$1$jscomp$704$$,$children$jscomp$144$$){return $APP.$cljs$core$first$$($children$jscomp$144$$)});
var $app$common$schema$openapi$required_xf$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($malli$core$_comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$not$$,$APP.$cljs$cst$450$optional$$,$APP.$cljs$core$second$$)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($cuerdas$core$camel$$));
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$202$map$$,function($G__46383__$1__$jscomp$1112_required$jscomp$2$$,$closed_QMARK__schema$jscomp$209$$,$G__46383_children$jscomp$145_props$jscomp$64$$){$G__46383__$1__$jscomp$1112_required$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$common$schema$openapi$required_xf$$,$G__46383_children$jscomp$145_props$jscomp$64$$);$G__46383_children$jscomp$145_props$jscomp$64$$=
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$array_map$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p__46372_s$jscomp$520$$){var $k$jscomp$592$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46372_s$jscomp$520$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46372_s$jscomp$520$$,1,null);$p__46372_s$jscomp$520$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__46372_s$jscomp$520$$,2,null);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cuerdas$core$camel$$($k$jscomp$592$$),$p__46372_s$jscomp$520$$],null)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$hidden$$,$G__46383_children$jscomp$145_props$jscomp$64$$)])));$closed_QMARK__schema$jscomp$209$$=$cljs$cst$462$closed$$.$cljs$core$IFn$_invoke$arity$1$($APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($closed_QMARK__schema$jscomp$209$$));
$G__46383_children$jscomp$145_props$jscomp$64$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"object",$cljs$cst$341$properties$$,$G__46383_children$jscomp$145_props$jscomp$64$$],null);$G__46383__$1__$jscomp$1112_required$jscomp$2$$=$APP.$cljs$core$seq$$($G__46383__$1__$jscomp$1112_required$jscomp$2$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__46383_children$jscomp$145_props$jscomp$64$$,$APP.$cljs$cst$1833$required$$,$G__46383__$1__$jscomp$1112_required$jscomp$2$$):
$G__46383_children$jscomp$145_props$jscomp$64$$;return $APP.$cljs$core$truth_$$($closed_QMARK__schema$jscomp$209$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__46383__$1__$jscomp$1112_required$jscomp$2$$,$cljs$cst$1834$additionalProperties$$,!1):$G__46383__$1__$jscomp$1112_required$jscomp$2$$});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$531$multi$$,function($_$jscomp$1113$$,$___$1$jscomp$706$$,$children$jscomp$146$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1835$oneOf$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$last$$,$children$jscomp$146$$)],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$463$map_of$$,function($_$jscomp$1114$$,$schema$jscomp$211$$,$children$jscomp$147$$){return $app$common$schema$openapi$minmax_properties$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"object",$cljs$cst$1834$additionalProperties$$,$APP.$cljs$core$second$$($children$jscomp$147$$)],null),$schema$jscomp$211$$,$cljs$cst$1836$minProperties$$,$cljs$cst$1837$maxProperties$$)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$418$any$$,function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$936$description$$,"Any Value"],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,function($_$jscomp$1116$$,$schema$jscomp$212$$,$children$jscomp$148$$){return $app$common$schema$openapi$minmax_properties$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,"array",$APP.$cljs$cst$1838$items$$,$APP.$cljs$core$first$$($children$jscomp$148$$),$cljs$cst$1839$uniqueItems$$,!0],null),$schema$jscomp$212$$,$cljs$cst$1840$minItems$$,
$cljs$cst$1841$maxItems$$)});$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$951$app_DOT_common_DOT_schema_SLASH_vec$$,function($_$jscomp$1117$$,$schema$jscomp$213$$,$children$jscomp$149$$){return $app$common$schema$openapi$minmax_properties$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"array",$APP.$cljs$cst$1838$items$$,$APP.$cljs$core$first$$($children$jscomp$149$$)],null),$schema$jscomp$213$$,$cljs$cst$1840$minItems$$,$cljs$cst$1841$maxItems$$)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$200$vector$$,function($_$jscomp$1118$$,$schema$jscomp$214$$,$children$jscomp$150$$,$options$jscomp$426$$){return $app$common$schema$openapi$visit$$.$cljs$core$IFn$_invoke$arity$4$($cljs$cst$951$app_DOT_common_DOT_schema_SLASH_vec$$,$schema$jscomp$214$$,$children$jscomp$150$$,$options$jscomp$426$$)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$203$set$$,function($_$jscomp$1119$$,$schema$jscomp$215$$,$children$jscomp$151$$,$options$jscomp$427$$){return $app$common$schema$openapi$visit$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,$schema$jscomp$215$$,$children$jscomp$151$$,$options$jscomp$427$$)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$720$sequential$$,function($_$jscomp$1120$$,$schema$jscomp$216$$,$children$jscomp$152$$){return $app$common$schema$openapi$minmax_properties$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"array",$APP.$cljs$cst$1838$items$$,$APP.$cljs$core$first$$($children$jscomp$152$$)],null),$schema$jscomp$216$$,$cljs$cst$1840$minItems$$,$cljs$cst$1841$maxItems$$)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$499$enum$$,function($JSCompiler_temp_const$jscomp$757__$jscomp$1121$$,$G__46411$jscomp$inline_4892____$1$jscomp$712$$,$children$jscomp$153$$,$JSCompiler_inline_result$jscomp$759_options$jscomp$428$$){$JSCompiler_temp_const$jscomp$757__$jscomp$1121$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$;$G__46411$jscomp$inline_4892____$1$jscomp$712$$=$malli$core$_infer$$($children$jscomp$153$$);
$JSCompiler_inline_result$jscomp$759_options$jscomp$428$$=$G__46411$jscomp$inline_4892____$1$jscomp$712$$==null?null:$app$common$schema$openapi$transform_STAR_$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$schema$openapi$transform_STAR_$$.$cljs$core$IFn$_invoke$arity$2$($G__46411$jscomp$inline_4892____$1$jscomp$712$$,$JSCompiler_inline_result$jscomp$759_options$jscomp$428$$):$app$common$schema$openapi$transform_STAR_$$($G__46411$jscomp$inline_4892____$1$jscomp$712$$,$JSCompiler_inline_result$jscomp$759_options$jscomp$428$$);
return $JSCompiler_temp_const$jscomp$757__$jscomp$1121$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_inline_result$jscomp$759_options$jscomp$428$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$499$enum$$,$children$jscomp$153$$],null)]))});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$522$maybe$$,function($_$jscomp$1122_children__$1$jscomp$21$$,$___$1$jscomp$713$$,$children$jscomp$154$$){$_$jscomp$1122_children__$1$jscomp$21$$=$APP.$cljs$core$first$$($children$jscomp$154$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$1122_children__$1$jscomp$21$$,$cljs$cst$1842$nullable$$,!0)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$498$tuple$$,function($_$jscomp$1123$$,$___$1$jscomp$714$$,$children$jscomp$155$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,"array",$APP.$cljs$cst$1838$items$$,$children$jscomp$155$$,$cljs$cst$1843$additionalItems$$,!1],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$512$re$$,function($_$jscomp$1124$$,$schema$jscomp$217$$,$___$1$jscomp$715$$,$options$jscomp$429$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"string",$cljs$cst$1844$pattern$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($malli$core$children$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$217$$,$options$jscomp$429$$)))],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$197$nil$$,function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,"null"],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$198$string$$,function($_$jscomp$1126$$,$schema$jscomp$218$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,"string"],null),$APP.$clojure$set$rename_keys$$($APP.$cljs$core$select_keys$$($APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$218$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$338$min$$,$APP.$cljs$cst$339$max$$],null)),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,$cljs$cst$1845$minLength$$,$APP.$cljs$cst$339$max$$,$cljs$cst$1846$maxLength$$],null))]))});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,function($_$jscomp$1127_options$jscomp$430$$,$___$1$jscomp$718$$,$children$jscomp$156$$){$_$jscomp$1127_options$jscomp$430$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$name$$,$APP.$cljs$core$first$$($children$jscomp$156$$));return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"string",$APP.$cljs$cst$499$enum$$,
$_$jscomp$1127_options$jscomp$430$$],null)});$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$344$int$$,function($_$jscomp$1128$$,$schema$jscomp$219$$){return $app$common$schema$openapi$minmax_properties$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,"integer"],null),$schema$jscomp$219$$,$cljs$cst$1828$minimum$$,$cljs$cst$1830$maximum$$)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$345$double$$,function($_$jscomp$1129$$,$schema$jscomp$220$$){return $app$common$schema$openapi$minmax_properties$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"number",$APP.$cljs$cst$954$format$$,"double"],null),$schema$jscomp$220$$,$cljs$cst$1828$minimum$$,$cljs$cst$1830$maximum$$)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$,function($_$jscomp$1130$$,$schema$jscomp$221$$,$children$jscomp$157$$,$options$jscomp$431$$){return $app$common$schema$openapi$visit$$.$cljs$core$IFn$_invoke$arity$4$($cljs$cst$344$int$$,$schema$jscomp$221$$,$children$jscomp$157$$,$options$jscomp$431$$)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$959$app_DOT_common_DOT_schema_SLASH_double$$,function($_$jscomp$1131$$,$schema$jscomp$222$$,$children$jscomp$158$$,$options$jscomp$432$$){return $app$common$schema$openapi$visit$$.$cljs$core$IFn$_invoke$arity$4$($cljs$cst$345$double$$,$schema$jscomp$222$$,$children$jscomp$158$$,$options$jscomp$432$$)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$421$boolean$$,function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,"boolean"],null)});$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$,function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,"boolean"],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$221$keyword$$,function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,"string"],null)});$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$422$qualified_keyword$$,function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,"string"],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$219$symbol$$,function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,"string"],null)});$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$423$qualified_symbol$$,function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,"string"],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$424$uuid$$,function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"string",$APP.$cljs$cst$954$format$$,"uuid"],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$,function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"string",$APP.$cljs$cst$954$format$$,"uuid"],null)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$298$schema$$,function($_$jscomp$1140$$,$schema$jscomp$223$$,$children$jscomp$159$$,$options$jscomp$433$$){return $app$common$schema$openapi$visit$$.$cljs$core$IFn$_invoke$arity$4$($cljs$cst$412$malli_DOT_core_SLASH_schema$$,$schema$jscomp$223$$,$children$jscomp$159$$,$options$jscomp$433$$)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$412$malli_DOT_core_SLASH_schema$$,function($G__46438$jscomp$inline_4894__$jscomp$1141_defpath$$,$nname_nname__$1_rkey_schema$jscomp$224$$,$___$1$jscomp$729_result$jscomp$176$$,$options$jscomp$434_temp__5823__auto__$jscomp$102_tname_tname__$1$$){$G__46438$jscomp$inline_4894__$jscomp$1141_defpath$$=$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$($nname_nname__$1_rkey_schema$jscomp$224$$,null);$___$1$jscomp$729_result$jscomp$176$$=
$app$common$schema$openapi$transform_STAR_$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$schema$openapi$transform_STAR_$$.$cljs$core$IFn$_invoke$arity$2$($G__46438$jscomp$inline_4894__$jscomp$1141_defpath$$,$options$jscomp$434_temp__5823__auto__$jscomp$102_tname_tname__$1$$):$app$common$schema$openapi$transform_STAR_$$($G__46438$jscomp$inline_4894__$jscomp$1141_defpath$$,$options$jscomp$434_temp__5823__auto__$jscomp$102_tname_tname__$1$$);$G__46438$jscomp$inline_4894__$jscomp$1141_defpath$$=$cljs$cst$1847$app_DOT_common_DOT_schema_DOT_openapi_SLASH_definitions_path$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$434_temp__5823__auto__$jscomp$102_tname_tname__$1$$,
"#/definitions/");if($APP.$cljs$core$truth_$$($cljs$cst$1848$app_DOT_common_DOT_schema_DOT_openapi_SLASH_embed$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$434_temp__5823__auto__$jscomp$102_tname_tname__$1$$)))return $___$1$jscomp$729_result$jscomp$176$$;$options$jscomp$434_temp__5823__auto__$jscomp$102_tname_tname__$1$$=$malli$core$_ref$$($nname_nname__$1_rkey_schema$jscomp$224$$);return $APP.$cljs$core$truth_$$($options$jscomp$434_temp__5823__auto__$jscomp$102_tname_tname__$1$$)?($nname_nname__$1_rkey_schema$jscomp$224$$=
$APP.$cljs$core$namespace$$($options$jscomp$434_temp__5823__auto__$jscomp$102_tname_tname__$1$$),$options$jscomp$434_temp__5823__auto__$jscomp$102_tname_tname__$1$$=$APP.$cljs$core$name$$($options$jscomp$434_temp__5823__auto__$jscomp$102_tname_tname__$1$$),$options$jscomp$434_temp__5823__auto__$jscomp$102_tname_tname__$1$$=$APP.$cuerdas$core$capital$$($cuerdas$core$camel$$($options$jscomp$434_temp__5823__auto__$jscomp$102_tname_tname__$1$$)),$nname_nname__$1_rkey_schema$jscomp$224$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($nname_nname__$1_rkey_schema$jscomp$224$$,
"app.common.schema")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($nname_nname__$1_rkey_schema$jscomp$224$$,"app.common.time")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($nname_nname__$1_rkey_schema$jscomp$224$$,"app.common.features")?"":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($nname_nname__$1_rkey_schema$jscomp$224$$,"datoteka.fs")?"Filesystem":$APP.$cuerdas$core$starts_with_QMARK_$$($nname_nname__$1_rkey_schema$jscomp$224$$,"app.common.geom")?$APP.$cuerdas$core$capital$$($cuerdas$core$camel$$($APP.$cuerdas$core$replace$$($nname_nname__$1_rkey_schema$jscomp$224$$,
/app\.common\.geom\.\w+/,"geom"))):$APP.$cuerdas$core$starts_with_QMARK_$$($nname_nname__$1_rkey_schema$jscomp$224$$,"app.")?$APP.$cuerdas$core$capital$$($cuerdas$core$camel$$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($nname_nname__$1_rkey_schema$jscomp$224$$,4))):$APP.$cuerdas$core$capital$$($cuerdas$core$camel$$($nname_nname__$1_rkey_schema$jscomp$224$$)),$nname_nname__$1_rkey_schema$jscomp$224$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($nname_nname__$1_rkey_schema$jscomp$224$$),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$434_temp__5823__auto__$jscomp$102_tname_tname__$1$$)].join(""),new $APP.$cljs$core$PersistentArrayMap$$(null,1,["$ref",""+($G__46438$jscomp$inline_4894__$jscomp$1141_defpath$$??"")+($nname_nname__$1_rkey_schema$jscomp$224$$??"")],null)):$___$1$jscomp$729_result$jscomp$176$$});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$735$merge$$,function($G__46447__$jscomp$1142$$,$schema$jscomp$225$$,$___$1$jscomp$730$$,$options$jscomp$435$$){$G__46447__$jscomp$1142$$=$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$($schema$jscomp$225$$,null);return $app$common$schema$openapi$transform_STAR_$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$schema$openapi$transform_STAR_$$.$cljs$core$IFn$_invoke$arity$2$($G__46447__$jscomp$1142$$,
$options$jscomp$435$$):$app$common$schema$openapi$transform_STAR_$$($G__46447__$jscomp$1142$$,$options$jscomp$435$$)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$736$union$$,function($G__46450__$jscomp$1143$$,$schema$jscomp$226$$,$___$1$jscomp$731$$,$options$jscomp$436$$){$G__46450__$jscomp$1143$$=$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$($schema$jscomp$226$$,null);return $app$common$schema$openapi$transform_STAR_$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$schema$openapi$transform_STAR_$$.$cljs$core$IFn$_invoke$arity$2$($G__46450__$jscomp$1143$$,
$options$jscomp$436$$):$app$common$schema$openapi$transform_STAR_$$($G__46450__$jscomp$1143$$,$options$jscomp$436$$)});
$app$common$schema$openapi$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$737$select_keys$$,function($G__46453__$jscomp$1144$$,$schema$jscomp$227$$,$___$1$jscomp$732$$,$options$jscomp$437$$){$G__46453__$jscomp$1144$$=$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$($schema$jscomp$227$$,null);return $app$common$schema$openapi$transform_STAR_$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$schema$openapi$transform_STAR_$$.$cljs$core$IFn$_invoke$arity$2$($G__46453__$jscomp$1144$$,
$options$jscomp$437$$):$app$common$schema$openapi$transform_STAR_$$($G__46453__$jscomp$1144$$,$options$jscomp$437$$)});/*
 MPL-2.0 <https://www.mozilla.org/en-US/MPL/2.0/>
*/
var $MOVE_TO$$module$app$common$svg$path$parser$$=$APP.$cljs$core$keyword$$("move-to"),$CLOSE_PATH$$module$app$common$svg$path$parser$$=$APP.$cljs$core$keyword$$("close-path"),$LINE_TO$$module$app$common$svg$path$parser$$=$APP.$cljs$core$keyword$$("line-to"),$CURVE_TO$$module$app$common$svg$path$parser$$=$APP.$cljs$core$keyword$$("curve-to"),$K_COMMAND$$module$app$common$svg$path$parser$$=$APP.$cljs$core$keyword$$("command"),$K_PARAMS$$module$app$common$svg$path$parser$$=$APP.$cljs$core$keyword$$("params"),
$K_X$$module$app$common$svg$path$parser$$=$APP.$cljs$core$keyword$$("x"),$K_Y$$module$app$common$svg$path$parser$$=$APP.$cljs$core$keyword$$("y"),$K_C1X$$module$app$common$svg$path$parser$$=$APP.$cljs$core$keyword$$("c1x"),$K_C1Y$$module$app$common$svg$path$parser$$=$APP.$cljs$core$keyword$$("c1y"),$K_C2X$$module$app$common$svg$path$parser$$=$APP.$cljs$core$keyword$$("c2x"),$K_C2Y$$module$app$common$svg$path$parser$$=$APP.$cljs$core$keyword$$("c2y"),$Segment$$module$app$common$svg$path$parser$$=class{constructor($command$jscomp$3$$,
$params$jscomp$97$$){this.command=$command$jscomp$3$$;this.params=$params$jscomp$97$$}toPersistentMap(){let $command$jscomp$4$$,$params$jscomp$98$$;switch(this.command){case "M":$command$jscomp$4$$=$MOVE_TO$$module$app$common$svg$path$parser$$;$params$jscomp$98$$=$APP.$cljs$core$PersistentArrayMap$fromArray$$([$K_X$$module$app$common$svg$path$parser$$,this.params[0],$K_Y$$module$app$common$svg$path$parser$$,this.params[1]]);break;case "Z":$command$jscomp$4$$=$CLOSE_PATH$$module$app$common$svg$path$parser$$;
$params$jscomp$98$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;break;case "L":$command$jscomp$4$$=$LINE_TO$$module$app$common$svg$path$parser$$;$params$jscomp$98$$=$APP.$cljs$core$PersistentArrayMap$fromArray$$([$K_X$$module$app$common$svg$path$parser$$,this.params[0],$K_Y$$module$app$common$svg$path$parser$$,this.params[1]]);break;case "C":$command$jscomp$4$$=$CURVE_TO$$module$app$common$svg$path$parser$$;$params$jscomp$98$$=$APP.$cljs$core$PersistentArrayMap$fromArray$$([$K_C1X$$module$app$common$svg$path$parser$$,
this.params[0],$K_C1Y$$module$app$common$svg$path$parser$$,this.params[1],$K_C2X$$module$app$common$svg$path$parser$$,this.params[2],$K_C2Y$$module$app$common$svg$path$parser$$,this.params[3],$K_X$$module$app$common$svg$path$parser$$,this.params[4],$K_Y$$module$app$common$svg$path$parser$$,this.params[5]]);break;default:$params$jscomp$98$$=$command$jscomp$4$$=null}if($command$jscomp$4$$===null||$params$jscomp$98$$===null)throw Error("invalid segment");return $APP.$cljs$core$PersistentArrayMap$fromArray$$([$K_COMMAND$$module$app$common$svg$path$parser$$,
$command$jscomp$4$$,$K_PARAMS$$module$app$common$svg$path$parser$$,$params$jscomp$98$$])}},$Parser$$module$app$common$svg$path$parser$$=class{constructor($string$jscomp$18$$){this.$_string$=$string$jscomp$18$$;this.$_currentIndex$=0;this.$_endIndex$=this.$_string$.length;this.$_prevCommand$=null;$JSCompiler_StaticMethods__skipOptionalSpaces$$(this)}[Symbol.iterator](){return this}next(){if(this.hasNext()){a:{var $ch$jscomp$inline_4897_params$jscomp$inline_4899$$=this.$_string$[this.$_currentIndex$];
var $JSCompiler_inline_result$jscomp$761_JSCompiler_temp$jscomp$760_command$jscomp$inline_4898$$=$validCommand$$module$app$common$svg$path$parser$$($ch$jscomp$inline_4897_params$jscomp$inline_4899$$)?$ch$jscomp$inline_4897_params$jscomp$inline_4899$$:null;if($JSCompiler_inline_result$jscomp$761_JSCompiler_temp$jscomp$760_command$jscomp$inline_4898$$===null){if(this.$_prevCommand$===null){$JSCompiler_inline_result$jscomp$761_JSCompiler_temp$jscomp$760_command$jscomp$inline_4898$$=null;break a}$JSCompiler_inline_result$jscomp$761_JSCompiler_temp$jscomp$760_command$jscomp$inline_4898$$=
($ch$jscomp$inline_4897_params$jscomp$inline_4899$$==="+"||$ch$jscomp$inline_4897_params$jscomp$inline_4899$$==="-"||$ch$jscomp$inline_4897_params$jscomp$inline_4899$$==="."||$ch$jscomp$inline_4897_params$jscomp$inline_4899$$>="0"&&$ch$jscomp$inline_4897_params$jscomp$inline_4899$$<="9")&&this.$_prevCommand$!=="Z"?this.$_prevCommand$==="M"?"L":this.$_prevCommand$==="m"?"l":this.$_prevCommand$:null;if($JSCompiler_inline_result$jscomp$761_JSCompiler_temp$jscomp$760_command$jscomp$inline_4898$$===null){$JSCompiler_inline_result$jscomp$761_JSCompiler_temp$jscomp$760_command$jscomp$inline_4898$$=
null;break a}}else this.$_currentIndex$+=1;this.$_prevCommand$=$JSCompiler_inline_result$jscomp$761_JSCompiler_temp$jscomp$760_command$jscomp$inline_4898$$;$ch$jscomp$inline_4897_params$jscomp$inline_4899$$=null;var $cmd$jscomp$inline_4900$$=$JSCompiler_inline_result$jscomp$761_JSCompiler_temp$jscomp$760_command$jscomp$inline_4898$$.toUpperCase();$cmd$jscomp$inline_4900$$==="H"||$cmd$jscomp$inline_4900$$==="V"?$ch$jscomp$inline_4897_params$jscomp$inline_4899$$=[$JSCompiler_StaticMethods__parseNumber$$(this)]:
$cmd$jscomp$inline_4900$$==="M"||$cmd$jscomp$inline_4900$$==="L"||$cmd$jscomp$inline_4900$$==="T"?$ch$jscomp$inline_4897_params$jscomp$inline_4899$$=[$JSCompiler_StaticMethods__parseNumber$$(this),$JSCompiler_StaticMethods__parseNumber$$(this)]:$cmd$jscomp$inline_4900$$==="S"||$cmd$jscomp$inline_4900$$==="Q"?$ch$jscomp$inline_4897_params$jscomp$inline_4899$$=[$JSCompiler_StaticMethods__parseNumber$$(this),$JSCompiler_StaticMethods__parseNumber$$(this),$JSCompiler_StaticMethods__parseNumber$$(this),
$JSCompiler_StaticMethods__parseNumber$$(this)]:$cmd$jscomp$inline_4900$$==="C"?$ch$jscomp$inline_4897_params$jscomp$inline_4899$$=[$JSCompiler_StaticMethods__parseNumber$$(this),$JSCompiler_StaticMethods__parseNumber$$(this),$JSCompiler_StaticMethods__parseNumber$$(this),$JSCompiler_StaticMethods__parseNumber$$(this),$JSCompiler_StaticMethods__parseNumber$$(this),$JSCompiler_StaticMethods__parseNumber$$(this)]:$cmd$jscomp$inline_4900$$==="A"?$ch$jscomp$inline_4897_params$jscomp$inline_4899$$=[$JSCompiler_StaticMethods__parseNumber$$(this),
$JSCompiler_StaticMethods__parseNumber$$(this),$JSCompiler_StaticMethods__parseNumber$$(this),$JSCompiler_StaticMethods__parseArcFlag$$(this),$JSCompiler_StaticMethods__parseArcFlag$$(this),$JSCompiler_StaticMethods__parseNumber$$(this),$JSCompiler_StaticMethods__parseNumber$$(this)]:$cmd$jscomp$inline_4900$$==="Z"&&($JSCompiler_StaticMethods__skipOptionalSpaces$$(this),$ch$jscomp$inline_4897_params$jscomp$inline_4899$$=[]);$JSCompiler_inline_result$jscomp$761_JSCompiler_temp$jscomp$760_command$jscomp$inline_4898$$=
$ch$jscomp$inline_4897_params$jscomp$inline_4899$$===null||$ch$jscomp$inline_4897_params$jscomp$inline_4899$$.indexOf(null)>=0?null:new $Segment$$module$app$common$svg$path$parser$$($JSCompiler_inline_result$jscomp$761_JSCompiler_temp$jscomp$760_command$jscomp$inline_4898$$,$ch$jscomp$inline_4897_params$jscomp$inline_4899$$)}$JSCompiler_inline_result$jscomp$761_JSCompiler_temp$jscomp$760_command$jscomp$inline_4898$$={done:!1,value:$JSCompiler_inline_result$jscomp$761_JSCompiler_temp$jscomp$760_command$jscomp$inline_4898$$}}else $JSCompiler_inline_result$jscomp$761_JSCompiler_temp$jscomp$760_command$jscomp$inline_4898$$=
{done:!0};return $JSCompiler_inline_result$jscomp$761_JSCompiler_temp$jscomp$760_command$jscomp$inline_4898$$}hasNext(){if(this.$_currentIndex$===0){var $JSCompiler_inline_result$jscomp$762_ch$jscomp$inline_4903$$=this.$_string$[this.$_currentIndex$];$JSCompiler_inline_result$jscomp$762_ch$jscomp$inline_4903$$=$validCommand$$module$app$common$svg$path$parser$$($JSCompiler_inline_result$jscomp$762_ch$jscomp$inline_4903$$)?$JSCompiler_inline_result$jscomp$762_ch$jscomp$inline_4903$$:null;return this.$_currentIndex$<
this.$_endIndex$&&($JSCompiler_inline_result$jscomp$762_ch$jscomp$inline_4903$$==="M"||$JSCompiler_inline_result$jscomp$762_ch$jscomp$inline_4903$$==="m")}return this.$_currentIndex$<this.$_endIndex$}};$module$app$common$svg$path$parser$$={};$module$app$common$svg$path$parser$$.$arcToBeziers$=$arcToBeziers$$module$app$common$svg$path$parser$$;
$module$app$common$svg$path$parser$$.parse=function($string$jscomp$19$$){if(!$string$jscomp$19$$||$string$jscomp$19$$.length===0)return[];try{var $pdata$jscomp$inline_4976_result$jscomp$179$$=Array.from(new $Parser$$module$app$common$svg$path$parser$$($string$jscomp$19$$)),$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$=$pdata$jscomp$inline_4976_result$jscomp$179$$,$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=null,$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=
null,$lastControlY$jscomp$inline_4980_subpathX$jscomp$inline_4965$$=null,$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$=null;for(let $i$jscomp$inline_4973$$=0;$i$jscomp$inline_4973$$<$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$.length;$i$jscomp$inline_4973$$++){let $segment$jscomp$inline_4974$$=$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$[$i$jscomp$inline_4973$$];switch($segment$jscomp$inline_4974$$.command){case "M":var $currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=
$segment$jscomp$inline_4974$$.params[0],$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$segment$jscomp$inline_4974$$.params[1];$lastControlY$jscomp$inline_4980_subpathX$jscomp$inline_4965$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=
$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;break;case "m":$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$+$segment$jscomp$inline_4974$$.params[0];$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$+$segment$jscomp$inline_4974$$.params[1];$segment$jscomp$inline_4974$$.command="M";$segment$jscomp$inline_4974$$.params[0]=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;
$segment$jscomp$inline_4974$$.params[1]=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;$lastControlY$jscomp$inline_4980_subpathX$jscomp$inline_4965$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;
break;case "L":$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$segment$jscomp$inline_4974$$.params[0];$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$segment$jscomp$inline_4974$$.params[1];$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;break;case "l":$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$+
$segment$jscomp$inline_4974$$.params[0];$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$+$segment$jscomp$inline_4974$$.params[1];$segment$jscomp$inline_4974$$.command="L";$segment$jscomp$inline_4974$$.params[0]=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$segment$jscomp$inline_4974$$.params[1]=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;
$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;break;case "C":$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$segment$jscomp$inline_4974$$.params[4];$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$segment$jscomp$inline_4974$$.params[5];$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;
break;case "c":var $subpathY$jscomp$inline_4984_x1$jscomp$inline_4969$$=$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$+$segment$jscomp$inline_4974$$.params[0],$i$jscomp$inline_5001_y1$jscomp$inline_4970$$=$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$+$segment$jscomp$inline_4974$$.params[1],$x2$jscomp$inline_4971$$=$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$+$segment$jscomp$inline_4974$$.params[2],$y2$jscomp$inline_4972$$=$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$+
$segment$jscomp$inline_4974$$.params[3];$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$+$segment$jscomp$inline_4974$$.params[4];$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$+$segment$jscomp$inline_4974$$.params[5];$segment$jscomp$inline_4974$$.command="C";$segment$jscomp$inline_4974$$.params[0]=$subpathY$jscomp$inline_4984_x1$jscomp$inline_4969$$;$segment$jscomp$inline_4974$$.params[1]=
$i$jscomp$inline_5001_y1$jscomp$inline_4970$$;$segment$jscomp$inline_4974$$.params[2]=$x2$jscomp$inline_4971$$;$segment$jscomp$inline_4974$$.params[3]=$y2$jscomp$inline_4972$$;$segment$jscomp$inline_4974$$.params[4]=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$segment$jscomp$inline_4974$$.params[5]=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=
$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;break;case "Q":$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$segment$jscomp$inline_4974$$.params[2];$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$segment$jscomp$inline_4974$$.params[3];$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;break;case "q":$subpathY$jscomp$inline_4984_x1$jscomp$inline_4969$$=
$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$+$segment$jscomp$inline_4974$$.params[0];$i$jscomp$inline_5001_y1$jscomp$inline_4970$$=$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$+$segment$jscomp$inline_4974$$.params[1];$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$+$segment$jscomp$inline_4974$$.params[2];$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$+
$segment$jscomp$inline_4974$$.params[3];$segment$jscomp$inline_4974$$.command="Q";$segment$jscomp$inline_4974$$.params[0]=$subpathY$jscomp$inline_4984_x1$jscomp$inline_4969$$;$segment$jscomp$inline_4974$$.params[1]=$i$jscomp$inline_5001_y1$jscomp$inline_4970$$;$segment$jscomp$inline_4974$$.params[2]=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$segment$jscomp$inline_4974$$.params[3]=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=
$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;break;case "A":$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$segment$jscomp$inline_4974$$.params[5];$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$segment$jscomp$inline_4974$$.params[6];$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=
$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;break;case "a":$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$+$segment$jscomp$inline_4974$$.params[5];$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$+$segment$jscomp$inline_4974$$.params[6];$segment$jscomp$inline_4974$$.command="A";$segment$jscomp$inline_4974$$.params[5]=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;
$segment$jscomp$inline_4974$$.params[6]=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;break;case "H":$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$segment$jscomp$inline_4974$$.params[0];break;case "h":$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=
$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$+$segment$jscomp$inline_4974$$.params[0];$segment$jscomp$inline_4974$$.command="H";$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$segment$jscomp$inline_4974$$.params[0]=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;break;case "V":$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$segment$jscomp$inline_4974$$.params[0];break;case "v":$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=
$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$+$segment$jscomp$inline_4974$$.params[0];$segment$jscomp$inline_4974$$.command="V";$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$segment$jscomp$inline_4974$$.params[0]=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;break;case "S":$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$segment$jscomp$inline_4974$$.params[2];$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$segment$jscomp$inline_4974$$.params[3];$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=
$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;break;case "s":$x2$jscomp$inline_4971$$=$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$+$segment$jscomp$inline_4974$$.params[0];$y2$jscomp$inline_4972$$=$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$+$segment$jscomp$inline_4974$$.params[1];$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$+
$segment$jscomp$inline_4974$$.params[2];$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$+$segment$jscomp$inline_4974$$.params[3];$segment$jscomp$inline_4974$$.command="S";$segment$jscomp$inline_4974$$.params[0]=$x2$jscomp$inline_4971$$;$segment$jscomp$inline_4974$$.params[1]=$y2$jscomp$inline_4972$$;$segment$jscomp$inline_4974$$.params[2]=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$segment$jscomp$inline_4974$$.params[3]=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;
$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;break;case "T":$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$segment$jscomp$inline_4974$$.params[0];$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$segment$jscomp$inline_4974$$.params[1];$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;
$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;break;case "t":$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$+$segment$jscomp$inline_4974$$.params[0];$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$+$segment$jscomp$inline_4974$$.params[1];$segment$jscomp$inline_4974$$.command="T";$segment$jscomp$inline_4974$$.params[0]=
$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$segment$jscomp$inline_4974$$.params[1]=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$;break;case "Z":case "z":$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=$lastControlY$jscomp$inline_4980_subpathX$jscomp$inline_4965$$,
$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$,$segment$jscomp$inline_4974$$.command="Z"}}$pdata$jscomp$inline_4976_result$jscomp$179$$=$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$;$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$=[];$subpathY$jscomp$inline_4984_x1$jscomp$inline_4969$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$=
$lastControlY$jscomp$inline_4980_subpathX$jscomp$inline_4965$$=$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=null;for($i$jscomp$inline_5001_y1$jscomp$inline_4970$$=0;$i$jscomp$inline_5001_y1$jscomp$inline_4970$$<$pdata$jscomp$inline_4976_result$jscomp$179$$.length;$i$jscomp$inline_5001_y1$jscomp$inline_4970$$++){const $segment$jscomp$inline_5002$$=$pdata$jscomp$inline_4976_result$jscomp$179$$[$i$jscomp$inline_5001_y1$jscomp$inline_4970$$],
$currentCommand$jscomp$inline_5003$$=$segment$jscomp$inline_5002$$.command;switch($currentCommand$jscomp$inline_5003$$){case "M":var $x$jscomp$inline_4985$$=$segment$jscomp$inline_5002$$.params[0],$y$jscomp$inline_4986$$=$segment$jscomp$inline_5002$$.params[1];$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$.push($segment$jscomp$inline_5002$$);$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$=$x$jscomp$inline_4985$$;$subpathY$jscomp$inline_4984_x1$jscomp$inline_4969$$=$y$jscomp$inline_4986$$;
$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$=$x$jscomp$inline_4985$$;$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$y$jscomp$inline_4986$$;break;case "C":var $x2$jscomp$inline_4987$$=$segment$jscomp$inline_5002$$.params[2],$y2$jscomp$inline_4988$$=$segment$jscomp$inline_5002$$.params[3];$x$jscomp$inline_4985$$=$segment$jscomp$inline_5002$$.params[4];$y$jscomp$inline_4986$$=$segment$jscomp$inline_5002$$.params[5];$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$.push($segment$jscomp$inline_5002$$);
$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$x2$jscomp$inline_4987$$;$lastControlY$jscomp$inline_4980_subpathX$jscomp$inline_4965$$=$y2$jscomp$inline_4988$$;$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$=$x$jscomp$inline_4985$$;$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$y$jscomp$inline_4986$$;break;case "L":$x$jscomp$inline_4985$$=$segment$jscomp$inline_5002$$.params[0];$y$jscomp$inline_4986$$=$segment$jscomp$inline_5002$$.params[1];$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$.push($segment$jscomp$inline_5002$$);
$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$=$x$jscomp$inline_4985$$;$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$y$jscomp$inline_4986$$;break;case "H":$x$jscomp$inline_4985$$=$segment$jscomp$inline_5002$$.params[0];$segment$jscomp$inline_5002$$.command="L";$segment$jscomp$inline_5002$$.params=[$x$jscomp$inline_4985$$,$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$];$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$.push($segment$jscomp$inline_5002$$);$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$=
$x$jscomp$inline_4985$$;break;case "V":$y$jscomp$inline_4986$$=$segment$jscomp$inline_5002$$.params[0];$segment$jscomp$inline_5002$$.command="L";$segment$jscomp$inline_5002$$.params=[$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$,$y$jscomp$inline_4986$$];$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$.push($segment$jscomp$inline_5002$$);$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$y$jscomp$inline_4986$$;break;case "S":$x2$jscomp$inline_4987$$=$segment$jscomp$inline_5002$$.params[0];
$y2$jscomp$inline_4988$$=$segment$jscomp$inline_5002$$.params[1];$x$jscomp$inline_4985$$=$segment$jscomp$inline_5002$$.params[2];$y$jscomp$inline_4986$$=$segment$jscomp$inline_5002$$.params[3];if($currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$==="C"||$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$==="S"){var $cx1$jscomp$inline_4989$$=$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$+($currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$-$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$);
var $cy1$jscomp$inline_4990$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$+($currentY$jscomp$inline_4982_x$jscomp$inline_4967$$-$lastControlY$jscomp$inline_4980_subpathX$jscomp$inline_4965$$)}else $cx1$jscomp$inline_4989$$=$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$,$cy1$jscomp$inline_4990$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$segment$jscomp$inline_5002$$.command="C";$segment$jscomp$inline_5002$$.params=[$cx1$jscomp$inline_4989$$,$cy1$jscomp$inline_4990$$,$x2$jscomp$inline_4987$$,
$y2$jscomp$inline_4988$$,$x$jscomp$inline_4985$$,$y$jscomp$inline_4986$$];$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$.push($segment$jscomp$inline_5002$$);$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$x2$jscomp$inline_4987$$;$lastControlY$jscomp$inline_4980_subpathX$jscomp$inline_4965$$=$y2$jscomp$inline_4988$$;$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$=$x$jscomp$inline_4985$$;$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$y$jscomp$inline_4986$$;break;
case "T":$x$jscomp$inline_4985$$=$segment$jscomp$inline_5002$$.params[0];$y$jscomp$inline_4986$$=$segment$jscomp$inline_5002$$.params[1];if($currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$==="Q"||$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$==="T"){var $x1$jscomp$inline_4991$$=$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$+($currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$-$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$);var $y1$jscomp$inline_4992$$=
$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$+($currentY$jscomp$inline_4982_x$jscomp$inline_4967$$-$lastControlY$jscomp$inline_4980_subpathX$jscomp$inline_4965$$)}else $x1$jscomp$inline_4991$$=$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$,$y1$jscomp$inline_4992$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$;$cx1$jscomp$inline_4989$$=$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$+2*($x1$jscomp$inline_4991$$-$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$)/
3;$cy1$jscomp$inline_4990$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$+2*($y1$jscomp$inline_4992$$-$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$)/3;var $cx2$jscomp$inline_4993$$=$x$jscomp$inline_4985$$+2*($x1$jscomp$inline_4991$$-$x$jscomp$inline_4985$$)/3,$cy2$jscomp$inline_4994$$=$y$jscomp$inline_4986$$+2*($y1$jscomp$inline_4992$$-$y$jscomp$inline_4986$$)/3;$segment$jscomp$inline_5002$$.command="C";$segment$jscomp$inline_5002$$.params=[$cx1$jscomp$inline_4989$$,$cy1$jscomp$inline_4990$$,
$cx2$jscomp$inline_4993$$,$cy2$jscomp$inline_4994$$,$x$jscomp$inline_4985$$,$y$jscomp$inline_4986$$];$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$.push($segment$jscomp$inline_5002$$);$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$x1$jscomp$inline_4991$$;$lastControlY$jscomp$inline_4980_subpathX$jscomp$inline_4965$$=$y1$jscomp$inline_4992$$;$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$=$x$jscomp$inline_4985$$;$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=
$y$jscomp$inline_4986$$;break;case "Q":$x1$jscomp$inline_4991$$=$segment$jscomp$inline_5002$$.params[0];$y1$jscomp$inline_4992$$=$segment$jscomp$inline_5002$$.params[1];$x$jscomp$inline_4985$$=$segment$jscomp$inline_5002$$.params[2];$y$jscomp$inline_4986$$=$segment$jscomp$inline_5002$$.params[3];$cx1$jscomp$inline_4989$$=$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$+2*($x1$jscomp$inline_4991$$-$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$)/3;$cy1$jscomp$inline_4990$$=$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$+
2*($y1$jscomp$inline_4992$$-$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$)/3;$cx2$jscomp$inline_4993$$=$x$jscomp$inline_4985$$+2*($x1$jscomp$inline_4991$$-$x$jscomp$inline_4985$$)/3;$cy2$jscomp$inline_4994$$=$y$jscomp$inline_4986$$+2*($y1$jscomp$inline_4992$$-$y$jscomp$inline_4986$$)/3;$segment$jscomp$inline_5002$$.command="C";$segment$jscomp$inline_5002$$.params=[$cx1$jscomp$inline_4989$$,$cy1$jscomp$inline_4990$$,$cx2$jscomp$inline_4993$$,$cy2$jscomp$inline_4994$$,$x$jscomp$inline_4985$$,
$y$jscomp$inline_4986$$];$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$.push($segment$jscomp$inline_5002$$);$currentY$jscomp$inline_4964_lastControlX$jscomp$inline_4979$$=$x1$jscomp$inline_4991$$;$lastControlY$jscomp$inline_4980_subpathX$jscomp$inline_4965$$=$y1$jscomp$inline_4992$$;$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$=$x$jscomp$inline_4985$$;$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$y$jscomp$inline_4986$$;break;case "A":var $rx$jscomp$inline_4995$$=Math.abs($segment$jscomp$inline_5002$$.params[0]),
$ry$jscomp$inline_4996$$=Math.abs($segment$jscomp$inline_5002$$.params[1]),$phi$jscomp$inline_4997$$=$segment$jscomp$inline_5002$$.params[2],$fa$jscomp$inline_4998$$=$segment$jscomp$inline_5002$$.params[3],$fs$jscomp$inline_4999$$=$segment$jscomp$inline_5002$$.params[4];$x$jscomp$inline_4985$$=$segment$jscomp$inline_5002$$.params[5];$y$jscomp$inline_4986$$=$segment$jscomp$inline_5002$$.params[6];if($rx$jscomp$inline_4995$$===0||$ry$jscomp$inline_4996$$===0)$segment$jscomp$inline_5002$$.command="C",
$segment$jscomp$inline_5002$$.params=[$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$,$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$,$x$jscomp$inline_4985$$,$y$jscomp$inline_4986$$,$x$jscomp$inline_4985$$,$y$jscomp$inline_4986$$],$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$.add($segment$jscomp$inline_5002$$),$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$=$x$jscomp$inline_4985$$,$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$y$jscomp$inline_4986$$;else if($currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$!==
$x$jscomp$inline_4985$$||$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$!==$y$jscomp$inline_4986$$){var $segments$jscomp$inline_5000$$=$arcToBeziers$$module$app$common$svg$path$parser$$($currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$,$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$,$x$jscomp$inline_4985$$,$y$jscomp$inline_4986$$,$fa$jscomp$inline_4998$$,$fs$jscomp$inline_4999$$,$rx$jscomp$inline_4995$$,$ry$jscomp$inline_4996$$,$phi$jscomp$inline_4997$$);$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$.push(...$segments$jscomp$inline_5000$$);
$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$=$x$jscomp$inline_4985$$;$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$y$jscomp$inline_4986$$}break;case "Z":$pdata$jscomp$inline_4962_result$jscomp$inline_4977$$.push($segment$jscomp$inline_5002$$),$currentX$jscomp$inline_4981_subpathY$jscomp$inline_4966$$=$subpathX$jscomp$inline_4983_y$jscomp$inline_4968$$,$currentY$jscomp$inline_4982_x$jscomp$inline_4967$$=$subpathY$jscomp$inline_4984_x1$jscomp$inline_4969$$}$currentX$jscomp$inline_4963_lastCommand$jscomp$inline_4978$$=
$currentCommand$jscomp$inline_5003$$}return $pdata$jscomp$inline_4962_result$jscomp$inline_4977$$}catch($cause$jscomp$31$$){return console.group("unexpected exception parsing path"),console.log(`string: ${$string$jscomp$19$$}`),console.error($cause$jscomp$31$$),console.groupEnd("unexpected exception parsing path"),[]}};var $app$common$types$path$impl$schema_COLON_content$$,$app$common$types$path$impl$check_segment$$,$app$common$types$path$impl$check_content$$,$app$common$types$path$impl$from_bytes$$;$APP.$JSCompiler_prototypeAlias$$=$app$common$types$path$impl$PathData$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$app$common$types$path$impl$IPathData$_get_byte_size$arity$1$=function(){return this.buffer.byteLength};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$path$impl$IPathData$_write_to$arity$3$=function($_$jscomp$1159_size__$1$jscomp$5$$,$into_buffer$$,$offset$jscomp$118$$){$_$jscomp$1159_size__$1$jscomp$5$$=this.buffer.byteLength;var $src_off$jscomp$1$$=this.buffer.byteOffset;return(new Uint8Array($into_buffer$$,$offset$jscomp$118$$,$_$jscomp$1159_size__$1$jscomp$5$$)).set(new Uint8Array(this.buffer.buffer,$src_off$jscomp$1$$,$_$jscomp$1159_size__$1$jscomp$5$$))};
$APP.$JSCompiler_prototypeAlias$$.toString=function(){for(var $buffer$jscomp$inline_5038$$=this.buffer,$size$jscomp$inline_5039$$=this.size,$builder$jscomp$inline_5040$$=new $APP.$goog$string$StringBuffer$$,$index_47994$jscomp$inline_5041$$=0;;)if($index_47994$jscomp$inline_5041$$<$size$jscomp$inline_5039$$){var $builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$=$index_47994$jscomp$inline_5041$$*28,$type_47997$jscomp$inline_5043_x$jscomp$inline_11910$$=$buffer$jscomp$inline_5038$$.getInt16($builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$,
!0),$buffer$jscomp$inline_11906_y$jscomp$inline_11911$$=$buffer$jscomp$inline_5038$$,$offset$jscomp$inline_11907$$=$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$;$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$=$builder$jscomp$inline_5040$$;switch($APP.$cljs$core$fix$$($type_47997$jscomp$inline_5043_x$jscomp$inline_11910$$)){case 1:$type_47997$jscomp$inline_5043_x$jscomp$inline_11910$$=$buffer$jscomp$inline_11906_y$jscomp$inline_11911$$.getFloat32($offset$jscomp$inline_11907$$+
20,!0);$buffer$jscomp$inline_11906_y$jscomp$inline_11911$$=$buffer$jscomp$inline_11906_y$jscomp$inline_11911$$.getFloat32($offset$jscomp$inline_11907$$+24,!0);$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append("M");$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append($type_47997$jscomp$inline_5043_x$jscomp$inline_11910$$);$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append(",");$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append($buffer$jscomp$inline_11906_y$jscomp$inline_11911$$);
break;case 2:$type_47997$jscomp$inline_5043_x$jscomp$inline_11910$$=$buffer$jscomp$inline_11906_y$jscomp$inline_11911$$.getFloat32($offset$jscomp$inline_11907$$+20,!0);$buffer$jscomp$inline_11906_y$jscomp$inline_11911$$=$buffer$jscomp$inline_11906_y$jscomp$inline_11911$$.getFloat32($offset$jscomp$inline_11907$$+24,!0);$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append("L");$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append($type_47997$jscomp$inline_5043_x$jscomp$inline_11910$$);
$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append(",");$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append($buffer$jscomp$inline_11906_y$jscomp$inline_11911$$);break;case 3:var $c1x$jscomp$inline_11912$$=$buffer$jscomp$inline_11906_y$jscomp$inline_11911$$.getFloat32($offset$jscomp$inline_11907$$+4,!0),$c1y$jscomp$inline_11913$$=$buffer$jscomp$inline_11906_y$jscomp$inline_11911$$.getFloat32($offset$jscomp$inline_11907$$+8,!0),$c2x$jscomp$inline_11914$$=$buffer$jscomp$inline_11906_y$jscomp$inline_11911$$.getFloat32($offset$jscomp$inline_11907$$+
12,!0),$c2y$jscomp$inline_11915$$=$buffer$jscomp$inline_11906_y$jscomp$inline_11911$$.getFloat32($offset$jscomp$inline_11907$$+16,!0);$type_47997$jscomp$inline_5043_x$jscomp$inline_11910$$=$buffer$jscomp$inline_11906_y$jscomp$inline_11911$$.getFloat32($offset$jscomp$inline_11907$$+20,!0);$buffer$jscomp$inline_11906_y$jscomp$inline_11911$$=$buffer$jscomp$inline_11906_y$jscomp$inline_11911$$.getFloat32($offset$jscomp$inline_11907$$+24,!0);$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append("C");
$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append($c1x$jscomp$inline_11912$$);$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append(",");$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append($c1y$jscomp$inline_11913$$);$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append(",");$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append($c2x$jscomp$inline_11914$$);$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append(",");
$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append($c2y$jscomp$inline_11915$$);$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append(",");$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append($type_47997$jscomp$inline_5043_x$jscomp$inline_11910$$);$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append(",");$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append($buffer$jscomp$inline_11906_y$jscomp$inline_11911$$);break;
case 4:$builder$jscomp$inline_11909_offset_47996$jscomp$inline_5042$$.append("Z")}$index_47994$jscomp$inline_5041$$+=1}else break;return $builder$jscomp$inline_5040$$.toString()};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($_$jscomp$1161$$,$i$jscomp$487$$){return $i$jscomp$487$$<this.size&&$i$jscomp$487$$>=0?$app$common$types$path$impl$read_segment$$(this.buffer,$i$jscomp$487$$):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($_$jscomp$1162$$,$i$jscomp$488$$,$default$$jscomp$52$$){return $i$jscomp$488$$<this.size&&$i$jscomp$488$$>=0?$app$common$types$path$impl$read_segment$$(this.buffer,$i$jscomp$488$$):$default$$jscomp$52$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$633$$,$other$jscomp$178$$){return $other$jscomp$178$$ instanceof $app$common$types$path$impl$PathData$$?$app$common$buffer$equals_QMARK_$$(this.buffer,$other$jscomp$178$$.buffer):!1};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$48_h__5134__auto____$1$jscomp$48$$=this.$__hash$;return $h__5134__auto__$jscomp$48_h__5134__auto____$1$jscomp$48$$!=null?$h__5134__auto__$jscomp$48_h__5134__auto____$1$jscomp$48$$:this.$__hash$=$h__5134__auto__$jscomp$48_h__5134__auto____$1$jscomp$48$$=$cljs$core$hash_ordered_coll$$(this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.size};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){var $self__$jscomp$2751$$=this;return $self__$jscomp$2751$$.size>0?function $app$common$types$path$impl$next_seq$$($i$jscomp$489$$){if($i$jscomp$489$$<$self__$jscomp$2751$$.size){var $segment$jscomp$15$$=$app$common$types$path$impl$read_segment$$($self__$jscomp$2751$$.buffer,$i$jscomp$489$$);return $segment$jscomp$15$$!=null?$APP.$cljs$core$cons$$($segment$jscomp$15$$,new $APP.$cljs$core$LazySeq$$(null,function(){return $app$common$types$path$impl$next_seq$$($i$jscomp$489$$+
1)},null,null)):$app$common$types$path$impl$next_seq$$($i$jscomp$489$$+1)}return null}(0):null};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$path$impl$ITransformable$_transform$arity$2$=function($buffer__$1$jscomp$1_dst_buff$jscomp$inline_5048_src_len$jscomp$inline_5046_this$$jscomp$635$$,$f$jscomp$inline_5058_m$jscomp$203$$){var $buffer$jscomp$inline_5045_size$jscomp$inline_5052_src_view$jscomp$inline_5047$$=this.buffer;$buffer__$1$jscomp$1_dst_buff$jscomp$inline_5048_src_len$jscomp$inline_5046_this$$jscomp$635$$=$buffer$jscomp$inline_5045_size$jscomp$inline_5052_src_view$jscomp$inline_5047$$.byteLength;
$buffer$jscomp$inline_5045_size$jscomp$inline_5052_src_view$jscomp$inline_5047$$=new Uint8Array($buffer$jscomp$inline_5045_size$jscomp$inline_5052_src_view$jscomp$inline_5047$$.buffer,$buffer$jscomp$inline_5045_size$jscomp$inline_5052_src_view$jscomp$inline_5047$$.byteOffset,$buffer__$1$jscomp$1_dst_buff$jscomp$inline_5048_src_len$jscomp$inline_5046_this$$jscomp$635$$);$buffer__$1$jscomp$1_dst_buff$jscomp$inline_5048_src_len$jscomp$inline_5046_this$$jscomp$635$$=new ArrayBuffer($buffer__$1$jscomp$1_dst_buff$jscomp$inline_5048_src_len$jscomp$inline_5046_this$$jscomp$635$$);
(new Uint8Array($buffer__$1$jscomp$1_dst_buff$jscomp$inline_5048_src_len$jscomp$inline_5046_this$$jscomp$635$$)).set($buffer$jscomp$inline_5045_size$jscomp$inline_5052_src_view$jscomp$inline_5047$$);$buffer__$1$jscomp$1_dst_buff$jscomp$inline_5048_src_len$jscomp$inline_5046_this$$jscomp$635$$=new DataView($buffer__$1$jscomp$1_dst_buff$jscomp$inline_5048_src_len$jscomp$inline_5046_this$$jscomp$635$$);a:{$buffer$jscomp$inline_5045_size$jscomp$inline_5052_src_view$jscomp$inline_5047$$=this.size;var $a$jscomp$inline_5053$$=
$f$jscomp$inline_5058_m$jscomp$203$$?.a??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$inline_5058_m$jscomp$203$$,$APP.$cljs$cst$1519$a$$),$b$jscomp$inline_5054$$=$f$jscomp$inline_5058_m$jscomp$203$$?.b??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$inline_5058_m$jscomp$203$$,$APP.$cljs$cst$1520$b$$),$c$jscomp$inline_5055$$=$f$jscomp$inline_5058_m$jscomp$203$$?.c??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$inline_5058_m$jscomp$203$$,$cljs$cst$1521$c$$),
$d$jscomp$inline_5056$$=$f$jscomp$inline_5058_m$jscomp$203$$?.d??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$inline_5058_m$jscomp$203$$,$cljs$cst$1447$d$$),$e$jscomp$inline_5057$$=$f$jscomp$inline_5058_m$jscomp$203$$?.e??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$inline_5058_m$jscomp$203$$,$cljs$cst$1449$e$$);$f$jscomp$inline_5058_m$jscomp$203$$=$f$jscomp$inline_5058_m$jscomp$203$$?.f??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$inline_5058_m$jscomp$203$$,
$cljs$cst$598$f$$);for(var $index$jscomp$inline_5059$$=0;;)if($index$jscomp$inline_5059$$<$buffer$jscomp$inline_5045_size$jscomp$inline_5052_src_view$jscomp$inline_5047$$){var $buffer$jscomp$inline_11917$$=$buffer__$1$jscomp$1_dst_buff$jscomp$inline_5048_src_len$jscomp$inline_5046_this$$jscomp$635$$,$offset$jscomp$inline_11918$$=$index$jscomp$inline_5059$$*28,$a$jscomp$inline_11919$$=$a$jscomp$inline_5053$$,$b$jscomp$inline_11920_y_SINGLEQUOTE_$jscomp$inline_11928$$=$b$jscomp$inline_5054$$,$c$jscomp$inline_11921$$=
$c$jscomp$inline_5055$$,$d$jscomp$inline_11922$$=$d$jscomp$inline_5056$$,$e$jscomp$inline_11923$$=$e$jscomp$inline_5057$$,$f$jscomp$inline_11924$$=$f$jscomp$inline_5058_m$jscomp$203$$;switch($buffer$jscomp$inline_11917$$.getInt16($offset$jscomp$inline_11918$$,!0)){case 1:case 2:var $x$jscomp$inline_11925$$=$buffer$jscomp$inline_11917$$.getFloat32($offset$jscomp$inline_11918$$+20,!0),$y$jscomp$inline_11926$$=$buffer$jscomp$inline_11917$$.getFloat32($offset$jscomp$inline_11918$$+24,!0);$b$jscomp$inline_11920_y_SINGLEQUOTE_$jscomp$inline_11928$$=
$x$jscomp$inline_11925$$*$b$jscomp$inline_11920_y_SINGLEQUOTE_$jscomp$inline_11928$$+$y$jscomp$inline_11926$$*$d$jscomp$inline_11922$$+$f$jscomp$inline_11924$$;$buffer$jscomp$inline_11917$$.setFloat32($offset$jscomp$inline_11918$$+20,$x$jscomp$inline_11925$$*$a$jscomp$inline_11919$$+$y$jscomp$inline_11926$$*$c$jscomp$inline_11921$$+$e$jscomp$inline_11923$$,!0);$buffer$jscomp$inline_11917$$.setFloat32($offset$jscomp$inline_11918$$+24,$b$jscomp$inline_11920_y_SINGLEQUOTE_$jscomp$inline_11928$$,!0);
break;case 3:var $c1x$jscomp$inline_11929$$=$buffer$jscomp$inline_11917$$.getFloat32($offset$jscomp$inline_11918$$+4,!0),$c1y$jscomp$inline_11930$$=$buffer$jscomp$inline_11917$$.getFloat32($offset$jscomp$inline_11918$$+8,!0);var $c2x$jscomp$inline_11931_x_SINGLEQUOTE_$jscomp$inline_11927$$=$buffer$jscomp$inline_11917$$.getFloat32($offset$jscomp$inline_11918$$+12,!0);var $c2y$jscomp$inline_11932_c2y_SINGLEQUOTE_$jscomp$inline_11935$$=$buffer$jscomp$inline_11917$$.getFloat32($offset$jscomp$inline_11918$$+
16,!0);$x$jscomp$inline_11925$$=$buffer$jscomp$inline_11917$$.getFloat32($offset$jscomp$inline_11918$$+20,!0);$y$jscomp$inline_11926$$=$buffer$jscomp$inline_11917$$.getFloat32($offset$jscomp$inline_11918$$+24,!0);var $c1y_SINGLEQUOTE_$jscomp$inline_11933$$=$c1x$jscomp$inline_11929$$*$b$jscomp$inline_11920_y_SINGLEQUOTE_$jscomp$inline_11928$$+$c1y$jscomp$inline_11930$$*$d$jscomp$inline_11922$$+$f$jscomp$inline_11924$$,$c2x_SINGLEQUOTE_$jscomp$inline_11934$$=$c2x$jscomp$inline_11931_x_SINGLEQUOTE_$jscomp$inline_11927$$*
$a$jscomp$inline_11919$$+$c2y$jscomp$inline_11932_c2y_SINGLEQUOTE_$jscomp$inline_11935$$*$c$jscomp$inline_11921$$+$e$jscomp$inline_11923$$;$c2y$jscomp$inline_11932_c2y_SINGLEQUOTE_$jscomp$inline_11935$$=$c2x$jscomp$inline_11931_x_SINGLEQUOTE_$jscomp$inline_11927$$*$b$jscomp$inline_11920_y_SINGLEQUOTE_$jscomp$inline_11928$$+$c2y$jscomp$inline_11932_c2y_SINGLEQUOTE_$jscomp$inline_11935$$*$d$jscomp$inline_11922$$+$f$jscomp$inline_11924$$;$c2x$jscomp$inline_11931_x_SINGLEQUOTE_$jscomp$inline_11927$$=
$x$jscomp$inline_11925$$*$a$jscomp$inline_11919$$+$y$jscomp$inline_11926$$*$c$jscomp$inline_11921$$+$e$jscomp$inline_11923$$;$b$jscomp$inline_11920_y_SINGLEQUOTE_$jscomp$inline_11928$$=$x$jscomp$inline_11925$$*$b$jscomp$inline_11920_y_SINGLEQUOTE_$jscomp$inline_11928$$+$y$jscomp$inline_11926$$*$d$jscomp$inline_11922$$+$f$jscomp$inline_11924$$;$buffer$jscomp$inline_11917$$.setFloat32($offset$jscomp$inline_11918$$+4,$c1x$jscomp$inline_11929$$*$a$jscomp$inline_11919$$+$c1y$jscomp$inline_11930$$*$c$jscomp$inline_11921$$+
$e$jscomp$inline_11923$$,!0);$buffer$jscomp$inline_11917$$.setFloat32($offset$jscomp$inline_11918$$+8,$c1y_SINGLEQUOTE_$jscomp$inline_11933$$,!0);$buffer$jscomp$inline_11917$$.setFloat32($offset$jscomp$inline_11918$$+12,$c2x_SINGLEQUOTE_$jscomp$inline_11934$$,!0);$buffer$jscomp$inline_11917$$.setFloat32($offset$jscomp$inline_11918$$+16,$c2y$jscomp$inline_11932_c2y_SINGLEQUOTE_$jscomp$inline_11935$$,!0);$buffer$jscomp$inline_11917$$.setFloat32($offset$jscomp$inline_11918$$+20,$c2x$jscomp$inline_11931_x_SINGLEQUOTE_$jscomp$inline_11927$$,
!0);$buffer$jscomp$inline_11917$$.setFloat32($offset$jscomp$inline_11918$$+24,$b$jscomp$inline_11920_y_SINGLEQUOTE_$jscomp$inline_11928$$,!0)}$index$jscomp$inline_5059$$+=1}else break a}return new $app$common$types$path$impl$PathData$$(this.size,$buffer__$1$jscomp$1_dst_buff$jscomp$inline_5048_src_len$jscomp$inline_5046_this$$jscomp$635$$,new $module$app$common$weak$impl_weak_value_map$$.$WeakValueMap$,null)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$path$impl$ITransformable$_walk$arity$3$=function($_$jscomp$1164$$,$f$jscomp$767$$,$initial$jscomp$12$$){return $app$common$types$path$impl$impl_walk$$(this.buffer,$f$jscomp$767$$,$initial$jscomp$12$$,this.size)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$path$impl$ITransformable$_reduce$arity$3$=function($_$jscomp$1165$$,$f$jscomp$768$$,$initial$jscomp$13$$){return $app$common$types$path$impl$impl_reduce$$(this.buffer,$f$jscomp$768$$,$initial$jscomp$13$$,this.size)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$path$impl$ITransformable$_lookup$arity$3$=function($_$jscomp$1166$$,$index$jscomp$182$$,$f$jscomp$769$$){return 0<=$index$jscomp$182$$&&$index$jscomp$182$$<this.size?$app$common$types$path$impl$impl_lookup$$(this.buffer,$index$jscomp$182$$,$f$jscomp$769$$):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$636$$,$writer$jscomp$164$$){return $APP.$cljs$core$_write$$($writer$jscomp$164$$,['#penpot/path-data "',$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.toString()),'"'].join(""))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$2$=function($_$jscomp$1168_index$jscomp$183$$,$f$jscomp$770$$){$_$jscomp$1168_index$jscomp$183$$=1;for(var $G__48024_result$jscomp$182_result__$1$jscomp$16$$=this.size>0?$app$common$types$path$impl$read_segment$$(this.buffer,0):null;;)if($_$jscomp$1168_index$jscomp$183$$<this.size){var $segment$jscomp$16$$=$app$common$types$path$impl$read_segment$$(this.buffer,$_$jscomp$1168_index$jscomp$183$$);$G__48024_result$jscomp$182_result__$1$jscomp$16$$=
$segment$jscomp$16$$!=null?$f$jscomp$770$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$770$$.$cljs$core$IFn$_invoke$arity$2$($G__48024_result$jscomp$182_result__$1$jscomp$16$$,$segment$jscomp$16$$):$f$jscomp$770$$($G__48024_result$jscomp$182_result__$1$jscomp$16$$,$segment$jscomp$16$$):$G__48024_result$jscomp$182_result__$1$jscomp$16$$;if($cljs$core$reduced_QMARK_$$($G__48024_result$jscomp$182_result__$1$jscomp$16$$))return $APP.$cljs$core$_deref$$($G__48024_result$jscomp$182_result__$1$jscomp$16$$);
$_$jscomp$1168_index$jscomp$183$$+=1}else return $G__48024_result$jscomp$182_result__$1$jscomp$16$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReduce$_reduce$arity$3$=function($_$jscomp$1169_index$jscomp$184$$,$f$jscomp$771$$,$G__48027_result$jscomp$183_result__$1$jscomp$17_start$jscomp$204$$){for($_$jscomp$1169_index$jscomp$184$$=0;;)if($_$jscomp$1169_index$jscomp$184$$<this.size){var $segment$jscomp$17$$=$app$common$types$path$impl$read_segment$$(this.buffer,$_$jscomp$1169_index$jscomp$184$$);$G__48027_result$jscomp$183_result__$1$jscomp$17_start$jscomp$204$$=$segment$jscomp$17$$!=null?$f$jscomp$771$$.$cljs$core$IFn$_invoke$arity$2$?
$f$jscomp$771$$.$cljs$core$IFn$_invoke$arity$2$($G__48027_result$jscomp$183_result__$1$jscomp$17_start$jscomp$204$$,$segment$jscomp$17$$):$f$jscomp$771$$($G__48027_result$jscomp$183_result__$1$jscomp$17_start$jscomp$204$$,$segment$jscomp$17$$):$G__48027_result$jscomp$183_result__$1$jscomp$17_start$jscomp$204$$;if($cljs$core$reduced_QMARK_$$($G__48027_result$jscomp$183_result__$1$jscomp$17_start$jscomp$204$$))return $APP.$cljs$core$_deref$$($G__48027_result$jscomp$183_result__$1$jscomp$17_start$jscomp$204$$);
$_$jscomp$1169_index$jscomp$184$$+=1}else return $G__48027_result$jscomp$183_result__$1$jscomp$17_start$jscomp$204$$};
var $app$common$types$path$impl$schema_COLON_safe_number$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$298$schema$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$small_int$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$339$max$$,100,$APP.$cljs$cst$338$min$$,-100]))],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],
null),$app$common$types$path$impl$schema_COLON_segment$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$531$multi$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,"PathSegment",$cljs$cst$532$dispatch$$,$APP.$cljs$cst$1812$command$$,$APP.$cljs$cst$938$decode_SLASH_json$$,function($p1__47905_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__47905_SHARP_$$,$APP.$cljs$cst$1812$command$$,
$APP.$cljs$core$keyword$$)}],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1814$line_to$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,
$APP.$cljs$cst$1814$line_to$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$app$common$types$path$impl$schema_COLON_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1511$y$$,$app$common$types$path$impl$schema_COLON_safe_number$$],null)],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1850$close_path$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$1850$close_path$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1813$move_to$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$1813$move_to$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$app$common$types$path$impl$schema_COLON_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1511$y$$,$app$common$types$path$impl$schema_COLON_safe_number$$],null)],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1819$curve_to$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$1819$curve_to$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentVector$$(null,
7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$app$common$types$path$impl$schema_COLON_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1511$y$$,$app$common$types$path$impl$schema_COLON_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1815$c1x$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$path$impl$schema_COLON_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1816$c1y$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$path$impl$schema_COLON_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1817$c2x$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$path$impl$schema_COLON_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1818$c2y$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$path$impl$schema_COLON_safe_number$$],null)],null)],null)],null)],null)],null),$JSCompiler_temp_const$jscomp$772$$=
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$JSCompiler_inline_result$jscomp$773$$,$opts$jscomp$inline_5061$$=$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$path$impl$schema_COLON_segment$$)]);$JSCompiler_inline_result$jscomp$773$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$generators$vector$$,$opts$jscomp$inline_5061$$);
$APP.$app$common$types$path$impl$schema_COLON_segments$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$JSCompiler_temp_const$jscomp$772$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$filter$$(function($e1$jscomp$8_p__47908$$){$e1$jscomp$8_p__47908$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($e1$jscomp$8_p__47908$$,0,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1812$command$$.$cljs$core$IFn$_invoke$arity$1$($e1$jscomp$8_p__47908$$),
$APP.$cljs$cst$1813$move_to$$)},$app$common$schema$generators$filter$$($APP.$cljs$core$not_empty$$,$JSCompiler_inline_result$jscomp$773$$))],null),$app$common$types$path$impl$schema_COLON_segment$$],null);
$app$common$types$path$impl$schema_COLON_content$$=$app$common$schema$type_schema$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$1851$app_DOT_common_DOT_types_DOT_path_SLASH_content$$,$APP.$cljs$cst$411$compile$$,function(){var $decoder$jscomp$2$$=new $APP.$cljs$core$Delay$$(function(){return $malli$core$decoder$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$path$impl$schema_COLON_segments$$)}),
$generator$jscomp$15$$=$app$common$schema$generators$fmap$$($APP.$app$common$types$path$impl$from_plain$$,$app$common$schema$generators$filter$$($APP.$cljs$core$not_empty$$,$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$types$path$impl$schema_COLON_segments$$)));return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$351$pred$$,$app$common$types$path$impl$path_data_QMARK_$$,$cljs$cst$415$type_properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$cljs$cst$942$app_DOT_common_DOT_schema_DOT_openapi_SLASH_type$$,"string",$cljs$cst$869$gen_SLASH_gen$$,$generator$jscomp$15$$,$cljs$cst$941$encode_SLASH_json$$,$APP.$cljs$core$identity$$,$APP.$cljs$cst$938$decode_SLASH_json$$,function($G__47920_G__47921_s$jscomp$524$$){if(typeof $G__47920_G__47921_s$jscomp$524$$==="string")return $APP.$cuerdas$core$empty_QMARK_$$($G__47920_G__47921_s$jscomp$524$$)?($G__47920_G__47921_s$jscomp$524$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$app$common$types$path$impl$from_plain$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$app$common$types$path$impl$from_plain$$.$cljs$core$IFn$_invoke$arity$1$($G__47920_G__47921_s$jscomp$524$$):$APP.$app$common$types$path$impl$from_plain$$($G__47920_G__47921_s$jscomp$524$$)):$app$common$types$path$impl$from_string$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$path$impl$from_string$$.$cljs$core$IFn$_invoke$arity$1$($G__47920_G__47921_s$jscomp$524$$):$app$common$types$path$impl$from_string$$($G__47920_G__47921_s$jscomp$524$$);if($APP.$cljs$core$vector_QMARK_$$($G__47920_G__47921_s$jscomp$524$$)){var $decode_fn$jscomp$1$$=
$APP.$cljs$core$_deref$$($decoder$jscomp$2$$);$G__47920_G__47921_s$jscomp$524$$=$decode_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$decode_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__47920_G__47921_s$jscomp$524$$):$decode_fn$jscomp$1$$($G__47920_G__47921_s$jscomp$524$$);return $APP.$app$common$types$path$impl$from_plain$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$path$impl$from_plain$$.$cljs$core$IFn$_invoke$arity$1$($G__47920_G__47921_s$jscomp$524$$):$APP.$app$common$types$path$impl$from_plain$$($G__47920_G__47921_s$jscomp$524$$)}return $G__47920_G__47921_s$jscomp$524$$}],
null)],null)}],null)]));$app$common$schema$check_fn$$($APP.$app$common$types$path$impl$schema_COLON_segments$$);$app$common$types$path$impl$check_segment$$=$app$common$schema$check_fn$$($app$common$types$path$impl$schema_COLON_segment$$);$app$common$types$path$impl$check_content$$=$app$common$schema$check_fn$$($app$common$types$path$impl$schema_COLON_content$$);$APP.$app$common$types$path$impl$decode_segments$$=$app$common$schema$lazy_decoder$$($APP.$app$common$types$path$impl$schema_COLON_segments$$);
$app$common$types$path$impl$from_bytes$$=function $app$common$types$path$impl$from_bytes$$($G__47936_G__47938_G__47941_buffer$jscomp$55$$){if($G__47936_G__47938_G__47941_buffer$jscomp$55$$ instanceof ArrayBuffer){var $count$jscomp$68_size$jscomp$95$$=$G__47936_G__47938_G__47941_buffer$jscomp$55$$.byteLength;$count$jscomp$68_size$jscomp$95$$=$APP.$cljs$core$fix$$($count$jscomp$68_size$jscomp$95$$/28);return new $app$common$types$path$impl$PathData$$($count$jscomp$68_size$jscomp$95$$,new DataView($G__47936_G__47938_G__47941_buffer$jscomp$55$$),
new $module$app$common$weak$impl_weak_value_map$$.$WeakValueMap$,null)}if($G__47936_G__47938_G__47941_buffer$jscomp$55$$ instanceof DataView)return $count$jscomp$68_size$jscomp$95$$=$G__47936_G__47938_G__47941_buffer$jscomp$55$$.byteLength,$count$jscomp$68_size$jscomp$95$$=$APP.$cljs$core$fix$$($count$jscomp$68_size$jscomp$95$$/28),new $app$common$types$path$impl$PathData$$($count$jscomp$68_size$jscomp$95$$,$G__47936_G__47938_G__47941_buffer$jscomp$55$$,new $module$app$common$weak$impl_weak_value_map$$.$WeakValueMap$,
null);if($G__47936_G__47938_G__47941_buffer$jscomp$55$$ instanceof Uint8Array){var $ab$jscomp$1$$=$G__47936_G__47938_G__47941_buffer$jscomp$55$$.buffer,$offset$jscomp$119$$=$G__47936_G__47938_G__47941_buffer$jscomp$55$$.byteOffset;$count$jscomp$68_size$jscomp$95$$=$G__47936_G__47938_G__47941_buffer$jscomp$55$$.byteLength;$G__47936_G__47938_G__47941_buffer$jscomp$55$$=new DataView($ab$jscomp$1$$,$offset$jscomp$119$$,$count$jscomp$68_size$jscomp$95$$);return $app$common$types$path$impl$from_bytes$$.$cljs$core$IFn$_invoke$arity$1$?
$app$common$types$path$impl$from_bytes$$.$cljs$core$IFn$_invoke$arity$1$($G__47936_G__47938_G__47941_buffer$jscomp$55$$):$app$common$types$path$impl$from_bytes$$($G__47936_G__47938_G__47941_buffer$jscomp$55$$)}if($G__47936_G__47938_G__47941_buffer$jscomp$55$$ instanceof Uint32Array||$G__47936_G__47938_G__47941_buffer$jscomp$55$$ instanceof Int8Array)return $ab$jscomp$1$$=$G__47936_G__47938_G__47941_buffer$jscomp$55$$.buffer,$offset$jscomp$119$$=$G__47936_G__47938_G__47941_buffer$jscomp$55$$.byteOffset,
$count$jscomp$68_size$jscomp$95$$=$G__47936_G__47938_G__47941_buffer$jscomp$55$$.byteLength,$G__47936_G__47938_G__47941_buffer$jscomp$55$$=new DataView($ab$jscomp$1$$,$offset$jscomp$119$$,$count$jscomp$68_size$jscomp$95$$),$app$common$types$path$impl$from_bytes$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$path$impl$from_bytes$$.$cljs$core$IFn$_invoke$arity$1$($G__47936_G__47938_G__47941_buffer$jscomp$55$$):$app$common$types$path$impl$from_bytes$$($G__47936_G__47938_G__47941_buffer$jscomp$55$$);
throw Error("invalid data provided");};
$APP.$app$common$transit$add_handlers_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"penpot/path-data",$APP.$cljs$cst$1291$class$$,$app$common$types$path$impl$PathData$$,$APP.$cljs$cst$1314$wfn$$,function($buffer$jscomp$57_pdata$jscomp$2$$){$buffer$jscomp$57_pdata$jscomp$2$$=$buffer$jscomp$57_pdata$jscomp$2$$.buffer;return new Uint8Array($buffer$jscomp$57_pdata$jscomp$2$$.buffer,$buffer$jscomp$57_pdata$jscomp$2$$.byteOffset,
$buffer$jscomp$57_pdata$jscomp$2$$.byteLength)},$APP.$cljs$cst$1315$rfn$$,$app$common$types$path$impl$from_bytes$$],null)]));var $app$common$types$path$segment$xf_COLON_mapcat_points$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__48132_SHARP_$$){return new $APP.$cljs$core$List$$(null,$cljs$cst$1855$next_p$$.$cljs$core$IFn$_invoke$arity$1$($p1__48132_SHARP_$$),new $APP.$cljs$core$List$$(null,$cljs$cst$1856$prev_p$$.$cljs$core$IFn$_invoke$arity$1$($p1__48132_SHARP_$$),null,1,null),2,null)}),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nil_QMARK_$$));var $app$common$types$path$subpath$xf_mapcat_data$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$142$data$$);$APP.$app$common$types$path$bool$group_style_properties$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1653$blur$$,null,$APP.$cljs$cst$1654$shadow$$,null],null),null);
$APP.$app$common$types$path$bool$style_properties$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$path$bool$group_style_properties$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1634$fills$$,$APP.$cljs$cst$1636$strokes$$],null));$APP.$app$common$types$shape$attrs$editable_attrs$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$1608$group$$,$APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$1417$circle$$,$APP.$cljs$cst$1613$svg_raw$$,$APP.$cljs$cst$1612$image$$,$APP.$cljs$cst$1610$bool$$,$APP.$cljs$cst$1611$rect$$,$APP.$cljs$cst$1588$text$$],[new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,48,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1746$fill_color$$,
null,$APP.$cljs$cst$1711$layout_item_absolute$$,null,$APP.$cljs$cst$1865$stroke_cap_start$$,null,$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$1866$stroke_style$$,null,$APP.$cljs$cst$1739$stroke_color$$,null,$APP.$cljs$cst$1867$blend_mode$$,null,$APP.$cljs$cst$1640$fill_color_ref_file$$,null,$APP.$cljs$cst$1740$stroke_opacity$$,null,$APP.$cljs$cst$1748$fill_color_gradient$$,null,$APP.$cljs$cst$1698$layout_item_margin_type$$,null,$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1868$stroke_alignment$$,
null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1645$fixed_scroll$$,null,$APP.$cljs$cst$1706$layout_item_max_w$$,null,$APP.$cljs$cst$1708$layout_item_h_sizing$$,null,$APP.$cljs$cst$1808$proportion_lock$$,null,$APP.$cljs$cst$1869$stroke_cap_end$$,null,$APP.$cljs$cst$1870$exports$$,null,$APP.$cljs$cst$1742$stroke_color_ref_id$$,null,$APP.$cljs$cst$1709$layout_item_v_sizing$$,null,$APP.$cljs$cst$1871$constraints_v$$,null,$APP.$cljs$cst$1653$blur$$,null,$APP.$cljs$cst$1655$stroke_width$$,null,$APP.$cljs$cst$1872$constraints_h$$,
null,$APP.$cljs$cst$1620$hidden$$,null,$APP.$cljs$cst$1734$opacity$$,null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1619$parent_id$$,null,$APP.$cljs$cst$1641$stroke_color_ref_file$$,null,$APP.$cljs$cst$1607$frame_id$$,null,$APP.$cljs$cst$1636$strokes$$,null,$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1623$blocked$$,null,$APP.$cljs$cst$1654$shadow$$,null,$APP.$cljs$cst$1741$stroke_color_gradient$$,null,$APP.$cljs$cst$1699$layout_item_margin$$,null,$APP.$cljs$cst$1710$layout_item_align_self$$,
null,$APP.$cljs$cst$1605$selrect$$,null,$APP.$cljs$cst$1634$fills$$,null,$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null,$APP.$cljs$cst$1747$fill_opacity$$,null,$APP.$cljs$cst$1745$fill_color_ref_id$$,null,$APP.$cljs$cst$1522$height$$,null,$APP.$cljs$cst$1712$layout_item_z_index$$,null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,32,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1711$layout_item_absolute$$,
null,$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$1867$blend_mode$$,null,$APP.$cljs$cst$1698$layout_item_margin_type$$,null,$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1645$fixed_scroll$$,null,$APP.$cljs$cst$1706$layout_item_max_w$$,null,$APP.$cljs$cst$1708$layout_item_h_sizing$$,null,$APP.$cljs$cst$1808$proportion_lock$$,null,$APP.$cljs$cst$1870$exports$$,null,$APP.$cljs$cst$1709$layout_item_v_sizing$$,null,$APP.$cljs$cst$1871$constraints_v$$,null,$APP.$cljs$cst$1653$blur$$,
null,$APP.$cljs$cst$1872$constraints_h$$,null,$APP.$cljs$cst$1620$hidden$$,null,$APP.$cljs$cst$1734$opacity$$,null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1619$parent_id$$,null,$APP.$cljs$cst$1873$applied_tokens$$,null,$APP.$cljs$cst$1607$frame_id$$,null,$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1623$blocked$$,null,$APP.$cljs$cst$1654$shadow$$,null,$APP.$cljs$cst$1699$layout_item_margin$$,null,$APP.$cljs$cst$1710$layout_item_align_self$$,null,$APP.$cljs$cst$1605$selrect$$,null,
$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null,$APP.$cljs$cst$1522$height$$,null,$APP.$cljs$cst$1712$layout_item_z_index$$,null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,65,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1695$layout_grid_columns$$,null,$APP.$cljs$cst$1874$hide_fill_on_export$$,null,$APP.$cljs$cst$1746$fill_color$$,null,$APP.$cljs$cst$1711$layout_item_absolute$$,null,$APP.$cljs$cst$1683$layout_gap_type$$,
null,$APP.$cljs$cst$1865$stroke_cap_start$$,null,$APP.$cljs$cst$1686$layout_padding$$,null,$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$1684$layout_wrap_type$$,null,$APP.$cljs$cst$1866$stroke_style$$,null,$APP.$cljs$cst$1739$stroke_color$$,null,$APP.$cljs$cst$1615$layout$$,null,$APP.$cljs$cst$1875$hide_in_viewer$$,null,$APP.$cljs$cst$1867$blend_mode$$,null,$APP.$cljs$cst$1640$fill_color_ref_file$$,null,$APP.$cljs$cst$1740$stroke_opacity$$,null,$APP.$cljs$cst$1692$layout_align_items$$,null,$APP.$cljs$cst$1748$fill_color_gradient$$,
null,$APP.$cljs$cst$1698$layout_item_margin_type$$,null,$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1685$layout_padding_type$$,null,$APP.$cljs$cst$1868$stroke_alignment$$,null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1647$r2$$,null,$APP.$cljs$cst$1706$layout_item_max_w$$,null,$APP.$cljs$cst$1876$show_content$$,null,$APP.$cljs$cst$1708$layout_item_h_sizing$$,null,$APP.$cljs$cst$1808$proportion_lock$$,null,$APP.$cljs$cst$1869$stroke_cap_end$$,null,$APP.$cljs$cst$1680$layout_gap$$,null,$APP.$cljs$cst$1870$exports$$,
null,$APP.$cljs$cst$1742$stroke_color_ref_id$$,null,$APP.$cljs$cst$1709$layout_item_v_sizing$$,null,$APP.$cljs$cst$1648$r3$$,null,$APP.$cljs$cst$1689$layout_justify_content$$,null,$APP.$cljs$cst$1653$blur$$,null,$APP.$cljs$cst$1655$stroke_width$$,null,$APP.$cljs$cst$1646$r1$$,null,$APP.$cljs$cst$1620$hidden$$,null,$APP.$cljs$cst$1734$opacity$$,null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1690$layout_justify_items$$,null,$APP.$cljs$cst$1679$layout_flex_dir$$,null,$APP.$cljs$cst$1873$applied_tokens$$,
null,$APP.$cljs$cst$1691$layout_align_content$$,null,$APP.$cljs$cst$1641$stroke_color_ref_file$$,null,$APP.$cljs$cst$1636$strokes$$,null,$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1623$blocked$$,null,$APP.$cljs$cst$1654$shadow$$,null,$APP.$cljs$cst$1649$r4$$,null,$APP.$cljs$cst$1694$layout_grid_rows$$,null,$APP.$cljs$cst$1741$stroke_color_gradient$$,null,$APP.$cljs$cst$1699$layout_item_margin$$,null,$APP.$cljs$cst$1710$layout_item_align_self$$,null,$APP.$cljs$cst$1605$selrect$$,null,$APP.$cljs$cst$1634$fills$$,
null,$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null,$APP.$cljs$cst$1693$layout_grid_dir$$,null,$APP.$cljs$cst$1747$fill_opacity$$,null,$APP.$cljs$cst$1745$fill_color_ref_id$$,null,$APP.$cljs$cst$1522$height$$,null,$APP.$cljs$cst$1712$layout_item_z_index$$,null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,48,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1746$fill_color$$,null,$APP.$cljs$cst$1711$layout_item_absolute$$,
null,$APP.$cljs$cst$1865$stroke_cap_start$$,null,$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$1866$stroke_style$$,null,$APP.$cljs$cst$1739$stroke_color$$,null,$APP.$cljs$cst$1867$blend_mode$$,null,$APP.$cljs$cst$1640$fill_color_ref_file$$,null,$APP.$cljs$cst$1740$stroke_opacity$$,null,$APP.$cljs$cst$1748$fill_color_gradient$$,null,$APP.$cljs$cst$1698$layout_item_margin_type$$,null,$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1868$stroke_alignment$$,null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1645$fixed_scroll$$,
null,$APP.$cljs$cst$1706$layout_item_max_w$$,null,$APP.$cljs$cst$1708$layout_item_h_sizing$$,null,$APP.$cljs$cst$1808$proportion_lock$$,null,$APP.$cljs$cst$1869$stroke_cap_end$$,null,$APP.$cljs$cst$1870$exports$$,null,$APP.$cljs$cst$1742$stroke_color_ref_id$$,null,$APP.$cljs$cst$1709$layout_item_v_sizing$$,null,$APP.$cljs$cst$1871$constraints_v$$,null,$APP.$cljs$cst$1653$blur$$,null,$APP.$cljs$cst$1655$stroke_width$$,null,$APP.$cljs$cst$1872$constraints_h$$,null,$APP.$cljs$cst$1620$hidden$$,null,
$APP.$cljs$cst$1734$opacity$$,null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1619$parent_id$$,null,$APP.$cljs$cst$1641$stroke_color_ref_file$$,null,$APP.$cljs$cst$1607$frame_id$$,null,$APP.$cljs$cst$1636$strokes$$,null,$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1623$blocked$$,null,$APP.$cljs$cst$1654$shadow$$,null,$APP.$cljs$cst$1741$stroke_color_gradient$$,null,$APP.$cljs$cst$1699$layout_item_margin$$,null,$APP.$cljs$cst$1710$layout_item_align_self$$,null,$APP.$cljs$cst$1605$selrect$$,
null,$APP.$cljs$cst$1634$fills$$,null,$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null,$APP.$cljs$cst$1747$fill_opacity$$,null,$APP.$cljs$cst$1745$fill_color_ref_id$$,null,$APP.$cljs$cst$1522$height$$,null,$APP.$cljs$cst$1712$layout_item_z_index$$,null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,52,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1746$fill_color$$,null,$APP.$cljs$cst$1711$layout_item_absolute$$,
null,$APP.$cljs$cst$1865$stroke_cap_start$$,null,$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$1866$stroke_style$$,null,$APP.$cljs$cst$1739$stroke_color$$,null,$APP.$cljs$cst$1867$blend_mode$$,null,$APP.$cljs$cst$1640$fill_color_ref_file$$,null,$APP.$cljs$cst$1740$stroke_opacity$$,null,$APP.$cljs$cst$1748$fill_color_gradient$$,null,$APP.$cljs$cst$1698$layout_item_margin_type$$,null,$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1868$stroke_alignment$$,null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1645$fixed_scroll$$,
null,$APP.$cljs$cst$1647$r2$$,null,$APP.$cljs$cst$1706$layout_item_max_w$$,null,$APP.$cljs$cst$1708$layout_item_h_sizing$$,null,$APP.$cljs$cst$1808$proportion_lock$$,null,$APP.$cljs$cst$1869$stroke_cap_end$$,null,$APP.$cljs$cst$1870$exports$$,null,$APP.$cljs$cst$1742$stroke_color_ref_id$$,null,$APP.$cljs$cst$1709$layout_item_v_sizing$$,null,$APP.$cljs$cst$1648$r3$$,null,$APP.$cljs$cst$1871$constraints_v$$,null,$APP.$cljs$cst$1653$blur$$,null,$APP.$cljs$cst$1655$stroke_width$$,null,$APP.$cljs$cst$1872$constraints_h$$,
null,$APP.$cljs$cst$1646$r1$$,null,$APP.$cljs$cst$1620$hidden$$,null,$APP.$cljs$cst$1734$opacity$$,null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1619$parent_id$$,null,$APP.$cljs$cst$1641$stroke_color_ref_file$$,null,$APP.$cljs$cst$1607$frame_id$$,null,$APP.$cljs$cst$1636$strokes$$,null,$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1623$blocked$$,null,$APP.$cljs$cst$1654$shadow$$,null,$APP.$cljs$cst$1649$r4$$,null,$APP.$cljs$cst$1741$stroke_color_gradient$$,null,$APP.$cljs$cst$1699$layout_item_margin$$,
null,$APP.$cljs$cst$1710$layout_item_align_self$$,null,$APP.$cljs$cst$1605$selrect$$,null,$APP.$cljs$cst$1634$fills$$,null,$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null,$APP.$cljs$cst$1747$fill_opacity$$,null,$APP.$cljs$cst$1745$fill_color_ref_id$$,null,$APP.$cljs$cst$1522$height$$,null,$APP.$cljs$cst$1712$layout_item_z_index$$,null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,35,[$APP.$cljs$cst$1511$y$$,
null,$APP.$cljs$cst$1711$layout_item_absolute$$,null,$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$1867$blend_mode$$,null,$APP.$cljs$cst$1698$layout_item_margin_type$$,null,$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1645$fixed_scroll$$,null,$APP.$cljs$cst$1647$r2$$,null,$APP.$cljs$cst$1706$layout_item_max_w$$,null,$APP.$cljs$cst$1708$layout_item_h_sizing$$,null,$APP.$cljs$cst$1808$proportion_lock$$,null,$APP.$cljs$cst$1870$exports$$,null,$APP.$cljs$cst$1709$layout_item_v_sizing$$,
null,$APP.$cljs$cst$1648$r3$$,null,$APP.$cljs$cst$1871$constraints_v$$,null,$APP.$cljs$cst$1653$blur$$,null,$APP.$cljs$cst$1872$constraints_h$$,null,$APP.$cljs$cst$1646$r1$$,null,$APP.$cljs$cst$1620$hidden$$,null,$APP.$cljs$cst$1734$opacity$$,null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1619$parent_id$$,null,$APP.$cljs$cst$1607$frame_id$$,null,$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1623$blocked$$,null,$APP.$cljs$cst$1654$shadow$$,null,$APP.$cljs$cst$1649$r4$$,null,$APP.$cljs$cst$1699$layout_item_margin$$,
null,$APP.$cljs$cst$1710$layout_item_align_self$$,null,$APP.$cljs$cst$1605$selrect$$,null,$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null,$APP.$cljs$cst$1522$height$$,null,$APP.$cljs$cst$1712$layout_item_z_index$$,null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,51,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1746$fill_color$$,null,$APP.$cljs$cst$1711$layout_item_absolute$$,null,$APP.$cljs$cst$1865$stroke_cap_start$$,
null,$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$1866$stroke_style$$,null,$APP.$cljs$cst$1739$stroke_color$$,null,$APP.$cljs$cst$1867$blend_mode$$,null,$APP.$cljs$cst$1640$fill_color_ref_file$$,null,$APP.$cljs$cst$1740$stroke_opacity$$,null,$APP.$cljs$cst$1748$fill_color_gradient$$,null,$APP.$cljs$cst$1698$layout_item_margin_type$$,null,$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1868$stroke_alignment$$,null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1645$fixed_scroll$$,null,$APP.$cljs$cst$1647$r2$$,
null,$APP.$cljs$cst$1706$layout_item_max_w$$,null,$APP.$cljs$cst$1708$layout_item_h_sizing$$,null,$APP.$cljs$cst$1808$proportion_lock$$,null,$APP.$cljs$cst$1869$stroke_cap_end$$,null,$APP.$cljs$cst$1870$exports$$,null,$APP.$cljs$cst$1742$stroke_color_ref_id$$,null,$APP.$cljs$cst$1709$layout_item_v_sizing$$,null,$APP.$cljs$cst$1648$r3$$,null,$APP.$cljs$cst$1871$constraints_v$$,null,$APP.$cljs$cst$1653$blur$$,null,$APP.$cljs$cst$1655$stroke_width$$,null,$APP.$cljs$cst$1872$constraints_h$$,null,$APP.$cljs$cst$1646$r1$$,
null,$APP.$cljs$cst$1620$hidden$$,null,$APP.$cljs$cst$1734$opacity$$,null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1619$parent_id$$,null,$APP.$cljs$cst$1641$stroke_color_ref_file$$,null,$APP.$cljs$cst$1607$frame_id$$,null,$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1623$blocked$$,null,$APP.$cljs$cst$1654$shadow$$,null,$APP.$cljs$cst$1649$r4$$,null,$APP.$cljs$cst$1741$stroke_color_gradient$$,null,$APP.$cljs$cst$1699$layout_item_margin$$,null,$APP.$cljs$cst$1710$layout_item_align_self$$,
null,$APP.$cljs$cst$1605$selrect$$,null,$APP.$cljs$cst$1634$fills$$,null,$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null,$APP.$cljs$cst$1747$fill_opacity$$,null,$APP.$cljs$cst$1745$fill_color_ref_id$$,null,$APP.$cljs$cst$1522$height$$,null,$APP.$cljs$cst$1712$layout_item_z_index$$,null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,52,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1746$fill_color$$,null,
$APP.$cljs$cst$1711$layout_item_absolute$$,null,$APP.$cljs$cst$1865$stroke_cap_start$$,null,$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$1866$stroke_style$$,null,$APP.$cljs$cst$1739$stroke_color$$,null,$APP.$cljs$cst$1867$blend_mode$$,null,$APP.$cljs$cst$1640$fill_color_ref_file$$,null,$APP.$cljs$cst$1740$stroke_opacity$$,null,$APP.$cljs$cst$1748$fill_color_gradient$$,null,$APP.$cljs$cst$1698$layout_item_margin_type$$,null,$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1868$stroke_alignment$$,
null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1645$fixed_scroll$$,null,$APP.$cljs$cst$1647$r2$$,null,$APP.$cljs$cst$1706$layout_item_max_w$$,null,$APP.$cljs$cst$1708$layout_item_h_sizing$$,null,$APP.$cljs$cst$1808$proportion_lock$$,null,$APP.$cljs$cst$1869$stroke_cap_end$$,null,$APP.$cljs$cst$1870$exports$$,null,$APP.$cljs$cst$1742$stroke_color_ref_id$$,null,$APP.$cljs$cst$1709$layout_item_v_sizing$$,null,$APP.$cljs$cst$1648$r3$$,null,$APP.$cljs$cst$1871$constraints_v$$,null,$APP.$cljs$cst$1653$blur$$,
null,$APP.$cljs$cst$1655$stroke_width$$,null,$APP.$cljs$cst$1872$constraints_h$$,null,$APP.$cljs$cst$1646$r1$$,null,$APP.$cljs$cst$1620$hidden$$,null,$APP.$cljs$cst$1734$opacity$$,null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1619$parent_id$$,null,$APP.$cljs$cst$1641$stroke_color_ref_file$$,null,$APP.$cljs$cst$1607$frame_id$$,null,$APP.$cljs$cst$1636$strokes$$,null,$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1623$blocked$$,null,$APP.$cljs$cst$1654$shadow$$,null,$APP.$cljs$cst$1649$r4$$,
null,$APP.$cljs$cst$1741$stroke_color_gradient$$,null,$APP.$cljs$cst$1699$layout_item_margin$$,null,$APP.$cljs$cst$1710$layout_item_align_self$$,null,$APP.$cljs$cst$1605$selrect$$,null,$APP.$cljs$cst$1634$fills$$,null,$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null,$APP.$cljs$cst$1747$fill_opacity$$,null,$APP.$cljs$cst$1745$fill_color_ref_id$$,null,$APP.$cljs$cst$1522$height$$,null,$APP.$cljs$cst$1712$layout_item_z_index$$,null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,63,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1765$line_height$$,null,$APP.$cljs$cst$1762$font_style$$,null,$APP.$cljs$cst$1746$fill_color$$,null,$APP.$cljs$cst$1711$layout_item_absolute$$,null,$APP.$cljs$cst$1865$stroke_cap_start$$,null,$APP.$cljs$cst$1756$typography_ref_id$$,null,$APP.$cljs$cst$1769$text_transform$$,null,$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$1763$text_align$$,null,$APP.$cljs$cst$1767$vertical_align$$,null,$APP.$cljs$cst$1757$font_id$$,
null,$APP.$cljs$cst$1770$grow_type$$,null,$APP.$cljs$cst$1866$stroke_style$$,null,$APP.$cljs$cst$1760$font_size$$,null,$APP.$cljs$cst$1739$stroke_color$$,null,$APP.$cljs$cst$1761$font_weight$$,null,$APP.$cljs$cst$1867$blend_mode$$,null,$APP.$cljs$cst$1642$typography_ref_file$$,null,$APP.$cljs$cst$1764$text_direction$$,null,$APP.$cljs$cst$1640$fill_color_ref_file$$,null,$APP.$cljs$cst$1740$stroke_opacity$$,null,$APP.$cljs$cst$1748$fill_color_gradient$$,null,$APP.$cljs$cst$1698$layout_item_margin_type$$,
null,$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1868$stroke_alignment$$,null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1645$fixed_scroll$$,null,$APP.$cljs$cst$1759$font_variant_id$$,null,$APP.$cljs$cst$1706$layout_item_max_w$$,null,$APP.$cljs$cst$1708$layout_item_h_sizing$$,null,$APP.$cljs$cst$1808$proportion_lock$$,null,$APP.$cljs$cst$1869$stroke_cap_end$$,null,$APP.$cljs$cst$1870$exports$$,null,$APP.$cljs$cst$1742$stroke_color_ref_id$$,null,$APP.$cljs$cst$1709$layout_item_v_sizing$$,
null,$APP.$cljs$cst$1871$constraints_v$$,null,$APP.$cljs$cst$1653$blur$$,null,$APP.$cljs$cst$1655$stroke_width$$,null,$APP.$cljs$cst$1872$constraints_h$$,null,$APP.$cljs$cst$1620$hidden$$,null,$APP.$cljs$cst$1734$opacity$$,null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1619$parent_id$$,null,$APP.$cljs$cst$1641$stroke_color_ref_file$$,null,$APP.$cljs$cst$1768$text_decoration$$,null,$APP.$cljs$cst$1607$frame_id$$,null,$APP.$cljs$cst$1636$strokes$$,null,$APP.$cljs$cst$1766$letter_spacing$$,
null,$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1623$blocked$$,null,$APP.$cljs$cst$1654$shadow$$,null,$APP.$cljs$cst$1741$stroke_color_gradient$$,null,$APP.$cljs$cst$1699$layout_item_margin$$,null,$APP.$cljs$cst$1710$layout_item_align_self$$,null,$APP.$cljs$cst$1605$selrect$$,null,$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null,$APP.$cljs$cst$1747$fill_opacity$$,null,$APP.$cljs$cst$1745$fill_color_ref_id$$,null,$APP.$cljs$cst$1758$font_family$$,null,$APP.$cljs$cst$1522$height$$,
null,$APP.$cljs$cst$1712$layout_item_z_index$$,null],null),null)]);var $app$common$types$path$shape_to_path$dissoc_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1881$rx$$,$APP.$cljs$cst$1882$ry$$,$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1649$r4$$,$cljs$cst$1633$metadata$$],null);var $app$common$types$path$update_geometry$$=function $app$common$types$path$update_geometry$$($var_args$jscomp$951$$){switch(arguments.length){case 2:return $app$common$types$path$update_geometry$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 1:return $app$common$types$path$update_geometry$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}},$app$common$types$path$wasm_COLON_calc_bool_content$$;
$app$common$types$path$update_geometry$$.$cljs$core$IFn$_invoke$arity$2$=function($shape$jscomp$91$$,$content$jscomp$79$$){return $app$common$types$path$update_geometry$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$91$$,$APP.$cljs$cst$1637$content$$,$content$jscomp$79$$))};
$app$common$types$path$update_geometry$$.$cljs$core$IFn$_invoke$arity$1$=function($shape$jscomp$92$$){var $flip_x$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$92$$,$APP.$cljs$cst$1879$flip_x$$),$flip_y$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$92$$,$APP.$cljs$cst$1880$flip_y$$),$content$jscomp$80$$=$APP.$app$common$types$path$impl$path_data$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$92$$,$APP.$cljs$cst$1637$content$$)),
$points$jscomp$21_transform$jscomp$42$$=function(){var $G__48648_G__48648__$1$$=$APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$92$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$());$G__48648_G__48648__$1$$=$APP.$cljs$core$truth_$$($flip_x$$)?$app$common$geom$matrix$scale$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48648_G__48648__$1$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,1)):$G__48648_G__48648__$1$$;return $APP.$cljs$core$truth_$$($flip_y$$)?
$app$common$geom$matrix$scale$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48648_G__48648__$1$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,-1)):$G__48648_G__48648__$1$$}(),$selrect$jscomp$6_transform_inverse$jscomp$8$$=function(){var $G__48651_G__48651__$1_G__48651__$2$$=$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$();$G__48651_G__48651__$1_G__48651__$2$$=$APP.$cljs$core$truth_$$($flip_x$$)?$app$common$geom$matrix$scale$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48651_G__48651__$1_G__48651__$2$$,
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,1)):$G__48651_G__48651__$1_G__48651__$2$$;$G__48651_G__48651__$1_G__48651__$2$$=$APP.$cljs$core$truth_$$($flip_y$$)?$app$common$geom$matrix$scale$cljs$0core$0IFn$0_invoke$0arity$02$$($G__48651_G__48651__$1_G__48651__$2$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,-1)):$G__48651_G__48651__$1_G__48651__$2$$;return $APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($G__48651_G__48651__$1_G__48651__$2$$,
$APP.$cljs$cst$1787$transform_inverse$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$92$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()))}(),$center$jscomp$15_points_center$$=function(){var $G__48653$jscomp$inline_5149_or__5025__auto__$jscomp$357$$=$shape$jscomp$92$$?.$selrect$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$92$$,$APP.$cljs$cst$1605$selrect$$);$G__48653$jscomp$inline_5149_or__5025__auto__$jscomp$357$$=$G__48653$jscomp$inline_5149_or__5025__auto__$jscomp$357$$==
null?null:$APP.$app$common$geom$rect$rect__GT_center$$($G__48653$jscomp$inline_5149_or__5025__auto__$jscomp$357$$);return $APP.$cljs$core$truth_$$($G__48653$jscomp$inline_5149_or__5025__auto__$jscomp$357$$)?$G__48653$jscomp$inline_5149_or__5025__auto__$jscomp$357$$:$APP.$app$common$geom$rect$rect__GT_center$$($app$common$types$path$segment$content__GT_selrect$$($content$jscomp$80$$))}(),$base_content$$=$app$common$types$path$segment$transform_content$$($content$jscomp$80$$,$APP.$app$common$geom$matrix$transform_in$$($center$jscomp$15_points_center$$,
$selrect$jscomp$6_transform_inverse$jscomp$8$$));$points$jscomp$21_transform$jscomp$42$$=$APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$geom$rect$rect__GT_points$$($app$common$types$path$segment$content__GT_selrect$$($base_content$$)),$center$jscomp$15_points_center$$,$points$jscomp$21_transform$jscomp$42$$);$center$jscomp$15_points_center$$=$APP.$app$common$geom$shapes$common$points__GT_center$$($points$jscomp$21_transform$jscomp$42$$);
$selrect$jscomp$6_transform_inverse$jscomp$8$$=$APP.$app$common$geom$rect$points__GT_rect$$($APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$03$$($points$jscomp$21_transform$jscomp$42$$,$center$jscomp$15_points_center$$,$selrect$jscomp$6_transform_inverse$jscomp$8$$));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$92$$,$APP.$cljs$cst$1637$content$$,
$content$jscomp$80$$),$APP.$cljs$cst$1604$points$$,$points$jscomp$21_transform$jscomp$42$$),$APP.$cljs$cst$1605$selrect$$,$selrect$jscomp$6_transform_inverse$jscomp$8$$)};$app$common$types$path$update_geometry$$.$cljs$lang$maxFixedArity$=2;$app$common$types$path$wasm_COLON_calc_bool_content$$=null;
$APP.$app$common$types$path$convert_to_path$$=function $app$common$types$path$convert_to_path$$($var_args$jscomp$953$$){switch(arguments.length){case 1:return $app$common$types$path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$types$path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$types$path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$1$=function($shape$jscomp$97$$){return $APP.$app$common$types$path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$97$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$common$types$path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$2$=function($shape$jscomp$98$$,$objects$jscomp$105$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$path$shape_to_path$convert_to_path$$($shape$jscomp$98$$,$objects$jscomp$105$$),$APP.$cljs$cst$1637$content$$,$APP.$app$common$types$path$impl$path_data$$)};$APP.$app$common$types$path$convert_to_path$$.$cljs$lang$maxFixedArity$=2;var $app$common$geom$shapes$transforms$transform_shape$$=function $app$common$geom$shapes$transforms$transform_shape$$($var_args$jscomp$957$$){switch(arguments.length){case 1:return $app$common$geom$shapes$transforms$transform_shape$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$geom$shapes$transforms$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$app$common$geom$shapes$transforms$transform_shape$$.$cljs$core$IFn$_invoke$arity$1$=function($shape$jscomp$114$$){var $modifiers$jscomp$30$$=$APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$114$$);return $app$common$geom$shapes$transforms$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$114$$,$APP.$cljs$cst$1810$modifiers$$),$modifiers$jscomp$30$$)};
$app$common$geom$shapes$transforms$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$=function($G__48833__$1_shape$jscomp$115$$,$modifiers$jscomp$31$$){if($G__48833__$1_shape$jscomp$115$$==null||$modifiers$jscomp$31$$==null||$app$common$types$modifiers$empty_QMARK_$$($modifiers$jscomp$31$$))return $G__48833__$1_shape$jscomp$115$$;var $transform$jscomp$50$$=$app$common$types$modifiers$modifiers__GT_transform$$($modifiers$jscomp$31$$);$G__48833__$1_shape$jscomp$115$$=$transform$jscomp$50$$==null||$APP.$app$common$files$helpers$root_QMARK_$$($G__48833__$1_shape$jscomp$115$$)?
$G__48833__$1_shape$jscomp$115$$:$APP.$app$common$geom$shapes$transforms$apply_transform$$($G__48833__$1_shape$jscomp$115$$,$transform$jscomp$50$$);return $app$common$types$modifiers$has_structure_QMARK_$$($modifiers$jscomp$31$$)?$APP.$app$common$types$modifiers$apply_structure_modifiers$$($G__48833__$1_shape$jscomp$115$$,$modifiers$jscomp$31$$):$G__48833__$1_shape$jscomp$115$$};$app$common$geom$shapes$transforms$transform_shape$$.$cljs$lang$maxFixedArity$=2;var $app$common$geom$shapes$constraints$constraint_modifier$$=function(){var $method_table__5622__auto__$jscomp$9$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$9$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$9$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$9$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.common.geom.shapes.constraints",
"constraint-modifier"),function(){function $G__49143$$($type$jscomp$339$$,$var_args$jscomp$963$$){if(arguments.length>1)for(var $G__49144__i$$=0,$G__49144__a$$=Array(arguments.length-1);$G__49144__i$$<$G__49144__a$$.length;)$G__49144__a$$[$G__49144__i$$]=arguments[$G__49144__i$$+1],++$G__49144__i$$;return $type$jscomp$339$$}$G__49143$$.$cljs$lang$maxFixedArity$=1;$G__49143$$.$cljs$lang$applyTo$=function($arglist__49145$$){var $type$jscomp$340$$=$APP.$cljs$core$first$$($arglist__49145$$);$APP.$cljs$core$rest$$($arglist__49145$$);
return $type$jscomp$340$$};$G__49143$$.$cljs$core$IFn$_invoke$arity$variadic$=function($type$jscomp$338$$){return $type$jscomp$338$$};return $G__49143$$}(),$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$9$$,$method_table__5622__auto__$jscomp$9$$,$prefer_table__5623__auto__$jscomp$9$$,$method_cache__5624__auto__$jscomp$9$$,$cached_hierarchy__5625__auto__$jscomp$9$$)}();
$app$common$geom$shapes$constraints$constraint_modifier$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$1292$start$$,function($_$jscomp$1200_start_before$$,$after_side_vector_axis$jscomp$16$$,$child_points_before$$,$before_side_vector_parent_points_before$$,$child_points_after_start_after$$,$parent_points_after$$){$_$jscomp$1200_start_before$$=$app$common$geom$shapes$constraints$start_vector$$($after_side_vector_axis$jscomp$16$$,$child_points_before$$,$before_side_vector_parent_points_before$$);
$child_points_after_start_after$$=$app$common$geom$shapes$constraints$start_vector$$($after_side_vector_axis$jscomp$16$$,$child_points_after_start_after$$,$parent_points_after$$);$before_side_vector_parent_points_before$$=$app$common$geom$shapes$constraints$side_vector$$($after_side_vector_axis$jscomp$16$$,$before_side_vector_parent_points_before$$);$after_side_vector_axis$jscomp$16$$=$app$common$geom$shapes$constraints$side_vector$$($after_side_vector_axis$jscomp$16$$,$parent_points_after$$);return $APP.$app$common$types$modifiers$move_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$geom$shapes$constraints$displacement$$($_$jscomp$1200_start_before$$,
$child_points_after_start_after$$,$before_side_vector_parent_points_before$$,$after_side_vector_axis$jscomp$16$$))});
$app$common$geom$shapes$constraints$constraint_modifier$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$1293$end$$,function($_$jscomp$1201_end_before$$,$after_side_vector$jscomp$1_axis$jscomp$17$$,$child_points_before$jscomp$1$$,$before_side_vector$jscomp$1_parent_points_before$jscomp$1$$,$child_points_after$jscomp$1_end_after$$,$parent_points_after$jscomp$1$$){$_$jscomp$1201_end_before$$=$app$common$geom$shapes$constraints$end_vector$$($after_side_vector$jscomp$1_axis$jscomp$17$$,
$child_points_before$jscomp$1$$,$before_side_vector$jscomp$1_parent_points_before$jscomp$1$$);$child_points_after$jscomp$1_end_after$$=$app$common$geom$shapes$constraints$end_vector$$($after_side_vector$jscomp$1_axis$jscomp$17$$,$child_points_after$jscomp$1_end_after$$,$parent_points_after$jscomp$1$$);$before_side_vector$jscomp$1_parent_points_before$jscomp$1$$=$app$common$geom$shapes$constraints$side_vector$$($after_side_vector$jscomp$1_axis$jscomp$17$$,$before_side_vector$jscomp$1_parent_points_before$jscomp$1$$);
$after_side_vector$jscomp$1_axis$jscomp$17$$=$app$common$geom$shapes$constraints$side_vector$$($after_side_vector$jscomp$1_axis$jscomp$17$$,$parent_points_after$jscomp$1$$);return $APP.$app$common$types$modifiers$move_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$geom$shapes$constraints$displacement$$($_$jscomp$1201_end_before$$,$child_points_after$jscomp$1_end_after$$,$before_side_vector$jscomp$1_parent_points_before$jscomp$1$$,$after_side_vector$jscomp$1_axis$jscomp$17$$))});
$app$common$geom$shapes$constraints$constraint_modifier$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$1671$fixed$$,function($_$jscomp$1202_disp_start_end_before$jscomp$1$$,$axis$jscomp$18_resize_vector$$,$before_vec_center$jscomp$26_child_points_before$jscomp$2_start_before$jscomp$1_transform_inverse$jscomp$10$$,$before_side_vector$jscomp$2_c1$jscomp$inline_5247_parent_points_before$jscomp$2$$,$child_points_after$jscomp$2_resize_origin$$,$parent_points_after$jscomp$2_transform$jscomp$54$$){$_$jscomp$1202_disp_start_end_before$jscomp$1$$=
$app$common$geom$shapes$constraints$end_vector$$($axis$jscomp$18_resize_vector$$,$before_vec_center$jscomp$26_child_points_before$jscomp$2_start_before$jscomp$1_transform_inverse$jscomp$10$$,$before_side_vector$jscomp$2_c1$jscomp$inline_5247_parent_points_before$jscomp$2$$);var $after_vec_disp_end_end_after$jscomp$1_scale$jscomp$18$$=$app$common$geom$shapes$constraints$end_vector$$($axis$jscomp$18_resize_vector$$,$child_points_after$jscomp$2_resize_origin$$,$parent_points_after$jscomp$2_transform$jscomp$54$$);
$before_vec_center$jscomp$26_child_points_before$jscomp$2_start_before$jscomp$1_transform_inverse$jscomp$10$$=$app$common$geom$shapes$constraints$start_vector$$($axis$jscomp$18_resize_vector$$,$before_vec_center$jscomp$26_child_points_before$jscomp$2_start_before$jscomp$1_transform_inverse$jscomp$10$$,$before_side_vector$jscomp$2_c1$jscomp$inline_5247_parent_points_before$jscomp$2$$);var $c0$jscomp$inline_5246_selrect$jscomp$16_start_after$jscomp$1$$=$app$common$geom$shapes$constraints$start_vector$$($axis$jscomp$18_resize_vector$$,
$child_points_after$jscomp$2_resize_origin$$,$parent_points_after$jscomp$2_transform$jscomp$54$$);$before_side_vector$jscomp$2_c1$jscomp$inline_5247_parent_points_before$jscomp$2$$=$app$common$geom$shapes$constraints$side_vector$$($axis$jscomp$18_resize_vector$$,$before_side_vector$jscomp$2_c1$jscomp$inline_5247_parent_points_before$jscomp$2$$);var $after_side_vector$jscomp$2_c3$jscomp$inline_5248$$=$app$common$geom$shapes$constraints$side_vector$$($axis$jscomp$18_resize_vector$$,$parent_points_after$jscomp$2_transform$jscomp$54$$);
$after_vec_disp_end_end_after$jscomp$1_scale$jscomp$18$$=$app$common$geom$shapes$constraints$displacement$$($_$jscomp$1202_disp_start_end_before$jscomp$1$$,$after_vec_disp_end_end_after$jscomp$1_scale$jscomp$18$$,$before_side_vector$jscomp$2_c1$jscomp$inline_5247_parent_points_before$jscomp$2$$,$after_side_vector$jscomp$2_c3$jscomp$inline_5248$$);$_$jscomp$1202_disp_start_end_before$jscomp$1$$=$app$common$geom$shapes$constraints$displacement$$($before_vec_center$jscomp$26_child_points_before$jscomp$2_start_before$jscomp$1_transform_inverse$jscomp$10$$,
$c0$jscomp$inline_5246_selrect$jscomp$16_start_after$jscomp$1$$,$before_side_vector$jscomp$2_c1$jscomp$inline_5247_parent_points_before$jscomp$2$$,$after_side_vector$jscomp$2_c3$jscomp$inline_5248$$);$before_vec_center$jscomp$26_child_points_before$jscomp$2_start_before$jscomp$1_transform_inverse$jscomp$10$$=$app$common$geom$shapes$constraints$side_vector$$($axis$jscomp$18_resize_vector$$,$child_points_after$jscomp$2_resize_origin$$);$c0$jscomp$inline_5246_selrect$jscomp$16_start_after$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points_after$jscomp$2_resize_origin$$,0,null);$before_side_vector$jscomp$2_c1$jscomp$inline_5247_parent_points_before$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points_after$jscomp$2_resize_origin$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points_after$jscomp$2_resize_origin$$,2,null);$after_side_vector$jscomp$2_c3$jscomp$inline_5248$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($child_points_after$jscomp$2_resize_origin$$,
3,null);$after_vec_disp_end_end_after$jscomp$1_scale$jscomp$18$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$18_resize_vector$$,$APP.$cljs$cst$1510$x$$)?$APP.$app$common$geom$point$to_vec$$($APP.$app$common$geom$point$add$$($c0$jscomp$inline_5246_selrect$jscomp$16_start_after$jscomp$1$$,$_$jscomp$1202_disp_start_end_before$jscomp$1$$),$APP.$app$common$geom$point$add$$($before_side_vector$jscomp$2_c1$jscomp$inline_5247_parent_points_before$jscomp$2$$,$after_vec_disp_end_end_after$jscomp$1_scale$jscomp$18$$)):
$APP.$app$common$geom$point$to_vec$$($APP.$app$common$geom$point$add$$($c0$jscomp$inline_5246_selrect$jscomp$16_start_after$jscomp$1$$,$_$jscomp$1202_disp_start_end_before$jscomp$1$$),$APP.$app$common$geom$point$add$$($after_side_vector$jscomp$2_c3$jscomp$inline_5248$$,$after_vec_disp_end_end_after$jscomp$1_scale$jscomp$18$$));$after_vec_disp_end_end_after$jscomp$1_scale$jscomp$18$$=$APP.$app$common$geom$point$length$$($after_vec_disp_end_end_after$jscomp$1_scale$jscomp$18$$)/Math.max(.01,$APP.$app$common$geom$point$length$$($before_vec_center$jscomp$26_child_points_before$jscomp$2_start_before$jscomp$1_transform_inverse$jscomp$10$$));
$child_points_after$jscomp$2_resize_origin$$=$APP.$app$common$geom$shapes$points$origin$$($child_points_after$jscomp$2_resize_origin$$);$before_vec_center$jscomp$26_child_points_before$jscomp$2_start_before$jscomp$1_transform_inverse$jscomp$10$$=$APP.$app$common$geom$shapes$common$points__GT_center$$($parent_points_after$jscomp$2_transform$jscomp$54$$);$c0$jscomp$inline_5246_selrect$jscomp$16_start_after$jscomp$1$$=$app$common$geom$shapes$transforms$calculate_selrect$$($parent_points_after$jscomp$2_transform$jscomp$54$$,
$before_vec_center$jscomp$26_child_points_before$jscomp$2_start_before$jscomp$1_transform_inverse$jscomp$10$$);$parent_points_after$jscomp$2_transform$jscomp$54$$=$app$common$geom$shapes$transforms$calculate_transform$$($parent_points_after$jscomp$2_transform$jscomp$54$$,$before_vec_center$jscomp$26_child_points_before$jscomp$2_start_before$jscomp$1_transform_inverse$jscomp$10$$,$c0$jscomp$inline_5246_selrect$jscomp$16_start_after$jscomp$1$$);$before_vec_center$jscomp$26_child_points_before$jscomp$2_start_before$jscomp$1_transform_inverse$jscomp$10$$=
$parent_points_after$jscomp$2_transform$jscomp$54$$!=null?$app$common$geom$matrix$inverse$$($parent_points_after$jscomp$2_transform$jscomp$54$$):null;$axis$jscomp$18_resize_vector$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$,$axis$jscomp$18_resize_vector$$)?$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($after_vec_disp_end_end_after$jscomp$1_scale$jscomp$18$$,1):$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,$after_vec_disp_end_end_after$jscomp$1_scale$jscomp$18$$);
return $APP.$app$common$types$modifiers$move$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$app$common$types$modifiers$empty$$(),$axis$jscomp$18_resize_vector$$,$child_points_after$jscomp$2_resize_origin$$,$parent_points_after$jscomp$2_transform$jscomp$54$$,$before_vec_center$jscomp$26_child_points_before$jscomp$2_start_before$jscomp$1_transform_inverse$jscomp$10$$),$_$jscomp$1202_disp_start_end_before$jscomp$1$$)});
$app$common$geom$shapes$constraints$constraint_modifier$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$1667$center$$,function($_$jscomp$1203_center_before$$,$after_side_vector$jscomp$3_axis$jscomp$19$$,$child_points_before$jscomp$3$$,$before_side_vector$jscomp$3_parent_points_before$jscomp$3$$,$center_after_child_points_after$jscomp$3$$,$parent_points_after$jscomp$3$$){$_$jscomp$1203_center_before$$=$app$common$geom$shapes$constraints$center_vector$$($after_side_vector$jscomp$3_axis$jscomp$19$$,
$child_points_before$jscomp$3$$,$before_side_vector$jscomp$3_parent_points_before$jscomp$3$$);$center_after_child_points_after$jscomp$3$$=$app$common$geom$shapes$constraints$center_vector$$($after_side_vector$jscomp$3_axis$jscomp$19$$,$center_after_child_points_after$jscomp$3$$,$parent_points_after$jscomp$3$$);$before_side_vector$jscomp$3_parent_points_before$jscomp$3$$=$app$common$geom$shapes$constraints$side_vector$$($after_side_vector$jscomp$3_axis$jscomp$19$$,$before_side_vector$jscomp$3_parent_points_before$jscomp$3$$);
$after_side_vector$jscomp$3_axis$jscomp$19$$=$app$common$geom$shapes$constraints$side_vector$$($after_side_vector$jscomp$3_axis$jscomp$19$$,$parent_points_after$jscomp$3$$);return $APP.$app$common$types$modifiers$move_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$geom$shapes$constraints$displacement$$($_$jscomp$1203_center_before$$,$center_after_child_points_after$jscomp$3$$,$before_side_vector$jscomp$3_parent_points_before$jscomp$3$$,$after_side_vector$jscomp$3_axis$jscomp$19$$))});
$app$common$geom$shapes$constraints$constraint_modifier$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function(){return $APP.$cljs$core$PersistentVector$EMPTY$$});
var $app$common$geom$shapes$constraints$const__GT_type_PLUS_axis$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1292$start$$,$APP.$cljs$cst$1562$top$$,$APP.$cljs$cst$1292$start$$,$APP.$cljs$cst$258$right$$,$APP.$cljs$cst$1293$end$$,$APP.$cljs$cst$1563$bottom$$,$APP.$cljs$cst$1293$end$$,$APP.$cljs$cst$1900$leftright$$,$APP.$cljs$cst$1671$fixed$$,$APP.$cljs$cst$1901$topbottom$$,$APP.$cljs$cst$1671$fixed$$,$APP.$cljs$cst$1667$center$$,$APP.$cljs$cst$1667$center$$,
$APP.$cljs$cst$1902$scale$$,$APP.$cljs$cst$1902$scale$$],null);$APP.$app$common$geom$shapes$bounds$get_object_bounds$$=function $app$common$geom$shapes$bounds$get_object_bounds$$($var_args$jscomp$968$$){switch(arguments.length){case 2:return $app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$112$$,$shape$jscomp$136$$){return $APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$112$$,$shape$jscomp$136$$,null)};
$APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$3$=function($children_bounds_objects$jscomp$113$$,$shape$jscomp$137$$,$ignore_shadow_margin_QMARK_$jscomp$4_map__48753__$1_p__48752$$){$ignore_shadow_margin_QMARK_$jscomp$4_map__48753__$1_p__48752$$=$APP.$cljs$core$__destructure_map$$($ignore_shadow_margin_QMARK_$jscomp$4_map__48753__$1_p__48752$$);var $base_bounds_filters$jscomp$4_ignore_margin_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($ignore_shadow_margin_QMARK_$jscomp$4_map__48753__$1_p__48752$$,
$APP.$cljs$cst$1911$ignore_margin_QMARK_$$,!0);$ignore_shadow_margin_QMARK_$jscomp$4_map__48753__$1_p__48752$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($ignore_shadow_margin_QMARK_$jscomp$4_map__48753__$1_p__48752$$,$APP.$cljs$cst$1912$ignore_shadow_margin_QMARK_$$,!1);$base_bounds_filters$jscomp$4_ignore_margin_QMARK_$jscomp$2$$=$app$common$geom$shapes$bounds$calculate_base_bounds$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$137$$,$base_bounds_filters$jscomp$4_ignore_margin_QMARK_$jscomp$2$$,
$ignore_shadow_margin_QMARK_$jscomp$4_map__48753__$1_p__48752$$);var $bounds$jscomp$7$$=$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$366_or__5025__auto____$1$jscomp$45$$=$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$137$$));if($or__5025__auto__$jscomp$366_or__5025__auto____$1$jscomp$45$$)return $or__5025__auto__$jscomp$366_or__5025__auto____$1$jscomp$45$$;$or__5025__auto__$jscomp$366_or__5025__auto____$1$jscomp$45$$=$APP.$cljs$cst$1609$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$137$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$366_or__5025__auto____$1$jscomp$45$$)?$or__5025__auto__$jscomp$366_or__5025__auto____$1$jscomp$45$$:$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$137$$)||$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$137$$)&&$APP.$cljs$core$not$$($APP.$cljs$cst$1876$show_content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$137$$))}())?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$base_bounds_filters$jscomp$4_ignore_margin_QMARK_$jscomp$2$$],null):$app$common$files$helpers$reduce_objects$cljs$0core$0IFn$0_invoke$0arity$05$$($children_bounds_objects$jscomp$113$$,function($shape__$1$jscomp$7$$){var $and__5023__auto__$jscomp$259_and__5023__auto____$1$jscomp$49_and__5023__auto____$2$jscomp$20_or__5025__auto__$jscomp$inline_5258$$=$APP.$cljs$core$not$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$7$$));return $and__5023__auto__$jscomp$259_and__5023__auto____$1$jscomp$49_and__5023__auto____$2$jscomp$20_or__5025__auto__$jscomp$inline_5258$$?
($and__5023__auto__$jscomp$259_and__5023__auto____$1$jscomp$49_and__5023__auto____$2$jscomp$20_or__5025__auto__$jscomp$inline_5258$$=$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$7$$)))?($and__5023__auto__$jscomp$259_and__5023__auto____$1$jscomp$49_and__5023__auto____$2$jscomp$20_or__5025__auto__$jscomp$inline_5258$$=($and__5023__auto__$jscomp$259_and__5023__auto____$1$jscomp$49_and__5023__auto____$2$jscomp$20_or__5025__auto__$jscomp$inline_5258$$=
!$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$7$$))?$and__5023__auto__$jscomp$259_and__5023__auto____$1$jscomp$49_and__5023__auto____$2$jscomp$20_or__5025__auto__$jscomp$inline_5258$$:$APP.$cljs$cst$1876$show_content$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$7$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$259_and__5023__auto____$1$jscomp$49_and__5023__auto____$2$jscomp$20_or__5025__auto__$jscomp$inline_5258$$)?!$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$7$$)||
$APP.$cljs$core$not$$($APP.$cljs$cst$1609$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$7$$)):$and__5023__auto__$jscomp$259_and__5023__auto____$1$jscomp$49_and__5023__auto____$2$jscomp$20_or__5025__auto__$jscomp$inline_5258$$):$and__5023__auto__$jscomp$259_and__5023__auto____$1$jscomp$49_and__5023__auto____$2$jscomp$20_or__5025__auto__$jscomp$inline_5258$$:$and__5023__auto__$jscomp$259_and__5023__auto____$1$jscomp$49_and__5023__auto____$2$jscomp$20_or__5025__auto__$jscomp$inline_5258$$},
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$137$$),function($result$jscomp$203$$,$child$jscomp$66$$){return $APP.$cljs$core$not$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$66$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$203$$,$app$common$geom$shapes$bounds$calculate_base_bounds$cljs$0core$0IFn$0_invoke$0arity$03$$($child$jscomp$66$$,!0,!1)):$result$jscomp$203$$},new $APP.$cljs$core$PersistentVector$$(null,1,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$base_bounds_filters$jscomp$4_ignore_margin_QMARK_$jscomp$2$$],null));$children_bounds_objects$jscomp$113$$=function(){var $G__48756$$=$APP.$app$common$geom$rect$join_rects$$($bounds$jscomp$7$$);if($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$137$$))return $G__48756$$;var $or__5025__auto__$jscomp$368$$=$APP.$cljs$cst$1913$children_bounds$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$137$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$368$$)?
$or__5025__auto__$jscomp$368$$:$G__48756$$}();$base_bounds_filters$jscomp$4_ignore_margin_QMARK_$jscomp$2$$=$app$common$geom$shapes$bounds$shape__GT_filters$$($shape$jscomp$137$$);var $blur_value$jscomp$3$$=function(){var $G__48757_or__5025__auto__$jscomp$369$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$137$$));switch($G__48757_or__5025__auto__$jscomp$369$$ instanceof $APP.$cljs$core$Keyword$$?$G__48757_or__5025__auto__$jscomp$369$$.$fqn$:
null){case "layer-blur":return $G__48757_or__5025__auto__$jscomp$369$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1653$blur$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$137$$)),$APP.$cljs$core$truth_$$($G__48757_or__5025__auto__$jscomp$369$$)?$G__48757_or__5025__auto__$jscomp$369$$:0;case "background-blur":return 0;default:return 0}}();return $app$common$geom$shapes$bounds$get_rect_filter_bounds$cljs$0core$0IFn$0_invoke$0arity$04$$($children_bounds_objects$jscomp$113$$,
$base_bounds_filters$jscomp$4_ignore_margin_QMARK_$jscomp$2$$,$blur_value$jscomp$3$$,$ignore_shadow_margin_QMARK_$jscomp$4_map__48753__$1_p__48752$$)};$APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$lang$maxFixedArity$=3;var $app$common$geom$shapes$transform_points$$;
$app$common$geom$shapes$transform_points$$=function(){var $app$common$geom$shapes$transform_points$$=null;$app$common$geom$shapes$transform_points$$=function($param49210$jscomp$1$$,$param49211$jscomp$1$$,$param49212$jscomp$1$$){switch(arguments.length){case 2:return $APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$02$$($param49210$jscomp$1$$,$param49211$jscomp$1$$);case 3:return $APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$03$$($param49210$jscomp$1$$,$param49211$jscomp$1$$,
$param49212$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$common$geom$shapes$transform_points$$.$cljs$core$IFn$_invoke$arity$2$=function($param49208$$,$param49209$$){return $APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$02$$($param49208$$,$param49209$$)};$app$common$geom$shapes$transform_points$$.$cljs$core$IFn$_invoke$arity$3$=function($param49210$$,$param49211$$,$param49212$$){return $APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$03$$($param49210$$,
$param49211$$,$param49212$$)};return $app$common$geom$shapes$transform_points$$}();
$APP.$app$common$geom$shapes$transform_matrix$$=function(){var $app$common$geom$shapes$transform_matrix$$=null;$app$common$geom$shapes$transform_matrix$$=function($param49221$jscomp$1$$,$param49222$jscomp$1$$,$param49223$jscomp$1$$){switch(arguments.length){case 1:return $APP.$app$common$geom$shapes$transforms$transform_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$($param49221$jscomp$1$$,null);case 2:return $APP.$app$common$geom$shapes$transforms$transform_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$($param49221$jscomp$1$$,$param49222$jscomp$1$$);
case 3:return $app$common$geom$shapes$transforms$transform_matrix$cljs$0core$0IFn$0_invoke$0arity$03$$($param49221$jscomp$1$$,$param49222$jscomp$1$$,$param49223$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$common$geom$shapes$transform_matrix$$.$cljs$core$IFn$_invoke$arity$1$=function($param49218$$){return $APP.$app$common$geom$shapes$transforms$transform_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$($param49218$$,null)};$app$common$geom$shapes$transform_matrix$$.$cljs$core$IFn$_invoke$arity$2$=
function($param49219$$,$param49220$$){return $APP.$app$common$geom$shapes$transforms$transform_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$($param49219$$,$param49220$$)};$app$common$geom$shapes$transform_matrix$$.$cljs$core$IFn$_invoke$arity$3$=function($param49221$$,$param49222$$,$param49223$$){return $app$common$geom$shapes$transforms$transform_matrix$cljs$0core$0IFn$0_invoke$0arity$03$$($param49221$$,$param49222$$,$param49223$$)};return $app$common$geom$shapes$transform_matrix$$}();
$APP.$app$common$geom$shapes$transform_str$$=function(){var $app$common$geom$shapes$transform_str$$=null;$app$common$geom$shapes$transform_str$$=function($param49229$jscomp$1$$,$param49230$jscomp$1$$){switch(arguments.length){case 1:return $app$common$geom$shapes$transforms$transform_str$cljs$0core$0IFn$0_invoke$0arity$02$$($param49229$jscomp$1$$,null);case 2:return $app$common$geom$shapes$transforms$transform_str$cljs$0core$0IFn$0_invoke$0arity$02$$($param49229$jscomp$1$$,$param49230$jscomp$1$$)}throw Error("Invalid arity: "+
arguments.length);};$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$=function($param49228$$){return $app$common$geom$shapes$transforms$transform_str$cljs$0core$0IFn$0_invoke$0arity$02$$($param49228$$,null)};$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$2$=function($param49229$$,$param49230$$){return $app$common$geom$shapes$transforms$transform_str$cljs$0core$0IFn$0_invoke$0arity$02$$($param49229$$,$param49230$$)};return $app$common$geom$shapes$transform_str$$}();
$APP.$app$common$geom$shapes$inverse_transform_matrix$$=function(){var $app$common$geom$shapes$inverse_transform_matrix$$=null;$app$common$geom$shapes$inverse_transform_matrix$$=function($param49234$jscomp$1$$,$param49235$jscomp$1$$,$param49236$jscomp$1$$){switch(arguments.length){case 1:return $app$common$geom$shapes$transforms$inverse_transform_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$($param49234$jscomp$1$$,null);case 2:return $app$common$geom$shapes$transforms$inverse_transform_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$($param49234$jscomp$1$$,
$param49235$jscomp$1$$);case 3:return $app$common$geom$shapes$transforms$inverse_transform_matrix$cljs$0core$0IFn$0_invoke$0arity$03$$($param49234$jscomp$1$$,$param49235$jscomp$1$$,$param49236$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$common$geom$shapes$inverse_transform_matrix$$.$cljs$core$IFn$_invoke$arity$1$=function($param49231$$){return $app$common$geom$shapes$transforms$inverse_transform_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$($param49231$$,null)};$app$common$geom$shapes$inverse_transform_matrix$$.$cljs$core$IFn$_invoke$arity$2$=
function($param49232$$,$param49233$$){return $app$common$geom$shapes$transforms$inverse_transform_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$($param49232$$,$param49233$$)};$app$common$geom$shapes$inverse_transform_matrix$$.$cljs$core$IFn$_invoke$arity$3$=function($param49234$$,$param49235$$,$param49236$$){return $app$common$geom$shapes$transforms$inverse_transform_matrix$cljs$0core$0IFn$0_invoke$0arity$03$$($param49234$$,$param49235$$,$param49236$$)};return $app$common$geom$shapes$inverse_transform_matrix$$}();
$APP.$app$common$geom$shapes$transform_shape$$=function(){function $app$common$geom$shapes$transform_shape__2$$($param49255$$,$param49256$$){return $app$common$geom$shapes$transforms$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($param49255$$,$param49256$$)}function $app$common$geom$shapes$transform_shape__1$$($param49254$$){return $app$common$geom$shapes$transforms$transform_shape$$.$cljs$core$IFn$_invoke$arity$1$($param49254$$)}var $app$common$geom$shapes$transform_shape$$=null;$app$common$geom$shapes$transform_shape$$=
function($param49255$jscomp$1$$,$param49256$jscomp$1$$){switch(arguments.length){case 1:return $app$common$geom$shapes$transform_shape__1$$.call(this,$param49255$jscomp$1$$);case 2:return $app$common$geom$shapes$transform_shape__2$$.call(this,$param49255$jscomp$1$$,$param49256$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$1$=$app$common$geom$shapes$transform_shape__1$$;$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$=
$app$common$geom$shapes$transform_shape__2$$;return $app$common$geom$shapes$transform_shape$$}();
$APP.$app$common$geom$shapes$apply_objects_modifiers$$=function(){var $app$common$geom$shapes$apply_objects_modifiers$$=null;$app$common$geom$shapes$apply_objects_modifiers$$=function($param49275$jscomp$1$$,$param49276$jscomp$1$$,$param49277$jscomp$1$$){switch(arguments.length){case 2:return $app$common$geom$shapes$transforms$apply_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$($param49275$jscomp$1$$,$param49276$jscomp$1$$,$APP.$cljs$core$keys$$($param49276$jscomp$1$$));case 3:return $app$common$geom$shapes$transforms$apply_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$($param49275$jscomp$1$$,
$param49276$jscomp$1$$,$param49277$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$common$geom$shapes$apply_objects_modifiers$$.$cljs$core$IFn$_invoke$arity$2$=function($param49273$$,$param49274$$){return $app$common$geom$shapes$transforms$apply_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$($param49273$$,$param49274$$,$APP.$cljs$core$keys$$($param49274$$))};$app$common$geom$shapes$apply_objects_modifiers$$.$cljs$core$IFn$_invoke$arity$3$=function($param49275$$,$param49276$$,
$param49277$$){return $app$common$geom$shapes$transforms$apply_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$($param49275$$,$param49276$$,$param49277$$)};return $app$common$geom$shapes$apply_objects_modifiers$$}();
$APP.$app$common$geom$shapes$center__GT_rect$$=function(){var $app$common$geom$shapes$center__GT_rect$$=null;$app$common$geom$shapes$center__GT_rect$$=function($param49328$jscomp$1$$,$param49329$jscomp$1$$,$param49330$jscomp$1$$){switch(arguments.length){case 2:return $APP.$app$common$geom$rect$center__GT_rect$cljs$0core$0IFn$0_invoke$0arity$03$$($param49328$jscomp$1$$,$param49329$jscomp$1$$,$param49329$jscomp$1$$);case 3:return $APP.$app$common$geom$rect$center__GT_rect$cljs$0core$0IFn$0_invoke$0arity$03$$($param49328$jscomp$1$$,
$param49329$jscomp$1$$,$param49330$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$common$geom$shapes$center__GT_rect$$.$cljs$core$IFn$_invoke$arity$2$=function($param49323$$,$param49324$$){return $APP.$app$common$geom$rect$center__GT_rect$cljs$0core$0IFn$0_invoke$0arity$03$$($param49323$$,$param49324$$,$param49324$$)};$app$common$geom$shapes$center__GT_rect$$.$cljs$core$IFn$_invoke$arity$3$=function($param49328$$,$param49329$$,$param49330$$){return $APP.$app$common$geom$rect$center__GT_rect$cljs$0core$0IFn$0_invoke$0arity$03$$($param49328$$,
$param49329$$,$param49330$$)};return $app$common$geom$shapes$center__GT_rect$$}();$APP.$app$main$data$helpers$lookup_file_data$$=function $app$main$data$helpers$lookup_file_data$$($var_args$jscomp$974$$){switch(arguments.length){case 1:return $app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$=function($state$jscomp$52$$){return $APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$52$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$52$$))};
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$=function($state$jscomp$53$$,$file_id$jscomp$2$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$53$$,$APP.$cljs$cst$1916$files$$),$file_id$jscomp$2$$),$APP.$cljs$cst$142$data$$)};$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$main$data$helpers$lookup_page$$=function $app$main$data$helpers$lookup_page$$($var_args$jscomp$975$$){switch(arguments.length){case 1:return $app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$=function($state$jscomp$54$$){var $file_id$jscomp$3$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$54$$),$page_id$jscomp$1$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$54$$);return $APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$54$$,$file_id$jscomp$3$$,$page_id$jscomp$1$$)};
$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$2$=function($state$jscomp$55$$,$page_id$jscomp$2$$){var $file_id$jscomp$4$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$55$$);return $APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$55$$,$file_id$jscomp$4$$,$page_id$jscomp$2$$)};
$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$3$=function($state$jscomp$56$$,$file_id$jscomp$5$$,$page_id$jscomp$3$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$56$$,$APP.$cljs$cst$1916$files$$),$file_id$jscomp$5$$),$APP.$cljs$cst$142$data$$),
$APP.$cljs$cst$1630$pages_index$$),$page_id$jscomp$3$$)};$APP.$app$main$data$helpers$lookup_page$$.$cljs$lang$maxFixedArity$=3;
$APP.$app$main$data$helpers$lookup_page_objects$$=function $app$main$data$helpers$lookup_page_objects$$($var_args$jscomp$976$$){switch(arguments.length){case 1:return $app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$=function($state$jscomp$57$$){return $APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$57$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$57$$),$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$57$$))};
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$=function($state$jscomp$58$$,$page_id$jscomp$4$$){return $APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$58$$,$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$58$$),$page_id$jscomp$4$$)};
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$=function($state$jscomp$59$$,$file_id$jscomp$6$$,$page_id$jscomp$5$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$59$$,$file_id$jscomp$6$$,$page_id$jscomp$5$$),$APP.$cljs$cst$1631$objects$$)};$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$lang$maxFixedArity$=3;var $shadow$js$shim$module$0ua_parser_js$$=shadow$bridge("ua-parser-js");var $app$common$types$grid$schema_COLON_grid_color$$,$app$common$types$grid$schema_COLON_column_params$$,$app$common$types$grid$schema_COLON_square_params$$,$app$common$types$grid$schema_COLON_grid$$,$app$common$types$grid$schema_COLON_default_grids$$,$app$common$types$grid$default_layout_params$$;
$app$common$types$grid$schema_COLON_grid_color$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"GridColor"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$app$common$types$color$schema_COLON_hex_color$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1734$opacity$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null)],null);
$app$common$types$grid$schema_COLON_column_params$$=new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ColumnGridParams"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$app$common$types$grid$schema_COLON_grid_color$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1667$center$$,null,$APP.$cljs$cst$258$right$$,null,$APP.$cljs$cst$1669$stretch$$,
null,$APP.$cljs$cst$257$left$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$874$size$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1929$margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1930$item_length$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1931$gutter$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$522$maybe$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null)],null)],null);
$app$common$types$grid$schema_COLON_square_params$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SquareGridParams"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$874$size$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$app$common$types$grid$schema_COLON_grid_color$$],null)],null);
$app$common$types$grid$schema_COLON_grid$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$531$multi$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,"Grid",$cljs$cst$532$dispatch$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$938$decode_SLASH_json$$,function($p1__48845_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__48845_SHARP_$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$core$keyword$$)}],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$216$column$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ColumnGridAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$216$column$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1932$display$$,$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,$app$common$types$grid$schema_COLON_column_params$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1656$row$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"RowGridAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$1656$row$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1932$display$$,$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,$app$common$types$grid$schema_COLON_column_params$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1933$square$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SquareGridAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$1933$square$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1932$display$$,$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,$app$common$types$grid$schema_COLON_square_params$$],null)],null)],null)],null);
$app$common$types$grid$schema_COLON_default_grids$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"PageGrid"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1933$square$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$grid$schema_COLON_square_params$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1656$row$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$grid$schema_COLON_column_params$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$216$column$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$grid$schema_COLON_column_params$$],
null)],null);$app$common$types$grid$default_layout_params$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$874$size$$,12,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1669$stretch$$,$APP.$cljs$cst$1930$item_length$$,null,$APP.$cljs$cst$1931$gutter$$,8,$APP.$cljs$cst$1929$margin$$,0,$APP.$cljs$cst$1298$color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,"#DE4762",$APP.$cljs$cst$1734$opacity$$,.1],null)],null);
$APP.$app$common$types$grid$default_grid_params$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1933$square$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$874$size$$,16,$APP.$cljs$cst$1298$color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,"#59B9E2",$APP.$cljs$cst$1734$opacity$$,.4],null)],null),$APP.$cljs$cst$216$column$$,$app$common$types$grid$default_layout_params$$,$APP.$cljs$cst$1656$row$$,$app$common$types$grid$default_layout_params$$],
null);$APP.$app$common$types$shape$blur$schema_COLON_blur$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Blur"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$499$enum$$,$APP.$cljs$cst$1908$layer_blur$$,$APP.$cljs$cst$1197$background_blur$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1620$hidden$$,$APP.$cljs$cst$421$boolean$$],null)],null);$APP.$app$common$types$shape$export$0$schema_COLON_export$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ShapeExport"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1534$png$$,null,$cljs$cst$1934$pdf$$,null,$APP.$cljs$cst$1536$webp$$,null,$APP.$cljs$cst$1538$svg$$,null,$APP.$cljs$cst$1535$jpeg$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1902$scale$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1371$suffix$$,$APP.$cljs$cst$198$string$$],null)],null);var $app$common$types$shape$interactions$action_types$$,$app$common$types$shape$interactions$overlay_positioning_types$$,$app$common$types$shape$interactions$easing_types$$,$app$common$types$shape$interactions$direction_types$$,$app$common$types$shape$interactions$schema_COLON_dissolve_animation$$,$app$common$types$shape$interactions$schema_COLON_slide_animation$$,$app$common$types$shape$interactions$schema_COLON_push_animation$$,$app$common$types$shape$interactions$schema_COLON_animation$$,$app$common$types$shape$interactions$schema_COLON_generic_interaction_attrs$$,
$app$common$types$shape$interactions$schema_COLON_navigate_interaction$$,$app$common$types$shape$interactions$schema_COLON_open_overlay_interaction$$,$app$common$types$shape$interactions$schema_COLON_toggle_overlay_interaction$$,$app$common$types$shape$interactions$schema_COLON_close_overlay_interaction$$,$app$common$types$shape$interactions$schema_COLON_prev_scren_interaction$$,$app$common$types$shape$interactions$schema_COLON_open_url_interaction$$;
$APP.$app$common$types$shape$interactions$event_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1935$after_delay$$,null,$APP.$cljs$cst$1936$mouse_leave$$,null,$cljs$cst$1937$mouse_over$$,null,$APP.$cljs$cst$1938$mouse_enter$$,null,$APP.$cljs$cst$1939$click$$,null,$cljs$cst$1940$mouse_press$$,null],null),null);
$app$common$types$shape$interactions$action_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1941$navigate$$,null,$APP.$cljs$cst$1942$close_overlay$$,null,$APP.$cljs$cst$1943$prev_screen$$,null,$APP.$cljs$cst$1944$toggle_overlay$$,null,$APP.$cljs$cst$1945$open_url$$,null,$APP.$cljs$cst$1946$open_overlay$$,null],null),null);
$app$common$types$shape$interactions$overlay_positioning_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1884$top_right$$,null,$APP.$cljs$cst$1883$top_left$$,null,$APP.$cljs$cst$1885$bottom_right$$,null,$APP.$cljs$cst$1667$center$$,null,$APP.$cljs$cst$1886$bottom_left$$,null,$APP.$cljs$cst$1673$manual$$,null,$APP.$cljs$cst$1947$top_center$$,null,$APP.$cljs$cst$1948$bottom_center$$,null],null),null);
$app$common$types$shape$interactions$easing_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1949$ease_in_out$$,null,$APP.$cljs$cst$1950$ease_in$$,null,$APP.$cljs$cst$1951$ease$$,null,$APP.$cljs$cst$287$linear$$,null,$APP.$cljs$cst$1952$ease_out$$,null],null),null);
$app$common$types$shape$interactions$direction_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1953$down$$,null,$APP.$cljs$cst$1954$up$$,null,$APP.$cljs$cst$258$right$$,null,$APP.$cljs$cst$257$left$$,null],null),null);
$app$common$types$shape$interactions$schema_COLON_dissolve_animation$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"AnimationDisolve"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1959$animation_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$1957$dissolve$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1960$duration$$,$cljs$cst$961$app_DOT_common_DOT_schema_SLASH_safe_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1961$easing$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,
$app$common$types$shape$interactions$easing_types$$],null)],null)],null);
$app$common$types$shape$interactions$schema_COLON_slide_animation$$=new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"AnimationSlide"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1959$animation_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$1958$slide$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1960$duration$$,$cljs$cst$961$app_DOT_common_DOT_schema_SLASH_safe_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1961$easing$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,
$app$common$types$shape$interactions$easing_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1962$way$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$1955$out$$,null,$APP.$cljs$cst$297$in$$,null],null),null)],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1963$direction$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$app$common$types$shape$interactions$direction_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1964$offset_effect$$,$APP.$cljs$cst$421$boolean$$],
null)],null);
$app$common$types$shape$interactions$schema_COLON_push_animation$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"PushAnimation"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1959$animation_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,
$APP.$cljs$cst$1956$push$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1960$duration$$,$cljs$cst$961$app_DOT_common_DOT_schema_SLASH_safe_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1961$easing$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,
$app$common$types$shape$interactions$easing_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1963$direction$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$app$common$types$shape$interactions$direction_types$$],null)],null)],null);
$app$common$types$shape$interactions$schema_COLON_animation$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$531$multi$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$532$dispatch$$,$APP.$cljs$cst$1959$animation_type$$,$APP.$cljs$cst$939$title$$,"Animation",$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$interactions$schema_COLON_dissolve_animation$$),
$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$interactions$schema_COLON_slide_animation$$),$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$interactions$schema_COLON_push_animation$$)])),$APP.$cljs$cst$938$decode_SLASH_json$$,function($p1__49007_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__49007_SHARP_$$,$APP.$cljs$cst$1959$animation_type$$,$APP.$cljs$core$keyword$$)}],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1957$dissolve$$,$app$common$types$shape$interactions$schema_COLON_dissolve_animation$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1958$slide$$,$app$common$types$shape$interactions$schema_COLON_slide_animation$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1956$push$$,$app$common$types$shape$interactions$schema_COLON_push_animation$$],null)],null);$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$1965$app_DOT_common_DOT_types_DOT_shape_DOT_interactions_SLASH_animation$$,$app$common$types$shape$interactions$schema_COLON_animation$$);$app$common$schema$check_fn$$($app$common$types$shape$interactions$schema_COLON_animation$$);
$app$common$types$shape$interactions$schema_COLON_generic_interaction_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,13,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"GenericInteractionAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1966$action_type$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$app$common$types$shape$interactions$action_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1557$event_type$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$interactions$event_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1967$destination$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1968$preserve_scroll$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$shape$interactions$schema_COLON_animation$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1970$overlay_position$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1518$app_DOT_common_DOT_geom_DOT_point_SLASH_point$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1971$overlay_pos_type$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$app$common$types$shape$interactions$overlay_positioning_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1972$close_click_outside$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1973$background_overlay$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1974$position_relative_to$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1975$url$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null)],null);
$app$common$types$shape$interactions$schema_COLON_navigate_interaction$$=new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"NavigateInteraction"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1966$action_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$1941$navigate$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1557$event_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$interactions$event_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1967$destination$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1968$preserve_scroll$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$shape$interactions$schema_COLON_animation$$],null)],null);
$app$common$types$shape$interactions$schema_COLON_open_overlay_interaction$$=new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"OpenOverlayInteraction"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1966$action_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$1946$open_overlay$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1557$event_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$interactions$event_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1970$overlay_position$$,$cljs$cst$1518$app_DOT_common_DOT_geom_DOT_point_SLASH_point$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1971$overlay_pos_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$app$common$types$shape$interactions$overlay_positioning_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1967$destination$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1972$close_click_outside$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1973$background_overlay$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$shape$interactions$schema_COLON_animation$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1974$position_relative_to$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,
$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],null);
$app$common$types$shape$interactions$schema_COLON_toggle_overlay_interaction$$=new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ToggleOverlayInteraction"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1966$action_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$1944$toggle_overlay$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1557$event_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$interactions$event_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1970$overlay_position$$,$cljs$cst$1518$app_DOT_common_DOT_geom_DOT_point_SLASH_point$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1971$overlay_pos_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$app$common$types$shape$interactions$overlay_positioning_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1967$destination$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1972$close_click_outside$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1973$background_overlay$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$shape$interactions$schema_COLON_animation$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1974$position_relative_to$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,
$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],null);
$app$common$types$shape$interactions$schema_COLON_close_overlay_interaction$$=new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"CloseOverlayInteraction"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1966$action_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$1942$close_overlay$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1557$event_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$interactions$event_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1967$destination$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1969$animation$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$app$common$types$shape$interactions$schema_COLON_animation$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1974$position_relative_to$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],
null);
$app$common$types$shape$interactions$schema_COLON_prev_scren_interaction$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"PrevScreenInteraction"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1966$action_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,
$APP.$cljs$cst$1943$prev_screen$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1557$event_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$interactions$event_types$$],null)],null)],null);
$app$common$types$shape$interactions$schema_COLON_open_url_interaction$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"OpenUrlInteraction"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1966$action_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$1945$open_url$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1557$event_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$interactions$event_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1975$url$$,$APP.$cljs$cst$198$string$$],null)],null);
$APP.$app$common$types$shape$interactions$schema_COLON_interaction$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$298$schema$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"Interaction",$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$one_of$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$interactions$schema_COLON_navigate_interaction$$),$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$interactions$schema_COLON_open_overlay_interaction$$),
$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$interactions$schema_COLON_close_overlay_interaction$$),$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$interactions$schema_COLON_toggle_overlay_interaction$$),$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$interactions$schema_COLON_prev_scren_interaction$$),$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$interactions$schema_COLON_open_url_interaction$$)]))],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$app$common$types$shape$interactions$schema_COLON_generic_interaction_attrs$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$531$multi$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$532$dispatch$$,$APP.$cljs$cst$1966$action_type$$,$APP.$cljs$cst$939$title$$,"InteractionAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1941$navigate$$,$app$common$types$shape$interactions$schema_COLON_navigate_interaction$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1946$open_overlay$$,$app$common$types$shape$interactions$schema_COLON_open_overlay_interaction$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1944$toggle_overlay$$,
$app$common$types$shape$interactions$schema_COLON_toggle_overlay_interaction$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1942$close_overlay$$,$app$common$types$shape$interactions$schema_COLON_close_overlay_interaction$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1943$prev_screen$$,$app$common$types$shape$interactions$schema_COLON_prev_scren_interaction$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1945$open_url$$,$app$common$types$shape$interactions$schema_COLON_open_url_interaction$$],null)],null)],null)],null);$app$common$schema$check_fn$$($APP.$app$common$types$shape$interactions$schema_COLON_interaction$$);
$APP.$app$common$types$shape$interactions$default_interaction$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1557$event_type$$,$APP.$cljs$cst$1939$click$$,$APP.$cljs$cst$1966$action_type$$,$APP.$cljs$cst$1941$navigate$$,$APP.$cljs$cst$1967$destination$$,null,$APP.$cljs$cst$1974$position_relative_to$$,null,$APP.$cljs$cst$1968$preserve_scroll$$,!1],null);var $app$common$types$shape$shadow$styles$$,$app$common$types$shape$shadow$schema_COLON_color$$,$app$common$types$shape$shadow$color_attrs$$;$app$common$types$shape$shadow$styles$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1905$drop_shadow$$,null,$cljs$cst$1907$inner_shadow$$,null],null),null);
$app$common$types$shape$shadow$schema_COLON_color$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$735$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ShadowColor"],null),$app$common$types$color$schema_COLON_color_attrs$$,$app$common$types$color$schema_COLON_plain_color$$],null);$app$common$types$shape$shadow$color_attrs$$=$app$common$schema$keys$$($app$common$types$shape$shadow$schema_COLON_color$$);
$APP.$app$common$types$shape$shadow$schema_COLON_shadow$$=new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Shadow"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,
$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1904$style$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$app$common$types$shape$shadow$styles$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1650$offset_x$$,
$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1651$offset_y$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1652$spread$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1620$hidden$$,$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$app$common$types$shape$shadow$schema_COLON_color$$],null)],null);$APP.$app$common$types$shape$shadow$check_shadow$$=$app$common$schema$check_fn$$($APP.$app$common$types$shape$shadow$schema_COLON_shadow$$);
$app$common$schema$validator$$($APP.$app$common$types$shape$shadow$schema_COLON_shadow$$);var $app$common$types$shape$text$schema_COLON_content$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,"root"],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$302$key$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$338$min$$,1,$cljs$cst$855$gen_SLASH_max$$,2,$cljs$cst$854$gen_SLASH_min$$,1],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,"paragraph-set"],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$302$key$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$338$min$$,1,$cljs$cst$855$gen_SLASH_max$$,2,$cljs$cst$854$gen_SLASH_min$$,1],null),new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,"paragraph"],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$302$key$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1634$fills$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$app$common$types$fills$schema_COLON_fills$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1758$font_family$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1760$font_size$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1762$font_style$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),
$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1761$font_weight$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1963$direction$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1768$text_decoration$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1769$text_transform$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1756$typography_ref_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1642$typography_ref_file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$338$min$$,1,$cljs$cst$855$gen_SLASH_max$$,2,$cljs$cst$854$gen_SLASH_min$$,1],null),new $APP.$cljs$core$PersistentVector$$(null,13,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$302$key$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1634$fills$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$app$common$types$fills$schema_COLON_fills$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1758$font_family$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1760$font_size$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1762$font_style$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1761$font_weight$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1963$direction$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),
$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1768$text_decoration$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1769$text_transform$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1756$typography_ref_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1642$typography_ref_file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],null)],null)],null)],null)],null)],null)],null)],null)],null)],null)],
null),$app$common$types$shape$text$valid_content_QMARK_$$=$app$common$schema$lazy_validator$$($app$common$types$shape$text$schema_COLON_content$$),$app$common$types$shape$text$schema_COLON_position_data$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,0,$cljs$cst$855$gen_SLASH_max$$,2],null),new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1511$y$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$,
$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1522$height$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1634$fills$$,$app$common$types$fills$schema_COLON_fills$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1758$font_family$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1760$font_size$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1762$font_style$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1761$font_weight$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1976$rtl$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1588$text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1768$text_decoration$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1769$text_transform$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],
null)],null)],null);var $app$common$types$token$composite_token_type__GT_dtcg_token_type$$,$app$common$types$token$composite_dtcg_token_type__GT_token_type$$,$app$common$types$token$token_types$$,$app$common$types$token$schema_COLON_token_ref$$,$app$common$types$token$schema_COLON_token_attrs$$,$app$common$types$token$schema_COLON_border_radius$$,$app$common$types$token$border_radius_keys$$,$app$common$types$token$color_keys$$,$app$common$types$token$schema_COLON_sizing_base$$,$app$common$types$token$schema_COLON_sizing_layout_item$$,
$app$common$types$token$sizing_layout_item_keys$$,$app$common$types$token$schema_COLON_sizing$$,$app$common$types$token$sizing_keys$$,$app$common$types$token$schema_COLON_spacing_gap$$,$app$common$types$token$schema_COLON_spacing_padding$$,$app$common$types$token$schema_COLON_spacing_gap_padding$$,$app$common$types$token$spacing_gap_padding_keys$$,$app$common$types$token$schema_COLON_spacing_margin$$,$app$common$types$token$schema_COLON_spacing$$,$app$common$types$token$spacing_keys$$,$app$common$types$token$schema_COLON_stroke_width$$,
$app$common$types$token$stroke_width_keys$$,$app$common$types$token$schema_COLON_dimensions$$,$app$common$types$token$dimensions_keys$$,$app$common$types$token$schema_COLON_font_family$$,$app$common$types$token$font_family_keys$$,$app$common$types$token$schema_COLON_font_size$$,$app$common$types$token$font_size_keys$$,$app$common$types$token$font_weight_keys$$,$app$common$types$token$schema_COLON_letter_spacing$$,$app$common$types$token$letter_spacing_keys$$,$app$common$types$token$schema_COLON_line_height$$,
$app$common$types$token$line_height_keys$$,$app$common$types$token$schema_COLON_rotation$$,$app$common$types$token$rotation_keys$$,$app$common$types$token$schema_COLON_number$$,$app$common$types$token$number_keys$$,$app$common$types$token$opacity_keys$$,$app$common$types$token$schema_COLON_shadow$$,$app$common$types$token$shadow_keys$$,$app$common$types$token$schema_COLON_text_case$$,$app$common$types$token$text_case_keys$$,$app$common$types$token$schema_COLON_text_decoration$$,$app$common$types$token$text_decoration_keys$$,
$app$common$types$token$typography_token_keys$$,$app$common$types$token$typography_keys$$,$app$common$types$token$axis_keys$$,$app$common$types$token$schema_COLON_applied_tokens$$,$app$common$types$token$generic_attributes$$,$app$common$types$token$rect_attributes$$,$app$common$types$token$frame_with_layout_attributes$$,$app$common$types$token$text_attributes$$,$app$common$types$token$attrs_in_text_content$$,$app$common$types$token$text_decoration_values$$,$app$common$types$token$font_weight_aliases$$,
$app$common$types$token$font_weight_values$$,$app$common$types$token$font_weight_map$$;
$APP.$app$common$types$token$token_type__GT_dtcg_token_type$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1977$sizing$$,$APP.$cljs$cst$1788$rotation$$,$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1978$number$$,$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1979$text_case$$,$cljs$cst$1349$other$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$1980$dimensions$$,$APP.$cljs$cst$1655$stroke_width$$,$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1981$typography$$,
$APP.$cljs$cst$1768$text_decoration$$,$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1982$border_radius$$,$APP.$cljs$cst$421$boolean$$,$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$1983$spacing$$],"sizing rotation color number fontSizes fontWeights textCase other string dimension borderWidth opacity typography textDecoration letterSpacing shadow borderRadius boolean fontFamilies spacing".split(" "));
$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$clojure$set$map_invert$$($APP.$app$common$types$token$token_type__GT_dtcg_token_type$$),"fontWeight",$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["fontSize",$APP.$cljs$cst$1760$font_size$$,"fontFamily",$APP.$cljs$cst$1758$font_family$$,"boxShadow",$APP.$cljs$cst$1654$shadow$$]));
$app$common$types$token$composite_token_type__GT_dtcg_token_type$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$types$token$token_type__GT_dtcg_token_type$$,$APP.$cljs$cst$1765$line_height$$,"lineHeights");
$app$common$types$token$composite_dtcg_token_type__GT_token_type$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$types$token$dtcg_token_type__GT_token_type$$,"lineHeights",$APP.$cljs$cst$1765$line_height$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["lineHeight",$APP.$cljs$cst$1765$line_height$$]));$app$common$types$token$token_types$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keys$$($APP.$app$common$types$token$token_type__GT_dtcg_token_type$$));
$APP.$app$common$types$token$token_name_validation_regex$$=/^[a-zA-Z0-9_-][a-zA-Z0-9$_-]*(\.[a-zA-Z0-9$_-]+)*$/;
$APP.$app$common$types$token$schema_COLON_token_name$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$512$re$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"TokenName",$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$text$$],null),$APP.$app$common$types$token$token_name_validation_regex$$],null);
$app$common$types$token$schema_COLON_token_ref$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$512$re$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"TokenRef",$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$text$$],null),/^\{[a-zA-Z0-9_-][a-zA-Z0-9$_-]*(\.[a-zA-Z0-9$_-]+)*\}$/],null);
$APP.$app$common$types$token$schema_COLON_token_node_name$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$512$re$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"TokenNodeName",$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$text$$],null),/^[a-zA-Z0-9_-][a-zA-Z0-9$_-]*(\.[a-zA-Z0-9$_-]+)*$/],null);
$app$common$types$token$schema_COLON_token_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Token"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$725$name$$,$APP.$app$common$types$token$schema_COLON_token_name$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$938$decode_SLASH_json$$,function($type$jscomp$343$$){return typeof $type$jscomp$343$$===
"string"?$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$343$$):(0,$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$)($type$jscomp$343$$):$type$jscomp$343$$}],null),$app$common$types$token$token_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,
$APP.$cljs$cst$974$app_DOT_common_DOT_schema_SLASH_any$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$936$description$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1737$modified_at$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null)],null);
$app$common$types$token$schema_COLON_border_radius$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"BorderRadiusTokenAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1646$r1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1647$r2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1648$r3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1649$r4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null);$app$common$types$token$border_radius_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_border_radius$$);
$app$common$types$token$color_keys$$=$app$common$types$token$schema_keys$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1403$fill$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1739$stroke_color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null));
$app$common$types$token$schema_COLON_sizing_base$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SizingBaseTokenAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1522$height$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null);
$app$common$types$token$schema_COLON_sizing_layout_item$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SizingLayoutItemTokenAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1707$layout_item_min_w$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1706$layout_item_max_w$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1705$layout_item_min_h$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1704$layout_item_max_h$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null);$app$common$types$token$sizing_layout_item_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_sizing_layout_item$$);
$app$common$types$token$schema_COLON_sizing$$=$malli$util$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$util$union$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$types$token$schema_COLON_sizing_base$$,$app$common$types$token$schema_COLON_sizing_layout_item$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$939$title$$,
"SizingTokenAttrs"]));$app$common$types$token$sizing_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_sizing$$);
$app$common$types$token$schema_COLON_spacing_gap$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SpacingGapTokenAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1681$row_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1682$column_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null);
$app$common$types$token$schema_COLON_spacing_padding$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SpacingPaddingTokenAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1093$p1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1091$p2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1687$p3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1688$p4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null);
$app$common$types$token$schema_COLON_spacing_gap_padding$$=$malli$util$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$util$union$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$types$token$schema_COLON_spacing_gap$$,$app$common$types$token$schema_COLON_spacing_padding$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$939$title$$,
"SpacingGapPaddingTokenAttrs"]));$app$common$types$token$spacing_gap_padding_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_spacing_gap_padding$$);
$app$common$types$token$schema_COLON_spacing_margin$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SpacingMarginTokenAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1700$m1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1701$m2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1702$m3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1703$m4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null);$APP.$app$common$types$token$spacing_margin_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_spacing_margin$$);
$app$common$types$token$schema_COLON_spacing$$=$malli$util$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$util$union$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$types$token$schema_COLON_spacing_gap$$,$app$common$types$token$schema_COLON_spacing_padding$$,$app$common$types$token$schema_COLON_spacing_margin$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$939$title$$,
"SpacingTokenAttrs"]));$app$common$types$token$spacing_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_spacing$$);
$app$common$types$token$schema_COLON_stroke_width$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1655$stroke_width$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null);
$app$common$types$token$stroke_width_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_stroke_width$$);
$app$common$types$token$schema_COLON_dimensions$$=$malli$util$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$util$union$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$types$token$schema_COLON_sizing$$,$app$common$types$token$schema_COLON_spacing$$,$app$common$types$token$schema_COLON_stroke_width$$,$app$common$types$token$schema_COLON_border_radius$$],null)),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$939$title$$,"DimensionsTokenAttrs"]));$app$common$types$token$dimensions_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_dimensions$$);
$app$common$types$token$schema_COLON_font_family$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1758$font_family$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null);
$app$common$types$token$font_family_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_font_family$$);
$app$common$types$token$schema_COLON_font_size$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"FontSizeTokenAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1760$font_size$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],
null)],null);$app$common$types$token$font_size_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_font_size$$);
$app$common$types$token$font_weight_keys$$=$app$common$types$token$schema_keys$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1761$font_weight$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null));
$app$common$types$token$schema_COLON_letter_spacing$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"LetterSpacingTokenAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1766$letter_spacing$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),
$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null);$app$common$types$token$letter_spacing_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_letter_spacing$$);
$app$common$types$token$schema_COLON_line_height$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"LineHeightTokenAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1765$line_height$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],
null)],null);$app$common$types$token$line_height_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_line_height$$);
$app$common$types$token$schema_COLON_rotation$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"RotationTokenAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1788$rotation$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],
null)],null);$app$common$types$token$rotation_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_rotation$$);
$app$common$types$token$schema_COLON_number$$=$malli$util$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($malli$util$union$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$common$types$token$schema_COLON_line_height$$,$app$common$types$token$schema_COLON_rotation$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$939$title$$,"NumberTokenAttrs"]));
$app$common$types$token$number_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_number$$);
$app$common$types$token$opacity_keys$$=$app$common$types$token$schema_keys$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"OpacityTokenAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1734$opacity$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null));
$app$common$types$token$schema_COLON_shadow$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ShadowTokenAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1654$shadow$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],
null)],null);$app$common$types$token$shadow_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_shadow$$);
$app$common$types$token$schema_COLON_text_case$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1979$text_case$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null);$app$common$types$token$text_case_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_text_case$$);
$app$common$types$token$schema_COLON_text_decoration$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1768$text_decoration$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null);
$app$common$types$token$text_decoration_keys$$=$app$common$types$token$schema_keys$$($app$common$types$token$schema_COLON_text_decoration$$);
$app$common$types$token$typography_token_keys$$=$app$common$types$token$schema_keys$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1981$typography$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null));
$app$common$types$token$typography_keys$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$variadic$($app$common$types$token$font_family_keys$$,$app$common$types$token$font_size_keys$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$types$token$font_weight_keys$$,$app$common$types$token$letter_spacing_keys$$,$app$common$types$token$line_height_keys$$,$app$common$types$token$text_case_keys$$,$app$common$types$token$text_decoration_keys$$,$app$common$types$token$typography_token_keys$$]));
$app$common$types$token$axis_keys$$=$app$common$types$token$schema_keys$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1511$y$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$token$schema_COLON_token_name$$],null)],null));
$APP.$app$common$types$token$all_keys$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$variadic$($app$common$types$token$axis_keys$$,$app$common$types$token$border_radius_keys$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$types$token$color_keys$$,$app$common$types$token$dimensions_keys$$,$app$common$types$token$number_keys$$,$app$common$types$token$opacity_keys$$,$app$common$types$token$rotation_keys$$,$app$common$types$token$shadow_keys$$,$app$common$types$token$sizing_keys$$,
$app$common$types$token$spacing_keys$$,$app$common$types$token$stroke_width_keys$$,$app$common$types$token$typography_keys$$,$app$common$types$token$typography_token_keys$$]));
$app$common$types$token$schema_COLON_applied_tokens$$=new $APP.$cljs$core$PersistentVector$$(null,15,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$735$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"AppliedTokens"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"GenericTokenAttrs"],null)],null),
$app$common$types$token$schema_COLON_border_radius$$,$app$common$types$token$schema_COLON_shadow$$,$app$common$types$token$schema_COLON_sizing$$,$app$common$types$token$schema_COLON_spacing$$,$app$common$types$token$schema_COLON_rotation$$,$app$common$types$token$schema_COLON_number$$,$app$common$types$token$schema_COLON_font_size$$,$app$common$types$token$schema_COLON_letter_spacing$$,$app$common$types$token$schema_COLON_font_family$$,$app$common$types$token$schema_COLON_text_case$$,$app$common$types$token$schema_COLON_text_decoration$$,
$app$common$types$token$schema_COLON_dimensions$$],null);
$APP.$app$common$types$token$shape_attr__GT_token_attrs$$=function $app$common$types$token$shape_attr__GT_token_attrs$$($var_args$jscomp$986$$){switch(arguments.length){case 1:return $app$common$types$token$shape_attr__GT_token_attrs$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$types$token$shape_attr__GT_token_attrs$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$types$token$shape_attr__GT_token_attrs$$.$cljs$core$IFn$_invoke$arity$1$=function($shape_attr$$){return $APP.$app$common$types$token$shape_attr__GT_token_attrs$$.$cljs$core$IFn$_invoke$arity$2$($shape_attr$$,null)};
$APP.$app$common$types$token$shape_attr__GT_token_attrs$$.$cljs$core$IFn$_invoke$arity$2$=function($shape_attr$jscomp$1$$,$changed_sub_attr$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1634$fills$$,$shape_attr$jscomp$1$$)?new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1403$fill$$,null],null),null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1636$strokes$$,$shape_attr$jscomp$1$$)&&
$changed_sub_attr$$==null?new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1739$stroke_color$$,null,$APP.$cljs$cst$1655$stroke_width$$,null],null),null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1636$strokes$$,$shape_attr$jscomp$1$$)?$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1739$stroke_color$$,null],
null),null),$changed_sub_attr$$))?new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1739$stroke_color$$,null],null),null):$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1655$stroke_width$$,null],null),null),$changed_sub_attr$$))?new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1655$stroke_width$$,
null],null),null):null:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1686$layout_padding$$,$shape_attr$jscomp$1$$)?$APP.$cljs$core$seq$$($changed_sub_attr$$)?$changed_sub_attr$$:new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1091$p2$$,null,$APP.$cljs$cst$1688$p4$$,null,$APP.$cljs$cst$1687$p3$$,null,$APP.$cljs$cst$1093$p1$$,null],null),null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1699$layout_item_margin$$,
$shape_attr$jscomp$1$$)?$APP.$cljs$core$seq$$($changed_sub_attr$$)?$changed_sub_attr$$:new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1702$m3$$,null,$APP.$cljs$cst$1703$m4$$,null,$APP.$cljs$cst$1701$m2$$,null,$APP.$cljs$cst$1700$m1$$,null],null),null):$APP.$cljs$core$truth_$$($app$common$types$token$font_size_keys$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$font_size_keys$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$1$$):
$app$common$types$token$font_size_keys$$($shape_attr$jscomp$1$$))?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_attr$jscomp$1$$,$APP.$cljs$cst$1981$typography$$]):$APP.$cljs$core$truth_$$($app$common$types$token$letter_spacing_keys$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$letter_spacing_keys$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$1$$):$app$common$types$token$letter_spacing_keys$$($shape_attr$jscomp$1$$))?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_attr$jscomp$1$$,
$APP.$cljs$cst$1981$typography$$]):$APP.$cljs$core$truth_$$($app$common$types$token$font_family_keys$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$font_family_keys$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$1$$):$app$common$types$token$font_family_keys$$($shape_attr$jscomp$1$$))?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_attr$jscomp$1$$,$APP.$cljs$cst$1981$typography$$]):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1765$line_height$$,
$shape_attr$jscomp$1$$)?new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1765$line_height$$,null,$APP.$cljs$cst$1981$typography$$,null],null),null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1769$text_transform$$,$shape_attr$jscomp$1$$)?new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1979$text_case$$,null,$APP.$cljs$cst$1981$typography$$,null],null),null):
$APP.$cljs$core$truth_$$($app$common$types$token$text_decoration_keys$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$text_decoration_keys$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$1$$):$app$common$types$token$text_decoration_keys$$($shape_attr$jscomp$1$$))?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_attr$jscomp$1$$,$APP.$cljs$cst$1981$typography$$]):$APP.$cljs$core$truth_$$($app$common$types$token$font_weight_keys$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$font_weight_keys$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$1$$):
$app$common$types$token$font_weight_keys$$($shape_attr$jscomp$1$$))?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_attr$jscomp$1$$,$APP.$cljs$cst$1981$typography$$]):$APP.$cljs$core$truth_$$($app$common$types$token$border_radius_keys$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$border_radius_keys$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$1$$):$app$common$types$token$border_radius_keys$$($shape_attr$jscomp$1$$))?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_attr$jscomp$1$$]):
$APP.$cljs$core$truth_$$($app$common$types$token$shadow_keys$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$shadow_keys$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$1$$):$app$common$types$token$shadow_keys$$($shape_attr$jscomp$1$$))?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_attr$jscomp$1$$]):$APP.$cljs$core$truth_$$($app$common$types$token$sizing_keys$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$sizing_keys$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$1$$):
$app$common$types$token$sizing_keys$$($shape_attr$jscomp$1$$))?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_attr$jscomp$1$$]):$APP.$cljs$core$truth_$$($app$common$types$token$opacity_keys$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$opacity_keys$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$1$$):$app$common$types$token$opacity_keys$$($shape_attr$jscomp$1$$))?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_attr$jscomp$1$$]):$APP.$cljs$core$truth_$$($app$common$types$token$spacing_keys$$.$cljs$core$IFn$_invoke$arity$1$?
$app$common$types$token$spacing_keys$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$1$$):$app$common$types$token$spacing_keys$$($shape_attr$jscomp$1$$))?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_attr$jscomp$1$$]):$APP.$cljs$core$truth_$$($app$common$types$token$rotation_keys$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$rotation_keys$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$1$$):$app$common$types$token$rotation_keys$$($shape_attr$jscomp$1$$))?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_attr$jscomp$1$$]):
$APP.$cljs$core$truth_$$($app$common$types$token$number_keys$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$number_keys$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$1$$):$app$common$types$token$number_keys$$($shape_attr$jscomp$1$$))?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_attr$jscomp$1$$]):$APP.$cljs$core$truth_$$($app$common$types$token$axis_keys$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$token$axis_keys$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$1$$):
$app$common$types$token$axis_keys$$($shape_attr$jscomp$1$$))?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_attr$jscomp$1$$]):null};$APP.$app$common$types$token$shape_attr__GT_token_attrs$$.$cljs$lang$maxFixedArity$=2;
$app$common$types$token$generic_attributes$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$variadic$($app$common$types$token$color_keys$$,$app$common$types$token$stroke_width_keys$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$types$token$rotation_keys$$,$app$common$types$token$sizing_keys$$,$app$common$types$token$opacity_keys$$,$app$common$types$token$shadow_keys$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,
[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1510$x$$,null],null),null)]));$app$common$types$token$rect_attributes$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$token$generic_attributes$$,$app$common$types$token$border_radius_keys$$);$app$common$types$token$frame_with_layout_attributes$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$token$rect_attributes$$,$app$common$types$token$spacing_gap_padding_keys$$);
$app$common$types$token$text_attributes$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$variadic$($app$common$types$token$generic_attributes$$,$app$common$types$token$typography_keys$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$types$token$number_keys$$]));
$app$common$types$token$attrs_in_text_content$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$token$typography_keys$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1403$fill$$,null],null),null));
$APP.$app$common$types$token$tokens_by_input$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1765$line_height$$,$APP.$cljs$cst$1984$min_width$$,$APP.$cljs$cst$1985$vertical_padding$$,$APP.$cljs$cst$1986$max_height$$,$APP.$cljs$cst$1788$rotation$$,$APP.$cljs$cst$1987$horizontal_margin$$,$cljs$cst$1988$min_height$$,$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$1739$stroke_color$$,$APP.$cljs$cst$1403$fill$$,$cljs$cst$1989$sided_paddings$$,$APP.$cljs$cst$290$width$$,
$APP.$cljs$cst$281$max_width$$,$APP.$cljs$cst$1682$column_gap$$,$APP.$cljs$cst$1990$vertical_margin$$,$APP.$cljs$cst$1991$horizontal_padding$$,$APP.$cljs$cst$1655$stroke_width$$,$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1981$typography$$,$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1982$border_radius$$,$cljs$cst$1992$sided_margins$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1681$row_gap$$],[new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1765$line_height$$,$APP.$cljs$cst$1978$number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1977$sizing$$,$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1983$spacing$$,$APP.$cljs$cst$1980$dimensions$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1977$sizing$$,$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1788$rotation$$,$APP.$cljs$cst$1978$number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1983$spacing$$,$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1977$sizing$$,$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1760$font_size$$],null),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$],null),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1983$spacing$$,$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1977$sizing$$,$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1977$sizing$$,$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1983$spacing$$,$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1983$spacing$$,$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1983$spacing$$,$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1655$stroke_width$$,$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1734$opacity$$],null),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1981$typography$$],null),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1766$letter_spacing$$],null),new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1982$border_radius$$,$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1983$spacing$$,$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1977$sizing$$,$APP.$cljs$cst$1980$dimensions$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1983$spacing$$,$APP.$cljs$cst$1980$dimensions$$],null)]);$app$common$types$token$text_decoration_values$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,["none",null,"strike-through",null,"underline",null],null),null);
$app$common$types$token$font_weight_aliases$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$("600 300 700 400 100 200 500 900 800 950".split(" "),[new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,7,["demi-bold",null,"halbfett",null,"demibold",null,"demi bold",null,"semibold",null,"semi bold",null,"semi-bold",null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["light",null,"leicht",null],null),null),
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["dreiviertelfett",null,"bold",null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,["book",null,"normal",null,"buch",null,"regular",null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["thin",null,"hairline",null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
7,["ultra light",null,"extralight",null,"extraleicht",null,"extra-light",null,"ultra-light",null,"ultralight",null,"extra light",null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,["kräftig",null,"medium",null,"kraeftig",null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,["heavy",null,"black",null,"extrafett",null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
7,["extrabold",null,"fett",null,"extra-bold",null,"ultrabold",null,"ultra-bold",null,"extra bold",null,"ultra bold",null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,["extra-black",null,"extra black",null,"ultra-black",null,"ultra black",null],null),null)]);$app$common$types$token$font_weight_values$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keys$$($app$common$types$token$font_weight_aliases$$));
$app$common$types$token$font_weight_map$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$95$$,$p__49123_vs$jscomp$6$$){var $k$jscomp$593$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49123_vs$jscomp$6$$,0,null);$p__49123_vs$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49123_vs$jscomp$6$$,1,null);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$95$$,$APP.$cljs$core$zipmap$$($p__49123_vs$jscomp$6$$,
$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$($k$jscomp$593$$)))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$app$common$types$token$font_weight_aliases$$);$APP.$app$common$path_names$split_path$$=function $app$common$path_names$split_path$$($var_args$jscomp$987$$){for(var $args__5755__auto__$jscomp$151$$=[],$len__5749__auto___49146$$=arguments.length,$i__5750__auto___49147$$=0;;)if($i__5750__auto___49147$$<$len__5749__auto___49146$$)$args__5755__auto__$jscomp$151$$.push(arguments[$i__5750__auto___49147$$]),$i__5750__auto___49147$$+=1;else break;return $app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args__5755__auto__$jscomp$151$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$151$$.slice(1),0,null):null)};
$APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$=function($path_str$jscomp$1$$,$map__49065__$1_p__49064_separator$jscomp$4$$){$map__49065__$1_p__49064_separator$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($map__49065__$1_p__49064_separator$jscomp$4$$);$map__49065__$1_p__49064_separator$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49065__$1_p__49064_separator$jscomp$4$$,$APP.$cljs$cst$1472$separator$$,"/");var $xf$jscomp$2$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$trim$$),
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$empty_QMARK_$$));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$xf$jscomp$2$$,$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($path_str$jscomp$1$$,$map__49065__$1_p__49064_separator$jscomp$4$$))};$APP.$app$common$path_names$split_path$$.$cljs$lang$maxFixedArity$=1;
$APP.$app$common$path_names$split_path$$.$cljs$lang$applyTo$=function($seq49059_seq49059__$1$$){var $G__49060$$=$APP.$cljs$core$first$$($seq49059_seq49059__$1$$);$seq49059_seq49059__$1$$=$APP.$cljs$core$next$$($seq49059_seq49059__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__49060$$,$seq49059_seq49059__$1$$)};var $app$common$types$variant$schema_COLON_variant_property$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$198$string$$],null)],null),
$app$common$types$variant$schema_COLON_variant_component$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2000$variant_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2001$variant_properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$app$common$types$variant$schema_COLON_variant_property$$],null)],null)],null),$app$common$types$variant$schema_COLON_variant_shape$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2000$variant_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2002$variant_name$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2003$variant_error$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null)],null),$app$common$types$variant$schema_COLON_variant_container$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2004$is_variant_container$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null)],null),$app$common$types$variant$property_regex$$,$app$common$types$variant$xf_COLON_map_name$$;$app$common$schema$check_fn$$($app$common$types$variant$schema_COLON_variant_component$$);$app$common$types$variant$property_regex$$=$APP.$cljs$core$re_pattern$$("Property (\\d+)");
$app$common$types$variant$xf_COLON_map_name$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$);
$APP.$app$common$types$variant$boolean_pairs$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["on","off"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["yes","no"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["true","false"],null)],null);var $app$common$types$shape$_STAR_shape_changes_STAR_$$=null,$app$common$types$shape$wasm_enabled_QMARK_$$=!1,$app$common$types$shape$wasm_create_shape$$=$APP.$cljs$core$constantly$$(null),$app$common$types$shape$stroke_caps_line$$,$app$common$types$shape$stroke_caps_marker$$,$app$common$types$shape$stroke_caps$$,$app$common$types$shape$shape_types$$,$app$common$types$shape$grow_types$$,$app$common$types$shape$schema_COLON_points$$,$app$common$types$shape$valid_stroke_attrs$$,$app$common$types$shape$schema_COLON_stroke_attrs$$;
$APP.$JSCompiler_prototypeAlias$$=$app$common$types$shape$Shape$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$app$common$types$shape$IShape$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this$$jscomp$637$$,$f__42602__auto__$jscomp$3$$,$init__42603__auto__$jscomp$3$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__42604__auto__$jscomp$3$$,$p__49350_v__42605__auto__$jscomp$3$$){var $key_49344$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49350_v__42605__auto__$jscomp$3$$,0,null);$p__49350_v__42605__auto__$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49350_v__42605__auto__$jscomp$3$$,
1,null);return $f__42602__auto__$jscomp$3$$.$cljs$core$IFn$_invoke$arity$3$?$f__42602__auto__$jscomp$3$$.$cljs$core$IFn$_invoke$arity$3$($ret__42604__auto__$jscomp$3$$,$key_49344$$,$p__49350_v__42605__auto__$jscomp$3$$):$f__42602__auto__$jscomp$3$$($ret__42604__auto__$jscomp$3$$,$key_49344$$,$p__49350_v__42605__auto__$jscomp$3$$)},$init__42603__auto__$jscomp$3$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$638$$,$other$jscomp$187$$){return this===$other$jscomp$187$$||$other$jscomp$187$$!=null&&this.constructor===$other$jscomp$187$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.id,$other$jscomp$187$$.id)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.name,$other$jscomp$187$$.name)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.type,$other$jscomp$187$$.type)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.x,$other$jscomp$187$$.x)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.y,$other$jscomp$187$$.y)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.width,$other$jscomp$187$$.width)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.height,$other$jscomp$187$$.height)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.rotation,$other$jscomp$187$$.rotation)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$selrect$,
$other$jscomp$187$$.$selrect$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.points,$other$jscomp$187$$.points)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.transform,$other$jscomp$187$$.transform)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$transform_inverse$,$other$jscomp$187$$.$transform_inverse$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$parent_id$,$other$jscomp$187$$.$parent_id$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$frame_id$,
$other$jscomp$187$$.$frame_id$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$flip_x$,$other$jscomp$187$$.$flip_x$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$flip_y$,$other$jscomp$187$$.$flip_y$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$$extmap$,$other$jscomp$187$$.$$extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__42526__auto__$jscomp$3_h__42526__auto____$1$jscomp$3$$=this.$$hash$;return $h__42526__auto__$jscomp$3_h__42526__auto____$1$jscomp$3$$!=null?$h__42526__auto__$jscomp$3_h__42526__auto____$1$jscomp$3$$:this.$$hash$=$h__42526__auto__$jscomp$3_h__42526__auto____$1$jscomp$3$$=-1623361444^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this$$jscomp$640$$,$val_49345$$){return $APP.$cljs$core$vector_QMARK_$$($val_49345$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($val_49345$$,0),$APP.$cljs$core$_nth$$($val_49345$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$val_49345$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 16+$APP.$cljs$core$count$$(this.$$extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$266$id$$,this.id,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$725$name$$,this.name,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$139$type$$,this.type,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1510$x$$,
this.x,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1511$y$$,this.y,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$290$width$$,this.width,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1522$height$$,this.height,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1788$rotation$$,this.rotation,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1605$selrect$$,this.$selrect$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1604$points$$,this.points,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1289$transform$$,
this.transform,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1787$transform_inverse$$,this.$transform_inverse$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1619$parent_id$$,this.$parent_id$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1607$frame_id$$,this.$frame_id$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1879$flip_x$$,this.$flip_x$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1880$flip_y$$,this.$flip_y$,null)],null),this.$$extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$$meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $app$common$types$shape$Shape$$(this.id,this.name,this.type,this.x,this.y,this.width,this.height,this.rotation,this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,this.$flip_y$,this.$$meta$,this.$$extmap$,this.$$hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$646$$,$writer__42713__auto__$jscomp$3$$,$opts__42714__auto__$jscomp$3$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__42713__auto__$jscomp$3$$,function($keyval__42716__auto__$jscomp$3$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__42713__auto__$jscomp$3$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__42714__auto__$jscomp$3$$,$keyval__42716__auto__$jscomp$3$$)},"#app.common.types.shape.Shape{",
", ","}",$opts__42714__auto__$jscomp$3$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,this.id],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,this.name],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,this.type],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,this.x],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1511$y$$,this.y],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$,this.width],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1522$height$$,this.height],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1788$rotation$$,this.rotation],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1605$selrect$$,this.$selrect$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1604$points$$,
this.points],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1289$transform$$,this.transform],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1787$transform_inverse$$,this.$transform_inverse$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$,this.$parent_id$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1607$frame_id$$,this.$frame_id$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1879$flip_x$$,this.$flip_x$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1880$flip_y$$,this.$flip_y$],null)],null),this.$$extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,16,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1788$rotation$$,$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1604$points$$,$APP.$cljs$cst$1289$transform$$,
$APP.$cljs$cst$1787$transform_inverse$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1879$flip_x$$,$APP.$cljs$cst$1880$flip_y$$],null),$APP.$cljs$core$truth_$$(this.$$extmap$)?$APP.$cljs$core$_iterator$$(this.$$extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ITransientAssociative$_assoc_BANG_$arity$3$=function($this$$jscomp$648$$,$key_49344$jscomp$1$$,$val_49345$jscomp$1$$){switch($key_49344$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$key_49344$jscomp$1$$.$fqn$:null){case "id":this.id=$val_49345$jscomp$1$$;break;case "name":this.name=$val_49345$jscomp$1$$;break;case "type":this.type=$val_49345$jscomp$1$$;break;case "x":this.x=$val_49345$jscomp$1$$;break;case "y":this.y=$val_49345$jscomp$1$$;break;case "width":this.width=
$val_49345$jscomp$1$$;break;case "height":this.height=$val_49345$jscomp$1$$;break;case "rotation":this.rotation=$val_49345$jscomp$1$$;break;case "selrect":this.$selrect$=$val_49345$jscomp$1$$;break;case "points":this.points=$val_49345$jscomp$1$$;break;case "transform":this.transform=$val_49345$jscomp$1$$;break;case "transform-inverse":this.$transform_inverse$=$val_49345$jscomp$1$$;break;case "parent-id":this.$parent_id$=$val_49345$jscomp$1$$;break;case "frame-id":this.$frame_id$=$val_49345$jscomp$1$$;
break;case "flip-x":this.$flip_x$=$val_49345$jscomp$1$$;break;case "flip-y":this.$flip_y$=$val_49345$jscomp$1$$;break;default:this.$$extmap$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$$extmap$,$key_49344$jscomp$1$$,$val_49345$jscomp$1$$)}return this};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this$$jscomp$649$$,$val_49345$jscomp$2$$){return new $app$common$types$shape$Shape$$(this.id,this.name,this.type,this.x,this.y,this.width,this.height,this.rotation,this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,this.$flip_y$,$val_49345$jscomp$2$$,this.$$extmap$,this.$$hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this$$jscomp$650$$,$key_49344$jscomp$2$$){switch($key_49344$jscomp$2$$ instanceof $APP.$cljs$core$Keyword$$?$key_49344$jscomp$2$$.$fqn$:null){case "id":case "name":case "type":case "x":case "y":case "width":case "height":case "rotation":case "selrect":case "points":case "transform":case "transform-inverse":case "parent-id":case "frame-id":case "flip-x":case "flip-y":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$$extmap$,
$key_49344$jscomp$2$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this$$jscomp$651$$,$key_49344$jscomp$3$$,$val_49345$jscomp$3$$){switch($key_49344$jscomp$3$$ instanceof $APP.$cljs$core$Keyword$$?$key_49344$jscomp$3$$.$fqn$:null){case "id":return new $app$common$types$shape$Shape$$($val_49345$jscomp$3$$,this.name,this.type,this.x,this.y,this.width,this.height,this.rotation,this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,
this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "name":return new $app$common$types$shape$Shape$$(this.id,$val_49345$jscomp$3$$,this.type,this.x,this.y,this.width,this.height,this.rotation,this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "type":return new $app$common$types$shape$Shape$$(this.id,this.name,$val_49345$jscomp$3$$,this.x,this.y,this.width,this.height,this.rotation,
this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "x":return new $app$common$types$shape$Shape$$(this.id,this.name,this.type,$val_49345$jscomp$3$$,this.y,this.width,this.height,this.rotation,this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "y":return new $app$common$types$shape$Shape$$(this.id,
this.name,this.type,this.x,$val_49345$jscomp$3$$,this.width,this.height,this.rotation,this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "width":return new $app$common$types$shape$Shape$$(this.id,this.name,this.type,this.x,this.y,$val_49345$jscomp$3$$,this.height,this.rotation,this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,
this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "height":return new $app$common$types$shape$Shape$$(this.id,this.name,this.type,this.x,this.y,this.width,$val_49345$jscomp$3$$,this.rotation,this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "rotation":return new $app$common$types$shape$Shape$$(this.id,this.name,this.type,this.x,this.y,this.width,this.height,$val_49345$jscomp$3$$,
this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "selrect":return new $app$common$types$shape$Shape$$(this.id,this.name,this.type,this.x,this.y,this.width,this.height,this.rotation,$val_49345$jscomp$3$$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "points":return new $app$common$types$shape$Shape$$(this.id,
this.name,this.type,this.x,this.y,this.width,this.height,this.rotation,this.$selrect$,$val_49345$jscomp$3$$,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "transform":return new $app$common$types$shape$Shape$$(this.id,this.name,this.type,this.x,this.y,this.width,this.height,this.rotation,this.$selrect$,this.points,$val_49345$jscomp$3$$,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,
this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "transform-inverse":return new $app$common$types$shape$Shape$$(this.id,this.name,this.type,this.x,this.y,this.width,this.height,this.rotation,this.$selrect$,this.points,this.transform,$val_49345$jscomp$3$$,this.$parent_id$,this.$frame_id$,this.$flip_x$,this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "parent-id":return new $app$common$types$shape$Shape$$(this.id,this.name,this.type,this.x,this.y,this.width,this.height,this.rotation,this.$selrect$,
this.points,this.transform,this.$transform_inverse$,$val_49345$jscomp$3$$,this.$frame_id$,this.$flip_x$,this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "frame-id":return new $app$common$types$shape$Shape$$(this.id,this.name,this.type,this.x,this.y,this.width,this.height,this.rotation,this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,$val_49345$jscomp$3$$,this.$flip_x$,this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "flip-x":return new $app$common$types$shape$Shape$$(this.id,
this.name,this.type,this.x,this.y,this.width,this.height,this.rotation,this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,$val_49345$jscomp$3$$,this.$flip_y$,this.$$meta$,this.$$extmap$,null);case "flip-y":return new $app$common$types$shape$Shape$$(this.id,this.name,this.type,this.x,this.y,this.width,this.height,this.rotation,this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,$val_49345$jscomp$3$$,
this.$$meta$,this.$$extmap$,null);default:return new $app$common$types$shape$Shape$$(this.id,this.name,this.type,this.x,this.y,this.width,this.height,this.rotation,this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,this.$flip_y$,this.$$meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$$extmap$,$key_49344$jscomp$3$$,$val_49345$jscomp$3$$),null)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($extmap1__42599__auto__$jscomp$3_this$$jscomp$652$$,$extmap2__42600__auto__$jscomp$3_key_49344$jscomp$4$$){switch($extmap2__42600__auto__$jscomp$3_key_49344$jscomp$4$$ instanceof $APP.$cljs$core$Keyword$$?$extmap2__42600__auto__$jscomp$3_key_49344$jscomp$4$$.$fqn$:null){case "id":case "name":case "type":case "x":case "y":case "width":case "height":case "rotation":case "selrect":case "points":case "transform":case "transform-inverse":case "parent-id":case "frame-id":case "flip-x":case "flip-y":return this.$cljs$core$IAssociative$_assoc$arity$3$(null,
$extmap2__42600__auto__$jscomp$3_key_49344$jscomp$4$$,null);default:return $extmap1__42599__auto__$jscomp$3_this$$jscomp$652$$=this.$$extmap$,$extmap2__42600__auto__$jscomp$3_key_49344$jscomp$4$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($extmap1__42599__auto__$jscomp$3_this$$jscomp$652$$,$extmap2__42600__auto__$jscomp$3_key_49344$jscomp$4$$),$extmap1__42599__auto__$jscomp$3_this$$jscomp$652$$===$extmap2__42600__auto__$jscomp$3_key_49344$jscomp$4$$?this:new $app$common$types$shape$Shape$$(this.id,
this.name,this.type,this.x,this.y,this.width,this.height,this.rotation,this.$selrect$,this.points,this.transform,this.$transform_inverse$,this.$parent_id$,this.$frame_id$,this.$flip_x$,this.$flip_y$,this.$$meta$,$APP.$cljs$core$not_empty$$($extmap2__42600__auto__$jscomp$3_key_49344$jscomp$4$$),null)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this$$jscomp$653$$,$k__42595__auto__$jscomp$3$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__42595__auto__$jscomp$3$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this$$jscomp$654$$,$key_49344$jscomp$5$$,$else__42596__auto__$jscomp$3$$){switch($key_49344$jscomp$5$$ instanceof $APP.$cljs$core$Keyword$$?$key_49344$jscomp$5$$.$fqn$:null){case "id":return this.id;case "name":return this.name;case "type":return this.type;case "x":return this.x;case "y":return this.y;case "width":return this.width;case "height":return this.height;case "rotation":return this.rotation;case "selrect":return this.$selrect$;
case "points":return this.points;case "transform":return this.transform;case "transform-inverse":return this.$transform_inverse$;case "parent-id":return this.$parent_id$;case "frame-id":return this.$frame_id$;case "flip-x":return this.$flip_x$;case "flip-y":return this.$flip_y$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$$extmap$,$key_49344$jscomp$5$$,$else__42596__auto__$jscomp$3$$)}};
$app$common$types$shape$stroke_caps_line$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2012$round$$,null,$APP.$cljs$cst$1933$square$$,null],null),null);
$app$common$types$shape$stroke_caps_marker$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2013$line_arrow$$,null,$APP.$cljs$cst$2014$diamond_marker$$,null,$APP.$cljs$cst$2015$triangle_arrow$$,null,$APP.$cljs$cst$2016$circle_marker$$,null,$APP.$cljs$cst$2017$square_marker$$,null],null),null);
$app$common$types$shape$stroke_caps$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$shape$stroke_caps_line$$,$app$common$types$shape$stroke_caps_marker$$),null);
$app$common$types$shape$shape_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,9,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$1608$group$$,null,$APP.$cljs$cst$1606$frame$$,null,$APP.$cljs$cst$1417$circle$$,null,$APP.$cljs$cst$1613$svg_raw$$,null,$APP.$cljs$cst$1612$image$$,null,$APP.$cljs$cst$1610$bool$$,null,$APP.$cljs$cst$1611$rect$$,null,$APP.$cljs$cst$1588$text$$,null],null),null);
$APP.$app$common$types$shape$blend_modes$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,16,[$APP.$cljs$cst$2018$hue$$,null,$APP.$cljs$cst$2019$screen$$,null,$APP.$cljs$cst$1298$color$$,null,$APP.$cljs$cst$2020$darken$$,null,$APP.$cljs$cst$2021$saturation$$,null,$APP.$cljs$cst$2022$lighten$$,null,$APP.$cljs$cst$2023$normal$$,null,$APP.$cljs$cst$2024$overlay$$,null,$APP.$cljs$cst$2025$difference$$,null,$APP.$cljs$cst$2026$luminosity$$,null,$APP.$cljs$cst$2027$exclusion$$,
null,$APP.$cljs$cst$2028$hard_light$$,null,$APP.$cljs$cst$2029$multiply$$,null,$APP.$cljs$cst$2030$soft_light$$,null,$APP.$cljs$cst$2031$color_dodge$$,null,$APP.$cljs$cst$2032$color_burn$$,null],null),null);
$APP.$app$common$types$shape$horizontal_constraint_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1902$scale$$,null,$APP.$cljs$cst$1667$center$$,null,$APP.$cljs$cst$258$right$$,null,$APP.$cljs$cst$1900$leftright$$,null,$APP.$cljs$cst$257$left$$,null],null),null);
$APP.$app$common$types$shape$vertical_constraint_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1563$bottom$$,null,$APP.$cljs$cst$1902$scale$$,null,$APP.$cljs$cst$1562$top$$,null,$APP.$cljs$cst$1667$center$$,null,$APP.$cljs$cst$1901$topbottom$$,null],null),null);
$APP.$app$common$types$shape$bool_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2033$exclude$$,null,$APP.$cljs$cst$2034$intersection$$,null,$APP.$cljs$cst$2025$difference$$,null,$APP.$cljs$cst$736$union$$,null],null),null);
$app$common$types$shape$grow_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2035$auto_height$$,null,$APP.$cljs$cst$1671$fixed$$,null,$APP.$cljs$cst$2036$auto_width$$,null],null),null);
$app$common$types$shape$schema_COLON_points$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$855$gen_SLASH_max$$,4,$cljs$cst$854$gen_SLASH_min$$,4],null),$cljs$cst$1518$app_DOT_common_DOT_geom_DOT_point_SLASH_point$$],null);
$app$common$types$shape$valid_stroke_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1635$stroke_image$$,null,$APP.$cljs$cst$1739$stroke_color$$,null,$APP.$cljs$cst$1741$stroke_color_gradient$$,null],null),null);
$app$common$types$shape$schema_COLON_stroke_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"StrokeAttrs",$cljs$cst$462$closed$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1641$stroke_color_ref_file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1742$stroke_color_ref_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1740$stroke_opacity$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1866$stroke_style$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2037$solid$$,null,$APP.$cljs$cst$2038$mixed$$,null,$APP.$cljs$cst$2039$dashed$$,null,$APP.$cljs$cst$2040$dotted$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1655$stroke_width$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1868$stroke_alignment$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1667$center$$,null,$APP.$cljs$cst$2041$inner$$,null,$APP.$cljs$cst$2042$outer$$,
null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1865$stroke_cap_start$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$app$common$types$shape$stroke_caps$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1869$stroke_cap_end$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$app$common$types$shape$stroke_caps$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1739$stroke_color$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$color$schema_COLON_hex_color$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1741$stroke_color_gradient$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$color$schema_COLON_gradient$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1635$stroke_image$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$types$color$schema_COLON_image$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1620$hidden$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null)],null);$app$common$schema$keys$$($app$common$types$shape$schema_COLON_stroke_attrs$$);
$APP.$app$common$types$shape$schema_COLON_stroke$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$app$common$types$shape$schema_COLON_stroke_attrs$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,function($attrs$jscomp$12_color$jscomp$20_result$jscomp$205$$){$attrs$jscomp$12_color$jscomp$20_result$jscomp$205$$=$APP.$cljs$core$set$$($APP.$cljs$core$keys$$($attrs$jscomp$12_color$jscomp$20_result$jscomp$205$$));
$attrs$jscomp$12_color$jscomp$20_result$jscomp$205$$=$APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$12_color$jscomp$20_result$jscomp$205$$,$app$common$types$shape$valid_stroke_attrs$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($attrs$jscomp$12_color$jscomp$20_result$jscomp$205$$))}],null)],null);$app$common$schema$check_fn$$($APP.$app$common$types$shape$schema_COLON_stroke$$);
var $app$common$types$shape$schema_COLON_shape_base_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ShapeMinimalRecord"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$app$common$types$shape$shape_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1605$selrect$$,$cljs$cst$1533$app_DOT_common_DOT_geom_DOT_rect_SLASH_rect$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1604$points$$,$app$common$types$shape$schema_COLON_points$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1289$transform$$,$cljs$cst$1603$app_DOT_common_DOT_geom_DOT_matrix_SLASH_matrix$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1787$transform_inverse$$,$cljs$cst$1603$app_DOT_common_DOT_geom_DOT_matrix_SLASH_matrix$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null)],null),$app$common$types$shape$schema_COLON_shape_geom_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ShapeGeometryAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1511$y$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1522$height$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],
null)],null),$app$common$types$shape$schema_COLON_shape_generic_attrs$$=$APP.$cljs$core$PersistentVector$fromArray$$([$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ShapeGenericAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1627$component_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1643$component_file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2044$component_root$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2045$main_instance$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2046$remote_synced$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2047$shape_ref$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$221$keyword$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1623$blocked$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2048$collapsed$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,
[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2049$locked$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1620$hidden$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1609$masked_group$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1634$fills$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$app$common$types$fills$schema_COLON_fills$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1807$proportion$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1808$proportion_lock$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1872$constraints_h$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$horizontal_constraint_types$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1871$constraints_v$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$vertical_constraint_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1645$fixed_scroll$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1646$r1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1647$r2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1648$r3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1649$r4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1734$opacity$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2050$grids$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,2],null),$app$common$types$grid$schema_COLON_grid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1870$exports$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,2],null),$APP.$app$common$types$shape$export$0$schema_COLON_export$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,2],null),$APP.$app$common$types$shape$schema_COLON_stroke$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1867$blend_mode$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$blend_modes$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2051$interactions$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,2],null),$APP.$app$common$types$shape$interactions$schema_COLON_interaction$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1654$shadow$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,1],null),$APP.$app$common$types$shape$shadow$schema_COLON_shadow$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$APP.$app$common$types$shape$blur$schema_COLON_blur$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1770$grow_type$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$app$common$types$shape$grow_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1873$applied_tokens$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$token$schema_COLON_applied_tokens$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1738$plugin_data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$plugins$schema_COLON_plugin_data$$],
null)],!0),$app$common$types$shape$schema_COLON_group_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"GroupAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1614$shapes$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$855$gen_SLASH_max$$,10,$cljs$cst$854$gen_SLASH_min$$,1],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],null),$app$common$types$shape$schema_COLON_frame_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"FrameAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1614$shapes$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$855$gen_SLASH_max$$,10,$cljs$cst$854$gen_SLASH_min$$,1],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1874$hide_fill_on_export$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1876$show_content$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1875$hide_in_viewer$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null)],null),$app$common$types$shape$schema_COLON_bool_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"BoolAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1614$shapes$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$855$gen_SLASH_max$$,10,$cljs$cst$854$gen_SLASH_min$$,1],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1888$bool_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$APP.$app$common$types$shape$bool_types$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$app$common$types$path$impl$schema_COLON_content$$],null)],null),$app$common$types$shape$schema_COLON_rect_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$939$title$$,"RectAttrs"],null)],null),$app$common$types$shape$schema_COLON_circle_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"CircleAttrs"],null)],null),$app$common$types$shape$schema_COLON_svg_raw_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SvgRawAttrs"],null)],null),$app$common$types$shape$schema_COLON_image_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ImageAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1633$metadata$$,new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$small_int$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$338$min$$,1]))],null),$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1522$height$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$small_int$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$338$min$$,1]))],null),$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1726$mtype$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$450$optional$$,!0,$cljs$cst$869$gen_SLASH_gen$$,$clojure$test$check$generators$elements$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["image/jpeg","image/png"],null))],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],null)],null),$app$common$types$shape$schema_COLON_path_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"PathAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1637$content$$,$app$common$types$path$impl$schema_COLON_content$$],null)],null),$app$common$types$shape$schema_COLON_text_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"TextAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1891$position_data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$app$common$types$shape$text$schema_COLON_position_data$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$522$maybe$$,$app$common$types$shape$text$schema_COLON_content$$],null)],null)],null),$app$common$types$shape$schema_COLON_shape_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$531$multi$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$532$dispatch$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$938$decode_SLASH_json$$,function($shape$jscomp$164$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$164$$,
$APP.$cljs$cst$139$type$$,$APP.$cljs$core$keyword$$)},$APP.$cljs$cst$939$title$$,"Shape"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1608$group$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$735$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"GroupShape"],null),$app$common$types$shape$layout$schema_COLON_layout_child_attrs$$,
$app$common$types$shape$schema_COLON_group_attrs$$,$app$common$types$shape$schema_COLON_shape_generic_attrs$$,$app$common$types$shape$schema_COLON_shape_geom_attrs$$,$app$common$types$shape$schema_COLON_shape_base_attrs$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1606$frame$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$735$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$939$title$$,"FrameShape"],null),$app$common$types$shape$layout$schema_COLON_layout_child_attrs$$,$app$common$types$shape$layout$schema_COLON_layout_attrs$$,$app$common$types$shape$schema_COLON_frame_attrs$$,$app$common$types$shape$schema_COLON_shape_generic_attrs$$,$app$common$types$shape$schema_COLON_shape_geom_attrs$$,$app$common$types$shape$schema_COLON_shape_base_attrs$$,$app$common$types$variant$schema_COLON_variant_shape$$,$app$common$types$variant$schema_COLON_variant_container$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1610$bool$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$735$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"BoolShape"],null),$app$common$types$shape$layout$schema_COLON_layout_child_attrs$$,$app$common$types$shape$schema_COLON_bool_attrs$$,$app$common$types$shape$schema_COLON_shape_generic_attrs$$,
$app$common$types$shape$schema_COLON_shape_base_attrs$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1611$rect$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$735$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"RectShape"],null),$app$common$types$shape$layout$schema_COLON_layout_child_attrs$$,$app$common$types$shape$schema_COLON_rect_attrs$$,
$app$common$types$shape$schema_COLON_shape_generic_attrs$$,$app$common$types$shape$schema_COLON_shape_geom_attrs$$,$app$common$types$shape$schema_COLON_shape_base_attrs$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1417$circle$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$735$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,
"CircleShape"],null),$app$common$types$shape$layout$schema_COLON_layout_child_attrs$$,$app$common$types$shape$schema_COLON_circle_attrs$$,$app$common$types$shape$schema_COLON_shape_generic_attrs$$,$app$common$types$shape$schema_COLON_shape_geom_attrs$$,$app$common$types$shape$schema_COLON_shape_base_attrs$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1612$image$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$735$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ImageShape"],null),$app$common$types$shape$layout$schema_COLON_layout_child_attrs$$,$app$common$types$shape$schema_COLON_image_attrs$$,$app$common$types$shape$schema_COLON_shape_generic_attrs$$,$app$common$types$shape$schema_COLON_shape_geom_attrs$$,$app$common$types$shape$schema_COLON_shape_base_attrs$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1613$svg_raw$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$735$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SvgRawShape"],null),$app$common$types$shape$layout$schema_COLON_layout_child_attrs$$,$app$common$types$shape$schema_COLON_svg_raw_attrs$$,$app$common$types$shape$schema_COLON_shape_generic_attrs$$,$app$common$types$shape$schema_COLON_shape_geom_attrs$$,$app$common$types$shape$schema_COLON_shape_base_attrs$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$296$path$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$735$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"PathShape"],null),$app$common$types$shape$layout$schema_COLON_layout_child_attrs$$,$app$common$types$shape$schema_COLON_path_attrs$$,$app$common$types$shape$schema_COLON_shape_generic_attrs$$,
$app$common$types$shape$schema_COLON_shape_base_attrs$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1588$text$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$735$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"TextShape"],null),$app$common$types$shape$layout$schema_COLON_layout_child_attrs$$,$app$common$types$shape$schema_COLON_text_attrs$$,
$app$common$types$shape$schema_COLON_shape_generic_attrs$$,$app$common$types$shape$schema_COLON_shape_geom_attrs$$,$app$common$types$shape$schema_COLON_shape_base_attrs$$],null)],null)],null),$app$common$types$shape$schema_COLON_shape$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,"Shape",$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$fmap$$($app$common$types$shape$create_shape$$,
$app$common$schema$generators$mcat$$(function($p__49421$$){var $map__49422__$1$$=$APP.$cljs$core$__destructure_map$$($p__49421$$),$type$jscomp$348$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49422__$1$$,$APP.$cljs$cst$139$type$$);return $clojure$test$check$generators$bind$$($app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$schema_COLON_shape_generic_attrs$$),function($attrs1$$){return $clojure$test$check$generators$bind$$($app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$schema_COLON_shape_geom_attrs$$),
function($attrs2$$){return $clojure$test$check$generators$bind$$(function(){var $G__49423__$1$$=$type$jscomp$348$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$348$$.$fqn$:null;switch($G__49423__$1$$){case "text":return $app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$schema_COLON_text_attrs$$);case "path":return $app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$schema_COLON_path_attrs$$);case "svg-raw":return $app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$schema_COLON_svg_raw_attrs$$);
case "image":return $app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$schema_COLON_image_attrs$$);case "circle":return $app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$schema_COLON_circle_attrs$$);case "rect":return $app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$schema_COLON_rect_attrs$$);case "bool":return $app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$schema_COLON_bool_attrs$$);
case "group":return $app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$schema_COLON_group_attrs$$);case "frame":return $app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$schema_COLON_frame_attrs$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__49423__$1$$)].join(""));}}(),function($attrs3_val__32629__auto__$jscomp$1$$){$attrs3_val__32629__auto__$jscomp$1$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$348$$,$APP.$cljs$cst$296$path$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$348$$,$APP.$cljs$cst$1610$bool$$)?$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs1$$,$map__49422__$1$$,$attrs3_val__32629__auto__$jscomp$1$$])):$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs1$$,
$map__49422__$1$$,$attrs2$$,$attrs3_val__32629__auto__$jscomp$1$$]));return $attrs3_val__32629__auto__$jscomp$1$$ instanceof $clojure$test$check$generators$Generator$$?$attrs3_val__32629__auto__$jscomp$1$$:$clojure$test$check$generators$return$0$$($attrs3_val__32629__auto__$jscomp$1$$)})})})},$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$shape$schema_COLON_shape_base_attrs$$))),$APP.$cljs$cst$938$decode_SLASH_json$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$382$leave$$,function($o$jscomp$250$$){return $APP.$cljs$core$map_QMARK_$$($o$jscomp$250$$)?$app$common$types$shape$create_shape$$($o$jscomp$250$$):$o$jscomp$250$$}],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$APP.$app$common$types$shape$shape_QMARK_$$],null),$app$common$types$shape$schema_COLON_shape_attrs$$],null),$app$common$types$shape$check_shape_generic_attrs$$=$app$common$schema$check_fn$$($app$common$types$shape$schema_COLON_shape_generic_attrs$$);
$app$common$schema$check_fn$$($app$common$types$shape$schema_COLON_shape_attrs$$);
var $app$common$types$shape$check_shape$$=$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$types$shape$schema_COLON_shape$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,"expected valid shape"])),$app$common$types$shape$allowed_shape_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,35,[$APP.$cljs$cst$1609$masked_group$$,null,$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$2048$collapsed$$,
null,$APP.$cljs$cst$1770$grow_type$$,null,$APP.$cljs$cst$2046$remote_synced$$,null,$APP.$cljs$cst$1867$blend_mode$$,null,$APP.$cljs$cst$1626$touched$$,null,$APP.$cljs$cst$1645$fixed_scroll$$,null,$APP.$cljs$cst$1647$r2$$,null,$APP.$cljs$cst$2044$component_root$$,null,$APP.$cljs$cst$2047$shape_ref$$,null,$APP.$cljs$cst$1738$plugin_data$$,null,$APP.$cljs$cst$1808$proportion_lock$$,null,$APP.$cljs$cst$2043$page_id$$,null,$APP.$cljs$cst$1870$exports$$,null,$APP.$cljs$cst$1648$r3$$,null,$APP.$cljs$cst$1871$constraints_v$$,
null,$APP.$cljs$cst$1653$blur$$,null,$APP.$cljs$cst$2051$interactions$$,null,$APP.$cljs$cst$1872$constraints_h$$,null,$APP.$cljs$cst$1646$r1$$,null,$APP.$cljs$cst$1620$hidden$$,null,$cljs$cst$2049$locked$$,null,$APP.$cljs$cst$1734$opacity$$,null,$APP.$cljs$cst$1873$applied_tokens$$,null,$APP.$cljs$cst$1627$component_id$$,null,$APP.$cljs$cst$1636$strokes$$,null,$APP.$cljs$cst$2045$main_instance$$,null,$APP.$cljs$cst$1623$blocked$$,null,$APP.$cljs$cst$1807$proportion$$,null,$APP.$cljs$cst$2050$grids$$,
null,$APP.$cljs$cst$1654$shadow$$,null,$APP.$cljs$cst$1649$r4$$,null,$APP.$cljs$cst$1634$fills$$,null,$APP.$cljs$cst$1643$component_file$$,null],null),null),$app$common$types$shape$allowed_shape_base_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,9,[$APP.$cljs$cst$1289$transform$$,null,$APP.$cljs$cst$725$name$$,null,$APP.$cljs$cst$139$type$$,null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1787$transform_inverse$$,null,$APP.$cljs$cst$266$id$$,
null,$APP.$cljs$cst$1619$parent_id$$,null,$APP.$cljs$cst$1607$frame_id$$,null,$APP.$cljs$cst$1605$selrect$$,null],null),null),$app$common$types$shape$allowed_bool_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1888$bool_type$$,null,$APP.$cljs$cst$1637$content$$,null,$APP.$cljs$cst$1614$shapes$$,null],null),null),$app$common$types$shape$allowed_group_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1614$shapes$$,null],null),null),$app$common$types$shape$allowed_frame_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,18,[$APP.$cljs$cst$1695$layout_grid_columns$$,null,$APP.$cljs$cst$1874$hide_fill_on_export$$,null,$APP.$cljs$cst$1683$layout_gap_type$$,null,$APP.$cljs$cst$1686$layout_padding$$,null,$APP.$cljs$cst$1684$layout_wrap_type$$,null,$APP.$cljs$cst$1615$layout$$,null,$APP.$cljs$cst$1875$hide_in_viewer$$,null,$APP.$cljs$cst$1692$layout_align_items$$,
null,$APP.$cljs$cst$1685$layout_padding_type$$,null,$APP.$cljs$cst$1876$show_content$$,null,$APP.$cljs$cst$1680$layout_gap$$,null,$APP.$cljs$cst$1689$layout_justify_content$$,null,$APP.$cljs$cst$1690$layout_justify_items$$,null,$APP.$cljs$cst$1679$layout_flex_dir$$,null,$APP.$cljs$cst$1691$layout_align_content$$,null,$APP.$cljs$cst$1694$layout_grid_rows$$,null,$APP.$cljs$cst$1693$layout_grid_dir$$,null,$APP.$cljs$cst$1614$shapes$$,null],null),null),$app$common$types$shape$allowed_image_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$1633$metadata$$,null],null),null),$app$common$types$shape$allowed_svg_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1637$content$$,null],null),null),$app$common$types$shape$allowed_path_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1637$content$$,null],null),null),$app$common$types$shape$allowed_text_attrs$$=
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1637$content$$,null],null),null),$app$common$types$shape$allowed_generic_attrs$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$variadic$($app$common$types$shape$allowed_shape_attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1522$height$$,
null],null),null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$types$shape$allowed_shape_base_attrs$$])),$app$common$types$shape$minimal_rect_attrs$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1611$rect$$,$APP.$cljs$cst$725$name$$,"Rectangle",$APP.$cljs$cst$1634$fills$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1746$fill_color$$,
"#B1B2B5",$APP.$cljs$cst$1747$fill_opacity$$,1],null)],null),$APP.$cljs$cst$1636$strokes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1646$r1$$,0,$APP.$cljs$cst$1647$r2$$,0,$APP.$cljs$cst$1648$r3$$,0,$APP.$cljs$cst$1649$r4$$,0],null),$app$common$types$shape$minimal_image_attrs$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1612$image$$,$APP.$cljs$cst$1646$r1$$,0,$APP.$cljs$cst$1647$r2$$,0,$APP.$cljs$cst$1648$r3$$,0,$APP.$cljs$cst$1649$r4$$,
0,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1636$strokes$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$app$common$types$shape$minimal_frame_attrs$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1874$hide_fill_on_export$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1636$strokes$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$cst$1614$shapes$$],
[!1,"Board",0,0,0,$APP.$app$common$uuid$zero$$,$APP.$cljs$core$PersistentVector$EMPTY$$,0,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1746$fill_color$$,"#FFFFFF",$APP.$cljs$cst$1747$fill_opacity$$,1],null)],null),$APP.$cljs$core$PersistentVector$EMPTY$$]),$app$common$types$shape$minimal_circle_attrs$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1417$circle$$,
$APP.$cljs$cst$725$name$$,"Ellipse",$APP.$cljs$cst$1634$fills$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1746$fill_color$$,"#B1B2B5",$APP.$cljs$cst$1747$fill_opacity$$,1],null)],null),$APP.$cljs$cst$1636$strokes$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$app$common$types$shape$minimal_group_attrs$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$1608$group$$,$APP.$cljs$cst$725$name$$,"Group",$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1636$strokes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$app$common$types$shape$minimal_bool_attrs$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1610$bool$$,$APP.$cljs$cst$725$name$$,"Bool",$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$cst$1636$strokes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$app$common$types$shape$minimal_text_attrs$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$725$name$$,"Text"],null),$app$common$types$shape$minimal_path_attrs$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$725$name$$,
"Path",$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1636$strokes$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1866$stroke_style$$,$APP.$cljs$cst$2037$solid$$,$APP.$cljs$cst$1868$stroke_alignment$$,$APP.$cljs$cst$2041$inner$$,$APP.$cljs$cst$1655$stroke_width$$,2,$APP.$cljs$cst$1739$stroke_color$$,"#000000",$APP.$cljs$cst$1740$stroke_opacity$$,1],
null)],null)],null),$app$common$types$shape$minimal_svg_raw_attrs$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1613$svg_raw$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1636$strokes$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$app$common$types$shape$minimal_multiple_attrs$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1616$multiple$$],null);
$APP.$app$common$transit$add_handlers_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"shape",$APP.$cljs$cst$1291$class$$,$app$common$types$shape$Shape$$,$APP.$cljs$cst$1314$wfn$$,function($p1__49472_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$p1__49472_SHARP_$$)},$APP.$cljs$cst$1315$rfn$$,
$app$common$types$shape$create_shape$$],null)]));
var $app$common$types$shape$basic_extract_props$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,21,[$APP.$cljs$cst$1711$layout_item_absolute$$,null,$APP.$cljs$cst$1698$layout_item_margin_type$$,null,$APP.$cljs$cst$1647$r2$$,null,$APP.$cljs$cst$1706$layout_item_max_w$$,null,$APP.$cljs$cst$1708$layout_item_h_sizing$$,null,$APP.$cljs$cst$1709$layout_item_v_sizing$$,null,$APP.$cljs$cst$1648$r3$$,null,$APP.$cljs$cst$1871$constraints_v$$,null,$APP.$cljs$cst$1653$blur$$,
null,$APP.$cljs$cst$1872$constraints_h$$,null,$APP.$cljs$cst$1646$r1$$,null,$APP.$cljs$cst$1734$opacity$$,null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1636$strokes$$,null,$APP.$cljs$cst$1654$shadow$$,null,$APP.$cljs$cst$1649$r4$$,null,$APP.$cljs$cst$1699$layout_item_margin$$,null,$APP.$cljs$cst$1634$fills$$,null,$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null,$APP.$cljs$cst$1712$layout_item_z_index$$,null],null),null);var $app$common$types$page$schema_COLON_flow$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Flow"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2053$starting_frame$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),$app$common$types$page$schema_COLON_guide$$=new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,
"Guide"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2054$axis$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1510$x$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1607$frame_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,
[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$522$maybe$$,$app$common$types$color$schema_COLON_hex_color$$],null)],null)],null),$app$common$types$page$schema_COLON_objects$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,5],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$,$app$common$types$shape$schema_COLON_shape$$],null),$app$common$types$page$schema_COLON_page$$=
new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"FilePage"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,
$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1795$index$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$objects$$,$app$common$types$page$schema_COLON_objects$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2055$default_grids$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$grid$schema_COLON_default_grids$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2056$flows$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,2],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$,$app$common$types$page$schema_COLON_flow$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2057$guides$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,2],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$,$app$common$types$page$schema_COLON_guide$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1738$plugin_data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$plugins$schema_COLON_plugin_data$$],null),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2058$background$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$color$schema_COLON_hex_color$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2059$pixel_grid_color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$color$schema_COLON_hex_color$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2060$pixel_grid_opacity$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2061$comment_thread_positions$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"CommentThreadPosition"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,$cljs$cst$1518$app_DOT_common_DOT_geom_DOT_point_SLASH_point$$],null)],null)],null)],null)],null);$app$common$schema$check_fn$$($app$common$types$page$schema_COLON_page$$);
var $app$common$types$page$empty_page_data$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1631$objects$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$APP.$app$common$uuid$zero$$,$APP.$app$common$types$shape$setup_shape$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$zero$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$app$common$uuid$zero$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$app$common$uuid$zero$$,
$APP.$cljs$cst$725$name$$,"Root Frame"],null))])],null);var $app$common$types$component$sync_attrs$$,$app$common$types$component$xf_COLON_normal_touched$$,$app$common$types$component$extract_ids$$;
$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$735$merge$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1737$modified_at$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$objects$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$855$gen_SLASH_max$$,10,$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$page$schema_COLON_objects$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2062$main_instance_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2063$main_instance_page$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1738$plugin_data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$plugins$schema_COLON_plugin_data$$],null)],null),$app$common$types$variant$schema_COLON_variant_component$$],
null));
$app$common$types$component$sync_attrs$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1695$layout_grid_columns$$,$APP.$cljs$cst$1765$line_height$$,$APP.$cljs$cst$1762$font_style$$,$APP.$cljs$cst$1874$hide_fill_on_export$$,$APP.$cljs$cst$1746$fill_color$$,$APP.$cljs$cst$1711$layout_item_absolute$$,$APP.$cljs$cst$1609$masked_group$$,$APP.$cljs$cst$1683$layout_gap_type$$,$APP.$cljs$cst$1686$layout_padding$$,$APP.$cljs$cst$1289$transform$$,$APP.$cljs$cst$1788$rotation$$,$APP.$cljs$cst$1763$text_align$$,
$APP.$cljs$cst$1684$layout_wrap_type$$,$APP.$cljs$cst$1888$bool_type$$,$APP.$cljs$cst$1770$grow_type$$,$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1615$layout$$,$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$1867$blend_mode$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$1692$layout_align_items$$,$APP.$cljs$cst$1698$layout_item_margin_type$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$1685$layout_padding_type$$,$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$1604$points$$,$APP.$cljs$cst$1645$fixed_scroll$$,$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1706$layout_item_max_w$$,$APP.$cljs$cst$1876$show_content$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$,$APP.$cljs$cst$1808$proportion_lock$$,$APP.$cljs$cst$1680$layout_gap$$,$APP.$cljs$cst$1787$transform_inverse$$,$APP.$cljs$cst$1870$exports$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1689$layout_justify_content$$,$APP.$cljs$cst$1871$constraints_v$$,$APP.$cljs$cst$1653$blur$$,
$APP.$cljs$cst$1655$stroke_width$$,$APP.$cljs$cst$1872$constraints_h$$,$APP.$cljs$cst$1646$r1$$,$APP.$cljs$cst$1620$hidden$$,$cljs$cst$2049$locked$$,$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1707$layout_item_min_w$$,$APP.$cljs$cst$1690$layout_justify_items$$,$APP.$cljs$cst$1679$layout_flex_dir$$,$APP.$cljs$cst$1691$layout_align_content$$,$APP.$cljs$cst$1891$position_data$$,$APP.$cljs$cst$1636$strokes$$,$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1623$blocked$$,$APP.$cljs$cst$1807$proportion$$,
$APP.$cljs$cst$2050$grids$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1649$r4$$,$APP.$cljs$cst$1694$layout_grid_rows$$,$APP.$cljs$cst$1699$layout_item_margin$$,$APP.$cljs$cst$1710$layout_item_align_self$$,$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$cst$1705$layout_item_min_h$$,$cljs$cst$2064$bool_content$$,$APP.$cljs$cst$1704$layout_item_max_h$$,$APP.$cljs$cst$1693$layout_grid_dir$$,$APP.$cljs$cst$1747$fill_opacity$$,$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$1522$height$$,
$APP.$cljs$cst$1712$layout_item_z_index$$],[$cljs$cst$2065$geometry_group$$,$APP.$cljs$cst$1695$layout_grid_columns$$,$cljs$cst$2066$text_display_group$$,$cljs$cst$2067$text_font_group$$,$cljs$cst$2068$fill_group$$,$cljs$cst$2068$fill_group$$,$APP.$cljs$cst$1711$layout_item_absolute$$,$cljs$cst$2069$mask_group$$,$APP.$cljs$cst$1680$layout_gap$$,$APP.$cljs$cst$1686$layout_padding$$,$cljs$cst$2065$geometry_group$$,$cljs$cst$2065$geometry_group$$,$cljs$cst$2066$text_display_group$$,$APP.$cljs$cst$1684$layout_wrap_type$$,
$cljs$cst$2070$content_group$$,$cljs$cst$2067$text_font_group$$,$cljs$cst$2067$text_font_group$$,$cljs$cst$2067$text_font_group$$,$APP.$cljs$cst$2071$layout_container$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$296$path$$,$cljs$cst$2065$geometry_group$$,$APP.$cljs$cst$1588$text$$,$cljs$cst$2070$content_group$$],null),$cljs$cst$2072$layer_effects_group$$,$APP.$cljs$cst$2073$name_group$$,$APP.$cljs$cst$1692$layout_align_items$$,$APP.$cljs$cst$1699$layout_item_margin$$,$cljs$cst$2065$geometry_group$$,
$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$1686$layout_padding$$,$cljs$cst$2065$geometry_group$$,$cljs$cst$2065$geometry_group$$,$cljs$cst$2074$constraints_group$$,$cljs$cst$2075$radius_group$$,$APP.$cljs$cst$1706$layout_item_max_w$$,$APP.$cljs$cst$1876$show_content$$,$APP.$cljs$cst$1708$layout_item_h_sizing$$,$cljs$cst$2065$geometry_group$$,$APP.$cljs$cst$1680$layout_gap$$,$cljs$cst$2065$geometry_group$$,$cljs$cst$2076$exports_group$$,$APP.$cljs$cst$1709$layout_item_v_sizing$$,$cljs$cst$2075$radius_group$$,
$APP.$cljs$cst$1689$layout_justify_content$$,$cljs$cst$2074$constraints_group$$,$cljs$cst$2077$blur_group$$,$cljs$cst$2078$stroke_group$$,$cljs$cst$2074$constraints_group$$,$cljs$cst$2075$radius_group$$,$cljs$cst$2079$visibility_group$$,$cljs$cst$2065$geometry_group$$,$cljs$cst$2072$layer_effects_group$$,$APP.$cljs$cst$1707$layout_item_min_w$$,$APP.$cljs$cst$1690$layout_justify_items$$,$APP.$cljs$cst$1679$layout_flex_dir$$,$APP.$cljs$cst$1691$layout_align_content$$,$cljs$cst$2070$content_group$$,
$cljs$cst$2078$stroke_group$$,$cljs$cst$2066$text_display_group$$,$cljs$cst$2065$geometry_group$$,$cljs$cst$2080$modifiable_group$$,$cljs$cst$2065$geometry_group$$,$cljs$cst$2081$grids_group$$,$cljs$cst$2082$shadow_group$$,$cljs$cst$2075$radius_group$$,$APP.$cljs$cst$1694$layout_grid_rows$$,$APP.$cljs$cst$1699$layout_item_margin$$,$APP.$cljs$cst$1710$layout_item_align_self$$,$cljs$cst$2065$geometry_group$$,$cljs$cst$2068$fill_group$$,$APP.$cljs$cst$1705$layout_item_min_h$$,$cljs$cst$2070$content_group$$,
$APP.$cljs$cst$1704$layout_item_max_h$$,$APP.$cljs$cst$1693$layout_grid_dir$$,$cljs$cst$2068$fill_group$$,$cljs$cst$2067$text_font_group$$,$cljs$cst$2065$geometry_group$$,$APP.$cljs$cst$1712$layout_item_z_index$$]);
$APP.$app$common$types$component$swap_keep_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,12,[$APP.$cljs$cst$1711$layout_item_absolute$$,null,$APP.$cljs$cst$1698$layout_item_margin_type$$,null,$APP.$cljs$cst$1706$layout_item_max_w$$,null,$APP.$cljs$cst$1708$layout_item_h_sizing$$,null,$APP.$cljs$cst$1709$layout_item_v_sizing$$,null,$APP.$cljs$cst$2051$interactions$$,null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1699$layout_item_margin$$,
null,$APP.$cljs$cst$1710$layout_item_align_self$$,null,$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null,$APP.$cljs$cst$1712$layout_item_z_index$$,null],null),null);$app$common$types$component$xf_COLON_normal_touched$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($app$common$types$component$swap_slot_QMARK_$$);
$app$common$types$component$extract_ids$$=function $app$common$types$component$extract_ids$$($child_ids_shape$jscomp$207$$){if($APP.$cljs$core$map_QMARK_$$($child_ids_shape$jscomp$207$$)){var $current_id$jscomp$3$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_ids_shape$jscomp$207$$);$child_ids_shape$jscomp$207$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$types$component$extract_ids$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($child_ids_shape$jscomp$207$$)]));
return $APP.$cljs$core$cons$$($current_id$jscomp$3$$,$child_ids_shape$jscomp$207$$)}return $APP.$cljs$core$PersistentVector$EMPTY$$};
$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$99$$,$_$jscomp$1209$$,$v$jscomp$528$$){return $APP.$cljs$core$map_QMARK_$$($v$jscomp$528$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$99$$,$APP.$cljs$core$vals$$($v$jscomp$528$$)):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$99$$,$v$jscomp$528$$)},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$app$common$types$component$sync_attrs$$);var $app$common$types$shape_tree$delete_shape$$=function $app$common$types$shape_tree$delete_shape$$($var_args$jscomp$992$$){switch(arguments.length){case 2:return $app$common$types$shape_tree$delete_shape$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$common$types$shape_tree$delete_shape$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$app$common$types$shape_tree$delete_shape$$.$cljs$core$IFn$_invoke$arity$2$=function($container$jscomp$5$$,$shape_id$jscomp$20$$){return $app$common$types$shape_tree$delete_shape$$.$cljs$core$IFn$_invoke$arity$3$($container$jscomp$5$$,$shape_id$jscomp$20$$,!1)};
$app$common$types$shape_tree$delete_shape$$.$cljs$core$IFn$_invoke$arity$3$=function($container$jscomp$6$$,$shape_id$jscomp$21$$,$ignore_touched$jscomp$1$$){function $delete_from_parent$$($parent$jscomp$190_parent__$1$jscomp$51$$){$parent$jscomp$190_parent__$1$jscomp$51$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($parent$jscomp$190_parent__$1$jscomp$51$$,$APP.$cljs$cst$1614$shapes$$,$app$common$data$without_obj$$,$shape_id$jscomp$21$$);var $and__5023__auto__$jscomp$inline_5292$$=$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$190_parent__$1$jscomp$51$$);
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_5292$$)?$APP.$cljs$core$not$$($ignore_touched$jscomp$1$$):$and__5023__auto__$jscomp$inline_5292$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$190_parent__$1$jscomp$51$$,$APP.$cljs$cst$2046$remote_synced$$):$parent$jscomp$190_parent__$1$jscomp$51$$}return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($container$jscomp$6$$,$APP.$cljs$cst$1631$objects$$,function($objects$jscomp$131$$){var $parent_id$jscomp$21_temp__5823__auto__$jscomp$112$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$131$$,$shape_id$jscomp$21$$);if($APP.$cljs$core$truth_$$($parent_id$jscomp$21_temp__5823__auto__$jscomp$112$$)){var $children_ids$jscomp$2_or__5025__auto__$jscomp$inline_5294$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($parent_id$jscomp$21_temp__5823__auto__$jscomp$112$$);$parent_id$jscomp$21_temp__5823__auto__$jscomp$112$$=$APP.$cljs$core$truth_$$($children_ids$jscomp$2_or__5025__auto__$jscomp$inline_5294$$)?
$children_ids$jscomp$2_or__5025__auto__$jscomp$inline_5294$$:$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($parent_id$jscomp$21_temp__5823__auto__$jscomp$112$$);$children_ids$jscomp$2_or__5025__auto__$jscomp$inline_5294$$=$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$131$$,$shape_id$jscomp$21$$);return $APP.$app$common$data$update_when$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$dissoc$$,$objects$jscomp$131$$,
$APP.$cljs$core$cons$$($shape_id$jscomp$21$$,$children_ids$jscomp$2_or__5025__auto__$jscomp$inline_5294$$)),$parent_id$jscomp$21_temp__5823__auto__$jscomp$112$$,$delete_from_parent$$)}return $objects$jscomp$131$$})};$app$common$types$shape_tree$delete_shape$$.$cljs$lang$maxFixedArity$=3;
$APP.$app$common$types$shape_tree$get_frames$$=function $app$common$types$shape_tree$get_frames$$($var_args$jscomp$993$$){switch(arguments.length){case 1:return $app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$1$=function($objects$jscomp$133$$){return $APP.$app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$133$$,null)};
$APP.$app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$2$=function($objects$jscomp$134$$,$frame_index_map__49741__$1_p__49740$$){$frame_index_map__49741__$1_p__49740$$=$APP.$cljs$core$__destructure_map$$($frame_index_map__49741__$1_p__49740$$);var $skip_components_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($frame_index_map__49741__$1_p__49740$$,$cljs$cst$2083$skip_components_QMARK_$$,!1),$skip_copies_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($frame_index_map__49741__$1_p__49740$$,
$APP.$cljs$cst$2084$skip_copies_QMARK_$$,!1),$ignore_index_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($frame_index_map__49741__$1_p__49740$$,$APP.$cljs$cst$2085$ignore_index_QMARK_$$,!1);$frame_index_map__49741__$1_p__49740$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$270$$=$APP.$cljs$core$not$$($ignore_index_QMARK_$$);return $and__5023__auto__$jscomp$270$$?$cljs$cst$2086$app_DOT_common_DOT_types_DOT_shape_tree_SLASH_index_frames$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($objects$jscomp$134$$)):
$and__5023__auto__$jscomp$270$$}())?$cljs$cst$2086$app_DOT_common_DOT_types_DOT_shape_tree_SLASH_index_frames$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($objects$jscomp$134$$)):function(){var $lookup$jscomp$2_xform$jscomp$23$$=$APP.$app$common$data$getf$$($objects$jscomp$134$$);$lookup$jscomp$2_xform$jscomp$23$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__49736_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,
$p1__49736_SHARP_$$)}),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($lookup$jscomp$2_xform$jscomp$23$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$frame_shape_QMARK_$$));return $APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($lookup$jscomp$2_xform$jscomp$23$$,$APP.$cljs$core$keys$$($objects$jscomp$134$$))}();return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__49737_SHARP_$$){return $skip_components_QMARK_$$&&
$APP.$app$common$types$component$instance_head_QMARK_$$($p1__49737_SHARP_$$)||$skip_copies_QMARK_$$&&$APP.$app$common$types$component$instance_head_QMARK_$$($p1__49737_SHARP_$$)&&!$APP.$app$common$types$component$main_instance_QMARK_$$($p1__49737_SHARP_$$)},$frame_index_map__49741__$1_p__49740$$)};$APP.$app$common$types$shape_tree$get_frames$$.$cljs$lang$maxFixedArity$=2;$clojure$core$protocols$datafy$$["null"]=function(){return null};$clojure$core$protocols$datafy$$._=function($o$jscomp$253$$){return $o$jscomp$253$$};Error.prototype.$clojure$core$protocols$Datafiable$datafy$arity$1$=function(){return $cljs$core$Throwable__GT_map$$(this)};$APP.$cljs$core$ExceptionInfo$$.prototype.$clojure$core$protocols$Datafiable$datafy$arity$1$=function(){return $cljs$core$Throwable__GT_map$$(this)};$APP.$cljs$core$Var$$.prototype.$clojure$core$protocols$Datafiable$datafy$arity$1$=function(){return $clojure$datafy$datify_ref$$(this)};$cljs$core$Reduced$$.prototype.$clojure$core$protocols$Datafiable$datafy$arity$1$=function(){return $clojure$datafy$datify_ref$$(this)};
$cljs$core$Atom$$.prototype.$clojure$core$protocols$Datafiable$datafy$arity$1$=function(){return $clojure$datafy$datify_ref$$(this)};$cljs$core$Volatile$$.prototype.$clojure$core$protocols$Datafiable$datafy$arity$1$=function(){return $clojure$datafy$datify_ref$$(this)};$APP.$cljs$core$Delay$$.prototype.$clojure$core$protocols$Datafiable$datafy$arity$1$=function(){return $clojure$datafy$datify_ref$$(this)};var $app$common$types$tokens_lib$schema_COLON_token_set$$,$app$common$types$tokens_lib$schema_COLON_token_theme$$,$app$common$types$tokens_lib$check_token_theme_attrs$$,$app$common$types$tokens_lib$check_token_theme$$,$app$common$types$tokens_lib$hidden_theme_path$$,$app$common$types$tokens_lib$schema_COLON_token_themes$$,$app$common$types$tokens_lib$schema_COLON_active_themes$$,$app$common$types$tokens_lib$schema_COLON_tokens_lib_map$$,$app$common$types$tokens_lib$valid_tokens_lib_map_QMARK_$$,$app$common$types$tokens_lib$check_tokens_lib_map$$,
$app$common$types$tokens_lib$schema_COLON_tokens_lib$$,$app$common$types$tokens_lib$schema_COLON_dtcg_node$$,$app$common$types$tokens_lib$schema_COLON_multi_set_dtcg$$,$app$common$types$tokens_lib$check_multi_set_dtcg_data$$,$app$common$types$tokens_lib$decode_multi_set_dtcg_data$$;$APP.$app$common$types$tokens_lib$get_id$$["null"]=function(){return null};$APP.$app$common$types$tokens_lib$get_name$$["null"]=function(){return null};$APP.$app$common$types$tokens_lib$get_description$$["null"]=function(){return null};
$APP.$app$common$types$tokens_lib$rename$$["null"]=function(){return null};$APP.$app$common$types$tokens_lib$reid$$["null"]=function(){return null};$APP.$JSCompiler_prototypeAlias$$=$app$common$types$tokens_lib$Token$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$19$$,$k__5324__auto__$jscomp$19$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$19$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$19$$,$k49397$$,$else__5326__auto__$jscomp$19$$){switch($k49397$$ instanceof $APP.$cljs$core$Keyword$$?$k49397$$.$fqn$:null){case "id":return this.id;case "name":return this.name;case "type":return this.type;case "value":return this.value;case "description":return this.description;case "modified-at":return this.$modified_at$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,
$k49397$$,$else__5326__auto__$jscomp$19$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$19$$,$f__5344__auto__$jscomp$19$$,$init__5345__auto__$jscomp$19$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$19$$,$p__49415_v__5348__auto__$jscomp$19$$){var $k__5347__auto__$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49415_v__5348__auto__$jscomp$19$$,0,null);$p__49415_v__5348__auto__$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49415_v__5348__auto__$jscomp$19$$,
1,null);return $f__5344__auto__$jscomp$19$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$19$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$19$$,$k__5347__auto__$jscomp$19$$,$p__49415_v__5348__auto__$jscomp$19$$):$f__5344__auto__$jscomp$19$$($ret__5346__auto__$jscomp$19$$,$k__5347__auto__$jscomp$19$$,$p__49415_v__5348__auto__$jscomp$19$$)},$init__5345__auto__$jscomp$19$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$19$$,$writer__5339__auto__$jscomp$19$$,$opts__5340__auto__$jscomp$19$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$19$$,function($keyval__5342__auto__$jscomp$19$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$19$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$19$$,$keyval__5342__auto__$jscomp$19$$)},"#app.common.types.tokens-lib.Token{",
", ","}",$opts__5340__auto__$jscomp$19$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,this.id],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,this.name],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,this.type],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,this.value],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$936$description$$,this.description],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1737$modified_at$$,
this.$modified_at$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,6,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$936$description$$,$APP.$cljs$cst$1737$modified_at$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $app$common$types$tokens_lib$Token$$(this.id,this.name,this.type,this.value,this.description,this.$modified_at$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 6+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$49_h__5134__auto____$1$jscomp$49$$=this.$__hash$;return $h__5134__auto__$jscomp$49_h__5134__auto____$1$jscomp$49$$!=null?$h__5134__auto__$jscomp$49_h__5134__auto____$1$jscomp$49$$:this.$__hash$=$h__5134__auto__$jscomp$49_h__5134__auto____$1$jscomp$49$$=-269476610^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this49399$$,$other49400$$){return $other49400$$!=null&&this.constructor===$other49400$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.id,$other49400$$.id)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.name,$other49400$$.name)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.type,$other49400$$.type)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.value,$other49400$$.value)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.description,$other49400$$.description)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$modified_at$,$other49400$$.$modified_at$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other49400$$.$__extmap$)};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$get_id$arity$1$=function(){return this.id};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$get_name$arity$1$=function(){return this.name};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$get_description$arity$1$=function(){return this.description};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$rename$arity$2$=function($this$$jscomp$655$$,$new_name$jscomp$3$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this,$APP.$cljs$cst$725$name$$,$new_name$jscomp$3$$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$reid$arity$2$=function($this$$jscomp$656$$,$new_id$jscomp$4$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this,$APP.$cljs$cst$266$id$$,$new_id$jscomp$4$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$19$$,$k__5334__auto__$jscomp$19$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$936$description$$,null,$APP.$cljs$cst$725$name$$,null,$APP.$cljs$cst$260$value$$,null,$APP.$cljs$cst$139$type$$,null,$APP.$cljs$cst$1737$modified_at$$,null,$APP.$cljs$cst$266$id$$,null],null),null),$k__5334__auto__$jscomp$19$$)?
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),this.$__meta$),$k__5334__auto__$jscomp$19$$):new $app$common$types$tokens_lib$Token$$(this.id,this.name,this.type,this.value,this.description,this.$modified_at$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$19$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$19$$,$k49397$jscomp$1$$){switch($k49397$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k49397$jscomp$1$$.$fqn$:null){case "id":case "name":case "type":case "value":case "description":case "modified-at":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k49397$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$19$$,$k__5332__auto__$jscomp$19$$,$G__49396$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$k__5332__auto__$jscomp$19$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$266$id$$,$k__5332__auto__$jscomp$19$$))?new $app$common$types$tokens_lib$Token$$($G__49396$jscomp$1$$,
this.name,this.type,this.value,this.description,this.$modified_at$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$k__5332__auto__$jscomp$19$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$725$name$$,$k__5332__auto__$jscomp$19$$))?new $app$common$types$tokens_lib$Token$$(this.id,$G__49396$jscomp$1$$,
this.type,this.value,this.description,this.$modified_at$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$,$k__5332__auto__$jscomp$19$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$139$type$$,$k__5332__auto__$jscomp$19$$))?new $app$common$types$tokens_lib$Token$$(this.id,this.name,$G__49396$jscomp$1$$,
this.value,this.description,this.$modified_at$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$19$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$19$$))?new $app$common$types$tokens_lib$Token$$(this.id,this.name,this.type,$G__49396$jscomp$1$$,
this.description,this.$modified_at$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$936$description$$,$k__5332__auto__$jscomp$19$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$936$description$$,$k__5332__auto__$jscomp$19$$))?new $app$common$types$tokens_lib$Token$$(this.id,this.name,this.type,this.value,$G__49396$jscomp$1$$,
this.$modified_at$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1737$modified_at$$,$k__5332__auto__$jscomp$19$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1737$modified_at$$,$k__5332__auto__$jscomp$19$$))?new $app$common$types$tokens_lib$Token$$(this.id,this.name,this.type,this.value,this.description,$G__49396$jscomp$1$$,
this.$__meta$,this.$__extmap$,null):new $app$common$types$tokens_lib$Token$$(this.id,this.name,this.type,this.value,this.description,this.$modified_at$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$19$$,$G__49396$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$266$id$$,this.id,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$725$name$$,this.name,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$139$type$$,this.type,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$260$value$$,
this.value,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$936$description$$,this.description,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1737$modified_at$$,this.$modified_at$,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$clojure$core$protocols$Datafiable$datafy$arity$1$=function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$19$$,$G__49396$jscomp$2$$){return new $app$common$types$tokens_lib$Token$$(this.id,this.name,this.type,this.value,this.description,this.$modified_at$,$G__49396$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$19$$,$entry__5329__auto__$jscomp$19$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$19$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$19$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$19$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$19$$)};
$cljs$pprint$simple_dispatch$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$app$common$types$tokens_lib$Token$$,function($obj$jscomp$174$$){$cljs$core$_STAR_out_STAR_$$.write("#penpot/token ");$cljs$pprint$pprint_newline$$($cljs$cst$288$miser$$);return $cljs$pprint$pprint$$.$cljs$core$IFn$_invoke$arity$1$($APP.$clojure$datafy$datafy$$($obj$jscomp$174$$))});$app$common$types$tokens_lib$Token$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$app$common$types$tokens_lib$Token$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$659$$,$writer$jscomp$165$$,$opts$jscomp$253$$){$APP.$cljs$core$_write$$($writer$jscomp$165$$,"#penpot/token ");return $APP.$cljs$core$_pr_writer$$($APP.$clojure$datafy$datafy$$(this),$writer$jscomp$165$$,$opts$jscomp$253$$)};$app$common$types$tokens_lib$Token$$.prototype.$cljs$core$IEncodeJS$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$app$common$types$tokens_lib$Token$$.prototype.$cljs$core$IEncodeJS$_clj__GT_js$arity$1$=function(){return $APP.$cljs$core$clj__GT_js$$($APP.$clojure$datafy$datafy$$(this))};
var $app$common$types$tokens_lib$schema_COLON_token$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$fmap$$(function($p1__49443_SHARP_$$){return $app$common$types$tokens_lib$make_token$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$tokens_lib$make_token$$.$cljs$core$IFn$_invoke$arity$1$($p1__49443_SHARP_$$):$app$common$types$tokens_lib$make_token$$($p1__49443_SHARP_$$)},
$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$token$schema_COLON_token_attrs$$))],null),$malli$util$required_keys$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$schema$schema$$($app$common$types$token$schema_COLON_token_attrs$$)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$APP.$app$common$types$tokens_lib$token_QMARK_$$],null)],null),$app$common$types$tokens_lib$check_token_attrs$$=
$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$types$token$schema_COLON_token_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,"expected valid params for token"])),$app$common$types$tokens_lib$check_token$$=$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$types$tokens_lib$schema_COLON_token$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,
"expected valid token"]));$APP.$JSCompiler_prototypeAlias$$=$APP.$app$common$types$tokens_lib$TokenSet$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.equals=function($other$jscomp$189$$){return $other$jscomp$189$$ instanceof $APP.$app$common$types$tokens_lib$TokenSet$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.id,$other$jscomp$189$$.id)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.name,$other$jscomp$189$$.name)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.description,$other$jscomp$189$$.description)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$modified_at$,
$other$jscomp$189$$.$modified_at$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.tokens,$other$jscomp$189$$.tokens)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$661$$,$other$jscomp$190$$){return this.equals($other$jscomp$190$$)};
$APP.$JSCompiler_prototypeAlias$$.$clojure$core$protocols$Datafiable$datafy$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$725$name$$,this.name,$APP.$cljs$cst$936$description$$,this.description,$APP.$cljs$cst$1737$modified_at$$,this.$modified_at$,$APP.$cljs$cst$2100$tokens$$,this.tokens],null)};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$get_id$arity$1$=function(){return this.id};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$get_name$arity$1$=function(){return this.name};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$get_description$arity$1$=function(){return this.description};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$rename$arity$2$=function($_$jscomp$1262$$,$new_name$jscomp$6$$){return new $APP.$app$common$types$tokens_lib$TokenSet$$(this.id,$new_name$jscomp$6$$,this.description,$APP.$app$common$time$now$$(),this.tokens)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$reid$arity$2$=function($_$jscomp$1263$$,$new_id$jscomp$5$$){return new $APP.$app$common$types$tokens_lib$TokenSet$$($new_id$jscomp$5$$,this.name,this.description,$APP.$app$common$time$now$$(),this.tokens)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSet$add_token_$arity$2$=function($_$jscomp$1265_token__$1$$,$token$jscomp$48$$){$_$jscomp$1265_token__$1$$=$app$common$types$tokens_lib$check_token$$($token$jscomp$48$$);return new $APP.$app$common$types$tokens_lib$TokenSet$$(this.id,this.name,this.description,$APP.$app$common$time$now$$(),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.tokens,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1265_token__$1$$),
$_$jscomp$1265_token__$1$$))};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSet$update_token_$arity$3$=function($JSCompiler_temp$jscomp$10664_temp__5823__auto__$jscomp$115_this$$jscomp$662$$,$JSCompiler_temp_const$jscomp$10662_token_id$$,$JSCompiler_temp_const$jscomp$10663_f$jscomp$781_token_SINGLEQUOTE_$$){$JSCompiler_temp$jscomp$10664_temp__5823__auto__$jscomp$115_this$$jscomp$662$$=this.$app$common$types$tokens_lib$ITokenSet$get_token_$arity$2$(null,$JSCompiler_temp_const$jscomp$10662_token_id$$);if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$10664_temp__5823__auto__$jscomp$115_this$$jscomp$662$$)&&
($JSCompiler_temp_const$jscomp$10663_f$jscomp$781_token_SINGLEQUOTE_$$=$JSCompiler_temp_const$jscomp$10663_f$jscomp$781_token_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_temp_const$jscomp$10663_f$jscomp$781_token_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10664_temp__5823__auto__$jscomp$115_this$$jscomp$662$$):$JSCompiler_temp_const$jscomp$10663_f$jscomp$781_token_SINGLEQUOTE_$$($JSCompiler_temp$jscomp$10664_temp__5823__auto__$jscomp$115_this$$jscomp$662$$),
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$10664_temp__5823__auto__$jscomp$115_this$$jscomp$662$$,$JSCompiler_temp_const$jscomp$10663_f$jscomp$781_token_SINGLEQUOTE_$$))){var $JSCompiler_inline_result$jscomp$10667_token_SINGLEQUOTE___$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp_const$jscomp$10663_f$jscomp$781_token_SINGLEQUOTE_$$,$APP.$cljs$cst$1737$modified_at$$,$APP.$app$common$time$now$$());$JSCompiler_temp_const$jscomp$10663_f$jscomp$781_token_SINGLEQUOTE_$$=
this.id;$JSCompiler_temp_const$jscomp$10662_token_id$$=this.name;var $JSCompiler_temp_const$jscomp$10661$$=this.description,$JSCompiler_temp_const$jscomp$10660$$=$APP.$app$common$time$now$$();if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10664_temp__5823__auto__$jscomp$115_this$$jscomp$662$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10667_token_SINGLEQUOTE___$1$$)))$JSCompiler_temp$jscomp$10664_temp__5823__auto__$jscomp$115_this$$jscomp$662$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.tokens,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10667_token_SINGLEQUOTE___$1$$),$JSCompiler_inline_result$jscomp$10667_token_SINGLEQUOTE___$1$$);else{var $JSCompiler_temp_const$jscomp$10665$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$,$o$jscomp$inline_12030$$=this.tokens,$before_k$jscomp$inline_12031_temp__5823__auto__$jscomp$inline_12034$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10664_temp__5823__auto__$jscomp$115_this$$jscomp$662$$),
$k$jscomp$inline_12032$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10667_token_SINGLEQUOTE___$1$$),$G__31189$jscomp$inline_12035$$=$APP.$cljs$core$keys$$($o$jscomp$inline_12030$$);$before_k$jscomp$inline_12031_temp__5823__auto__$jscomp$inline_12034$$=$APP.$app$common$data$index_of$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$data$index_of$$.$cljs$core$IFn$_invoke$arity$2$($G__31189$jscomp$inline_12035$$,$before_k$jscomp$inline_12031_temp__5823__auto__$jscomp$inline_12034$$):
$APP.$app$common$data$index_of$$($G__31189$jscomp$inline_12035$$,$before_k$jscomp$inline_12031_temp__5823__auto__$jscomp$inline_12034$$);$JSCompiler_inline_result$jscomp$10667_token_SINGLEQUOTE___$1$$=$APP.$cljs$core$truth_$$($before_k$jscomp$inline_12031_temp__5823__auto__$jscomp$inline_12034$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$linked$map$empty_linked_map$$,$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($before_k$jscomp$inline_12031_temp__5823__auto__$jscomp$inline_12034$$,
$o$jscomp$inline_12030$$)),$k$jscomp$inline_12032$$,$JSCompiler_inline_result$jscomp$10667_token_SINGLEQUOTE___$1$$),$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($before_k$jscomp$inline_12031_temp__5823__auto__$jscomp$inline_12034$$,$o$jscomp$inline_12030$$)):$app$common$data$oassoc$$.$cljs$core$IFn$_invoke$arity$variadic$($o$jscomp$inline_12030$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$k$jscomp$inline_12032$$,$JSCompiler_inline_result$jscomp$10667_token_SINGLEQUOTE___$1$$]));
$JSCompiler_temp$jscomp$10664_temp__5823__auto__$jscomp$115_this$$jscomp$662$$=$JSCompiler_temp_const$jscomp$10665$$.call($APP.$cljs$core$dissoc$$,$JSCompiler_inline_result$jscomp$10667_token_SINGLEQUOTE___$1$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$10664_temp__5823__auto__$jscomp$115_this$$jscomp$662$$))}return new $APP.$app$common$types$tokens_lib$TokenSet$$($JSCompiler_temp_const$jscomp$10663_f$jscomp$781_token_SINGLEQUOTE_$$,$JSCompiler_temp_const$jscomp$10662_token_id$$,
$JSCompiler_temp_const$jscomp$10661$$,$JSCompiler_temp_const$jscomp$10660$$,$JSCompiler_temp$jscomp$10664_temp__5823__auto__$jscomp$115_this$$jscomp$662$$)}return this};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSet$delete_token_$arity$2$=function($this$$jscomp$663_token$jscomp$50$$,$token_id$jscomp$1$$){$this$$jscomp$663_token$jscomp$50$$=this.$app$common$types$tokens_lib$ITokenSet$get_token_$arity$2$(null,$token_id$jscomp$1$$);return new $APP.$app$common$types$tokens_lib$TokenSet$$(this.id,this.name,this.description,$APP.$app$common$time$now$$(),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.tokens,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$663_token$jscomp$50$$)))};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSet$get_token_$arity$2$=function($_$jscomp$1266$$,$token_id$jscomp$2$$){return $APP.$cljs$core$some$$(function($p1__49511_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__49511_SHARP_$$),$token_id$jscomp$2$$)?$p1__49511_SHARP_$$:null},$APP.$cljs$core$vals$$(this.tokens))};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSet$get_tokens_$arity$1$=function(){return this.tokens};$cljs$pprint$simple_dispatch$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$app$common$types$tokens_lib$TokenSet$$,function($obj$jscomp$175$$){$cljs$core$_STAR_out_STAR_$$.write("#penpot/token-set ");$cljs$pprint$pprint_newline$$($cljs$cst$288$miser$$);return $cljs$pprint$pprint$$.$cljs$core$IFn$_invoke$arity$1$($APP.$clojure$datafy$datafy$$($obj$jscomp$175$$))});
$APP.$app$common$types$tokens_lib$TokenSet$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$app$common$types$tokens_lib$TokenSet$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$664$$,$writer$jscomp$166$$,$opts$jscomp$254$$){$APP.$cljs$core$_write$$($writer$jscomp$166$$,"#penpot/token-set ");return $APP.$cljs$core$_pr_writer$$($APP.$clojure$datafy$datafy$$(this),$writer$jscomp$166$$,$opts$jscomp$254$$)};
$APP.$app$common$types$tokens_lib$TokenSet$$.prototype.$cljs$core$IEncodeJS$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$app$common$types$tokens_lib$TokenSet$$.prototype.$cljs$core$IEncodeJS$_clj__GT_js$arity$1$=function(){return $APP.$cljs$core$clj__GT_js$$($APP.$clojure$datafy$datafy$$(this))};
$APP.$app$common$types$tokens_lib$normalize_set_name$$=function $app$common$types$tokens_lib$normalize_set_name$$($var_args$jscomp$1005$$){switch(arguments.length){case 1:return $app$common$types$tokens_lib$normalize_set_name$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$common$types$tokens_lib$normalize_set_name$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$types$tokens_lib$normalize_set_name$$.$cljs$core$IFn$_invoke$arity$1$=function($name$jscomp$201$$){return $APP.$app$common$path_names$join_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$tokens_lib$split_set_name$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$201$$)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,"/",$APP.$cljs$cst$1998$with_spaces_QMARK_$$,!1]))};
$APP.$app$common$types$tokens_lib$normalize_set_name$$.$cljs$core$IFn$_invoke$arity$2$=function($name$jscomp$202$$,$relative_to$jscomp$6$$){return $APP.$app$common$path_names$join_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$butlast$$($APP.$app$common$types$tokens_lib$split_set_name$$($relative_to$jscomp$6$$)),$APP.$app$common$types$tokens_lib$split_set_name$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$202$$))),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1472$separator$$,"/",$APP.$cljs$cst$1998$with_spaces_QMARK_$$,!1]))};$APP.$app$common$types$tokens_lib$normalize_set_name$$.$cljs$lang$maxFixedArity$=2;
var $JSCompiler_temp_const$jscomp$843$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$JSCompiler_temp_const$jscomp$842$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"TokenSet"],null),$JSCompiler_temp_const$jscomp$841$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),$JSCompiler_temp_const$jscomp$840$$=new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,function($p1__49587_SHARP_$$){return $APP.$app$common$types$tokens_lib$normalized_set_name_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$tokens_lib$normalized_set_name_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__49587_SHARP_$$):
$APP.$app$common$types$tokens_lib$normalized_set_name_QMARK_$$($p1__49587_SHARP_$$)}],null)],null)],null),$JSCompiler_temp_const$jscomp$839$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$936$description$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),$JSCompiler_temp_const$jscomp$838$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1737$modified_at$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),$JSCompiler_temp_const$jscomp$837$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$JSCompiler_inline_result$jscomp$844$$,$kg$jscomp$inline_5357$$=$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$),$vg$jscomp$inline_5358$$=$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$tokens_lib$schema_COLON_token$$);
$JSCompiler_inline_result$jscomp$844$$=$clojure$test$check$generators$map$$.$cljs$core$IFn$_invoke$arity$3$($kg$jscomp$inline_5357$$,$vg$jscomp$inline_5358$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$776$min_elements$$,1,$cljs$cst$777$max_elements$$,3],null));
$APP.$app$common$types$tokens_lib$schema_COLON_token_set_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,7,5,$JSCompiler_temp_const$jscomp$843$$,[$APP.$cljs$cst$202$map$$,$JSCompiler_temp_const$jscomp$842$$,$JSCompiler_temp_const$jscomp$841$$,$JSCompiler_temp_const$jscomp$840$$,$JSCompiler_temp_const$jscomp$839$$,$JSCompiler_temp_const$jscomp$838$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$JSCompiler_temp_const$jscomp$837$$,[$APP.$cljs$cst$2100$tokens$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$450$optional$$,!0,$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$fmap$$(function($p1__49588_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$linked$map$empty_linked_map$$,$p1__49588_SHARP_$$)},$JSCompiler_inline_result$jscomp$844$$)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$855$gen_SLASH_max$$,5,$APP.$cljs$cst$938$decode_SLASH_json$$,function($v$jscomp$533$$){return $APP.$app$common$data$ordered_map_QMARK_$$($v$jscomp$533$$)?$v$jscomp$533$$:$APP.$cljs$core$map_QMARK_$$($v$jscomp$533$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$linked$map$empty_linked_map$$,$v$jscomp$533$$):$v$jscomp$533$$}],null),$APP.$cljs$cst$198$string$$,$app$common$types$tokens_lib$schema_COLON_token$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$APP.$app$common$data$ordered_map_QMARK_$$],null)],null)],null)],null);
$app$common$types$tokens_lib$schema_COLON_token_set$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$298$schema$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$fmap$$(function($p1__49594_SHARP_$$){return $app$common$types$tokens_lib$make_token_set$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$tokens_lib$make_token_set$$.$cljs$core$IFn$_invoke$arity$1$($p1__49594_SHARP_$$):
$app$common$types$tokens_lib$make_token_set$$($p1__49594_SHARP_$$)},$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$types$tokens_lib$schema_COLON_token_set_attrs$$))],null),$malli$util$required_keys$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$schema$schema$$($APP.$app$common$types$tokens_lib$schema_COLON_token_set_attrs$$))],null);
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$2102$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_token_set$$,$app$common$types$tokens_lib$schema_COLON_token_set$$);var $app$common$types$tokens_lib$check_token_set_attrs$$=$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$tokens_lib$schema_COLON_token_set_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,"expected valid params for token-set"]));
$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$types$tokens_lib$schema_COLON_token_set$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,"expected valid token set"]));
var $app$common$types$tokens_lib$schema_COLON_token_sets$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"TokenSets"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$298$schema$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$352$registry$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2105$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_node$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$common$types$tokens_lib$token_set_QMARK_$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,5],null),$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$550$ref$$,$cljs$cst$2105$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_node$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$APP.$app$common$data$ordered_map_QMARK_$$],null)],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$550$ref$$,$cljs$cst$2105$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_node$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$516$fn$$,$APP.$app$common$data$ordered_map_QMARK_$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,function($ids$jscomp$25_sets$jscomp$3$$){$ids$jscomp$25_sets$jscomp$3$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$tokens_lib$get_id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$core$instance_QMARK_$$,
$APP.$app$common$types$tokens_lib$TokenSet$$),$APP.$cljs$core$tree_seq$$($APP.$app$common$data$ordered_map_QMARK_$$,$APP.$cljs$core$vals$$,$ids$jscomp$25_sets$jscomp$3$$)));var $ids_SINGLEQUOTE_$$=$APP.$cljs$core$set$$($ids$jscomp$25_sets$jscomp$3$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$25_sets$jscomp$3$$),$APP.$cljs$core$count$$($ids_SINGLEQUOTE_$$))}],null)],null);$APP.$JSCompiler_prototypeAlias$$=$app$common$types$tokens_lib$TokenTheme$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$21$$,$k__5324__auto__$jscomp$21$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$21$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$21$$,$k49692$$,$else__5326__auto__$jscomp$21$$){switch($k49692$$ instanceof $APP.$cljs$core$Keyword$$?$k49692$$.$fqn$:null){case "id":return this.id;case "name":return this.name;case "group":return this.group;case "description":return this.description;case "is-source":return this.$is_source$;case "external-id":return this.$external_id$;case "modified-at":return this.$modified_at$;case "sets":return this.$sets$;
default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k49692$$,$else__5326__auto__$jscomp$21$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$21$$,$f__5344__auto__$jscomp$21$$,$init__5345__auto__$jscomp$21$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$21$$,$p__49708_v__5348__auto__$jscomp$21$$){var $k__5347__auto__$jscomp$21$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49708_v__5348__auto__$jscomp$21$$,0,null);$p__49708_v__5348__auto__$jscomp$21$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49708_v__5348__auto__$jscomp$21$$,
1,null);return $f__5344__auto__$jscomp$21$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$21$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$21$$,$k__5347__auto__$jscomp$21$$,$p__49708_v__5348__auto__$jscomp$21$$):$f__5344__auto__$jscomp$21$$($ret__5346__auto__$jscomp$21$$,$k__5347__auto__$jscomp$21$$,$p__49708_v__5348__auto__$jscomp$21$$)},$init__5345__auto__$jscomp$21$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$21$$,$writer__5339__auto__$jscomp$21$$,$opts__5340__auto__$jscomp$21$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$21$$,function($keyval__5342__auto__$jscomp$21$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$21$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$21$$,$keyval__5342__auto__$jscomp$21$$)},"#app.common.types.tokens-lib.TokenTheme{",
", ","}",$opts__5340__auto__$jscomp$21$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,this.id],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,this.name],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1608$group$$,this.group],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$936$description$$,this.description],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2106$is_source$$,this.$is_source$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2107$external_id$$,
this.$external_id$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1737$modified_at$$,this.$modified_at$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2108$sets$$,this.$sets$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,8,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$1608$group$$,$APP.$cljs$cst$936$description$$,$cljs$cst$2106$is_source$$,$APP.$cljs$cst$2107$external_id$$,$APP.$cljs$cst$1737$modified_at$$,$APP.$cljs$cst$2108$sets$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?
$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $app$common$types$tokens_lib$TokenTheme$$(this.id,this.name,this.group,this.description,this.$is_source$,this.$external_id$,this.$modified_at$,this.$sets$,this.$__meta$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 8+$APP.$cljs$core$count$$(this.$__extmap$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$51_h__5134__auto____$1$jscomp$51$$=this.$__hash$;return $h__5134__auto__$jscomp$51_h__5134__auto____$1$jscomp$51$$!=null?$h__5134__auto__$jscomp$51_h__5134__auto____$1$jscomp$51$$:this.$__hash$=$h__5134__auto__$jscomp$51_h__5134__auto____$1$jscomp$51$$=92571567^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this49693$$,$other49694$$){return $other49694$$!=null&&this.constructor===$other49694$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.id,$other49694$$.id)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.name,$other49694$$.name)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.group,$other49694$$.group)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.description,
$other49694$$.description)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$is_source$,$other49694$$.$is_source$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$external_id$,$other49694$$.$external_id$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$modified_at$,$other49694$$.$modified_at$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$sets$,$other49694$$.$sets$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other49694$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$get_id$arity$1$=function(){return this.id};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$get_name$arity$1$=function(){return this.name};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$get_description$arity$1$=function(){return this.description};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$rename$arity$2$=function($this$$jscomp$666$$,$new_name$jscomp$7$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this,$APP.$cljs$cst$725$name$$,$new_name$jscomp$7$$)};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$INamedItem$reid$arity$2$=function($this$$jscomp$667$$,$new_id$jscomp$6$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this,$APP.$cljs$cst$266$id$$,$new_id$jscomp$6$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$21$$,$k__5334__auto__$jscomp$21$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$936$description$$,null,$APP.$cljs$cst$1608$group$$,null,$APP.$cljs$cst$725$name$$,null,$cljs$cst$2106$is_source$$,null,$APP.$cljs$cst$1737$modified_at$$,null,$APP.$cljs$cst$2107$external_id$$,null,$APP.$cljs$cst$266$id$$,
null,$APP.$cljs$cst$2108$sets$$,null],null),null),$k__5334__auto__$jscomp$21$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),this.$__meta$),$k__5334__auto__$jscomp$21$$):new $app$common$types$tokens_lib$TokenTheme$$(this.id,this.name,this.group,this.description,this.$is_source$,this.$external_id$,this.$modified_at$,this.$sets$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,
$k__5334__auto__$jscomp$21$$)),null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$21$$,$k49692$jscomp$1$$){switch($k49692$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k49692$jscomp$1$$.$fqn$:null){case "id":case "name":case "group":case "description":case "is-source":case "external-id":case "modified-at":case "sets":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k49692$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$21$$,$k__5332__auto__$jscomp$21$$,$G__49691$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$k__5332__auto__$jscomp$21$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$266$id$$,$k__5332__auto__$jscomp$21$$))?new $app$common$types$tokens_lib$TokenTheme$$($G__49691$jscomp$1$$,
this.name,this.group,this.description,this.$is_source$,this.$external_id$,this.$modified_at$,this.$sets$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$k__5332__auto__$jscomp$21$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$725$name$$,$k__5332__auto__$jscomp$21$$))?new $app$common$types$tokens_lib$TokenTheme$$(this.id,
$G__49691$jscomp$1$$,this.group,this.description,this.$is_source$,this.$external_id$,this.$modified_at$,this.$sets$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,$k__5332__auto__$jscomp$21$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1608$group$$,$k__5332__auto__$jscomp$21$$))?new $app$common$types$tokens_lib$TokenTheme$$(this.id,
this.name,$G__49691$jscomp$1$$,this.description,this.$is_source$,this.$external_id$,this.$modified_at$,this.$sets$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$936$description$$,$k__5332__auto__$jscomp$21$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$936$description$$,$k__5332__auto__$jscomp$21$$))?new $app$common$types$tokens_lib$TokenTheme$$(this.id,
this.name,this.group,$G__49691$jscomp$1$$,this.$is_source$,this.$external_id$,this.$modified_at$,this.$sets$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2106$is_source$$,$k__5332__auto__$jscomp$21$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$2106$is_source$$,$k__5332__auto__$jscomp$21$$))?new $app$common$types$tokens_lib$TokenTheme$$(this.id,
this.name,this.group,this.description,$G__49691$jscomp$1$$,this.$external_id$,this.$modified_at$,this.$sets$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2107$external_id$$,$k__5332__auto__$jscomp$21$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2107$external_id$$,$k__5332__auto__$jscomp$21$$))?new $app$common$types$tokens_lib$TokenTheme$$(this.id,
this.name,this.group,this.description,this.$is_source$,$G__49691$jscomp$1$$,this.$modified_at$,this.$sets$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1737$modified_at$$,$k__5332__auto__$jscomp$21$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1737$modified_at$$,$k__5332__auto__$jscomp$21$$))?new $app$common$types$tokens_lib$TokenTheme$$(this.id,
this.name,this.group,this.description,this.$is_source$,this.$external_id$,$G__49691$jscomp$1$$,this.$sets$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2108$sets$$,$k__5332__auto__$jscomp$21$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2108$sets$$,$k__5332__auto__$jscomp$21$$))?new $app$common$types$tokens_lib$TokenTheme$$(this.id,
this.name,this.group,this.description,this.$is_source$,this.$external_id$,this.$modified_at$,$G__49691$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $app$common$types$tokens_lib$TokenTheme$$(this.id,this.name,this.group,this.description,this.$is_source$,this.$external_id$,this.$modified_at$,this.$sets$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$21$$,$G__49691$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$266$id$$,this.id,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$725$name$$,this.name,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1608$group$$,this.group,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$936$description$$,
this.description,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$2106$is_source$$,this.$is_source$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2107$external_id$$,this.$external_id$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1737$modified_at$$,this.$modified_at$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2108$sets$$,this.$sets$,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$clojure$core$protocols$Datafiable$datafy$arity$1$=function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$21$$,$G__49691$jscomp$2$$){return new $app$common$types$tokens_lib$TokenTheme$$(this.id,this.name,this.group,this.description,this.$is_source$,this.$external_id$,this.$modified_at$,this.$sets$,$G__49691$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$21$$,$entry__5329__auto__$jscomp$21$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$21$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$21$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$21$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$21$$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenTheme$set_sets$arity$2$=function($_$jscomp$1319$$,$set_names$jscomp$6$$){return new $app$common$types$tokens_lib$TokenTheme$$(this.id,this.name,this.group,this.description,this.$is_source$,this.$external_id$,$APP.$app$common$time$now$$(),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$some_QMARK_$$),$set_names$jscomp$6$$),
null,null,null)};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenTheme$enable_sets$arity$2$=function($this$$jscomp$670$$,$set_names$jscomp$7$$){return this.$app$common$types$tokens_lib$ITokenTheme$set_sets$arity$2$(null,$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$(this.$sets$,$set_names$jscomp$7$$))};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenTheme$enable_set$arity$2$=function($this$$jscomp$671$$,$set_name$jscomp$9$$){return this.$app$common$types$tokens_lib$ITokenTheme$set_sets$arity$2$(null,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$(this.$sets$,$set_name$jscomp$9$$))};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenTheme$disable_sets$arity$2$=function($JSCompiler_temp_const$jscomp$858_this$$jscomp$672$$,$or__5025__auto__$jscomp$inline_5432_set_names$jscomp$8$$){$JSCompiler_temp_const$jscomp$858_this$$jscomp$672$$=this.$app$common$types$tokens_lib$ITokenTheme$set_sets$arity$2$;$or__5025__auto__$jscomp$inline_5432_set_names$jscomp$8$$=$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$(this.$sets$,$or__5025__auto__$jscomp$inline_5432_set_names$jscomp$8$$);
return $JSCompiler_temp_const$jscomp$858_this$$jscomp$672$$.call(this,null,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_5432_set_names$jscomp$8$$)?$or__5025__auto__$jscomp$inline_5432_set_names$jscomp$8$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenTheme$disable_set$arity$2$=function($this$$jscomp$673$$,$set_name$jscomp$10$$){return this.$app$common$types$tokens_lib$ITokenTheme$set_sets$arity$2$(null,$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$(this.$sets$,$set_name$jscomp$10$$))};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenTheme$hidden_theme_QMARK_$arity$1$=function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$(this),"")&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$(this),"__PENPOT__HIDDEN__TOKEN__THEME__")};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenTheme$toggle_set$arity$2$=function($this$$jscomp$677$$,$set_name$jscomp$12$$){return $APP.$cljs$core$truth_$$(this.$sets$.$cljs$core$IFn$_invoke$arity$1$?this.$sets$.$cljs$core$IFn$_invoke$arity$1$($set_name$jscomp$12$$):this.$sets$($set_name$jscomp$12$$))?this.$app$common$types$tokens_lib$ITokenTheme$disable_set$arity$2$(null,$set_name$jscomp$12$$):this.$app$common$types$tokens_lib$ITokenTheme$enable_set$arity$2$(null,$set_name$jscomp$12$$)};
$cljs$pprint$simple_dispatch$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$app$common$types$tokens_lib$TokenTheme$$,function($obj$jscomp$176$$){$cljs$core$_STAR_out_STAR_$$.write("#penpot/token-theme ");$cljs$pprint$pprint_newline$$($cljs$cst$288$miser$$);return $cljs$pprint$pprint$$.$cljs$core$IFn$_invoke$arity$1$($APP.$clojure$datafy$datafy$$($obj$jscomp$176$$))});$app$common$types$tokens_lib$TokenTheme$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$app$common$types$tokens_lib$TokenTheme$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$678$$,$writer$jscomp$167$$,$opts$jscomp$255$$){$APP.$cljs$core$_write$$($writer$jscomp$167$$,"#penpot/token-theme ");return $APP.$cljs$core$_pr_writer$$($APP.$clojure$datafy$datafy$$(this),$writer$jscomp$167$$,$opts$jscomp$255$$)};$app$common$types$tokens_lib$TokenTheme$$.prototype.$cljs$core$IEncodeJS$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$app$common$types$tokens_lib$TokenTheme$$.prototype.$cljs$core$IEncodeJS$_clj__GT_js$arity$1$=function(){return $APP.$cljs$core$clj__GT_js$$($APP.$clojure$datafy$datafy$$(this))};
$APP.$app$common$types$tokens_lib$schema_COLON_token_theme_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"TokenTheme"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1608$group$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$936$description$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2106$is_source$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2107$external_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,
[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1737$modified_at$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2108$sets$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$203$set$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,5],null),$APP.$cljs$cst$198$string$$],null)],null)],null);
$app$common$types$tokens_lib$schema_COLON_token_theme$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$malli$util$required_keys$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$schema$schema$$($APP.$app$common$types$tokens_lib$schema_COLON_token_theme_attrs$$)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,function($o$jscomp$257$$){return $o$jscomp$257$$ instanceof
$app$common$types$tokens_lib$TokenTheme$$}],null)],null);$app$common$types$tokens_lib$check_token_theme_attrs$$=$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$tokens_lib$schema_COLON_token_theme_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,"expected valid params for token-theme"]));
$app$common$types$tokens_lib$check_token_theme$$=$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$types$tokens_lib$schema_COLON_token_theme$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,"expected a valid token-theme"]));$app$common$types$tokens_lib$hidden_theme_path$$=$app$common$types$tokens_lib$join_theme_path$$("","__PENPOT__HIDDEN__TOKEN__THEME__");
$app$common$types$tokens_lib$schema_COLON_token_themes$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"TokenThemes"],null),$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,$APP.$cljs$cst$198$string$$,$app$common$types$tokens_lib$schema_COLON_token_theme$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$APP.$app$common$data$ordered_map_QMARK_$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$516$fn$$,$APP.$app$common$data$ordered_map_QMARK_$$],null)],null);$app$common$types$tokens_lib$schema_COLON_active_themes$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$198$string$$],null);$APP.$JSCompiler_prototypeAlias$$=$app$common$types$tokens_lib$TokensLib$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$clojure$core$protocols$Datafiable$datafy$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2108$sets$$,this.$sets$,$APP.$cljs$cst$2122$themes$$,this.$themes$,$cljs$cst$2123$active_themes$$,this.$active_themes$],null)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSets$get_set_by_name$arity$2$=function($_$jscomp$1389_path$jscomp$181$$,$name$jscomp$215$$){$_$jscomp$1389_path$jscomp$181$$=$app$common$types$tokens_lib$set_full_path__GT_set_prefixed_full_path$$($APP.$app$common$types$tokens_lib$split_set_name$$($name$jscomp$215$$));return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$(this.$sets$,$_$jscomp$1389_path$jscomp$181$$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSets$get_set_tree$arity$1$=function(){return this.$sets$};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSets$get_sets$arity$1$=function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$core$instance_QMARK_$$,$APP.$app$common$types$tokens_lib$TokenSet$$),$APP.$cljs$core$tree_seq$$($APP.$app$common$data$ordered_map_QMARK_$$,$APP.$cljs$core$vals$$,this.$sets$))};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSets$get_set_names$arity$1$=function(){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$tokens_lib$get_name$$,this.$app$common$types$tokens_lib$ITokenSets$get_sets$arity$1$(null))};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSets$move_set_group$arity$5$=function($prefixed_from_path_themes_SINGLEQUOTE__this$$jscomp$682$$,$from_path$jscomp$4$$,$prefixed_to_path_to_path$jscomp$4$$,$before_path$jscomp$4_sets_SINGLEQUOTE_$$,$before_group_QMARK_$jscomp$4_reorder_QMARK_$$){var $self__$jscomp$2872$$=this,$this$__$1$jscomp$363$$=this;$prefixed_from_path_themes_SINGLEQUOTE__this$$jscomp$682$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$tokens_lib$add_set_path_group_prefix$$,
$from_path$jscomp$4$$);var $prev_set_group$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$2872$$.$sets$,$prefixed_from_path_themes_SINGLEQUOTE__this$$jscomp$682$$);if($APP.$cljs$core$truth_$$($prev_set_group$$)){var $from_path_str$jscomp$2$$=$APP.$app$common$types$tokens_lib$join_set_path$$($from_path$jscomp$4$$),$to_path_str$jscomp$2$$=$APP.$app$common$types$tokens_lib$join_set_path$$($prefixed_to_path_to_path$jscomp$4$$);$prefixed_to_path_to_path$jscomp$4$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$tokens_lib$add_set_path_group_prefix$$,
$prefixed_to_path_to_path$jscomp$4$$);var $prefixed_before_path$$=$APP.$cljs$core$truth_$$($before_path$jscomp$4_sets_SINGLEQUOTE_$$)?$APP.$cljs$core$truth_$$($before_group_QMARK_$jscomp$4_reorder_QMARK_$$)?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$tokens_lib$add_set_path_group_prefix$$,$before_path$jscomp$4_sets_SINGLEQUOTE_$$):$app$common$types$tokens_lib$set_full_path__GT_set_prefixed_full_path$$($before_path$jscomp$4_sets_SINGLEQUOTE_$$):null;$before_path$jscomp$4_sets_SINGLEQUOTE_$$=
($before_group_QMARK_$jscomp$4_reorder_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prefixed_from_path_themes_SINGLEQUOTE__this$$jscomp$682$$,$prefixed_to_path_to_path$jscomp$4$$))?$app$common$data$oreorder_before$$($self__$jscomp$2872$$.$sets$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$butlast$$($prefixed_from_path_themes_SINGLEQUOTE__this$$jscomp$682$$)),$APP.$cljs$core$last$$($prefixed_from_path_themes_SINGLEQUOTE__this$$jscomp$682$$),
$prev_set_group$$,$APP.$cljs$core$last$$($prefixed_before_path$$)):$app$common$data$oupdate_in$$($APP.$app$common$data$dissoc_in$$($APP.$cljs$core$truth_$$($before_path$jscomp$4_sets_SINGLEQUOTE_$$)?$app$common$data$oassoc_in_before$$($self__$jscomp$2872$$.$sets$,$prefixed_before_path$$,$prefixed_to_path_to_path$jscomp$4$$,$prev_set_group$$):$app$common$data$oassoc_in$$($self__$jscomp$2872$$.$sets$,$prefixed_to_path_to_path$jscomp$4$$,$prev_set_group$$),$prefixed_from_path_themes_SINGLEQUOTE__this$$jscomp$682$$),
$prefixed_to_path_to_path$jscomp$4$$,function($sets__$1$jscomp$1$$){return $clojure$walk$prewalk$$(function($form$jscomp$150$$){return $app$common$types$tokens_lib$token_set_QMARK_$$($form$jscomp$150$$)?$APP.$app$common$types$tokens_lib$rename$$($form$jscomp$150$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($to_path_str$jscomp$2$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cuerdas$core$strip_prefix$$($APP.$app$common$types$tokens_lib$get_name$$($form$jscomp$150$$),$from_path_str$jscomp$2$$))].join("")):
$form$jscomp$150$$},$sets__$1$jscomp$1$$)});$prefixed_from_path_themes_SINGLEQUOTE__this$$jscomp$682$$=$before_group_QMARK_$jscomp$4_reorder_QMARK_$$?$self__$jscomp$2872$$.$themes$:function(){var $rename_sets_map$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($set$jscomp$4$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$4$$),
[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($to_path_str$jscomp$2$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cuerdas$core$strip_prefix$$($APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$4$$),$from_path_str$jscomp$2$$))].join("")],null)},$this$__$1$jscomp$363$$.$app$common$types$tokens_lib$ITokenSets$get_sets_at_path$arity$2$(null,$from_path$jscomp$4$$)));return $APP.$clojure$walk$postwalk$$(function($form$jscomp$151$$){return $form$jscomp$151$$ instanceof $app$common$types$tokens_lib$TokenTheme$$?
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($form$jscomp$151$$,$APP.$cljs$cst$2108$sets$$,function($p1__49917_SHARP_$$){return $APP.$cljs$core$set$$($APP.$cljs$core$replace$cljs$0core$0IFn$0_invoke$0arity$02$$($rename_sets_map$$,$p1__49917_SHARP_$$))}):$form$jscomp$151$$},$self__$jscomp$2872$$.$themes$)}();return new $app$common$types$tokens_lib$TokensLib$$($before_path$jscomp$4_sets_SINGLEQUOTE_$$,$prefixed_from_path_themes_SINGLEQUOTE__this$$jscomp$682$$,$self__$jscomp$2872$$.$active_themes$)}return new $app$common$types$tokens_lib$TokensLib$$($self__$jscomp$2872$$.$sets$,
$self__$jscomp$2872$$.$themes$,$self__$jscomp$2872$$.$active_themes$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSets$rename_set_group$arity$3$=function($sets__$1$jscomp$2_this$$jscomp$683$$,$path$jscomp$182$$,$path_fname$$){var $from_path_str$jscomp$3$$=$APP.$app$common$types$tokens_lib$join_set_path$$($path$jscomp$182$$),$to_path_str$jscomp$3$$=$APP.$app$common$types$tokens_lib$join_set_path$$($APP.$app$common$types$tokens_lib$replace_last_path_name$$($path$jscomp$182$$,$path_fname$$));$sets__$1$jscomp$2_this$$jscomp$683$$=this.$app$common$types$tokens_lib$ITokenSets$get_sets_at_path$arity$2$(null,
$path$jscomp$182$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($lib$$,$set$jscomp$5$$){return $app$common$types$tokens_lib$update_set$$($lib$$,$APP.$app$common$types$tokens_lib$get_id$$($set$jscomp$5$$),function($set_SINGLEQUOTE_$$){return $APP.$app$common$types$tokens_lib$rename$$($set_SINGLEQUOTE_$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($to_path_str$jscomp$3$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cuerdas$core$strip_prefix$$($APP.$app$common$types$tokens_lib$get_name$$($set_SINGLEQUOTE_$$),
$from_path_str$jscomp$3$$))].join(""))})},this,$sets__$1$jscomp$2_this$$jscomp$683$$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSets$get_sets_at_path$arity$2$=function($G__49946_G__49946__$1_G__49946__$2__$jscomp$1392$$,$path$jscomp$183$$){$G__49946_G__49946__$1_G__49946__$2__$jscomp$1392$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$tokens_lib$add_set_path_group_prefix$$,$path$jscomp$183$$);$G__49946_G__49946__$1_G__49946__$2__$jscomp$1392$$=$G__49946_G__49946__$1_G__49946__$2__$jscomp$1392$$==null?null:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$(this.$sets$,
$G__49946_G__49946__$1_G__49946__$2__$jscomp$1392$$);$G__49946_G__49946__$1_G__49946__$2__$jscomp$1392$$=$G__49946_G__49946__$1_G__49946__$2__$jscomp$1392$$==null?null:$APP.$cljs$core$tree_seq$$($APP.$app$common$data$ordered_map_QMARK_$$,$APP.$cljs$core$vals$$,$G__49946_G__49946__$1_G__49946__$2__$jscomp$1392$$);return $G__49946_G__49946__$1_G__49946__$2__$jscomp$1392$$==null?null:$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$core$instance_QMARK_$$,
$APP.$app$common$types$tokens_lib$TokenSet$$),$G__49946_G__49946__$1_G__49946__$2__$jscomp$1392$$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSets$update_set$arity$3$=function($prefixed_full_path_this$$jscomp$684$$,$id$jscomp$204_prefixed_full_path_SINGLEQUOTE__set$jscomp$6$$,$f$jscomp$788_set_SINGLEQUOTE_$jscomp$1$$){$id$jscomp$204_prefixed_full_path_SINGLEQUOTE__set$jscomp$6$$=this.$app$common$types$tokens_lib$ITokenSets$get_set$arity$2$(null,$id$jscomp$204_prefixed_full_path_SINGLEQUOTE__set$jscomp$6$$);var $name$jscomp$216$$=$APP.$app$common$types$tokens_lib$get_name$$($id$jscomp$204_prefixed_full_path_SINGLEQUOTE__set$jscomp$6$$);
$prefixed_full_path_this$$jscomp$684$$=$app$common$types$tokens_lib$set_full_path__GT_set_prefixed_full_path$$($APP.$app$common$types$tokens_lib$split_set_name$$($name$jscomp$216$$));if($APP.$cljs$core$truth_$$($id$jscomp$204_prefixed_full_path_SINGLEQUOTE__set$jscomp$6$$)){$f$jscomp$788_set_SINGLEQUOTE_$jscomp$1$$=$f$jscomp$788_set_SINGLEQUOTE_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$788_set_SINGLEQUOTE_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$204_prefixed_full_path_SINGLEQUOTE__set$jscomp$6$$):
$f$jscomp$788_set_SINGLEQUOTE_$jscomp$1$$($id$jscomp$204_prefixed_full_path_SINGLEQUOTE__set$jscomp$6$$);var $name_SINGLEQUOTE_$jscomp$2$$=$APP.$app$common$types$tokens_lib$get_name$$($f$jscomp$788_set_SINGLEQUOTE_$jscomp$1$$);$id$jscomp$204_prefixed_full_path_SINGLEQUOTE__set$jscomp$6$$=$app$common$types$tokens_lib$get_set_prefixed_path$$($f$jscomp$788_set_SINGLEQUOTE_$jscomp$1$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$216$$,$name_SINGLEQUOTE_$jscomp$2$$)?new $app$common$types$tokens_lib$TokensLib$$($app$common$data$oassoc_in$$(this.$sets$,
$prefixed_full_path_this$$jscomp$684$$,$f$jscomp$788_set_SINGLEQUOTE_$jscomp$1$$),this.$themes$,this.$active_themes$):new $app$common$types$tokens_lib$TokensLib$$($APP.$app$common$data$dissoc_in$$($app$common$data$oassoc_in_before$$(this.$sets$,$prefixed_full_path_this$$jscomp$684$$,$id$jscomp$204_prefixed_full_path_SINGLEQUOTE__set$jscomp$6$$,$f$jscomp$788_set_SINGLEQUOTE_$jscomp$1$$),$prefixed_full_path_this$$jscomp$684$$),$APP.$clojure$walk$postwalk$$(function($form$jscomp$152$$){return $form$jscomp$152$$ instanceof
$app$common$types$tokens_lib$TokenTheme$$?$JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenTheme$update_set_name$arity$3$$($form$jscomp$152$$,$name$jscomp$216$$,$name_SINGLEQUOTE_$jscomp$2$$):$form$jscomp$152$$},this.$themes$),this.$active_themes$)}return this};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSets$add_set$arity$2$=function($_$jscomp$1393_path$jscomp$184$$,$token_set$jscomp$5$$){$_$jscomp$1393_path$jscomp$184$$=$app$common$types$tokens_lib$get_set_prefixed_path$$($token_set$jscomp$5$$);return new $app$common$types$tokens_lib$TokensLib$$($app$common$data$oassoc_in$$(this.$sets$,$_$jscomp$1393_path$jscomp$184$$,$token_set$jscomp$5$$),this.$themes$,this.$active_themes$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSets$move_set$arity$5$=function($_$jscomp$1394_prefixed_from_path$jscomp$1$$,$from_path$jscomp$5_prefixed_to_path$jscomp$1$$,$reorder_QMARK_$jscomp$1_to_path$jscomp$5$$,$before_path$jscomp$5_sets_SINGLEQUOTE_$jscomp$1$$,$before_group_QMARK_$jscomp$5_prefixed_before_path$jscomp$1$$){$_$jscomp$1394_prefixed_from_path$jscomp$1$$=$app$common$types$tokens_lib$set_full_path__GT_set_prefixed_full_path$$($from_path$jscomp$5_prefixed_to_path$jscomp$1$$);
var $prev_set$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$(this.$sets$,$_$jscomp$1394_prefixed_from_path$jscomp$1$$);if($prev_set$$ instanceof $APP.$app$common$types$tokens_lib$TokenSet$$){$from_path$jscomp$5_prefixed_to_path$jscomp$1$$=$app$common$types$tokens_lib$set_full_path__GT_set_prefixed_full_path$$($reorder_QMARK_$jscomp$1_to_path$jscomp$5$$);$before_group_QMARK_$jscomp$5_prefixed_before_path$jscomp$1$$=$APP.$cljs$core$truth_$$($before_path$jscomp$5_sets_SINGLEQUOTE_$jscomp$1$$)?
$APP.$cljs$core$truth_$$($before_group_QMARK_$jscomp$5_prefixed_before_path$jscomp$1$$)?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$tokens_lib$add_set_path_group_prefix$$,$before_path$jscomp$5_sets_SINGLEQUOTE_$jscomp$1$$):$app$common$types$tokens_lib$set_full_path__GT_set_prefixed_full_path$$($before_path$jscomp$5_sets_SINGLEQUOTE_$jscomp$1$$):null;var $set$jscomp$7$$=$prev_set$$.$app$common$types$tokens_lib$INamedItem$rename$arity$2$(null,$APP.$app$common$types$tokens_lib$join_set_path$$($reorder_QMARK_$jscomp$1_to_path$jscomp$5$$));
$before_path$jscomp$5_sets_SINGLEQUOTE_$jscomp$1$$=($reorder_QMARK_$jscomp$1_to_path$jscomp$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1394_prefixed_from_path$jscomp$1$$,$from_path$jscomp$5_prefixed_to_path$jscomp$1$$))?$app$common$data$oreorder_before$$(this.$sets$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$butlast$$($_$jscomp$1394_prefixed_from_path$jscomp$1$$)),$APP.$cljs$core$last$$($_$jscomp$1394_prefixed_from_path$jscomp$1$$),
$set$jscomp$7$$,$APP.$cljs$core$last$$($before_group_QMARK_$jscomp$5_prefixed_before_path$jscomp$1$$)):$APP.$app$common$data$dissoc_in$$($APP.$cljs$core$truth_$$($before_path$jscomp$5_sets_SINGLEQUOTE_$jscomp$1$$)?$app$common$data$oassoc_in_before$$(this.$sets$,$before_group_QMARK_$jscomp$5_prefixed_before_path$jscomp$1$$,$from_path$jscomp$5_prefixed_to_path$jscomp$1$$,$set$jscomp$7$$):$app$common$data$oassoc_in$$(this.$sets$,$from_path$jscomp$5_prefixed_to_path$jscomp$1$$,$set$jscomp$7$$),$_$jscomp$1394_prefixed_from_path$jscomp$1$$);
return new $app$common$types$tokens_lib$TokensLib$$($before_path$jscomp$5_sets_SINGLEQUOTE_$jscomp$1$$,$reorder_QMARK_$jscomp$1_to_path$jscomp$5$$?this.$themes$:$APP.$clojure$walk$postwalk$$(function($form$jscomp$153$$){return $form$jscomp$153$$ instanceof $app$common$types$tokens_lib$TokenTheme$$?$JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenTheme$update_set_name$arity$3$$($form$jscomp$153$$,$prev_set$$.name,$APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$7$$)):$form$jscomp$153$$},
this.$themes$),this.$active_themes$)}return new $app$common$types$tokens_lib$TokensLib$$(this.$sets$,this.$themes$,this.$active_themes$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSets$delete_set$arity$2$=function($prefixed_path_set$jscomp$8_this$$jscomp$685$$,$id$jscomp$205$$){$prefixed_path_set$jscomp$8_this$$jscomp$685$$=this.$app$common$types$tokens_lib$ITokenSets$get_set$arity$2$(null,$id$jscomp$205$$);var $set_name$jscomp$19$$=$APP.$app$common$types$tokens_lib$get_name$$($prefixed_path_set$jscomp$8_this$$jscomp$685$$);$prefixed_path_set$jscomp$8_this$$jscomp$685$$=$app$common$types$tokens_lib$set_full_path__GT_set_prefixed_full_path$$($APP.$app$common$types$tokens_lib$split_set_name$$($set_name$jscomp$19$$));
return new $app$common$types$tokens_lib$TokensLib$$($APP.$app$common$data$dissoc_in$$(this.$sets$,$prefixed_path_set$jscomp$8_this$$jscomp$685$$),$APP.$clojure$walk$postwalk$$(function($form$jscomp$154$$){return $form$jscomp$154$$ instanceof $app$common$types$tokens_lib$TokenTheme$$?$form$jscomp$154$$.$app$common$types$tokens_lib$ITokenTheme$disable_set$arity$2$(null,$set_name$jscomp$19$$):$form$jscomp$154$$},this.$themes$),this.$active_themes$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenSets$get_set$arity$2$=function($this$$jscomp$686$$,$id$jscomp$206$$){return $APP.$cljs$core$some$$(function($p1__49918_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$tokens_lib$get_id$$($p1__49918_SHARP_$$),$id$jscomp$206$$)?$p1__49918_SHARP_$$:null},this.$app$common$types$tokens_lib$ITokenSets$get_sets$arity$1$(null))};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$activate_theme$arity$2$=function($active_themes_SINGLEQUOTE__temp__5823__auto__$jscomp$117_this$$jscomp$687$$,$group$jscomp$21_group_themes_id$jscomp$207$$){$active_themes_SINGLEQUOTE__temp__5823__auto__$jscomp$117_this$$jscomp$687$$=this.$app$common$types$tokens_lib$ITokenThemes$get_theme$arity$2$(null,$group$jscomp$21_group_themes_id$jscomp$207$$);return $APP.$cljs$core$truth_$$($active_themes_SINGLEQUOTE__temp__5823__auto__$jscomp$117_this$$jscomp$687$$)?
($group$jscomp$21_group_themes_id$jscomp$207$$=$APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($active_themes_SINGLEQUOTE__temp__5823__auto__$jscomp$117_this$$jscomp$687$$),$group$jscomp$21_group_themes_id$jscomp$207$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$tokens_lib$get_theme_path$$,$APP.$cljs$core$val$$),
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this.$themes$,$group$jscomp$21_group_themes_id$jscomp$207$$))),$active_themes_SINGLEQUOTE__temp__5823__auto__$jscomp$117_this$$jscomp$687$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$(this.$active_themes$,$group$jscomp$21_group_themes_id$jscomp$207$$),$APP.$app$common$types$tokens_lib$get_theme_path$$($active_themes_SINGLEQUOTE__temp__5823__auto__$jscomp$117_this$$jscomp$687$$)),
new $app$common$types$tokens_lib$TokensLib$$(this.$sets$,this.$themes$,$active_themes_SINGLEQUOTE__temp__5823__auto__$jscomp$117_this$$jscomp$687$$)):this};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$theme_active_QMARK_$arity$2$=function($temp__5825__auto__$jscomp$133_this$$jscomp$689$$,$id$jscomp$208$$){$temp__5825__auto__$jscomp$133_this$$jscomp$689$$=this.$app$common$types$tokens_lib$ITokenThemes$get_theme$arity$2$(null,$id$jscomp$208$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$133_this$$jscomp$689$$)?$APP.$cljs$core$contains_QMARK_$$(this.$active_themes$,$APP.$app$common$types$tokens_lib$get_theme_path$$($temp__5825__auto__$jscomp$133_this$$jscomp$689$$)):
null};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$deactivate_theme$arity$2$=function($temp__5823__auto__$jscomp$118_this$$jscomp$690$$,$id$jscomp$209$$){$temp__5823__auto__$jscomp$118_this$$jscomp$690$$=this.$app$common$types$tokens_lib$ITokenThemes$get_theme$arity$2$(null,$id$jscomp$209$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$118_this$$jscomp$690$$)?new $app$common$types$tokens_lib$TokensLib$$(this.$sets$,this.$themes$,$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$(this.$active_themes$,$APP.$app$common$types$tokens_lib$get_theme_path$$($temp__5823__auto__$jscomp$118_this$$jscomp$690$$))):
this};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$delete_theme$arity$2$=function($theme$jscomp$4_this$$jscomp$691$$,$group$jscomp$22_id$jscomp$210$$){$theme$jscomp$4_this$$jscomp$691$$=this.$app$common$types$tokens_lib$ITokenThemes$get_theme$arity$2$(null,$group$jscomp$22_id$jscomp$210$$);var $name$jscomp$217_vec__49956$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$4_this$$jscomp$691$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$4_this$$jscomp$691$$)],
null);$group$jscomp$22_id$jscomp$210$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$217_vec__49956$$,0,null);$name$jscomp$217_vec__49956$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$217_vec__49956$$,1,null);return $APP.$cljs$core$truth_$$($theme$jscomp$4_this$$jscomp$691$$)?new $app$common$types$tokens_lib$TokensLib$$(this.$sets$,$APP.$app$common$data$dissoc_in$$(this.$themes$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$group$jscomp$22_id$jscomp$210$$,$name$jscomp$217_vec__49956$$],null)),$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$(this.$active_themes$,$app$common$types$tokens_lib$join_theme_path$$($group$jscomp$22_id$jscomp$210$$,$name$jscomp$217_vec__49956$$))):this};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$toggle_theme_active$arity$2$=function($this$$jscomp$692$$,$id$jscomp$211$$){return $APP.$cljs$core$truth_$$(this.$app$common$types$tokens_lib$ITokenThemes$theme_active_QMARK_$arity$2$(null,$id$jscomp$211$$))?this.$app$common$types$tokens_lib$ITokenThemes$deactivate_theme$arity$2$(null,$id$jscomp$211$$):this.$app$common$types$tokens_lib$ITokenThemes$activate_theme$arity$2$(null,$id$jscomp$211$$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$add_theme$arity$2$=function($_$jscomp$1395_token_theme__$1$$,$token_theme$jscomp$2$$){$_$jscomp$1395_token_theme__$1$$=$app$common$types$tokens_lib$check_token_theme$$($token_theme$jscomp$2$$);return new $app$common$types$tokens_lib$TokensLib$$(this.$sets$,$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$(this.$themes$,$APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1395_token_theme__$1$$),$app$common$data$oassoc$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1395_token_theme__$1$$),$_$jscomp$1395_token_theme__$1$$),this.$active_themes$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$get_theme$arity$2$=function($this$$jscomp$693$$,$id$jscomp$212$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__49922_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__49922_SHARP_$$),$id$jscomp$212$$)},this.$app$common$types$tokens_lib$ITokenThemes$get_themes$arity$1$(null))};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$get_theme_by_name$arity$3$=function($_$jscomp$1396$$,$group$jscomp$23$$,$name$jscomp$218$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this.$themes$,$group$jscomp$23$$),$name$jscomp$218$$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$get_theme_groups$arity$1$=function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$key$$),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($app$common$types$tokens_lib$top_level_theme_group_QMARK_$$)),this.$themes$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$get_themes$arity$1$=function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$core$instance_QMARK_$$,$app$common$types$tokens_lib$TokenTheme$$),$APP.$cljs$core$tree_seq$$($APP.$app$common$data$ordered_map_QMARK_$$,$APP.$cljs$core$vals$$,this.$themes$))};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$get_active_theme_paths$arity$1$=function(){return this.$active_themes$};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$update_theme$arity$3$=function($group$jscomp$24_this$$jscomp$694$$,$id$jscomp$213_name$jscomp$219$$,$f$jscomp$789_theme_SINGLEQUOTE_$$){var $group_SINGLEQUOTE__temp__5823__auto__$jscomp$119$$=this.$app$common$types$tokens_lib$ITokenThemes$get_theme$arity$2$(null,$id$jscomp$213_name$jscomp$219$$);if($APP.$cljs$core$truth_$$($group_SINGLEQUOTE__temp__5823__auto__$jscomp$119$$)){$group$jscomp$24_this$$jscomp$694$$=$APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($group_SINGLEQUOTE__temp__5823__auto__$jscomp$119$$);
$id$jscomp$213_name$jscomp$219$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($group_SINGLEQUOTE__temp__5823__auto__$jscomp$119$$);$f$jscomp$789_theme_SINGLEQUOTE_$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$types$tokens_lib$make_token_theme$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$f$jscomp$789_theme_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$789_theme_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$1$($group_SINGLEQUOTE__temp__5823__auto__$jscomp$119$$):
$f$jscomp$789_theme_SINGLEQUOTE_$$($group_SINGLEQUOTE__temp__5823__auto__$jscomp$119$$)])),$APP.$cljs$cst$1737$modified_at$$,$APP.$app$common$time$now$$());$group_SINGLEQUOTE__temp__5823__auto__$jscomp$119$$=$APP.$cljs$cst$1608$group$$.$cljs$core$IFn$_invoke$arity$1$($f$jscomp$789_theme_SINGLEQUOTE_$$);var $name_SINGLEQUOTE_$jscomp$3$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($f$jscomp$789_theme_SINGLEQUOTE_$$),$same_group_QMARK__same_path_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($group$jscomp$24_this$$jscomp$694$$,
$group_SINGLEQUOTE__temp__5823__auto__$jscomp$119$$),$same_name_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$213_name$jscomp$219$$,$name_SINGLEQUOTE_$jscomp$3$$);$same_group_QMARK__same_path_QMARK_$$=$same_group_QMARK__same_path_QMARK_$$&&$same_name_QMARK_$$;return new $app$common$types$tokens_lib$TokensLib$$(this.$sets$,$same_group_QMARK__same_path_QMARK_$$?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$(this.$themes$,$group_SINGLEQUOTE__temp__5823__auto__$jscomp$119$$,
$APP.$cljs$core$assoc$$,$name_SINGLEQUOTE_$jscomp$3$$,$f$jscomp$789_theme_SINGLEQUOTE_$$):$APP.$app$common$data$dissoc_in$$($app$common$data$oassoc_in_before$$(this.$themes$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$group$jscomp$24_this$$jscomp$694$$,$id$jscomp$213_name$jscomp$219$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$group_SINGLEQUOTE__temp__5823__auto__$jscomp$119$$,$name_SINGLEQUOTE_$jscomp$3$$],
null),$f$jscomp$789_theme_SINGLEQUOTE_$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$group$jscomp$24_this$$jscomp$694$$,$id$jscomp$213_name$jscomp$219$$],null)),$same_group_QMARK__same_path_QMARK_$$?this.$active_themes$:$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$(this.$active_themes$,$app$common$types$tokens_lib$join_theme_path$$($group$jscomp$24_this$$jscomp$694$$,$id$jscomp$213_name$jscomp$219$$)))}return this};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$get_hidden_theme$arity$1$=function(){return this.$app$common$types$tokens_lib$ITokenThemes$get_theme$arity$2$(null,$APP.$app$common$uuid$zero$$)};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$get_theme_tree$arity$1$=function(){return this.$themes$};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokenThemes$set_active_themes$arity$2$=function($_$jscomp$1401$$,$active_themes__$1$$){return new $app$common$types$tokens_lib$TokensLib$$(this.$sets$,this.$themes$,$active_themes__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$get_token$arity$3$=function($G__49974__$1_this$$jscomp$698$$,$set_id$jscomp$10$$,$token_id$jscomp$9$$){$G__49974__$1_this$$jscomp$698$$=this==null?null:this.$app$common$types$tokens_lib$ITokenSets$get_set$arity$2$(null,$set_id$jscomp$10$$);return $G__49974__$1_this$$jscomp$698$$==null?null:$app$common$types$tokens_lib$get_token_$$($G__49974__$1_this$$jscomp$698$$,$token_id$jscomp$9$$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$get_all_tokens_map$arity$1$=function(){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($tokens_SINGLEQUOTE_$jscomp$1$$,$set$jscomp$9$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($tokens_SINGLEQUOTE_$jscomp$1$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($x$jscomp$1130$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$1130$$),$x$jscomp$1130$$],null)},$APP.$cljs$core$vals$$($APP.$app$common$types$tokens_lib$get_tokens_$$($set$jscomp$9$$))))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,this.$app$common$types$tokens_lib$ITokenSets$get_sets$arity$1$(null))};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$get_tokens$arity$2$=function($G__49975__$1_this$$jscomp$700$$,$set_id$jscomp$11$$){$G__49975__$1_this$$jscomp$700$$=this==null?null:this.$app$common$types$tokens_lib$ITokenSets$get_set$arity$2$(null,$set_id$jscomp$11$$);return $G__49975__$1_this$$jscomp$700$$==null?null:$APP.$app$common$types$tokens_lib$get_tokens_$$($G__49975__$1_this$$jscomp$700$$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$update_token$arity$4$=function($this$$jscomp$701$$,$set_id$jscomp$12$$,$token_id$jscomp$10$$,$f$jscomp$790$$){return this.$app$common$types$tokens_lib$ITokenSets$update_set$arity$3$(null,$set_id$jscomp$12$$,function($p1__49926_SHARP_$$){return $app$common$types$tokens_lib$update_token_$$($p1__49926_SHARP_$$,$token_id$jscomp$10$$,$f$jscomp$790$$)})};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$set_path_exists_QMARK_$arity$2$=function($_$jscomp$1402$$,$set_path$jscomp$1$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$(this.$sets$,$app$common$types$tokens_lib$set_full_path__GT_set_prefixed_full_path$$($set_path$jscomp$1$$))!=null};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$sets_at_path_all_active_QMARK_$arity$2$=function($active_set_names_this$$jscomp$702$$,$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$){$active_set_names_this$$jscomp$702$$=this.$app$common$types$tokens_lib$ITokensLib$get_active_themes_set_names$arity$1$(null);$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$=
$APP.$app$common$types$tokens_lib$join_set_path$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$tokens_lib$add_set_path_group_prefix$$,$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$));if($APP.$cljs$core$seq$$($active_set_names_this$$jscomp$702$$)){$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$(this.$sets$,$APP.$app$common$types$tokens_lib$split_set_name$$($G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$));$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$=$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$==
null?null:$APP.$cljs$core$tree_seq$$($APP.$app$common$data$ordered_map_QMARK_$$,$APP.$cljs$core$vals$$,$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$);$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$=$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$==
null?null:$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$core$instance_QMARK_$$,$APP.$app$common$types$tokens_lib$TokenSet$$),$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$);$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$=
$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$==null?null:$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$tokens_lib$get_name$$,$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$);$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$=
$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$==null?null:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$);var $difference$$=
$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$,$active_set_names_this$$jscomp$702$$);return $APP.$cljs$core$empty_QMARK_$$($difference$$)?$APP.$cljs$cst$2124$all$$:$APP.$cljs$core$seq$$($APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($G__49980$jscomp$inline_5557_G__49980__$1$jscomp$inline_5558_G__49980__$2$jscomp$inline_5559_G__49980__$3$jscomp$inline_5560_group_path$jscomp$3_path_active_set_names_prefixed_path_str$$,
$active_set_names_this$$jscomp$702$$))?$APP.$cljs$cst$2125$partial$$:$APP.$cljs$cst$226$none$$}return $APP.$cljs$cst$226$none$$};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$add_token$arity$3$=function($this$$jscomp$703$$,$set_id$jscomp$13$$,$token$jscomp$55$$){return this.$app$common$types$tokens_lib$ITokenSets$update_set$arity$3$(null,$set_id$jscomp$13$$,function($p1__49925_SHARP_$$){return $app$common$types$tokens_lib$add_token_$$($p1__49925_SHARP_$$,$token$jscomp$55$$)})};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$delete_token$arity$3$=function($this$$jscomp$704$$,$set_id$jscomp$14$$,$token_id$jscomp$11$$){return this.$app$common$types$tokens_lib$ITokenSets$update_set$arity$3$(null,$set_id$jscomp$14$$,function($p1__49927_SHARP_$$){return $app$common$types$tokens_lib$delete_token_$$($p1__49927_SHARP_$$,$token_id$jscomp$11$$)})};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$empty_lib_QMARK_$arity$1$=function(){var $JSCompiler_temp_const$jscomp$886_and__5023__auto__$jscomp$277_and__5023__auto____$1$jscomp$51_or__5025__auto__$jscomp$400$$=$APP.$cljs$core$empty_QMARK_$$(this.$sets$);if($JSCompiler_temp_const$jscomp$886_and__5023__auto__$jscomp$277_and__5023__auto____$1$jscomp$51_or__5025__auto__$jscomp$400$$){if($JSCompiler_temp_const$jscomp$886_and__5023__auto__$jscomp$277_and__5023__auto____$1$jscomp$51_or__5025__auto__$jscomp$400$$=
$APP.$cljs$core$empty_QMARK_$$(this.$themes$))return $JSCompiler_temp_const$jscomp$886_and__5023__auto__$jscomp$277_and__5023__auto____$1$jscomp$51_or__5025__auto__$jscomp$400$$;$JSCompiler_temp_const$jscomp$886_and__5023__auto__$jscomp$277_and__5023__auto____$1$jscomp$51_or__5025__auto__$jscomp$400$$=$APP.$cljs$core$_EQ_$$;var $JSCompiler_temp_const$jscomp$885$$=$JSCompiler_temp_const$jscomp$886_and__5023__auto__$jscomp$277_and__5023__auto____$1$jscomp$51_or__5025__auto__$jscomp$400$$.$cljs$core$IFn$_invoke$arity$2$;
var $JSCompiler_inline_result$jscomp$887$$=$APP.$cljs$core$count$$(this.$app$common$types$tokens_lib$ITokenThemes$get_themes$arity$1$(null));return($JSCompiler_temp_const$jscomp$886_and__5023__auto__$jscomp$277_and__5023__auto____$1$jscomp$51_or__5025__auto__$jscomp$400$$=$JSCompiler_temp_const$jscomp$885$$.call($JSCompiler_temp_const$jscomp$886_and__5023__auto__$jscomp$277_and__5023__auto____$1$jscomp$51_or__5025__auto__$jscomp$400$$,$JSCompiler_inline_result$jscomp$887$$,1))?this.$app$common$types$tokens_lib$ITokenThemes$get_hidden_theme$arity$1$(null):
$JSCompiler_temp_const$jscomp$886_and__5023__auto__$jscomp$277_and__5023__auto____$1$jscomp$51_or__5025__auto__$jscomp$400$$}return $JSCompiler_temp_const$jscomp$886_and__5023__auto__$jscomp$277_and__5023__auto____$1$jscomp$51_or__5025__auto__$jscomp$400$$};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$get_all_tokens$arity$1$=function(){return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__49932_SHARP_$$){return $APP.$cljs$core$vals$$($APP.$app$common$types$tokens_lib$get_tokens_$$($p1__49932_SHARP_$$))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$app$common$types$tokens_lib$ITokenSets$get_sets$arity$1$(null)]))};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$set_group_path_exists_QMARK_$arity$2$=function($_$jscomp$1403$$,$set_path$jscomp$2$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$(this.$sets$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$tokens_lib$add_set_path_group_prefix$$,$set_path$jscomp$2$$))!=null};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$get_tokens_in_active_sets$arity$1$=function(){var $this$__$1$jscomp$388$$=this,$active_set_names$jscomp$1_theme_set_names$$=$this$__$1$jscomp$388$$.$app$common$types$tokens_lib$ITokensLib$get_active_themes_set_names$arity$1$(null),$all_set_names$$=$this$__$1$jscomp$388$$.$app$common$types$tokens_lib$ITokenSets$get_set_names$arity$1$(null);$active_set_names$jscomp$1_theme_set_names$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($active_set_names$jscomp$1_theme_set_names$$,
$all_set_names$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($tokens$jscomp$12$$,$set$jscomp$10_set_name$jscomp$21$$){$set$jscomp$10_set_name$jscomp$21$$=$this$__$1$jscomp$388$$.$app$common$types$tokens_lib$ITokenSets$get_set_by_name$arity$2$(null,$set$jscomp$10_set_name$jscomp$21$$);return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tokens$jscomp$12$$,$APP.$app$common$types$tokens_lib$get_tokens_$$($set$jscomp$10_set_name$jscomp$21$$)]))},
$APP.$linked$map$empty_linked_map$$,$active_set_names$jscomp$1_theme_set_names$$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$get_tokens_in_active_sets_force$arity$2$=function($active_set_names$jscomp$2_this$$jscomp$709$$,$force_set_id$jscomp$2$$){var $this$__$1$jscomp$390$$=this,$theme_set_names$jscomp$1$$=$this$__$1$jscomp$390$$.$app$common$types$tokens_lib$ITokensLib$get_active_themes_set_names$arity$1$(null),$all_set_names$jscomp$1$$=$this$__$1$jscomp$390$$.$app$common$types$tokens_lib$ITokenSets$get_set_names$arity$1$(null),$force_set$$=$this$__$1$jscomp$390$$.$app$common$types$tokens_lib$ITokenSets$get_set$arity$2$(null,
$force_set_id$jscomp$2$$);$active_set_names$jscomp$2_this$$jscomp$709$$=function(){var $G__49987$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($theme_set_names$jscomp$1$$,$all_set_names$jscomp$1$$);return $force_set$$!=null?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__49987$$,$APP.$app$common$types$tokens_lib$get_name$$($force_set$$)):$G__49987$$}();return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($tokens$jscomp$14$$,$set$jscomp$11_set_name$jscomp$23$$){$set$jscomp$11_set_name$jscomp$23$$=
$this$__$1$jscomp$390$$.$app$common$types$tokens_lib$ITokenSets$get_set_by_name$arity$2$(null,$set$jscomp$11_set_name$jscomp$23$$);return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tokens$jscomp$14$$,$APP.$app$common$types$tokens_lib$get_tokens_$$($set$jscomp$11_set_name$jscomp$23$$)]))},$APP.$linked$map$empty_linked_map$$,$active_set_names$jscomp$2_this$$jscomp$709$$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$token_set_active_QMARK_$arity$2$=function($set_names$jscomp$9_this$$jscomp$710$$,$set_name$jscomp$24$$){$set_names$jscomp$9_this$$jscomp$710$$=this.$app$common$types$tokens_lib$ITokensLib$get_active_themes_set_names$arity$1$(null);return $APP.$cljs$core$contains_QMARK_$$($set_names$jscomp$9_this$$jscomp$710$$,$set_name$jscomp$24$$)};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$ITokensLib$get_active_themes_set_names$arity$1$=function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2108$sets$$),$JSCompiler_StaticMethods_app$common$types$tokens_lib$ITokenThemes$get_active_themes$arity$1$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$tokens_lib$IValidation$valid_QMARK_$arity$1$=function(){var $G__49993$$=$APP.$clojure$datafy$datafy$$(this);return $app$common$types$tokens_lib$valid_tokens_lib_map_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$tokens_lib$valid_tokens_lib_map_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__49993$$):$app$common$types$tokens_lib$valid_tokens_lib_map_QMARK_$$($G__49993$$)};
$cljs$pprint$simple_dispatch$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$app$common$types$tokens_lib$TokensLib$$,function($obj$jscomp$177$$){$cljs$core$_STAR_out_STAR_$$.write("#penpot/tokens-lib ");$cljs$pprint$pprint_newline$$($cljs$cst$288$miser$$);return $cljs$pprint$pprint$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$tokens_lib$export_dtcg_json$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$tokens_lib$export_dtcg_json$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$177$$):
$APP.$app$common$types$tokens_lib$export_dtcg_json$$($obj$jscomp$177$$))});$app$common$types$tokens_lib$TokensLib$$.prototype.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$app$common$types$tokens_lib$TokensLib$$.prototype.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$714$$,$writer$jscomp$168$$,$opts$jscomp$257$$){$APP.$cljs$core$_write$$($writer$jscomp$168$$,"#penpot/tokens-lib ");return $APP.$cljs$core$_pr_writer$$($APP.$app$common$types$tokens_lib$export_dtcg_json$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$tokens_lib$export_dtcg_json$$.$cljs$core$IFn$_invoke$arity$1$(this):$APP.$app$common$types$tokens_lib$export_dtcg_json$$(this),
$writer$jscomp$168$$,$opts$jscomp$257$$)};$app$common$types$tokens_lib$TokensLib$$.prototype.$cljs$core$IEncodeJS$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$app$common$types$tokens_lib$TokensLib$$.prototype.$cljs$core$IEncodeJS$_clj__GT_js$arity$1$=function(){return $APP.$cljs$core$clj__GT_js$$($APP.$clojure$datafy$datafy$$(this))};
$app$common$types$tokens_lib$schema_COLON_tokens_lib_map$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"TokensLib"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2108$sets$$,$app$common$types$tokens_lib$schema_COLON_token_sets$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2122$themes$$,$app$common$types$tokens_lib$schema_COLON_token_themes$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2123$active_themes$$,$app$common$types$tokens_lib$schema_COLON_active_themes$$],null)],null);$app$common$types$tokens_lib$valid_tokens_lib_map_QMARK_$$=$app$common$schema$lazy_validator$$($app$common$types$tokens_lib$schema_COLON_tokens_lib_map$$);
$app$common$types$tokens_lib$check_tokens_lib_map$$=$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$types$tokens_lib$schema_COLON_tokens_lib_map$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,"invalid tokens-lib internal data structure"]));
$app$common$types$tokens_lib$schema_COLON_tokens_lib$$=$app$common$schema$type_schema$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$2128$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_tokens_lib$$,$APP.$cljs$cst$351$pred$$,function($o$jscomp$259$$){var $and__5023__auto__$jscomp$278$$=$o$jscomp$259$$ instanceof $app$common$types$tokens_lib$TokensLib$$;return $and__5023__auto__$jscomp$278$$?
$app$common$types$tokens_lib$valid_QMARK_$$($o$jscomp$259$$):$and__5023__auto__$jscomp$278$$},$cljs$cst$415$type_properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$941$encode_SLASH_json$$,function($p1__50019_SHARP_$$){return $p1__50019_SHARP_$$==null?null:$APP.$app$common$types$tokens_lib$export_dtcg_json$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$tokens_lib$export_dtcg_json$$.$cljs$core$IFn$_invoke$arity$1$($p1__50019_SHARP_$$):$APP.$app$common$types$tokens_lib$export_dtcg_json$$($p1__50019_SHARP_$$)},
$APP.$cljs$cst$938$decode_SLASH_json$$,function($p1__50020_SHARP_$$){return $p1__50020_SHARP_$$==null?null:$app$common$types$tokens_lib$read_multi_set_dtcg$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$types$tokens_lib$read_multi_set_dtcg$$.$cljs$core$IFn$_invoke$arity$1$($p1__50020_SHARP_$$):$app$common$types$tokens_lib$read_multi_set_dtcg$$($p1__50020_SHARP_$$)},$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$fmap$$(function(){return $APP.$app$common$types$tokens_lib$make_tokens_lib$$()},
$app$common$schema$generators$small_int$$())],null)],null)]));
$APP.$app$common$types$tokens_lib$legacy_node_QMARK_$$=$app$common$schema$validator$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["value",$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["type",$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["value",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$720$sequential$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["type",$APP.$cljs$cst$198$string$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["type",$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["value",$APP.$cljs$cst$202$map$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["type",$APP.$cljs$cst$198$string$$],null)],null)],null));
$app$common$types$tokens_lib$schema_COLON_dtcg_node$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$298$schema$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$352$registry$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$2129$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_simple_value$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,$APP.$cljs$cst$198$string$$,
$cljs$cst$344$int$$,$cljs$cst$345$double$$,$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$],null),$cljs$cst$2130$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_value$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$550$ref$$,$cljs$cst$2129$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_simple_value$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$cljs$cst$2129$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_simple_value$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,$APP.$cljs$cst$198$string$$,$cljs$cst$2129$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_simple_value$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$550$ref$$,$cljs$cst$2129$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_simple_value$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$cljs$cst$2129$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_simple_value$$],null)],null)],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["$type",$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["$value",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$550$ref$$,$cljs$cst$2130$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_value$$],null)],null)],null)],null);$APP.$app$common$types$tokens_lib$dtcg_node_QMARK_$$=$app$common$schema$validator$$($app$common$types$tokens_lib$schema_COLON_dtcg_node$$);
$APP.$app$common$types$tokens_lib$flatten_nested_tokens_json$$=function $app$common$types$tokens_lib$flatten_nested_tokens_json$$($decoded_json_tokens$$,$parent_path$jscomp$4$$){return $APP.$cljs$core$reduce_kv$$(function($tokens$jscomp$15$$,$child_path$jscomp$1_k$jscomp$601$$,$v$jscomp$536$$){$child_path$jscomp$1_k$jscomp$601$$=$APP.$cljs$core$empty_QMARK_$$($parent_path$jscomp$4$$)?$APP.$cljs$core$name$$($child_path$jscomp$1_k$jscomp$601$$):[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($parent_path$jscomp$4$$),
".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($child_path$jscomp$1_k$jscomp$601$$)].join("");if($APP.$cljs$core$map_QMARK_$$($v$jscomp$536$$)&&!$APP.$cljs$core$contains_QMARK_$$($v$jscomp$536$$,"$type"))return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tokens$jscomp$15$$,$app$common$types$tokens_lib$flatten_nested_tokens_json$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$types$tokens_lib$flatten_nested_tokens_json$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$536$$,
$child_path$jscomp$1_k$jscomp$601$$):$app$common$types$tokens_lib$flatten_nested_tokens_json$$($v$jscomp$536$$,$child_path$jscomp$1_k$jscomp$601$$)]));var $token_type$jscomp$1$$=function(){var $G__50065$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$536$$,"$type");return $APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$($G__50065$$):(0,$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$)($G__50065$$)}();
return $APP.$cljs$core$truth_$$($token_type$jscomp$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($tokens$jscomp$15$$,$child_path$jscomp$1_k$jscomp$601$$,$APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,$child_path$jscomp$1_k$jscomp$601$$,$APP.$cljs$cst$139$type$$,$token_type$jscomp$1$$,$APP.$cljs$cst$260$value$$,function(){var $token_value$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$536$$,
"$value");switch($token_type$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$token_type$jscomp$1$$.$fqn$:null){case "font-family":return $APP.$app$common$types$tokens_lib$convert_dtcg_font_family$$($token_value$jscomp$3$$);case "typography":return $APP.$app$common$types$tokens_lib$convert_dtcg_typography_composite$$($token_value$jscomp$3$$);case "shadow":return $APP.$app$common$types$tokens_lib$convert_dtcg_shadow_composite$$($token_value$jscomp$3$$);default:return $token_value$jscomp$3$$}}(),$APP.$cljs$cst$936$description$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$536$$,"$description")]))):$tokens$jscomp$15$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$decoded_json_tokens$$)};
$app$common$types$tokens_lib$schema_COLON_multi_set_dtcg$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$298$schema$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$352$registry$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2105$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_node$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$550$ref$$,$cljs$cst$2105$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_node$$],null)],null),$app$common$types$tokens_lib$schema_COLON_dtcg_node$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["$themes",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Theme"],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["id",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["name",$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["description",$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["isSource",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["selectedTokenSets",new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$499$enum$$,"enabled","disabled"],null)],null)],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["$metadata",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Metadata"],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["tokenSetOrder",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["activeThemes",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["activeSets",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$198$string$$],
null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$379$malli_DOT_core_SLASH_default$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$550$ref$$,$cljs$cst$2105$app_DOT_common_DOT_types_DOT_tokens_lib_SLASH_node$$],null)],
null)],null)],null)],null);$app$common$types$tokens_lib$check_multi_set_dtcg_data$$=$app$common$schema$check_fn$$($app$common$types$tokens_lib$schema_COLON_multi_set_dtcg$$);$app$common$types$tokens_lib$decode_multi_set_dtcg_data$$=$malli$core$decoder$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$tokens_lib$schema_COLON_multi_set_dtcg$$);
$APP.$app$common$transit$add_handlers_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"penpot/tokens-lib",$APP.$cljs$cst$1291$class$$,$app$common$types$tokens_lib$TokensLib$$,$APP.$cljs$cst$1314$wfn$$,$APP.$clojure$datafy$datafy$$,$APP.$cljs$cst$1315$rfn$$,function($p1__50094_SHARP_$$){return $app$common$types$tokens_lib$make_tokens_lib$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__50094_SHARP_$$]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"penpot/token-set",$APP.$cljs$cst$1291$class$$,$APP.$app$common$types$tokens_lib$TokenSet$$,$APP.$cljs$cst$1314$wfn$$,$APP.$clojure$datafy$datafy$$,$APP.$cljs$cst$1315$rfn$$,function($p1__50095_SHARP_$$){return $APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__50095_SHARP_$$]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$266$id$$,"penpot/token-theme",$APP.$cljs$cst$1291$class$$,$app$common$types$tokens_lib$TokenTheme$$,$APP.$cljs$cst$1314$wfn$$,$APP.$clojure$datafy$datafy$$,$APP.$cljs$cst$1315$rfn$$,function($p1__50096_SHARP_$$){return $app$common$types$tokens_lib$map__GT_TokenTheme$$($p1__50096_SHARP_$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"penpot/token",$APP.$cljs$cst$1291$class$$,$app$common$types$tokens_lib$Token$$,$APP.$cljs$cst$1314$wfn$$,$APP.$clojure$datafy$datafy$$,
$APP.$cljs$cst$1315$rfn$$,function($p1__50097_SHARP_$$){return $app$common$types$tokens_lib$map__GT_Token$$($p1__50097_SHARP_$$)}],null)]));var $app$main$data$workspace$check_libraries_synchronization_71599$$,$app$main$data$workspace$library_resolved_71606$$,$app$main$data$workspace$fetch_libries_71610$$,$app$main$data$workspace$workspace_initialized_71620$$,$app$main$data$workspace$bundle_fetched_71625$$,$app$main$data$workspace$zoom_to_frame_71628$$,$app$main$data$workspace$fetch_bundle_71631$$,$app$main$data$workspace$initialize_file_71639$$,$app$main$data$workspace$initialize_workspace_71650$$,$app$main$data$workspace$reload_current_file_71695$$,
$app$main$data$workspace$update_shape_71731$$,$app$main$data$workspace$start_rename_shape_71734$$,$app$main$data$workspace$end_rename_shape_71742$$,$app$main$data$workspace$rename_shape_or_variant_71747$$,$app$main$data$workspace$delete_selected_71754$$,$app$main$data$workspace$start_rename_selected_71775$$,$app$main$data$workspace$vertical_order_selected_71778$$,$app$main$data$workspace$relocate_selected_shapes_71791$$,$app$main$data$workspace$start_editing_selected_71798$$,$app$main$data$workspace$select_parent_layer_71817$$,
$app$main$data$workspace$align_objects_71829$$,$app$main$data$workspace$distribute_objects_71839$$,$app$main$data$workspace$toggle_proportion_lock_71866$$,$app$main$data$workspace$show_context_menu_71962$$,$app$main$data$workspace$show_shape_context_menu_71968$$,$app$main$data$workspace$hide_context_menu_72022$$,$app$main$data$workspace$toggle_distances_display_72029$$,$app$main$data$workspace$change_canvas_color_72051$$,$app$main$data$workspace$fix_orphan_shapes_72083$$,$app$main$data$workspace$find_components_norefs_72124$$,
$app$main$data$workspace$open_layers_search_72132$$,$app$main$data$workspace$close_layers_search_72139$$;var $app$main$store$last_events$$;$APP.$app$common$logging$loggers$$.set("app.main.store",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1161$info$$));$cljs$core$enable_console_print_BANG_$$();var $app$main$store$on_error$$=$okulary$core$atom$$($APP.$cljs$core$identity$$);
$potok$v2$core$resolve$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function($type$jscomp$356$$,$data$jscomp$141$$){return $APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$356$$,$data$jscomp$141$$)});var $app$main$store$on_event$$=$APP.$cljs$core$identity$$,$app$main$store$_STAR_debug_events_STAR_$$=!1,$app$main$store$_STAR_debug_events_time_STAR_$$=!1,$app$main$store$current_measure$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);
if($APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)){var $app$main$store$debug_exclude_events$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$2140$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_pointer_update$$,null,$cljs$cst$2141$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_change_hover_state$$,null,$cljs$cst$2142$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_pointer_send$$,
null,$cljs$cst$2143$app_DOT_main_DOT_data_DOT_websocket_SLASH_send_message$$,null],null),null);$app$main$store$on_event$$=function($e$jscomp$289$$){$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$279$$=$app$main$store$_STAR_debug_events_time_STAR_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$279$$)?$potok$v2$core$event_QMARK_$$($e$jscomp$289$$):$and__5023__auto__$jscomp$279$$}())&&$app$main$store$measure_time_to_render$$($APP.$potok$v2$core$type$$($e$jscomp$289$$));
return $APP.$cljs$core$truth_$$(function(){var $G__49428$jscomp$inline_5564_JSCompiler_inline_result$jscomp$890_JSCompiler_temp$jscomp$888_JSCompiler_temp$jscomp$889_and__5023__auto__$jscomp$280$$=$app$main$store$_STAR_debug_events_STAR_$$;$APP.$cljs$core$truth_$$($G__49428$jscomp$inline_5564_JSCompiler_inline_result$jscomp$890_JSCompiler_temp$jscomp$888_JSCompiler_temp$jscomp$889_and__5023__auto__$jscomp$280$$)&&($G__49428$jscomp$inline_5564_JSCompiler_inline_result$jscomp$890_JSCompiler_temp$jscomp$888_JSCompiler_temp$jscomp$889_and__5023__auto__$jscomp$280$$=
$potok$v2$core$event_QMARK_$$($e$jscomp$289$$))&&($G__49428$jscomp$inline_5564_JSCompiler_inline_result$jscomp$890_JSCompiler_temp$jscomp$888_JSCompiler_temp$jscomp$889_and__5023__auto__$jscomp$280$$=$APP.$potok$v2$core$type$$($e$jscomp$289$$),$G__49428$jscomp$inline_5564_JSCompiler_inline_result$jscomp$890_JSCompiler_temp$jscomp$888_JSCompiler_temp$jscomp$889_and__5023__auto__$jscomp$280$$=$app$main$store$debug_exclude_events$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$store$debug_exclude_events$$.$cljs$core$IFn$_invoke$arity$1$($G__49428$jscomp$inline_5564_JSCompiler_inline_result$jscomp$890_JSCompiler_temp$jscomp$888_JSCompiler_temp$jscomp$889_and__5023__auto__$jscomp$280$$):
$app$main$store$debug_exclude_events$$($G__49428$jscomp$inline_5564_JSCompiler_inline_result$jscomp$890_JSCompiler_temp$jscomp$888_JSCompiler_temp$jscomp$889_and__5023__auto__$jscomp$280$$),$G__49428$jscomp$inline_5564_JSCompiler_inline_result$jscomp$890_JSCompiler_temp$jscomp$888_JSCompiler_temp$jscomp$889_and__5023__auto__$jscomp$280$$=$APP.$cljs$core$not$$($G__49428$jscomp$inline_5564_JSCompiler_inline_result$jscomp$890_JSCompiler_temp$jscomp$888_JSCompiler_temp$jscomp$889_and__5023__auto__$jscomp$280$$));
return $G__49428$jscomp$inline_5564_JSCompiler_inline_result$jscomp$890_JSCompiler_temp$jscomp$888_JSCompiler_temp$jscomp$889_and__5023__auto__$jscomp$280$$}())?console.log(["[stream]: ",$potok$v2$core$repr_event$$($e$jscomp$289$$)].join("")):null}}
$APP.$app$main$store$state$$=function($map__43902__$1_p__43901$$){function $process_watch$$($event$jscomp$14$$){var $result$jscomp$141$$=$potok$v2$core$watch$$($event$jscomp$14$$,$APP.$cljs$core$_deref$$($state_STAR_$$),$input_sm$$);return $result$jscomp$141$$ instanceof $beicon$v2$core$Observable$$?$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__43886_SHARP_$$){return $input_sb$$.next($p1__43886_SHARP_$$)},$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($process_error$$,
$result$jscomp$141$$)):$potok$v2$core$promise_QMARK_$$($result$jscomp$141$$)?$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__43887_SHARP_$$){return $input_sb$$.next($p1__43887_SHARP_$$)},$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($process_error$$,$APP.$beicon$v2$core$from$$($result$jscomp$141$$))):$result$jscomp$141$$==null?null:console.warn("Event returned unexpected object from `watch` method (ignoring).",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$cljs$cst$1556$event$$,$event$jscomp$14$$,$APP.$cljs$cst$1557$event_type$$,$APP.$potok$v2$core$type$$($event$jscomp$14$$)],null)])))}function $process_error$$($error$jscomp$36_res$jscomp$32$$){$error$jscomp$36_res$jscomp$32$$=$on_error$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_error$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$36_res$jscomp$32$$):$on_error$jscomp$2$$($error$jscomp$36_res$jscomp$32$$);return $error$jscomp$36_res$jscomp$32$$ instanceof $beicon$v2$core$Observable$$?
$error$jscomp$36_res$jscomp$32$$:$APP.$beicon$v2$core$empty$$()}function $process_update$$($event$jscomp$13$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$$,function($hint_44106_result$jscomp$140_state__$1$jscomp$7$$){$hint_44106_result$jscomp$140_state__$1$jscomp$7$$=$potok$v2$core$update$$($event$jscomp$13$$,$hint_44106_result$jscomp$140_state__$1$jscomp$7$$);if(!$APP.$cljs$core$truth_$$($validate_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$validate_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($hint_44106_result$jscomp$140_state__$1$jscomp$7$$):
$validate_fn$jscomp$1$$($hint_44106_result$jscomp$140_state__$1$jscomp$7$$)))throw $hint_44106_result$jscomp$140_state__$1$jscomp$7$$=["seems like the event '",$potok$v2$core$repr_event$$($event$jscomp$13$$),"' does not pass validation"].join(""),Error($hint_44106_result$jscomp$140_state__$1$jscomp$7$$);return $hint_44106_result$jscomp$140_state__$1$jscomp$7$$})}$map__43902__$1_p__43901$$=$APP.$cljs$core$__destructure_map$$($map__43902__$1_p__43901$$);var $on_error$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__43902__$1_p__43901$$,
$APP.$cljs$cst$1295$on_error$$,$potok$v2$core$handle_error$$),$on_event$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__43902__$1_p__43901$$,$cljs$cst$1554$on_event$$),$state$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__43902__$1_p__43901$$,$APP.$cljs$cst$769$state$$),$validate_fn$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__43902__$1_p__43901$$,$cljs$cst$1555$validate_fn$$,$APP.$cljs$core$map_QMARK_$$),$input_sb$$=$APP.$beicon$v2$core$subject$$(),
$input_sm$$=function(){var $G__43906_G__43906__$1$$=$input_sb$$.asObservable();$G__43906_G__43906__$1$$=$on_event$$!=null?$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($on_event$$,$G__43906_G__43906__$1$$):$G__43906_G__43906__$1$$;return $APP.$beicon$v2$core$share$$($G__43906_G__43906__$1$$)}(),$state_STAR_$$=$okulary$core$atom$$($state$jscomp$43$$);$APP.$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($input_sm$$,function($event$jscomp$16$$){try{return $potok$v2$core$update_QMARK_$$($event$jscomp$16$$)&&
$process_update$$($event$jscomp$16$$),$potok$v2$core$watch_QMARK_$$($event$jscomp$16$$)&&$process_watch$$($event$jscomp$16$$),$potok$v2$core$effect_QMARK_$$($event$jscomp$16$$)?$potok$v2$core$effect$$($event$jscomp$16$$,$APP.$cljs$core$_deref$$($state_STAR_$$),$input_sm$$):null}catch($e43931$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__43888_SHARP_$$){return $input_sb$$.next($p1__43888_SHARP_$$)},$process_error$$($e43931$$))}});$state_STAR_$$.next=function($event$jscomp$17$$){return $input_sb$$.next($event$jscomp$17$$)};
$state_STAR_$$.error=function(){return $input_sb$$.complete()};$state_STAR_$$.complete=function(){return $input_sb$$.complete()};$state_STAR_$$.getInputStream=function(){return $input_sm$$};$state_STAR_$$.$beicon$v2$core$IDisposable$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$state_STAR_$$.$beicon$v2$core$IDisposable$_dispose$arity$1$=function(){return $input_sb$$.complete()};return $state_STAR_$$}(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$898$resolve$$,$potok$v2$core$resolve$$,$cljs$cst$1554$on_event$$,
$app$main$store$on_event$$,$APP.$cljs$cst$1295$on_error$$,function($cause$jscomp$33$$){if($APP.$cljs$core$truth_$$($cause$jscomp$33$$)){var $fexpr__49429$$=$APP.$cljs$core$_deref$$($app$main$store$on_error$$);return $fexpr__49429$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__49429$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$33$$):$fexpr__49429$$($cause$jscomp$33$$)}return null}],null));$APP.$app$main$store$stream$$=$APP.$app$main$store$state$$.getInputStream();
$app$main$store$last_events$$=function(){var $buffer$jscomp$59$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentVector$EMPTY$$),$omitset$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$2144$app_DOT_main_DOT_data_DOT_workspace_DOT_persistence_SLASH_update_persistence_status$$,null,$cljs$cst$2142$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_handle_pointer_send$$,null,$cljs$cst$1551$potok_DOT_v2_DOT_core_SLASH_undefined$$,
null,$cljs$cst$2145$app_DOT_main_DOT_router_SLASH_assign_exception$$,null,$cljs$cst$2143$app_DOT_main_DOT_data_DOT_websocket_SLASH_send_message$$,null],null),null);$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__49432_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($buffer$jscomp$59$$,$APP.$cljs$core$vec$$($p1__49432_SHARP_$$))},$APP.$beicon$v2$core$scan$cljs$0core$0IFn$0_invoke$0arity$03$$(function($buffer__$1$jscomp$2$$,$G__49433_event$jscomp$42$$){$G__49433_event$jscomp$42$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($buffer__$1$jscomp$2$$,$G__49433_event$jscomp$42$$);return $APP.$cljs$core$count$$($buffer__$1$jscomp$2$$)>50?$APP.$cljs$core$pop$$($G__49433_event$jscomp$42$$):$G__49433_event$jscomp$42$$},$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentQueue$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$map$$($APP.$cljs$core$str$$,
$APP.$beicon$v2$core$filter$$(function($p1__49431_SHARP_$$){return!$APP.$cljs$core$contains_QMARK_$$($omitset$$,$p1__49431_SHARP_$$)},$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$(function($p1__49430_SHARP_$$){return $cljs$cst$2146$hint_origin$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($p1__49430_SHARP_$$))},$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$2147$app_DOT_main_DOT_data_DOT_changes_SLASH_commit$$),$APP.$app$main$store$stream$$)),
$APP.$beicon$v2$core$map$$($APP.$potok$v2$core$type$$,$APP.$app$main$store$stream$$)))))));return $buffer$jscomp$59$$}();
$APP.$app$main$store$emit_BANG_$$=function $app$main$store$emit_BANG_$$($var_args$jscomp$1017$$){switch(arguments.length){case 0:return $app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:for(var $args_arr__5774__auto__$jscomp$97$$=[],$len__5749__auto___49449$$=arguments.length,$i__5750__auto___49450$$=0;;)if($i__5750__auto___49450$$<$len__5749__auto___49449$$)$args_arr__5774__auto__$jscomp$97$$.push(arguments[$i__5750__auto___49450$$]),
$i__5750__auto___49450$$+=1;else break;return $app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args_arr__5774__auto__$jscomp$97$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$97$$.slice(1),0,null):null)}};$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$0$=function(){return null};
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$=function($event$jscomp$43$$){$potok$v2$core$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$store$state$$,$event$jscomp$43$$);return null};$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$=function($event$jscomp$44$$,$events$$){$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($potok$v2$core$emit_BANG_$$,$APP.$app$main$store$state$$,$APP.$cljs$core$cons$$($event$jscomp$44$$,$events$$));return null};
$APP.$app$main$store$emit_BANG_$$.$cljs$lang$applyTo$=function($seq49437_seq49437__$1$$){var $G__49438$$=$APP.$cljs$core$first$$($seq49437_seq49437__$1$$);$seq49437_seq49437__$1$$=$APP.$cljs$core$next$$($seq49437_seq49437__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__49438$$,$seq49437_seq49437__$1$$)};$APP.$app$main$store$emit_BANG_$$.$cljs$lang$maxFixedArity$=1;var $app$main$store$ongoing_tasks$$=$okulary$core$atom$$($APP.$cljs$core$PersistentHashSet$EMPTY$$);
$cljs$core$_add_watch$$($app$main$store$ongoing_tasks$$,$cljs$cst$2148$app_DOT_main_DOT_store_SLASH_ongoing_tasks$$,function($_$jscomp$1405$$,$___$1$jscomp$804$$,$___$2$jscomp$122$$,$events$jscomp$1$$){return $APP.$cljs$core$empty_QMARK_$$($events$jscomp$1$$)?$APP.$app$util$object$set_BANG_$$(window,"onbeforeunload",null):$APP.$app$util$object$set_BANG_$$(window,"onbeforeunload",$APP.$cljs$core$constantly$$(!1))});var $app$util$keyboard$alt_key_QMARK_$$,$app$util$keyboard$ctrl_key_QMARK_$$,$app$util$keyboard$meta_key_QMARK_$$,$app$util$keyboard$comma_QMARK_$$;$APP.$JSCompiler_prototypeAlias$$=$APP.$app$util$keyboard$KeyboardEvent$$.prototype;$APP.$JSCompiler_prototypeAlias$$.preventDefault=function(){return $APP.$app$util$dom$prevent_default$$(this.$native_event$)};$APP.$JSCompiler_prototypeAlias$$.stopPropagation=function(){return $APP.$app$util$dom$stop_propagation$$(this.$native_event$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$22$$,$k__5324__auto__$jscomp$22$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$22$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$22$$,$k49497$$,$else__5326__auto__$jscomp$22$$){switch($k49497$$ instanceof $APP.$cljs$core$Keyword$$?$k49497$$.$fqn$:null){case "type":return this.type;case "key":return this.key;case "shift":return this.shift;case "ctrl":return this.$ctrl$;case "alt":return this.alt;case "meta":return this.$meta$;case "mod":return this.$mod$;case "editing":return this.editing;case "native-event":return this.$native_event$;
default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k49497$$,$else__5326__auto__$jscomp$22$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$22$$,$f__5344__auto__$jscomp$22$$,$init__5345__auto__$jscomp$22$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$22$$,$p__49506_v__5348__auto__$jscomp$22$$){var $k__5347__auto__$jscomp$22$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49506_v__5348__auto__$jscomp$22$$,0,null);$p__49506_v__5348__auto__$jscomp$22$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49506_v__5348__auto__$jscomp$22$$,
1,null);return $f__5344__auto__$jscomp$22$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$22$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$22$$,$k__5347__auto__$jscomp$22$$,$p__49506_v__5348__auto__$jscomp$22$$):$f__5344__auto__$jscomp$22$$($ret__5346__auto__$jscomp$22$$,$k__5347__auto__$jscomp$22$$,$p__49506_v__5348__auto__$jscomp$22$$)},$init__5345__auto__$jscomp$22$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$22$$,$writer__5339__auto__$jscomp$22$$,$opts__5340__auto__$jscomp$22$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$22$$,function($keyval__5342__auto__$jscomp$22$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$22$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$22$$,$keyval__5342__auto__$jscomp$22$$)},"#app.util.keyboard.KeyboardEvent{",
", ","}",$opts__5340__auto__$jscomp$22$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,this.type],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$302$key$$,this.key],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2149$shift$$,this.shift],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2150$ctrl$$,this.$ctrl$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$717$alt$$,this.alt],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2$meta$$,this.$meta$],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2151$mod$$,this.$mod$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2152$editing$$,this.editing],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2153$native_event$$,this.$native_event$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,9,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$2149$shift$$,$cljs$cst$2150$ctrl$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$2$meta$$,$cljs$cst$2151$mod$$,$APP.$cljs$cst$2152$editing$$,$cljs$cst$2153$native_event$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?
$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$app$util$keyboard$KeyboardEvent$$(this.type,this.key,this.shift,this.$ctrl$,this.alt,this.$meta$,this.$mod$,this.editing,this.$native_event$,this.$__meta$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 9+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$52_h__5134__auto____$1$jscomp$52$$=this.$__hash$;return $h__5134__auto__$jscomp$52_h__5134__auto____$1$jscomp$52$$!=null?$h__5134__auto__$jscomp$52_h__5134__auto____$1$jscomp$52$$:this.$__hash$=$h__5134__auto__$jscomp$52_h__5134__auto____$1$jscomp$52$$=-327343103^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this49498$$,$other49499$$){return $other49499$$!=null&&this.constructor===$other49499$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.type,$other49499$$.type)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.key,$other49499$$.key)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.shift,$other49499$$.shift)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$ctrl$,
$other49499$$.$ctrl$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.alt,$other49499$$.alt)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$meta$,$other49499$$.$meta$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$mod$,$other49499$$.$mod$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.editing,$other49499$$.editing)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$native_event$,$other49499$$.$native_event$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,
$other49499$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$22$$,$k__5334__auto__$jscomp$22$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,9,[$APP.$cljs$cst$2149$shift$$,null,$cljs$cst$2$meta$$,null,$APP.$cljs$cst$302$key$$,null,$APP.$cljs$cst$717$alt$$,null,$cljs$cst$2151$mod$$,null,$APP.$cljs$cst$139$type$$,null,$cljs$cst$2150$ctrl$$,null,$APP.$cljs$cst$2152$editing$$,
null,$cljs$cst$2153$native_event$$,null],null),null),$k__5334__auto__$jscomp$22$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),this.$__meta$),$k__5334__auto__$jscomp$22$$):new $APP.$app$util$keyboard$KeyboardEvent$$(this.type,this.key,this.shift,this.$ctrl$,this.alt,this.$meta$,this.$mod$,this.editing,this.$native_event$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,
$k__5334__auto__$jscomp$22$$)),null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$22$$,$k49497$jscomp$1$$){switch($k49497$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k49497$jscomp$1$$.$fqn$:null){case "type":case "key":case "shift":case "ctrl":case "alt":case "meta":case "mod":case "editing":case "native-event":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k49497$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$22$$,$k__5332__auto__$jscomp$22$$,$G__49496$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$,$k__5332__auto__$jscomp$22$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$139$type$$,$k__5332__auto__$jscomp$22$$))?
new $APP.$app$util$keyboard$KeyboardEvent$$($G__49496$jscomp$1$$,this.key,this.shift,this.$ctrl$,this.alt,this.$meta$,this.$mod$,this.editing,this.$native_event$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$302$key$$,$k__5332__auto__$jscomp$22$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$302$key$$,$k__5332__auto__$jscomp$22$$))?
new $APP.$app$util$keyboard$KeyboardEvent$$(this.type,$G__49496$jscomp$1$$,this.shift,this.$ctrl$,this.alt,this.$meta$,this.$mod$,this.editing,this.$native_event$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2149$shift$$,$k__5332__auto__$jscomp$22$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2149$shift$$,
$k__5332__auto__$jscomp$22$$))?new $APP.$app$util$keyboard$KeyboardEvent$$(this.type,this.key,$G__49496$jscomp$1$$,this.$ctrl$,this.alt,this.$meta$,this.$mod$,this.editing,this.$native_event$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2150$ctrl$$,$k__5332__auto__$jscomp$22$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$2150$ctrl$$,
$k__5332__auto__$jscomp$22$$))?new $APP.$app$util$keyboard$KeyboardEvent$$(this.type,this.key,this.shift,$G__49496$jscomp$1$$,this.alt,this.$meta$,this.$mod$,this.editing,this.$native_event$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$717$alt$$,$k__5332__auto__$jscomp$22$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$717$alt$$,
$k__5332__auto__$jscomp$22$$))?new $APP.$app$util$keyboard$KeyboardEvent$$(this.type,this.key,this.shift,this.$ctrl$,$G__49496$jscomp$1$$,this.$meta$,this.$mod$,this.editing,this.$native_event$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2$meta$$,$k__5332__auto__$jscomp$22$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$2$meta$$,
$k__5332__auto__$jscomp$22$$))?new $APP.$app$util$keyboard$KeyboardEvent$$(this.type,this.key,this.shift,this.$ctrl$,this.alt,$G__49496$jscomp$1$$,this.$mod$,this.editing,this.$native_event$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2151$mod$$,$k__5332__auto__$jscomp$22$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$2151$mod$$,
$k__5332__auto__$jscomp$22$$))?new $APP.$app$util$keyboard$KeyboardEvent$$(this.type,this.key,this.shift,this.$ctrl$,this.alt,this.$meta$,$G__49496$jscomp$1$$,this.editing,this.$native_event$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2152$editing$$,$k__5332__auto__$jscomp$22$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2152$editing$$,
$k__5332__auto__$jscomp$22$$))?new $APP.$app$util$keyboard$KeyboardEvent$$(this.type,this.key,this.shift,this.$ctrl$,this.alt,this.$meta$,this.$mod$,$G__49496$jscomp$1$$,this.$native_event$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2153$native_event$$,$k__5332__auto__$jscomp$22$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$2153$native_event$$,
$k__5332__auto__$jscomp$22$$))?new $APP.$app$util$keyboard$KeyboardEvent$$(this.type,this.key,this.shift,this.$ctrl$,this.alt,this.$meta$,this.$mod$,this.editing,$G__49496$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $APP.$app$util$keyboard$KeyboardEvent$$(this.type,this.key,this.shift,this.$ctrl$,this.alt,this.$meta$,this.$mod$,this.editing,this.$native_event$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$22$$,$G__49496$jscomp$1$$),
null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$139$type$$,this.type,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$302$key$$,this.key,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2149$shift$$,this.shift,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$2150$ctrl$$,this.$ctrl$,
null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$717$alt$$,this.alt,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$2$meta$$,this.$meta$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$2151$mod$$,this.$mod$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2152$editing$$,this.editing,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$2153$native_event$$,this.$native_event$,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$22$$,$G__49496$jscomp$2$$){return new $APP.$app$util$keyboard$KeyboardEvent$$(this.type,this.key,this.shift,this.$ctrl$,this.alt,this.$meta$,this.$mod$,this.editing,this.$native_event$,$G__49496$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$22$$,$entry__5329__auto__$jscomp$22$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$22$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$22$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$22$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$22$$)};
$APP.$app$util$keyboard$esc_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("Escape");$APP.$app$util$keyboard$enter_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("Enter");$APP.$app$util$keyboard$space_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$(" ");$APP.$app$util$keyboard$z_QMARK_$$=$APP.$app$util$keyboard$is_key_ignore_case_QMARK_$$("z");$APP.$app$util$keyboard$equals_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("\x3d");
$APP.$app$util$keyboard$plus_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("+");$APP.$app$util$keyboard$minus_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("-");$APP.$app$util$keyboard$underscore_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("_");$APP.$app$util$keyboard$up_arrow_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("ArrowUp");
$APP.$app$util$keyboard$down_arrow_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("ArrowDown");$APP.$app$util$keyboard$left_arrow_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("ArrowLeft");$APP.$app$util$keyboard$right_arrow_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("ArrowRight");$app$util$keyboard$alt_key_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("Alt");
$APP.$app$util$keyboard$shift_key_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("Shift");$app$util$keyboard$ctrl_key_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("Control");$app$util$keyboard$meta_key_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("Meta");$app$util$keyboard$comma_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$(",");
$APP.$app$util$keyboard$backspace_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("Backspace");$APP.$app$util$keyboard$home_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("Home");$APP.$app$util$keyboard$tab_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("Tab");$APP.$app$util$keyboard$delete_QMARK_$$=$app$util$keyboard$is_key_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$("Delete");$APP.$JSCompiler_prototypeAlias$$=$APP.$app$util$mouse$MouseEvent$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$23$$,$k__5324__auto__$jscomp$23$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$23$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$23$$,$k49513$$,$else__5326__auto__$jscomp$23$$){switch($k49513$$ instanceof $APP.$cljs$core$Keyword$$?$k49513$$.$fqn$:null){case "type":return this.type;case "ctrl":return this.$ctrl$;case "shift":return this.shift;case "alt":return this.alt;case "meta":return this.$meta$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k49513$$,$else__5326__auto__$jscomp$23$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$23$$,$f__5344__auto__$jscomp$23$$,$init__5345__auto__$jscomp$23$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$23$$,$p__49522_v__5348__auto__$jscomp$23$$){var $k__5347__auto__$jscomp$23$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49522_v__5348__auto__$jscomp$23$$,0,null);$p__49522_v__5348__auto__$jscomp$23$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49522_v__5348__auto__$jscomp$23$$,
1,null);return $f__5344__auto__$jscomp$23$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$23$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$23$$,$k__5347__auto__$jscomp$23$$,$p__49522_v__5348__auto__$jscomp$23$$):$f__5344__auto__$jscomp$23$$($ret__5346__auto__$jscomp$23$$,$k__5347__auto__$jscomp$23$$,$p__49522_v__5348__auto__$jscomp$23$$)},$init__5345__auto__$jscomp$23$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$23$$,$writer__5339__auto__$jscomp$23$$,$opts__5340__auto__$jscomp$23$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$23$$,function($keyval__5342__auto__$jscomp$23$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$23$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$23$$,$keyval__5342__auto__$jscomp$23$$)},"#app.util.mouse.MouseEvent{",
", ","}",$opts__5340__auto__$jscomp$23$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,this.type],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2150$ctrl$$,this.$ctrl$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2149$shift$$,this.shift],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$717$alt$$,this.alt],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2$meta$$,this.$meta$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,5,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,$cljs$cst$2150$ctrl$$,$APP.$cljs$cst$2149$shift$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$2$meta$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$app$util$mouse$MouseEvent$$(this.type,this.$ctrl$,this.shift,this.alt,this.$meta$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 5+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$53_h__5134__auto____$1$jscomp$53$$=this.$__hash$;return $h__5134__auto__$jscomp$53_h__5134__auto____$1$jscomp$53$$!=null?$h__5134__auto__$jscomp$53_h__5134__auto____$1$jscomp$53$$:this.$__hash$=$h__5134__auto__$jscomp$53_h__5134__auto____$1$jscomp$53$$=-1048159938^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this49514$$,$other49515$$){return $other49515$$!=null&&this.constructor===$other49515$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.type,$other49515$$.type)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$ctrl$,$other49515$$.$ctrl$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.shift,$other49515$$.shift)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.alt,
$other49515$$.alt)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$meta$,$other49515$$.$meta$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other49515$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$23$$,$k__5334__auto__$jscomp$23$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2149$shift$$,null,$cljs$cst$2$meta$$,null,$APP.$cljs$cst$717$alt$$,null,$APP.$cljs$cst$139$type$$,null,$cljs$cst$2150$ctrl$$,null],null),null),$k__5334__auto__$jscomp$23$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$23$$):new $APP.$app$util$mouse$MouseEvent$$(this.type,this.$ctrl$,this.shift,this.alt,this.$meta$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$23$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$23$$,$k49513$jscomp$1$$){switch($k49513$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k49513$jscomp$1$$.$fqn$:null){case "type":case "ctrl":case "shift":case "alt":case "meta":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k49513$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$23$$,$k__5332__auto__$jscomp$23$$,$G__49512$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$,$k__5332__auto__$jscomp$23$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$139$type$$,$k__5332__auto__$jscomp$23$$))?
new $APP.$app$util$mouse$MouseEvent$$($G__49512$jscomp$1$$,this.$ctrl$,this.shift,this.alt,this.$meta$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2150$ctrl$$,$k__5332__auto__$jscomp$23$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$2150$ctrl$$,$k__5332__auto__$jscomp$23$$))?new $APP.$app$util$mouse$MouseEvent$$(this.type,
$G__49512$jscomp$1$$,this.shift,this.alt,this.$meta$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2149$shift$$,$k__5332__auto__$jscomp$23$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2149$shift$$,$k__5332__auto__$jscomp$23$$))?new $APP.$app$util$mouse$MouseEvent$$(this.type,this.$ctrl$,$G__49512$jscomp$1$$,
this.alt,this.$meta$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$717$alt$$,$k__5332__auto__$jscomp$23$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$717$alt$$,$k__5332__auto__$jscomp$23$$))?new $APP.$app$util$mouse$MouseEvent$$(this.type,this.$ctrl$,this.shift,$G__49512$jscomp$1$$,this.$meta$,this.$__meta$,
this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2$meta$$,$k__5332__auto__$jscomp$23$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$2$meta$$,$k__5332__auto__$jscomp$23$$))?new $APP.$app$util$mouse$MouseEvent$$(this.type,this.$ctrl$,this.shift,this.alt,$G__49512$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $APP.$app$util$mouse$MouseEvent$$(this.type,
this.$ctrl$,this.shift,this.alt,this.$meta$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$23$$,$G__49512$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$139$type$$,this.type,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$2150$ctrl$$,this.$ctrl$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2149$shift$$,this.shift,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$717$alt$$,
this.alt,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$2$meta$$,this.$meta$,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$23$$,$G__49512$jscomp$2$$){return new $APP.$app$util$mouse$MouseEvent$$(this.type,this.$ctrl$,this.shift,this.alt,this.$meta$,$G__49512$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$23$$,$entry__5329__auto__$jscomp$23$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$23$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$23$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$23$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$23$$)};
$APP.$JSCompiler_prototypeAlias$$=$APP.$app$util$mouse$PointerEvent$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$24$$,$k__5324__auto__$jscomp$24$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$24$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$24$$,$k49579$$,$else__5326__auto__$jscomp$24$$){switch($k49579$$ instanceof $APP.$cljs$core$Keyword$$?$k49579$$.$fqn$:null){case "source":return this.source;case "pt":return this.pt;case "ctrl":return this.$ctrl$;case "shift":return this.shift;case "alt":return this.alt;case "meta":return this.$meta$;case "movement":return this.$movement$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,
$k49579$$,$else__5326__auto__$jscomp$24$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$24$$,$f__5344__auto__$jscomp$24$$,$init__5345__auto__$jscomp$24$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$24$$,$p__49595_v__5348__auto__$jscomp$24$$){var $k__5347__auto__$jscomp$24$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49595_v__5348__auto__$jscomp$24$$,0,null);$p__49595_v__5348__auto__$jscomp$24$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49595_v__5348__auto__$jscomp$24$$,
1,null);return $f__5344__auto__$jscomp$24$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$24$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$24$$,$k__5347__auto__$jscomp$24$$,$p__49595_v__5348__auto__$jscomp$24$$):$f__5344__auto__$jscomp$24$$($ret__5346__auto__$jscomp$24$$,$k__5347__auto__$jscomp$24$$,$p__49595_v__5348__auto__$jscomp$24$$)},$init__5345__auto__$jscomp$24$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$24$$,$writer__5339__auto__$jscomp$24$$,$opts__5340__auto__$jscomp$24$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$24$$,function($keyval__5342__auto__$jscomp$24$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$24$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$24$$,$keyval__5342__auto__$jscomp$24$$)},"#app.util.mouse.PointerEvent{",
", ","}",$opts__5340__auto__$jscomp$24$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$193$source$$,this.source],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2159$pt$$,this.pt],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2150$ctrl$$,this.$ctrl$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2149$shift$$,this.shift],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$717$alt$$,this.alt],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2$meta$$,this.$meta$],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2160$movement$$,this.$movement$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,7,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$193$source$$,$APP.$cljs$cst$2159$pt$$,$cljs$cst$2150$ctrl$$,$APP.$cljs$cst$2149$shift$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$2$meta$$,$cljs$cst$2160$movement$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$app$util$mouse$PointerEvent$$(this.source,this.pt,this.$ctrl$,this.shift,this.alt,this.$meta$,this.$movement$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 7+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$54_h__5134__auto____$1$jscomp$54$$=this.$__hash$;return $h__5134__auto__$jscomp$54_h__5134__auto____$1$jscomp$54$$!=null?$h__5134__auto__$jscomp$54_h__5134__auto____$1$jscomp$54$$:this.$__hash$=$h__5134__auto__$jscomp$54_h__5134__auto____$1$jscomp$54$$=-821521640^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this49580$$,$other49581$$){return $other49581$$!=null&&this.constructor===$other49581$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.source,$other49581$$.source)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.pt,$other49581$$.pt)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$ctrl$,$other49581$$.$ctrl$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.shift,
$other49581$$.shift)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.alt,$other49581$$.alt)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$meta$,$other49581$$.$meta$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$movement$,$other49581$$.$movement$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other49581$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$24$$,$k__5334__auto__$jscomp$24$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2149$shift$$,null,$cljs$cst$2160$movement$$,null,$APP.$cljs$cst$2159$pt$$,null,$cljs$cst$2$meta$$,null,$APP.$cljs$cst$717$alt$$,null,$APP.$cljs$cst$193$source$$,null,$cljs$cst$2150$ctrl$$,null],null),null),$k__5334__auto__$jscomp$24$$)?
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),this.$__meta$),$k__5334__auto__$jscomp$24$$):new $APP.$app$util$mouse$PointerEvent$$(this.source,this.pt,this.$ctrl$,this.shift,this.alt,this.$meta$,this.$movement$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$24$$)),
null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$24$$,$k49579$jscomp$1$$){switch($k49579$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k49579$jscomp$1$$.$fqn$:null){case "source":case "pt":case "ctrl":case "shift":case "alt":case "meta":case "movement":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k49579$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$24$$,$k__5332__auto__$jscomp$24$$,$G__49578$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$193$source$$,$k__5332__auto__$jscomp$24$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$193$source$$,$k__5332__auto__$jscomp$24$$))?
new $APP.$app$util$mouse$PointerEvent$$($G__49578$jscomp$1$$,this.pt,this.$ctrl$,this.shift,this.alt,this.$meta$,this.$movement$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2159$pt$$,$k__5332__auto__$jscomp$24$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2159$pt$$,$k__5332__auto__$jscomp$24$$))?new $APP.$app$util$mouse$PointerEvent$$(this.source,
$G__49578$jscomp$1$$,this.$ctrl$,this.shift,this.alt,this.$meta$,this.$movement$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2150$ctrl$$,$k__5332__auto__$jscomp$24$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$2150$ctrl$$,$k__5332__auto__$jscomp$24$$))?new $APP.$app$util$mouse$PointerEvent$$(this.source,this.pt,$G__49578$jscomp$1$$,
this.shift,this.alt,this.$meta$,this.$movement$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2149$shift$$,$k__5332__auto__$jscomp$24$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2149$shift$$,$k__5332__auto__$jscomp$24$$))?new $APP.$app$util$mouse$PointerEvent$$(this.source,this.pt,this.$ctrl$,$G__49578$jscomp$1$$,
this.alt,this.$meta$,this.$movement$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$717$alt$$,$k__5332__auto__$jscomp$24$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$717$alt$$,$k__5332__auto__$jscomp$24$$))?new $APP.$app$util$mouse$PointerEvent$$(this.source,this.pt,this.$ctrl$,this.shift,$G__49578$jscomp$1$$,
this.$meta$,this.$movement$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2$meta$$,$k__5332__auto__$jscomp$24$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$2$meta$$,$k__5332__auto__$jscomp$24$$))?new $APP.$app$util$mouse$PointerEvent$$(this.source,this.pt,this.$ctrl$,this.shift,this.alt,$G__49578$jscomp$1$$,this.$movement$,
this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2160$movement$$,$k__5332__auto__$jscomp$24$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$2160$movement$$,$k__5332__auto__$jscomp$24$$))?new $APP.$app$util$mouse$PointerEvent$$(this.source,this.pt,this.$ctrl$,this.shift,this.alt,this.$meta$,$G__49578$jscomp$1$$,this.$__meta$,
this.$__extmap$,null):new $APP.$app$util$mouse$PointerEvent$$(this.source,this.pt,this.$ctrl$,this.shift,this.alt,this.$meta$,this.$movement$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$24$$,$G__49578$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$193$source$$,this.source,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2159$pt$$,this.pt,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$2150$ctrl$$,this.$ctrl$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2149$shift$$,
this.shift,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$717$alt$$,this.alt,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$2$meta$$,this.$meta$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$2160$movement$$,this.$movement$,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$24$$,$G__49578$jscomp$2$$){return new $APP.$app$util$mouse$PointerEvent$$(this.source,this.pt,this.$ctrl$,this.shift,this.alt,this.$meta$,this.$movement$,$G__49578$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$24$$,$entry__5329__auto__$jscomp$24$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$24$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$24$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$24$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$24$$)};
$APP.$JSCompiler_prototypeAlias$$=$APP.$app$util$mouse$BlurEvent$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$26$$,$k__5324__auto__$jscomp$26$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$26$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$26$$,$k49651$$,$else__5326__auto__$jscomp$26$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k49651$$,$else__5326__auto__$jscomp$26$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$26$$,$f__5344__auto__$jscomp$26$$,$init__5345__auto__$jscomp$26$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$26$$,$p__49657_v__5348__auto__$jscomp$26$$){var $k__5347__auto__$jscomp$26$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49657_v__5348__auto__$jscomp$26$$,0,null);$p__49657_v__5348__auto__$jscomp$26$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49657_v__5348__auto__$jscomp$26$$,
1,null);return $f__5344__auto__$jscomp$26$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$26$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$26$$,$k__5347__auto__$jscomp$26$$,$p__49657_v__5348__auto__$jscomp$26$$):$f__5344__auto__$jscomp$26$$($ret__5346__auto__$jscomp$26$$,$k__5347__auto__$jscomp$26$$,$p__49657_v__5348__auto__$jscomp$26$$)},$init__5345__auto__$jscomp$26$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$26$$,$writer__5339__auto__$jscomp$26$$,$opts__5340__auto__$jscomp$26$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$26$$,function($keyval__5342__auto__$jscomp$26$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$26$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$26$$,$keyval__5342__auto__$jscomp$26$$)},"#app.util.mouse.BlurEvent{",
", ","}",$opts__5340__auto__$jscomp$26$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,0,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $APP.$app$util$mouse$BlurEvent$$(this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 0+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$56_h__5134__auto____$1$jscomp$56$$=this.$__hash$;return $h__5134__auto__$jscomp$56_h__5134__auto____$1$jscomp$56$$!=null?$h__5134__auto__$jscomp$56_h__5134__auto____$1$jscomp$56$$:this.$__hash$=$h__5134__auto__$jscomp$56_h__5134__auto____$1$jscomp$56$$=-1792553993^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this49652$$,$other49653$$){return $other49653$$!=null&&this.constructor===$other49653$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other49653$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$26$$,$k__5334__auto__$jscomp$26$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$k__5334__auto__$jscomp$26$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),this.$__meta$),$k__5334__auto__$jscomp$26$$):new $APP.$app$util$mouse$BlurEvent$$(this.$__meta$,
$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$26$$)),null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$26$$,$k49651$jscomp$1$$){return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k49651$jscomp$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$26$$,$k__5332__auto__$jscomp$26$$,$G__49650$jscomp$1$$){return new $APP.$app$util$mouse$BlurEvent$$(this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$26$$,$G__49650$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$26$$,$G__49650$jscomp$2$$){return new $APP.$app$util$mouse$BlurEvent$$($G__49650$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$26$$,$entry__5329__auto__$jscomp$26$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$26$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$26$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$26$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$26$$)};var $app$main$streams$wasm_modifiers$$,$app$main$streams$workspace_selrect$$,$app$main$streams$pointer$$,$sub$jscomp$inline_5566$$,$ob$jscomp$inline_5567$$,$ob$jscomp$inline_5573$$,$ob$jscomp$inline_5576$$,$app$main$streams$window_blur$$,$ob$jscomp$inline_5579$$,$ob$jscomp$inline_5591$$;$app$main$streams$wasm_modifiers$$=$APP.$beicon$v2$core$behavior_subject$$(null);$app$main$streams$workspace_selrect$$=$APP.$beicon$v2$core$behavior_subject$$(null);
$app$main$streams$pointer$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$filter$$($APP.$app$util$mouse$pointer_event_QMARK_$$,$APP.$app$main$store$stream$$));
$APP.$app$main$streams$mouse_position$$=function(){var $sub$jscomp$2$$=$APP.$beicon$v2$core$behavior_subject$$(null),$ob$jscomp$83$$=$APP.$beicon$v2$core$map$$($APP.$app$util$mouse$get_pointer_position$$,$APP.$beicon$v2$core$filter$$(function($p1__49677_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2170$viewport$$,$p1__49677_SHARP_$$.source)},$app$main$streams$pointer$$));$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($ob$jscomp$83$$,$sub$jscomp$2$$);
return $sub$jscomp$2$$}();$sub$jscomp$inline_5566$$=$APP.$beicon$v2$core$behavior_subject$$(null);$ob$jscomp$inline_5567$$=$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$map$$(function($ev$jscomp$4$$){return $ev$jscomp$4$$.$ctrl$},$app$main$streams$pointer$$));$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($ob$jscomp$inline_5567$$,$sub$jscomp$inline_5566$$);
var $sub$jscomp$inline_5569$$=$APP.$beicon$v2$core$behavior_subject$$(null),$ob$jscomp$inline_5570$$=$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$map$$(function($ev$jscomp$5$$){return $ev$jscomp$5$$.$meta$},$app$main$streams$pointer$$));$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($ob$jscomp$inline_5570$$,$sub$jscomp$inline_5569$$);
$APP.$app$main$streams$mouse_position_mod$$=$APP.$app$config$check_platform_QMARK_$$()?$sub$jscomp$inline_5569$$:$sub$jscomp$inline_5566$$;$APP.$sub$jscomp$inline_5572$$=$APP.$beicon$v2$core$behavior_subject$$(null);$ob$jscomp$inline_5573$$=$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$map$$(function($ev$jscomp$7$$){return $ev$jscomp$7$$.shift},$app$main$streams$pointer$$));
$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($ob$jscomp$inline_5573$$,$APP.$sub$jscomp$inline_5572$$);$APP.$sub$jscomp$inline_5575$$=$APP.$beicon$v2$core$behavior_subject$$(null);$ob$jscomp$inline_5576$$=$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$map$$(function($ev$jscomp$6$$){return $ev$jscomp$6$$.alt},$app$main$streams$pointer$$));
$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($ob$jscomp$inline_5576$$,$APP.$sub$jscomp$inline_5575$$);$app$main$streams$window_blur$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$(!1),$APP.$shadow$js$shim$module$0rxjs$$.fromEvent($APP.$app$util$globals$window$$,"blur")));$APP.$app$main$streams$keyboard$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$filter$$($app$util$keyboard$keyboard_event_QMARK_$$,$APP.$app$main$store$stream$$));
$APP.$sub$jscomp$inline_5578$$=$APP.$beicon$v2$core$behavior_subject$$(null);$ob$jscomp$inline_5579$$=$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$merge$$($app$main$streams$window_blur$$,$APP.$beicon$v2$core$map$$($APP.$app$util$keyboard$key_down_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($app$util$keyboard$alt_key_QMARK_$$,$APP.$app$main$streams$keyboard$$))));
$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($ob$jscomp$inline_5579$$,$APP.$sub$jscomp$inline_5578$$);
var $sub$jscomp$inline_5581$$=$APP.$beicon$v2$core$behavior_subject$$(null),$ob$jscomp$inline_5582$$=$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$merge$$($app$main$streams$window_blur$$,$APP.$beicon$v2$core$map$$($APP.$app$util$keyboard$key_down_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($app$util$keyboard$ctrl_key_QMARK_$$,$APP.$app$main$streams$keyboard$$))));
$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($ob$jscomp$inline_5582$$,$sub$jscomp$inline_5581$$);
var $sub$jscomp$inline_5584$$=$APP.$beicon$v2$core$behavior_subject$$(null),$ob$jscomp$inline_5585$$=$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$merge$$($app$main$streams$window_blur$$,$APP.$beicon$v2$core$map$$($APP.$app$util$keyboard$key_down_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($APP.$app$util$keyboard$shift_key_QMARK_$$,$APP.$app$main$streams$keyboard$$))));
$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($ob$jscomp$inline_5585$$,$sub$jscomp$inline_5584$$);
var $sub$jscomp$inline_5587$$=$APP.$beicon$v2$core$behavior_subject$$(null),$ob$jscomp$inline_5588$$=$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$merge$$($app$main$streams$window_blur$$,$APP.$beicon$v2$core$map$$($APP.$app$util$keyboard$key_down_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($app$util$keyboard$meta_key_QMARK_$$,$APP.$app$main$streams$keyboard$$))));
$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($ob$jscomp$inline_5588$$,$sub$jscomp$inline_5587$$);$APP.$app$main$streams$keyboard_mod$$=$APP.$app$config$check_platform_QMARK_$$()?$sub$jscomp$inline_5587$$:$sub$jscomp$inline_5581$$;$APP.$sub$jscomp$inline_5590$$=$APP.$beicon$v2$core$behavior_subject$$(null);
$ob$jscomp$inline_5591$$=$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$merge$$($app$main$streams$window_blur$$,$APP.$beicon$v2$core$map$$($APP.$app$util$keyboard$key_down_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$complement$$($APP.$app$util$keyboard$editing_event_QMARK_$$),$APP.$beicon$v2$core$filter$$($APP.$app$util$keyboard$space_QMARK_$$,$APP.$app$main$streams$keyboard$$)))));
$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($ob$jscomp$inline_5591$$,$APP.$sub$jscomp$inline_5590$$);var $app$main$refs$selected_shapes_data$$,$app$main$refs$workspace_file_colors$$,$app$main$refs$workspace_frame_modifiers$$,$app$main$refs$workspace_clipboard_style$$,$app$main$refs$viewer_overlays$$;$APP.$app$main$refs$route$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$2171$route$$),$APP.$app$main$store$state$$);
$APP.$app$main$refs$router$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$2172$router$$),$APP.$app$main$store$state$$);$APP.$app$main$refs$profile$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$1914$profile$$),$APP.$app$main$store$state$$);
$APP.$app$main$refs$current_page_id$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$1918$current_page_id$$),$APP.$app$main$store$state$$);
$APP.$app$main$refs$team$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$86_teams$$){var $team_id$jscomp$2$$=$APP.$cljs$cst$1926$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$86_teams$$);$state$jscomp$86_teams$$=$APP.$cljs$cst$2173$teams$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$86_teams$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$86_teams$$,$team_id$jscomp$2$$)},$APP.$app$main$store$state$$);
$APP.$app$main$refs$project$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($projects_state$jscomp$87$$){var $project_id$$=$APP.$cljs$cst$2174$current_project_id$$.$cljs$core$IFn$_invoke$arity$1$($projects_state$jscomp$87$$);$projects_state$jscomp$87$$=$APP.$cljs$cst$1928$projects$$.$cljs$core$IFn$_invoke$arity$1$($projects_state$jscomp$87$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($projects_state$jscomp$87$$,$project_id$$)},$APP.$app$main$store$state$$);
$APP.$app$main$refs$permissions$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$1722$permissions$$),$APP.$app$main$refs$team$$);$APP.$app$main$refs$teams$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$2173$teams$$),$APP.$app$main$store$state$$);$APP.$app$main$refs$exception$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$727$exception$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$threads$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2175$comment_threads$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$share_links$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2176$share_links$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$export$0$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2177$export$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$persistence$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2178$persistence$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$projects$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1928$projects$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$files$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1916$files$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$file$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($files_state$jscomp$88$$){var $file_id$jscomp$10$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($files_state$jscomp$88$$);$files_state$jscomp$88$$=$APP.$cljs$cst$1916$files$$.$cljs$core$IFn$_invoke$arity$1$($files_state$jscomp$88$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files_state$jscomp$88$$,$file_id$jscomp$10$$)},$APP.$app$main$store$state$$);
$APP.$app$main$refs$shared_files$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2179$shared_files$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$libraries$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($file_id$jscomp$12_state$jscomp$89$$){var $files$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$12_state$jscomp$89$$,$APP.$cljs$cst$1916$files$$);$file_id$jscomp$12_state$jscomp$89$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$12_state$jscomp$89$$,$APP.$cljs$cst$1917$current_file_id$$);return $APP.$app$main$refs$select_libraries$$($files$jscomp$2$$,
$file_id$jscomp$12_state$jscomp$89$$)},$APP.$app$main$store$state$$);
$APP.$app$main$refs$selected_files$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($files$jscomp$4_state$jscomp$90$$){var $selected$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$4_state$jscomp$90$$,$APP.$cljs$cst$2183$selected_files$$);$files$jscomp$4_state$jscomp$90$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$4_state$jscomp$90$$,$APP.$cljs$cst$1916$files$$);return $APP.$app$main$refs$extract_selected_files$$($files$jscomp$4_state$jscomp$90$$,
$selected$jscomp$11$$)},$APP.$app$main$store$state$$);$APP.$app$main$refs$selected_project$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2184$selected_project$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$dashboard_local$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2185$dashboard_local$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$render_context_lost_QMARK_$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$2187$lost$$,$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$2186$render_state$$,$APP.$app$main$store$state$$));$APP.$app$main$refs$workspace_local$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1920$workspace_local$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$workspace_global$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2188$workspace_global$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$mcp$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1236$mcp$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$workspace_drawing$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2189$workspace_drawing$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$workspace_tokens$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2137$workspace_tokens$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$workspace_selrect$$=function(){var $a$jscomp$367$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$APP.$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$streams$workspace_selrect$$,function($p1__50194_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($a$jscomp$367$$,$p1__50194_SHARP_$$)});return $a$jscomp$367$$}();
$app$main$refs$selected_shapes_data$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($selected$jscomp$12_state$jscomp$91$$){var $objects$jscomp$161$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$12_state$jscomp$91$$);$selected$jscomp$12_state$jscomp$91$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$12_state$jscomp$91$$,$APP.$cljs$cst$1920$workspace_local$$),
$APP.$cljs$cst$1921$selected$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1631$objects$$,$objects$jscomp$161$$,$APP.$cljs$cst$1921$selected$$,$selected$jscomp$12_state$jscomp$91$$],null)},$APP.$app$main$store$state$$,function($v1$jscomp$29$$,$v2$jscomp$21$$){return $APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($v1$jscomp$29$$)===$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($v2$jscomp$21$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1921$selected$$.$cljs$core$IFn$_invoke$arity$1$($v1$jscomp$29$$),
$APP.$cljs$cst$1921$selected$$.$cljs$core$IFn$_invoke$arity$1$($v2$jscomp$21$$))});
$APP.$app$main$refs$selected_shapes$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects$jscomp$162_p__50202$$){var $map__50203__$1_selected$jscomp$13$$=$APP.$cljs$core$__destructure_map$$($objects$jscomp$162_p__50202$$);$objects$jscomp$162_p__50202$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50203__$1_selected$jscomp$13$$,$APP.$cljs$cst$1631$objects$$);$map__50203__$1_selected$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50203__$1_selected$jscomp$13$$,
$APP.$cljs$cst$1921$selected$$);return $app$main$data$helpers$process_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$162_p__50202$$,$map__50203__$1_selected$jscomp$13$$)},$app$main$refs$selected_shapes_data$$,$APP.$cljs$core$_EQ_$$);$APP.$app$main$refs$selected_zoom$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2196$zoom$$,$APP.$app$main$refs$workspace_local$$);
$APP.$app$main$refs$selected_drawing_tool$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2197$tool$$,$APP.$app$main$refs$workspace_drawing$$);$APP.$app$main$refs$selected_edition$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2199$edition$$,$APP.$app$main$refs$workspace_local$$);$APP.$app$main$refs$current_transform$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1289$transform$$,$APP.$app$main$refs$workspace_local$$);
$APP.$app$main$refs$options_mode_global$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2200$options_mode$$,$APP.$app$main$refs$workspace_global$$);$APP.$app$main$refs$default_font$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2201$default_font$$,$APP.$app$main$refs$workspace_global$$);$APP.$app$main$refs$workspace_vport$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2203$vport$$,$APP.$app$main$refs$workspace_local$$);
$APP.$app$main$refs$vbox$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1925$vbox$$,$APP.$app$main$refs$workspace_local$$);$APP.$app$main$refs$editing_page_item$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2207$page_item$$,$APP.$app$main$refs$workspace_local$$);
$APP.$app$main$refs$current_hover_ids$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2208$hover_ids$$,$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2205$context_menu$$,$APP.$app$main$refs$workspace_local$$));$APP.$app$main$refs$workspace_layout$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2209$workspace_layout$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$snap_pixel_QMARK_$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__50213_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($p1__50213_SHARP_$$,$APP.$cljs$cst$2210$snap_pixel_grid$$)},$APP.$app$main$refs$workspace_layout$$);$APP.$app$main$refs$rulers_QMARK_$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__50214_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($p1__50214_SHARP_$$,$APP.$cljs$cst$2211$rulers$$)},$APP.$app$main$refs$workspace_layout$$);
$APP.$app$main$refs$workspace_data$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$helpers$lookup_file_data$$,$APP.$app$main$store$state$$);
$app$main$refs$workspace_file_colors$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($G__50218_map__50217__$1_p__50216$$){$G__50218_map__50217__$1_p__50216$$=$APP.$cljs$core$__destructure_map$$($G__50218_map__50217__$1_p__50216$$);var $id$jscomp$216$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__50218_map__50217__$1_p__50216$$,$APP.$cljs$cst$266$id$$);$G__50218_map__50217__$1_p__50216$$=$APP.$cljs$cst$2212$colors$$.$cljs$core$IFn$_invoke$arity$1$($G__50218_map__50217__$1_p__50216$$);
return $G__50218_map__50217__$1_p__50216$$==null?null:$APP.$cljs$core$update_vals$$($G__50218_map__50217__$1_p__50216$$,function($p1__50215_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__50215_SHARP_$$,$APP.$cljs$cst$1644$file_id$$,$id$jscomp$216$$)})},$APP.$app$main$refs$workspace_data$$,$APP.$cljs$core$_EQ_$$);
$APP.$app$main$refs$recent_colors$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$92$$){var $temp__5825__auto__$jscomp$137$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$92$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$137$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$92$$,$APP.$cljs$cst$2213$recent_colors$$),$temp__5825__auto__$jscomp$137$$):
null},$APP.$app$main$store$state$$);
$APP.$app$main$refs$recent_fonts$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$93$$){var $temp__5825__auto__$jscomp$138$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$93$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$138$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$93$$,$APP.$cljs$cst$2214$recent_fonts$$),$temp__5825__auto__$jscomp$138$$):
null},$APP.$app$main$store$state$$);$APP.$app$main$refs$workspace_file_typography$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2215$typographies$$,$APP.$app$main$refs$workspace_data$$);$APP.$app$main$refs$workspace_presence$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2216$workspace_presence$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$workspace_page$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$helpers$lookup_page$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$workspace_page_flows$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__50225_SHARP_$$){return $APP.$cljs$core$not_empty$$($APP.$cljs$cst$2056$flows$$.$cljs$core$IFn$_invoke$arity$1$($p1__50225_SHARP_$$))},$APP.$app$main$refs$workspace_page$$);
$APP.$app$main$refs$workspace_page_guides$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2057$guides$$,$APP.$app$main$refs$workspace_page$$);$APP.$app$main$refs$workspace_page_objects$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$main$data$helpers$lookup_page_objects$$,$APP.$app$main$store$state$$,$cljs$core$identical_QMARK_$$);
$APP.$app$main$refs$workspace_read_only_QMARK_$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2217$read_only_QMARK_$$,$APP.$app$main$refs$workspace_global$$);$APP.$app$main$refs$workspace_paddings_selected$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2218$paddings_selected$$,$APP.$app$main$refs$workspace_global$$);
$APP.$app$main$refs$workspace_gap_selected$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2219$gap_selected$$,$APP.$app$main$refs$workspace_global$$);$APP.$app$main$refs$workspace_margins_selected$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2220$margins_selected$$,$APP.$app$main$refs$workspace_global$$);
$APP.$app$main$refs$workspace_frames$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$shape_tree$get_frames$$,$APP.$app$main$refs$workspace_page_objects$$,$APP.$cljs$core$_EQ_$$);$APP.$app$main$refs$workspace_editor$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2221$workspace_editor$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$workspace_editor_state$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2222$workspace_editor_state$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$workspace_v2_editor_state$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$2223$workspace_v2_editor_state$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$workspace_modifiers$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1922$workspace_modifiers$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$workspace_wasm_editor_styles$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2224$workspace_wasm_editor_styles$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$workspace_wasm_modifiers$$=function(){var $a$jscomp$368$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$APP.$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$streams$wasm_modifiers$$,function($p1__50254_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($a$jscomp$368$$,$p1__50254_SHARP_$$)});return $a$jscomp$368$$}();
$app$main$refs$workspace_frame_modifiers$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($map__50268__$1_p__50267$$){$map__50268__$1_p__50267$$=$APP.$cljs$core$__destructure_map$$($map__50268__$1_p__50267$$);var $modifiers$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50268__$1_p__50267$$,$APP.$cljs$cst$1810$modifiers$$),$objects$jscomp$167$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50268__$1_p__50267$$,$APP.$cljs$cst$1631$objects$$);
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$212$$,$modifiers__$1$jscomp$11_p__50270$$){var $id$jscomp$221$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers__$1$jscomp$11_p__50270$$,0,null);$modifiers__$1$jscomp$11_p__50270$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers__$1$jscomp$11_p__50270$$,1,null);var $shape$jscomp$215$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$167$$,$id$jscomp$221$$),
$frame_id$jscomp$22$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$215$$);return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$215$$)?$APP.$cljs$core$assoc_in$$($result$jscomp$212$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$221$$,$id$jscomp$221$$],null),$modifiers__$1$jscomp$11_p__50270$$):$frame_id$jscomp$22$$!=null?$APP.$cljs$core$assoc_in$$($result$jscomp$212$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$22$$,$id$jscomp$221$$],null),$modifiers__$1$jscomp$11_p__50270$$):$result$jscomp$212$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$modifiers$jscomp$42$$)},$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($state$jscomp$94$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1810$modifiers$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$94$$,
$APP.$cljs$cst$1922$workspace_modifiers$$),$APP.$cljs$cst$1631$objects$$,$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$94$$)],null)},$APP.$app$main$store$state$$,function($a$jscomp$369$$,$b$jscomp$299$$){return $APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$369$$)===$APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$299$$)&&$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$369$$)===
$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$299$$)}));$app$main$refs$workspace_clipboard_style$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2225$clipboard_style$$,$APP.$app$main$refs$workspace_global$$);$APP.$app$main$refs$workspace_focus_selected$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2226$workspace_focus_selected$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$tokens_lib$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2139$tokens_lib$$,$APP.$app$main$refs$workspace_data$$);$APP.$app$main$refs$workspace_token_theme_groups$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$data$nilf$$($app$common$types$tokens_lib$get_theme_groups$$),$APP.$app$main$refs$tokens_lib$$);
$APP.$app$main$refs$workspace_token_theme_tree_no_hidden$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($G__50296__$1$jscomp$inline_5593_lib$jscomp$3_or__5025__auto__$jscomp$410$$){$G__50296__$1$jscomp$inline_5593_lib$jscomp$3_or__5025__auto__$jscomp$410$$=$G__50296__$1$jscomp$inline_5593_lib$jscomp$3_or__5025__auto__$jscomp$410$$==null?null:$app$common$types$tokens_lib$delete_theme$$($G__50296__$1$jscomp$inline_5593_lib$jscomp$3_or__5025__auto__$jscomp$410$$,$APP.$app$common$uuid$zero$$);
$G__50296__$1$jscomp$inline_5593_lib$jscomp$3_or__5025__auto__$jscomp$410$$=$G__50296__$1$jscomp$inline_5593_lib$jscomp$3_or__5025__auto__$jscomp$410$$==null?null:$app$common$types$tokens_lib$get_theme_tree$$($G__50296__$1$jscomp$inline_5593_lib$jscomp$3_or__5025__auto__$jscomp$410$$);return $APP.$cljs$core$truth_$$($G__50296__$1$jscomp$inline_5593_lib$jscomp$3_or__5025__auto__$jscomp$410$$)?$G__50296__$1$jscomp$inline_5593_lib$jscomp$3_or__5025__auto__$jscomp$410$$:$APP.$cljs$core$PersistentVector$EMPTY$$},
$APP.$app$main$refs$tokens_lib$$);
$APP.$app$main$refs$workspace_token_themes_no_hidden$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__50303_SHARP_$$){return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$tokens_lib$hidden_theme_QMARK_$$,$p1__50303_SHARP_$$)},$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($or__5025__auto__$jscomp$411_p1__50299_SHARP_$$){$or__5025__auto__$jscomp$411_p1__50299_SHARP_$$=$or__5025__auto__$jscomp$411_p1__50299_SHARP_$$==null?
null:$APP.$app$common$types$tokens_lib$get_themes$$($or__5025__auto__$jscomp$411_p1__50299_SHARP_$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$411_p1__50299_SHARP_$$)?$or__5025__auto__$jscomp$411_p1__50299_SHARP_$$:$APP.$cljs$core$PersistentVector$EMPTY$$},$APP.$app$main$refs$tokens_lib$$));$APP.$app$main$refs$selected_token_set_id$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$2138$selected_token_set_id$$),$APP.$app$main$refs$workspace_tokens$$);
$APP.$app$main$refs$workspace_ordered_token_sets$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($or__5025__auto__$jscomp$412_p1__50308_SHARP_$$){$or__5025__auto__$jscomp$412_p1__50308_SHARP_$$=$or__5025__auto__$jscomp$412_p1__50308_SHARP_$$==null?null:$APP.$app$common$types$tokens_lib$get_sets$$($or__5025__auto__$jscomp$412_p1__50308_SHARP_$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$412_p1__50308_SHARP_$$)?$or__5025__auto__$jscomp$412_p1__50308_SHARP_$$:
$APP.$cljs$core$PersistentVector$EMPTY$$},$APP.$app$main$refs$tokens_lib$$);$APP.$app$main$refs$workspace_token_sets_tree$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$data$nilf$$($APP.$app$common$types$tokens_lib$get_set_tree$$),$APP.$app$main$refs$tokens_lib$$);$APP.$app$main$refs$workspace_active_theme_paths$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$data$nilf$$($app$common$types$tokens_lib$get_active_theme_paths$$),$APP.$app$main$refs$tokens_lib$$);
$APP.$app$main$refs$workspace_all_tokens_map$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$data$nilf$$($APP.$app$common$types$tokens_lib$get_all_tokens_map$$),$APP.$app$main$refs$tokens_lib$$);
$APP.$app$main$refs$workspace_active_theme_paths_no_hidden$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__50319_SHARP_$$){return $APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($p1__50319_SHARP_$$,$app$common$types$tokens_lib$hidden_theme_path$$)},$APP.$app$main$refs$workspace_active_theme_paths$$);
$APP.$app$main$refs$workspace_all_tokens_in_selected_set$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($G__50112$jscomp$inline_5597_G__50112__$1$jscomp$inline_5598_p1__50333_SHARP_$$){var $or__5025__auto__$jscomp$414_temp__5825__auto__$jscomp$inline_5596$$=$APP.$app$main$data$workspace$tokens$selected_set$get_selected_token_set_id$$($G__50112$jscomp$inline_5597_G__50112__$1$jscomp$inline_5598_p1__50333_SHARP_$$);$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$414_temp__5825__auto__$jscomp$inline_5596$$)?
($G__50112$jscomp$inline_5597_G__50112__$1$jscomp$inline_5598_p1__50333_SHARP_$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($G__50112$jscomp$inline_5597_G__50112__$1$jscomp$inline_5598_p1__50333_SHARP_$$),$G__50112$jscomp$inline_5597_G__50112__$1$jscomp$inline_5598_p1__50333_SHARP_$$=$G__50112$jscomp$inline_5597_G__50112__$1$jscomp$inline_5598_p1__50333_SHARP_$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__50112$jscomp$inline_5597_G__50112__$1$jscomp$inline_5598_p1__50333_SHARP_$$,
$APP.$cljs$cst$2139$tokens_lib$$),$or__5025__auto__$jscomp$414_temp__5825__auto__$jscomp$inline_5596$$=$G__50112$jscomp$inline_5597_G__50112__$1$jscomp$inline_5598_p1__50333_SHARP_$$==null?null:$APP.$app$common$types$tokens_lib$get_tokens$$($G__50112$jscomp$inline_5597_G__50112__$1$jscomp$inline_5598_p1__50333_SHARP_$$,$or__5025__auto__$jscomp$414_temp__5825__auto__$jscomp$inline_5596$$)):$or__5025__auto__$jscomp$414_temp__5825__auto__$jscomp$inline_5596$$=null;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$414_temp__5825__auto__$jscomp$inline_5596$$)?
$or__5025__auto__$jscomp$414_temp__5825__auto__$jscomp$inline_5596$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$},$APP.$app$main$store$state$$);$APP.$app$main$refs$plugins_permissions_peek$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$96$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$96$$,$APP.$cljs$cst$2227$plugins_permissions_peek$$),$APP.$cljs$cst$142$data$$)},$APP.$app$main$store$state$$);
$APP.$app$main$refs$viewer_data$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$1592$viewer$$),$APP.$app$main$store$state$$);$APP.$app$main$refs$viewer_local$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2231$viewer_local$$,$APP.$app$main$store$state$$);$app$main$refs$viewer_overlays$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2232$viewer_overlays$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$comment_threads$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2175$comment_threads$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$comments_local$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2233$comments_local$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$profiles$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1915$profiles$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$viewer_zoom_type$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$99$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$99$$,$APP.$cljs$cst$2231$viewer_local$$),$APP.$cljs$cst$2235$zoom_type$$)},$APP.$app$main$store$state$$);
$APP.$app$main$refs$workspace_text_modifier$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2238$workspace_text_modifier$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$colorpicker$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2239$colorpicker$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$workspace_grid_edition$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2240$workspace_grid_edition$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$workspace_preview_blend$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2241$workspace_preview_blend$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$specialized_panel$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2242$specialized_panel$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$updating_library$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$2243$updating_library$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$persistence_state$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$109$status$$,$APP.$cljs$cst$2178$persistence$$),$APP.$app$main$store$state$$);$APP.$app$main$refs$progress$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2244$progress$$,$APP.$app$main$store$state$$);
$APP.$app$main$refs$access_tokens$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1177$access_tokens$$,$APP.$app$main$store$state$$);$APP.$app$main$refs$access_token_created$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2245$access_token_created$$,$APP.$app$main$store$state$$);var $shadow$js$shim$module$0eventsource_parser$0stream$$=shadow$bridge("eventsource-parser/stream");var $app$main$repo$retryable_types$$,$app$main$repo$default_retry_config$$,$app$main$repo$default_options$$;$APP.$app$common$logging$loggers$$.set("app.main.repo",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1161$info$$));
$app$main$repo$retryable_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$2246$offline$$,null,$cljs$cst$2247$service_unavailable$$,null,$cljs$cst$1584$network$$,null,$cljs$cst$2248$bad_gateway$$,null],null),null);$app$main$repo$default_retry_config$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$2249$max_retries$$,3,$cljs$cst$2250$base_delay_ms$$,1E3],null);
$app$main$repo$default_options$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$2257$app_DOT_util_DOT_sse_SLASH_clone_template$$,$cljs$cst$2258$app_DOT_util_DOT_sse_SLASH_import_binfile$$,$APP.$cljs$cst$2259$create_file_thumbnail$$,$cljs$cst$2260$export_binfile$$,$APP.$cljs$cst$2261$app_DOT_util_DOT_sse_SLASH_restore_deleted_team_files$$,$cljs$cst$2262$create_file_object_thumbnail$$,$APP.$cljs$cst$2263$app_DOT_util_DOT_sse_SLASH_export_binfile$$,$cljs$cst$2264$get_raw_file$$,$APP.$cljs$cst$2265$update_file$$,
$APP.$cljs$cst$2266$app_DOT_util_DOT_sse_SLASH_permanently_delete_team_files$$,$cljs$cst$2267$retrieve_list_of_builtin_templates$$],[new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2268$stream_QMARK_$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2268$stream_QMARK_$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2269$query_params$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,
$APP.$cljs$cst$2270$revn$$],null),$cljs$cst$2271$form_data_QMARK_$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$cst$1591$blob$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2268$stream_QMARK_$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2269$query_params$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$2272$object_id$$,
$APP.$cljs$cst$78$tag$$],null),$cljs$cst$2271$form_data_QMARK_$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2268$stream_QMARK_$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$2273$rename_to$$,$APP.$cljs$cst$2274$get_file$$,$cljs$cst$2275$raw_transit_QMARK_$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2269$query_params$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2268$stream_QMARK_$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2269$query_params$$,$APP.$cljs$cst$2124$all$$],null)]);
$APP.$app$main$repo$cmd_BANG_$$=function(){var $method_table__5622__auto__$jscomp$10$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$10$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$10$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$10$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.main.repo",
"cmd!"),function($id$jscomp$229$$){return $id$jscomp$229$$},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$10$$,$method_table__5622__auto__$jscomp$10$$,$prefer_table__5623__auto__$jscomp$10$$,$method_cache__5624__auto__$jscomp$10$$,$cached_hierarchy__5625__auto__$jscomp$10$$)}();
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function($id$jscomp$230$$,$params$jscomp$110$$){return $app$main$repo$send_BANG_$$($id$jscomp$230$$,$params$jscomp$110$$)});
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$1175$login_with_oidc$$,function($_$jscomp$1411_uri$jscomp$67$$,$params$jscomp$111$$){$_$jscomp$1411_uri$jscomp$67$$=$APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"api/auth/oidc"]));return $APP.$beicon$v2$core$mapcat$$($APP.$app$main$repo$handle_response$$,$APP.$beicon$v2$core$map$$($app$util$http$conditional_decode_transit$$,
$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$2276$post$$,$APP.$cljs$cst$1579$uri$$,$_$jscomp$1411_uri$jscomp$67$$,$APP.$cljs$cst$1583$credentials$$,"include",$cljs$cst$1580$headers$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["x-external-session-id",$APP.$app$config$external_session_id$$(),"x-event-origin",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($params$jscomp$111$$))],
null),$APP.$cljs$cst$747$query$$,$params$jscomp$111$$],null))))});
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2177$export$$,function($_$jscomp$1412_map__49703__$1$jscomp$inline_5601_p__49702$jscomp$inline_5600$$,$blob_QMARK_$jscomp$inline_5602_params$jscomp$113$$){$_$jscomp$1412_map__49703__$1$jscomp$inline_5601_p__49702$jscomp$inline_5600$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,
[$APP.$cljs$cst$2281$wait$$,!1,$cljs$cst$2280$blob_QMARK_$$,!1],null),$blob_QMARK_$jscomp$inline_5602_params$jscomp$113$$]));$_$jscomp$1412_map__49703__$1$jscomp$inline_5601_p__49702$jscomp$inline_5600$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$1412_map__49703__$1$jscomp$inline_5601_p__49702$jscomp$inline_5600$$);$blob_QMARK_$jscomp$inline_5602_params$jscomp$113$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1412_map__49703__$1$jscomp$inline_5601_p__49702$jscomp$inline_5600$$,
$cljs$cst$2280$blob_QMARK_$$);var $JSCompiler_temp_const$jscomp$10746$$=$APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"api/export"])),$data$jscomp$inline_12041$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1412_map__49703__$1$jscomp$inline_5601_p__49702$jscomp$inline_5600$$,$cljs$cst$2280$blob_QMARK_$$);return $APP.$beicon$v2$core$mapcat$$($APP.$app$main$repo$handle_response$$,
$APP.$beicon$v2$core$map$$($app$util$http$conditional_decode_transit$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$2276$post$$,$APP.$cljs$cst$1579$uri$$,$JSCompiler_temp_const$jscomp$10746$$,$APP.$cljs$cst$1581$body$$,new $APP.$app$util$http$t_app$0util$0http45214$$($data$jscomp$inline_12041$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cljs$cst$1580$headers$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["x-external-session-id",
$APP.$app$config$external_session_id$$(),"x-event-origin",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($_$jscomp$1412_map__49703__$1$jscomp$inline_5601_p__49702$jscomp$inline_5600$$))],null),$APP.$cljs$cst$1583$credentials$$,"include",$APP.$cljs$cst$1587$response_type$$,$APP.$cljs$core$truth_$$($blob_QMARK_$jscomp$inline_5602_params$jscomp$113$$)?$APP.$cljs$cst$1591$blob$$:$APP.$cljs$cst$1588$text$$],null))))});
$cljs$core$derive$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2282$upload_file_media_object$$,$cljs$cst$2283$app_DOT_main_DOT_repo_SLASH_multipart_upload$$);$cljs$core$derive$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2284$upload_chunk$$,$cljs$cst$2283$app_DOT_main_DOT_repo_SLASH_multipart_upload$$);$cljs$core$derive$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2285$update_profile_photo$$,$cljs$cst$2283$app_DOT_main_DOT_repo_SLASH_multipart_upload$$);
$cljs$core$derive$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2286$update_team_photo$$,$cljs$cst$2283$app_DOT_main_DOT_repo_SLASH_multipart_upload$$);
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2283$app_DOT_main_DOT_repo_SLASH_multipart_upload$$,function($id$jscomp$231$$,$params$jscomp$114$$){return $APP.$beicon$v2$core$mapcat$$($APP.$app$main$repo$handle_response$$,$APP.$beicon$v2$core$map$$($app$util$http$conditional_decode_transit$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1578$method$$,$APP.$cljs$cst$2276$post$$,$APP.$cljs$cst$1579$uri$$,$APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,
"api/main/methods/",$APP.$cljs$core$name$$($id$jscomp$231$$)])),$APP.$cljs$cst$1583$credentials$$,"include",$cljs$cst$1580$headers$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["x-external-session-id",$APP.$app$config$external_session_id$$(),"x-event-origin",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($params$jscomp$114$$))],null),$APP.$cljs$cst$1581$body$$,$app$util$http$form_data$$($params$jscomp$114$$)],null))))});$APP.$app$common$i18n$tr$$=function $app$common$i18n$tr$$($var_args$jscomp$1022$$){for(var $args__5755__auto__$jscomp$167$$=[],$len__5749__auto___49704$$=arguments.length,$i__5750__auto___49705$$=0;;)if($i__5750__auto___49705$$<$len__5749__auto___49704$$)$args__5755__auto__$jscomp$167$$.push(arguments[$i__5750__auto___49705$$]),$i__5750__auto___49705$$+=1;else break;return $app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args__5755__auto__$jscomp$167$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$167$$.slice(1),
0,null):null)};$APP.$app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$=function($key$jscomp$316$$){return $key$jscomp$316$$};$APP.$app$common$i18n$tr$$.$cljs$lang$maxFixedArity$=1;$APP.$app$common$i18n$tr$$.$cljs$lang$applyTo$=function($seq49697_seq49697__$1$$){var $G__49698$$=$APP.$cljs$core$first$$($seq49697_seq49697__$1$$);$seq49697_seq49697__$1$$=$APP.$cljs$core$next$$($seq49697_seq49697__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__49698$$,$seq49697_seq49697__$1$$)};var $shadow$esm$loadables$$={};$shadow$esm$add_loadable$$("app.main.ui.settings/settings-page*","main-settings",function(){return $APP.$app$main$ui$settings$settings_page_STAR_$$});$shadow$esm$add_loadable$$("app.main.ui.auth.verify-token/verify-token-page*","main-auth",function(){return $APP.$app$main$ui$auth$verify_token$verify_token_page_STAR_$$});$shadow$esm$add_loadable$$("app.main.ui.dashboard/dashboard-page*","main-dashboard",function(){return $APP.$app$main$ui$dashboard$dashboard_page_STAR_$$});
$shadow$esm$add_loadable$$("app.main.ui.viewer/viewer-page*","main-viewer",function(){return $APP.$app$main$ui$viewer$viewer_page_STAR_$$});$shadow$esm$add_loadable$$("app.util.code-highlight/highlight!","util-highlight",function(){return $APP.$app$util$code_highlight$highlight_BANG_$$});$shadow$esm$add_loadable$$("app.main.ui.workspace/workspace-page*","main-workspace",function(){return $APP.$app$main$ui$workspace$workspace_page_STAR_$$});
$shadow$esm$add_loadable$$("app.main.ui.auth/auth-page*","main-auth",function(){return $APP.$app$main$ui$auth$auth_page_STAR_$$});var $app$util$i18n$browser_locales$$,$or__5025__auto__$jscomp$inline_5604$$;$APP.$app$common$logging$loggers$$.set("app.util.i18n",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1161$info$$));
$APP.$app$util$i18n$supported_locales$$=$APP.$cljs$core$PersistentVector$fromArray$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"English",$APP.$cljs$cst$260$value$$,"en"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Español",$APP.$cljs$cst$260$value$$,"es"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Català",$APP.$cljs$cst$260$value$$,"ca"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2287$label$$,"Deutsch (community)",$APP.$cljs$cst$260$value$$,"de"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Dutch (community)",$APP.$cljs$cst$260$value$$,"nl"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Euskera (community)",$APP.$cljs$cst$260$value$$,"eu"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Français (community)",$APP.$cljs$cst$260$value$$,"fr"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Français - Canada (community)",$APP.$cljs$cst$260$value$$,"fr_CA"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Gallego (Community)",$APP.$cljs$cst$260$value$$,"gl"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Hausa (Community)",$APP.$cljs$cst$260$value$$,"ha"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,
"Hrvatski (Community)",$APP.$cljs$cst$260$value$$,"hr"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Italiano (community)",$APP.$cljs$cst$260$value$$,"it"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Norsk - Bokmål (community)",$APP.$cljs$cst$260$value$$,"nb_no"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Polski (community)",$APP.$cljs$cst$260$value$$,"pl"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2287$label$$,"Portuguese - Brazil (community)",$APP.$cljs$cst$260$value$$,"pt_br"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Portuguese - Portugal (community)",$APP.$cljs$cst$260$value$$,"pt_pt"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Bahasa Indonesia (community)",$APP.$cljs$cst$260$value$$,"id"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Rumanian (community)",
$APP.$cljs$cst$260$value$$,"ro"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Türkçe (community)",$APP.$cljs$cst$260$value$$,"tr"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Ελληνική γλώσσα (community)",$APP.$cljs$cst$260$value$$,"el"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Русский (community)",$APP.$cljs$cst$260$value$$,"ru"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2287$label$$,"Украї́нська мо́ва (community)",$APP.$cljs$cst$260$value$$,"uk"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Český jazyk (community)",$APP.$cljs$cst$260$value$$,"cs"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Latviešu valoda (community)",$APP.$cljs$cst$260$value$$,"lv"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Српски (community)",$APP.$cljs$cst$260$value$$,
"sr"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Føroyskt mál (community)",$APP.$cljs$cst$260$value$$,"fo"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Korean (community)",$APP.$cljs$cst$260$value$$,"ko"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"עִבְרִית (community)",$APP.$cljs$cst$260$value$$,"he"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,
"आधुनिक मानक हिन्दी (community)",$APP.$cljs$cst$260$value$$,"hi"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"عربي/عربى (community)",$APP.$cljs$cst$260$value$$,"ar"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"فارسی (community)",$APP.$cljs$cst$260$value$$,"fa"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"日本語 (Community)",$APP.$cljs$cst$260$value$$,"ja_jp"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2287$label$$,"简体中文 (community)",$APP.$cljs$cst$260$value$$,"zh_cn"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"繁體中文 (community)",$APP.$cljs$cst$260$value$$,"zh_hant"],null)],!0);$app$util$i18n$browser_locales$$=new $APP.$cljs$core$Delay$$(function(){return $app$util$i18n$parse_locale$$($app$util$globals$navigator$$.language)});$APP.$app$util$globals$global$$.penpotTranslations==null&&($APP.$app$util$globals$global$$.penpotTranslations={});
$or__5025__auto__$jscomp$inline_5604$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$storage$global$$,$cljs$cst$2288$app_DOT_util_DOT_i18n_SLASH_locale$$);$APP.$app$util$i18n$_STAR_current_locale_STAR_$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_5604$$)?$or__5025__auto__$jscomp$inline_5604$$:$app$util$i18n$autodetect$$();var $app$util$i18n$locale$$=$okulary$core$atom$$($APP.$app$util$i18n$_STAR_current_locale_STAR_$$);
$app$util$i18n$C$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.$val$};
var $app$util$i18n$t$$=function $app$util$i18n$t$$($var_args$jscomp$1023$$){switch(arguments.length){case 2:return $app$util$i18n$t$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$98$$=[],$len__5749__auto___49862$$=arguments.length,$i__5750__auto___49863$$=0;;)if($i__5750__auto___49863$$<$len__5749__auto___49862$$)$args_arr__5774__auto__$jscomp$98$$.push(arguments[$i__5750__auto___49863$$]),$i__5750__auto___49863$$+=1;else break;return $app$util$i18n$t$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],
arguments[1],2<$args_arr__5774__auto__$jscomp$98$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$98$$.slice(2),0,null):null)}};
$app$util$i18n$t$$.$cljs$core$IFn$_invoke$arity$2$=function($locale$jscomp$10$$,$code$jscomp$18_code__$1$jscomp$1$$){var $translations$jscomp$1_value$jscomp$448$$=$APP.$app$util$i18n$get_translations$$();$code$jscomp$18_code__$1$jscomp$1$$=$APP.$app$common$data$name$$($code$jscomp$18_code__$1$jscomp$1$$);$translations$jscomp$1_value$jscomp$448$$=$module$contents$goog$object_getValueByKeys$$($translations$jscomp$1_value$jscomp$448$$,$locale$jscomp$10$$,$code$jscomp$18_code__$1$jscomp$1$$);return $translations$jscomp$1_value$jscomp$448$$==
null||$APP.$cljs$core$empty_QMARK_$$($translations$jscomp$1_value$jscomp$448$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("en",$locale$jscomp$10$$)?$code$jscomp$18_code__$1$jscomp$1$$:$app$util$i18n$t$$.$cljs$core$IFn$_invoke$arity$2$("en",$code$jscomp$18_code__$1$jscomp$1$$):$APP.$cljs$core$array_QMARK_$$($translations$jscomp$1_value$jscomp$448$$)?$translations$jscomp$1_value$jscomp$448$$[0]:$translations$jscomp$1_value$jscomp$448$$};
$app$util$i18n$t$$.$cljs$core$IFn$_invoke$arity$variadic$=function($locale$jscomp$11_plural_value__$1$jscomp$6$$,$code$jscomp$19_code__$1$jscomp$2$$,$args$jscomp$238$$){var $translations$jscomp$2_value$jscomp$449$$=$APP.$app$util$i18n$get_translations$$();$code$jscomp$19_code__$1$jscomp$2$$=$APP.$app$common$data$name$$($code$jscomp$19_code__$1$jscomp$2$$);$translations$jscomp$2_value$jscomp$449$$=$module$contents$goog$object_getValueByKeys$$($translations$jscomp$2_value$jscomp$449$$,$locale$jscomp$11_plural_value__$1$jscomp$6$$,
$code$jscomp$19_code__$1$jscomp$2$$);if($translations$jscomp$2_value$jscomp$449$$==null||$APP.$cljs$core$empty_QMARK_$$($translations$jscomp$2_value$jscomp$449$$))return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("en",$locale$jscomp$11_plural_value__$1$jscomp$6$$)?$code$jscomp$19_code__$1$jscomp$2$$:$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$4$($app$util$i18n$t$$,"en",$code$jscomp$19_code__$1$jscomp$2$$,$args$jscomp$238$$);$locale$jscomp$11_plural_value__$1$jscomp$6$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$util$i18n$c_QMARK_$$,
$args$jscomp$238$$));$locale$jscomp$11_plural_value__$1$jscomp$6$$=$APP.$cljs$core$array_QMARK_$$($translations$jscomp$2_value$jscomp$449$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($locale$jscomp$11_plural_value__$1$jscomp$6$$),1)?$translations$jscomp$2_value$jscomp$449$$[0]:$translations$jscomp$2_value$jscomp$449$$[1]:$translations$jscomp$2_value$jscomp$449$$;return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cuerdas$core$format$$,$locale$jscomp$11_plural_value__$1$jscomp$6$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__49822_SHARP_$$){return $app$util$i18n$c_QMARK_$$($p1__49822_SHARP_$$)?$APP.$cljs$core$_deref$$($p1__49822_SHARP_$$):$p1__49822_SHARP_$$},$args$jscomp$238$$))};
$app$util$i18n$t$$.$cljs$lang$applyTo$=function($G__49826_seq49824$$){var $G__49825$$=$APP.$cljs$core$first$$($G__49826_seq49824$$),$seq49824__$1_seq49824__$2$$=$APP.$cljs$core$next$$($G__49826_seq49824$$);$G__49826_seq49824$$=$APP.$cljs$core$first$$($seq49824__$1_seq49824__$2$$);$seq49824__$1_seq49824__$2$$=$APP.$cljs$core$next$$($seq49824__$1_seq49824__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__49825$$,$G__49826_seq49824$$,$seq49824__$1_seq49824__$2$$)};
$app$util$i18n$t$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$util$i18n$tr$$=function $app$util$i18n$tr$$($var_args$jscomp$1024$$){switch(arguments.length){case 1:return $app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:for(var $args_arr__5774__auto__$jscomp$99$$=[],$len__5749__auto___49868$$=arguments.length,$i__5750__auto___49869$$=0;;)if($i__5750__auto___49869$$<$len__5749__auto___49868$$)$args_arr__5774__auto__$jscomp$99$$.push(arguments[$i__5750__auto___49869$$]),$i__5750__auto___49869$$+=1;else break;return $app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],
1<$args_arr__5774__auto__$jscomp$99$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$99$$.slice(1),0,null):null)}};$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$=function($code$jscomp$20$$){return $app$util$i18n$t$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$i18n$_STAR_current_locale_STAR_$$,$code$jscomp$20$$)};
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$=function($code$jscomp$21$$,$args$jscomp$239$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$4$($app$util$i18n$t$$,$APP.$app$util$i18n$_STAR_current_locale_STAR_$$,$code$jscomp$21$$,$args$jscomp$239$$)};
$APP.$app$util$i18n$tr$$.$cljs$lang$applyTo$=function($seq49836_seq49836__$1$$){var $G__49837$$=$APP.$cljs$core$first$$($seq49836_seq49836__$1$$);$seq49836_seq49836__$1$$=$APP.$cljs$core$next$$($seq49836_seq49836__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__49837$$,$seq49836_seq49836__$1$$)};$APP.$app$util$i18n$tr$$.$cljs$lang$maxFixedArity$=1;
$cljs$core$_add_watch$$($app$util$i18n$locale$$,"common.time",function($_$jscomp$1414$$,$___$1$jscomp$806$$,$pv$jscomp$10$$,$cv$jscomp$8$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($pv$jscomp$10$$,$cv$jscomp$8$$)?$app$common$time$set_default_locale$$($cv$jscomp$8$$):null});$app$common$time$set_default_locale$$($APP.$app$util$i18n$_STAR_current_locale_STAR_$$);$APP.$app$common$i18n$tr$$=$APP.$app$util$i18n$tr$$;$app$common$i18n$c$$=$APP.$app$util$i18n$c$$;$APP.$app$common$logging$loggers$$.set("app.main.data.event",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1161$info$$));
$APP.$app$main$data$event$context$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(function(){var $uagent$$=new $shadow$js$shim$module$0ua_parser_js$$.UAParser;return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2289$version$$,$APP.$cljs$cst$1273$full$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$),
$APP.$cljs$cst$888$locale$$,$APP.$app$util$i18n$_STAR_current_locale_STAR_$$],null),function(){var $browser$jscomp$4$$=$uagent$$.getBrowser();return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1357$browser$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($browser$jscomp$4$$,"name"),$cljs$cst$2290$browser_version$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($browser$jscomp$4$$,"version")],null)}(),function(){var $engine$$=$uagent$$.getEngine();
return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$2291$engine$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($engine$$,"name"),$cljs$cst$2292$engine_version$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($engine$$,"version")],null)}(),function(){var $os$jscomp$4$$=$uagent$$.getOS(),$version$jscomp$12$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($os$jscomp$4$$,"version");return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$2293$os$$,
[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($os$jscomp$4$$,"name"))," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($version$jscomp$12$$)].join(""),$cljs$cst$2294$os_version$$,$version$jscomp$12$$],null)}(),function(){var $device$$=$uagent$$.getDevice(),$temp__5823__auto__$jscomp$124$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($device$$,"type");return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$124$$)?
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$2295$device_type$$,$temp__5823__auto__$jscomp$124$$,$cljs$cst$2296$device_vendor$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($device$$,"vendor"),$cljs$cst$2297$device_model$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($device$$,"model")],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2295$device_type$$,"unknown"],null)}(),function(){var $screen__$1$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$window$$,
"screen");return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$2298$screen_width$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($screen__$1$$,"width"),$cljs$cst$2299$screen_height$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($screen__$1$$,"height"),$cljs$cst$2300$screen_color_depth$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($screen__$1$$,"colorDepth"),$cljs$cst$2301$screen_orientation$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($screen__$1$$,
"orientation"),"type")],null)}(),function(){var $cpu$$=$uagent$$.getCPU();return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2302$device_arch$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($cpu$$,"architecture")],null)}()]))}()));
$cljs$core$_add_watch$$($app$util$i18n$locale$$,"events",function($p1__50423_SHARP_$$,$p2__50424_SHARP_$$,$p3__50425_SHARP_$$,$p4__50421_SHARP_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$main$data$event$context$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$888$locale$$,$p4__50421_SHARP_$$)});
$APP.$app$main$data$event$xf_COLON_coerce_to_string$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($v$jscomp$548$$){return $v$jscomp$548$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$($v$jscomp$548$$):typeof $v$jscomp$548$$==="string"?$v$jscomp$548$$:$v$jscomp$548$$==null?null:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$548$$)});var $app$main$data$modal$show_modal_51434$$,$app$main$data$modal$hide_modal_51468$$,$app$main$data$modal$update_modal_51528$$;$APP.$app$main$data$modal$components$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $app$main$data$notifications$show_49872$$,$app$main$data$notifications$hide_49891$$;
$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,13,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Notification"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$284$level$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2343$warning$$,null,$APP.$cljs$cst$2344$success$$,null,$APP.$cljs$cst$1161$info$$,null,$APP.$cljs$cst$849$error$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$109$status$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2345$hide$$,null,$APP.$cljs$cst$2346$visible$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2347$floating$$,null,$APP.$cljs$cst$1671$fixed$$,null,$APP.$cljs$cst$2348$inline$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2349$toast$$,null,$APP.$cljs$cst$2312$context$$,null,$APP.$cljs$cst$2348$inline$$,
null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2350$controls$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$2351$bottom_actions$$,
null,$cljs$cst$1862$close$$,null,$APP.$cljs$cst$2352$inline_actions$$,null,$APP.$cljs$cst$226$none$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$78$tag$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$221$keyword$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2353$timeout$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$cljs$cst$344$int$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$924$accept$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2287$label$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2354$callback$$,$cljs$cst$968$app_DOT_common_DOT_schema_SLASH_fn$$],
null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2355$cancel$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2287$label$$,$APP.$cljs$cst$198$string$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2354$callback$$,$cljs$cst$968$app_DOT_common_DOT_schema_SLASH_fn$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2356$actions$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2287$label$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2354$callback$$,$cljs$cst$968$app_DOT_common_DOT_schema_SLASH_fn$$],null)],null)],null)],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2357$links$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2287$label$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2354$callback$$,$cljs$cst$968$app_DOT_common_DOT_schema_SLASH_fn$$],null)],null)],null)],null)],null));
$APP.$app$main$data$notifications$hide$$=function $app$main$data$notifications$hide$$($var_args$jscomp$1029$$){for(var $args__5755__auto__$jscomp$168$$=[],$len__5749__auto___49940$$=arguments.length,$i__5750__auto___49941$$=0;;)if($i__5750__auto___49941$$<$len__5749__auto___49940$$)$args__5755__auto__$jscomp$168$$.push(arguments[$i__5750__auto___49941$$]),$i__5750__auto___49941$$+=1;else break;return $app$main$data$notifications$hide$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$168$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$168$$.slice(0),0,null):null)};
$APP.$app$main$data$notifications$hide$$.$cljs$core$IFn$_invoke$arity$variadic$=function($p__49888$$){var $map__49889__$1$$=$APP.$cljs$core$__destructure_map$$($p__49888$$),$tag$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49889__$1$$,$APP.$cljs$cst$78$tag$$);typeof $app$main$data$notifications$hide_49891$$==="undefined"&&($app$main$data$notifications$hide_49891$$=function($p__49888$jscomp$1$$,$map__49889$jscomp$1$$,$tag$jscomp$52$$,$meta49892$$){this.$p__49888$=$p__49888$jscomp$1$$;
this.$map__49889$=$map__49889$jscomp$1$$;this.tag=$tag$jscomp$52$$;this.$meta49892$=$meta49892$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$notifications$hide_49891$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$notifications$hide_49891$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$2360$app_DOT_main_DOT_data_DOT_notifications_SLASH_hide$$},$app$main$data$notifications$hide_49891$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_49893$$,$meta49892__$1$$){return new $app$main$data$notifications$hide_49891$$(this.$p__49888$,this.$map__49889$,this.tag,$meta49892__$1$$)},$app$main$data$notifications$hide_49891$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta49892$},$app$main$data$notifications$hide_49891$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$notifications$hide_49891$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1431_notification$jscomp$1$$,
$state$jscomp$110$$){return this.tag!=null?($_$jscomp$1431_notification$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$110$$,$APP.$cljs$cst$2359$notification$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.tag,$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1431_notification$jscomp$1$$))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$110$$,$APP.$cljs$cst$2359$notification$$):$state$jscomp$110$$):$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$110$$,
$APP.$cljs$cst$2359$notification$$)});return new $app$main$data$notifications$hide_49891$$($p__49888$$,$map__49889__$1$$,$tag$jscomp$51$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$main$data$notifications$hide$$.$cljs$lang$maxFixedArity$=0;$APP.$app$main$data$notifications$hide$$.$cljs$lang$applyTo$=function($seq49876$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq49876$$))};$APP.$reitit$exception$format_exception$$=function(){var $method_table__5622__auto__$jscomp$11$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$11$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$11$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$11$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("reitit.exception",
"format-exception"),function($type$jscomp$372$$){return $type$jscomp$372$$},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$11$$,$method_table__5622__auto__$jscomp$11$$,$prefer_table__5623__auto__$jscomp$11$$,$method_cache__5624__auto__$jscomp$11$$,$cached_hierarchy__5625__auto__$jscomp$11$$)}();
$APP.$reitit$exception$format_exception$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function($_$jscomp$1433$$,$message$jscomp$56$$,$data$jscomp$155$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($message$jscomp$56$$),$APP.$cljs$core$truth_$$($data$jscomp$155$$)?["\n\n",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$data$jscomp$155$$]))].join(""):null].join("")});
$APP.$reitit$exception$format_exception$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2363$path_conflicts$$,function($_$jscomp$1434$$,$___$1$jscomp$821$$,$conflicts$$){function $resolve_str$$($path$jscomp$189$$,$route_data$$){return[$APP.$cljs$core$truth_$$($APP.$cljs$cst$2364$conflicting$$.$cljs$core$IFn$_invoke$arity$1$($route_data$$))?"   ":"-\x3e ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$189$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$not_empty$$($APP.$cljs$core$select_keys$$($route_data$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2364$conflicting$$],null))))].join("")}return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$str$$,"Router contains conflicting route paths:\n\n",$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__49877_vals$jscomp$12$$){var $route_data$jscomp$1_vec__49881$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49877_vals$jscomp$12$$,0,null),
$path$jscomp$190$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($route_data$jscomp$1_vec__49881$$,0,null);$route_data$jscomp$1_vec__49881$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($route_data$jscomp$1_vec__49881$$,1,null);$p__49877_vals$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49877_vals$jscomp$12$$,1,null);return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($resolve_str$$($path$jscomp$190$$,$route_data$jscomp$1_vec__49881$$)),
"\n",$APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__49894_route_data__$1$$){var $path__$1$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49894_route_data__$1$$,0,null);$p__49894_route_data__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49894_route_data__$1$$,1,null);return $resolve_str$$($path__$1$jscomp$5$$,$p__49894_route_data__$1$$)},$p__49877_vals$jscomp$12$$)),"\n\n"].join("")},
$conflicts$$))});
$APP.$reitit$exception$format_exception$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2365$name_conflicts$$,function($_$jscomp$1435$$,$___$1$jscomp$822$$,$conflicts$jscomp$1$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$str$$,"Router contains conflicting route names:\n\n",$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__49898_vals$jscomp$13$$){var $name$jscomp$227$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49898_vals$jscomp$13$$,0,
null);$p__49898_vals$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49898_vals$jscomp$13$$,1,null);return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$227$$),"\n-\x3e ",$APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$("\n-\x3e ",$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$p__49898_vals$jscomp$13$$)),"\n"].join("")},$conflicts$jscomp$1$$))});
$APP.$reitit$exception$format_exception$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2366$reitit_DOT_impl_SLASH_merge_data$$,function($_$jscomp$1436$$,$___$1$jscomp$823$$,$data$jscomp$156$$){return["Error merging route-data\n\n",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$data$jscomp$156$$]))].join("")});$APP.$reitit$impl$into_string$$.string=function($this$$jscomp$738$$){return $this$$jscomp$738$$};$APP.$cljs$core$Keyword$$.prototype.$reitit$impl$IntoString$into_string$arity$1$=function(){var $ns$jscomp$33$$=$APP.$cljs$core$namespace$$(this);return[$ns$jscomp$33$$,$APP.$cljs$core$truth_$$($ns$jscomp$33$$)?"/":null,$APP.$cljs$core$name$$(this)].join("")};$APP.$reitit$impl$into_string$$["boolean"]=function($this$$jscomp$740$$){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$740$$)};
$APP.$reitit$impl$into_string$$.number=function($this$$jscomp$741$$){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$741$$)};$APP.$reitit$impl$into_string$$.object=function($this$$jscomp$742$$){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$742$$)};$APP.$reitit$impl$into_string$$["null"]=function(){return null};var $reitit$core$Router$match_by_name$dyn_52182$$;$APP.$cljs$core$Keyword$$.prototype.$reitit$core$Expand$expand$arity$2$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,this],null)};$APP.$cljs$core$PersistentArrayMap$$.prototype.$reitit$core$Expand$expand$arity$2$=function(){return this};$APP.$cljs$core$PersistentHashMap$$.prototype.$reitit$core$Expand$expand$arity$2$=function(){return this};
$APP.$reitit$core$expand$$["function"]=function($this$$jscomp$748$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2402$handler$$,$this$$jscomp$748$$],null)};$APP.$cljs$core$Var$$.prototype.$reitit$core$Expand$expand$arity$2$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2402$handler$$,this],null)};$APP.$reitit$core$expand$$["null"]=function(){return null};
$reitit$core$Router$match_by_name$dyn_52182$$=function(){function $G__52183__3$$($this$$jscomp$763$$,$name$jscomp$229$$,$path_params$jscomp$3$$){var $m__5372__auto__$jscomp$354_m__5374__auto__$jscomp$354$$=$APP.$reitit$core$match_by_name$$[$APP.$goog$typeOf$$($this$$jscomp$763$$==null?null:$this$$jscomp$763$$)];if($m__5372__auto__$jscomp$354_m__5374__auto__$jscomp$354$$!=null)return $m__5372__auto__$jscomp$354_m__5374__auto__$jscomp$354$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$354_m__5374__auto__$jscomp$354$$.$cljs$core$IFn$_invoke$arity$3$($this$$jscomp$763$$,
$name$jscomp$229$$,$path_params$jscomp$3$$):$m__5372__auto__$jscomp$354_m__5374__auto__$jscomp$354$$($this$$jscomp$763$$,$name$jscomp$229$$,$path_params$jscomp$3$$);$m__5372__auto__$jscomp$354_m__5374__auto__$jscomp$354$$=$APP.$reitit$core$match_by_name$$._;if($m__5372__auto__$jscomp$354_m__5374__auto__$jscomp$354$$!=null)return $m__5372__auto__$jscomp$354_m__5374__auto__$jscomp$354$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$354_m__5374__auto__$jscomp$354$$.$cljs$core$IFn$_invoke$arity$3$($this$$jscomp$763$$,
$name$jscomp$229$$,$path_params$jscomp$3$$):$m__5372__auto__$jscomp$354_m__5374__auto__$jscomp$354$$($this$$jscomp$763$$,$name$jscomp$229$$,$path_params$jscomp$3$$);throw $APP.$cljs$core$missing_protocol$$("Router.match-by-name",$this$$jscomp$763$$);}function $G__52183__2$$($this$$jscomp$762$$,$name$jscomp$228$$){var $m__5372__auto__$jscomp$353_m__5374__auto__$jscomp$353$$=$APP.$reitit$core$match_by_name$$[$APP.$goog$typeOf$$($this$$jscomp$762$$==null?null:$this$$jscomp$762$$)];if($m__5372__auto__$jscomp$353_m__5374__auto__$jscomp$353$$!=
null)return $m__5372__auto__$jscomp$353_m__5374__auto__$jscomp$353$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$353_m__5374__auto__$jscomp$353$$.$cljs$core$IFn$_invoke$arity$2$($this$$jscomp$762$$,$name$jscomp$228$$):$m__5372__auto__$jscomp$353_m__5374__auto__$jscomp$353$$($this$$jscomp$762$$,$name$jscomp$228$$);$m__5372__auto__$jscomp$353_m__5374__auto__$jscomp$353$$=$APP.$reitit$core$match_by_name$$._;if($m__5372__auto__$jscomp$353_m__5374__auto__$jscomp$353$$!=null)return $m__5372__auto__$jscomp$353_m__5374__auto__$jscomp$353$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$353_m__5374__auto__$jscomp$353$$.$cljs$core$IFn$_invoke$arity$2$($this$$jscomp$762$$,$name$jscomp$228$$):$m__5372__auto__$jscomp$353_m__5374__auto__$jscomp$353$$($this$$jscomp$762$$,$name$jscomp$228$$);throw $APP.$cljs$core$missing_protocol$$("Router.match-by-name",$this$$jscomp$762$$);}var $G__52183$$=null;$G__52183$$=function($this$$jscomp$764$$,$name$jscomp$230$$,$path_params$jscomp$4$$){switch(arguments.length){case 2:return $G__52183__2$$.call(this,$this$$jscomp$764$$,
$name$jscomp$230$$);case 3:return $G__52183__3$$.call(this,$this$$jscomp$764$$,$name$jscomp$230$$,$path_params$jscomp$4$$)}throw Error("Invalid arity: "+arguments.length);};$G__52183$$.$cljs$core$IFn$_invoke$arity$2$=$G__52183__2$$;$G__52183$$.$cljs$core$IFn$_invoke$arity$3$=$G__52183__3$$;return $G__52183$$}();
$APP.$reitit$core$match_by_name$$=function $reitit$core$match_by_name$$($var_args$jscomp$1041$$){switch(arguments.length){case 2:return $reitit$core$match_by_name$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $reitit$core$match_by_name$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$reitit$core$match_by_name$$.$cljs$core$IFn$_invoke$arity$2$=function($this$$jscomp$765$$,$name$jscomp$231$$){return $this$$jscomp$765$$!=null&&$this$$jscomp$765$$.$reitit$core$Router$match_by_name$arity$2$!=null?$this$$jscomp$765$$.$reitit$core$Router$match_by_name$arity$2$($this$$jscomp$765$$,$name$jscomp$231$$):$reitit$core$Router$match_by_name$dyn_52182$$($this$$jscomp$765$$,$name$jscomp$231$$)};
$APP.$reitit$core$match_by_name$$.$cljs$core$IFn$_invoke$arity$3$=function($this$$jscomp$766$$,$name$jscomp$232$$,$path_params$jscomp$5$$){return $this$$jscomp$766$$!=null&&$this$$jscomp$766$$.$reitit$core$Router$match_by_name$arity$3$!=null?$this$$jscomp$766$$.$reitit$core$Router$match_by_name$arity$3$($this$$jscomp$766$$,$name$jscomp$232$$,$path_params$jscomp$5$$):$reitit$core$Router$match_by_name$dyn_52182$$($this$$jscomp$766$$,$name$jscomp$232$$,$path_params$jscomp$5$$)};
$APP.$reitit$core$match_by_name$$.$cljs$lang$maxFixedArity$=3;var $app$main$router$navigate_52236$$,$app$main$router$assign_exception_52270$$,$app$main$router$nav_back_52329$$,$app$main$router$nav_root_52349$$,$app$main$router$reload_52363$$,$app$main$router$nav_raw_52379$$;var $app$main$data$common$show_notification_52495$$,$app$main$data$common$show_shared_dialog_52501$$,$app$main$data$common$change_team_role_52528$$,$app$main$data$common$team_membership_change_52543$$,$app$main$data$common$go_to_dashboard_files_52620$$,$app$main$data$common$go_to_dashboard_search_52636$$,$app$main$data$common$go_to_dashboard_libraries_52647$$,$app$main$data$common$go_to_dashboard_fonts_52675$$,$app$main$data$common$go_to_dashboard_recent_52687$$,$app$main$data$common$go_to_dashboard_members_52702$$,
$app$main$data$common$go_to_dashboard_invitations_52716$$,$app$main$data$common$go_to_dashboard_webhooks_52727$$,$app$main$data$common$go_to_dashboard_settings_52737$$,$app$main$data$common$go_to_workspace_52749$$,$app$main$data$common$go_to_viewer_52767$$;
$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$720$sequential$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Files"],null),new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"FileParam"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2181$project_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2182$is_shared$$,$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$],null)],null)],null));$APP.$app$main$data$common$noop_fn$$=$APP.$cljs$core$constantly$$(null);
$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Progress"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$302$key$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1795$index$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2328$total$$,$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2498$hints$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,$APP.$cljs$cst$221$keyword$$,$APP.$cljs$core$fn_QMARK_$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2499$slow_progress_threshold$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$],
null)],null));var $app$common$schema$desc_native$visit$$=function(){var $method_table__5622__auto__$jscomp$12$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$12$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$12$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$12$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$205$default$$,$cljs$cst$2537$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_default$$],null),$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():
$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.common.schema.desc-native","visit"),function($name$jscomp$253$$){return $name$jscomp$253$$},$cljs$cst$2537$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_default$$,$hierarchy__5626__auto__$jscomp$12$$,$method_table__5622__auto__$jscomp$12$$,$prefer_table__5623__auto__$jscomp$12$$,$method_cache__5624__auto__$jscomp$12$$,$cached_hierarchy__5625__auto__$jscomp$12$$)}();
$app$common$schema$desc_native$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2537$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_default$$,function($_$jscomp$1561$$,$schema$jscomp$230$$,$___$1$jscomp$944$$,$options$jscomp$479$$){return $malli$core$form$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$230$$,$options$jscomp$479$$)});
$app$common$schema$desc_native$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$200$vector$$,function($_$jscomp$1562$$,$___$1$jscomp$945$$,$children$jscomp$174$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vector$$,$APP.$cljs$cst$200$vector$$,$children$jscomp$174$$)});
$app$common$schema$desc_native$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$202$map$$,function($_$jscomp$1563_params$jscomp$160$$,$___$1$jscomp$946$$,$children$jscomp$175$$){$_$jscomp$1563_params$jscomp$160$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($c$jscomp$289_p__50100$$){var $k$jscomp$616$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$289_p__50100$$,0,null),$p$jscomp$236$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$289_p__50100$$,
1,null);$c$jscomp$289_p__50100$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$289_p__50100$$,2,null);return $p$jscomp$236$$==null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$616$$,$c$jscomp$289_p__50100$$],null):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$616$$,$APP.$app$common$data$without_qualified$cljs$0core$0IFn$0_invoke$0arity$01$$($p$jscomp$236$$),$c$jscomp$289_p__50100$$],
null)},$children$jscomp$175$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vector$$,$APP.$cljs$cst$202$map$$,$_$jscomp$1563_params$jscomp$160$$)});
$app$common$schema$desc_native$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$531$multi$$,function($_$jscomp$1564_props$jscomp$93$$,$schema$jscomp$231$$,$children$jscomp$176$$,$options$jscomp$480$$){$_$jscomp$1564_props$jscomp$93$$=$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($schema$jscomp$231$$);return $APP.$cljs$core$truth_$$($cljs$cst$2538$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_simplified$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1564_props$jscomp$93$$))?
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$531$multi$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1564_props$jscomp$93$$,$cljs$cst$2538$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_simplified$$),$APP.$cljs$cst$873$options$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,
$children$jscomp$176$$)))],null):$malli$core$form$$.$cljs$core$IFn$_invoke$arity$2$($schema$jscomp$231$$,$options$jscomp$480$$)});$app$common$schema$desc_native$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$735$merge$$,function($_$jscomp$1565$$,$___$1$jscomp$947$$,$children$jscomp$177$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vector$$,$APP.$cljs$cst$735$merge$$,$children$jscomp$177$$)});
$app$common$schema$desc_native$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$298$schema$$,function($_$jscomp$1566$$,$schema$jscomp$232$$,$children$jscomp$178$$,$options$jscomp$481$$){return $app$common$schema$desc_native$visit$$.$cljs$core$IFn$_invoke$arity$4$($cljs$cst$412$malli_DOT_core_SLASH_schema$$,$schema$jscomp$232$$,$children$jscomp$178$$,$options$jscomp$481$$)});
$app$common$schema$desc_native$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$449$malli_DOT_core_SLASH_val$$,function($_$jscomp$1567$$,$___$1$jscomp$948$$,$children$jscomp$179$$){return $APP.$cljs$core$last$$($children$jscomp$179$$)});
$app$common$schema$desc_native$visit$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$412$malli_DOT_core_SLASH_schema$$,function($G__50109__$jscomp$1568$$,$schema$jscomp$233$$,$___$1$jscomp$949$$,$G__50110_options$jscomp$482$$){$G__50109__$jscomp$1568$$=$malli$core$deref$cljs$0core$0IFn$0_invoke$0arity$02$$($schema$jscomp$233$$,null);$G__50110_options$jscomp$482$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__50110_options$jscomp$482$$,$cljs$cst$2539$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_level$$,
$APP.$cljs$core$inc$$);return $app$common$schema$desc_native$describe_STAR_$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$schema$desc_native$describe_STAR_$$.$cljs$core$IFn$_invoke$arity$2$($G__50109__$jscomp$1568$$,$G__50110_options$jscomp$482$$):$app$common$schema$desc_native$describe_STAR_$$($G__50109__$jscomp$1568$$,$G__50110_options$jscomp$482$$)});var $app$common$types$container$schema_COLON_container$$=$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1624$page$$,null,$APP.$cljs$cst$1625$component$$,null],null),null)],null)],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$296$path$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1737$modified_at$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$objects$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,10],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$,$APP.$cljs$cst$202$map$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1738$plugin_data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$app$common$types$plugins$schema_COLON_plugin_data$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$934$app_DOT_common_DOT_schema_SLASH_type$$,$cljs$cst$2546$app_DOT_common_DOT_types_DOT_container_SLASH_container$$],null))),$app$common$types$container$get_child_heads$$,$app$common$types$container$get_first_valid_parent$$,$app$common$types$container$collect_main_shapes$$;$app$common$schema$check_fn$$($app$common$types$container$schema_COLON_container$$);
$app$common$types$container$get_child_heads$$=function $app$common$types$container$get_child_heads$$($objects$jscomp$181$$,$shape$jscomp$224_shape_id$jscomp$25$$){$shape$jscomp$224_shape_id$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$181$$,$shape$jscomp$224_shape_id$jscomp$25$$);return $shape$jscomp$224_shape_id$jscomp$25$$==null?$APP.$cljs$core$PersistentVector$EMPTY$$:$APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$224_shape_id$jscomp$25$$)?
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$224_shape_id$jscomp$25$$],null):$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__51514_SHARP_$$){return $app$common$types$container$get_child_heads$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$types$container$get_child_heads$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$181$$,$p1__51514_SHARP_$$):$app$common$types$container$get_child_heads$$($objects$jscomp$181$$,
$p1__51514_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$224_shape_id$jscomp$25$$)]))};
$APP.$app$common$types$container$get_instance_root$$=function $app$common$types$container$get_instance_root$$($objects$jscomp$185$$,$G__51540_shape$jscomp$228$$){if($G__51540_shape$jscomp$228$$==null||$APP.$app$common$files$helpers$root_QMARK_$$($G__51540_shape$jscomp$228$$))return null;if($APP.$app$common$types$component$instance_root_QMARK_$$($G__51540_shape$jscomp$228$$))return $G__51540_shape$jscomp$228$$;$G__51540_shape$jscomp$228$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$185$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($G__51540_shape$jscomp$228$$));return $app$common$types$container$get_instance_root$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$types$container$get_instance_root$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$185$$,$G__51540_shape$jscomp$228$$):$app$common$types$container$get_instance_root$$($objects$jscomp$185$$,$G__51540_shape$jscomp$228$$)};
$app$common$types$container$get_first_valid_parent$$=function $app$common$types$container$get_first_valid_parent$$($objects$jscomp$193$$,$G__51633_id$jscomp$251_shape$jscomp$236$$){$G__51633_id$jscomp$251_shape$jscomp$236$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$193$$,$G__51633_id$jscomp$251_shape$jscomp$236$$);var $JSCompiler_inline_result$jscomp$902_or__5025__auto__$jscomp$inline_5646$$=($JSCompiler_inline_result$jscomp$902_or__5025__auto__$jscomp$inline_5646$$=$APP.$app$common$types$component$in_component_copy_QMARK_$$($G__51633_id$jscomp$251_shape$jscomp$236$$))?
$JSCompiler_inline_result$jscomp$902_or__5025__auto__$jscomp$inline_5646$$:$APP.$app$common$types$component$is_variant_container_QMARK_$$($G__51633_id$jscomp$251_shape$jscomp$236$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$902_or__5025__auto__$jscomp$inline_5646$$)?($G__51633_id$jscomp$251_shape$jscomp$236$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($G__51633_id$jscomp$251_shape$jscomp$236$$),$app$common$types$container$get_first_valid_parent$$.$cljs$core$IFn$_invoke$arity$2$?
$app$common$types$container$get_first_valid_parent$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$193$$,$G__51633_id$jscomp$251_shape$jscomp$236$$):$app$common$types$container$get_first_valid_parent$$($objects$jscomp$193$$,$G__51633_id$jscomp$251_shape$jscomp$236$$)):$G__51633_id$jscomp$251_shape$jscomp$236$$};
$APP.$app$common$types$container$has_any_copy_parent_QMARK_$$=function $app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$194$$,$G__51642_shape$jscomp$237$$){var $parent$jscomp$193$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$194$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($G__51642_shape$jscomp$237$$));if($parent$jscomp$193$$==null)return!1;if($APP.$app$common$types$component$in_component_copy_QMARK_$$($parent$jscomp$193$$))return!0;
$G__51642_shape$jscomp$237$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($G__51642_shape$jscomp$237$$);return $app$common$types$container$has_any_copy_parent_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$types$container$has_any_copy_parent_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$194$$,$G__51642_shape$jscomp$237$$):$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$194$$,$G__51642_shape$jscomp$237$$)};
$app$common$types$container$collect_main_shapes$$=function $app$common$types$container$collect_main_shapes$$($shape$jscomp$240_temp__5823__auto__$jscomp$145$$,$objects$jscomp$197$$){if($APP.$app$common$types$component$main_instance_QMARK_$$($shape$jscomp$240_temp__5823__auto__$jscomp$145$$))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$240_temp__5823__auto__$jscomp$145$$],null);$shape$jscomp$240_temp__5823__auto__$jscomp$145$$=
$app$common$files$helpers$get_children$$($objects$jscomp$197$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$240_temp__5823__auto__$jscomp$145$$));return $APP.$cljs$core$truth_$$($shape$jscomp$240_temp__5823__auto__$jscomp$145$$)?$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__51644_SHARP_$$){return $app$common$types$container$collect_main_shapes$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$types$container$collect_main_shapes$$.$cljs$core$IFn$_invoke$arity$2$($p1__51644_SHARP_$$,
$objects$jscomp$197$$):$app$common$types$container$collect_main_shapes$$($p1__51644_SHARP_$$,$objects$jscomp$197$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shape$jscomp$240_temp__5823__auto__$jscomp$145$$])):$APP.$cljs$core$PersistentVector$EMPTY$$};var $app$common$features$default_features$$,$app$common$features$backend_only_features$$;
$APP.$app$common$features$supported_features$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,15,["fdata/path-data",null,"plugins/runtime",null,"design-tokens/v1",null,"variants/v1",null,"layout/grid",null,"styles/v2",null,"fdata/pointer-map",null,"text-editor/v2-html-paste",null,"fdata/objects-map",null,"text-editor/v2",null,"tokens/numeric-input",null,"render-wasm/v1",null,"text-editor-wasm/v1",null,"components/v2",null,"fdata/shape-data-type",null],null),
null);$app$common$features$default_features$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,9,["fdata/path-data",null,"plugins/runtime",null,"design-tokens/v1",null,"variants/v1",null,"layout/grid",null,"styles/v2",null,"tokens/numeric-input",null,"components/v2",null,"fdata/shape-data-type",null],null),null);
$APP.$app$common$features$frontend_only_features$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,7,["plugins/runtime",null,"styles/v2",null,"text-editor/v2-html-paste",null,"text-editor/v2",null,"tokens/numeric-input",null,"render-wasm/v1",null,"text-editor-wasm/v1",null],null),null);
$app$common$features$backend_only_features$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["fdata/pointer-map",null,"fdata/objects-map",null],null),null);
$APP.$app$common$features$no_migration_features$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,["fdata/path-data",null,"design-tokens/v1",null,"variants/v1",null,"layout/grid",null,"tokens/numeric-input",null,"fdata/shape-data-type",null],null),null),$APP.$app$common$features$frontend_only_features$$),$app$common$features$backend_only_features$$);
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$298$schema$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,"FileFeatures",$cljs$cst$2559$app_DOT_common_DOT_schema_DOT_desc_js_like_SLASH_inline$$,!0,$cljs$cst$869$gen_SLASH_gen$$,function($elements$jscomp$3$$){var $dest$jscomp$1$$=$APP.$cljs$core$PersistentVector$EMPTY$$;
return $clojure$test$check$generators$fmap$$(function($bools$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($dest$jscomp$1$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$list$$,$bools$$,$elements$jscomp$3$$))},$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($clojure$test$check$generators$tuple$$,
$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$count$$($elements$jscomp$3$$),$clojure$test$check$generators$boolean$0$$)))}($APP.$app$common$features$supported_features$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$934$app_DOT_common_DOT_schema_SLASH_type$$,
$cljs$cst$2560$app_DOT_common_DOT_features_SLASH_features$$],null)));$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$contains_QMARK_$$,$APP.$app$common$features$supported_features$$));$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__51444_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($p1__51444_SHARP_$$,"ephimeral/")});
var $app$common$features$xf_flag_to_feature$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($flag$jscomp$5$$){switch($flag$jscomp$5$$ instanceof $APP.$cljs$core$Keyword$$?$flag$jscomp$5$$.$fqn$:null){case "feature-styles-v2":return"styles/v2";case "feature-fdata-objects-map":return"fdata/objects-map";case "feature-fdata-pointer-map":return"fdata/pointer-map";case "feature-plugins":return"plugins/runtime";case "feature-design-tokens":return"design-tokens/v1";case "feature-text-editor-v2":return"text-editor/v2";
case "feature-text-editor-v2-html-paste":return"text-editor/v2-html-paste";case "feature-text-editor-wasm":return"text-editor-wasm/v1";case "feature-render-wasm":return"render-wasm/v1";case "feature-variants":return"variants/v1";case "feature-token-input":return"tokens/numeric-input";default:return null}});var $app$common$types$typography$schema_COLON_typography$$;
$app$common$types$typography$schema_COLON_typography$$=new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Typography"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1757$font_id$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1759$font_variant_id$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1762$font_style$$,
$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1765$line_height$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1769$text_transform$$,$APP.$cljs$cst$198$string$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1737$modified_at$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$296$path$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1738$plugin_data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$plugins$schema_COLON_plugin_data$$],null)],null);$APP.$app$common$types$typography$check_typography$$=$app$common$schema$check_fn$$($app$common$types$typography$schema_COLON_typography$$);var $app$common$types$file$schema_COLON_media$$=new $APP.$cljs$core$PersistentVector$$(null,13,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"FileMedia"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1569$created_at$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2571$deleted_at$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$,$cljs$cst$961$app_DOT_common_DOT_schema_SLASH_safe_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1522$height$$,$cljs$cst$961$app_DOT_common_DOT_schema_SLASH_safe_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1726$mtype$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2572$media_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2573$thumbnail_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2574$is_local$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null)],null),$app$common$types$file$schema_COLON_colors$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,5],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$,$app$common$types$color$schema_COLON_library_color$$],null),$app$common$types$file$schema_COLON_typographies$$=
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,2],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$,$app$common$types$typography$schema_COLON_typography$$],null),$app$common$types$file$schema_COLON_data$$=new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$939$title$$,"FileData"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2228$pages$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,5],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$,$app$common$types$page$schema_COLON_page$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$873$options$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"FileOptions"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2575$components_v2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2576$base_font_size$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2212$colors$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$file$schema_COLON_colors$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,5],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$,$app$common$types$container$schema_COLON_container$$],null)],null),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2215$typographies$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$file$schema_COLON_typographies$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1738$plugin_data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$plugins$schema_COLON_plugin_data$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2139$tokens_lib$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$tokens_lib$schema_COLON_tokens_lib$$],null)],null),$app$common$types$file$schema_COLON_file$$=new $APP.$cljs$core$PersistentVector$$(null,17,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$939$title$$,"file"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2270$revn$$,
$cljs$cst$344$int$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2577$vern$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$344$int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1569$created_at$$,$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1737$modified_at$$,$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2571$deleted_at$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2181$project_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1927$team_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2182$is_shared$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2578$has_media_trimmed$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$types$file$schema_COLON_data$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2289$version$$,$cljs$cst$344$int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$227$features$$,$cljs$cst$2560$app_DOT_common_DOT_features_SLASH_features$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2579$migrations$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$948$ordered$$,!0],null),$APP.$cljs$cst$198$string$$],null)],null)],null),
$app$common$types$file$empty_file_data$$,$app$common$types$file$find_next_related_swap_shape_id$$;$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$2580$app_DOT_common_DOT_types_DOT_file_SLASH_data$$,$app$common$types$file$schema_COLON_data$$);$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$2581$app_DOT_common_DOT_types_DOT_file_SLASH_file$$,$app$common$types$file$schema_COLON_file$$);
$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$2582$app_DOT_common_DOT_types_DOT_file_SLASH_colors$$,$app$common$types$file$schema_COLON_colors$$);$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$2583$app_DOT_common_DOT_types_DOT_file_SLASH_typographies$$,$app$common$types$file$schema_COLON_typographies$$);
$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$types$file$schema_COLON_file$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,"invalid file"]));var $app$common$types$file$check_file_data$$=$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$types$file$schema_COLON_data$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,"invalid file data"]));$app$common$schema$check_fn$$($app$common$types$file$schema_COLON_media$$);
$app$common$types$file$empty_file_data$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2228$pages$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1630$pages_index$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null);
$app$common$types$file$find_next_related_swap_shape_id$$=function $app$common$types$file$find_next_related_swap_shape_id$$($parent$jscomp$198_referenced_shape$$,$swap_slot_id$$,$libraries$jscomp$20$$){var $container$jscomp$25$$=$app$common$types$file$get_component_container_from_head$$($parent$jscomp$198_referenced_shape$$,$libraries$jscomp$20$$),$children$jscomp$189_objects$jscomp$209$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$25$$);$children$jscomp$189_objects$jscomp$209$$=
$app$common$files$helpers$get_children$$($children$jscomp$189_objects$jscomp$209$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$198_referenced_shape$$));var $original_shape_id$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51868_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($swap_slot_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__51868_SHARP_$$))},
$children$jscomp$189_objects$jscomp$209$$)));if($APP.$cljs$core$truth_$$($original_shape_id$$))return $original_shape_id$$;$parent$jscomp$198_referenced_shape$$=$app$common$types$file$find_ref_shape$$(null,$container$jscomp$25$$,$libraries$jscomp$20$$,$parent$jscomp$198_referenced_shape$$);var $next_shape_id$$=$APP.$cljs$core$truth_$$($parent$jscomp$198_referenced_shape$$)?$app$common$types$file$find_next_related_swap_shape_id$$.$cljs$core$IFn$_invoke$arity$3$?$app$common$types$file$find_next_related_swap_shape_id$$.$cljs$core$IFn$_invoke$arity$3$($parent$jscomp$198_referenced_shape$$,
$swap_slot_id$$,$libraries$jscomp$20$$):$app$common$types$file$find_next_related_swap_shape_id$$($parent$jscomp$198_referenced_shape$$,$swap_slot_id$$,$libraries$jscomp$20$$):null;return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51869_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($next_shape_id$$,$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($p1__51869_SHARP_$$))},
$children$jscomp$189_objects$jscomp$209$$)))};
$APP.$app$common$types$file$load_component_objects$$=function $app$common$types$file$load_component_objects$$($var_args$jscomp$1095$$){switch(arguments.length){case 2:return $app$common$types$file$load_component_objects$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$common$types$file$load_component_objects$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$types$file$load_component_objects$$.$cljs$core$IFn$_invoke$arity$2$=function($file_data$jscomp$44$$,$component$jscomp$32$$){return $APP.$app$common$types$file$load_component_objects$$.$cljs$core$IFn$_invoke$arity$3$($file_data$jscomp$44$$,$component$jscomp$32$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0))};
$APP.$app$common$types$file$load_component_objects$$.$cljs$core$IFn$_invoke$arity$3$=function($component_page$jscomp$3_file_data$jscomp$45_objects$jscomp$211$$,$component$jscomp$33$$,$delta$jscomp$12$$){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($component$jscomp$33$$)?$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$33$$)):$component$jscomp$33$$)){$component_page$jscomp$3_file_data$jscomp$45_objects$jscomp$211$$=$APP.$app$common$types$file$get_component_page$$($component_page$jscomp$3_file_data$jscomp$45_objects$jscomp$211$$,
$component$jscomp$33$$);var $page_objects$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component_page$jscomp$3_file_data$jscomp$45_objects$jscomp$211$$);$component_page$jscomp$3_file_data$jscomp$45_objects$jscomp$211$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51880_SHARP_$$){return $app$common$geom$shapes$transforms$move$$($p1__51880_SHARP_$$,$delta$jscomp$12$$)},
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__51879_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page_objects$$,$p1__51879_SHARP_$$)},$APP.$cljs$core$cons$$($APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$33$$),$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($page_objects$$,$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$33$$))))));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($component$jscomp$33$$,
$APP.$cljs$cst$1631$objects$$,$component_page$jscomp$3_file_data$jscomp$45_objects$jscomp$211$$)}return $component$jscomp$33$$};$APP.$app$common$types$file$load_component_objects$$.$cljs$lang$maxFixedArity$=3;
var $app$common$types$file$uses_asset_QMARK_$$=function(){var $method_table__5622__auto__$jscomp$13$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$13$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$13$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$13$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.common.types.file",
"uses-asset?"),function($asset_type$$){return $asset_type$$},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$13$$,$method_table__5622__auto__$jscomp$13$$,$prefer_table__5623__auto__$jscomp$13$$,$method_cache__5624__auto__$jscomp$13$$,$cached_hierarchy__5625__auto__$jscomp$13$$)}();
$app$common$types$file$uses_asset_QMARK_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$1625$component$$,function($_$jscomp$1574$$,$shape$jscomp$270$$,$library_id$jscomp$10$$,$component$jscomp$35$$){return $app$common$types$component$instance_of_QMARK_$$($shape$jscomp$270$$,$library_id$jscomp$10$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$35$$))});
$app$common$types$file$uses_asset_QMARK_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$1298$color$$,function($_$jscomp$1575$$,$shape$jscomp$271$$,$library_id$jscomp$11$$,$color$jscomp$33$$){return $app$common$types$shape$uses_library_color_QMARK_$$($shape$jscomp$271$$,$library_id$jscomp$11$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$33$$))});
$app$common$types$file$uses_asset_QMARK_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$1981$typography$$,function($_$jscomp$1576$$,$shape$jscomp$272$$,$library_id$jscomp$12$$,$typography$jscomp$5$$){return $app$common$types$typography$uses_library_typography_QMARK_$$($shape$jscomp$272$$,$library_id$jscomp$12$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$5$$))});
var $app$common$types$file$dump_shape$$=function $app$common$types$file$dump_shape$$($shape_id$jscomp$28$$,$level$jscomp$52$$,$objects$jscomp$212$$,$file$jscomp$30$$,$libraries$jscomp$23$$,$p__52043_show_ids$$){var $map__52044__$1$$=$APP.$cljs$core$__destructure_map$$($p__52043_show_ids$$);$p__52043_show_ids$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52044__$1$$,$cljs$cst$2593$show_ids$$);var $show_touched$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52044__$1$$,
$cljs$cst$2594$show_touched$$),$shape$jscomp$280$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$212$$,$shape_id$jscomp$28$$);$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cuerdas$core$pad$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cuerdas$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$("  ",$level$jscomp$52$$)),$APP.$cljs$core$truth_$$($APP.$cljs$cst$2045$main_instance$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$280$$))?
"{":null,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$280$$)),$APP.$cljs$core$truth_$$($APP.$cljs$cst$2045$main_instance$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$280$$))?"}":null,$APP.$cljs$core$seq$$($APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$280$$))?"*":null,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($p__52043_show_ids$$)?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$(" %s",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$280$$)])):null)].join("")),$app$common$types$file$dump_shape_component_info$$.$cljs$core$IFn$_invoke$arity$5$?$app$common$types$file$dump_shape_component_info$$.$cljs$core$IFn$_invoke$arity$5$($shape$jscomp$280$$,$objects$jscomp$212$$,$file$jscomp$30$$,$libraries$jscomp$23$$,$map__52044__$1$$):$app$common$types$file$dump_shape_component_info$$($shape$jscomp$280$$,$objects$jscomp$212$$,
$file$jscomp$30$$,$libraries$jscomp$23$$,$map__52044__$1$$)]));$APP.$cljs$core$truth_$$($show_touched$$)&&($APP.$cljs$core$seq$$($APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$280$$))&&$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cuerdas$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$("  ",$level$jscomp$52$$)),"    ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$280$$))].join("")])),
$APP.$cljs$core$truth_$$($APP.$cljs$cst$2046$remote_synced$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$280$$))&&$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cuerdas$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$("  ",$level$jscomp$52$$)),"    (remote-synced)"].join("")])));return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$280$$))?
$cljs$core$dorun$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return function $app$common$types$file$dump_shape_$_iter__52049$$($s__52050$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__52050__$2_temp__5825__auto__$jscomp$146$$=$APP.$cljs$core$seq$$($s__52050$$);if($s__52050__$2_temp__5825__auto__$jscomp$146$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__52050__$2_temp__5825__auto__$jscomp$146$$)){var $c__5501__auto__$jscomp$23$$=$APP.$cljs$core$_chunked_first$$($s__52050__$2_temp__5825__auto__$jscomp$146$$),
$size__5502__auto__$jscomp$23$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$23$$),$b__52052$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$23$$);return function(){for(var $i__52051$$=0;;)if($i__52051$$<$size__5502__auto__$jscomp$23$$){var $G__52053$jscomp$inline_5676_JSCompiler_inline_result$jscomp$912_shape_id__$1$jscomp$1$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$23$$,$i__52051$$),$JSCompiler_temp_const$jscomp$911$$=$b__52052$$,$G__52054$jscomp$inline_5677$$=$level$jscomp$52$$+
1;$G__52053$jscomp$inline_5676_JSCompiler_inline_result$jscomp$912_shape_id__$1$jscomp$1$$=$app$common$types$file$dump_shape$$.$cljs$core$IFn$_invoke$arity$6$?$app$common$types$file$dump_shape$$.$cljs$core$IFn$_invoke$arity$6$($G__52053$jscomp$inline_5676_JSCompiler_inline_result$jscomp$912_shape_id__$1$jscomp$1$$,$G__52054$jscomp$inline_5677$$,$objects$jscomp$212$$,$file$jscomp$30$$,$libraries$jscomp$23$$,$map__52044__$1$$):$app$common$types$file$dump_shape$$($G__52053$jscomp$inline_5676_JSCompiler_inline_result$jscomp$912_shape_id__$1$jscomp$1$$,
$G__52054$jscomp$inline_5677$$,$objects$jscomp$212$$,$file$jscomp$30$$,$libraries$jscomp$23$$,$map__52044__$1$$);$JSCompiler_temp_const$jscomp$911$$.add($G__52053$jscomp$inline_5676_JSCompiler_inline_result$jscomp$912_shape_id__$1$jscomp$1$$);$i__52051$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__52052$$),$app$common$types$file$dump_shape_$_iter__52049$$($APP.$cljs$core$_chunked_rest$$($s__52050__$2_temp__5825__auto__$jscomp$146$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__52052$$),
null)}var $shape_id__$1$$=$APP.$cljs$core$first$$($s__52050__$2_temp__5825__auto__$jscomp$146$$);return $APP.$cljs$core$cons$$(function(){var $G__52059$$=$shape_id__$1$$,$G__52060$$=$level$jscomp$52$$+1;return $app$common$types$file$dump_shape$$.$cljs$core$IFn$_invoke$arity$6$?$app$common$types$file$dump_shape$$.$cljs$core$IFn$_invoke$arity$6$($G__52059$$,$G__52060$$,$objects$jscomp$212$$,$file$jscomp$30$$,$libraries$jscomp$23$$,$map__52044__$1$$):$app$common$types$file$dump_shape$$($G__52059$$,$G__52060$$,
$objects$jscomp$212$$,$file$jscomp$30$$,$libraries$jscomp$23$$,$map__52044__$1$$)}(),$app$common$types$file$dump_shape_$_iter__52049$$($APP.$cljs$core$rest$$($s__52050__$2_temp__5825__auto__$jscomp$146$$)))}return null}},null,null)}($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$280$$))}()):null};var $app$common$files$changes$schema_COLON_operation$$,$app$common$files$changes$schema_COLON_set_default_grid_change$$,$app$common$files$changes$schema_COLON_set_guide_change$$,$app$common$files$changes$schema_COLON_set_flow_change$$,$app$common$files$changes$schema_COLON_set_plugin_data_change$$,$app$common$files$changes$schema_COLON_change$$,$app$common$files$changes$schema_COLON_changes$$,$app$common$files$changes$check_changes$$,$app$common$files$changes$_STAR_touched_changes_STAR_$$,$app$common$files$changes$process_change$$,
$app$common$files$changes$process_operation$$;
$app$common$files$changes$schema_COLON_operation$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$531$multi$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$532$dispatch$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$939$title$$,"Operation",$APP.$cljs$cst$938$decode_SLASH_json$$,function($p1__52196_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__52196_SHARP_$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$core$keyword$$)},
$cljs$cst$2538$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_simplified$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2598$assign$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"AssignOperation"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2598$assign$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,$APP.$cljs$cst$221$keyword$$,$APP.$cljs$cst$974$app_DOT_common_DOT_schema_SLASH_any$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2556$ignore_touched$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2557$ignore_geometry$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],
null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$203$set$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetOperation"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$203$set$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2599$attr$$,$APP.$cljs$cst$221$keyword$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$974$app_DOT_common_DOT_schema_SLASH_any$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2556$ignore_touched$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2557$ignore_geometry$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2600$set_touched$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetTouchedOperation"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$cljs$cst$2600$set_touched$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1626$touched$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$221$keyword$$],null)],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2601$set_remote_synced$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetRemoteSyncedOperation"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$cljs$cst$2601$set_remote_synced$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2046$remote_synced$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$421$boolean$$],null)],null)],null)],null)],null);
$app$common$files$changes$schema_COLON_set_default_grid_change$$=function(){var $gen$jscomp$41$$=$app$common$schema$generators$mcat$$(function($grid_type$$){return $app$common$schema$generators$fmap$$(function($params$jscomp$162$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2043$page_id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2602$set_default_grid$$,$APP.$cljs$cst$2603$grid_type$$,$grid_type$$,$APP.$cljs$cst$1430$params$$,$params$jscomp$162$$],
null)},function(){var $G__52202__$1$$=$grid_type$$ instanceof $APP.$cljs$core$Keyword$$?$grid_type$$.$fqn$:null;switch($G__52202__$1$$){case "square":return $app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$grid$schema_COLON_square_params$$);case "column":return $app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$grid$schema_COLON_column_params$$);case "row":return $app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$types$grid$schema_COLON_column_params$$);
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__52202__$1$$)].join(""));}}())},$clojure$test$check$generators$elements$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$216$column$$,null,$APP.$cljs$cst$1933$square$$,null,$APP.$cljs$cst$1656$row$$,null],null),null)));return new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$531$multi$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$938$decode_SLASH_json$$,function($p1__52200_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__52200_SHARP_$$,$APP.$cljs$cst$2603$grid_type$$,$APP.$cljs$core$keyword$$)},$cljs$cst$869$gen_SLASH_gen$$,$gen$jscomp$41$$,$APP.$cljs$cst$939$title$$,"SetDefaultGridChange",$cljs$cst$532$dispatch$$,$APP.$cljs$cst$2603$grid_type$$,$cljs$cst$2538$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_simplified$$,!0],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1933$square$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetDefautSquareGridAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2602$set_default_grid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2603$grid_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$1933$square$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$app$common$types$grid$schema_COLON_square_params$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$216$column$$,
new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetDefaultColumnGridAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2602$set_default_grid$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2603$grid_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$216$column$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$app$common$types$grid$schema_COLON_column_params$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1656$row$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetDefaultRowGridAttrs"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2602$set_default_grid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,
$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2603$grid_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$1656$row$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$app$common$types$grid$schema_COLON_column_params$$],null)],null)],null)],null)],null)}();
$app$common$files$changes$schema_COLON_set_guide_change$$=function(){var $schema$jscomp$235$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetGuideChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$cljs$cst$2604$set_guide$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$app$common$types$page$schema_COLON_guide$$],null)],null)],null),$gen$jscomp$42$$=$app$common$schema$generators$fmap$$(function($change$jscomp$2$$){return $APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$2$$)!=null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($change$jscomp$2$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$2$$)):$change$jscomp$2$$},$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($schema$jscomp$235$$));return $APP.$app$common$schema$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($schema$jscomp$235$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$869$gen_SLASH_gen$$,$gen$jscomp$42$$]))}();
$app$common$files$changes$schema_COLON_set_flow_change$$=function(){var $schema$jscomp$236$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetFlowChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$cljs$cst$2605$set_flow$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1430$params$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$app$common$types$page$schema_COLON_flow$$],null)],null)],null),$gen$jscomp$43$$=$app$common$schema$generators$fmap$$(function($change$jscomp$3$$){return $APP.$cljs$cst$1430$params$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$3$$)!=null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($change$jscomp$3$$,$APP.$cljs$cst$1430$params$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$3$$)):$change$jscomp$3$$},$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($schema$jscomp$236$$));return $APP.$app$common$schema$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($schema$jscomp$236$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$869$gen_SLASH_gen$$,$gen$jscomp$43$$]))}();
$app$common$files$changes$schema_COLON_set_plugin_data_change$$=function(){var $schema$jscomp$237$$=new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetPagePluginData"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2606$set_plugin_data$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2607$object_type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1298$color$$,null,$APP.$cljs$cst$208$file$$,
null,$APP.$cljs$cst$1624$page$$,null,$APP.$cljs$cst$1625$component$$,null,$APP.$cljs$cst$1811$shape$$,null,$APP.$cljs$cst$1981$typography$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2272$object_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$394$namespace$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$869$gen_SLASH_gen$$,$clojure$test$check$generators$fmap$$($APP.$cljs$core$keyword$$,$app$common$schema$generators$word_string$$())],
null),$APP.$cljs$cst$221$keyword$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$302$key$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$word_string$$()],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$869$gen_SLASH_gen$$,$app$common$schema$generators$word_string$$()],null)],null)],null)],null)],null),$check1$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$890$error_SLASH_path$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$],null),$APP.$cljs$cst$882$error_SLASH_message$$,"missing page-id"],null),function($map__52221__$1_p__52220$$){$map__52221__$1_p__52220$$=$APP.$cljs$core$__destructure_map$$($map__52221__$1_p__52220$$);var $object_type$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52221__$1_p__52220$$,$APP.$cljs$cst$2607$object_type$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1811$shape$$,
$object_type$$)?$APP.$cljs$core$uuid_QMARK_$$($APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($map__52221__$1_p__52220$$)):!0}],null),$gen$jscomp$44$$=$app$common$schema$generators$fmap$$(function($map__52227__$1_p__52225$$){$map__52227__$1_p__52225$$=$APP.$cljs$core$__destructure_map$$($map__52227__$1_p__52225$$);var $object_type$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52227__$1_p__52225$$,$APP.$cljs$cst$2607$object_type$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$208$file$$,
$object_type$jscomp$1$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($map__52227__$1_p__52225$$,$APP.$cljs$cst$2272$object_id$$),$APP.$cljs$cst$2043$page_id$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1811$shape$$,$object_type$jscomp$1$$)?$map__52227__$1_p__52225$$:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($map__52227__$1_p__52225$$,$APP.$cljs$cst$2043$page_id$$)},$app$common$schema$generators$filter$$($APP.$cljs$cst$2043$page_id$$,
$app$common$schema$generators$filter$$($APP.$cljs$cst$2272$object_id$$,$app$common$schema$generators$generator$cljs$0core$0IFn$0_invoke$0arity$01$$($schema$jscomp$237$$))));return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$app$common$schema$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($schema$jscomp$237$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$869$gen_SLASH_gen$$,$gen$jscomp$44$$])),
$check1$$],null)}();
$app$common$files$changes$schema_COLON_change$$=$APP.$cljs$core$PersistentVector$fromArray$$([$cljs$cst$531$multi$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$532$dispatch$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$939$title$$,"Change",$APP.$cljs$cst$938$decode_SLASH_json$$,function($p1__52228_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__52228_SHARP_$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$core$keyword$$)},$cljs$cst$2538$app_DOT_common_DOT_schema_DOT_desc_native_SLASH_simplified$$,!0],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2608$set_comment_thread_position$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetCommentThreadPositionChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2609$comment_thread_id$$,
$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1607$frame_id$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,
$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$cljs$cst$1518$app_DOT_common_DOT_geom_DOT_point_SLASH_point$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2610$add_obj$$,new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"AddObjChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2610$add_obj$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2611$obj$$,$app$common$types$shape$schema_COLON_shape$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1627$component_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1607$frame_id$$,
$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1795$index$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$cljs$cst$344$int$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2556$ignore_touched$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2612$mod_obj$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ModObjChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2612$mod_obj$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1627$component_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2613$operations$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,5],null),$app$common$files$changes$schema_COLON_operation$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2614$del_obj$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"DelObjChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2614$del_obj$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,
$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1627$component_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2556$ignore_touched$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2604$set_guide$$,
$app$common$files$changes$schema_COLON_set_guide_change$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2605$set_flow$$,$app$common$files$changes$schema_COLON_set_flow_change$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2602$set_default_grid$$,$app$common$files$changes$schema_COLON_set_default_grid_change$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2615$fix_obj$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"FixObjChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$cljs$cst$2615$fix_obj$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1697$fix$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$221$keyword$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1627$component_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2616$mov_objects$$,new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"MovObjectsChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2616$mov_objects$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1627$component_id$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2556$ignore_touched$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$cst$974$app_DOT_common_DOT_schema_SLASH_any$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1795$index$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$cljs$cst$344$int$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2617$after_shape$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$974$app_DOT_common_DOT_schema_SLASH_any$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2618$allow_altering_copies$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2619$reorder_children$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ReorderChildrenChange"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2619$reorder_children$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1627$component_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2556$ignore_touched$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$cst$974$app_DOT_common_DOT_schema_SLASH_any$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2620$add_page$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"AddPageChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2620$add_page$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1624$page$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$974$app_DOT_common_DOT_schema_SLASH_any$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2621$mod_page$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ModPageChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2621$mod_page$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,
$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2058$background$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$app$common$types$color$schema_COLON_hex_color$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2059$pixel_grid_color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$522$maybe$$,$app$common$types$color$schema_COLON_hex_color$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2060$pixel_grid_opacity$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$cljs$cst$963$app_DOT_common_DOT_schema_SLASH_safe_number$$],null)],
null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2606$set_plugin_data$$,$app$common$files$changes$schema_COLON_set_plugin_data_change$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2622$del_page$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$939$title$$,"DelPageChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2622$del_page$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2623$mov_page$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"MovPageChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2623$mov_page$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1795$index$$,$cljs$cst$344$int$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2624$reg_objects$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"RegObjectsChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2624$reg_objects$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1627$component_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1614$shapes$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$855$gen_SLASH_max$$,5],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2625$add_color$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"AddColorChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2625$add_color$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,$app$common$types$color$schema_COLON_library_color$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2626$mod_color$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ModColorChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2626$mod_color$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,
$app$common$types$color$schema_COLON_library_color$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2627$del_color$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"DelColorChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2627$del_color$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2628$add_media$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"AddMediaChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2628$add_media$$],null)],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2198$object$$,$app$common$types$file$schema_COLON_media$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2629$mod_media$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,
"ModMediaChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2629$mod_media$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2198$object$$,$app$common$types$file$schema_COLON_media$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2630$del_media$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"DelMediaChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2630$del_media$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2631$add_component$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"AddComponentChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2631$add_component$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,
$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2062$main_instance_id$$,
$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2063$main_instance_page$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2000$variant_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2001$variant_properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$app$common$types$variant$schema_COLON_variant_property$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$2632$mod_component$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ModComponentChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2632$mod_component$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$296$path$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2000$variant_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2001$variant_properties$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$app$common$types$variant$schema_COLON_variant_property$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2633$del_component$$,new $APP.$cljs$core$PersistentVector$$(null,
6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"DelComponentChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2633$del_component$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2634$delta$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1518$app_DOT_common_DOT_geom_DOT_point_SLASH_point$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$2635$skip_undelete_QMARK_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2636$restore_component$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,
"RestoreComponentChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2636$restore_component$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2637$purge_component$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,
"PurgeComponentChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2637$purge_component$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2638$add_typography$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"AddTypogrphyChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2638$add_typography$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1981$typography$$,$app$common$types$typography$schema_COLON_typography$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2639$mod_typography$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ModTypogrphyChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2639$mod_typography$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1981$typography$$,$app$common$types$typography$schema_COLON_typography$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2640$del_typography$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"DelTypogrphyChange"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2640$del_typography$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2641$set_tokens_lib$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetTokensLib"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2641$set_tokens_lib$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2139$tokens_lib$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$app$common$types$tokens_lib$schema_COLON_tokens_lib$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2642$set_token$$,new $APP.$cljs$core$PersistentVector$$(null,
6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetTokenChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2642$set_token$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2643$set_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2644$token_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$app$common$types$token$schema_COLON_token_attrs$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2646$set_token_set$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetTokenSetChange"],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2646$set_token_set$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$app$common$types$tokens_lib$schema_COLON_token_set_attrs$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2647$set_token_theme$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetTokenThemeChange"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$2647$set_token_theme$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$app$common$types$tokens_lib$schema_COLON_token_theme_attrs$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$2648$set_active_token_themes$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SetActiveTokenThemes"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,
$cljs$cst$2648$set_active_token_themes$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2649$theme_paths$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$198$string$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2650$rename_token_set_group$$,new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"RenameTokenSetGroup"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2650$rename_token_set_group$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2651$set_group_path$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2652$set_group_fname$$,$APP.$cljs$cst$198$string$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2653$move_token_set$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"MoveTokenSet"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2653$move_token_set$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2654$from_path$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2655$to_path$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2656$before_path$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$198$string$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2657$before_group$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$421$boolean$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2658$move_token_set_group$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"MoveTokenSetGroup"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2658$move_token_set_group$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2654$from_path$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2655$to_path$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2656$before_path$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$198$string$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2657$before_group$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$421$boolean$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2659$set_base_font_size$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,
"ModBaseFontSize"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$2659$set_base_font_size$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2576$base_font_size$$,$APP.$cljs$cst$198$string$$],null)],null)],null)],!0);
$app$common$files$changes$schema_COLON_changes$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$720$sequential$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$855$gen_SLASH_max$$,5,$cljs$cst$854$gen_SLASH_min$$,1],null),$app$common$files$changes$schema_COLON_change$$],null);$app$common$files$changes$check_changes$$=$app$common$schema$check_fn$$($app$common$files$changes$schema_COLON_changes$$);
$app$common$files$changes$_STAR_touched_changes_STAR_$$=null;
$app$common$files$changes$process_change$$=function(){var $method_table__5622__auto__$jscomp$14$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$14$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$14$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$14$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.common.files.changes",
"process-change"),function($_$jscomp$1577$$,$change$jscomp$6$$){return $APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$6$$)},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$14$$,$method_table__5622__auto__$jscomp$14$$,$prefer_table__5623__auto__$jscomp$14$$,$method_cache__5624__auto__$jscomp$14$$,$cached_hierarchy__5625__auto__$jscomp$14$$)}();
$app$common$files$changes$process_operation$$=function(){var $method_table__5622__auto__$jscomp$15$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$15$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$15$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$15$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.common.files.changes",
"process-operation"),function($_$jscomp$1578$$,$op$jscomp$13$$){return $APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($op$jscomp$13$$)},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$15$$,$method_table__5622__auto__$jscomp$15$$,$prefer_table__5623__auto__$jscomp$15$$,$method_cache__5624__auto__$jscomp$15$$,$cached_hierarchy__5625__auto__$jscomp$15$$)}();
$APP.$app$common$files$changes$process_changes$$=function $app$common$files$changes$process_changes$$($var_args$jscomp$1096$$){switch(arguments.length){case 2:return $app$common$files$changes$process_changes$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$common$files$changes$process_changes$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$common$files$changes$process_changes$$.$cljs$core$IFn$_invoke$arity$2$=function($data$jscomp$193$$,$items$jscomp$26$$){return $APP.$app$common$files$changes$process_changes$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$193$$,$items$jscomp$26$$,!0)};
$APP.$app$common$files$changes$process_changes$$.$cljs$core$IFn$_invoke$arity$3$=function($data$jscomp$194$$,$items$jscomp$27$$,$_STAR_touched_changes_STAR__orig_val__52325_verify_QMARK_$$){$APP.$cljs$core$truth_$$($_STAR_touched_changes_STAR__orig_val__52325_verify_QMARK_$$)&&$app$common$files$changes$check_changes$$($items$jscomp$27$$);$_STAR_touched_changes_STAR__orig_val__52325_verify_QMARK_$$=$app$common$files$changes$_STAR_touched_changes_STAR_$$;$app$common$files$changes$_STAR_touched_changes_STAR_$$=
$APP.$cljs$core$volatile_BANG_$$($APP.$cljs$core$PersistentHashSet$EMPTY$$);try{var $result$jscomp$229$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__52315_SHARP_$$,$or__5025__auto__$jscomp$489_p2__52316_SHARP_$$){$or__5025__auto__$jscomp$489_p2__52316_SHARP_$$=$app$common$files$changes$process_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__52315_SHARP_$$,$or__5025__auto__$jscomp$489_p2__52316_SHARP_$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$489_p2__52316_SHARP_$$)?
$or__5025__auto__$jscomp$489_p2__52316_SHARP_$$:$p1__52315_SHARP_$$},$data$jscomp$194$$,$items$jscomp$27$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$files$changes$process_touched_change$$,$result$jscomp$229$$,$APP.$cljs$core$_deref$$($app$common$files$changes$_STAR_touched_changes_STAR_$$))}finally{$app$common$files$changes$_STAR_touched_changes_STAR_$$=$_STAR_touched_changes_STAR__orig_val__52325_verify_QMARK_$$}};
$APP.$app$common$files$changes$process_changes$$.$cljs$lang$maxFixedArity$=3;
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2608$set_comment_thread_position$$,function($data$jscomp$195$$,$map__52334__$1_p__52333$$){$map__52334__$1_p__52333$$=$APP.$cljs$core$__destructure_map$$($map__52334__$1_p__52333$$);var $page_id$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52334__$1_p__52333$$,$APP.$cljs$cst$2043$page_id$$),$comment_thread_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52334__$1_p__52333$$,
$cljs$cst$2609$comment_thread_id$$),$position$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52334__$1_p__52333$$,$APP.$cljs$cst$1676$position$$),$frame_id$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52334__$1_p__52333$$,$APP.$cljs$cst$1607$frame_id$$);return $APP.$app$common$data$update_in_when$$($data$jscomp$195$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$page_id$jscomp$31$$],
null),function($page$jscomp$19$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($position$jscomp$51$$)?$frame_id$jscomp$27$$:$position$jscomp$51$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($page$jscomp$19$$,$APP.$cljs$cst$2061$comment_thread_positions$$,$APP.$cljs$core$assoc$$,$comment_thread_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$27$$,$APP.$cljs$cst$1676$position$$,$position$jscomp$51$$],null)):$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($page$jscomp$19$$,
$APP.$cljs$cst$2061$comment_thread_positions$$,$APP.$cljs$core$dissoc$$,$comment_thread_id$$)})});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2604$set_guide$$,function($data$jscomp$196$$,$p__52339_page_id$jscomp$32$$){var $map__52340__$1_params$jscomp$163_params__$1$jscomp$19$$=$APP.$cljs$core$__destructure_map$$($p__52339_page_id$jscomp$32$$);$p__52339_page_id$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52340__$1_params$jscomp$163_params__$1$jscomp$19$$,$APP.$cljs$cst$2043$page_id$$);var $id$jscomp$259$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52340__$1_params$jscomp$163_params__$1$jscomp$19$$,
$APP.$cljs$cst$266$id$$);$map__52340__$1_params$jscomp$163_params__$1$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52340__$1_params$jscomp$163_params__$1$jscomp$19$$,$APP.$cljs$cst$1430$params$$);if($map__52340__$1_params$jscomp$163_params__$1$jscomp$19$$==null)return $APP.$app$common$data$update_in_when$$($data$jscomp$196$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$p__52339_page_id$jscomp$32$$],
null),function($page$jscomp$20$$){var $guides_guides__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$20$$,$APP.$cljs$cst$2057$guides$$);$guides_guides__$1$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($guides_guides__$1$$,$id$jscomp$259$$);return $APP.$cljs$core$empty_QMARK_$$($guides_guides__$1$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$20$$,$APP.$cljs$cst$2057$guides$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($page$jscomp$20$$,
$APP.$cljs$cst$2057$guides$$,$guides_guides__$1$$)});$map__52340__$1_params$jscomp$163_params__$1$jscomp$19$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__52340__$1_params$jscomp$163_params__$1$jscomp$19$$,$APP.$cljs$cst$266$id$$,$id$jscomp$259$$);return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data$jscomp$196$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,
$p__52339_page_id$jscomp$32$$],null),$APP.$cljs$core$update$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2057$guides$$,$APP.$cljs$core$assoc$$,$id$jscomp$259$$,$map__52340__$1_params$jscomp$163_params__$1$jscomp$19$$]))});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2605$set_flow$$,function($data$jscomp$197$$,$p__52347_page_id$jscomp$33$$){var $map__52348__$1_params$jscomp$164_params__$1$jscomp$20$$=$APP.$cljs$core$__destructure_map$$($p__52347_page_id$jscomp$33$$);$p__52347_page_id$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52348__$1_params$jscomp$164_params__$1$jscomp$20$$,$APP.$cljs$cst$2043$page_id$$);var $id$jscomp$260$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52348__$1_params$jscomp$164_params__$1$jscomp$20$$,
$APP.$cljs$cst$266$id$$);$map__52348__$1_params$jscomp$164_params__$1$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52348__$1_params$jscomp$164_params__$1$jscomp$20$$,$APP.$cljs$cst$1430$params$$);if($map__52348__$1_params$jscomp$164_params__$1$jscomp$20$$==null)return $APP.$app$common$data$update_in_when$$($data$jscomp$197$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$p__52347_page_id$jscomp$33$$],
null),function($page$jscomp$21$$){var $flows$jscomp$1_flows__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$21$$,$APP.$cljs$cst$2056$flows$$);$flows$jscomp$1_flows__$1$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($flows$jscomp$1_flows__$1$$,$id$jscomp$260$$);return $APP.$cljs$core$empty_QMARK_$$($flows$jscomp$1_flows__$1$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$21$$,$APP.$cljs$cst$2056$flows$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($page$jscomp$21$$,
$APP.$cljs$cst$2056$flows$$,$flows$jscomp$1_flows__$1$$)});$map__52348__$1_params$jscomp$164_params__$1$jscomp$20$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__52348__$1_params$jscomp$164_params__$1$jscomp$20$$,$APP.$cljs$cst$266$id$$,$id$jscomp$260$$);return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data$jscomp$197$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,
$p__52347_page_id$jscomp$33$$],null),$APP.$cljs$core$update$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2056$flows$$,$APP.$cljs$core$assoc$$,$id$jscomp$260$$,$map__52348__$1_params$jscomp$164_params__$1$jscomp$20$$]))});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2602$set_default_grid$$,function($data$jscomp$198$$,$p__52355_page_id$jscomp$34$$){var $map__52356__$1_params$jscomp$165$$=$APP.$cljs$core$__destructure_map$$($p__52355_page_id$jscomp$34$$);$p__52355_page_id$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52356__$1_params$jscomp$165$$,$APP.$cljs$cst$2043$page_id$$);var $grid_type$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52356__$1_params$jscomp$165$$,
$APP.$cljs$cst$2603$grid_type$$);$map__52356__$1_params$jscomp$165$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52356__$1_params$jscomp$165$$,$APP.$cljs$cst$1430$params$$);return $map__52356__$1_params$jscomp$165$$==null?$APP.$app$common$data$update_in_when$$($data$jscomp$198$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$p__52355_page_id$jscomp$34$$],null),function($page$jscomp$22$$){var $default_grids_default_grids__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$22$$,$APP.$cljs$cst$2055$default_grids$$);$default_grids_default_grids__$1$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($default_grids_default_grids__$1$$,$grid_type$jscomp$1$$);return $APP.$cljs$core$empty_QMARK_$$($default_grids_default_grids__$1$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$22$$,$APP.$cljs$cst$2055$default_grids$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($page$jscomp$22$$,
$APP.$cljs$cst$2055$default_grids$$,$default_grids_default_grids__$1$$)}):$APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data$jscomp$198$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$p__52355_page_id$jscomp$34$$],null),$APP.$cljs$core$update$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2055$default_grids$$,$APP.$cljs$core$assoc$$,$grid_type$jscomp$1$$,
$map__52356__$1_params$jscomp$165$$]))});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2610$add_obj$$,function($data$jscomp$199$$,$map__52371__$1_p__52370$$){function $update_container$$($p1__52368_SHARP_$$){return $app$common$types$shape_tree$add_shape$$($id$jscomp$262$$,$obj$jscomp$186$$,$p1__52368_SHARP_$$,$frame_id$jscomp$28$$,$parent_id$jscomp$27$$,$index$jscomp$217$$,$ignore_touched$jscomp$3$$)}$map__52371__$1_p__52370$$=$APP.$cljs$core$__destructure_map$$($map__52371__$1_p__52370$$);var $id$jscomp$262$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52371__$1_p__52370$$,$APP.$cljs$cst$266$id$$),$obj$jscomp$186$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52371__$1_p__52370$$,$APP.$cljs$cst$2611$obj$$),$page_id$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52371__$1_p__52370$$,$APP.$cljs$cst$2043$page_id$$),$component_id$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52371__$1_p__52370$$,$APP.$cljs$cst$1627$component_id$$),
$frame_id$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52371__$1_p__52370$$,$APP.$cljs$cst$1607$frame_id$$),$parent_id$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52371__$1_p__52370$$,$APP.$cljs$cst$1619$parent_id$$),$index$jscomp$217$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52371__$1_p__52370$$,$APP.$cljs$cst$1795$index$$),$ignore_touched$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52371__$1_p__52370$$,
$APP.$cljs$cst$2556$ignore_touched$$);$APP.$cljs$core$truth_$$(null)&&$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$(null,$app$common$files$changes$collect_shape_media_refs$$,$obj$jscomp$186$$,$page_id$jscomp$36$$);return $APP.$cljs$core$truth_$$($page_id$jscomp$36$$)?$APP.$app$common$data$update_in_when$$($data$jscomp$199$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$page_id$jscomp$36$$],null),$update_container$$):
$APP.$app$common$data$update_in_when$$($data$jscomp$199$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$component_id$jscomp$23$$],null),$update_container$$)});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2612$mod_obj$$,function($data$jscomp$200$$,$map__52387__$1_p__52386$$){$map__52387__$1_p__52386$$=$APP.$cljs$core$__destructure_map$$($map__52387__$1_p__52386$$);var $page_id$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52387__$1_p__52386$$,$APP.$cljs$cst$2043$page_id$$),$component_id$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52387__$1_p__52386$$,
$APP.$cljs$cst$1627$component_id$$);return $APP.$cljs$core$truth_$$($page_id$jscomp$38$$)?$APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data$jscomp$200$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$page_id$jscomp$38$$,$APP.$cljs$cst$1631$objects$$],null),$app$common$files$changes$process_operations$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__52387__$1_p__52386$$])):
$APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data$jscomp$200$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$component_id$jscomp$24$$,$APP.$cljs$cst$1631$objects$$],null),$app$common$files$changes$process_operations$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__52387__$1_p__52386$$]))});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2619$reorder_children$$,function($data$jscomp$201$$,$map__52402__$1_p__52401$$){$map__52402__$1_p__52401$$=$APP.$cljs$core$__destructure_map$$($map__52402__$1_p__52401$$);var $page_id$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52402__$1_p__52401$$,$APP.$cljs$cst$2043$page_id$$),$component_id$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52402__$1_p__52401$$,
$APP.$cljs$cst$1627$component_id$$);return $APP.$cljs$core$truth_$$($page_id$jscomp$39$$)?$APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data$jscomp$201$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$page_id$jscomp$39$$,$APP.$cljs$cst$1631$objects$$],null),$app$common$files$changes$process_children_reordering$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__52402__$1_p__52401$$])):
$APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data$jscomp$201$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$component_id$jscomp$25$$,$APP.$cljs$cst$1631$objects$$],null),$app$common$files$changes$process_children_reordering$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__52402__$1_p__52401$$]))});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2614$del_obj$$,function($data$jscomp$202$$,$p__52406_page_id$jscomp$40$$){var $ignore_touched$jscomp$4_map__52407__$1$$=$APP.$cljs$core$__destructure_map$$($p__52406_page_id$jscomp$40$$);$p__52406_page_id$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ignore_touched$jscomp$4_map__52407__$1$$,$APP.$cljs$cst$2043$page_id$$);var $component_id$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ignore_touched$jscomp$4_map__52407__$1$$,
$APP.$cljs$cst$1627$component_id$$),$id$jscomp$264$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ignore_touched$jscomp$4_map__52407__$1$$,$APP.$cljs$cst$266$id$$);$ignore_touched$jscomp$4_map__52407__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ignore_touched$jscomp$4_map__52407__$1$$,$APP.$cljs$cst$2556$ignore_touched$$);return $APP.$cljs$core$truth_$$($p__52406_page_id$jscomp$40$$)?$APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data$jscomp$202$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$p__52406_page_id$jscomp$40$$],null),$app$common$types$shape_tree$delete_shape$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$id$jscomp$264$$,$ignore_touched$jscomp$4_map__52407__$1$$])):$APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data$jscomp$202$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1638$components$$,$component_id$jscomp$26$$],null),$app$common$types$shape_tree$delete_shape$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$id$jscomp$264$$,$ignore_touched$jscomp$4_map__52407__$1$$]))});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2615$fix_obj$$,function($data$jscomp$203$$,$p__52409_page_id$jscomp$41$$){function $fix_container$$($container$jscomp$35$$){var $G__52428$$=$APP.$cljs$cst$1697$fix$$.$cljs$core$IFn$_invoke$arity$2$($map__52411__$1$$,$cljs$cst$2661$broken_children$$);switch($G__52428$$ instanceof $APP.$cljs$core$Keyword$$?$G__52428$$.$fqn$:null){case "broken-children":return $app$common$types$shape_tree$fix_broken_children$$($container$jscomp$35$$,
$id$jscomp$265$$);default:throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("internal",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$1752$internal$$,$APP.$cljs$cst$273$code$$,$cljs$cst$2662$fix_not_implemented$$,$APP.$cljs$cst$1697$fix$$,$APP.$cljs$cst$1697$fix$$.$cljs$core$IFn$_invoke$arity$1$($map__52411__$1$$)],null),
null])),null);}}var $map__52411__$1$$=$APP.$cljs$core$__destructure_map$$($p__52409_page_id$jscomp$41$$);$p__52409_page_id$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52411__$1$$,$APP.$cljs$cst$2043$page_id$$);var $component_id$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52411__$1$$,$APP.$cljs$cst$1627$component_id$$),$id$jscomp$265$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52411__$1$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$truth_$$($p__52409_page_id$jscomp$41$$)?
$APP.$app$common$data$update_in_when$$($data$jscomp$203$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$p__52409_page_id$jscomp$41$$],null),$fix_container$$):$APP.$app$common$data$update_in_when$$($data$jscomp$203$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$component_id$jscomp$27$$],null),$fix_container$$)});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2624$reg_objects$$,function($data$jscomp$204$$,$map__52462__$1_p__52461$$){function $update_group$$($JSCompiler_temp$jscomp$807_JSCompiler_temp$jscomp$808_JSCompiler_temp$jscomp$809_group$jscomp$28$$,$children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$){var $lookup$jscomp$16$$=$APP.$app$common$data$getf$$($children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$),
$children$jscomp$192$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$807_JSCompiler_temp$jscomp$808_JSCompiler_temp$jscomp$809_group$jscomp$28$$,$APP.$cljs$cst$1614$shapes$$);$APP.$cljs$core$empty_QMARK_$$($children$jscomp$192$$)||($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1610$bool$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$807_JSCompiler_temp$jscomp$808_JSCompiler_temp$jscomp$809_group$jscomp$28$$))?
$JSCompiler_temp$jscomp$807_JSCompiler_temp$jscomp$808_JSCompiler_temp$jscomp$809_group$jscomp$28$$=$APP.$app$common$types$path$update_bool_shape$$($JSCompiler_temp$jscomp$807_JSCompiler_temp$jscomp$808_JSCompiler_temp$jscomp$809_group$jscomp$28$$,$children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$):$APP.$cljs$core$truth_$$($APP.$cljs$cst$1609$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$807_JSCompiler_temp$jscomp$808_JSCompiler_temp$jscomp$809_group$jscomp$28$$))?
($children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($lookup$jscomp$16$$,$children$jscomp$192$$),$children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$=$APP.$cljs$core$first$$($children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$),$JSCompiler_temp$jscomp$807_JSCompiler_temp$jscomp$808_JSCompiler_temp$jscomp$809_group$jscomp$28$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$807_JSCompiler_temp$jscomp$808_JSCompiler_temp$jscomp$809_group$jscomp$28$$,
$APP.$cljs$cst$1605$selrect$$,$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$)),$APP.$cljs$cst$1604$points$$,$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$)),$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$))),
$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$))),$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$))),
$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$))),$APP.$cljs$cst$1879$flip_x$$,$APP.$cljs$cst$1879$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$)),$APP.$cljs$cst$1880$flip_y$$,$APP.$cljs$cst$1880$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$))):
($children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($lookup$jscomp$16$$,$children$jscomp$192$$),$JSCompiler_temp$jscomp$807_JSCompiler_temp$jscomp$808_JSCompiler_temp$jscomp$809_group$jscomp$28$$=$APP.$app$common$geom$shapes$transforms$update_group_selrect$$($JSCompiler_temp$jscomp$807_JSCompiler_temp$jscomp$808_JSCompiler_temp$jscomp$809_group$jscomp$28$$,$children$jscomp$inline_5702_mask$jscomp$inline_5703_objects$jscomp$222_param49244$jscomp$inline_5706$$)));
return $JSCompiler_temp$jscomp$807_JSCompiler_temp$jscomp$808_JSCompiler_temp$jscomp$809_group$jscomp$28$$}function $reg_objects$$($objects$jscomp$221$$){var $lookup$jscomp$15$$=$APP.$app$common$data$getf$$($objects$jscomp$221$$),$xform$jscomp$26$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__52456_SHARP_$$){return $APP.$cljs$core$cons$$($p1__52456_SHARP_$$,$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$221$$,
$p1__52456_SHARP_$$))}),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__52457_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1608$group$$,null,$APP.$cljs$cst$1610$bool$$,null],null),null),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($lookup$jscomp$15$$($p1__52457_SHARP_$$)))}),$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$0$());return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__52454_SHARP_$$,
$p2__52455_SHARP_$$){return $APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($p1__52454_SHARP_$$,$p2__52455_SHARP_$$,$update_group$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__52454_SHARP_$$]))},$objects$jscomp$221$$,$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($xform$jscomp$26$$,$shapes$jscomp$20$$))}$map__52462__$1_p__52461$$=$APP.$cljs$core$__destructure_map$$($map__52462__$1_p__52461$$);var $page_id$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52462__$1_p__52461$$,
$APP.$cljs$cst$2043$page_id$$),$component_id$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52462__$1_p__52461$$,$APP.$cljs$cst$1627$component_id$$),$shapes$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52462__$1_p__52461$$,$APP.$cljs$cst$1614$shapes$$);return $APP.$cljs$core$truth_$$($page_id$jscomp$42$$)?$APP.$app$common$data$update_in_when$$($data$jscomp$204$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1630$pages_index$$,$page_id$jscomp$42$$,$APP.$cljs$cst$1631$objects$$],null),$reg_objects$$):$APP.$app$common$data$update_in_when$$($data$jscomp$204$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$component_id$jscomp$28$$,$APP.$cljs$cst$1631$objects$$],null),$reg_objects$$)});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2616$mov_objects$$,function($data$jscomp$205$$,$map__52508__$1_p__52507$$){function $is_valid_move_QMARK_$$($objects$jscomp$228$$,$and__5023__auto____$2$jscomp$24_shape_id$jscomp$32$$){var $and__5023__auto____$1$jscomp$57_invalid_targets$$=$calculate_invalid_targets$$($objects$jscomp$228$$,$and__5023__auto____$2$jscomp$24_shape_id$jscomp$32$$),$shape$jscomp$294$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$228$$,
$and__5023__auto____$2$jscomp$24_shape_id$jscomp$32$$);return $APP.$cljs$core$truth_$$($shape$jscomp$294$$)?($and__5023__auto____$1$jscomp$57_invalid_targets$$=$APP.$cljs$core$not$$($and__5023__auto____$1$jscomp$57_invalid_targets$$.$cljs$core$IFn$_invoke$arity$1$?$and__5023__auto____$1$jscomp$57_invalid_targets$$.$cljs$core$IFn$_invoke$arity$1$($parent_id$jscomp$29$$):$and__5023__auto____$1$jscomp$57_invalid_targets$$($parent_id$jscomp$29$$)))?($and__5023__auto____$2$jscomp$24_shape_id$jscomp$32$$=
$APP.$cljs$core$not$$($app$common$files$helpers$components_nesting_loop_QMARK_$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$228$$,$and__5023__auto____$2$jscomp$24_shape_id$jscomp$32$$,$parent_id$jscomp$29$$)))?$APP.$cljs$core$truth_$$($allow_altering_copies$$)?$allow_altering_copies$$:$APP.$cljs$core$truth_$$($syncing$$)?$syncing$$:!$APP.$app$common$types$component$in_component_copy_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$228$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$294$$)))&&
!$APP.$app$common$types$component$in_component_copy_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$228$$,$parent_id$jscomp$29$$)):$and__5023__auto____$2$jscomp$24_shape_id$jscomp$32$$:$and__5023__auto____$1$jscomp$57_invalid_targets$$:$shape$jscomp$294$$}function $update_parent_id$$($objects$jscomp$227$$,$id$jscomp$267$$){return $APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($objects$jscomp$227$$,$id$jscomp$267$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$parent_id$$,$parent_id$jscomp$29$$]))}function $add_to_parent$$($parent$jscomp$201$$,$index__$1$jscomp$2$$,$shapes__$1$jscomp$3$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($parent$jscomp$201$$,$APP.$cljs$cst$1614$shapes$$,function($JSCompiler_inline_result$jscomp$10793_parent_shapes_prev_shapes__$1$jscomp$inline_12110$$){$JSCompiler_inline_result$jscomp$10793_parent_shapes_prev_shapes__$1$jscomp$inline_12110$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$10793_parent_shapes_prev_shapes__$1$jscomp$inline_12110$$)?$JSCompiler_inline_result$jscomp$10793_parent_shapes_prev_shapes__$1$jscomp$inline_12110$$:$APP.$cljs$core$PersistentVector$EMPTY$$;$JSCompiler_inline_result$jscomp$10793_parent_shapes_prev_shapes__$1$jscomp$inline_12110$$=$APP.$cljs$core$truth_$$($index__$1$jscomp$2$$)?$APP.$app$common$data$insert_at_index$$($JSCompiler_inline_result$jscomp$10793_parent_shapes_prev_shapes__$1$jscomp$inline_12110$$,
$index__$1$jscomp$2$$,$shapes__$1$jscomp$3$$):$app$common$files$helpers$append_at_the_end$$($JSCompiler_inline_result$jscomp$10793_parent_shapes_prev_shapes__$1$jscomp$inline_12110$$,$shapes__$1$jscomp$3$$);return $APP.$app$common$data$vec_without_nils$$($JSCompiler_inline_result$jscomp$10793_parent_shapes_prev_shapes__$1$jscomp$inline_12110$$)})}function $move_objects$$($objects$jscomp$226$$){var $parent$jscomp$200$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$226$$,$parent_id$jscomp$29$$);
if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$316_and__5023__auto____$1$jscomp$56$$=$APP.$cljs$core$seq$$($shapes$jscomp$21$$);return $and__5023__auto__$jscomp$316_and__5023__auto____$1$jscomp$56$$?($and__5023__auto__$jscomp$316_and__5023__auto____$1$jscomp$56$$=$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($is_valid_move_QMARK_$$,$objects$jscomp$226$$),$shapes$jscomp$21$$))?$parent$jscomp$200$$:$and__5023__auto__$jscomp$316_and__5023__auto____$1$jscomp$56$$:
$and__5023__auto__$jscomp$316_and__5023__auto____$1$jscomp$56$$}())){var $index__$1$jscomp$1$$=function(){var $G__52572$jscomp$inline_5710_or__5025__auto__$jscomp$490$$=$APP.$app$common$data$index_of$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$200$$),$after_shape$$);$G__52572$jscomp$inline_5710_or__5025__auto__$jscomp$490$$=$G__52572$jscomp$inline_5710_or__5025__auto__$jscomp$490$$==null?null:$G__52572$jscomp$inline_5710_or__5025__auto__$jscomp$490$$+1;return $APP.$cljs$core$truth_$$($G__52572$jscomp$inline_5710_or__5025__auto__$jscomp$490$$)?
$G__52572$jscomp$inline_5710_or__5025__auto__$jscomp$490$$:$index$jscomp$218$$}(),$$__$4$jscomp$1_frame_id$jscomp$30$$=$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$200$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$200$$):$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$200$$),$$__$1$jscomp$12_$__$2$jscomp$3_$__$3$jscomp$1$$=$APP.$app$common$data$update_when$$($objects$jscomp$226$$,$parent_id$jscomp$29$$,
function($p1__52506_SHARP_$$){return $add_to_parent$$($p1__52506_SHARP_$$,$index__$1$jscomp$1$$,$shapes$jscomp$21$$)});$$__$1$jscomp$12_$__$2$jscomp$3_$__$3$jscomp$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($update_parent_id$$,$$__$1$jscomp$12_$__$2$jscomp$3_$__$3$jscomp$1$$,$shapes$jscomp$21$$);$$__$1$jscomp$12_$__$2$jscomp$3_$__$3$jscomp$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($remove_from_old_parent$$,
$objects$jscomp$226$$),$$__$1$jscomp$12_$__$2$jscomp$3_$__$3$jscomp$1$$,$shapes$jscomp$21$$);$$__$4$jscomp$1_frame_id$jscomp$30$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($update_frame_id$$,$$__$4$jscomp$1_frame_id$jscomp$30$$),$$__$1$jscomp$12_$__$2$jscomp$3_$__$3$jscomp$1$$,$shapes$jscomp$21$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($validate_shape$$,$$__$4$jscomp$1_frame_id$jscomp$30$$,$shapes$jscomp$21$$)}return $objects$jscomp$226$$}
function $remove_from_old_parent$$($old_objects_prev_parent_id$$,$objects$jscomp$225$$,$shape_id$jscomp$31$$){$old_objects_prev_parent_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_objects_prev_parent_id$$,$shape_id$jscomp$31$$),$APP.$cljs$cst$1619$parent_id$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($old_objects_prev_parent_id$$,$parent_id$jscomp$29$$)?$objects$jscomp$225$$:$APP.$app$common$data$update_in_when$$($objects$jscomp$225$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$old_objects_prev_parent_id$$,$APP.$cljs$cst$1614$shapes$$],null),function($shapes__$1$jscomp$2$$){return $APP.$app$common$data$vec_without_nils$$($app$common$data$without_obj$$($shapes__$1$jscomp$2$$,$shape_id$jscomp$31$$))})}function $validate_shape$$($objects$jscomp$223$$){return $objects$jscomp$223$$}$map__52508__$1_p__52507$$=$APP.$cljs$core$__destructure_map$$($map__52508__$1_p__52507$$);var $parent_id$jscomp$29$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52508__$1_p__52507$$,$APP.$cljs$cst$1619$parent_id$$),$shapes$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52508__$1_p__52507$$,$APP.$cljs$cst$1614$shapes$$),$index$jscomp$218$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52508__$1_p__52507$$,$APP.$cljs$cst$1795$index$$),$page_id$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52508__$1_p__52507$$,$APP.$cljs$cst$2043$page_id$$),
$component_id$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52508__$1_p__52507$$,$APP.$cljs$cst$1627$component_id$$),$after_shape$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52508__$1_p__52507$$,$cljs$cst$2617$after_shape$$),$allow_altering_copies$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52508__$1_p__52507$$,$cljs$cst$2618$allow_altering_copies$$),$syncing$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52508__$1_p__52507$$,
$cljs$cst$2663$syncing$$),$update_frame_id$$=function $app$common$files$changes$update_frame_id$$($frame_id$jscomp$29$$,$G__52561__$1_objects$jscomp$224$$,$id$jscomp$266$$){var $G__52560$jscomp$inline_5708_obj$jscomp$187$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__52561__$1_objects$jscomp$224$$,$id$jscomp$266$$);$G__52560$jscomp$inline_5708_obj$jscomp$187$$=$G__52560$jscomp$inline_5708_obj$jscomp$187$$==null?null:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__52560$jscomp$inline_5708_obj$jscomp$187$$,
$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$29$$);$G__52561__$1_objects$jscomp$224$$=$G__52560$jscomp$inline_5708_obj$jscomp$187$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__52561__$1_objects$jscomp$224$$,$id$jscomp$266$$,$G__52560$jscomp$inline_5708_obj$jscomp$187$$):$G__52561__$1_objects$jscomp$224$$;return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__52560$jscomp$inline_5708_obj$jscomp$187$$)?$G__52561__$1_objects$jscomp$224$$:
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$files$changes$update_frame_id$$,$frame_id$jscomp$29$$),$G__52561__$1_objects$jscomp$224$$,$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($G__52560$jscomp$inline_5708_obj$jscomp$187$$))},$calculate_invalid_targets$$=function $app$common$files$changes$calculate_invalid_targets$$($objects$jscomp$229$$,$shape_id$jscomp$33$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__52504_SHARP_$$,
$p2__52505_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($p1__52504_SHARP_$$,$app$common$files$changes$calculate_invalid_targets$$($objects$jscomp$229$$,$p2__52505_SHARP_$$))},$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_id$jscomp$33$$]),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$229$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$33$$,$APP.$cljs$cst$1614$shapes$$],
null)))};return $APP.$cljs$core$truth_$$($page_id$jscomp$43$$)?$APP.$app$common$data$update_in_when$$($data$jscomp$205$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$page_id$jscomp$43$$,$APP.$cljs$cst$1631$objects$$],null),$move_objects$$):$APP.$app$common$data$update_in_when$$($data$jscomp$205$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,
$component_id$jscomp$29$$,$APP.$cljs$cst$1631$objects$$],null),$move_objects$$)});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2620$add_page$$,function($data$jscomp$206$$,$id$jscomp$268_p__52591_page__$1$jscomp$5$$){var $map__52592__$1_page$jscomp$23$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$268_p__52591_page__$1$jscomp$5$$);$id$jscomp$268_p__52591_page__$1$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52592__$1_page$jscomp$23$$,$APP.$cljs$cst$266$id$$);var $name$jscomp$258$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52592__$1_page$jscomp$23$$,
$APP.$cljs$cst$725$name$$);$map__52592__$1_page$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52592__$1_page$jscomp$23$$,$APP.$cljs$cst$1624$page$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($id$jscomp$268_p__52591_page__$1$jscomp$5$$)?$APP.$cljs$core$truth_$$($name$jscomp$258$$)?$map__52592__$1_page$jscomp$23$$:$name$jscomp$258$$:$id$jscomp$268_p__52591_page__$1$jscomp$5$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("id+name or page should be provided, never both",
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$cljs$cst$2664$conflict$$,$APP.$cljs$cst$275$hint$$,"id+name or page should be provided, never both"],null),null])),null);$id$jscomp$268_p__52591_page__$1$jscomp$5$$=typeof $name$jscomp$258$$==="string"&&$APP.$cljs$core$uuid_QMARK_$$($id$jscomp$268_p__52591_page__$1$jscomp$5$$)?$app$common$types$page$make_empty_page$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$266$id$$,$id$jscomp$268_p__52591_page__$1$jscomp$5$$,$APP.$cljs$cst$725$name$$,$name$jscomp$258$$],null)):$map__52592__$1_page$jscomp$23$$;return $app$common$types$pages_list$add_page$$($data$jscomp$206$$,$id$jscomp$268_p__52591_page__$1$jscomp$5$$)});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2621$mod_page$$,function($data$jscomp$207$$,$id$jscomp$269_p__52593$$){var $map__52594__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$269_p__52593$$);$id$jscomp$269_p__52593$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52594__$1$$,$APP.$cljs$cst$266$id$$);return $APP.$app$common$data$update_in_when$$($data$jscomp$207$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1630$pages_index$$,$id$jscomp$269_p__52593$$],null),function($G__52595__$1_G__52595__$2_page$jscomp$24$$){var $name$jscomp$259$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52594__$1$$,$APP.$cljs$cst$725$name$$),$G__52595__$3_G__52595__$4_bg$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__52594__$1$$,$APP.$cljs$cst$2058$background$$,$APP.$cljs$cst$2665$not_found$$),$G__52595__$5_G__52595__$6_grid_color$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__52594__$1$$,
$APP.$cljs$cst$2059$pixel_grid_color$$,$APP.$cljs$cst$2665$not_found$$),$grid_op$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__52594__$1$$,$APP.$cljs$cst$2060$pixel_grid_opacity$$,$APP.$cljs$cst$2665$not_found$$);$G__52595__$1_G__52595__$2_page$jscomp$24$$=typeof $name$jscomp$259$$==="string"?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__52595__$1_G__52595__$2_page$jscomp$24$$,$APP.$cljs$cst$725$name$$,$name$jscomp$259$$):$G__52595__$1_G__52595__$2_page$jscomp$24$$;$G__52595__$1_G__52595__$2_page$jscomp$24$$=
typeof $G__52595__$3_G__52595__$4_bg$$==="string"?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__52595__$1_G__52595__$2_page$jscomp$24$$,$APP.$cljs$cst$2058$background$$,$G__52595__$3_G__52595__$4_bg$$):$G__52595__$1_G__52595__$2_page$jscomp$24$$;$G__52595__$3_G__52595__$4_bg$$=$G__52595__$3_G__52595__$4_bg$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__52595__$1_G__52595__$2_page$jscomp$24$$,$APP.$cljs$cst$2058$background$$):$G__52595__$1_G__52595__$2_page$jscomp$24$$;
$G__52595__$3_G__52595__$4_bg$$=typeof $G__52595__$5_G__52595__$6_grid_color$jscomp$1$$==="string"?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__52595__$3_G__52595__$4_bg$$,$APP.$cljs$cst$2059$pixel_grid_color$$,$G__52595__$5_G__52595__$6_grid_color$jscomp$1$$):$G__52595__$3_G__52595__$4_bg$$;$G__52595__$5_G__52595__$6_grid_color$jscomp$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__52595__$5_G__52595__$6_grid_color$jscomp$1$$,$APP.$cljs$cst$2665$not_found$$)&&$G__52595__$5_G__52595__$6_grid_color$jscomp$1$$==
null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__52595__$3_G__52595__$4_bg$$,$APP.$cljs$cst$2059$pixel_grid_color$$):$G__52595__$3_G__52595__$4_bg$$;$G__52595__$5_G__52595__$6_grid_color$jscomp$1$$=typeof $grid_op$$==="number"?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__52595__$5_G__52595__$6_grid_color$jscomp$1$$,$APP.$cljs$cst$2060$pixel_grid_opacity$$,$grid_op$$):$G__52595__$5_G__52595__$6_grid_color$jscomp$1$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grid_op$$,
$APP.$cljs$cst$2665$not_found$$)&&$grid_op$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__52595__$5_G__52595__$6_grid_color$jscomp$1$$,$APP.$cljs$cst$2060$pixel_grid_opacity$$):$G__52595__$5_G__52595__$6_grid_color$jscomp$1$$})});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2606$set_plugin_data$$,function($data$jscomp$208$$,$object_id$jscomp$2_p__52608$$){function $update_fn$jscomp$7$$($data__$1$jscomp$8$$){return $value$jscomp$454$$!=null?$APP.$cljs$core$assoc_in$$($data__$1$jscomp$8$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1738$plugin_data$$,$namespace$jscomp$10$$,$key$jscomp$330$$],null),$value$jscomp$454$$):
$APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data__$1$jscomp$8$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1738$plugin_data$$,$namespace$jscomp$10$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$key$jscomp$330$$]))}var $G__52610__$1_map__52609__$1$$=$APP.$cljs$core$__destructure_map$$($object_id$jscomp$2_p__52608$$),$object_type$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__52610__$1_map__52609__$1$$,
$APP.$cljs$cst$2607$object_type$$);$object_id$jscomp$2_p__52608$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__52610__$1_map__52609__$1$$,$APP.$cljs$cst$2272$object_id$$);var $page_id$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__52610__$1_map__52609__$1$$,$APP.$cljs$cst$2043$page_id$$),$namespace$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__52610__$1_map__52609__$1$$,$APP.$cljs$cst$394$namespace$$),$key$jscomp$330$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__52610__$1_map__52609__$1$$,
$APP.$cljs$cst$302$key$$),$value$jscomp$454$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__52610__$1_map__52609__$1$$,$APP.$cljs$cst$260$value$$);$G__52610__$1_map__52609__$1$$=$object_type$jscomp$2$$ instanceof $APP.$cljs$core$Keyword$$?$object_type$jscomp$2$$.$fqn$:null;switch($G__52610__$1_map__52609__$1$$){case "file":return $update_fn$jscomp$7$$($data$jscomp$208$$);case "page":return $APP.$app$common$data$update_in_when$$($data$jscomp$208$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$object_id$jscomp$2_p__52608$$],null),$update_fn$jscomp$7$$);case "shape":return $APP.$app$common$data$update_in_when$$($data$jscomp$208$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$pages_index$$,$page_id$jscomp$44$$,$APP.$cljs$cst$1631$objects$$,$object_id$jscomp$2_p__52608$$],null),$update_fn$jscomp$7$$);case "color":return $APP.$app$common$data$update_in_when$$($data$jscomp$208$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2212$colors$$,$object_id$jscomp$2_p__52608$$],null),$update_fn$jscomp$7$$);case "typography":return $APP.$app$common$data$update_in_when$$($data$jscomp$208$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2215$typographies$$,$object_id$jscomp$2_p__52608$$],null),$update_fn$jscomp$7$$);case "component":return $APP.$app$common$data$update_in_when$$($data$jscomp$208$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$object_id$jscomp$2_p__52608$$],null),$update_fn$jscomp$7$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__52610__$1_map__52609__$1$$)].join(""));}});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2622$del_page$$,function($data$jscomp$209$$,$id$jscomp$270_map__52613__$1_p__52612$$){$id$jscomp$270_map__52613__$1_p__52612$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$270_map__52613__$1_p__52612$$);$id$jscomp$270_map__52613__$1_p__52612$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$270_map__52613__$1_p__52612$$,$APP.$cljs$cst$266$id$$);return $app$common$types$pages_list$delete_page$$($data$jscomp$209$$,
$id$jscomp$270_map__52613__$1_p__52612$$)});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2623$mov_page$$,function($data$jscomp$210$$,$id$jscomp$271_p__52614$$){var $index$jscomp$219_map__52615__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$271_p__52614$$);$id$jscomp$271_p__52614$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$219_map__52615__$1$$,$APP.$cljs$cst$266$id$$);$index$jscomp$219_map__52615__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$219_map__52615__$1$$,$APP.$cljs$cst$1795$index$$);
return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($data$jscomp$210$$,$APP.$cljs$cst$2228$pages$$,$APP.$app$common$data$insert_at_index$$,$index$jscomp$219_map__52615__$1$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$271_p__52614$$],null))});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2625$add_color$$,function($data$jscomp$211$$,$color$jscomp$35_map__52617__$1_p__52616$$){$color$jscomp$35_map__52617__$1_p__52616$$=$APP.$cljs$core$__destructure_map$$($color$jscomp$35_map__52617__$1_p__52616$$);$color$jscomp$35_map__52617__$1_p__52616$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$35_map__52617__$1_p__52616$$,$APP.$cljs$cst$1298$color$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($data$jscomp$211$$,
$APP.$cljs$cst$2212$colors$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$35_map__52617__$1_p__52616$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$35_map__52617__$1_p__52616$$,$APP.$cljs$cst$1737$modified_at$$,$APP.$app$common$time$now$$()))});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2626$mod_color$$,function($data$jscomp$212$$,$color$jscomp$36_map__52626__$1_p__52625$$){$color$jscomp$36_map__52626__$1_p__52625$$=$APP.$cljs$core$__destructure_map$$($color$jscomp$36_map__52626__$1_p__52625$$);$color$jscomp$36_map__52626__$1_p__52625$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$36_map__52626__$1_p__52625$$,$APP.$cljs$cst$1298$color$$);return $app$common$data$assoc_in_when$$($data$jscomp$212$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2212$colors$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$36_map__52626__$1_p__52625$$)],null),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$36_map__52626__$1_p__52625$$,$APP.$cljs$cst$1737$modified_at$$,$APP.$app$common$time$now$$()))});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2627$del_color$$,function($data$jscomp$213$$,$id$jscomp$272_map__52629__$1_p__52627$$){$id$jscomp$272_map__52629__$1_p__52627$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$272_map__52629__$1_p__52627$$);$id$jscomp$272_map__52629__$1_p__52627$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$272_map__52629__$1_p__52627$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($data$jscomp$213$$,
$APP.$cljs$cst$2212$colors$$,$APP.$cljs$core$dissoc$$,$id$jscomp$272_map__52629__$1_p__52627$$)});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2628$add_media$$,function($data$jscomp$214$$,$map__52631__$1_object$jscomp$19_p__52630$$){$map__52631__$1_object$jscomp$19_p__52630$$=$APP.$cljs$core$__destructure_map$$($map__52631__$1_object$jscomp$19_p__52630$$);$map__52631__$1_object$jscomp$19_p__52630$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52631__$1_object$jscomp$19_p__52630$$,$APP.$cljs$cst$2198$object$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($data$jscomp$214$$,
$APP.$cljs$cst$1639$media$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__52631__$1_object$jscomp$19_p__52630$$),$map__52631__$1_object$jscomp$19_p__52630$$)});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2629$mod_media$$,function($data$jscomp$215$$,$map__52635__$1_object$jscomp$20_p__52633$$){$map__52635__$1_object$jscomp$20_p__52633$$=$APP.$cljs$core$__destructure_map$$($map__52635__$1_object$jscomp$20_p__52633$$);$map__52635__$1_object$jscomp$20_p__52633$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52635__$1_object$jscomp$20_p__52633$$,$APP.$cljs$cst$2198$object$$);return $APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data$jscomp$215$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1639$media$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__52635__$1_object$jscomp$20_p__52633$$)],null),$APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__52635__$1_object$jscomp$20_p__52633$$]))});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2630$del_media$$,function($data$jscomp$216$$,$id$jscomp$273_map__52640__$1_p__52639$$){$id$jscomp$273_map__52640__$1_p__52639$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$273_map__52640__$1_p__52639$$);$id$jscomp$273_map__52640__$1_p__52639$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$273_map__52640__$1_p__52639$$,$APP.$cljs$cst$266$id$$);return $APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data$jscomp$216$$,
$APP.$cljs$cst$1639$media$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$id$jscomp$273_map__52640__$1_p__52639$$]))});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2631$add_component$$,function($G__50283$jscomp$inline_5730_data$jscomp$217_fdata__$1$jscomp$inline_5729$$,$id$jscomp$inline_5721_params$jscomp$168$$){var $map__50280__$1$jscomp$inline_5720_variant_properties$jscomp$inline_5728$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$inline_5721_params$jscomp$168$$);$id$jscomp$inline_5721_params$jscomp$168$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50280__$1$jscomp$inline_5720_variant_properties$jscomp$inline_5728$$,
$APP.$cljs$cst$266$id$$);var $name$jscomp$inline_5722$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50280__$1$jscomp$inline_5720_variant_properties$jscomp$inline_5728$$,$APP.$cljs$cst$725$name$$),$path$jscomp$inline_5723$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50280__$1$jscomp$inline_5720_variant_properties$jscomp$inline_5728$$,$APP.$cljs$cst$296$path$$),$main_instance_id$jscomp$inline_5724$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50280__$1$jscomp$inline_5720_variant_properties$jscomp$inline_5728$$,
$APP.$cljs$cst$2062$main_instance_id$$),$main_instance_page$jscomp$inline_5725$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50280__$1$jscomp$inline_5720_variant_properties$jscomp$inline_5728$$,$APP.$cljs$cst$2063$main_instance_page$$),$G__50283__$1$jscomp$inline_5731_annotation$jscomp$inline_5726$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50280__$1$jscomp$inline_5720_variant_properties$jscomp$inline_5728$$,$APP.$cljs$cst$2542$annotation$$),$G__50283__$2$jscomp$inline_5732_variant_id$jscomp$inline_5727$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50280__$1$jscomp$inline_5720_variant_properties$jscomp$inline_5728$$,$APP.$cljs$cst$2000$variant_id$$);$map__50280__$1$jscomp$inline_5720_variant_properties$jscomp$inline_5728$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50280__$1$jscomp$inline_5720_variant_properties$jscomp$inline_5728$$,$APP.$cljs$cst$2001$variant_properties$$);$G__50283$jscomp$inline_5730_data$jscomp$217_fdata__$1$jscomp$inline_5729$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($G__50283$jscomp$inline_5730_data$jscomp$217_fdata__$1$jscomp$inline_5729$$,
$APP.$cljs$cst$1638$components$$,$APP.$cljs$core$assoc$$,$id$jscomp$inline_5721_params$jscomp$168$$,$app$common$types$components_list$touch$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$id$jscomp$inline_5721_params$jscomp$168$$,$APP.$cljs$cst$725$name$$,$name$jscomp$inline_5722$$,$APP.$cljs$cst$296$path$$,$path$jscomp$inline_5723$$],null)));$G__50283$jscomp$inline_5730_data$jscomp$217_fdata__$1$jscomp$inline_5729$$=$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$variadic$($G__50283$jscomp$inline_5730_data$jscomp$217_fdata__$1$jscomp$inline_5729$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$id$jscomp$inline_5721_params$jscomp$168$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2062$main_instance_id$$,$main_instance_id$jscomp$inline_5724$$,$APP.$cljs$cst$2063$main_instance_page$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$main_instance_page$jscomp$inline_5725$$]));$G__50283__$1$jscomp$inline_5731_annotation$jscomp$inline_5726$$=$APP.$cljs$core$truth_$$($G__50283__$1$jscomp$inline_5731_annotation$jscomp$inline_5726$$)?
$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($G__50283$jscomp$inline_5730_data$jscomp$217_fdata__$1$jscomp$inline_5729$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$id$jscomp$inline_5721_params$jscomp$168$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2542$annotation$$,$G__50283__$1$jscomp$inline_5731_annotation$jscomp$inline_5726$$):$G__50283$jscomp$inline_5730_data$jscomp$217_fdata__$1$jscomp$inline_5729$$;
$G__50283__$2$jscomp$inline_5732_variant_id$jscomp$inline_5727$$=$APP.$cljs$core$truth_$$($G__50283__$2$jscomp$inline_5732_variant_id$jscomp$inline_5727$$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($G__50283__$1$jscomp$inline_5731_annotation$jscomp$inline_5726$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$id$jscomp$inline_5721_params$jscomp$168$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2000$variant_id$$,
$G__50283__$2$jscomp$inline_5732_variant_id$jscomp$inline_5727$$):$G__50283__$1$jscomp$inline_5731_annotation$jscomp$inline_5726$$;return $APP.$cljs$core$truth_$$($map__50280__$1$jscomp$inline_5720_variant_properties$jscomp$inline_5728$$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($G__50283__$2$jscomp$inline_5732_variant_id$jscomp$inline_5727$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1638$components$$,$id$jscomp$inline_5721_params$jscomp$168$$],
null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2001$variant_properties$$,$map__50280__$1$jscomp$inline_5720_variant_properties$jscomp$inline_5728$$):$G__50283__$2$jscomp$inline_5732_variant_id$jscomp$inline_5727$$});$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2632$mod_component$$,function($data$jscomp$218$$,$params$jscomp$169$$){return $app$common$types$components_list$mod_component$$($data$jscomp$218$$,$params$jscomp$169$$)});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2633$del_component$$,function($data$jscomp$219$$,$id$jscomp$274_p__52641$$){var $delta$jscomp$14_map__52642__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$274_p__52641$$);$id$jscomp$274_p__52641$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($delta$jscomp$14_map__52642__$1$$,$APP.$cljs$cst$266$id$$);var $skip_undelete_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($delta$jscomp$14_map__52642__$1$$,
$cljs$cst$2635$skip_undelete_QMARK_$$);$delta$jscomp$14_map__52642__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($delta$jscomp$14_map__52642__$1$$,$cljs$cst$2634$delta$$);return $app$common$types$file$delete_component$$($data$jscomp$219$$,$id$jscomp$274_p__52641$$,$skip_undelete_QMARK_$jscomp$1$$,$delta$jscomp$14_map__52642__$1$$)});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2636$restore_component$$,function($data$jscomp$220$$,$id$jscomp$275_p__52651$$){var $map__52652__$1_page_id$jscomp$45$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$275_p__52651$$);$id$jscomp$275_p__52651$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52652__$1_page_id$jscomp$45$$,$APP.$cljs$cst$266$id$$);$map__52652__$1_page_id$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52652__$1_page_id$jscomp$45$$,
$APP.$cljs$cst$2043$page_id$$);return $app$common$types$file$restore_component$$($data$jscomp$220$$,$id$jscomp$275_p__52651$$,$map__52652__$1_page_id$jscomp$45$$)});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2637$purge_component$$,function($data$jscomp$221$$,$id$jscomp$276_map__52654__$1_p__52653$$){$id$jscomp$276_map__52654__$1_p__52653$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$276_map__52654__$1_p__52653$$);$id$jscomp$276_map__52654__$1_p__52653$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$276_map__52654__$1_p__52653$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($data$jscomp$221$$,
$APP.$cljs$cst$1638$components$$,$APP.$cljs$core$dissoc$$,$id$jscomp$276_map__52654__$1_p__52653$$)});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2638$add_typography$$,function($data$jscomp$222$$,$map__52656__$1_p__52655_typography$jscomp$7$$){$map__52656__$1_p__52655_typography$jscomp$7$$=$APP.$cljs$core$__destructure_map$$($map__52656__$1_p__52655_typography$jscomp$7$$);$map__52656__$1_p__52655_typography$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52656__$1_p__52655_typography$jscomp$7$$,$APP.$cljs$cst$1981$typography$$);
return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($data$jscomp$222$$,$APP.$cljs$cst$2215$typographies$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__52656__$1_p__52655_typography$jscomp$7$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__52656__$1_p__52655_typography$jscomp$7$$,$APP.$cljs$cst$1737$modified_at$$,$APP.$app$common$time$now$$()))});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2639$mod_typography$$,function($data$jscomp$223$$,$map__52661__$1_p__52660_typography$jscomp$8$$){$map__52661__$1_p__52660_typography$jscomp$8$$=$APP.$cljs$core$__destructure_map$$($map__52661__$1_p__52660_typography$jscomp$8$$);$map__52661__$1_p__52660_typography$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52661__$1_p__52660_typography$jscomp$8$$,$APP.$cljs$cst$1981$typography$$);
return $app$common$types$typographies_list$update_typography$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($data$jscomp$223$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__52661__$1_p__52660_typography$jscomp$8$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__52661__$1_p__52660_typography$jscomp$8$$]))});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2640$del_typography$$,function($data$jscomp$224$$,$id$jscomp$277_map__52665__$1_p__52663$$){$id$jscomp$277_map__52665__$1_p__52663$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$277_map__52665__$1_p__52663$$);$id$jscomp$277_map__52665__$1_p__52663$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$277_map__52665__$1_p__52663$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($data$jscomp$224$$,
$APP.$cljs$cst$2215$typographies$$,$APP.$cljs$core$dissoc$$,$id$jscomp$277_map__52665__$1_p__52663$$)});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2641$set_tokens_lib$$,function($data$jscomp$225$$,$map__52667__$1_p__52666_tokens_lib$jscomp$5$$){$map__52667__$1_p__52666_tokens_lib$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($map__52667__$1_p__52666_tokens_lib$jscomp$5$$);$map__52667__$1_p__52666_tokens_lib$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52667__$1_p__52666_tokens_lib$jscomp$5$$,$APP.$cljs$cst$2139$tokens_lib$$);
return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$225$$,$APP.$cljs$cst$2139$tokens_lib$$,$map__52667__$1_p__52666_tokens_lib$jscomp$5$$)});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2642$set_token$$,function($data$jscomp$226$$,$map__52674__$1_p__52672$$){$map__52674__$1_p__52672$$=$APP.$cljs$core$__destructure_map$$($map__52674__$1_p__52672$$);var $set_id$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52674__$1_p__52672$$,$APP.$cljs$cst$2643$set_id$$),$token_id$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52674__$1_p__52672$$,
$APP.$cljs$cst$2644$token_id$$),$attrs$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52674__$1_p__52672$$,$APP.$cljs$cst$2645$attrs$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$226$$,$APP.$cljs$cst$2139$tokens_lib$$,function($lib$jscomp$5_lib_SINGLEQUOTE_$$){$lib$jscomp$5_lib_SINGLEQUOTE_$$=$app$common$types$tokens_lib$ensure_tokens_lib$$($lib$jscomp$5_lib_SINGLEQUOTE_$$);return $APP.$cljs$core$not$$($attrs$jscomp$20$$)?$app$common$types$tokens_lib$delete_token$$($lib$jscomp$5_lib_SINGLEQUOTE_$$,
$set_id$jscomp$19$$,$token_id$jscomp$14$$):$APP.$cljs$core$not$$($APP.$app$common$types$tokens_lib$get_token$$($lib$jscomp$5_lib_SINGLEQUOTE_$$,$set_id$jscomp$19$$,$token_id$jscomp$14$$))?$app$common$types$tokens_lib$add_token$$($lib$jscomp$5_lib_SINGLEQUOTE_$$,$set_id$jscomp$19$$,$APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs$jscomp$20$$]))):$app$common$types$tokens_lib$update_token$$($lib$jscomp$5_lib_SINGLEQUOTE_$$,
$set_id$jscomp$19$$,$token_id$jscomp$14$$,function($prev_token$$){return $APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$prev_token$$,$attrs$jscomp$20$$]))]))})})});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2646$set_token_set$$,function($data$jscomp$227$$,$map__52679__$1_p__52678$$){$map__52679__$1_p__52678$$=$APP.$cljs$core$__destructure_map$$($map__52679__$1_p__52678$$);var $id$jscomp$278$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52679__$1_p__52678$$,$APP.$cljs$cst$266$id$$),$attrs$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52679__$1_p__52678$$,$APP.$cljs$cst$2645$attrs$$);
return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$227$$,$APP.$cljs$cst$2139$tokens_lib$$,function($lib$jscomp$6_lib_SINGLEQUOTE_$jscomp$1$$){$lib$jscomp$6_lib_SINGLEQUOTE_$jscomp$1$$=$app$common$types$tokens_lib$ensure_tokens_lib$$($lib$jscomp$6_lib_SINGLEQUOTE_$jscomp$1$$);return $APP.$cljs$core$not$$($attrs$jscomp$21$$)?$app$common$types$tokens_lib$delete_set$$($lib$jscomp$6_lib_SINGLEQUOTE_$jscomp$1$$,$id$jscomp$278$$):$APP.$cljs$core$not$$($APP.$app$common$types$tokens_lib$get_set$$($lib$jscomp$6_lib_SINGLEQUOTE_$jscomp$1$$,
$id$jscomp$278$$))?$APP.$app$common$types$tokens_lib$add_set$$($lib$jscomp$6_lib_SINGLEQUOTE_$jscomp$1$$,$APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs$jscomp$21$$]))):$app$common$types$tokens_lib$update_set$$($lib$jscomp$6_lib_SINGLEQUOTE_$jscomp$1$$,$id$jscomp$278$$,function(){return $APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs$jscomp$21$$]))})})});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2647$set_token_theme$$,function($data$jscomp$228$$,$map__52683__$1_p__52682$$){$map__52683__$1_p__52682$$=$APP.$cljs$core$__destructure_map$$($map__52683__$1_p__52682$$);var $id$jscomp$279$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52683__$1_p__52682$$,$APP.$cljs$cst$266$id$$),$attrs$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52683__$1_p__52682$$,$APP.$cljs$cst$2645$attrs$$);
return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$228$$,$APP.$cljs$cst$2139$tokens_lib$$,function($lib$jscomp$7_lib_SINGLEQUOTE_$jscomp$2$$){$lib$jscomp$7_lib_SINGLEQUOTE_$jscomp$2$$=$app$common$types$tokens_lib$ensure_tokens_lib$$($lib$jscomp$7_lib_SINGLEQUOTE_$jscomp$2$$);return $APP.$cljs$core$not$$($attrs$jscomp$22$$)?$app$common$types$tokens_lib$delete_theme$$($lib$jscomp$7_lib_SINGLEQUOTE_$jscomp$2$$,$id$jscomp$279$$):$APP.$cljs$core$not$$($APP.$app$common$types$tokens_lib$get_theme$$($lib$jscomp$7_lib_SINGLEQUOTE_$jscomp$2$$,
$id$jscomp$279$$))?$app$common$types$tokens_lib$add_theme$$($lib$jscomp$7_lib_SINGLEQUOTE_$jscomp$2$$,$APP.$app$common$types$tokens_lib$make_token_theme$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs$jscomp$22$$]))):$app$common$types$tokens_lib$update_theme$$($lib$jscomp$7_lib_SINGLEQUOTE_$jscomp$2$$,$id$jscomp$279$$,function($prev_token_theme$$){return $APP.$app$common$types$tokens_lib$make_token_theme$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$prev_token_theme$$,
$attrs$jscomp$22$$]))]))})})});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2648$set_active_token_themes$$,function($data$jscomp$229$$,$map__52696__$1_p__52695$$){$map__52696__$1_p__52695$$=$APP.$cljs$core$__destructure_map$$($map__52696__$1_p__52695$$);var $theme_paths$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52696__$1_p__52695$$,$cljs$cst$2649$theme_paths$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$229$$,$APP.$cljs$cst$2139$tokens_lib$$,
function($p1__52693_SHARP_$$){return $app$common$types$tokens_lib$set_active_themes$$($app$common$types$tokens_lib$ensure_tokens_lib$$($p1__52693_SHARP_$$),$theme_paths$$)})});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2650$rename_token_set_group$$,function($data$jscomp$230$$,$map__52701__$1_p__52699$$){$map__52701__$1_p__52699$$=$APP.$cljs$core$__destructure_map$$($map__52701__$1_p__52699$$);var $set_group_path$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52701__$1_p__52699$$,$APP.$cljs$cst$2651$set_group_path$$),$set_group_fname$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52701__$1_p__52699$$,
$APP.$cljs$cst$2652$set_group_fname$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$230$$,$APP.$cljs$cst$2139$tokens_lib$$,function($lib$jscomp$8$$){return $app$common$types$tokens_lib$rename_set_group$$($app$common$types$tokens_lib$ensure_tokens_lib$$($lib$jscomp$8$$),$set_group_path$$,$set_group_fname$$)})});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2653$move_token_set$$,function($data$jscomp$231$$,$map__52707__$1_p__52706$$){$map__52707__$1_p__52706$$=$APP.$cljs$core$__destructure_map$$($map__52707__$1_p__52706$$);var $from_path$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52707__$1_p__52706$$,$APP.$cljs$cst$2654$from_path$$),$to_path$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52707__$1_p__52706$$,
$APP.$cljs$cst$2655$to_path$$),$before_path$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52707__$1_p__52706$$,$APP.$cljs$cst$2656$before_path$$),$before_group$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52707__$1_p__52706$$,$APP.$cljs$cst$2657$before_group$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$231$$,$APP.$cljs$cst$2139$tokens_lib$$,function($p1__52705_SHARP_$$){return $app$common$types$tokens_lib$move_set$$($app$common$types$tokens_lib$ensure_tokens_lib$$($p1__52705_SHARP_$$),
$from_path$jscomp$6$$,$to_path$jscomp$6$$,$before_path$jscomp$6$$,$before_group$$)})});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2658$move_token_set_group$$,function($data$jscomp$232$$,$map__52710__$1_p__52709$$){$map__52710__$1_p__52709$$=$APP.$cljs$core$__destructure_map$$($map__52710__$1_p__52709$$);var $from_path$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52710__$1_p__52709$$,$APP.$cljs$cst$2654$from_path$$),$to_path$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52710__$1_p__52709$$,
$APP.$cljs$cst$2655$to_path$$),$before_path$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52710__$1_p__52709$$,$APP.$cljs$cst$2656$before_path$$),$before_group$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52710__$1_p__52709$$,$APP.$cljs$cst$2657$before_group$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$232$$,$APP.$cljs$cst$2139$tokens_lib$$,function($p1__52708_SHARP_$$){return $app$common$types$tokens_lib$move_set_group$$($app$common$types$tokens_lib$ensure_tokens_lib$$($p1__52708_SHARP_$$),
$from_path$jscomp$7$$,$to_path$jscomp$7$$,$before_path$jscomp$7$$,$before_group$jscomp$1$$)})});
$app$common$files$changes$process_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2659$set_base_font_size$$,function($data$jscomp$233$$,$base_font_size$jscomp$1_map__52712__$1_p__52711$$){$base_font_size$jscomp$1_map__52712__$1_p__52711$$=$APP.$cljs$core$__destructure_map$$($base_font_size$jscomp$1_map__52712__$1_p__52711$$);$base_font_size$jscomp$1_map__52712__$1_p__52711$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_font_size$jscomp$1_map__52712__$1_p__52711$$,$APP.$cljs$cst$2576$base_font_size$$);
return $APP.$cljs$core$assoc_in$$($data$jscomp$233$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$873$options$$,$APP.$cljs$cst$2576$base_font_size$$],null),$base_font_size$jscomp$1_map__52712__$1_p__52711$$)});var $app$common$files$changes$decode_shape_attrs$$=$malli$core$decoder$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$shape$schema_COLON_shape_attrs$$);
$app$common$files$changes$process_operation$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2598$assign$$,function($map__52730__$1_p__52725$$,$modifications_modifications__$1_p__52726_value$jscomp$455$$){$map__52730__$1_p__52725$$=$APP.$cljs$core$__destructure_map$$($map__52730__$1_p__52725$$);var $type$jscomp$376$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52730__$1_p__52725$$,$APP.$cljs$cst$139$type$$),$map__52732__$1$$=$APP.$cljs$core$__destructure_map$$($modifications_modifications__$1_p__52726_value$jscomp$455$$);
$modifications_modifications__$1_p__52726_value$jscomp$455$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52732__$1$$,$APP.$cljs$cst$260$value$$);$modifications_modifications__$1_p__52726_value$jscomp$455$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($modifications_modifications__$1_p__52726_value$jscomp$455$$,$APP.$cljs$cst$139$type$$,$type$jscomp$376$$);$modifications_modifications__$1_p__52726_value$jscomp$455$$=$app$common$files$changes$decode_shape_attrs$$.$cljs$core$IFn$_invoke$arity$1$?
$app$common$files$changes$decode_shape_attrs$$.$cljs$core$IFn$_invoke$arity$1$($modifications_modifications__$1_p__52726_value$jscomp$455$$):$app$common$files$changes$decode_shape_attrs$$($modifications_modifications__$1_p__52726_value$jscomp$455$$);return $APP.$cljs$core$reduce_kv$$(function($shape__$1$jscomp$26$$,$k$jscomp$617$$,$v$jscomp$560$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$560$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$26$$,
$k$jscomp$617$$))?$app$common$files$changes$process_operation$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$26$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2599$attr$$,$k$jscomp$617$$,$APP.$cljs$cst$108$val$$,$v$jscomp$560$$,$APP.$cljs$cst$2556$ignore_touched$$,$APP.$cljs$cst$2556$ignore_touched$$.$cljs$core$IFn$_invoke$arity$1$($map__52732__$1$$),$APP.$cljs$cst$2557$ignore_geometry$$,$APP.$cljs$cst$2557$ignore_geometry$$.$cljs$core$IFn$_invoke$arity$1$($map__52732__$1$$)],
null)):$shape__$1$jscomp$26$$},$map__52730__$1_p__52725$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($modifications_modifications__$1_p__52726_value$jscomp$455$$,$APP.$cljs$cst$139$type$$))});
$app$common$files$changes$process_operation$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$203$set$$,function($shape$jscomp$296$$,$op$jscomp$15$$){return $app$common$types$container$set_shape_attr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape$jscomp$296$$,$APP.$cljs$cst$2599$attr$$.$cljs$core$IFn$_invoke$arity$1$($op$jscomp$15$$),$APP.$cljs$cst$108$val$$.$cljs$core$IFn$_invoke$arity$1$($op$jscomp$15$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2556$ignore_touched$$,
$APP.$cljs$cst$2556$ignore_touched$$.$cljs$core$IFn$_invoke$arity$1$($op$jscomp$15$$),$APP.$cljs$cst$2557$ignore_geometry$$,$APP.$cljs$cst$2557$ignore_geometry$$.$cljs$core$IFn$_invoke$arity$1$($op$jscomp$15$$)]))});
$app$common$files$changes$process_operation$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2600$set_touched$$,function($shape$jscomp$297$$,$op$jscomp$16_touched$jscomp$4$$){$op$jscomp$16_touched$jscomp$4$$=$APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($op$jscomp$16_touched$jscomp$4$$);return!$APP.$app$common$types$component$in_component_copy_QMARK_$$($shape$jscomp$297$$)||$op$jscomp$16_touched$jscomp$4$$==null||$APP.$cljs$core$empty_QMARK_$$($op$jscomp$16_touched$jscomp$4$$)?
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$297$$,$APP.$cljs$cst$1626$touched$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$297$$,$APP.$cljs$cst$1626$touched$$,$op$jscomp$16_touched$jscomp$4$$)});
$app$common$files$changes$process_operation$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2601$set_remote_synced$$,function($shape$jscomp$298$$,$op$jscomp$17_remote_synced$$){$op$jscomp$17_remote_synced$$=$APP.$cljs$cst$2046$remote_synced$$.$cljs$core$IFn$_invoke$arity$1$($op$jscomp$17_remote_synced$$);return!$APP.$app$common$types$component$in_component_copy_QMARK_$$($shape$jscomp$298$$)||$APP.$cljs$core$not$$($op$jscomp$17_remote_synced$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$298$$,
$APP.$cljs$cst$2046$remote_synced$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$298$$,$APP.$cljs$cst$2046$remote_synced$$,!0)});
$app$common$files$changes$process_operation$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function($_$jscomp$1580$$,$op$jscomp$18$$){throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("not-implemented",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$2666$not_implemented$$,$APP.$cljs$cst$273$code$$,
$cljs$cst$2667$operation_not_implemented$$,$APP.$cljs$cst$2312$context$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($op$jscomp$18$$)],null)],null),null])),null);});
var $app$common$files$changes$components_changed$$=function(){var $method_table__5622__auto__$jscomp$16$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$16$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$16$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$16$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.common.files.changes",
"components-changed"),function($_$jscomp$1581$$,$change$jscomp$11$$){return $APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$11$$)},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$16$$,$method_table__5622__auto__$jscomp$16$$,$prefer_table__5623__auto__$jscomp$16$$,$method_cache__5624__auto__$jscomp$16$$,$cached_hierarchy__5625__auto__$jscomp$16$$)}();
$app$common$files$changes$components_changed$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2612$mod_obj$$,function($file_data$jscomp$59_shape_and_parents$$,$id$jscomp$280_p__52756_xform$jscomp$27$$){var $any_sync_QMARK__map__52757__$1_operations$jscomp$6$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$280_p__52756_xform$jscomp$27$$);$id$jscomp$280_p__52756_xform$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($any_sync_QMARK__map__52757__$1_operations$jscomp$6$$,
$APP.$cljs$cst$266$id$$);var $page_id$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($any_sync_QMARK__map__52757__$1_operations$jscomp$6$$,$APP.$cljs$cst$2043$page_id$$),$component_id$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($any_sync_QMARK__map__52757__$1_operations$jscomp$6$$,$APP.$cljs$cst$1627$component_id$$);$any_sync_QMARK__map__52757__$1_operations$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($any_sync_QMARK__map__52757__$1_operations$jscomp$6$$,
$APP.$cljs$cst$2613$operations$$);$any_sync_QMARK__map__52757__$1_operations$jscomp$6$$=$APP.$cljs$core$some$$(function($attr$jscomp$inline_5737_operation$jscomp$1$$){var $JSCompiler_temp$jscomp$816$$;if($JSCompiler_temp$jscomp$816$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$inline_5737_operation$jscomp$1$$),$APP.$cljs$cst$203$set$$))$attr$jscomp$inline_5737_operation$jscomp$1$$=$APP.$cljs$cst$2599$attr$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$inline_5737_operation$jscomp$1$$),
$JSCompiler_temp$jscomp$816$$=$APP.$cljs$core$contains_QMARK_$$($app$common$types$component$sync_attrs$$,$attr$jscomp$inline_5737_operation$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2047$shape_ref$$,$attr$jscomp$inline_5737_operation$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1873$applied_tokens$$,$attr$jscomp$inline_5737_operation$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1627$component_id$$,
$attr$jscomp$inline_5737_operation$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1643$component_file$$,$attr$jscomp$inline_5737_operation$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2044$component_root$$,$attr$jscomp$inline_5737_operation$jscomp$1$$);return $JSCompiler_temp$jscomp$816$$},$any_sync_QMARK__map__52757__$1_operations$jscomp$6$$);if($APP.$cljs$core$truth_$$($any_sync_QMARK__map__52757__$1_operations$jscomp$6$$)){if($APP.$cljs$core$truth_$$($page_id$jscomp$46$$)){var $page$jscomp$25$$=
$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$59_shape_and_parents$$,$page_id$jscomp$46$$);$file_data$jscomp$59_shape_and_parents$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__52755_SHARP_$$){return $APP.$app$common$types$container$get_shape$$($page$jscomp$25$$,$p1__52755_SHARP_$$)},$APP.$cljs$core$cons$$($id$jscomp$280_p__52756_xform$jscomp$27$$,$APP.$app$common$files$helpers$get_parent_ids$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$25$$),
$id$jscomp$280_p__52756_xform$jscomp$27$$)));$id$jscomp$280_p__52756_xform$jscomp$27$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2045$main_instance$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1627$component_id$$));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$id$jscomp$280_p__52756_xform$jscomp$27$$,$file_data$jscomp$59_shape_and_parents$$)}return $APP.$cljs$core$truth_$$($component_id$jscomp$30$$)?
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$component_id$jscomp$30$$]):null}return null});
$app$common$files$changes$components_changed$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2616$mov_objects$$,function($file_data$jscomp$60$$,$p__52761_page_id$jscomp$47$$){var $map__52762__$1_shapes$jscomp$22$$=$APP.$cljs$core$__destructure_map$$($p__52761_page_id$jscomp$47$$);$p__52761_page_id$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52762__$1_shapes$jscomp$22$$,$APP.$cljs$cst$2043$page_id$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52762__$1_shapes$jscomp$22$$,
$cljs$cst$2668$_component_id$$);var $parent_id$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52762__$1_shapes$jscomp$22$$,$APP.$cljs$cst$1619$parent_id$$);$map__52762__$1_shapes$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52762__$1_shapes$jscomp$22$$,$APP.$cljs$cst$1614$shapes$$);if($APP.$cljs$core$truth_$$($p__52761_page_id$jscomp$47$$)){var $page$jscomp$26$$=$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$60$$,$p__52761_page_id$jscomp$47$$),
$xform$jscomp$28$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2045$main_instance$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1627$component_id$$)),$check_shape$$=function($all_parents_shape_id$jscomp$34$$,$others$jscomp$3$$){$all_parents_shape_id$jscomp$34$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$container$get_shape$$,
$page$jscomp$26$$),$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($others$jscomp$3$$,$APP.$app$common$files$helpers$get_parent_ids$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$26$$),$all_parents_shape_id$jscomp$34$$)));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$xform$jscomp$28$$,$all_parents_shape_id$jscomp$34$$)};return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__52759_SHARP_$$,
$p2__52760_SHARP_$$){return $APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($p1__52759_SHARP_$$,$check_shape$$($p2__52760_SHARP_$$,$APP.$cljs$core$PersistentVector$EMPTY$$))},$check_shape$$($parent_id$jscomp$30$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent_id$jscomp$30$$],null)),$map__52762__$1_shapes$jscomp$22$$)}return null});
$app$common$files$changes$components_changed$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2610$add_obj$$,function($file_data$jscomp$61_page$jscomp$27_parents$jscomp$4$$,$p__52770_parent_id$jscomp$31_xform$jscomp$29$$){var $map__52771__$1$$=$APP.$cljs$core$__destructure_map$$($p__52770_parent_id$jscomp$31_xform$jscomp$29$$);$p__52770_parent_id$jscomp$31_xform$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52771__$1$$,$APP.$cljs$cst$1619$parent_id$$);var $page_id$jscomp$48$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52771__$1$$,$APP.$cljs$cst$2043$page_id$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52771__$1$$,$cljs$cst$2668$_component_id$$);return $APP.$cljs$core$truth_$$($page_id$jscomp$48$$)?($file_data$jscomp$61_page$jscomp$27_parents$jscomp$4$$=$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$61_page$jscomp$27_parents$jscomp$4$$,$page_id$jscomp$48$$),$file_data$jscomp$61_page$jscomp$27_parents$jscomp$4$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$container$get_shape$$,
$file_data$jscomp$61_page$jscomp$27_parents$jscomp$4$$),$APP.$cljs$core$cons$$($p__52770_parent_id$jscomp$31_xform$jscomp$29$$,$APP.$app$common$files$helpers$get_parent_ids$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$61_page$jscomp$27_parents$jscomp$4$$),$p__52770_parent_id$jscomp$31_xform$jscomp$29$$))),$p__52770_parent_id$jscomp$31_xform$jscomp$29$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2045$main_instance$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1627$component_id$$)),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$p__52770_parent_id$jscomp$31_xform$jscomp$29$$,$file_data$jscomp$61_page$jscomp$27_parents$jscomp$4$$)):null});
$app$common$files$changes$components_changed$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2614$del_obj$$,function($file_data$jscomp$62_page$jscomp$28_shape_and_parents$jscomp$1$$,$id$jscomp$281_p__52772_xform$jscomp$30$$){var $map__52773__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$281_p__52772_xform$jscomp$30$$);$id$jscomp$281_p__52772_xform$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52773__$1$$,$APP.$cljs$cst$266$id$$);var $page_id$jscomp$49$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52773__$1$$,$APP.$cljs$cst$2043$page_id$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52773__$1$$,$cljs$cst$2668$_component_id$$);return $APP.$cljs$core$truth_$$($page_id$jscomp$49$$)?($file_data$jscomp$62_page$jscomp$28_shape_and_parents$jscomp$1$$=$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$62_page$jscomp$28_shape_and_parents$jscomp$1$$,$page_id$jscomp$49$$),$file_data$jscomp$62_page$jscomp$28_shape_and_parents$jscomp$1$$=
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$container$get_shape$$,$file_data$jscomp$62_page$jscomp$28_shape_and_parents$jscomp$1$$),$APP.$cljs$core$cons$$($id$jscomp$281_p__52772_xform$jscomp$30$$,$APP.$app$common$files$helpers$get_parent_ids$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$62_page$jscomp$28_shape_and_parents$jscomp$1$$),$id$jscomp$281_p__52772_xform$jscomp$30$$))),
$id$jscomp$281_p__52772_xform$jscomp$30$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2045$main_instance$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1627$component_id$$)),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$id$jscomp$281_p__52772_xform$jscomp$30$$,$file_data$jscomp$62_page$jscomp$28_shape_and_parents$jscomp$1$$)):null});
$app$common$files$changes$components_changed$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function(){return null});
var $app$common$files$changes$frames_changed$$=function(){var $method_table__5622__auto__$jscomp$17$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$17$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$17$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$17$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.common.files.changes",
"frames-changed"),function($_$jscomp$1583$$,$change$jscomp$15$$){return $APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$15$$)},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$17$$,$method_table__5622__auto__$jscomp$17$$,$prefer_table__5623__auto__$jscomp$17$$,$method_cache__5624__auto__$jscomp$17$$,$cached_hierarchy__5625__auto__$jscomp$17$$)}();
$app$common$files$changes$frames_changed$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2612$mod_obj$$,function($file_data$jscomp$63_page$jscomp$29$$,$id$jscomp$283_p__52775$$){var $map__52776__$1_operations$jscomp$7$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$283_p__52775$$);$id$jscomp$283_p__52775$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52776__$1_operations$jscomp$7$$,$APP.$cljs$cst$266$id$$);var $page_id$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52776__$1_operations$jscomp$7$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52776__$1_operations$jscomp$7$$,$cljs$cst$2668$_component_id$$);$map__52776__$1_operations$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52776__$1_operations$jscomp$7$$,$APP.$cljs$cst$2613$operations$$);return $APP.$cljs$core$truth_$$($page_id$jscomp$50$$)?($file_data$jscomp$63_page$jscomp$29$$=$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$63_page$jscomp$29$$,$page_id$jscomp$50$$),
$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($operation$jscomp$2$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($operation$jscomp$2$$),$APP.$cljs$cst$203$set$$)&&$APP.$cljs$core$contains_QMARK_$$($app$common$types$component$sync_attrs$$,$APP.$cljs$cst$2599$attr$$.$cljs$core$IFn$_invoke$arity$1$($operation$jscomp$2$$))},$map__52776__$1_operations$jscomp$7$$))?$app$common$files$changes$parents_frames$$($id$jscomp$283_p__52775$$,
$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$63_page$jscomp$29$$)):null):null});
$app$common$files$changes$frames_changed$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2616$mov_objects$$,function($file_data$jscomp$64$$,$p__52781_page_id$jscomp$51$$){var $map__52782__$1_shapes$jscomp$23$$=$APP.$cljs$core$__destructure_map$$($p__52781_page_id$jscomp$51$$);$p__52781_page_id$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52782__$1_shapes$jscomp$23$$,$APP.$cljs$cst$2043$page_id$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52782__$1_shapes$jscomp$23$$,
$cljs$cst$2668$_component_id$$);var $parent_id$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52782__$1_shapes$jscomp$23$$,$APP.$cljs$cst$1619$parent_id$$);$map__52782__$1_shapes$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52782__$1_shapes$jscomp$23$$,$APP.$cljs$cst$1614$shapes$$);if($APP.$cljs$core$truth_$$($p__52781_page_id$jscomp$51$$)){var $page$jscomp$30$$=$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$64$$,$p__52781_page_id$jscomp$51$$);
return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($app$common$files$changes$parents_frames$$($parent_id$jscomp$32$$,$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$30$$)),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__52780_SHARP_$$){return $app$common$files$changes$parents_frames$$($APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__52780_SHARP_$$),$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$30$$))},
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__52782__$1_shapes$jscomp$23$$])))}return null});
$app$common$files$changes$frames_changed$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2610$add_obj$$,function($file_data$jscomp$65_page$jscomp$31$$,$p__52791_parent_id$jscomp$33$$){var $map__52792__$1$$=$APP.$cljs$core$__destructure_map$$($p__52791_parent_id$jscomp$33$$);$p__52791_parent_id$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52792__$1$$,$APP.$cljs$cst$1619$parent_id$$);var $page_id$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52792__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52792__$1$$,$cljs$cst$2668$_component_id$$);return $APP.$cljs$core$truth_$$($page_id$jscomp$52$$)?($file_data$jscomp$65_page$jscomp$31$$=$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$65_page$jscomp$31$$,$page_id$jscomp$52$$),$app$common$files$changes$parents_frames$$($p__52791_parent_id$jscomp$33$$,$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$65_page$jscomp$31$$))):
null});
$app$common$files$changes$frames_changed$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2614$del_obj$$,function($file_data$jscomp$66_page$jscomp$32$$,$id$jscomp$284_p__52793$$){var $map__52794__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$284_p__52793$$);$id$jscomp$284_p__52793$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52794__$1$$,$APP.$cljs$cst$266$id$$);var $page_id$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52794__$1$$,$APP.$cljs$cst$2043$page_id$$);
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52794__$1$$,$cljs$cst$2668$_component_id$$);return $APP.$cljs$core$truth_$$($page_id$jscomp$53$$)?($file_data$jscomp$66_page$jscomp$32$$=$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$66_page$jscomp$32$$,$page_id$jscomp$53$$),$app$common$files$changes$parents_frames$$($id$jscomp$284_p__52793$$,$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$66_page$jscomp$32$$))):null});
$app$common$files$changes$frames_changed$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function(){return null});var $shadow$js$shim$module$0react_dom$0server$$=shadow$bridge("react-dom/server");var $app$main$data$render_wasm$context_lost_51723$$,$app$main$data$render_wasm$context_restored_51732$$;var $app$main$data$workspace$texts_v3$v3_update_text_editor_styles_51737$$;var $app$main$fonts$google_fonts$$,$app$main$fonts$local_fonts$$;$APP.$app$common$logging$loggers$$.set("app.main.fonts",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));
$app$main$fonts$google_fonts$$=$APP.$cljs$core$PersistentVector$fromArray$$([new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-abeezee",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7f863d42-3dc5-4d4b-8ed5-731fe3131d23",39539668),$APP.$cljs$cst$2675$family$$,"ABeeZee",$APP.$cljs$cst$725$name$$,"ABeeZee",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/abeezee/v23/esDR31xSG-6AGleN6tKukbcHCpE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/abeezee/v23/esDT31xSG-6AGleN2tCklZUCGpG-GQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-adlam-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d5f2c2db-30a7-4f2e-9dc2-a07b77ffb9d8",-972360647),$APP.$cljs$cst$2675$family$$,"ADLaM Display",$APP.$cljs$cst$725$name$$,"ADLaM Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adlamdisplay/v1/KFOhCnGXkPOLlhx6jD8_b1ZECsHYkYBPY3o.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ar-one-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0da3e2c1-5004-4d66-995e-16e52a82812e",653916061),$APP.$cljs$cst$2675$family$$,"AR One Sans",$APP.$cljs$cst$725$name$$,"AR One Sans",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aronesans/v6/TUZezwhrmbFp0Srr_tH6fv6RcUejHO_u7GF5aXfv-U2QzBLF6gslWn_9DW03no5mBF4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aronesans/v6/TUZezwhrmbFp0Srr_tH6fv6RcUejHO_u7GF5aXfv-U2QzBLF6gslWk39DW03no5mBF4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aronesans/v6/TUZezwhrmbFp0Srr_tH6fv6RcUejHO_u7GF5aXfv-U2QzBLF6gslWqH6DW03no5mBF4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aronesans/v6/TUZezwhrmbFp0Srr_tH6fv6RcUejHO_u7GF5aXfv-U2QzBLF6gslWpj6DW03no5mBF4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-abel",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7cc4721d-93c9-4fbc-ad1b-79ec6a9baa08",
1567222793),$APP.$cljs$cst$2675$family$$,"Abel",$APP.$cljs$cst$725$name$$,"Abel",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/abel/v18/MwQ5bhbm2POE6VhLPJp6qGI.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-abhaya-libre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5361d4c0-9a79-4dc5-b505-523169668a3a",-956705091),$APP.$cljs$cst$2675$family$$,"Abhaya Libre",$APP.$cljs$cst$725$name$$,"Abhaya Libre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/abhayalibre/v18/e3tmeuGtX-Co5MNzeAOqinEge0PWovdU4w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/abhayalibre/v18/e3t5euGtX-Co5MNzeAOqinEYj2ryqtxI6oYtBA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/abhayalibre/v18/e3t5euGtX-Co5MNzeAOqinEYo23yqtxI6oYtBA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/abhayalibre/v18/e3t5euGtX-Co5MNzeAOqinEYx2zyqtxI6oYtBA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/abhayalibre/v18/e3t5euGtX-Co5MNzeAOqinEY22_yqtxI6oYtBA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-aboreto",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8588b8f4-ff98-4106-88bd-90e621d59f9c",-452000579),
$APP.$cljs$cst$2675$family$$,"Aboreto",$APP.$cljs$cst$725$name$$,"Aboreto",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aboreto/v2/5DCXAKLhwDDQ4N8blKTeA2yuxSY.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-abril-fatface",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ce025127-c5c6-44b4-ae1e-58a981138d66",-1815096456),$APP.$cljs$cst$2675$family$$,"Abril Fatface",$APP.$cljs$cst$725$name$$,"Abril Fatface",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/abrilfatface/v25/zOL64pLDlL1D99S8g8PtiKchm-BsjOLhZBY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-abyssinica-sil",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("59a9c6e6-efcf-4b54-9a20-9e6440f58641",-375785584),$APP.$cljs$cst$2675$family$$,"Abyssinica SIL",$APP.$cljs$cst$725$name$$,"Abyssinica SIL",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/abyssinicasil/v9/oY1H8ezOqK7iI3rK_45WKoc8J6UZBFOVAXuI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-aclonica",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("943b30fd-6955-49a2-9dfa-be0692bf9305",1669331019),$APP.$cljs$cst$2675$family$$,"Aclonica",$APP.$cljs$cst$725$name$$,"Aclonica",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/aclonica/v25/K2FyfZJVlfNNSEBXGb7TCI6oBjLz.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-acme",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3fb84d30-d69a-470d-b7d7-528ade96a38e",861008970),$APP.$cljs$cst$2675$family$$,"Acme",$APP.$cljs$cst$725$name$$,"Acme",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/acme/v27/RrQfboBx-C5_bx3Lb23lzLk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-actor",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2d2d29cd-6098-4069-9726-bcca90ceb6e6",-894442066),$APP.$cljs$cst$2675$family$$,"Actor",$APP.$cljs$cst$725$name$$,"Actor",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/actor/v18/wEOzEBbCkc5cO3ekXygtUMIO.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-adamina",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("57a3311f-5214-494f-9ac1-e47c79349a3e",1054455376),$APP.$cljs$cst$2675$family$$,"Adamina",$APP.$cljs$cst$725$name$$,"Adamina",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/adamina/v22/j8_r6-DH1bjoc-dwu-reETl4Bno.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-advent-pro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6cd83cd0-eb77-4c0d-aaa1-06735c619c98",1105050961),$APP.$cljs$cst$2675$family$$,"Advent Pro",$APP.$cljs$cst$725$name$$,"Advent Pro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mqoQfxVT4Dvddr_yOwrzaFxV7JtdQgFqXdUAQrGp_zgX5sWCpLQyJPTJoonw1aBA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mqoQfxVT4Dvddr_yOwrzaFxV7JtdQgFqXdUAQrGp_zgX5sWCpLwyNPTJoonw1aBA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mqoQfxVT4Dvddr_yOwrzaFxV7JtdQgFqXdUAQrGp_zgX5sWCpLHSNPTJoonw1aBA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mqoQfxVT4Dvddr_yOwrzaFxV7JtdQgFqXdUAQrGp_zgX5sWCpLQyNPTJoonw1aBA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mqoQfxVT4Dvddr_yOwrzaFxV7JtdQgFqXdUAQrGp_zgX5sWCpLcSNPTJoonw1aBA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mqoQfxVT4Dvddr_yOwrzaFxV7JtdQgFqXdUAQrGp_zgX5sWCpLnSRPTJoonw1aBA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mqoQfxVT4Dvddr_yOwrzaFxV7JtdQgFqXdUAQrGp_zgX5sWCpLpCRPTJoonw1aBA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mqoQfxVT4Dvddr_yOwrzaFxV7JtdQgFqXdUAQrGp_zgX5sWCpLwyRPTJoonw1aBA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mqoQfxVT4Dvddr_yOwrzaFxV7JtdQgFqXdUAQrGp_zgX5sWCpL6iRPTJoonw1aBA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mkoQfxVT4Dvddr_yOwhT-3Jr6w5kKOEbAVEvZiKGAr6BX29i1ei2CnDpAsvQhKBH4C.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mkoQfxVT4Dvddr_yOwhT-3Jr6w5kKOEbAVEvZiKGAr6BX29i1ei2AnD5AsvQhKBH4C.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",
$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mkoQfxVT4Dvddr_yOwhT-3Jr6w5kKOEbAVEvZiKGAr6BX29i1ei2D5D5AsvQhKBH4C.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mkoQfxVT4Dvddr_yOwhT-3Jr6w5kKOEbAVEvZiKGAr6BX29i1ei2CnD5AsvQhKBH4C.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mkoQfxVT4Dvddr_yOwhT-3Jr6w5kKOEbAVEvZiKGAr6BX29i1ei2CVD5AsvQhKBH4C.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mkoQfxVT4Dvddr_yOwhT-3Jr6w5kKOEbAVEvZiKGAr6BX29i1ei2B5CJAsvQhKBH4C.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mkoQfxVT4Dvddr_yOwhT-3Jr6w5kKOEbAVEvZiKGAr6BX29i1ei2BACJAsvQhKBH4C.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mkoQfxVT4Dvddr_yOwhT-3Jr6w5kKOEbAVEvZiKGAr6BX29i1ei2AnCJAsvQhKBH4C.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,
"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/adventpro/v33/V8mkoQfxVT4Dvddr_yOwhT-3Jr6w5kKOEbAVEvZiKGAr6BX29i1ei2AOCJAsvQhKBH4C.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-afacad",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1fc53393-0214-4020-9233-082155ab0a01",645327147),$APP.$cljs$cst$2675$family$$,"Afacad",$APP.$cljs$cst$725$name$$,"Afacad",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacad/v3/6NUK8FKMIQOGaw6wjYT7ZHG_zsBBfhXtWmA08mCgdfM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacad/v3/6NUK8FKMIQOGaw6wjYT7ZHG_zsBBfiftWmA08mCgdfM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacad/v3/6NUK8FKMIQOGaw6wjYT7ZHG_zsBBfsvqWmA08mCgdfM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacad/v3/6NUK8FKMIQOGaw6wjYT7ZHG_zsBBfvLqWmA08mCgdfM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacad/v3/6NUI8FKMIQOGaw6ahLYEvBjUVG5Ga92usiM-9kKlZfNfuw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacad/v3/6NUI8FKMIQOGaw6ahLYEvBjUVG5Ga92ugCM-9kKlZfNfuw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacad/v3/6NUI8FKMIQOGaw6ahLYEvBjUVG5Ga92ubCQ-9kKlZfNfuw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacad/v3/6NUI8FKMIQOGaw6ahLYEvBjUVG5Ga92uVSQ-9kKlZfNfuw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-afacad-flux",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("35a3184c-33b8-4e66-b779-d96f9db3e577",-2060036324),$APP.$cljs$cst$2675$family$$,"Afacad Flux",$APP.$cljs$cst$725$name$$,"Afacad Flux",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacadflux/v4/9oRgNYYQryMlneUPykRmTuH4ET0fri4I5rJVT_CWHKDZnskVK5edsUwWZaRqQsJr67E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacadflux/v4/9oRgNYYQryMlneUPykRmTuH4ET0fri4I5rJVT_CWHKDZnskVK5edscwXZaRqQsJr67E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacadflux/v4/9oRgNYYQryMlneUPykRmTuH4ET0fri4I5rJVT_CWHKDZnskVK5edsRIXZaRqQsJr67E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacadflux/v4/9oRgNYYQryMlneUPykRmTuH4ET0fri4I5rJVT_CWHKDZnskVK5edsUwXZaRqQsJr67E.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacadflux/v4/9oRgNYYQryMlneUPykRmTuH4ET0fri4I5rJVT_CWHKDZnskVK5edsX4XZaRqQsJr67E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacadflux/v4/9oRgNYYQryMlneUPykRmTuH4ET0fri4I5rJVT_CWHKDZnskVK5edsZIQZaRqQsJr67E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacadflux/v4/9oRgNYYQryMlneUPykRmTuH4ET0fri4I5rJVT_CWHKDZnskVK5edsasQZaRqQsJr67E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacadflux/v4/9oRgNYYQryMlneUPykRmTuH4ET0fri4I5rJVT_CWHKDZnskVK5edscwQZaRqQsJr67E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/afacadflux/v4/9oRgNYYQryMlneUPykRmTuH4ET0fri4I5rJVT_CWHKDZnskVK5edseUQZaRqQsJr67E.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-agbalumo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fdbe80c5-a6c4-46a8-aba7-8dd584b96616",-911031706),$APP.$cljs$cst$2675$family$$,"Agbalumo",$APP.$cljs$cst$725$name$$,"Agbalumo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/agbalumo/v6/55xvey5uMdT2N37KZcMFirl08KDJ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-agdasima",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1e38a5c9-38ef-46d1-8ad3-0c5a27abd488",820683300),$APP.$cljs$cst$2675$family$$,"Agdasima",$APP.$cljs$cst$725$name$$,"Agdasima",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/agdasima/v5/PN_zRfyxp2f1fUCgAMg6rzjb_-Da.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/agdasima/v5/PN_0Rfyxp2f1fUCgAPCGgBzT1PzTz2Mi.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-agu-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3223b68f-3cf3-4c90-b204-846294a4a66c",243183945),$APP.$cljs$cst$2675$family$$,"Agu Display",$APP.$cljs$cst$725$name$$,"Agu Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/agudisplay/v3/iJWXBXKbbi6BeMC1_RX7qF_V5E7aciGRRWUwX4ftka9LM6y8Zg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-aguafina-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("da2ccb46-2cb0-4ed5-b1f4-1193b2ec3d9a",
-1784290223),$APP.$cljs$cst$2675$family$$,"Aguafina Script",$APP.$cljs$cst$725$name$$,"Aguafina Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aguafinascript/v24/If2QXTv_ZzSxGIO30LemWEOmt1bHqs4pgicOrg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-akatab",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("58de0f07-322a-4481-9691-6b008ebe3c9e",1478221480),$APP.$cljs$cst$2675$family$$,"Akatab",$APP.$cljs$cst$725$name$$,"Akatab",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/akatab/v9/VuJwdNrK3Z7gqJEPWIz5NIh-YA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/akatab/v9/VuJzdNrK3Z7gqJE3rKXdPKNiaRpFvg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/akatab/v9/VuJzdNrK3Z7gqJE3gKLdPKNiaRpFvg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/akatab/v9/VuJzdNrK3Z7gqJE35KPdPKNiaRpFvg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/akatab/v9/VuJzdNrK3Z7gqJE3-KDdPKNiaRpFvg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/akatab/v9/VuJzdNrK3Z7gqJE33KHdPKNiaRpFvg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-akaya-kanadaka",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d1a7f76f-2fd3-4fcd-bd61-8f1e1c6b736c",-52272133),$APP.$cljs$cst$2675$family$$,"Akaya Kanadaka",$APP.$cljs$cst$725$name$$,"Akaya Kanadaka",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/akayakanadaka/v18/N0bM2S5CPO5oOQqvazoRRb-8-PfRS5VBBSSF.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-akaya-telivigala",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f49188b3-8bf2-4939-b900-3f23bb6a228d",-1511063371),$APP.$cljs$cst$2675$family$$,"Akaya Telivigala",
$APP.$cljs$cst$725$name$$,"Akaya Telivigala",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/akayatelivigala/v28/lJwc-oo_iG9wXqU3rCTD395tp0uifdLdsIH0YH8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-akronim",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("782ca958-2f8c-47ed-bd32-23a2f68f2c5c",-939110704),$APP.$cljs$cst$2675$family$$,"Akronim",$APP.$cljs$cst$725$name$$,"Akronim",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/akronim/v23/fdN-9sqWtWZZlHRp-gBxkFYN-a8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-akshar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1d139af8-9d88-4afe-b2c1-ced9a7f64179",-311015279),$APP.$cljs$cst$2675$family$$,"Akshar",$APP.$cljs$cst$725$name$$,"Akshar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/akshar/v17/Yq6I-LyHWTfz9rGoqDaUbHvhkAUsSSgFy9CY94XsnPc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/akshar/v17/Yq6I-LyHWTfz9rGoqDaUbHvhkAUsSXYFy9CY94XsnPc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/akshar/v17/Yq6I-LyHWTfz9rGoqDaUbHvhkAUsSUQFy9CY94XsnPc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/akshar/v17/Yq6I-LyHWTfz9rGoqDaUbHvhkAUsSagCy9CY94XsnPc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/akshar/v17/Yq6I-LyHWTfz9rGoqDaUbHvhkAUsSZECy9CY94XsnPc.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-aladin",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6c940616-06a7-484b-bcc1-cd0a6f169a0c",-1703481197),$APP.$cljs$cst$2675$family$$,"Aladin",$APP.$cljs$cst$725$name$$,"Aladin",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aladin/v26/ZgNSjPJFPrvJV5f16Sf4pGT2Ng.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alan-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d81e264a-c18c-4790-8b4a-5f6552f487f1",-63969293),$APP.$cljs$cst$2675$family$$,"Alan Sans",$APP.$cljs$cst$725$name$$,"Alan Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alansans/v5/zOLt4pbDmq5Eu6ebjMSx4sywa339j__gfIHoxyB1jBwiRr0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alansans/v5/zOLt4pbDmq5Eu6ebjMSx4sywa339j__gfN_oxyB1jBwiRr0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alansans/v5/zOLt4pbDmq5Eu6ebjMSx4sywa339j__gfO3oxyB1jBwiRr0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alansans/v5/zOLt4pbDmq5Eu6ebjMSx4sywa339j__gfAHvxyB1jBwiRr0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alansans/v5/zOLt4pbDmq5Eu6ebjMSx4sywa339j__gfDjvxyB1jBwiRr0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alansans/v5/zOLt4pbDmq5Eu6ebjMSx4sywa339j__gfF_vxyB1jBwiRr0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/alansans/v5/zOLt4pbDmq5Eu6ebjMSx4sywa339j__gfHbvxyB1jBwiRr0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alata",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b43c6aa4-3bd0-4017-801e-5d1774148630",-1607455531),$APP.$cljs$cst$2675$family$$,"Alata",$APP.$cljs$cst$725$name$$,"Alata",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alata/v12/PbytFmztEwbIofe6xKcRQEOX.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alatsi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7501903d-ea53-4c1c-b511-240c7789745a",-722264052),$APP.$cljs$cst$2675$family$$,"Alatsi",$APP.$cljs$cst$725$name$$,
"Alatsi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alatsi/v14/TK3iWkUJAxQ2nLNGHjUHte5fKg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-albert-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e22e8c9f-a40b-46ef-89c3-7a32ebfdbfcc",1381386942),$APP.$cljs$cst$2675$family$$,"Albert Sans",$APP.$cljs$cst$725$name$$,"Albert Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dZIFdwYjGaAMFtZd_QA3xXSKZqhr-TenSHq5L_rI32TxAj1g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dZIFdwYjGaAMFtZd_QA3xXSKZqhr-TenSHK5P_rI32TxAj1g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dZIFdwYjGaAMFtZd_QA3xXSKZqhr-TenSH9ZP_rI32TxAj1g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dZIFdwYjGaAMFtZd_QA3xXSKZqhr-TenSHq5P_rI32TxAj1g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dZIFdwYjGaAMFtZd_QA3xXSKZqhr-TenSHmZP_rI32TxAj1g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dZIFdwYjGaAMFtZd_QA3xXSKZqhr-TenSHdZT_rI32TxAj1g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dZIFdwYjGaAMFtZd_QA3xXSKZqhr-TenSHTJT_rI32TxAj1g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dZIFdwYjGaAMFtZd_QA3xXSKZqhr-TenSHK5T_rI32TxAj1g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dZIFdwYjGaAMFtZd_QA3xXSKZqhr-TenSHApT_rI32TxAj1g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dfIFdwYjGaAMFtZd_QA1Zeelmy79QJ1HOSY9AX7ofybRUz1r5t.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dfIFdwYjGaAMFtZd_QA1Zeelmy79QJ1HOSY9CX74fybRUz1r5t.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dfIFdwYjGaAMFtZd_QA1Zeelmy79QJ1HOSY9BJ74fybRUz1r5t.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dfIFdwYjGaAMFtZd_QA1Zeelmy79QJ1HOSY9AX74fybRUz1r5t.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/albertsans/v4/i7dfIFdwYjGaAMFtZd_QA1Zeelmy79QJ1HOSY9Al74fybRUz1r5t.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dfIFdwYjGaAMFtZd_QA1Zeelmy79QJ1HOSY9DJ6IfybRUz1r5t.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dfIFdwYjGaAMFtZd_QA1Zeelmy79QJ1HOSY9Dw6IfybRUz1r5t.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dfIFdwYjGaAMFtZd_QA1Zeelmy79QJ1HOSY9CX6IfybRUz1r5t.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/albertsans/v4/i7dfIFdwYjGaAMFtZd_QA1Zeelmy79QJ1HOSY9C-6IfybRUz1r5t.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-aldrich",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a0afdb4a-c4f6-418b-b202-0a71d0882288",
120986126),$APP.$cljs$cst$2675$family$$,"Aldrich",$APP.$cljs$cst$725$name$$,"Aldrich",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aldrich/v22/MCoTzAn-1s3IGyJMZaAS3pP5H_E.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alef",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("52d93070-124b-4e8c-996d-26a0872a1492",-1257846926),$APP.$cljs$cst$2675$family$$,"Alef",$APP.$cljs$cst$725$name$$,"Alef",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alef/v24/FeVfS0NQpLYgrjJbC5FxxbU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alef/v24/FeVQS0NQpLYglo50L5la2bxii28.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-alegreya",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5550d88c-2180-44b4-8b4e-a13180ac81de",-1132269501),$APP.$cljs$cst$2675$family$$,"Alegreya",$APP.$cljs$cst$725$name$$,"Alegreya",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreya/v39/4UacrEBBsBhlBjvfkQjt71kZfyBzPgNG9hUI_KCisSGVrw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreya/v39/4UacrEBBsBhlBjvfkQjt71kZfyBzPgNGxBUI_KCisSGVrw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreya/v39/4UacrEBBsBhlBjvfkQjt71kZfyBzPgNGKBII_KCisSGVrw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreya/v39/4UacrEBBsBhlBjvfkQjt71kZfyBzPgNGERII_KCisSGVrw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreya/v39/4UacrEBBsBhlBjvfkQjt71kZfyBzPgNGdhII_KCisSGVrw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/alegreya/v39/4UacrEBBsBhlBjvfkQjt71kZfyBzPgNGXxII_KCisSGVrw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreya/v39/4UaSrEBBsBhlBjvfkSLk3abBFkvpkARTPlbgv6qmkySFr9V9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",
$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreya/v39/4UaSrEBBsBhlBjvfkSLk3abBFkvpkARTPlbSv6qmkySFr9V9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreya/v39/4UaSrEBBsBhlBjvfkSLk3abBFkvpkARTPlY-uKqmkySFr9V9.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreya/v39/4UaSrEBBsBhlBjvfkSLk3abBFkvpkARTPlYHuKqmkySFr9V9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreya/v39/4UaSrEBBsBhlBjvfkSLk3abBFkvpkARTPlZguKqmkySFr9V9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreya/v39/4UaSrEBBsBhlBjvfkSLk3abBFkvpkARTPlZJuKqmkySFr9V9.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-alegreya-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e7a0116a-32a1-4061-bb32-e9d3847779bf",-1271899334),$APP.$cljs$cst$2675$family$$,"Alegreya SC",$APP.$cljs$cst$725$name$$,"Alegreya SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasc/v26/taiOGmRtCJ62-O0HhNEa-a6o05E5abe_.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasc/v26/taiMGmRtCJ62-O0HhNEa-Z6q2ZUbbKe_DGs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasc/v26/taiTGmRtCJ62-O0HhNEa-ZZc-rUxQqu2FXKD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasc/v26/taiRGmRtCJ62-O0HhNEa-Z6q4WEySK-UEGKDBz4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasc/v26/taiTGmRtCJ62-O0HhNEa-ZYU_LUxQqu2FXKD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasc/v26/taiRGmRtCJ62-O0HhNEa-Z6q4Sk0SK-UEGKDBz4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasc/v26/taiTGmRtCJ62-O0HhNEa-ZYI_7UxQqu2FXKD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",
$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasc/v26/taiRGmRtCJ62-O0HhNEa-Z6q4TU3SK-UEGKDBz4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasc/v26/taiTGmRtCJ62-O0HhNEa-ZYs_rUxQqu2FXKD.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasc/v26/taiRGmRtCJ62-O0HhNEa-Z6q4RE2SK-UEGKDBz4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alegreya-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6a678abc-754b-4668-87f9-38b4c6bb946c",
-1151213113),$APP.$cljs$cst$2675$family$$,"Alegreya Sans",$APP.$cljs$cst$725$name$$,"Alegreya Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasans/v26/5aUt9_-1phKLFgshYDvh6Vwt5TltuGdShm5bsg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasans/v26/5aUv9_-1phKLFgshYDvh6Vwt7V9V3G1WpGtLsgu7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasans/v26/5aUu9_-1phKLFgshYDvh6Vwt5fFPmE18imdCqxI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasans/v26/5aUo9_-1phKLFgshYDvh6Vwt7V9VFE92jkVHuxKiBA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasans/v26/5aUz9_-1phKLFgshYDvh6Vwt3V1nvEVXlm4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasans/v26/5aUt9_-1phKLFgshYDvh6Vwt7V9tuGdShm5bsg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasans/v26/5aUu9_-1phKLFgshYDvh6Vwt5alOmE18imdCqxI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasans/v26/5aUo9_-1phKLFgshYDvh6Vwt7V9VTE52jkVHuxKiBA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasans/v26/5aUu9_-1phKLFgshYDvh6Vwt5eFImE18imdCqxI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasans/v26/5aUo9_-1phKLFgshYDvh6Vwt7V9VBEh2jkVHuxKiBA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasans/v26/5aUu9_-1phKLFgshYDvh6Vwt5f1LmE18imdCqxI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasans/v26/5aUo9_-1phKLFgshYDvh6Vwt7V9VGEt2jkVHuxKiBA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasans/v26/5aUu9_-1phKLFgshYDvh6Vwt5dlKmE18imdCqxI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasans/v26/5aUo9_-1phKLFgshYDvh6Vwt7V9VPEp2jkVHuxKiBA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-alegreya-sans-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("05090b9c-49c1-4e5b-8bb3-4cc2be435ffc",560159528),$APP.$cljs$cst$2675$family$$,"Alegreya Sans SC",$APP.$cljs$cst$725$name$$,"Alegreya Sans SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasanssc/v24/mtGn4-RGJqfMvt7P8FUr0Q1j-Hf1Dipl8g5FPYtmMg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasanssc/v24/mtGl4-RGJqfMvt7P8FUr0Q1j-Hf1BkxdlgRBH452Mvds.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasanssc/v24/mtGm4-RGJqfMvt7P8FUr0Q1j-Hf1DuJH0iRrMYJ_K-4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasanssc/v24/mtGk4-RGJqfMvt7P8FUr0Q1j-Hf1BkxdXiZhNaB6O-51OA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasanssc/v24/mtGh4-RGJqfMvt7P8FUr0Q1j-Hf1Nk5v9ixALYs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasanssc/v24/mtGn4-RGJqfMvt7P8FUr0Q1j-Hf1Bkxl8g5FPYtmMg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasanssc/v24/mtGm4-RGJqfMvt7P8FUr0Q1j-Hf1DrpG0iRrMYJ_K-4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasanssc/v24/mtGk4-RGJqfMvt7P8FUr0Q1j-Hf1BkxdBidhNaB6O-51OA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasanssc/v24/mtGm4-RGJqfMvt7P8FUr0Q1j-Hf1DvJA0iRrMYJ_K-4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasanssc/v24/mtGk4-RGJqfMvt7P8FUr0Q1j-Hf1BkxdTiFhNaB6O-51OA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasanssc/v24/mtGm4-RGJqfMvt7P8FUr0Q1j-Hf1Du5D0iRrMYJ_K-4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasanssc/v24/mtGk4-RGJqfMvt7P8FUr0Q1j-Hf1BkxdUiJhNaB6O-51OA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasanssc/v24/mtGm4-RGJqfMvt7P8FUr0Q1j-Hf1DspC0iRrMYJ_K-4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alegreyasanssc/v24/mtGk4-RGJqfMvt7P8FUr0Q1j-Hf1BkxddiNhNaB6O-51OA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-aleo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e174bcb2-04e5-40aa-be0c-294e23e0a584",-2054555659),$APP.$cljs$cst$2675$family$$,"Aleo",$APP.$cljs$cst$725$name$$,"Aleo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m61nF8G8_s6gHhIOX0IYBo_KJ3G2P9HI4qCBtJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m61nF8G8_s6gHhIOX0IYBo_KL3GmP9HI4qCBtJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m61nF8G8_s6gHhIOX0IYBo_KIpGmP9HI4qCBtJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m61nF8G8_s6gHhIOX0IYBo_KJ3GmP9HI4qCBtJ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m61nF8G8_s6gHhIOX0IYBo_KJFGmP9HI4qCBtJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/aleo/v16/c4m61nF8G8_s6gHhIOX0IYBo_KKpHWP9HI4qCBtJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m61nF8G8_s6gHhIOX0IYBo_KKQHWP9HI4qCBtJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",
$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m61nF8G8_s6gHhIOX0IYBo_KL3HWP9HI4qCBtJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m61nF8G8_s6gHhIOX0IYBo_KLeHWP9HI4qCBtJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m81nF8G8_swAjT3z2dShrG-7e_WYu_FooIDQtJbok.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m81nF8G8_swAjT3z2dShrG-7e_WQu-FooIDQtJbok.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m81nF8G8_swAjT3z2dShrG-7e_WdW-FooIDQtJbok.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m81nF8G8_swAjT3z2dShrG-7e_WYu-FooIDQtJbok.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m81nF8G8_swAjT3z2dShrG-7e_Wbm-FooIDQtJbok.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m81nF8G8_swAjT3z2dShrG-7e_WVW5FooIDQtJbok.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m81nF8G8_swAjT3z2dShrG-7e_WWy5FooIDQtJbok.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m81nF8G8_swAjT3z2dShrG-7e_WQu5FooIDQtJbok.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aleo/v16/c4m81nF8G8_swAjT3z2dShrG-7e_WSK5FooIDQtJbok.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alex-brush",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("82d4289a-1f30-4768-bb8e-170938bf30e3",607817555),$APP.$cljs$cst$2675$family$$,"Alex Brush",$APP.$cljs$cst$725$name$$,"Alex Brush",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alexbrush/v23/SZc83FzrJKuqFbwMKk6EtUL57DtOmCc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alexandria",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("490658a5-24f6-4c6c-9445-0c05a241d43e",1623261584),$APP.$cljs$cst$2675$family$$,
"Alexandria",$APP.$cljs$cst$725$name$$,"Alexandria",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alexandria/v6/UMBCrPdDqW66y0Y2usFeQCH18mulUxBvI9r7T6bHHJ8BRq0b.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alexandria/v6/UMBCrPdDqW66y0Y2usFeQCH18mulUxBvI9p7TqbHHJ8BRq0b.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alexandria/v6/UMBCrPdDqW66y0Y2usFeQCH18mulUxBvI9qlTqbHHJ8BRq0b.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alexandria/v6/UMBCrPdDqW66y0Y2usFeQCH18mulUxBvI9r7TqbHHJ8BRq0b.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alexandria/v6/UMBCrPdDqW66y0Y2usFeQCH18mulUxBvI9rJTqbHHJ8BRq0b.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alexandria/v6/UMBCrPdDqW66y0Y2usFeQCH18mulUxBvI9olSabHHJ8BRq0b.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alexandria/v6/UMBCrPdDqW66y0Y2usFeQCH18mulUxBvI9ocSabHHJ8BRq0b.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alexandria/v6/UMBCrPdDqW66y0Y2usFeQCH18mulUxBvI9p7SabHHJ8BRq0b.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alexandria/v6/UMBCrPdDqW66y0Y2usFeQCH18mulUxBvI9pSSabHHJ8BRq0b.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alfa-slab-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e7df930a-72e0-4d1c-9110-40b247f2faa5",
767794619),$APP.$cljs$cst$2675$family$$,"Alfa Slab One",$APP.$cljs$cst$725$name$$,"Alfa Slab One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alfaslabone/v21/6NUQ8FmMKwSEKjnm5-4v-4Jh6dVretWvYmE.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alice",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b1eba8f3-3257-4eaf-ad99-c6fcf1600d86",-1568087610),$APP.$cljs$cst$2675$family$$,"Alice",$APP.$cljs$cst$725$name$$,"Alice",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alice/v21/OpNCnoEEmtHa6FcJpA_chzJ0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alike",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8563d1b7-be04-40bb-8c53-5ca2d589513b",854592491),$APP.$cljs$cst$2675$family$$,"Alike",$APP.$cljs$cst$725$name$$,"Alike",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alike/v22/HI_EiYEYI6BIoEjBSZXAQ4-d.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alike-angular",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ad5960fa-8b4d-4716-b509-a74539311f5a",
271762262),$APP.$cljs$cst$2675$family$$,"Alike Angular",$APP.$cljs$cst$725$name$$,"Alike Angular",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alikeangular/v27/3qTrojWunjGQtEBlIcwMbSoI3kM6bB7FKjE.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alkalami",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("33226f16-2e63-4402-bc99-97206e5c75e5",274858467),$APP.$cljs$cst$2675$family$$,"Alkalami",$APP.$cljs$cst$725$name$$,"Alkalami",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alkalami/v8/zOL_4pfDmqRL95WXi5eLw8BMuvhH.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alkatra",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("65064433-a955-48aa-a18e-b7bdd1c8e7d1",-388677667),$APP.$cljs$cst$2675$family$$,"Alkatra",$APP.$cljs$cst$725$name$$,"Alkatra",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alkatra/v5/r05EGLZA5qhCYsyJbuChFuK48Medzngmu7cPrNDVemxE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alkatra/v5/r05EGLZA5qhCYsyJbuChFuK48MedzngUu7cPrNDVemxE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alkatra/v5/r05EGLZA5qhCYsyJbuChFuK48Medznj4vLcPrNDVemxE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alkatra/v5/r05EGLZA5qhCYsyJbuChFuK48MedznjBvLcPrNDVemxE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-allan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ff31daa5-0dd0-4d0d-bde5-a8f51f2e1983",1678389870),$APP.$cljs$cst$2675$family$$,"Allan",$APP.$cljs$cst$725$name$$,
"Allan",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/allan/v26/ea8XadU7WuTxEtb2P9SF8nZE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",
$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/allan/v26/ea8aadU7WuTxEu5KEPCN2WpNgEKU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-allerta",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4f98bc2b-b4ec-48ca-9df0-4d6f980b7e72",87659967),$APP.$cljs$cst$2675$family$$,"Allerta",$APP.$cljs$cst$725$name$$,"Allerta",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/allerta/v19/TwMO-IAHRlkbx940UnEdSQqO5uY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-allerta-stencil",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("23725987-412e-44af-b6b2-e13cf4982d9a",1773703640),$APP.$cljs$cst$2675$family$$,"Allerta Stencil",$APP.$cljs$cst$725$name$$,"Allerta Stencil",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/allertastencil/v24/HTx0L209KT-LmIE9N7OR6eiycOeF-zz313DuvQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-allison",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9243b979-3997-4aa9-b734-e471a514d0e6",1573335148),$APP.$cljs$cst$2675$family$$,"Allison",$APP.$cljs$cst$725$name$$,"Allison",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/allison/v13/X7nl4b88AP2nkbvZOCaQ4MTgAgk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-allura",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("84a19dd1-f189-4717-8afb-19cf2ad0d0e0",-1679750435),$APP.$cljs$cst$2675$family$$,"Allura",$APP.$cljs$cst$725$name$$,
"Allura",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/allura/v23/9oRPNYsQpS4zjuAPjAIXPtrrGA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-almarai",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("08ca1d70-e0bd-481b-a9a5-9c2b75e5bccb",-523276247),$APP.$cljs$cst$2675$family$$,"Almarai",$APP.$cljs$cst$725$name$$,"Almarai",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/almarai/v19/tssoApxBaigK_hnnS_anhnicoq72sXg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/almarai/v19/tsstApxBaigK_hnnc1qPonC3vqc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/almarai/v19/tssoApxBaigK_hnnS-aghnicoq72sXg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/almarai/v19/tssoApxBaigK_hnnS_qjhnicoq72sXg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-almendra",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("28b1741b-3622-4176-b00b-9c84d9013d70",-1088556845),$APP.$cljs$cst$2675$family$$,"Almendra",$APP.$cljs$cst$725$name$$,"Almendra",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/almendra/v28/H4ckBXKAlMnTn0CskyY6wr-wg763.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/almendra/v28/H4ciBXKAlMnTn0CskxY4yLuShq63czE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/almendra/v28/H4cjBXKAlMnTn0Cskx6G7Zu4qKK-aihq.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/almendra/v28/H4chBXKAlMnTn0CskxY48Ae9oqacbzhqDtg.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-almendra-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d0cd1315-01c6-4474-b80f-c74effda5ba4",-2043541670),$APP.$cljs$cst$2675$family$$,"Almendra Display",$APP.$cljs$cst$725$name$$,"Almendra Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/almendradisplay/v33/0FlPVOGWl1Sb4O3tETtADHRRlZhzXS_eTyer338.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-almendra-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("257cb2be-d958-43f9-9ff7-351fa7306a22",-955976516),$APP.$cljs$cst$2675$family$$,"Almendra SC",$APP.$cljs$cst$725$name$$,"Almendra SC",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/almendrasc/v31/Iure6Yx284eebowr7hbyTZZJprVA4XQ0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-alumni-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("60299b7b-cc1c-4472-acda-bd7bbeccbfc9",-466185621),$APP.$cljs$cst$2675$family$$,"Alumni Sans",$APP.$cljs$cst$725$name$$,"Alumni Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpHtKqkOwdO2aOIwhWudEWpx_zq_Xna-Xd9OO5QqFsJ3C8qng.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpHtKqkOwdO2aOIwhWudEWpx_zq_Xna-Xd9uO9QqFsJ3C8qng.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpHtKqkOwdO2aOIwhWudEWpx_zq_Xna-Xd9Zu9QqFsJ3C8qng.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpHtKqkOwdO2aOIwhWudEWpx_zq_Xna-Xd9OO9QqFsJ3C8qng.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpHtKqkOwdO2aOIwhWudEWpx_zq_Xna-Xd9Cu9QqFsJ3C8qng.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpHtKqkOwdO2aOIwhWudEWpx_zq_Xna-Xd95uhQqFsJ3C8qng.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpHtKqkOwdO2aOIwhWudEWpx_zq_Xna-Xd93-hQqFsJ3C8qng.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpHtKqkOwdO2aOIwhWudEWpx_zq_Xna-Xd9uOhQqFsJ3C8qng.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpHtKqkOwdO2aOIwhWudEWpx_zq_Xna-Xd9kehQqFsJ3C8qng.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpBtKqkOwdO2aOIwhWudG-g9QMylBJAV3Bo8Ky46lEN_io6npfB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpBtKqkOwdO2aOIwhWudG-g9QMylBJAV3Bo8Kw461EN_io6npfB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpBtKqkOwdO2aOIwhWudG-g9QMylBJAV3Bo8Kzm61EN_io6npfB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpBtKqkOwdO2aOIwhWudG-g9QMylBJAV3Bo8Ky461EN_io6npfB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/alumnisans/v20/nwpBtKqkOwdO2aOIwhWudG-g9QMylBJAV3Bo8KyK61EN_io6npfB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpBtKqkOwdO2aOIwhWudG-g9QMylBJAV3Bo8Kxm7FEN_io6npfB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpBtKqkOwdO2aOIwhWudG-g9QMylBJAV3Bo8Kxf7FEN_io6npfB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpBtKqkOwdO2aOIwhWudG-g9QMylBJAV3Bo8Kw47FEN_io6npfB.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisans/v20/nwpBtKqkOwdO2aOIwhWudG-g9QMylBJAV3Bo8KwR7FEN_io6npfB.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alumni-sans-collegiate-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c3053c27-8e21-4115-b0c9-1dc183cb6a9e",
1829161495),$APP.$cljs$cst$2675$family$$,"Alumni Sans Collegiate One",$APP.$cljs$cst$725$name$$,"Alumni Sans Collegiate One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanscollegiateone/v7/MQpB-XChK8G5CtmK_AuGxQrdNvPSXkn0RM-XqjWWhjdayDiPw2ta.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanscollegiateone/v7/MQpD-XChK8G5CtmK_AuGxQrdNvPSXkn0RM-XqjWWhgdYwjytxntaDFU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alumni-sans-inline-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d9f35458-218f-4439-ba54-dd273d27d3f6",
893370327),$APP.$cljs$cst$2675$family$$,"Alumni Sans Inline One",$APP.$cljs$cst$725$name$$,"Alumni Sans Inline One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisansinlineone/v7/RrQBbpJx9zZ3IXTBOASKp5gJAetBdaihcjbpD3AZcr7xbYw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisansinlineone/v7/RrQDbpJx9zZ3IXTBOASKp5gJAetBdaihcjbpP3ITdpz0fYxcrQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alumni-sans-pinstripe",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4ad479d4-7204-4f41-8c0a-9d97bc239e79",
1923544102),$APP.$cljs$cst$2675$family$$,"Alumni Sans Pinstripe",$APP.$cljs$cst$725$name$$,"Alumni Sans Pinstripe",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanspinstripe/v8/ZgNNjOFFPq_AUJD1umyS30W-Xub8zD1ObhezYrVIpcDA5w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanspinstripe/v8/ZgNDjOFFPq_AUJD1umyS30W-Xub8zD1ObheDYL9Mh8XQ5_cY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-alumni-sans-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d4e9d39c-58c3-426e-bed4-be0bf6a1ff1a",
-1023937218),$APP.$cljs$cst$2675$family$$,"Alumni Sans SC",$APP.$cljs$cst$725$name$$,"Alumni Sans SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GfYaxzVjArrOeNFYbCvkZ8C28IyGwp26UHdIteaLxWgMKfbBlLNQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GfYaxzVjArrOeNFYbCvkZ8C28IyGwp26UHdIte6L1WgMKfbBlLNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GfYaxzVjArrOeNFYbCvkZ8C28IyGwp26UHdIteNr1WgMKfbBlLNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GfYaxzVjArrOeNFYbCvkZ8C28IyGwp26UHdIteaL1WgMKfbBlLNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GfYaxzVjArrOeNFYbCvkZ8C28IyGwp26UHdIteWr1WgMKfbBlLNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GfYaxzVjArrOeNFYbCvkZ8C28IyGwp26UHdItetrpWgMKfbBlLNQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GfYaxzVjArrOeNFYbCvkZ8C28IyGwp26UHdItej7pWgMKfbBlLNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GfYaxzVjArrOeNFYbCvkZ8C28IyGwp26UHdIte6LpWgMKfbBlLNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GfYaxzVjArrOeNFYbCvkZ8C28IyGwp26UHdItewbpWgMKfbBlLNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GdYaxzVjArrOeNFYbCvkZ8C0UB-pPxss6d2oxLoP6-wsibThxbNRJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GdYaxzVjArrOeNFYbCvkZ8C0UB-pPxss6d2oxLoP4-w8ibThxbNRJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GdYaxzVjArrOeNFYbCvkZ8C0UB-pPxss6d2oxLoP7gw8ibThxbNRJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GdYaxzVjArrOeNFYbCvkZ8C0UB-pPxss6d2oxLoP6-w8ibThxbNRJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GdYaxzVjArrOeNFYbCvkZ8C0UB-pPxss6d2oxLoP6Mw8ibThxbNRJQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GdYaxzVjArrOeNFYbCvkZ8C0UB-pPxss6d2oxLoP5gxMibThxbNRJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GdYaxzVjArrOeNFYbCvkZ8C0UB-pPxss6d2oxLoP5ZxMibThxbNRJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GdYaxzVjArrOeNFYbCvkZ8C0UB-pPxss6d2oxLoP4-xMibThxbNRJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/alumnisanssc/v3/Y4GdYaxzVjArrOeNFYbCvkZ8C0UB-pPxss6d2oxLoP4XxMibThxbNRJQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-amarante",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7abcbc41-1fc0-4824-ab5b-50f394b44a6a",473225353),$APP.$cljs$cst$2675$family$$,
"Amarante",$APP.$cljs$cst$725$name$$,"Amarante",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amarante/v30/xMQXuF1KTa6EvGx9bq-3C3rAmD-b.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-amaranth",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7968621b-c93f-496f-92b7-04d86d52e44b",-1205415726),$APP.$cljs$cst$2675$family$$,"Amaranth",$APP.$cljs$cst$725$name$$,"Amaranth",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amaranth/v19/KtkuALODe433f0j1zPnCF9GqwnzW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amaranth/v19/KtkoALODe433f0j1zMnAHdWIx2zWD4I.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amaranth/v19/KtkpALODe433f0j1zMF-OPWi6WDfFpuc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amaranth/v19/KtkrALODe433f0j1zMnAJWmn42T9E4ucRY8.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-amatic-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a5583ecd-ddd0-4d27-bf3b-60c5babf2f06",-1640377570),$APP.$cljs$cst$2675$family$$,"Amatic SC",$APP.$cljs$cst$725$name$$,"Amatic SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amaticsc/v28/TUZyzwprpvBS1izr_vO0De6ecZQf1A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amaticsc/v28/TUZ3zwprpvBS1izr_vOMscG6eb8D3WTy-A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-amethysta",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6b85d524-c59e-4dfa-89d9-f88bce1146f5",-1943571079),$APP.$cljs$cst$2675$family$$,"Amethysta",$APP.$cljs$cst$725$name$$,"Amethysta",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amethysta/v17/rP2Fp2K15kgb_F3ibfWIGDWCBl0O8Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-amiko",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("44979f05-2b07-4d9f-aa52-d7b8f4b50886",388730569),$APP.$cljs$cst$2675$family$$,"Amiko",$APP.$cljs$cst$725$name$$,"Amiko",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amiko/v15/WwkQxPq1DFK04tqlc17MMZgJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amiko/v15/WwkdxPq1DFK04uJ9XXrEGoQAUco5.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amiko/v15/WwkdxPq1DFK04uIZXHrEGoQAUco5.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-amiri",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bb01cd39-fc1c-43a2-bbd9-7cc5f7e69848",816411827),$APP.$cljs$cst$2675$family$$,
"Amiri",$APP.$cljs$cst$725$name$$,"Amiri",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amiri/v30/J7aRnpd8CGxBHqUpvrIw74NL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amiri/v30/J7afnpd8CGxBHpUrtLYS6pNLAjk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amiri/v30/J7acnpd8CGxBHp2VkZY4xJ9CGyAa.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amiri/v30/J7aanpd8CGxBHpUrjAo9zptgHjAavCA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-amiri-quran",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0111ba8f-a2aa-47c3-b24d-a6e8b74b5807",1987362761),
$APP.$cljs$cst$2675$family$$,"Amiri Quran",$APP.$cljs$cst$725$name$$,"Amiri Quran",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amiriquran/v19/_Xmo-Hk0rD6DbUL4_vH8Zq5t7Cycsu-2.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-amita",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("434732bb-a807-4f8f-b99f-14d862faf184",-1740135560),$APP.$cljs$cst$2675$family$$,"Amita",$APP.$cljs$cst$725$name$$,"Amita",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amita/v20/HhyaU5si9Om7PQlvAfSKEZZL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/amita/v20/HhyXU5si9Om7PTHTLtCCOopCTKkI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-anaheim",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("06f8d03d-6a8e-4d8d-90d7-5c338eba406f",-1087586719),$APP.$cljs$cst$2675$family$$,"Anaheim",$APP.$cljs$cst$725$name$$,"Anaheim",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anaheim/v17/8vIX7w042Wp87g4Gy0_24JbCiPrl-h5sLqrFIkJQb7zU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anaheim/v17/8vIX7w042Wp87g4Gy0_24JbCiPrl-h5eLqrFIkJQb7zU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anaheim/v17/8vIX7w042Wp87g4Gy0_24JbCiPrl-h6yKarFIkJQb7zU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anaheim/v17/8vIX7w042Wp87g4Gy0_24JbCiPrl-h6LKarFIkJQb7zU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anaheim/v17/8vIX7w042Wp87g4Gy0_24JbCiPrl-h7sKarFIkJQb7zU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ancizar-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7f836f6f-7fd0-4445-b285-7815fd9763c6",
-703595936),$APP.$cljs$cst$2675$family$$,"Ancizar Sans",$APP.$cljs$cst$725$name$$,"Ancizar Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC1zPYtHY2vX3wj8IbE7PxeWXCAxfsUebXFMyzipBpIu30AZbUY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC1zPYtHY2vX3wj8IbE7PxeWXCAxfsUebXFMy7ioBpIu30AZbUY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC1zPYtHY2vX3wj8IbE7PxeWXCAxfsUebXFMy2aoBpIu30AZbUY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC1zPYtHY2vX3wj8IbE7PxeWXCAxfsUebXFMyzioBpIu30AZbUY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC1zPYtHY2vX3wj8IbE7PxeWXCAxfsUebXFMywqoBpIu30AZbUY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC1zPYtHY2vX3wj8IbE7PxeWXCAxfsUebXFMy-avBpIu30AZbUY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC1zPYtHY2vX3wj8IbE7PxeWXCAxfsUebXFMy9-vBpIu30AZbUY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC1zPYtHY2vX3wj8IbE7PxeWXCAxfsUebXFMy7ivBpIu30AZbUY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC1zPYtHY2vX3wj8IbE7PxeWXCAxfsUebXFMy5GvBpIu30AZbUY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC11PYtHY2vX3wj8IbE7Pxe8VRLOpqx1999L3vDr7tAk22IcfUZgBQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC11PYtHY2vX3wj8IbE7Pxe8VRLOpqx1999L3vDrbtEk22IcfUZgBQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC11PYtHY2vX3wj8IbE7Pxe8VRLOpqx1999L3vDrsNEk22IcfUZgBQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC11PYtHY2vX3wj8IbE7Pxe8VRLOpqx1999L3vDr7tEk22IcfUZgBQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC11PYtHY2vX3wj8IbE7Pxe8VRLOpqx1999L3vDr3NEk22IcfUZgBQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC11PYtHY2vX3wj8IbE7Pxe8VRLOpqx1999L3vDrMNYk22IcfUZgBQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ancizarsans/v8/fC11PYtHY2vX3wj8IbE7Pxe8VRLOpqx1999L3vDrCdYk22IcfUZgBQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC11PYtHY2vX3wj8IbE7Pxe8VRLOpqx1999L3vDrbtYk22IcfUZgBQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarsans/v8/fC11PYtHY2vX3wj8IbE7Pxe8VRLOpqx1999L3vDrR9Yk22IcfUZgBQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ancizar-serif",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ef86e10b-f0ab-4ec4-b4bd-d0f73b73739a",-1445194265),$APP.$cljs$cst$2675$family$$,"Ancizar Serif",
$APP.$cljs$cst$725$name$$,"Ancizar Serif",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarserif/v8/PN_lRfmxrmD9dEi_Qbtf91W1xPPTOqu-ZIAJUN2H_fAQtYfaQ_ao.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarserif/v8/PN_lRfmxrmD9dEi_Qbtf91W1xPPTOqu-ZIAJUN3Z_fAQtYfaQ_ao.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarserif/v8/PN_lRfmxrmD9dEi_Qbtf91W1xPPTOqu-ZIAJUN3r_fAQtYfaQ_ao.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarserif/v8/PN_lRfmxrmD9dEi_Qbtf91W1xPPTOqu-ZIAJUN0H-vAQtYfaQ_ao.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarserif/v8/PN_lRfmxrmD9dEi_Qbtf91W1xPPTOqu-ZIAJUN0--vAQtYfaQ_ao.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarserif/v8/PN_lRfmxrmD9dEi_Qbtf91W1xPPTOqu-ZIAJUN1Z-vAQtYfaQ_ao.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarserif/v8/PN_lRfmxrmD9dEi_Qbtf91W1xPPTOqu-ZIAJUN1w-vAQtYfaQ_ao.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarserif/v8/PN_nRfmxrmD9dEi_Qbtf91W17vrhxXPXDxqnV8gRvkZTv4P4Ruao7Y0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarserif/v8/PN_nRfmxrmD9dEi_Qbtf91W17vrhxXPXDxqnV8gRvhhTv4P4Ruao7Y0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarserif/v8/PN_nRfmxrmD9dEi_Qbtf91W17vrhxXPXDxqnV8gRvipTv4P4Ruao7Y0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarserif/v8/PN_nRfmxrmD9dEi_Qbtf91W17vrhxXPXDxqnV8gRvsZUv4P4Ruao7Y0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarserif/v8/PN_nRfmxrmD9dEi_Qbtf91W17vrhxXPXDxqnV8gRvv9Uv4P4Ruao7Y0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ancizarserif/v8/PN_nRfmxrmD9dEi_Qbtf91W17vrhxXPXDxqnV8gRvphUv4P4Ruao7Y0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ancizarserif/v8/PN_nRfmxrmD9dEi_Qbtf91W17vrhxXPXDxqnV8gRvrFUv4P4Ruao7Y0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-andada-pro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b81ac815-4283-4143-995a-5840df63e9e5",903141217),$APP.$cljs$cst$2675$family$$,"Andada Pro",$APP.$cljs$cst$725$name$$,"Andada Pro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/andadapro/v24/HhyEU5Qi9-SuOEhPe4LtKoVCuWGURPcg3DPJBY8cFLzvIt2S.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/andadapro/v24/HhyEU5Qi9-SuOEhPe4LtKoVCuWGURPcg3DP7BY8cFLzvIt2S.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/andadapro/v24/HhyEU5Qi9-SuOEhPe4LtKoVCuWGURPcg3DMXAo8cFLzvIt2S.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/andadapro/v24/HhyEU5Qi9-SuOEhPe4LtKoVCuWGURPcg3DMuAo8cFLzvIt2S.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/andadapro/v24/HhyEU5Qi9-SuOEhPe4LtKoVCuWGURPcg3DNJAo8cFLzvIt2S.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/andadapro/v24/HhyGU5Qi9-SuOEhPe4LtAIxwRrn9L22O2yYBRmdfHrjNJ82Stjw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/andadapro/v24/HhyGU5Qi9-SuOEhPe4LtAIxwRrn9L22O2yYBRlVfHrjNJ82Stjw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/andadapro/v24/HhyGU5Qi9-SuOEhPe4LtAIxwRrn9L22O2yYBRrlYHrjNJ82Stjw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/andadapro/v24/HhyGU5Qi9-SuOEhPe4LtAIxwRrn9L22O2yYBRoBYHrjNJ82Stjw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/andadapro/v24/HhyGU5Qi9-SuOEhPe4LtAIxwRrn9L22O2yYBRudYHrjNJ82Stjw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-andika",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1217bf7f-1d79-4c48-b812-5a59515b8e44",1521700836),$APP.$cljs$cst$2675$family$$,"Andika",$APP.$cljs$cst$725$name$$,"Andika",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/andika/v27/mem_Ya6iyW-LwqgAbbwRWrwGVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/andika/v27/mem9Ya6iyW-Lwqgwb7YVeLkWVNBt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/andika/v27/mem8Ya6iyW-Lwqg40ZM1UpcaXcl0Aw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/andika/v27/mem6Ya6iyW-Lwqgwb46pV50ef8xkA76a.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-anek-bangla",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4600a47b-0d4b-4893-996a-0d16fd08ecd3",-2002039103),$APP.$cljs$cst$2675$family$$,"Anek Bangla",$APP.$cljs$cst$725$name$$,"Anek Bangla",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekbangla/v16/_gPW1R38qTExHg-17BhM6n66QhabMYB0fBKONtHhRSIUIre5mq3Ofm9YIocg56yyvt0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekbangla/v16/_gPW1R38qTExHg-17BhM6n66QhabMYB0fBKONtHhRSIUIre5mq3Ofu9ZIocg56yyvt0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekbangla/v16/_gPW1R38qTExHg-17BhM6n66QhabMYB0fBKONtHhRSIUIre5mq3OfjFZIocg56yyvt0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekbangla/v16/_gPW1R38qTExHg-17BhM6n66QhabMYB0fBKONtHhRSIUIre5mq3Ofm9ZIocg56yyvt0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekbangla/v16/_gPW1R38qTExHg-17BhM6n66QhabMYB0fBKONtHhRSIUIre5mq3Ofl1ZIocg56yyvt0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekbangla/v16/_gPW1R38qTExHg-17BhM6n66QhabMYB0fBKONtHhRSIUIre5mq3OfrFeIocg56yyvt0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekbangla/v16/_gPW1R38qTExHg-17BhM6n66QhabMYB0fBKONtHhRSIUIre5mq3OfoheIocg56yyvt0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekbangla/v16/_gPW1R38qTExHg-17BhM6n66QhabMYB0fBKONtHhRSIUIre5mq3Ofu9eIocg56yyvt0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-anek-devanagari",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d1d27bb8-6534-4bff-bcbf-09cad581494b",-1512402577),$APP.$cljs$cst$2675$family$$,
"Anek Devanagari",$APP.$cljs$cst$725$name$$,"Anek Devanagari",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekdevanagari/v17/jVyo7nP0CGrUsxB-QiRgw0NlLaVt_QUAkYxLRoCL23mlh20ZVHOMAWbgHLDtk-9nFk0LjZ7E.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekdevanagari/v17/jVyo7nP0CGrUsxB-QiRgw0NlLaVt_QUAkYxLRoCL23mlh20ZVHOMAWbgHLBtku9nFk0LjZ7E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekdevanagari/v17/jVyo7nP0CGrUsxB-QiRgw0NlLaVt_QUAkYxLRoCL23mlh20ZVHOMAWbgHLCzku9nFk0LjZ7E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekdevanagari/v17/jVyo7nP0CGrUsxB-QiRgw0NlLaVt_QUAkYxLRoCL23mlh20ZVHOMAWbgHLDtku9nFk0LjZ7E.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekdevanagari/v17/jVyo7nP0CGrUsxB-QiRgw0NlLaVt_QUAkYxLRoCL23mlh20ZVHOMAWbgHLDfku9nFk0LjZ7E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekdevanagari/v17/jVyo7nP0CGrUsxB-QiRgw0NlLaVt_QUAkYxLRoCL23mlh20ZVHOMAWbgHLAzle9nFk0LjZ7E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekdevanagari/v17/jVyo7nP0CGrUsxB-QiRgw0NlLaVt_QUAkYxLRoCL23mlh20ZVHOMAWbgHLAKle9nFk0LjZ7E.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekdevanagari/v17/jVyo7nP0CGrUsxB-QiRgw0NlLaVt_QUAkYxLRoCL23mlh20ZVHOMAWbgHLBtle9nFk0LjZ7E.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-anek-gujarati",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("40c323f8-df56-4be3-a8ee-ea7b3fdfc4e6",
737410644),$APP.$cljs$cst$2675$family$$,"Anek Gujarati",$APP.$cljs$cst$725$name$$,"Anek Gujarati",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgujarati/v17/l7g_bj5oysqknvkCo2T_8FuiIRBA7lncQUmbIBEtPKiYYQhRwyBxCD-0F5G7w0KgB7Lm7g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgujarati/v17/l7g_bj5oysqknvkCo2T_8FuiIRBA7lncQUmbIBEtPKiYYQhRwyBxCD-0l5C7w0KgB7Lm7g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgujarati/v17/l7g_bj5oysqknvkCo2T_8FuiIRBA7lncQUmbIBEtPKiYYQhRwyBxCD-0SZC7w0KgB7Lm7g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgujarati/v17/l7g_bj5oysqknvkCo2T_8FuiIRBA7lncQUmbIBEtPKiYYQhRwyBxCD-0F5C7w0KgB7Lm7g.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgujarati/v17/l7g_bj5oysqknvkCo2T_8FuiIRBA7lncQUmbIBEtPKiYYQhRwyBxCD-0JZC7w0KgB7Lm7g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgujarati/v17/l7g_bj5oysqknvkCo2T_8FuiIRBA7lncQUmbIBEtPKiYYQhRwyBxCD-0yZe7w0KgB7Lm7g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgujarati/v17/l7g_bj5oysqknvkCo2T_8FuiIRBA7lncQUmbIBEtPKiYYQhRwyBxCD-08Je7w0KgB7Lm7g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgujarati/v17/l7g_bj5oysqknvkCo2T_8FuiIRBA7lncQUmbIBEtPKiYYQhRwyBxCD-0l5e7w0KgB7Lm7g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-anek-gurmukhi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9af5dca7-e714-4fe4-8655-409fb41483ca",403833110),$APP.$cljs$cst$2675$family$$,
"Anek Gurmukhi",$APP.$cljs$cst$725$name$$,"Anek Gurmukhi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgurmukhi/v13/0QIAMXRO_YSkA0quVLY79JnHybfeEOrXCa9Dmd9Ql6a6R_vEMc5TaLkbd5ppXK41H6DjbA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgurmukhi/v13/0QIAMXRO_YSkA0quVLY79JnHybfeEOrXCa9Dmd9Ql6a6R_vEMc5TaLkb95tpXK41H6DjbA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgurmukhi/v13/0QIAMXRO_YSkA0quVLY79JnHybfeEOrXCa9Dmd9Ql6a6R_vEMc5TaLkbKZtpXK41H6DjbA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgurmukhi/v13/0QIAMXRO_YSkA0quVLY79JnHybfeEOrXCa9Dmd9Ql6a6R_vEMc5TaLkbd5tpXK41H6DjbA.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgurmukhi/v13/0QIAMXRO_YSkA0quVLY79JnHybfeEOrXCa9Dmd9Ql6a6R_vEMc5TaLkbRZtpXK41H6DjbA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgurmukhi/v13/0QIAMXRO_YSkA0quVLY79JnHybfeEOrXCa9Dmd9Ql6a6R_vEMc5TaLkbqZxpXK41H6DjbA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgurmukhi/v13/0QIAMXRO_YSkA0quVLY79JnHybfeEOrXCa9Dmd9Ql6a6R_vEMc5TaLkbkJxpXK41H6DjbA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekgurmukhi/v13/0QIAMXRO_YSkA0quVLY79JnHybfeEOrXCa9Dmd9Ql6a6R_vEMc5TaLkb95xpXK41H6DjbA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-anek-kannada",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5a4a811a-5e70-4afa-b20d-9946e89bd916",466814719),$APP.$cljs$cst$2675$family$$,
"Anek Kannada",$APP.$cljs$cst$725$name$$,"Anek Kannada",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekkannada/v15/raxcHiCNvNMKe1CKFsINYFlgkEIwGa8nL6ruWJg1j--h8pvBKSiw4dFDEAukVReA1oef.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekkannada/v15/raxcHiCNvNMKe1CKFsINYFlgkEIwGa8nL6ruWJg1j--h8pvBKSiw4dHDEQukVReA1oef.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekkannada/v15/raxcHiCNvNMKe1CKFsINYFlgkEIwGa8nL6ruWJg1j--h8pvBKSiw4dEdEQukVReA1oef.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekkannada/v15/raxcHiCNvNMKe1CKFsINYFlgkEIwGa8nL6ruWJg1j--h8pvBKSiw4dFDEQukVReA1oef.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekkannada/v15/raxcHiCNvNMKe1CKFsINYFlgkEIwGa8nL6ruWJg1j--h8pvBKSiw4dFxEQukVReA1oef.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekkannada/v15/raxcHiCNvNMKe1CKFsINYFlgkEIwGa8nL6ruWJg1j--h8pvBKSiw4dGdFgukVReA1oef.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekkannada/v15/raxcHiCNvNMKe1CKFsINYFlgkEIwGa8nL6ruWJg1j--h8pvBKSiw4dGkFgukVReA1oef.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekkannada/v15/raxcHiCNvNMKe1CKFsINYFlgkEIwGa8nL6ruWJg1j--h8pvBKSiw4dHDFgukVReA1oef.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-anek-latin",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("12f3328a-b06b-4644-8f74-8dd549dbde27",-471778583),$APP.$cljs$cst$2675$family$$,"Anek Latin",$APP.$cljs$cst$725$name$$,"Anek Latin",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aneklatin/v11/co3pmWZulTRoU4a8dqrWiajBS5ByUkvdrluH-xWG5uJTY4x-L3PuR7EZKdClWL3kgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aneklatin/v11/co3pmWZulTRoU4a8dqrWiajBS5ByUkvdrluH-xWG5uJTY4x-L3Pux7AZKdClWL3kgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aneklatin/v11/co3pmWZulTRoU4a8dqrWiajBS5ByUkvdrluH-xWG5uJTY4x-L3PuGbAZKdClWL3kgw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aneklatin/v11/co3pmWZulTRoU4a8dqrWiajBS5ByUkvdrluH-xWG5uJTY4x-L3PuR7AZKdClWL3kgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aneklatin/v11/co3pmWZulTRoU4a8dqrWiajBS5ByUkvdrluH-xWG5uJTY4x-L3PudbAZKdClWL3kgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aneklatin/v11/co3pmWZulTRoU4a8dqrWiajBS5ByUkvdrluH-xWG5uJTY4x-L3PumbcZKdClWL3kgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aneklatin/v11/co3pmWZulTRoU4a8dqrWiajBS5ByUkvdrluH-xWG5uJTY4x-L3PuoLcZKdClWL3kgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aneklatin/v11/co3pmWZulTRoU4a8dqrWiajBS5ByUkvdrluH-xWG5uJTY4x-L3Pux7cZKdClWL3kgw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-anek-malayalam",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a09cac2c-0f28-423e-a1ad-294e61ec1da8",882155445),$APP.$cljs$cst$2675$family$$,"Anek Malayalam",$APP.$cljs$cst$725$name$$,"Anek Malayalam",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",
$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekmalayalam/v18/6qLjKZActRTs_mZAJUZWWkhke0nYa_vC8_Azq3-gP1SReZeOtqQuDVUTUZu_HMr5PDO71Qs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekmalayalam/v18/6qLjKZActRTs_mZAJUZWWkhke0nYa_vC8_Azq3-gP1SReZeOtqQuDVUTURu-HMr5PDO71Qs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekmalayalam/v18/6qLjKZActRTs_mZAJUZWWkhke0nYa_vC8_Azq3-gP1SReZeOtqQuDVUTUcW-HMr5PDO71Qs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekmalayalam/v18/6qLjKZActRTs_mZAJUZWWkhke0nYa_vC8_Azq3-gP1SReZeOtqQuDVUTUZu-HMr5PDO71Qs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekmalayalam/v18/6qLjKZActRTs_mZAJUZWWkhke0nYa_vC8_Azq3-gP1SReZeOtqQuDVUTUam-HMr5PDO71Qs.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekmalayalam/v18/6qLjKZActRTs_mZAJUZWWkhke0nYa_vC8_Azq3-gP1SReZeOtqQuDVUTUUW5HMr5PDO71Qs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekmalayalam/v18/6qLjKZActRTs_mZAJUZWWkhke0nYa_vC8_Azq3-gP1SReZeOtqQuDVUTUXy5HMr5PDO71Qs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekmalayalam/v18/6qLjKZActRTs_mZAJUZWWkhke0nYa_vC8_Azq3-gP1SReZeOtqQuDVUTURu5HMr5PDO71Qs.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-anek-odia",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("720767bc-c634-4242-9d17-116b7836bf59",1218732261),$APP.$cljs$cst$2675$family$$,"Anek Odia",$APP.$cljs$cst$725$name$$,"Anek Odia",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekodia/v17/TK3PWkoJARApz5UCd345tuevwwQX0CwsoYkAWgWYevAauivBUnmZf63mXZAtm_es.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekodia/v17/TK3PWkoJARApz5UCd345tuevwwQX0CwsoYkAWgWYevAauivBUnkZfq3mXZAtm_es.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekodia/v17/TK3PWkoJARApz5UCd345tuevwwQX0CwsoYkAWgWYevAauivBUnnHfq3mXZAtm_es.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekodia/v17/TK3PWkoJARApz5UCd345tuevwwQX0CwsoYkAWgWYevAauivBUnmZfq3mXZAtm_es.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekodia/v17/TK3PWkoJARApz5UCd345tuevwwQX0CwsoYkAWgWYevAauivBUnmrfq3mXZAtm_es.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekodia/v17/TK3PWkoJARApz5UCd345tuevwwQX0CwsoYkAWgWYevAauivBUnlHea3mXZAtm_es.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekodia/v17/TK3PWkoJARApz5UCd345tuevwwQX0CwsoYkAWgWYevAauivBUnl-ea3mXZAtm_es.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anekodia/v17/TK3PWkoJARApz5UCd345tuevwwQX0CwsoYkAWgWYevAauivBUnkZea3mXZAtm_es.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-anek-tamil",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("001d3c81-f41f-4305-9be1-2b6556bc8a36",
511338312),$APP.$cljs$cst$2675$family$$,"Anek Tamil",$APP.$cljs$cst$725$name$$,"Anek Tamil",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektamil/v18/XLYJIZH2bYJHGYtPGSbUB8JKTp-_9n55SsLHW0WZez6TjtkDu3uNQiZ6q4v4oegjOQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektamil/v18/XLYJIZH2bYJHGYtPGSbUB8JKTp-_9n55SsLHW0WZez6TjtkDu3uNwid6q4v4oegjOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektamil/v18/XLYJIZH2bYJHGYtPGSbUB8JKTp-_9n55SsLHW0WZez6TjtkDu3uNHCd6q4v4oegjOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektamil/v18/XLYJIZH2bYJHGYtPGSbUB8JKTp-_9n55SsLHW0WZez6TjtkDu3uNQid6q4v4oegjOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektamil/v18/XLYJIZH2bYJHGYtPGSbUB8JKTp-_9n55SsLHW0WZez6TjtkDu3uNcCd6q4v4oegjOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektamil/v18/XLYJIZH2bYJHGYtPGSbUB8JKTp-_9n55SsLHW0WZez6TjtkDu3uNnCB6q4v4oegjOQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektamil/v18/XLYJIZH2bYJHGYtPGSbUB8JKTp-_9n55SsLHW0WZez6TjtkDu3uNpSB6q4v4oegjOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektamil/v18/XLYJIZH2bYJHGYtPGSbUB8JKTp-_9n55SsLHW0WZez6TjtkDu3uNwiB6q4v4oegjOQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-anek-telugu",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("157270f2-bc86-4554-ae20-0a894054c465",1978727051),$APP.$cljs$cst$2675$family$$,"Anek Telugu",$APP.$cljs$cst$725$name$$,"Anek Telugu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektelugu/v13/LhWLMVrUNvsddMtYGCx4FcVWOjlwE1WgXdoJ-5XHMl2DkooGK7i13y-_oE2G2ep10_8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektelugu/v13/LhWLMVrUNvsddMtYGCx4FcVWOjlwE1WgXdoJ-5XHMl2DkooGK7i136--oE2G2ep10_8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektelugu/v13/LhWLMVrUNvsddMtYGCx4FcVWOjlwE1WgXdoJ-5XHMl2DkooGK7i133G-oE2G2ep10_8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektelugu/v13/LhWLMVrUNvsddMtYGCx4FcVWOjlwE1WgXdoJ-5XHMl2DkooGK7i13y--oE2G2ep10_8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektelugu/v13/LhWLMVrUNvsddMtYGCx4FcVWOjlwE1WgXdoJ-5XHMl2DkooGK7i13x2-oE2G2ep10_8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektelugu/v13/LhWLMVrUNvsddMtYGCx4FcVWOjlwE1WgXdoJ-5XHMl2DkooGK7i13_G5oE2G2ep10_8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektelugu/v13/LhWLMVrUNvsddMtYGCx4FcVWOjlwE1WgXdoJ-5XHMl2DkooGK7i138i5oE2G2ep10_8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anektelugu/v13/LhWLMVrUNvsddMtYGCx4FcVWOjlwE1WgXdoJ-5XHMl2DkooGK7i136-5oE2G2ep10_8.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-angkor",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ce7c13db-bcfc-4f3a-9bf7-e69f1245c131",-1317399018),$APP.$cljs$cst$2675$family$$,"Angkor",$APP.$cljs$cst$725$name$$,"Angkor",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/angkor/v35/H4cmBXyAlsPdnlb-8iw-4Lqggw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-annapurna-sil",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f20bd22c-85c5-4afc-9f19-3c0144da2d5b",258496262),$APP.$cljs$cst$2675$family$$,"Annapurna SIL",$APP.$cljs$cst$725$name$$,"Annapurna SIL",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/annapurnasil/v2/yYLv0hDY0f2iu9tPmRWtllid8NN9dZT_PZs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/annapurnasil/v2/yYLy0hDY0f2iu9tPmRWtllidyG9SUZzUIZJ008A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-annie-use-your-telescope",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("32c589b0-c2cc-4749-903e-bdc2a9b0ad73",301046064),$APP.$cljs$cst$2675$family$$,"Annie Use Your Telescope",$APP.$cljs$cst$725$name$$,"Annie Use Your Telescope",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/annieuseyourtelescope/v20/daaLSS4tI2qYYl3Jq9s_Hu74xwktnlKxH6osGVGjlDfB3UUVZA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-anonymous-pro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("74f0e4da-4d1d-48e1-91ab-25b23dbc3c9f",346296806),$APP.$cljs$cst$2675$family$$,"Anonymous Pro",$APP.$cljs$cst$725$name$$,"Anonymous Pro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anonymouspro/v22/rP2Bp2a15UIB7Un-bOeISG3pLlw89CH98Ko.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anonymouspro/v22/rP2fp2a15UIB7Un-bOeISG3pHl428AP44Kqr2Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anonymouspro/v22/rP2cp2a15UIB7Un-bOeISG3pFuAT0CnW7KOywKo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anonymouspro/v22/rP2ap2a15UIB7Un-bOeISG3pHl4OTCzc6IG30KqB9Q.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-anta",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b49db6fe-ae3b-4001-a06d-643ebe09edbf",-1868474489),$APP.$cljs$cst$2675$family$$,"Anta",$APP.$cljs$cst$725$name$$,"Anta",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anta/v1/gyBzhwQ3KsIyZFwxPFimIo0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-antic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4513412b-10fc-497d-95b6-9e1ed31fa799",158545684),$APP.$cljs$cst$2675$family$$,"Antic",$APP.$cljs$cst$725$name$$,"Antic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/antic/v20/TuGfUVB8XY5DRaZLodgzydtk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-antic-didone",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fd2a091f-9b92-41c3-b552-e2d4d4c81cb7",
172100996),$APP.$cljs$cst$2675$family$$,"Antic Didone",$APP.$cljs$cst$725$name$$,"Antic Didone",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anticdidone/v17/RWmPoKKX6u8sp8fIWdnDKqDiqYsGBGBzCw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-antic-slab",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3b00c7d0-dc07-4db0-924d-e7697b1ed503",-1065152363),$APP.$cljs$cst$2675$family$$,"Antic Slab",$APP.$cljs$cst$725$name$$,"Antic Slab",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anticslab/v17/bWt97fPFfRzkCa9Jlp6IWcJWXW5p5Qo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-anton",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1d0b41c1-437a-4ed7-9ad0-35b96b6816f2",1230299773),$APP.$cljs$cst$2675$family$$,"Anton",$APP.$cljs$cst$725$name$$,"Anton",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anton/v27/1Ptgg87LROyAm0K08i4gS7lu.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-anton-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ecddc81b-824f-4f8e-bb2d-27939715f084",
343002528),$APP.$cljs$cst$2675$family$$,"Anton SC",$APP.$cljs$cst$725$name$$,"Anton SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/antonsc/v1/4UaBrEBBsgltGn71sxLmzanB44N1.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-antonio",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1c3305f9-7237-4a84-b521-dfa286aed4b8",-940208834),$APP.$cljs$cst$2675$family$$,"Antonio",$APP.$cljs$cst$725$name$$,"Antonio",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/antonio/v22/gNMbW3NwSYq_9WD34ngK5F8vR8T0PVxx8BtIY2DwSXlM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/antonio/v22/gNMbW3NwSYq_9WD34ngK5F8vR8T0PVzx8RtIY2DwSXlM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/antonio/v22/gNMbW3NwSYq_9WD34ngK5F8vR8T0PVwv8RtIY2DwSXlM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/antonio/v22/gNMbW3NwSYq_9WD34ngK5F8vR8T0PVxx8RtIY2DwSXlM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/antonio/v22/gNMbW3NwSYq_9WD34ngK5F8vR8T0PVxD8RtIY2DwSXlM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/antonio/v22/gNMbW3NwSYq_9WD34ngK5F8vR8T0PVyv9htIY2DwSXlM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/antonio/v22/gNMbW3NwSYq_9WD34ngK5F8vR8T0PVyW9htIY2DwSXlM.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-anuphan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b1c7c8b5-7787-4a9c-a4b8-cf7e8c289ccd",-2097275246),$APP.$cljs$cst$2675$family$$,"Anuphan",$APP.$cljs$cst$725$name$$,"Anuphan",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anuphan/v6/2sDBZGxYgY7LkLT0s2Yrm5UhuLoIZCkY9A4kGmW927Gu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anuphan/v6/2sDBZGxYgY7LkLT0s2Yrm5UhuLoIZCmY9Q4kGmW927Gu.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anuphan/v6/2sDBZGxYgY7LkLT0s2Yrm5UhuLoIZClG9Q4kGmW927Gu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/anuphan/v6/2sDBZGxYgY7LkLT0s2Yrm5UhuLoIZCkY9Q4kGmW927Gu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anuphan/v6/2sDBZGxYgY7LkLT0s2Yrm5UhuLoIZCkq9Q4kGmW927Gu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anuphan/v6/2sDBZGxYgY7LkLT0s2Yrm5UhuLoIZCnG8g4kGmW927Gu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anuphan/v6/2sDBZGxYgY7LkLT0s2Yrm5UhuLoIZCn_8g4kGmW927Gu.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-anybody",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("271d77de-122b-490c-a2fa-f64b3ce1c6b9",-585468926),$APP.$cljs$cst$2675$family$$,"Anybody",$APP.$cljs$cst$725$name$$,"Anybody",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJbdNvK2Ib2ppdWYq311GH32hxIv0sd5grncSUi2F_Wim4J12HPrsXD_nBPpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJbdNvK2Ib2ppdWYq311GH32hxIv0sd5grncSUi2F_Wim4JV2DPrsXD_nBPpQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJbdNvK2Ib2ppdWYq311GH32hxIv0sd5grncSUi2F_Wim4JiWDPrsXD_nBPpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJbdNvK2Ib2ppdWYq311GH32hxIv0sd5grncSUi2F_Wim4J12DPrsXD_nBPpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJbdNvK2Ib2ppdWYq311GH32hxIv0sd5grncSUi2F_Wim4J5WDPrsXD_nBPpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJbdNvK2Ib2ppdWYq311GH32hxIv0sd5grncSUi2F_Wim4JCWfPrsXD_nBPpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJbdNvK2Ib2ppdWYq311GH32hxIv0sd5grncSUi2F_Wim4JMGfPrsXD_nBPpQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJbdNvK2Ib2ppdWYq311GH32hxIv0sd5grncSUi2F_Wim4JV2fPrsXD_nBPpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJbdNvK2Ib2ppdWYq311GH32hxIv0sd5grncSUi2F_Wim4JfmfPrsXD_nBPpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJddNvK2Ib2ppdWSKTHN4GOiYrmuF7VpPiuQ9r6sTRMJGkcHyMn7M_H3HVfpcHY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJddNvK2Ib2ppdWSKTHN4GOiYrmuF7VpPiuQ9r6sTRMJGkcHyOn7c_H3HVfpcHY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/anybody/v13/VuJddNvK2Ib2ppdWSKTHN4GOiYrmuF7VpPiuQ9r6sTRMJGkcHyN57c_H3HVfpcHY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJddNvK2Ib2ppdWSKTHN4GOiYrmuF7VpPiuQ9r6sTRMJGkcHyMn7c_H3HVfpcHY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJddNvK2Ib2ppdWSKTHN4GOiYrmuF7VpPiuQ9r6sTRMJGkcHyMV7c_H3HVfpcHY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/anybody/v13/VuJddNvK2Ib2ppdWSKTHN4GOiYrmuF7VpPiuQ9r6sTRMJGkcHyP56s_H3HVfpcHY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJddNvK2Ib2ppdWSKTHN4GOiYrmuF7VpPiuQ9r6sTRMJGkcHyPA6s_H3HVfpcHY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/anybody/v13/VuJddNvK2Ib2ppdWSKTHN4GOiYrmuF7VpPiuQ9r6sTRMJGkcHyOn6s_H3HVfpcHY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/anybody/v13/VuJddNvK2Ib2ppdWSKTHN4GOiYrmuF7VpPiuQ9r6sTRMJGkcHyOO6s_H3HVfpcHY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-aoboshi-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5f2433cc-ca62-4523-b50f-03214cc33cef",-1233631222),$APP.$cljs$cst$2675$family$$,"Aoboshi One",$APP.$cljs$cst$725$name$$,"Aoboshi One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aoboshione/v13/Gg8xN5kXaAXtHQrFxwl10ysLBmZX_UEg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-arapey",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("752c2548-7284-4583-8676-a5cc990fce5a",1027584126),$APP.$cljs$cst$2675$family$$,
"Arapey",$APP.$cljs$cst$725$name$$,"Arapey",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arapey/v17/-W__XJn-UDDA2RC6Z9AcZkIzeg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arapey/v17/-W_9XJn-UDDA2RCKZdoYREcjeo0k.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-arbutus",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("54f7aea3-ae8b-427c-ad54-e28e33c95d12",2120948589),$APP.$cljs$cst$2675$family$$,"Arbutus",$APP.$cljs$cst$725$name$$,
"Arbutus",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arbutus/v30/NaPYcZ7dG_5J3poob9JtryO8fMU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-arbutus-slab",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5c999e9f-7edf-46be-bd5b-5deef37cff8d",-1496221877),$APP.$cljs$cst$2675$family$$,"Arbutus Slab",$APP.$cljs$cst$725$name$$,"Arbutus Slab",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arbutusslab/v17/oY1Z8e7OuLXkJGbXtr5ba7ZVa68dJlaFAQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-architects-daughter",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4fa6fe5c-b9ac-4e8e-a7df-1dc2baba3211",-733904859),$APP.$cljs$cst$2675$family$$,"Architects Daughter",$APP.$cljs$cst$725$name$$,"Architects Daughter",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/architectsdaughter/v20/KtkxAKiDZI_td1Lkx62xHZHDtgO_Y-bvfY5q4szgE-Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-archivo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("94b8bb21-c3e8-4b63-a120-6985feeb04cf",
-340288546),$APP.$cljs$cst$2675$family$$,"Archivo",$APP.$cljs$cst$725$name$$,"Archivo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k6o8UDI-1M0wlSV9XAw6lQkqWY8Q82sJaRE-NWIDdgffTTNDJp8B1oJ0vyVQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k6o8UDI-1M0wlSV9XAw6lQkqWY8Q82sJaRE-NWIDdgffTTtDNp8B1oJ0vyVQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k6o8UDI-1M0wlSV9XAw6lQkqWY8Q82sJaRE-NWIDdgffTTajNp8B1oJ0vyVQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k6o8UDI-1M0wlSV9XAw6lQkqWY8Q82sJaRE-NWIDdgffTTNDNp8B1oJ0vyVQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k6o8UDI-1M0wlSV9XAw6lQkqWY8Q82sJaRE-NWIDdgffTTBjNp8B1oJ0vyVQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k6o8UDI-1M0wlSV9XAw6lQkqWY8Q82sJaRE-NWIDdgffTT6jRp8B1oJ0vyVQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k6o8UDI-1M0wlSV9XAw6lQkqWY8Q82sJaRE-NWIDdgffTT0zRp8B1oJ0vyVQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k6o8UDI-1M0wlSV9XAw6lQkqWY8Q82sJaRE-NWIDdgffTTtDRp8B1oJ0vyVQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k6o8UDI-1M0wlSV9XAw6lQkqWY8Q82sJaRE-NWIDdgffTTnTRp8B1oJ0vyVQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k8o8UDI-1M0wlSfdzyIEkpwTM29hr-8mTYIRyOSVz60_PG_HCBshdsBU7iVdxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/archivo/v25/k3k8o8UDI-1M0wlSfdzyIEkpwTM29hr-8mTYIRyOSVz60_PG_HABsxdsBU7iVdxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k8o8UDI-1M0wlSfdzyIEkpwTM29hr-8mTYIRyOSVz60_PG_HDfsxdsBU7iVdxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k8o8UDI-1M0wlSfdzyIEkpwTM29hr-8mTYIRyOSVz60_PG_HCBsxdsBU7iVdxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/archivo/v25/k3k8o8UDI-1M0wlSfdzyIEkpwTM29hr-8mTYIRyOSVz60_PG_HCzsxdsBU7iVdxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k8o8UDI-1M0wlSfdzyIEkpwTM29hr-8mTYIRyOSVz60_PG_HBftBdsBU7iVdxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k8o8UDI-1M0wlSfdzyIEkpwTM29hr-8mTYIRyOSVz60_PG_HBmtBdsBU7iVdxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/archivo/v25/k3k8o8UDI-1M0wlSfdzyIEkpwTM29hr-8mTYIRyOSVz60_PG_HABtBdsBU7iVdxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivo/v25/k3k8o8UDI-1M0wlSfdzyIEkpwTM29hr-8mTYIRyOSVz60_PG_HAotBdsBU7iVdxQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-archivo-black",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1f43c561-79f1-4121-94f7-833c70f84a3f",-316594051),$APP.$cljs$cst$2675$family$$,"Archivo Black",$APP.$cljs$cst$725$name$$,"Archivo Black",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivoblack/v23/HTxqL289NzCGg4MzN6KJ7eW6OYuP_x7yx3A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-archivo-narrow",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e765fb82-710b-4f09-879b-9a2a49f139f4",1184493119),$APP.$cljs$cst$2675$family$$,"Archivo Narrow",$APP.$cljs$cst$725$name$$,"Archivo Narrow",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivonarrow/v35/tss5ApVBdCYD5Q7hcxTE1ArZ0Zz8oY2KRmwvKhhvLFGKpHOtFCQ76Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivonarrow/v35/tss5ApVBdCYD5Q7hcxTE1ArZ0Zz8oY2KRmwvKhhvHlGKpHOtFCQ76Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivonarrow/v35/tss5ApVBdCYD5Q7hcxTE1ArZ0Zz8oY2KRmwvKhhv8laKpHOtFCQ76Q.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivonarrow/v35/tss5ApVBdCYD5Q7hcxTE1ArZ0Zz8oY2KRmwvKhhvy1aKpHOtFCQ76Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivonarrow/v35/tss7ApVBdCYD5Q7hcxTE1ArZ0bb1k3JSLwe1hB965BJi53mpNiEr6T6Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivonarrow/v35/tss7ApVBdCYD5Q7hcxTE1ArZ0bb1k3JSLwe1hB965BJQ53mpNiEr6T6Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/archivonarrow/v35/tss7ApVBdCYD5Q7hcxTE1ArZ0bb1k3JSLwe1hB965BK84HmpNiEr6T6Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/archivonarrow/v35/tss7ApVBdCYD5Q7hcxTE1ArZ0bb1k3JSLwe1hB965BKF4HmpNiEr6T6Y.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-are-you-serious",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("42c2ad60-4d53-45c9-92c9-61cdce719f90",196043338),$APP.$cljs$cst$2675$family$$,"Are You Serious",$APP.$cljs$cst$725$name$$,"Are You Serious",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/areyouserious/v14/ll8kK2GVSSr-PtjQ5nONVcNn4306hT9nCGRayg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-aref-ruqaa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d5d1bf5a-2e24-48a3-b45f-01ba533a1f95",-1101505784),
$APP.$cljs$cst$2675$family$$,"Aref Ruqaa",$APP.$cljs$cst$725$name$$,"Aref Ruqaa",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arefruqaa/v26/WwkbxPW1E165rajQKDulEIAiVNo5xNY.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arefruqaa/v26/WwkYxPW1E165rajQKDulKDwNcNIS2N_7Bdk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-aref-ruqaa-ink",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("83c738ae-15c4-4328-98fd-b6dac630400f",-1841070177),
$APP.$cljs$cst$2675$family$$,"Aref Ruqaa Ink",$APP.$cljs$cst$725$name$$,"Aref Ruqaa Ink",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arefruqaaink/v11/1q2fY5WOGUFlt84GTOkP6Kdx72ThVIGpgnxL.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arefruqaaink/v11/1q2cY5WOGUFlt84GTOkP6Kdx71xde6WhqWBCyxWn.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-arima",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4340cb99-0b62-45fc-8a43-ec1caaa21471",-419249219),
$APP.$cljs$cst$2675$family$$,"Arima",$APP.$cljs$cst$725$name$$,"Arima",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arima/v7/neIWzCqmt4Aup_qE1nFWqxI1RZX1YTE-pQGOyYw2fw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arima/v7/neIWzCqmt4Aup_qE1nFWqxI1RZX14TA-pQGOyYw2fw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arima/v7/neIWzCqmt4Aup_qE1nFWqxI1RZX1PzA-pQGOyYw2fw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arima/v7/neIWzCqmt4Aup_qE1nFWqxI1RZX1YTA-pQGOyYw2fw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/arima/v7/neIWzCqmt4Aup_qE1nFWqxI1RZX1UzA-pQGOyYw2fw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arima/v7/neIWzCqmt4Aup_qE1nFWqxI1RZX1vzc-pQGOyYw2fw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",
$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arima/v7/neIWzCqmt4Aup_qE1nFWqxI1RZX1hjc-pQGOyYw2fw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-arimo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3615299d-7657-4c3a-830d-a3f46df61f6f",-1416159788),$APP.$cljs$cst$2675$family$$,"Arimo",$APP.$cljs$cst$725$name$$,"Arimo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arimo/v35/P5sfzZCDf9_T_3cV7NCUECyoxNk37cxsBxDAVQI4aA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arimo/v35/P5sfzZCDf9_T_3cV7NCUECyoxNk338xsBxDAVQI4aA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arimo/v35/P5sfzZCDf9_T_3cV7NCUECyoxNk3M8tsBxDAVQI4aA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arimo/v35/P5sfzZCDf9_T_3cV7NCUECyoxNk3CstsBxDAVQI4aA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arimo/v35/P5sdzZCDf9_T_10c3i9MeUcyat4iJY-ERBrEdwcoaKww.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arimo/v35/P5sdzZCDf9_T_10c3i9MeUcyat4iJY-2RBrEdwcoaKww.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arimo/v35/P5sdzZCDf9_T_10c3i9MeUcyat4iJY9aQxrEdwcoaKww.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arimo/v35/P5sdzZCDf9_T_10c3i9MeUcyat4iJY9jQxrEdwcoaKww.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-arizonia",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ece30fd3-cd5d-4472-994f-2d132a173909",-706953614),$APP.$cljs$cst$2675$family$$,"Arizonia",$APP.$cljs$cst$725$name$$,"Arizonia",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arizonia/v23/neIIzCemt4A5qa7mv6WGHK06UY30.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-armata",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("43ba4c11-78ad-48e4-b493-911f8f5c0e0b",1088597689),$APP.$cljs$cst$2675$family$$,"Armata",$APP.$cljs$cst$725$name$$,"Armata",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/armata/v21/gokvH63_HV5jQ-E9lD53Q2u_mQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-arsenal",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a16ca74e-058c-4673-8743-7b33d8516fb4",21460497),$APP.$cljs$cst$2675$family$$,
"Arsenal",$APP.$cljs$cst$725$name$$,"Arsenal",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arsenal/v13/wXKrE3kQtZQ4pF3D11_WAewrhXY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arsenal/v13/wXKpE3kQtZQ4pF3D513cBc4ulXYrtA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arsenal/v13/wXKuE3kQtZQ4pF3D7-P5JeQAmX8yrdk.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arsenal/v13/wXKsE3kQtZQ4pF3D513kueEKnV03vdnKjw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-arsenal-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("abe0545e-c6dd-4ec0-8b69-01b3f4c0d1fc",
121596511),$APP.$cljs$cst$2675$family$$,"Arsenal SC",$APP.$cljs$cst$725$name$$,"Arsenal SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arsenalsc/v1/x3dlckLHea6e5BEtsfxiXNossybsHQI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arsenalsc/v1/x3dnckLHea6e5BEtsfxibNgmtwTpDQIrGg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/arsenalsc/v1/x3dmckLHea6e5BEtsfxiZGYDly7HAQsyA2Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arsenalsc/v1/x3d4ckLHea6e5BEtsfxibNgeCyvNBSk3E2YljQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-artifika",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("84ece5b9-0d94-4af9-9392-c04d86ad4eb2",408981777),$APP.$cljs$cst$2675$family$$,"Artifika",$APP.$cljs$cst$725$name$$,"Artifika",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/artifika/v22/VEMyRoxzronptCuxu6Wt5jDtreOL.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-arvo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7be44786-9801-4de1-bb4f-adc4e536eeb8",-1241827199),$APP.$cljs$cst$2675$family$$,"Arvo",$APP.$cljs$cst$725$name$$,"Arvo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arvo/v23/tDbD2oWUg0MKmSAa7Lzr7vs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arvo/v23/tDbN2oWUg0MKqSIQ6J7u_vvijQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arvo/v23/tDbM2oWUg0MKoZw1yLTA8vL7lAE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/arvo/v23/tDbO2oWUg0MKqSIoVLHK9tD-hAHkGg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-arya",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1b1d3e5c-fba4-49f9-8970-35fd21b8beac",-845251711),$APP.$cljs$cst$2675$family$$,"Arya",$APP.$cljs$cst$725$name$$,"Arya",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arya/v21/ga6CawNG-HJd9Ub1-beqdFE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/arya/v21/ga6NawNG-HJdzfra3b-BaFg3dRE.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-asap",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d019a728-079a-4cb3-a66d-d972cce0ce87",1925734214),$APP.$cljs$cst$2675$family$$,"Asap",$APP.$cljs$cst$725$name$$,"Asap",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOOCniXp96a4Tc2DaTeuDAoKsE617JFc49knOIYdjTYkqQsLmOXoA7Glw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOOCniXp96a4Tc2DaTeuDAoKsE617JFc49knOIYdjTYEqUsLmOXoA7Glw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOOCniXp96a4Tc2DaTeuDAoKsE617JFc49knOIYdjTYzKUsLmOXoA7Glw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOOCniXp96a4Tc2DaTeuDAoKsE617JFc49knOIYdjTYkqUsLmOXoA7Glw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOOCniXp96a4Tc2DaTeuDAoKsE617JFc49knOIYdjTYoKUsLmOXoA7Glw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOOCniXp96a4Tc2DaTeuDAoKsE617JFc49knOIYdjTYTKIsLmOXoA7Glw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOOCniXp96a4Tc2DaTeuDAoKsE617JFc49knOIYdjTYdaIsLmOXoA7Glw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOOCniXp96a4Tc2DaTeuDAoKsE617JFc49knOIYdjTYEqIsLmOXoA7Glw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOOCniXp96a4Tc2DaTeuDAoKsE617JFc49knOIYdjTYO6IsLmOXoA7Glw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOMCniXp96ayz4E7kSn66aGLdTylUAMQXC89YmC2DPNWubEbGmTggvWl0Qn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOMCniXp96ayz4E7kSn66aGLdTylUAMQXC89YmC2DPNWuZEbWmTggvWl0Qn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/asap/v34/KFOMCniXp96ayz4E7kSn66aGLdTylUAMQXC89YmC2DPNWuaabWmTggvWl0Qn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOMCniXp96ayz4E7kSn66aGLdTylUAMQXC89YmC2DPNWubEbWmTggvWl0Qn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOMCniXp96ayz4E7kSn66aGLdTylUAMQXC89YmC2DPNWub2bWmTggvWl0Qn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOMCniXp96ayz4E7kSn66aGLdTylUAMQXC89YmC2DPNWuYaammTggvWl0Qn.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOMCniXp96ayz4E7kSn66aGLdTylUAMQXC89YmC2DPNWuYjammTggvWl0Qn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOMCniXp96ayz4E7kSn66aGLdTylUAMQXC89YmC2DPNWuZEammTggvWl0Qn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asap/v34/KFOMCniXp96ayz4E7kSn66aGLdTylUAMQXC89YmC2DPNWuZtammTggvWl0Qn.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-asap-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("df9b2553-1917-4016-9393-25ad8fb69cb3",1245852096),$APP.$cljs$cst$2675$family$$,"Asap Condensed",$APP.$cljs$cst$725$name$$,"Asap Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxieypY1o9NHyXh3WvSbGSggdO9DSWlEgGqgp-pO.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxiYypY1o9NHyXh3WvSbGSggdOeJUIFFim6CovpOkXA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxieypY1o9NHyXh3WvSbGSggdO8nSmlEgGqgp-pO.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxiYypY1o9NHyXh3WvSbGSggdOeJUOVGim6CovpOkXA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxidypY1o9NHyXh3WvSbGSggdNeLYk1Mq3ap.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxifypY1o9NHyXh3WvSbGSggdOeJaElurmapvvM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxieypY1o9NHyXh3WvSbGSggdO9_S2lEgGqgp-pO.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxiYypY1o9NHyXh3WvSbGSggdOeJUL1Him6CovpOkXA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxieypY1o9NHyXh3WvSbGSggdO9TTGlEgGqgp-pO.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxiYypY1o9NHyXh3WvSbGSggdOeJUJFAim6CovpOkXA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxieypY1o9NHyXh3WvSbGSggdO83TWlEgGqgp-pO.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxiYypY1o9NHyXh3WvSbGSggdOeJUPVBim6CovpOkXA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxieypY1o9NHyXh3WvSbGSggdO8rTmlEgGqgp-pO.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxiYypY1o9NHyXh3WvSbGSggdOeJUOlCim6CovpOkXA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxieypY1o9NHyXh3WvSbGSggdO8PT2lEgGqgp-pO.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asapcondensed/v18/pxiYypY1o9NHyXh3WvSbGSggdOeJUM1Dim6CovpOkXA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-asar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("af16d674-7c83-4fea-8772-0e24bf919ead",-1841018409),$APP.$cljs$cst$2675$family$$,"Asar",$APP.$cljs$cst$725$name$$,"Asar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asar/v24/sZlLdRyI6TBIXkYQDLlTW6E.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-asimovian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f429a0c0-b711-4947-8911-5861cc6d2188",-1747210967),$APP.$cljs$cst$2675$family$$,
"Asimovian",$APP.$cljs$cst$725$name$$,"Asimovian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asimovian/v2/oY1c8evOub78P2XN94MXCv5xY4QBLw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-asset",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("827489e2-cc65-4087-bb72-89322b8386ea",-1785127088),$APP.$cljs$cst$2675$family$$,"Asset",$APP.$cljs$cst$725$name$$,"Asset",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asset/v30/SLXGc1na-mM4cWImRJqExst1.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-assistant",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5aa82cd6-a995-4a1f-9098-7c1bd51ff443",-1520538143),$APP.$cljs$cst$2675$family$$,"Assistant",$APP.$cljs$cst$725$name$$,"Assistant",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/assistant/v24/2sDPZGJYnIjSi6H75xkZZE1I0yCmYzzQtmZnEGGf3qGuvM4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/assistant/v24/2sDPZGJYnIjSi6H75xkZZE1I0yCmYzzQtrhnEGGf3qGuvM4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/assistant/v24/2sDPZGJYnIjSi6H75xkZZE1I0yCmYzzQtuZnEGGf3qGuvM4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/assistant/v24/2sDPZGJYnIjSi6H75xkZZE1I0yCmYzzQttRnEGGf3qGuvM4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/assistant/v24/2sDPZGJYnIjSi6H75xkZZE1I0yCmYzzQtjhgEGGf3qGuvM4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/assistant/v24/2sDPZGJYnIjSi6H75xkZZE1I0yCmYzzQtgFgEGGf3qGuvM4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/assistant/v24/2sDPZGJYnIjSi6H75xkZZE1I0yCmYzzQtmZgEGGf3qGuvM4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-asta-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d5e40e03-b43e-448c-841a-28c33c16b831",1844923963),$APP.$cljs$cst$2675$family$$,"Asta Sans",$APP.$cljs$cst$725$name$$,"Asta Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/astasans/v3/XoH32Y74XaWovvhMb0c3tN_dRqdT9zveo6r_mVnvqYRoVr0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/astasans/v3/XoH32Y74XaWovvhMb0c3tN_dRqdT9zveo_T_mVnvqYRoVr0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/astasans/v3/XoH32Y74XaWovvhMb0c3tN_dRqdT9zveo8b_mVnvqYRoVr0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/astasans/v3/XoH32Y74XaWovvhMb0c3tN_dRqdT9zveoyr4mVnvqYRoVr0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/astasans/v3/XoH32Y74XaWovvhMb0c3tN_dRqdT9zveoxP4mVnvqYRoVr0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/astasans/v3/XoH32Y74XaWovvhMb0c3tN_dRqdT9zveo3T4mVnvqYRoVr0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-astloch",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7e3ff35b-4a4a-4dce-a255-4159bc6b952a",328126254),
$APP.$cljs$cst$2675$family$$,"Astloch",$APP.$cljs$cst$725$name$$,"Astloch",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/astloch/v27/TuGRUVJ8QI5GSeUjq9wRzMtkH1Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/astloch/v27/TuGUUVJ8QI5GSeUjk2A-6MNPA10xLMQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-asul",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9e389927-8a64-4d1b-84b4-20872e09ad04",-715932297),$APP.$cljs$cst$2675$family$$,"Asul",$APP.$cljs$cst$725$name$$,
"Asul",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asul/v22/VuJ-dNjKxYr46fMFXK78JIg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/asul/v22/VuJxdNjKxYr40U8qeKbXOIFneRo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-athiti",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5a276a42-24e1-44a4-9b71-2977286ae68e",-1620644364),$APP.$cljs$cst$2675$family$$,"Athiti",$APP.$cljs$cst$725$name$$,"Athiti",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/athiti/v14/pe0sMISdLIZIv1wAxDNyAv2-C99ycg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/athiti/v14/pe0sMISdLIZIv1wAoDByAv2-C99ycg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/athiti/v14/pe0vMISdLIZIv1w4DBhWCtaiAg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/athiti/v14/pe0sMISdLIZIv1wA-DFyAv2-C99ycg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/athiti/v14/pe0sMISdLIZIv1wA1DZyAv2-C99ycg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/athiti/v14/pe0sMISdLIZIv1wAsDdyAv2-C99ycg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-atkinson-hyperlegible",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8cdf420f-8cfa-49c0-b16b-2ca0ed859380",-448882085),$APP.$cljs$cst$2675$family$$,"Atkinson Hyperlegible",
$APP.$cljs$cst$725$name$$,"Atkinson Hyperlegible",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegible/v12/9Bt23C1KxNDXMspQ1lPyU89-1h6ONRlW45GE5ZgpewSSbQ.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegible/v12/9Bt43C1KxNDXMspQ1lPyU89-1h6ONRlW45G055ItWQGCbUWn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegible/v12/9Bt73C1KxNDXMspQ1lPyU89-1h6ONRlW45G8WbcNcy-OZFy-FA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegible/v12/9Bt93C1KxNDXMspQ1lPyU89-1h6ONRlW45G056qRdiWKRlmuFH24.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-atkinson-hyperlegible-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("92c87e4a-fa61-47cd-9da3-768efddf9517",-1146992447),$APP.$cljs$cst$2675$family$$,"Atkinson Hyperlegible Mono",$APP.$cljs$cst$725$name$$,"Atkinson Hyperlegible Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblemono/v8/tssNAoFBci4C4gvhPXrt3wjT1MqSzhA4t7IIcncBiyihrK15gZ4k_SaZnNeiDSkb2qzelw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblemono/v8/tssNAoFBci4C4gvhPXrt3wjT1MqSzhA4t7IIcncBiyihrK15gZ4k_SaZQteiDSkb2qzelw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblemono/v8/tssNAoFBci4C4gvhPXrt3wjT1MqSzhA4t7IIcncBiyihrK15gZ4k_SaZHNeiDSkb2qzelw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblemono/v8/tssNAoFBci4C4gvhPXrt3wjT1MqSzhA4t7IIcncBiyihrK15gZ4k_SaZLteiDSkb2qzelw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblemono/v8/tssNAoFBci4C4gvhPXrt3wjT1MqSzhA4t7IIcncBiyihrK15gZ4k_SaZwtCiDSkb2qzelw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblemono/v8/tssNAoFBci4C4gvhPXrt3wjT1MqSzhA4t7IIcncBiyihrK15gZ4k_SaZ-9CiDSkb2qzelw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblemono/v8/tssNAoFBci4C4gvhPXrt3wjT1MqSzhA4t7IIcncBiyihrK15gZ4k_SaZnNCiDSkb2qzelw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblemono/v8/tssPAoFBci4C4gvhPXrt3wjT1MqSzhA4t7IIcncBiwKonlKh6PW-UyGM1JTKTiMf-KnOlxYs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblemono/v8/tssPAoFBci4C4gvhPXrt3wjT1MqSzhA4t7IIcncBiwKonlKh6PW-UyGM1JQUTiMf-KnOlxYs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblemono/v8/tssPAoFBci4C4gvhPXrt3wjT1MqSzhA4t7IIcncBiwKonlKh6PW-UyGM1JRKTiMf-KnOlxYs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblemono/v8/tssPAoFBci4C4gvhPXrt3wjT1MqSzhA4t7IIcncBiwKonlKh6PW-UyGM1JR4TiMf-KnOlxYs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblemono/v8/tssPAoFBci4C4gvhPXrt3wjT1MqSzhA4t7IIcncBiwKonlKh6PW-UyGM1JSUSSMf-KnOlxYs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblemono/v8/tssPAoFBci4C4gvhPXrt3wjT1MqSzhA4t7IIcncBiwKonlKh6PW-UyGM1JStSSMf-KnOlxYs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblemono/v8/tssPAoFBci4C4gvhPXrt3wjT1MqSzhA4t7IIcncBiwKonlKh6PW-UyGM1JTKSSMf-KnOlxYs.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-atkinson-hyperlegible-next",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("00755234-34de-44c4-890f-f481a6498e60",-760820112),$APP.$cljs$cst$2675$family$$,"Atkinson Hyperlegible Next",$APP.$cljs$cst$725$name$$,"Atkinson Hyperlegible Next",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblenext/v7/NaP4cYPdHfdVxJw0IfIP0lvYFqijb-UxCtm5_wdGscKFt4tOOfV4ZmW3bLQhtNl93TwPEQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/atkinsonhyperlegiblenext/v7/NaP4cYPdHfdVxJw0IfIP0lvYFqijb-UxCtm5_wdGscKFt4tOOfV4ZmW3srQhtNl93TwPEQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblenext/v7/NaP4cYPdHfdVxJw0IfIP0lvYFqijb-UxCtm5_wdGscKFt4tOOfV4ZmW37LQhtNl93TwPEQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblenext/v7/NaP4cYPdHfdVxJw0IfIP0lvYFqijb-UxCtm5_wdGscKFt4tOOfV4ZmW33rQhtNl93TwPEQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/atkinsonhyperlegiblenext/v7/NaP4cYPdHfdVxJw0IfIP0lvYFqijb-UxCtm5_wdGscKFt4tOOfV4ZmW3MrMhtNl93TwPEQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblenext/v7/NaP4cYPdHfdVxJw0IfIP0lvYFqijb-UxCtm5_wdGscKFt4tOOfV4ZmW3C7MhtNl93TwPEQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblenext/v7/NaP4cYPdHfdVxJw0IfIP0lvYFqijb-UxCtm5_wdGscKFt4tOOfV4ZmW3bLMhtNl93TwPEQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/atkinsonhyperlegiblenext/v7/NaP6cYPdHfdVxJw0IfIP0lvYFqijb-UxCtm5_wdGseiMhXSWUJ7iyGKiJPdJ99N5_zkfEYNP.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblenext/v7/NaP6cYPdHfdVxJw0IfIP0lvYFqijb-UxCtm5_wdGseiMhXSWUJ7iyGKiJPeX99N5_zkfEYNP.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblenext/v7/NaP6cYPdHfdVxJw0IfIP0lvYFqijb-UxCtm5_wdGseiMhXSWUJ7iyGKiJPfJ99N5_zkfEYNP.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblenext/v7/NaP6cYPdHfdVxJw0IfIP0lvYFqijb-UxCtm5_wdGseiMhXSWUJ7iyGKiJPf799N5_zkfEYNP.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblenext/v7/NaP6cYPdHfdVxJw0IfIP0lvYFqijb-UxCtm5_wdGseiMhXSWUJ7iyGKiJPcX8NN5_zkfEYNP.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblenext/v7/NaP6cYPdHfdVxJw0IfIP0lvYFqijb-UxCtm5_wdGseiMhXSWUJ7iyGKiJPcu8NN5_zkfEYNP.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,
"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atkinsonhyperlegiblenext/v7/NaP6cYPdHfdVxJw0IfIP0lvYFqijb-UxCtm5_wdGseiMhXSWUJ7iyGKiJPdJ8NN5_zkfEYNP.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-atma",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1768b062-2aab-4d4d-98f1-cdf911b06b36",701665430),$APP.$cljs$cst$2675$family$$,"Atma",$APP.$cljs$cst$725$name$$,"Atma",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atma/v19/uK_z4rqWc-Eoo8JzKjc9PvedRkM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atma/v19/uK_84rqWc-Eom25bDj8WIv4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atma/v19/uK_z4rqWc-Eoo5pyKjc9PvedRkM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atma/v19/uK_z4rqWc-Eoo7Z1Kjc9PvedRkM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atma/v19/uK_z4rqWc-Eoo9J0Kjc9PvedRkM.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-atomic-age",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fd570b38-40bf-4a22-a280-e2a9865a31fa",-126277917),$APP.$cljs$cst$2675$family$$,"Atomic Age",$APP.$cljs$cst$725$name$$,"Atomic Age",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/atomicage/v29/f0Xz0eug6sdmRFkYZZGL58Ht9a8GYeA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-aubrey",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ba7b5831-0718-4d66-90a2-8950d51f6b15",-1010574328),$APP.$cljs$cst$2675$family$$,"Aubrey",$APP.$cljs$cst$725$name$$,"Aubrey",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/aubrey/v29/q5uGsou7NPBw-p7vugNsCxVEgA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-audiowide",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("26300c4e-2dd2-4b9a-b80a-55cfe81e5057",
509102712),$APP.$cljs$cst$2675$family$$,"Audiowide",$APP.$cljs$cst$725$name$$,"Audiowide",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/audiowide/v22/l7gdbjpo0cum0ckerWCtkQXPExpQBw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-autour-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0105c6f5-daaa-4c3c-9c5a-150ae2f451b4",1820024629),$APP.$cljs$cst$2675$family$$,"Autour One",$APP.$cljs$cst$725$name$$,"Autour One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/autourone/v25/UqyVK80cP25l3fJgbdfbk5lWVscxdKE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-average",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6ef53a8a-06a1-421a-9bce-d164957f3217",-1002797757),$APP.$cljs$cst$2675$family$$,"Average",$APP.$cljs$cst$725$name$$,"Average",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/average/v19/fC1hPYBHe23MxA7rIeJwVWytTyk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-average-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("25a284c8-e93d-4a9f-ae5c-234afc8e2311",
-1468828742),$APP.$cljs$cst$2675$family$$,"Average Sans",$APP.$cljs$cst$725$name$$,"Average Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averagesans/v17/1Ptpg8fLXP2dlAXR-HlJJNJPBdqazVoK4A.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-averia-gruesa-libre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9ce99123-2524-430c-9822-012bf5602d8c",-2144372688),$APP.$cljs$cst$2675$family$$,"Averia Gruesa Libre",$APP.$cljs$cst$725$name$$,"Averia Gruesa Libre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averiagruesalibre/v22/NGSov4nEGEktOaDRKsY-1dhh8eEtIx3ZUmmJw0SLRA8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-averia-libre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b3914015-d678-4e79-90ee-87ea6f5c58a0",1826339718),$APP.$cljs$cst$2675$family$$,"Averia Libre",$APP.$cljs$cst$725$name$$,
"Averia Libre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averialibre/v16/2V0FKIcMGZEnV6xygz7eNjEarovtb07t-pQgTw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averialibre/v16/2V0HKIcMGZEnV6xygz7eNjESAJFhbUTp2JEwT4Sk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averialibre/v16/2V0aKIcMGZEnV6xygz7eNjEiAqPJZ2Xx8w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averialibre/v16/2V0EKIcMGZEnV6xygz7eNjESAKnNRWDh8405.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averialibre/v16/2V0FKIcMGZEnV6xygz7eNjEavoztb07t-pQgTw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averialibre/v16/2V0HKIcMGZEnV6xygz7eNjESAJFxakTp2JEwT4Sk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"gfont-averia-sans-libre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f3e82d15-07a6-4d56-80b9-d290d3dcb045",536707173),$APP.$cljs$cst$2675$family$$,"Averia Sans Libre",$APP.$cljs$cst$725$name$$,"Averia Sans Libre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averiasanslibre/v20/ga6SaxZG_G5OvCf_rt7FH3B6BHLMEd3lMKcQJZP1LmD9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averiasanslibre/v20/ga6caxZG_G5OvCf_rt7FH3B6BHLMEdVLKisSL5fXK3D9qtg.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averiasanslibre/v20/ga6XaxZG_G5OvCf_rt7FH3B6BHLMEeVJGIMYDo_8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averiasanslibre/v20/ga6RaxZG_G5OvCf_rt7FH3B6BHLMEdVLEoc6C5_8N3k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averiasanslibre/v20/ga6SaxZG_G5OvCf_rt7FH3B6BHLMEd31N6cQJZP1LmD9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averiasanslibre/v20/ga6caxZG_G5OvCf_rt7FH3B6BHLMEdVLKjsVL5fXK3D9qtg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-averia-serif-libre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("647672b1-1f23-408c-92be-506cac233bbe",1341107562),$APP.$cljs$cst$2675$family$$,"Averia Serif Libre",
$APP.$cljs$cst$725$name$$,"Averia Serif Libre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averiaseriflibre/v19/neIVzD2ms4wxr6GvjeD0X88SHPyX2xYGCSmqwacqdrKvbQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averiaseriflibre/v19/neIbzD2ms4wxr6GvjeD0X88SHPyX2xYOpzMmw60uVLe_bXHq.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averiaseriflibre/v19/neIWzD2ms4wxr6GvjeD0X88SHPyX2xY-pQGOyYw2fw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averiaseriflibre/v19/neIUzD2ms4wxr6GvjeD0X88SHPyX2xYOpwuK64kmf6u2.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averiaseriflibre/v19/neIVzD2ms4wxr6GvjeD0X88SHPyX2xYGGS6qwacqdrKvbQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/averiaseriflibre/v19/neIbzD2ms4wxr6GvjeD0X88SHPyX2xYOpzM2xK0uVLe_bXHq.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-azeret-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e44e5757-a15a-4073-a036-c42d5fef4e01",-1319980542),$APP.$cljs$cst$2675$family$$,"Azeret Mono",$APP.$cljs$cst$725$name$$,"Azeret Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF5ErsiyJsY9O_Gepph-FvtTQgMQUdNekSfnPRh0raa-5s3AA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF5ErsiyJsY9O_Gepph-FvtTQgMQUdNekSfHPVh0raa-5s3AA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF5ErsiyJsY9O_Gepph-FvtTQgMQUdNekSfwvVh0raa-5s3AA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF5ErsiyJsY9O_Gepph-FvtTQgMQUdNekSfnPVh0raa-5s3AA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF5ErsiyJsY9O_Gepph-FvtTQgMQUdNekSfrvVh0raa-5s3AA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF5ErsiyJsY9O_Gepph-FvtTQgMQUdNekSfQvJh0raa-5s3AA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF5ErsiyJsY9O_Gepph-FvtTQgMQUdNekSfe_Jh0raa-5s3AA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF5ErsiyJsY9O_Gepph-FvtTQgMQUdNekSfHPJh0raa-5s3AA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF5ErsiyJsY9O_Gepph-FvtTQgMQUdNekSfNfJh0raa-5s3AA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF_ErsiyJsY9O_Gepph-HHkf_fUKCzX1EOKVLaJkLye2Z4nAN7J.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF_ErsiyJsY9O_Gepph-HHkf_fUKCzX1EOKVLYJkbye2Z4nAN7J.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF_ErsiyJsY9O_Gepph-HHkf_fUKCzX1EOKVLbXkbye2Z4nAN7J.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF_ErsiyJsY9O_Gepph-HHkf_fUKCzX1EOKVLaJkbye2Z4nAN7J.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/azeretmono/v21/3XF_ErsiyJsY9O_Gepph-HHkf_fUKCzX1EOKVLa7kbye2Z4nAN7J.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF_ErsiyJsY9O_Gepph-HHkf_fUKCzX1EOKVLZXlrye2Z4nAN7J.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF_ErsiyJsY9O_Gepph-HHkf_fUKCzX1EOKVLZulrye2Z4nAN7J.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF_ErsiyJsY9O_Gepph-HHkf_fUKCzX1EOKVLYJlrye2Z4nAN7J.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/azeretmono/v21/3XF_ErsiyJsY9O_Gepph-HHkf_fUKCzX1EOKVLYglrye2Z4nAN7J.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-b612",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("01bfbb2b-3830-4969-9c8d-8ce57a91c469",
-1084112460),$APP.$cljs$cst$2675$family$$,"B612",$APP.$cljs$cst$725$name$$,"B612",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/b612/v13/3JnySDDxiSz32jm4GDigUXw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/b612/v13/3Jn8SDDxiSz36juyHBqlQXwdVw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/b612/v13/3Jn9SDDxiSz34oWXPDCLTXUETuE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/b612/v13/3Jn_SDDxiSz36juKoDWBSVcBXuFb0Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-b612-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2e64c489-274f-431f-9b3c-180ad04d5d68",1177453779),
$APP.$cljs$cst$2675$family$$,"B612 Mono",$APP.$cljs$cst$725$name$$,"B612 Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/b612mono/v16/kmK_Zq85QVWbN1eW6lJl1wTcquRTtg.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/b612mono/v16/kmK5Zq85QVWbN1eW6lJV1Q7YiOFDtqtf.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/b612mono/v16/kmK6Zq85QVWbN1eW6lJdayv4os9Pv7JGSg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/b612mono/v16/kmKkZq85QVWbN1eW6lJV1TZkp8VLnbdWSg4x.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bbh-sans-bartle",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a41d46f4-c8dc-4227-bca6-36636b82df7c",-1671374602),$APP.$cljs$cst$2675$family$$,"BBH Sans Bartle",$APP.$cljs$cst$725$name$$,"BBH Sans Bartle",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bbhsansbartle/v1/eLGEP-v-CSnwOk_evJ1qrrCJCQTJ9eYh0tfR-Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bbh-sans-bogle",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f6fec6fb-13e7-46d7-9f7c-c829c0dfaef3",-1669323752),$APP.$cljs$cst$2675$family$$,"BBH Sans Bogle",$APP.$cljs$cst$725$name$$,"BBH Sans Bogle",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bbhsansbogle/v1/LYjbdGTyv25vPsUz0wMCwj1DMf_fcpC69i6N.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bbh-sans-hegarty",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9f67c4dd-0b9b-4d3c-93f1-337d83382dd1",
-528256518),$APP.$cljs$cst$2675$family$$,"BBH Sans Hegarty",$APP.$cljs$cst$725$name$$,"BBH Sans Hegarty",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bbhsanshegarty/v1/UqyLK9cfCFIq--EuUZn21v4dILtJTKAJduj91zQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-biz-udgothic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("940dcf55-2d01-4f46-a5fe-5285a6b87af4",694503664),$APP.$cljs$cst$2675$family$$,"BIZ UDGothic",$APP.$cljs$cst$725$name$$,"BIZ UDGothic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bizudgothic/v12/daafSTouBF7RUjnbt8p3LuKttQN98z_MbQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bizudgothic/v12/daaASTouBF7RUjnbt8p3LuKVCSxZ-xTQZMhbaA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-biz-udmincho",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6259cb5c-1fe5-49ec-a141-c789a21139f2",1780937638),$APP.$cljs$cst$2675$family$$,"BIZ UDMincho",$APP.$cljs$cst$725$name$$,"BIZ UDMincho",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bizudmincho/v11/EJRRQgI6eOxFjBdKs38yhtW1dwT7rcpY8Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bizudmincho/v11/EJROQgI6eOxFjBdKs38yhtWNyyvfpeFE-IyCrw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-biz-udpgothic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3e8d33a4-3494-4871-ac2d-4487c2e9369a",-1357913742),$APP.$cljs$cst$2675$family$$,"BIZ UDPGothic",$APP.$cljs$cst$725$name$$,"BIZ UDPGothic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bizudpgothic/v15/hES36X5pHAIBjmS84VL0Bue83nUMQWkMUAk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bizudpgothic/v15/hESq6X5pHAIBjmS84VL0Bue85skjZWEnTABCSQo.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-biz-udpmincho",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2df83c3e-8140-4a48-ad03-7fb50936c5da",76146469),$APP.$cljs$cst$2675$family$$,"BIZ UDPMincho",$APP.$cljs$cst$725$name$$,"BIZ UDPMincho",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bizudpmincho/v11/ypvfbXOBrmYppy7oWWTg1_58nhhYtUb0gZk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bizudpmincho/v11/ypvCbXOBrmYppy7oWWTg1_58pqR3kU7fnZAy57k.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-babylonica",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("12ec36ca-faa8-4d2d-8824-cc81afd6541b",305634135),$APP.$cljs$cst$2675$family$$,"Babylonica",$APP.$cljs$cst$725$name$$,"Babylonica",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/babylonica/v7/5aUw9_i2qxWVCAE2aHjTqDJ0-VVMoEw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bacasime-antique",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1bebfa25-ca89-4ad6-ac42-843eead335b5",-1179757965),$APP.$cljs$cst$2675$family$$,"Bacasime Antique",$APP.$cljs$cst$725$name$$,"Bacasime Antique",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bacasimeantique/v1/tDbX2pGXkFYEykldjZSrmI6T_XWZOwStSUrV_BE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bad-script",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ee84c586-7012-4454-87d3-279867beb885",-195159636),$APP.$cljs$cst$2675$family$$,"Bad Script",$APP.$cljs$cst$725$name$$,"Bad Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/badscript/v18/6NUT8F6PJgbFWQn47_x7lOwuzd1AZtw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-badeen-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ba1d6aee-c4ed-494b-a077-97fcc41f99a2",-2011009586),$APP.$cljs$cst$2675$family$$,"Badeen Display",$APP.$cljs$cst$725$name$$,"Badeen Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/badeendisplay/v1/pxidypY2sdZSjFU4cPmNBzckadeLYk1Mq3ap.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bagel-fat-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("82a9278f-f26e-47bb-b084-d36490869f5b",2027254317),
$APP.$cljs$cst$2675$family$$,"Bagel Fat One",$APP.$cljs$cst$725$name$$,"Bagel Fat One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bagelfatone/v2/hYkPPucsQOr5dy02WmQr5Zkd0B5mvv0dSbM.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bahiana",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1f600952-916b-4596-b34d-f9dd2208ed41",-623118141),$APP.$cljs$cst$2675$family$$,"Bahiana",$APP.$cljs$cst$725$name$$,"Bahiana",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bahiana/v25/uU9PCBUV4YenPWJU7xPb3vyHmlI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bahianita",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("db8095d9-bbb6-4939-8588-d85211397bd4",533738622),$APP.$cljs$cst$2675$family$$,"Bahianita",$APP.$cljs$cst$725$name$$,"Bahianita",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bahianita/v23/yYLr0hTb3vuqqsBUgxWtxTvV2NJPcA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bai-jamjuree",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0b873743-b0ad-4131-951e-ba42ee351b78",
265438187),$APP.$cljs$cst$2675$family$$,"Bai Jamjuree",$APP.$cljs$cst$725$name$$,"Bai Jamjuree",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baijamjuree/v13/LDIqapSCOBt_aeQQ7ftydoa0kePuk5A1-yiSgA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baijamjuree/v13/LDIoapSCOBt_aeQQ7ftydoa8W_oGkpox2S2CgOva.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baijamjuree/v13/LDIqapSCOBt_aeQQ7ftydoa09eDuk5A1-yiSgA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baijamjuree/v13/LDIoapSCOBt_aeQQ7ftydoa8W_pikZox2S2CgOva.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baijamjuree/v13/LDI1apSCOBt_aeQQ7ftydoaMWcjKm7sp8g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baijamjuree/v13/LDIrapSCOBt_aeQQ7ftydoa8W8LOub458jGL.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baijamjuree/v13/LDIqapSCOBt_aeQQ7ftydoa0reHuk5A1-yiSgA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baijamjuree/v13/LDIoapSCOBt_aeQQ7ftydoa8W_o6kJox2S2CgOva.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baijamjuree/v13/LDIqapSCOBt_aeQQ7ftydoa0gebuk5A1-yiSgA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",
$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baijamjuree/v13/LDIoapSCOBt_aeQQ7ftydoa8W_oWl5ox2S2CgOva.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baijamjuree/v13/LDIqapSCOBt_aeQQ7ftydoa05efuk5A1-yiSgA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baijamjuree/v13/LDIoapSCOBt_aeQQ7ftydoa8W_pylpox2S2CgOva.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bakbak-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("20c80dd4-4108-43e1-bd44-25ae2bc07aca",
-1953667293),$APP.$cljs$cst$2675$family$$,"Bakbak One",$APP.$cljs$cst$725$name$$,"Bakbak One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bakbakone/v11/zOL54pXAl6RI-p_ardnuycRuv-hHkOs.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ballet",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("07795339-db47-4c29-b936-900e9187e9f9",1441049574),$APP.$cljs$cst$2675$family$$,"Ballet",$APP.$cljs$cst$725$name$$,"Ballet",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ballet/v30/QGYyz_MYZA-HM4NjuGOVnUEXme1I4Xi3C4G-EiAou6Y.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-baloo-2",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dd727697-8fb1-453d-96e5-db2b0be70d44",-435966935),$APP.$cljs$cst$2675$family$$,"Baloo 2",$APP.$cljs$cst$725$name$$,"Baloo 2",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloo2/v23/wXK0E3kTposypRydzVT08TS3JnAmtdgazapv9Fat7WcN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloo2/v23/wXK0E3kTposypRydzVT08TS3JnAmtdgozapv9Fat7WcN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloo2/v23/wXK0E3kTposypRydzVT08TS3JnAmtdjEyqpv9Fat7WcN.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloo2/v23/wXK0E3kTposypRydzVT08TS3JnAmtdj9yqpv9Fat7WcN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/baloo2/v23/wXK0E3kTposypRydzVT08TS3JnAmtdiayqpv9Fat7WcN.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-baloo-bhai-2",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f9e64e91-1af4-405a-97c0-b691ff1fbaa5",138742646),$APP.$cljs$cst$2675$family$$,"Baloo Bhai 2",$APP.$cljs$cst$725$name$$,"Baloo Bhai 2",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhai2/v30/sZlWdRSL-z1VEWZ4YNA7Y5ItevYWUOHDE8FvNighMXeCo-jsZzo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhai2/v30/sZlWdRSL-z1VEWZ4YNA7Y5ItevYWUOHDE8FvNhohMXeCo-jsZzo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhai2/v30/sZlWdRSL-z1VEWZ4YNA7Y5ItevYWUOHDE8FvNvYmMXeCo-jsZzo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhai2/v30/sZlWdRSL-z1VEWZ4YNA7Y5ItevYWUOHDE8FvNs8mMXeCo-jsZzo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhai2/v30/sZlWdRSL-z1VEWZ4YNA7Y5ItevYWUOHDE8FvNqgmMXeCo-jsZzo.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-baloo-bhaijaan-2",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0fccbeba-0656-4ebd-aa7d-a8c2eece4e79",-1290662630),$APP.$cljs$cst$2675$family$$,"Baloo Bhaijaan 2",$APP.$cljs$cst$725$name$$,"Baloo Bhaijaan 2",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhaijaan2/v21/zYXwKUwuEqdVGqM8tPDdAA_Y-_bMKo1EhQd2tWxo8TyRSqP4L4ppfcyC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhaijaan2/v21/zYXwKUwuEqdVGqM8tPDdAA_Y-_bMKo1EhQd2tWxo8TyjSqP4L4ppfcyC.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhaijaan2/v21/zYXwKUwuEqdVGqM8tPDdAA_Y-_bMKo1EhQd2tWxo8TxPTaP4L4ppfcyC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhaijaan2/v21/zYXwKUwuEqdVGqM8tPDdAA_Y-_bMKo1EhQd2tWxo8Tx2TaP4L4ppfcyC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhaijaan2/v21/zYXwKUwuEqdVGqM8tPDdAA_Y-_bMKo1EhQd2tWxo8TwRTaP4L4ppfcyC.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-baloo-bhaina-2",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ead5be48-472a-4832-9cb6-1fdcd1c7f49a",-1073848416),$APP.$cljs$cst$2675$family$$,"Baloo Bhaina 2",$APP.$cljs$cst$725$name$$,"Baloo Bhaina 2",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhaina2/v29/qWc-B6yyq4P9Adr3RtoX1q6ySgbwusXwJjkOS-XEssPvRfRLYWmZSA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhaina2/v29/qWc-B6yyq4P9Adr3RtoX1q6ySgbwusXwJjkOS-XEgMPvRfRLYWmZSA.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhaina2/v29/qWc-B6yyq4P9Adr3RtoX1q6ySgbwusXwJjkOS-XEbMTvRfRLYWmZSA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhaina2/v29/qWc-B6yyq4P9Adr3RtoX1q6ySgbwusXwJjkOS-XEVcTvRfRLYWmZSA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloobhaina2/v29/qWc-B6yyq4P9Adr3RtoX1q6ySgbwusXwJjkOS-XEMsTvRfRLYWmZSA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-baloo-chettan-2",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("65289d69-7c00-405d-b9b6-f53fe4513768",827315740),$APP.$cljs$cst$2675$family$$,"Baloo Chettan 2",$APP.$cljs$cst$725$name$$,"Baloo Chettan 2",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloochettan2/v23/vm8hdRbmXEva26PK-NtuX4ynWEzF69-L4gqgkIL5CeKTO1oeH9xI2gc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloochettan2/v23/vm8hdRbmXEva26PK-NtuX4ynWEzF69-L4gqgkIL5CdCTO1oeH9xI2gc.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloochettan2/v23/vm8hdRbmXEva26PK-NtuX4ynWEzF69-L4gqgkIL5CTyUO1oeH9xI2gc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloochettan2/v23/vm8hdRbmXEva26PK-NtuX4ynWEzF69-L4gqgkIL5CQWUO1oeH9xI2gc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloochettan2/v23/vm8hdRbmXEva26PK-NtuX4ynWEzF69-L4gqgkIL5CWKUO1oeH9xI2gc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-baloo-da-2",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5491bb2d-eae1-4a4a-ae76-b28c54aa2485",1816267359),$APP.$cljs$cst$2675$family$$,"Baloo Da 2",$APP.$cljs$cst$725$name$$,"Baloo Da 2",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balooda2/v26/2-c39J9j0IaUMQZwAJyJaOX1UUnf3GLnYjALsTNe55aRa7UE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balooda2/v26/2-c39J9j0IaUMQZwAJyJaOX1UUnf3GLnYjA5sTNe55aRa7UE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balooda2/v26/2-c39J9j0IaUMQZwAJyJaOX1UUnf3GLnYjDVtjNe55aRa7UE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balooda2/v26/2-c39J9j0IaUMQZwAJyJaOX1UUnf3GLnYjDstjNe55aRa7UE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balooda2/v26/2-c39J9j0IaUMQZwAJyJaOX1UUnf3GLnYjCLtjNe55aRa7UE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-baloo-paaji-2",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f2889e90-cc78-4a8f-94d1-ef42fbcbc9b9",
1470909354),$APP.$cljs$cst$2675$family$$,"Baloo Paaji 2",$APP.$cljs$cst$725$name$$,"Baloo Paaji 2",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloopaaji2/v29/i7dfIFFzbz-QHZUdV9_UGWZuelmy79QJ1HOSY9AX74fybRUz1r5t.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloopaaji2/v29/i7dfIFFzbz-QHZUdV9_UGWZuelmy79QJ1HOSY9Al74fybRUz1r5t.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloopaaji2/v29/i7dfIFFzbz-QHZUdV9_UGWZuelmy79QJ1HOSY9DJ6IfybRUz1r5t.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloopaaji2/v29/i7dfIFFzbz-QHZUdV9_UGWZuelmy79QJ1HOSY9Dw6IfybRUz1r5t.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloopaaji2/v29/i7dfIFFzbz-QHZUdV9_UGWZuelmy79QJ1HOSY9CX6IfybRUz1r5t.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-baloo-tamma-2",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8dcdf004-35c5-4203-b703-49a3a4419328",-1802358826),$APP.$cljs$cst$2675$family$$,
"Baloo Tamma 2",$APP.$cljs$cst$725$name$$,"Baloo Tamma 2",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balootamma2/v20/vEFE2_hCAgcR46PaajtrYlBbVUMUJgIC5LHTrMscPp-0IF71SGC5.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balootamma2/v20/vEFE2_hCAgcR46PaajtrYlBbVUMUJgIC5LHTrMsuPp-0IF71SGC5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balootamma2/v20/vEFE2_hCAgcR46PaajtrYlBbVUMUJgIC5LHTrMvCOZ-0IF71SGC5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balootamma2/v20/vEFE2_hCAgcR46PaajtrYlBbVUMUJgIC5LHTrMv7OZ-0IF71SGC5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balootamma2/v20/vEFE2_hCAgcR46PaajtrYlBbVUMUJgIC5LHTrMucOZ-0IF71SGC5.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-baloo-tammudu-2",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f44db15a-919f-4c46-9177-9aabdf92e242",558392740),$APP.$cljs$cst$2675$family$$,
"Baloo Tammudu 2",$APP.$cljs$cst$725$name$$,"Baloo Tammudu 2",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balootammudu2/v27/1Pt5g8TIS_SAmkLguUdFP8UaJcKkzlPmMT00GaE_Jf8e4c6PZSlGmAA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balootammudu2/v27/1Pt5g8TIS_SAmkLguUdFP8UaJcKkzlPmMT00GaE_Jc0e4c6PZSlGmAA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balootammudu2/v27/1Pt5g8TIS_SAmkLguUdFP8UaJcKkzlPmMT00GaE_JSEZ4c6PZSlGmAA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balootammudu2/v27/1Pt5g8TIS_SAmkLguUdFP8UaJcKkzlPmMT00GaE_JRgZ4c6PZSlGmAA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balootammudu2/v27/1Pt5g8TIS_SAmkLguUdFP8UaJcKkzlPmMT00GaE_JX8Z4c6PZSlGmAA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-baloo-thambi-2",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5c12e7c6-8c77-4a8f-972e-79f584f7c81a",1398943488),$APP.$cljs$cst$2675$family$$,
"Baloo Thambi 2",$APP.$cljs$cst$725$name$$,"Baloo Thambi 2",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloothambi2/v22/cY9RfjeOW0NHpmOQXranrbDyu5JMJmNp-aDvUBbKzcIzaQRG_n4osQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloothambi2/v22/cY9RfjeOW0NHpmOQXranrbDyu5JMJmNp-aDvUBbK_8IzaQRG_n4osQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloothambi2/v22/cY9RfjeOW0NHpmOQXranrbDyu5JMJmNp-aDvUBbKE8UzaQRG_n4osQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloothambi2/v22/cY9RfjeOW0NHpmOQXranrbDyu5JMJmNp-aDvUBbKKsUzaQRG_n4osQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baloothambi2/v22/cY9RfjeOW0NHpmOQXranrbDyu5JMJmNp-aDvUBbKTcUzaQRG_n4osQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-balsamiq-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("27a13c15-a7d4-4d52-bfba-5a27e4eba53e",1552393092),$APP.$cljs$cst$2675$family$$,
"Balsamiq Sans",$APP.$cljs$cst$725$name$$,"Balsamiq Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balsamiqsans/v15/P5sEzZiAbNrN8SB3lQQX7Pnc8dkdIYdNHzs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balsamiqsans/v15/P5sazZiAbNrN8SB3lQQX7PncwdsXJaVIDzvcXA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balsamiqsans/v15/P5sZzZiAbNrN8SB3lQQX7PncyWUyBY9mAzLFRQI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balsamiqsans/v15/P5sfzZiAbNrN8SB3lQQX7PncwdsvmYpsBxDAVQI4aA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-balthazar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("708babf8-6f5f-4365-92f5-c32429ac70e4",
1339425751),$APP.$cljs$cst$2675$family$$,"Balthazar",$APP.$cljs$cst$725$name$$,"Balthazar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/balthazar/v18/d6lKkaajS8Gm4CVQjFEvyRTo39l8hw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bangers",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("205c811c-7f9e-46b7-bb9e-87c20d3dd77d",-400185907),$APP.$cljs$cst$2675$family$$,"Bangers",$APP.$cljs$cst$725$name$$,"Bangers",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bangers/v25/FeVQS0BTqb0h60ACL5la2bxii28.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-barlow",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c7bc60ca-733d-49e3-8a1e-927f329a3514",985323861),$APP.$cljs$cst$2675$family$$,"Barlow",$APP.$cljs$cst$725$name$$,"Barlow",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHrv4kjgoGqM7E3b8s8yn4hnCci.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHtv4kjgoGqM7E_CfNYwHoDmTcibrA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHqv4kjgoGqM7E3w-oc4FAtlT47dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,
"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHsv4kjgoGqM7E_CfP04Voptzsrd6m9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHqv4kjgoGqM7E3p-kc4FAtlT47dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHsv4kjgoGqM7E_CfOQ4loptzsrd6m9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHpv4kjgoGqM7EPC8E46HsxnA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHrv4kjgoGqM7E_Ccs8yn4hnCci.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/barlow/v13/7cHqv4kjgoGqM7E3_-gc4FAtlT47dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHsv4kjgoGqM7E_CfPI41optzsrd6m9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHqv4kjgoGqM7E30-8c4FAtlT47dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHsv4kjgoGqM7E_CfPk5Foptzsrd6m9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHqv4kjgoGqM7E3t-4c4FAtlT47dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHsv4kjgoGqM7E_CfOA5Voptzsrd6m9.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHqv4kjgoGqM7E3q-0c4FAtlT47dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/barlow/v13/7cHsv4kjgoGqM7E_CfOc5loptzsrd6m9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHqv4kjgoGqM7E3j-wc4FAtlT47dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,
"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlow/v13/7cHsv4kjgoGqM7E_CfO451optzsrd6m9.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-barlow-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("17cbf22b-9c88-4840-bd60-ef5d2e83a7bb",-1312328624),$APP.$cljs$cst$2675$family$$,"Barlow Condensed",$APP.$cljs$cst$725$name$$,"Barlow Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxxL3I-JCGChYJ8VI-L6OO_au7B43LT31vytKgbaw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxzL3I-JCGChYJ8VI-L6OO_au7B6xTru1H2lq0La6JN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxwL3I-JCGChYJ8VI-L6OO_au7B497y_3HcuKECcrs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxyL3I-JCGChYJ8VI-L6OO_au7B6xTrF3DWvIMHYrtUxg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxwL3I-JCGChYJ8VI-L6OO_au7B47rx_3HcuKECcrs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxyL3I-JCGChYJ8VI-L6OO_au7B6xTrc3PWvIMHYrtUxg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTx3L3I-JCGChYJ8VI-L6OO_au7B2xbZ23n3pKg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxxL3I-JCGChYJ8VI-L6OO_au7B6xTT31vytKgbaw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxwL3I-JCGChYJ8VI-L6OO_au7B4-Lw_3HcuKECcrs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxyL3I-JCGChYJ8VI-L6OO_au7B6xTrK3LWvIMHYrtUxg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxwL3I-JCGChYJ8VI-L6OO_au7B4873_3HcuKECcrs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxyL3I-JCGChYJ8VI-L6OO_au7B6xTrB3XWvIMHYrtUxg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxwL3I-JCGChYJ8VI-L6OO_au7B46r2_3HcuKECcrs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxyL3I-JCGChYJ8VI-L6OO_au7B6xTrY3TWvIMHYrtUxg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxwL3I-JCGChYJ8VI-L6OO_au7B47b1_3HcuKECcrs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxyL3I-JCGChYJ8VI-L6OO_au7B6xTrf3fWvIMHYrtUxg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxwL3I-JCGChYJ8VI-L6OO_au7B45L0_3HcuKECcrs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowcondensed/v13/HTxyL3I-JCGChYJ8VI-L6OO_au7B6xTrW3bWvIMHYrtUxg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-barlow-semi-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1152416d-dde7-43fd-8538-bf3b84f1488e",-1851696274),$APP.$cljs$cst$2675$family$$,"Barlow Semi Condensed",$APP.$cljs$cst$725$name$$,"Barlow Semi Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlphgxjLBV1hqnzfr-F8sEYMB0Yybp0mudRfG4qvKk8ogoSP.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpjgxjLBV1hqnzfr-F8sEYMB0Yybp0mudRXfbLLIEsKh5SPZWs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpigxjLBV1hqnzfr-F8sEYMB0Yybp0mudRft6uPAGEki52WfA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpkgxjLBV1hqnzfr-F8sEYMB0Yybp0mudRXfbJnAWsgqZiGfHK5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpigxjLBV1hqnzfr-F8sEYMB0Yybp0mudRf06iPAGEki52WfA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpkgxjLBV1hqnzfr-F8sEYMB0Yybp0mudRXfbIDAmsgqZiGfHK5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpvgxjLBV1hqnzfr-F8sEYMB0Yybp0mudRnf4CrCEo4gg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlphgxjLBV1hqnzfr-F8sEYMB0Yybp0mudRXfYqvKk8ogoSP.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpigxjLBV1hqnzfr-F8sEYMB0Yybp0mudRfi6mPAGEki52WfA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpkgxjLBV1hqnzfr-F8sEYMB0Yybp0mudRXfbJbA2sgqZiGfHK5.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpigxjLBV1hqnzfr-F8sEYMB0Yybp0mudRfp66PAGEki52WfA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpkgxjLBV1hqnzfr-F8sEYMB0Yybp0mudRXfbJ3BGsgqZiGfHK5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpigxjLBV1hqnzfr-F8sEYMB0Yybp0mudRfw6-PAGEki52WfA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpkgxjLBV1hqnzfr-F8sEYMB0Yybp0mudRXfbITBWsgqZiGfHK5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpigxjLBV1hqnzfr-F8sEYMB0Yybp0mudRf36yPAGEki52WfA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpkgxjLBV1hqnzfr-F8sEYMB0Yybp0mudRXfbIPBmsgqZiGfHK5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpigxjLBV1hqnzfr-F8sEYMB0Yybp0mudRf-62PAGEki52WfA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barlowsemicondensed/v16/wlpkgxjLBV1hqnzfr-F8sEYMB0Yybp0mudRXfbIrB2sgqZiGfHK5.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-barriecito",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fd4022b5-7d2a-4a9b-9cba-225d912737f2",1935490056),$APP.$cljs$cst$2675$family$$,"Barriecito",$APP.$cljs$cst$725$name$$,"Barriecito",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barriecito/v18/WWXXlj-CbBOSLY2QTuY_KdUiYwTO0MU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-barrio",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("354fb1cc-3408-4abb-9694-862da0cb5ffe",-1317778418),$APP.$cljs$cst$2675$family$$,"Barrio",$APP.$cljs$cst$725$name$$,"Barrio",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/barrio/v20/wEO8EBXBk8hBIDiEdQYhWdsX1Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-basic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3facc009-309e-4783-999c-31e0668f4e8e",
-702936804),$APP.$cljs$cst$2675$family$$,"Basic",$APP.$cljs$cst$725$name$$,"Basic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/basic/v18/xfu_0WLxV2_XKQN34lDVyR7D.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-baskervville",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("02608ffa-daf3-442b-9d2c-3244a57d5f8f",6853999),$APP.$cljs$cst$2675$family$$,"Baskervville",$APP.$cljs$cst$725$name$$,"Baskervville",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baskervville/v20/YA9Br0yU4l_XOrogbkun3kQ6vLFYXmpq8sRsYuDrugOydR1FLkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baskervville/v20/YA9Br0yU4l_XOrogbkun3kQ6vLFYXmpq8sRsYtLrugOydR1FLkw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baskervville/v20/YA9Br0yU4l_XOrogbkun3kQ6vLFYXmpq8sRsYj7sugOydR1FLkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baskervville/v20/YA9Br0yU4l_XOrogbkun3kQ6vLFYXmpq8sRsYgfsugOydR1FLkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baskervville/v20/YA9Hr0yU4l_XOrogbkun3kQQtYOnhgMBaGprdyioUkC4cT9APkyagA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baskervville/v20/YA9Hr0yU4l_XOrogbkun3kQQtYOnhgMBaGprdyioYEC4cT9APkyagA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/baskervville/v20/YA9Hr0yU4l_XOrogbkun3kQQtYOnhgMBaGprdyiojEe4cT9APkyagA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baskervville/v20/YA9Hr0yU4l_XOrogbkun3kQQtYOnhgMBaGprdyiotUe4cT9APkyagA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-baskervville-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cb8c1cb4-fe1b-445e-99ea-9072f26c1fc3",787224616),$APP.$cljs$cst$2675$family$$,"Baskervville SC",$APP.$cljs$cst$725$name$$,"Baskervville SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baskervvillesc/v4/X7ny4bc_DeKlh6bBbk_WiKnBSUvL5HaHbrgS1MXKHjziXM3kPWntDsg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baskervvillesc/v4/X7ny4bc_DeKlh6bBbk_WiKnBSUvL5HaHbrgS1MXKHg7iXM3kPWntDsg.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baskervvillesc/v4/X7ny4bc_DeKlh6bBbk_WiKnBSUvL5HaHbrgS1MXKHuLlXM3kPWntDsg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baskervvillesc/v4/X7ny4bc_DeKlh6bBbk_WiKnBSUvL5HaHbrgS1MXKHtvlXM3kPWntDsg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-battambang",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("641acb8e-2b9b-4179-8bcb-e33ae7bfefdc",-947891409),$APP.$cljs$cst$2675$family$$,"Battambang",$APP.$cljs$cst$725$name$$,"Battambang",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/battambang/v26/uk-kEGe7raEw-HjkzZabNhGp5w50_o9T7Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/battambang/v26/uk-lEGe7raEw-HjkzZabNtmLxyRa8oZK9I0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/battambang/v26/uk-mEGe7raEw-HjkzZabDnWj4yxx7o8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",
$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/battambang/v26/uk-lEGe7raEw-HjkzZabNsmMxyRa8oZK9I0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/battambang/v26/uk-lEGe7raEw-HjkzZabNvGOxyRa8oZK9I0.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-baumans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d3ef9eb2-c16f-4745-95e0-558a2dfdd22f",1774253934),$APP.$cljs$cst$2675$family$$,"Baumans",$APP.$cljs$cst$725$name$$,"Baumans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/baumans/v18/-W_-XJj9QyTd3QfpR_oyaksqY5Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bayon",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("03d471ee-f149-468e-994e-3d8c061ae1df",2018425978),$APP.$cljs$cst$2675$family$$,"Bayon",$APP.$cljs$cst$725$name$$,"Bayon",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bayon/v36/9XUrlJNmn0LPFl-pOhYEd2NJ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-be-vietnam-pro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dfb71ecd-19f4-418c-a6af-0549a66af2f4",1849477658),$APP.$cljs$cst$2675$family$$,
"Be Vietnam Pro",$APP.$cljs$cst$725$name$$,"Be Vietnam Pro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVNSTAyLFyeg_IDWvOJmVES_HRUBX8YYbAiah8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVLSTAyLFyeg_IDWvOJmVES_HwyPRsSZZIneh-waA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVMSTAyLFyeg_IDWvOJmVES_HT4JF8yT7wrcwap.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVKSTAyLFyeg_IDWvOJmVES_HwyPbczRbgJdhapcUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVMSTAyLFyeg_IDWvOJmVES_HScJ18yT7wrcwap.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVKSTAyLFyeg_IDWvOJmVES_HwyPdMwRbgJdhapcUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVPSTAyLFyeg_IDWvOJmVES_EwwD3s6ZKAi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVNSTAyLFyeg_IDWvOJmVES_HwyBX8YYbAiah8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVMSTAyLFyeg_IDWvOJmVES_HTEJl8yT7wrcwap.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVKSTAyLFyeg_IDWvOJmVES_HwyPYsxRbgJdhapcUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVMSTAyLFyeg_IDWvOJmVES_HToIV8yT7wrcwap.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVKSTAyLFyeg_IDWvOJmVES_HwyPac2RbgJdhapcUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVMSTAyLFyeg_IDWvOJmVES_HSMIF8yT7wrcwap.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVKSTAyLFyeg_IDWvOJmVES_HwyPcM3RbgJdhapcUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVMSTAyLFyeg_IDWvOJmVES_HSQI18yT7wrcwap.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVKSTAyLFyeg_IDWvOJmVES_HwyPd80RbgJdhapcUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVMSTAyLFyeg_IDWvOJmVES_HS0Il8yT7wrcwap.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevietnampro/v12/QdVKSTAyLFyeg_IDWvOJmVES_HwyPfs1RbgJdhapcUU.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-beau-rivage",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e4fec75a-3f18-4459-a2a2-efe846fbb92a",1807056385),$APP.$cljs$cst$2675$family$$,"Beau Rivage",$APP.$cljs$cst$725$name$$,"Beau Rivage",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/beaurivage/v2/UcCi3FIgIG2bH4mMNWJUlmg3NZp8K2sL.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bebas-neue",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("00b5b776-87ee-4aff-807f-d7dd699cec10",-845538617),$APP.$cljs$cst$2675$family$$,"Bebas Neue",$APP.$cljs$cst$725$name$$,"Bebas Neue",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bebasneue/v16/JTUSjIg69CK48gW7PXooxW5rygbi49c.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-beiruti",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("4f197dd5-19ff-4c95-a3a6-1bdad20b6834",79812942),$APP.$cljs$cst$2675$family$$,"Beiruti",$APP.$cljs$cst$725$name$$,"Beiruti",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/beiruti/v5/JTUIjIU69Cmr9FGcYgRFEb7cdQn2-9Y95wujgWg2SGdV.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/beiruti/v5/JTUIjIU69Cmr9FGcYgRFEb7cdQn2-9bj5wujgWg2SGdV.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/beiruti/v5/JTUIjIU69Cmr9FGcYgRFEb7cdQn2-9a95wujgWg2SGdV.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/beiruti/v5/JTUIjIU69Cmr9FGcYgRFEb7cdQn2-9aP5wujgWg2SGdV.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/beiruti/v5/JTUIjIU69Cmr9FGcYgRFEb7cdQn2-9Zj4AujgWg2SGdV.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/beiruti/v5/JTUIjIU69Cmr9FGcYgRFEb7cdQn2-9Za4AujgWg2SGdV.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/beiruti/v5/JTUIjIU69Cmr9FGcYgRFEb7cdQn2-9Y94AujgWg2SGdV.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/beiruti/v5/JTUIjIU69Cmr9FGcYgRFEb7cdQn2-9YU4AujgWg2SGdV.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-belanosima",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("13f76341-81ad-460d-a2b6-edd17f3cf1dc",-1315419698),$APP.$cljs$cst$2675$family$$,"Belanosima",$APP.$cljs$cst$725$name$$,"Belanosima",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/belanosima/v4/3y9k6bI8ejDo_3MfCDSLxABbF3JBg54.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/belanosima/v4/3y9n6bI8ejDo_3MfCDSL_Nh1M3pqn5cdJ-4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/belanosima/v4/3y9n6bI8ejDo_3MfCDSL_Lx0M3pqn5cdJ-4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-belgrano",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("89fe2076-a54f-4521-8451-b5d320668f2e",579594930),$APP.$cljs$cst$2675$family$$,"Belgrano",$APP.$cljs$cst$725$name$$,"Belgrano",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/belgrano/v19/55xvey5tM9rwKWrJZcMFirl08KDJ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bellefair",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4053df8f-e580-4225-b390-a0d0d7ee43f7",-1300200285),$APP.$cljs$cst$2675$family$$,"Bellefair",$APP.$cljs$cst$725$name$$,"Bellefair",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bellefair/v15/kJExBuYY6AAuhiXUxG19__A2pOdvDA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-belleza",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b21c44e1-00bb-4bfb-87f9-3773eff10a70",-636799907),$APP.$cljs$cst$2675$family$$,"Belleza",$APP.$cljs$cst$725$name$$,"Belleza",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/belleza/v18/0nkoC9_pNeMfhX4BtcbyawzruP8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bellota",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("815cb0c6-91e6-4265-98c2-d1e6b78aec4d",
-1254448714),$APP.$cljs$cst$2675$family$$,"Bellota",$APP.$cljs$cst$725$name$$,"Bellota",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bellota/v17/MwQzbhXl3_qEpiwAID55kGMViblPtXs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bellota/v17/MwQxbhXl3_qEpiwAKJBjHGEfjZtKpXulTQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bellota/v17/MwQ2bhXl3_qEpiwAGJJRtGs-lbA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bellota/v17/MwQ0bhXl3_qEpiwAKJBbsEk7hbBWrA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bellota/v17/MwQzbhXl3_qEpiwAIC5-kGMViblPtXs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bellota/v17/MwQxbhXl3_qEpiwAKJBjDGYfjZtKpXulTQ.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bellota-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8534ca52-554f-4b3d-9648-f9492d7a074a",517579571),$APP.$cljs$cst$2675$family$$,"Bellota Text",$APP.$cljs$cst$725$name$$,"Bellota Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bellotatext/v20/0FlMVP2VnlWS4f3-UE9hHXM5VfsqfQXwQy6yxg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bellotatext/v20/0FlOVP2VnlWS4f3-UE9hHXMx--Gmfw_0YSuixmYK.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bellotatext/v20/0FlTVP2VnlWS4f3-UE9hHXMB-dMOdS7sSg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bellotatext/v20/0FlNVP2VnlWS4f3-UE9hHXMx-9kKVyv8Sjer.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bellotatext/v20/0FlMVP2VnlWS4f3-UE9hHXM5RfwqfQXwQy6yxg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",
$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bellotatext/v20/0FlOVP2VnlWS4f3-UE9hHXMx--G2eA_0YSuixmYK.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-benchnine",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f29c89cb-214e-4c66-b78c-ef46ed4add8c",429032875),$APP.$cljs$cst$2675$family$$,"BenchNine",$APP.$cljs$cst$725$name$$,"BenchNine",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/benchnine/v17/ahcev8612zF4jxrwMosT--tRhWa8q0v8ag.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/benchnine/v17/ahcbv8612zF4jxrwMosrV8N1jU2gog.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/benchnine/v17/ahcev8612zF4jxrwMosT6-xRhWa8q0v8ag.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-benne",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b5c2b3b1-5e15-404b-b7da-4e12e24e20d4",-194323404),$APP.$cljs$cst$2675$family$$,"Benne",$APP.$cljs$cst$725$name$$,"Benne",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/benne/v24/L0xzDFAhn18E6Vjxlt6qTDBN.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bentham",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d053dc06-ac33-45d9-be4a-3f188054abeb",-133560031),$APP.$cljs$cst$2675$family$$,"Bentham",$APP.$cljs$cst$725$name$$,"Bentham",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bentham/v20/VdGeAZQPEpYfmHglKWw7CJaK_y4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-berkshire-swash",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9c6c59f3-fc18-4938-9e11-73d57662a51c",
1667157086),$APP.$cljs$cst$2675$family$$,"Berkshire Swash",$APP.$cljs$cst$725$name$$,"Berkshire Swash",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/berkshireswash/v22/ptRRTi-cavZOGqCvnNJDl5m5XmNPrcQybX4pQA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-besley",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5979b1e7-beaa-4cec-9ce9-3e56bb7623d1",2084718976),$APP.$cljs$cst$2675$family$$,"Besley",$APP.$cljs$cst$725$name$$,"Besley",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/besley/v22/PlIhFlO1MaNwaNGWUC92IOH_mtG4fbbBSdRoFPOl8-E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/besley/v22/PlIhFlO1MaNwaNGWUC92IOH_mtG4fYTBSdRoFPOl8-E.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/besley/v22/PlIhFlO1MaNwaNGWUC92IOH_mtG4fWjGSdRoFPOl8-E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/besley/v22/PlIhFlO1MaNwaNGWUC92IOH_mtG4fVHGSdRoFPOl8-E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/besley/v22/PlIhFlO1MaNwaNGWUC92IOH_mtG4fTbGSdRoFPOl8-E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,
"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/besley/v22/PlIhFlO1MaNwaNGWUC92IOH_mtG4fR_GSdRoFPOl8-E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/besley/v22/PlIjFlO1MaNwaNG8WR2J-IiUAH-_aH6CoZdiENGg4-E04A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/besley/v22/PlIjFlO1MaNwaNG8WR2J-IiUAH-_aH6Ck5diENGg4-E04A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/besley/v22/PlIjFlO1MaNwaNG8WR2J-IiUAH-_aH6Cf5BiENGg4-E04A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/besley/v22/PlIjFlO1MaNwaNG8WR2J-IiUAH-_aH6CRpBiENGg4-E04A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/besley/v22/PlIjFlO1MaNwaNG8WR2J-IiUAH-_aH6CIZBiENGg4-E04A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/besley/v22/PlIjFlO1MaNwaNG8WR2J-IiUAH-_aH6CCJBiENGg4-E04A.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-beth-ellen",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e99fab42-fa7a-4ef4-ad83-40e3905f1d58",585648628),$APP.$cljs$cst$2675$family$$,"Beth Ellen",$APP.$cljs$cst$725$name$$,"Beth Ellen",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bethellen/v22/WwkbxPW2BE-3rb_JNT-qEIAiVNo5xNY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bevan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9989b32b-fdc0-45e8-8607-095949021708",-1400600899),$APP.$cljs$cst$2675$family$$,"Bevan",$APP.$cljs$cst$725$name$$,"Bevan",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevan/v26/4iCj6KZ0a9NXjF8aUir7tlSJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bevan/v26/4iCt6KZ0a9NXjG8YWC7Zs0SJD4U.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bhutuka-expanded-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f1fb4d52-06f7-40a3-bcc6-dd8d7611e13e",1519042846),$APP.$cljs$cst$2675$family$$,"BhuTuka Expanded One",$APP.$cljs$cst$725$name$$,"BhuTuka Expanded One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bhutukaexpandedone/v9/SLXXc0jZ4WUJcClHTtv0t7IaDRsBsWRiJCyX8pg_RVH1.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-big-shoulders",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("66dd432e-9e09-4f2d-99f1-6d897afb021c",
-1502412730),$APP.$cljs$cst$2675$family$$,"Big Shoulders",$APP.$cljs$cst$725$name$$,"Big Shoulders",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshoulders/v4/qFdk35CPh40oITJ69S3GFqy5-BQAcbz7z7beObrv_PytqyTi33thrko9SOL9ANM1LlZAtA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshoulders/v4/qFdk35CPh40oITJ69S3GFqy5-BQAcbz7z7beObrv_PytqyTi33thrko9yOP9ANM1LlZAtA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshoulders/v4/qFdk35CPh40oITJ69S3GFqy5-BQAcbz7z7beObrv_PytqyTi33thrko9FuP9ANM1LlZAtA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshoulders/v4/qFdk35CPh40oITJ69S3GFqy5-BQAcbz7z7beObrv_PytqyTi33thrko9SOP9ANM1LlZAtA.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshoulders/v4/qFdk35CPh40oITJ69S3GFqy5-BQAcbz7z7beObrv_PytqyTi33thrko9euP9ANM1LlZAtA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshoulders/v4/qFdk35CPh40oITJ69S3GFqy5-BQAcbz7z7beObrv_PytqyTi33thrko9luT9ANM1LlZAtA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshoulders/v4/qFdk35CPh40oITJ69S3GFqy5-BQAcbz7z7beObrv_PytqyTi33thrko9r-T9ANM1LlZAtA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshoulders/v4/qFdk35CPh40oITJ69S3GFqy5-BQAcbz7z7beObrv_PytqyTi33thrko9yOT9ANM1LlZAtA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshoulders/v4/qFdk35CPh40oITJ69S3GFqy5-BQAcbz7z7beObrv_PytqyTi33thrko94eT9ANM1LlZAtA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-big-shoulders-inline",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5dd3ecd4-029b-4b54-9c19-5462cdf71d7d",-1025367363),$APP.$cljs$cst$2675$family$$,"Big Shoulders Inline",$APP.$cljs$cst$725$name$$,"Big Shoulders Inline",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersinline/v4/bx68NwSCkev-8u0YNXAF6gArLyznvspgMZDcnsTZieUyOqQzOiBfauOMaRhGeKwO1nHb-oUTA-kSKkM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersinline/v4/bx68NwSCkev-8u0YNXAF6gArLyznvspgMZDcnsTZieUyOqQzOiBfauOMaRhGeKwO1vHa-oUTA-kSKkM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersinline/v4/bx68NwSCkev-8u0YNXAF6gArLyznvspgMZDcnsTZieUyOqQzOiBfauOMaRhGeKwO1i_a-oUTA-kSKkM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersinline/v4/bx68NwSCkev-8u0YNXAF6gArLyznvspgMZDcnsTZieUyOqQzOiBfauOMaRhGeKwO1nHa-oUTA-kSKkM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersinline/v4/bx68NwSCkev-8u0YNXAF6gArLyznvspgMZDcnsTZieUyOqQzOiBfauOMaRhGeKwO1kPa-oUTA-kSKkM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersinline/v4/bx68NwSCkev-8u0YNXAF6gArLyznvspgMZDcnsTZieUyOqQzOiBfauOMaRhGeKwO1q_d-oUTA-kSKkM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersinline/v4/bx68NwSCkev-8u0YNXAF6gArLyznvspgMZDcnsTZieUyOqQzOiBfauOMaRhGeKwO1pbd-oUTA-kSKkM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersinline/v4/bx68NwSCkev-8u0YNXAF6gArLyznvspgMZDcnsTZieUyOqQzOiBfauOMaRhGeKwO1vHd-oUTA-kSKkM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersinline/v4/bx68NwSCkev-8u0YNXAF6gArLyznvspgMZDcnsTZieUyOqQzOiBfauOMaRhGeKwO1tjd-oUTA-kSKkM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-big-shoulders-stencil",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3bb6d6b3-bfcd-43bf-aa05-3a3349984305",
-1424412184),$APP.$cljs$cst$2675$family$$,"Big Shoulders Stencil",$APP.$cljs$cst$725$name$$,"Big Shoulders Stencil",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersstencil/v4/TwM2-JIEQ1Je5sI6Bx1TKHD83rT3u3NSCfbFxqa9oQbR_CiZMgOzPB7iSLKdsgE9Sp2x5OZJnqtwIp4I.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersstencil/v4/TwM2-JIEQ1Je5sI6Bx1TKHD83rT3u3NSCfbFxqa9oQbR_CiZMgOzPB7iSLKdsgE9Sp0x5eZJnqtwIp4I.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersstencil/v4/TwM2-JIEQ1Je5sI6Bx1TKHD83rT3u3NSCfbFxqa9oQbR_CiZMgOzPB7iSLKdsgE9Sp3v5eZJnqtwIp4I.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersstencil/v4/TwM2-JIEQ1Je5sI6Bx1TKHD83rT3u3NSCfbFxqa9oQbR_CiZMgOzPB7iSLKdsgE9Sp2x5eZJnqtwIp4I.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersstencil/v4/TwM2-JIEQ1Je5sI6Bx1TKHD83rT3u3NSCfbFxqa9oQbR_CiZMgOzPB7iSLKdsgE9Sp2D5eZJnqtwIp4I.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersstencil/v4/TwM2-JIEQ1Je5sI6Bx1TKHD83rT3u3NSCfbFxqa9oQbR_CiZMgOzPB7iSLKdsgE9Sp1v4uZJnqtwIp4I.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersstencil/v4/TwM2-JIEQ1Je5sI6Bx1TKHD83rT3u3NSCfbFxqa9oQbR_CiZMgOzPB7iSLKdsgE9Sp1W4uZJnqtwIp4I.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersstencil/v4/TwM2-JIEQ1Je5sI6Bx1TKHD83rT3u3NSCfbFxqa9oQbR_CiZMgOzPB7iSLKdsgE9Sp0x4uZJnqtwIp4I.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigshouldersstencil/v4/TwM2-JIEQ1Je5sI6Bx1TKHD83rT3u3NSCfbFxqa9oQbR_CiZMgOzPB7iSLKdsgE9Sp0Y4uZJnqtwIp4I.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bigelow-rules",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f0533525-c858-4a01-8306-32627637adf0",-839306299),$APP.$cljs$cst$2675$family$$,"Bigelow Rules",$APP.$cljs$cst$725$name$$,"Bigelow Rules",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bigelowrules/v31/RrQWboly8iR_I3KWSzeRuN0zT4cCH8WAJVk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bigshot-one",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("eeb1f93c-5b77-4e57-a804-8b835952c031",-1248984461),$APP.$cljs$cst$2675$family$$,"Bigshot One",$APP.$cljs$cst$725$name$$,"Bigshot One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bigshotone/v31/u-470qukhRkkO6BD_7cM_gxuUQJBXv_-.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bilbo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("641de6b4-0401-4222-83e8-5c5805cb9f4b",1378899782),$APP.$cljs$cst$2675$family$$,"Bilbo",$APP.$cljs$cst$725$name$$,"Bilbo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bilbo/v21/o-0EIpgpwWwZ210hpIRz4wxE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bilbo-swash-caps",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("28fe386b-166f-434b-9f45-6ccd612c2164",-1259144363),$APP.$cljs$cst$2675$family$$,"Bilbo Swash Caps",$APP.$cljs$cst$725$name$$,
"Bilbo Swash Caps",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bilboswashcaps/v23/zrf-0GXbz-H3Wb4XBsGrTgq2PVmdqAPopiRfKp8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-biorhyme",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0d491eda-5464-4a86-ba24-ac188202964e",30429706),$APP.$cljs$cst$2675$family$$,"BioRhyme",$APP.$cljs$cst$725$name$$,"BioRhyme",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biorhyme/v21/1cXeaULHBpDMsHYW_GZNh7loEHurwOIGadI205trrbeBgQs4OrIimiaki-gkRDE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biorhyme/v21/1cXeaULHBpDMsHYW_GZNh7loEHurwOIGadI205trrbeBgQs4Omwimiaki-gkRDE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biorhyme/v21/1cXeaULHBpDMsHYW_GZNh7loEHurwOIGadI205trrbeBgQs4OjIimiaki-gkRDE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biorhyme/v21/1cXeaULHBpDMsHYW_GZNh7loEHurwOIGadI205trrbeBgQs4OgAimiaki-gkRDE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biorhyme/v21/1cXeaULHBpDMsHYW_GZNh7loEHurwOIGadI205trrbeBgQs4Ouwlmiaki-gkRDE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biorhyme/v21/1cXeaULHBpDMsHYW_GZNh7loEHurwOIGadI205trrbeBgQs4OtUlmiaki-gkRDE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biorhyme/v21/1cXeaULHBpDMsHYW_GZNh7loEHurwOIGadI205trrbeBgQs4OrIlmiaki-gkRDE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-biorhyme-expanded",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c4dcf981-2009-4033-bb25-58fe7ad658e8",-47970109),$APP.$cljs$cst$2675$family$$,"BioRhyme Expanded",$APP.$cljs$cst$725$name$$,"BioRhyme Expanded",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biorhymeexpanded/v23/i7dVIE1zZzytGswgU577CDY9LjbffxxcblSHSdTXrb_z.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biorhymeexpanded/v23/i7dVIE1zZzytGswgU577CDY9Ljbffxw4bVSHSdTXrb_z.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biorhymeexpanded/v23/i7dQIE1zZzytGswgU577CDY9LjbffySURXCPYsje.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biorhymeexpanded/v23/i7dVIE1zZzytGswgU577CDY9LjbffxwoalSHSdTXrb_z.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biorhymeexpanded/v23/i7dVIE1zZzytGswgU577CDY9Ljbffxw0aVSHSdTXrb_z.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-birthstone",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a63ba18e-cc5f-4289-818d-f1b61f372a9c",
1672255916),$APP.$cljs$cst$2675$family$$,"Birthstone",$APP.$cljs$cst$725$name$$,"Birthstone",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/birthstone/v16/8AtsGs2xO4yLRhy87sv_HLn5jRfZHzM.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-birthstone-bounce",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a4120f21-11ad-4b51-8921-1e00db6299ff",1676606694),$APP.$cljs$cst$2675$family$$,"Birthstone Bounce",$APP.$cljs$cst$725$name$$,"Birthstone Bounce",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/birthstonebounce/v13/ga6XaxZF43lIvTWrktHOTBJZGH7dEeVJGIMYDo_8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/birthstonebounce/v13/ga6SaxZF43lIvTWrktHOTBJZGH7dEd29MacQJZP1LmD9.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-biryani",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("54d6c5f2-9fed-45f7-9a6b-330ab8cd42a2",-1034270376),$APP.$cljs$cst$2675$family$$,"Biryani",$APP.$cljs$cst$725$name$$,"Biryani",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biryani/v15/hv-TlzNxIFoO84YddYQyGTBSU-J-RxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biryani/v15/hv-TlzNxIFoO84YddeAxGTBSU-J-RxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biryani/v15/hv-WlzNxIFoO84YdTUwZPTh5T-s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biryani/v15/hv-TlzNxIFoO84YddZQ3GTBSU-J-RxQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biryani/v15/hv-TlzNxIFoO84YddfA2GTBSU-J-RxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/biryani/v15/hv-TlzNxIFoO84Yddew1GTBSU-J-RxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/biryani/v15/hv-TlzNxIFoO84Yddcg0GTBSU-J-RxQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bitcount",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("6ac18d8c-80d7-4304-adb9-4baa695e5979",574872704),$APP.$cljs$cst$2675$family$$,"Bitcount",$APP.$cljs$cst$725$name$$,"Bitcount",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcount/v3/ijxXs53kQsE1Y5J-lI1wubXnlQH-1-E1LhaU1dJRZZaHU0slfybi9GQwiTv06bjtugLjdPqK3d9XKDqRc2jrJlC4ZRsgxqxP-aVoJVvr06JyZBdg54o.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcount/v3/ijxXs53kQsE1Y5J-lI1wubXnlQH-1-E1LhaU1dJRZZaHU0slfybi9GQwiTv06bjtugLjdPqK3d9XKDqRc2jrJlC4ZRsgxqxP-aVoJdvq06JyZBdg54o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcount/v3/ijxXs53kQsE1Y5J-lI1wubXnlQH-1-E1LhaU1dJRZZaHU0slfybi9GQwiTv06bjtugLjdPqK3d9XKDqRc2jrJlC4ZRsgxqxP-aVoJQXq06JyZBdg54o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcount/v3/ijxXs53kQsE1Y5J-lI1wubXnlQH-1-E1LhaU1dJRZZaHU0slfybi9GQwiTv06bjtugLjdPqK3d9XKDqRc2jrJlC4ZRsgxqxP-aVoJVvq06JyZBdg54o.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcount/v3/ijxXs53kQsE1Y5J-lI1wubXnlQH-1-E1LhaU1dJRZZaHU0slfybi9GQwiTv06bjtugLjdPqK3d9XKDqRc2jrJlC4ZRsgxqxP-aVoJWnq06JyZBdg54o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcount/v3/ijxXs53kQsE1Y5J-lI1wubXnlQH-1-E1LhaU1dJRZZaHU0slfybi9GQwiTv06bjtugLjdPqK3d9XKDqRc2jrJlC4ZRsgxqxP-aVoJYXt06JyZBdg54o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcount/v3/ijxXs53kQsE1Y5J-lI1wubXnlQH-1-E1LhaU1dJRZZaHU0slfybi9GQwiTv06bjtugLjdPqK3d9XKDqRc2jrJlC4ZRsgxqxP-aVoJbzt06JyZBdg54o.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcount/v3/ijxXs53kQsE1Y5J-lI1wubXnlQH-1-E1LhaU1dJRZZaHU0slfybi9GQwiTv06bjtugLjdPqK3d9XKDqRc2jrJlC4ZRsgxqxP-aVoJdvt06JyZBdg54o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,
"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcount/v3/ijxXs53kQsE1Y5J-lI1wubXnlQH-1-E1LhaU1dJRZZaHU0slfybi9GQwiTv06bjtugLjdPqK3d9XKDqRc2jrJlC4ZRsgxqxP-aVoJfLt06JyZBdg54o.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bitcount-grid-double",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fa820a79-beef-465b-a96c-d004b925c598",499452951),$APP.$cljs$cst$2675$family$$,"Bitcount Grid Double",$APP.$cljs$cst$725$name$$,
"Bitcount Grid Double",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddouble/v3/WBK7rFjbakJVFOargiWSKQysDITG_S0VtG0x3HD2FYHVdlZI-rLlahmEAPp8wjYMvkPq48MVQo5RQf2svjnxa5Anx8-Y-pHdkVb0ByRHaxzbXaLbA9wfZDxleZEXi_Ul10k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddouble/v3/WBK7rFjbakJVFOargiWSKQysDITG_S0VtG0x3HD2FYHVdlZI-rLlahmEAPp8wjYMvkPq48MVQo5RQf2svjnxa5Anx8-Y-pHdkVb0ByRHaxzbXaLbA9wfZLxkeZEXi_Ul10k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddouble/v3/WBK7rFjbakJVFOargiWSKQysDITG_S0VtG0x3HD2FYHVdlZI-rLlahmEAPp8wjYMvkPq48MVQo5RQf2svjnxa5Anx8-Y-pHdkVb0ByRHaxzbXaLbA9wfZGJkeZEXi_Ul10k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bitcountgriddouble/v3/WBK7rFjbakJVFOargiWSKQysDITG_S0VtG0x3HD2FYHVdlZI-rLlahmEAPp8wjYMvkPq48MVQo5RQf2svjnxa5Anx8-Y-pHdkVb0ByRHaxzbXaLbA9wfZDxkeZEXi_Ul10k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddouble/v3/WBK7rFjbakJVFOargiWSKQysDITG_S0VtG0x3HD2FYHVdlZI-rLlahmEAPp8wjYMvkPq48MVQo5RQf2svjnxa5Anx8-Y-pHdkVb0ByRHaxzbXaLbA9wfZA5keZEXi_Ul10k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddouble/v3/WBK7rFjbakJVFOargiWSKQysDITG_S0VtG0x3HD2FYHVdlZI-rLlahmEAPp8wjYMvkPq48MVQo5RQf2svjnxa5Anx8-Y-pHdkVb0ByRHaxzbXaLbA9wfZOJjeZEXi_Ul10k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddouble/v3/WBK7rFjbakJVFOargiWSKQysDITG_S0VtG0x3HD2FYHVdlZI-rLlahmEAPp8wjYMvkPq48MVQo5RQf2svjnxa5Anx8-Y-pHdkVb0ByRHaxzbXaLbA9wfZNtjeZEXi_Ul10k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bitcountgriddouble/v3/WBK7rFjbakJVFOargiWSKQysDITG_S0VtG0x3HD2FYHVdlZI-rLlahmEAPp8wjYMvkPq48MVQo5RQf2svjnxa5Anx8-Y-pHdkVb0ByRHaxzbXaLbA9wfZLxjeZEXi_Ul10k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddouble/v3/WBK7rFjbakJVFOargiWSKQysDITG_S0VtG0x3HD2FYHVdlZI-rLlahmEAPp8wjYMvkPq48MVQo5RQf2svjnxa5Anx8-Y-pHdkVb0ByRHaxzbXaLbA9wfZJVjeZEXi_Ul10k.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bitcount-grid-double-ink",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b93908bd-e35d-486d-86c8-1d42d70dad0a",-1063269881),$APP.$cljs$cst$2675$family$$,"Bitcount Grid Double Ink",$APP.$cljs$cst$725$name$$,"Bitcount Grid Double Ink",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddoubleink/v2/55zMcCw3FN_jOGTSZJcl588VlZiMRBEu8MNfAa1hTmcIC-EgZzYwMlaO_awRPudtyc3Y6uQYyaHkeKGSq8TU4RVR7xpYN_MnWZejEGOGrT-NcapoFhvUOhVjLNJ2XCLrbMxtAR6SYY1mL-OvDnjOVsnRj34-p6VMvv549Lg7J4HRX7TqUxwskRMxVR7_3L-QRhDtbv8kM-EDNmBQr1-hsC1tMPJC0vkO2JhzR07bFhBRdj-elg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddoubleink/v2/55zMcCw3FN_jOGTSZJcl588VlZiMRBEu8MNfAa1hTmcIC-EgZzYwMlaO_awRPudtyc3Y6uQYyaHkeKGSq8TU4RVR7xpYN_MnWZejEGOGrT-NcapoFhvUOhVjLNJ2XCLrbMxtAR6SYY1mL-OvDnjOVsnRj34-p6VMvv549Lg7J4HRX7TqUxwskRMxVR7_3L-QRhDtbv8kM-EDNmBQr1-hsC1tMPJC0vkO2Jhzx0_bFhBRdj-elg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddoubleink/v2/55zMcCw3FN_jOGTSZJcl588VlZiMRBEu8MNfAa1hTmcIC-EgZzYwMlaO_awRPudtyc3Y6uQYyaHkeKGSq8TU4RVR7xpYN_MnWZejEGOGrT-NcapoFhvUOhVjLNJ2XCLrbMxtAR6SYY1mL-OvDnjOVsnRj34-p6VMvv549Lg7J4HRX7TqUxwskRMxVR7_3L-QRhDtbv8kM-EDNmBQr1-hsC1tMPJC0vkO2JhzGU_bFhBRdj-elg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddoubleink/v2/55zMcCw3FN_jOGTSZJcl588VlZiMRBEu8MNfAa1hTmcIC-EgZzYwMlaO_awRPudtyc3Y6uQYyaHkeKGSq8TU4RVR7xpYN_MnWZejEGOGrT-NcapoFhvUOhVjLNJ2XCLrbMxtAR6SYY1mL-OvDnjOVsnRj34-p6VMvv549Lg7J4HRX7TqUxwskRMxVR7_3L-QRhDtbv8kM-EDNmBQr1-hsC1tMPJC0vkO2JhzR0_bFhBRdj-elg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddoubleink/v2/55zMcCw3FN_jOGTSZJcl588VlZiMRBEu8MNfAa1hTmcIC-EgZzYwMlaO_awRPudtyc3Y6uQYyaHkeKGSq8TU4RVR7xpYN_MnWZejEGOGrT-NcapoFhvUOhVjLNJ2XCLrbMxtAR6SYY1mL-OvDnjOVsnRj34-p6VMvv549Lg7J4HRX7TqUxwskRMxVR7_3L-QRhDtbv8kM-EDNmBQr1-hsC1tMPJC0vkO2JhzdU_bFhBRdj-elg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddoubleink/v2/55zMcCw3FN_jOGTSZJcl588VlZiMRBEu8MNfAa1hTmcIC-EgZzYwMlaO_awRPudtyc3Y6uQYyaHkeKGSq8TU4RVR7xpYN_MnWZejEGOGrT-NcapoFhvUOhVjLNJ2XCLrbMxtAR6SYY1mL-OvDnjOVsnRj34-p6VMvv549Lg7J4HRX7TqUxwskRMxVR7_3L-QRhDtbv8kM-EDNmBQr1-hsC1tMPJC0vkO2JhzmUjbFhBRdj-elg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddoubleink/v2/55zMcCw3FN_jOGTSZJcl588VlZiMRBEu8MNfAa1hTmcIC-EgZzYwMlaO_awRPudtyc3Y6uQYyaHkeKGSq8TU4RVR7xpYN_MnWZejEGOGrT-NcapoFhvUOhVjLNJ2XCLrbMxtAR6SYY1mL-OvDnjOVsnRj34-p6VMvv549Lg7J4HRX7TqUxwskRMxVR7_3L-QRhDtbv8kM-EDNmBQr1-hsC1tMPJC0vkO2JhzoEjbFhBRdj-elg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddoubleink/v2/55zMcCw3FN_jOGTSZJcl588VlZiMRBEu8MNfAa1hTmcIC-EgZzYwMlaO_awRPudtyc3Y6uQYyaHkeKGSq8TU4RVR7xpYN_MnWZejEGOGrT-NcapoFhvUOhVjLNJ2XCLrbMxtAR6SYY1mL-OvDnjOVsnRj34-p6VMvv549Lg7J4HRX7TqUxwskRMxVR7_3L-QRhDtbv8kM-EDNmBQr1-hsC1tMPJC0vkO2Jhzx0jbFhBRdj-elg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgriddoubleink/v2/55zMcCw3FN_jOGTSZJcl588VlZiMRBEu8MNfAa1hTmcIC-EgZzYwMlaO_awRPudtyc3Y6uQYyaHkeKGSq8TU4RVR7xpYN_MnWZejEGOGrT-NcapoFhvUOhVjLNJ2XCLrbMxtAR6SYY1mL-OvDnjOVsnRj34-p6VMvv549Lg7J4HRX7TqUxwskRMxVR7_3L-QRhDtbv8kM-EDNmBQr1-hsC1tMPJC0vkO2Jhz7kjbFhBRdj-elg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-bitcount-grid-single",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6311e4c9-22cb-43c5-9539-6027fb426130",954987261),$APP.$cljs$cst$2675$family$$,"Bitcount Grid Single",$APP.$cljs$cst$725$name$$,"Bitcount Grid Single",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingle/v3/cY8bfi2OU1tLpjaqQveNvbC2qfsuQPDVASHjTcBszBsXfC5C9kAKu8QoqnfqMiS4gVij5yxO41San7UnNMBH-Y9u33JUGFdHpUYahAAdbgvnnHmmgUGanohqZUINrmJ9z94.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingle/v3/cY8bfi2OU1tLpjaqQveNvbC2qfsuQPDVASHjTcBszBsXfC5C9kAKu8QoqnfqMiS4gVij5yxO41San7UnNMBH-Y9u33JUGFdHpUYahAAdbgvnnHmmgUGanghrZUINrmJ9z94.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingle/v3/cY8bfi2OU1tLpjaqQveNvbC2qfsuQPDVASHjTcBszBsXfC5C9kAKu8QoqnfqMiS4gVij5yxO41San7UnNMBH-Y9u33JUGFdHpUYahAAdbgvnnHmmgUGantZrZUINrmJ9z94.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingle/v3/cY8bfi2OU1tLpjaqQveNvbC2qfsuQPDVASHjTcBszBsXfC5C9kAKu8QoqnfqMiS4gVij5yxO41San7UnNMBH-Y9u33JUGFdHpUYahAAdbgvnnHmmgUGanohrZUINrmJ9z94.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bitcountgridsingle/v3/cY8bfi2OU1tLpjaqQveNvbC2qfsuQPDVASHjTcBszBsXfC5C9kAKu8QoqnfqMiS4gVij5yxO41San7UnNMBH-Y9u33JUGFdHpUYahAAdbgvnnHmmgUGanrprZUINrmJ9z94.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingle/v3/cY8bfi2OU1tLpjaqQveNvbC2qfsuQPDVASHjTcBszBsXfC5C9kAKu8QoqnfqMiS4gVij5yxO41San7UnNMBH-Y9u33JUGFdHpUYahAAdbgvnnHmmgUGanlZsZUINrmJ9z94.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingle/v3/cY8bfi2OU1tLpjaqQveNvbC2qfsuQPDVASHjTcBszBsXfC5C9kAKu8QoqnfqMiS4gVij5yxO41San7UnNMBH-Y9u33JUGFdHpUYahAAdbgvnnHmmgUGanm9sZUINrmJ9z94.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingle/v3/cY8bfi2OU1tLpjaqQveNvbC2qfsuQPDVASHjTcBszBsXfC5C9kAKu8QoqnfqMiS4gVij5yxO41San7UnNMBH-Y9u33JUGFdHpUYahAAdbgvnnHmmgUGanghsZUINrmJ9z94.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bitcountgridsingle/v3/cY8bfi2OU1tLpjaqQveNvbC2qfsuQPDVASHjTcBszBsXfC5C9kAKu8QoqnfqMiS4gVij5yxO41San7UnNMBH-Y9u33JUGFdHpUYahAAdbgvnnHmmgUGaniFsZUINrmJ9z94.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bitcount-grid-single-ink",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("966f7b96-13ea-45d3-8515-edbb5bbdf444",-122975590),$APP.$cljs$cst$2675$family$$,"Bitcount Grid Single Ink",$APP.$cljs$cst$725$name$$,"Bitcount Grid Single Ink",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingleink/v2/NaN4epOEK_VIyYAuIaZn7FnUAOSVYeI0Ctm5-AxV__OGadlXPkpqc2W3G80KvDvfZJcTBZtOWSEifRuVdQ9MPZtUsYBBEK6cMpFmAx9Xgbn8m7Ha_CUon9Fm0PP1zM05Dnsuyw04ZGzhvlKxYNMYWI3t91IQXOwJRiUJVTErJ5YUW4O8LJCoXjD9tXQjarshNDUf3e0O5j3ZjrZCu23Qd4G0EACUTNK-QKavMl1GIY8dxef0jQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingleink/v2/NaN4epOEK_VIyYAuIaZn7FnUAOSVYeI0Ctm5-AxV__OGadlXPkpqc2W3G80KvDvfZJcTBZtOWSEifRuVdQ9MPZtUsYBBEK6cMpFmAx9Xgbn8m7Ha_CUon9Fm0PP1zM05Dnsuyw04ZGzhvlKxYNMYWI3t91IQXOwJRiUJVTErJ5YUW4O8LJCoXjD9tXQjarshNDUf3e0O5j3ZjrZCu23Qd4G0EACUTNK-QKavslxGIY8dxef0jQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingleink/v2/NaN4epOEK_VIyYAuIaZn7FnUAOSVYeI0Ctm5-AxV__OGadlXPkpqc2W3G80KvDvfZJcTBZtOWSEifRuVdQ9MPZtUsYBBEK6cMpFmAx9Xgbn8m7Ha_CUon9Fm0PP1zM05Dnsuyw04ZGzhvlKxYNMYWI3t91IQXOwJRiUJVTErJ5YUW4O8LJCoXjD9tXQjarshNDUf3e0O5j3ZjrZCu23Qd4G0EACUTNK-QKavbFxGIY8dxef0jQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingleink/v2/NaN4epOEK_VIyYAuIaZn7FnUAOSVYeI0Ctm5-AxV__OGadlXPkpqc2W3G80KvDvfZJcTBZtOWSEifRuVdQ9MPZtUsYBBEK6cMpFmAx9Xgbn8m7Ha_CUon9Fm0PP1zM05Dnsuyw04ZGzhvlKxYNMYWI3t91IQXOwJRiUJVTErJ5YUW4O8LJCoXjD9tXQjarshNDUf3e0O5j3ZjrZCu23Qd4G0EACUTNK-QKavMlxGIY8dxef0jQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingleink/v2/NaN4epOEK_VIyYAuIaZn7FnUAOSVYeI0Ctm5-AxV__OGadlXPkpqc2W3G80KvDvfZJcTBZtOWSEifRuVdQ9MPZtUsYBBEK6cMpFmAx9Xgbn8m7Ha_CUon9Fm0PP1zM05Dnsuyw04ZGzhvlKxYNMYWI3t91IQXOwJRiUJVTErJ5YUW4O8LJCoXjD9tXQjarshNDUf3e0O5j3ZjrZCu23Qd4G0EACUTNK-QKavAFxGIY8dxef0jQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingleink/v2/NaN4epOEK_VIyYAuIaZn7FnUAOSVYeI0Ctm5-AxV__OGadlXPkpqc2W3G80KvDvfZJcTBZtOWSEifRuVdQ9MPZtUsYBBEK6cMpFmAx9Xgbn8m7Ha_CUon9Fm0PP1zM05Dnsuyw04ZGzhvlKxYNMYWI3t91IQXOwJRiUJVTErJ5YUW4O8LJCoXjD9tXQjarshNDUf3e0O5j3ZjrZCu23Qd4G0EACUTNK-QKav7FtGIY8dxef0jQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingleink/v2/NaN4epOEK_VIyYAuIaZn7FnUAOSVYeI0Ctm5-AxV__OGadlXPkpqc2W3G80KvDvfZJcTBZtOWSEifRuVdQ9MPZtUsYBBEK6cMpFmAx9Xgbn8m7Ha_CUon9Fm0PP1zM05Dnsuyw04ZGzhvlKxYNMYWI3t91IQXOwJRiUJVTErJ5YUW4O8LJCoXjD9tXQjarshNDUf3e0O5j3ZjrZCu23Qd4G0EACUTNK-QKav1VtGIY8dxef0jQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingleink/v2/NaN4epOEK_VIyYAuIaZn7FnUAOSVYeI0Ctm5-AxV__OGadlXPkpqc2W3G80KvDvfZJcTBZtOWSEifRuVdQ9MPZtUsYBBEK6cMpFmAx9Xgbn8m7Ha_CUon9Fm0PP1zM05Dnsuyw04ZGzhvlKxYNMYWI3t91IQXOwJRiUJVTErJ5YUW4O8LJCoXjD9tXQjarshNDUf3e0O5j3ZjrZCu23Qd4G0EACUTNK-QKavsltGIY8dxef0jQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountgridsingleink/v2/NaN4epOEK_VIyYAuIaZn7FnUAOSVYeI0Ctm5-AxV__OGadlXPkpqc2W3G80KvDvfZJcTBZtOWSEifRuVdQ9MPZtUsYBBEK6cMpFmAx9Xgbn8m7Ha_CUon9Fm0PP1zM05Dnsuyw04ZGzhvlKxYNMYWI3t91IQXOwJRiUJVTErJ5YUW4O8LJCoXjD9tXQjarshNDUf3e0O5j3ZjrZCu23Qd4G0EACUTNK-QKavm1tGIY8dxef0jQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bitcount-ink",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8b062dfd-8170-4635-a735-9c564bce2508",-426237793),$APP.$cljs$cst$2675$family$$,"Bitcount Ink",$APP.$cljs$cst$725$name$$,"Bitcount Ink",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountink/v2/CHw3XOqbPlXqZygxqACCMDRlDHEsWMeZ-ply2TQhrGdTTV70MvuSq-hd_83nDPWRtOLnAR0RGYwUI6_l53HbUsPlZt2f_nGD_DNHtMCB7B9hQwZ0b5o6F6iN-beb4rZZL0lJiDukrkTdyFcJaMYOfDmhx95p-j2BlGfR752-BOzpyNMOV-otpEi0LP8lkm2L_v1iV4b0vZlRFNojp-LpjycCL3BeDtAVdA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountink/v2/CHw3XOqbPlXqZygxqACCMDRlDHEsWMeZ-ply2TQhrGdTTV70MvuSq-hd_83nDPWRtOLnAR0RGYwUI6_l53HbUsPlZt2f_nGD_DNHtMCB7B9hQwZ0b5o6F6iN-beb4rZZL0lJiDukrkTdyFcJaMYOfDmhx95p-j2BlGfR752-BOzpyNMOV-otpEi0LP8lkm2L_v1iV4b0vZlRFNojp-LpDyYCL3BeDtAVdA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountink/v2/CHw3XOqbPlXqZygxqACCMDRlDHEsWMeZ-ply2TQhrGdTTV70MvuSq-hd_83nDPWRtOLnAR0RGYwUI6_l53HbUsPlZt2f_nGD_DNHtMCB7B9hQwZ0b5o6F6iN-beb4rZZL0lJiDukrkTdyFcJaMYOfDmhx95p-j2BlGfR752-BOzpyNMOV-otpEi0LP8lkm2L_v1iV4b0vZlRFNojp-Lp0SYCL3BeDtAVdA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountink/v2/CHw3XOqbPlXqZygxqACCMDRlDHEsWMeZ-ply2TQhrGdTTV70MvuSq-hd_83nDPWRtOLnAR0RGYwUI6_l53HbUsPlZt2f_nGD_DNHtMCB7B9hQwZ0b5o6F6iN-beb4rZZL0lJiDukrkTdyFcJaMYOfDmhx95p-j2BlGfR752-BOzpyNMOV-otpEi0LP8lkm2L_v1iV4b0vZlRFNojp-LpjyYCL3BeDtAVdA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bitcountink/v2/CHw3XOqbPlXqZygxqACCMDRlDHEsWMeZ-ply2TQhrGdTTV70MvuSq-hd_83nDPWRtOLnAR0RGYwUI6_l53HbUsPlZt2f_nGD_DNHtMCB7B9hQwZ0b5o6F6iN-beb4rZZL0lJiDukrkTdyFcJaMYOfDmhx95p-j2BlGfR752-BOzpyNMOV-otpEi0LP8lkm2L_v1iV4b0vZlRFNojp-LpvSYCL3BeDtAVdA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountink/v2/CHw3XOqbPlXqZygxqACCMDRlDHEsWMeZ-ply2TQhrGdTTV70MvuSq-hd_83nDPWRtOLnAR0RGYwUI6_l53HbUsPlZt2f_nGD_DNHtMCB7B9hQwZ0b5o6F6iN-beb4rZZL0lJiDukrkTdyFcJaMYOfDmhx95p-j2BlGfR752-BOzpyNMOV-otpEi0LP8lkm2L_v1iV4b0vZlRFNojp-LpUSECL3BeDtAVdA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountink/v2/CHw3XOqbPlXqZygxqACCMDRlDHEsWMeZ-ply2TQhrGdTTV70MvuSq-hd_83nDPWRtOLnAR0RGYwUI6_l53HbUsPlZt2f_nGD_DNHtMCB7B9hQwZ0b5o6F6iN-beb4rZZL0lJiDukrkTdyFcJaMYOfDmhx95p-j2BlGfR752-BOzpyNMOV-otpEi0LP8lkm2L_v1iV4b0vZlRFNojp-LpaCECL3BeDtAVdA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountink/v2/CHw3XOqbPlXqZygxqACCMDRlDHEsWMeZ-ply2TQhrGdTTV70MvuSq-hd_83nDPWRtOLnAR0RGYwUI6_l53HbUsPlZt2f_nGD_DNHtMCB7B9hQwZ0b5o6F6iN-beb4rZZL0lJiDukrkTdyFcJaMYOfDmhx95p-j2BlGfR752-BOzpyNMOV-otpEi0LP8lkm2L_v1iV4b0vZlRFNojp-LpDyECL3BeDtAVdA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountink/v2/CHw3XOqbPlXqZygxqACCMDRlDHEsWMeZ-ply2TQhrGdTTV70MvuSq-hd_83nDPWRtOLnAR0RGYwUI6_l53HbUsPlZt2f_nGD_DNHtMCB7B9hQwZ0b5o6F6iN-beb4rZZL0lJiDukrkTdyFcJaMYOfDmhx95p-j2BlGfR752-BOzpyNMOV-otpEi0LP8lkm2L_v1iV4b0vZlRFNojp-LpJiECL3BeDtAVdA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-bitcount-prop-double",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("12cef0f4-4de9-49e4-9b8e-494b49fc3689",1522174215),$APP.$cljs$cst$2675$family$$,"Bitcount Prop Double",$APP.$cljs$cst$725$name$$,"Bitcount Prop Double",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdouble/v3/K2EvfY5Wn-tBSVxaDL6DUOXQJ26dEAnh698zMFjGZaPCtbJHl1TFmDKfGe4_bKUh3sC1Q7DxZ5-3PQRHsSZEX9ctiFN1ZosZvKyl3LzeFmQvK5hIm0nBWck5Kx91m1YFsiM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdouble/v3/K2EvfY5Wn-tBSVxaDL6DUOXQJ26dEAnh698zMFjGZaPCtbJHl1TFmDKfGe4_bKUh3sC1Q7DxZ5-3PQRHsSZEX9ctiFN1ZosZvKyl3LzeFmQvK5hIm0nBWUk4Kx91m1YFsiM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdouble/v3/K2EvfY5Wn-tBSVxaDL6DUOXQJ26dEAnh698zMFjGZaPCtbJHl1TFmDKfGe4_bKUh3sC1Q7DxZ5-3PQRHsSZEX9ctiFN1ZosZvKyl3LzeFmQvK5hIm0nBWZc4Kx91m1YFsiM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdouble/v3/K2EvfY5Wn-tBSVxaDL6DUOXQJ26dEAnh698zMFjGZaPCtbJHl1TFmDKfGe4_bKUh3sC1Q7DxZ5-3PQRHsSZEX9ctiFN1ZosZvKyl3LzeFmQvK5hIm0nBWck4Kx91m1YFsiM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bitcountpropdouble/v3/K2EvfY5Wn-tBSVxaDL6DUOXQJ26dEAnh698zMFjGZaPCtbJHl1TFmDKfGe4_bKUh3sC1Q7DxZ5-3PQRHsSZEX9ctiFN1ZosZvKyl3LzeFmQvK5hIm0nBWfs4Kx91m1YFsiM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdouble/v3/K2EvfY5Wn-tBSVxaDL6DUOXQJ26dEAnh698zMFjGZaPCtbJHl1TFmDKfGe4_bKUh3sC1Q7DxZ5-3PQRHsSZEX9ctiFN1ZosZvKyl3LzeFmQvK5hIm0nBWRc_Kx91m1YFsiM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdouble/v3/K2EvfY5Wn-tBSVxaDL6DUOXQJ26dEAnh698zMFjGZaPCtbJHl1TFmDKfGe4_bKUh3sC1Q7DxZ5-3PQRHsSZEX9ctiFN1ZosZvKyl3LzeFmQvK5hIm0nBWS4_Kx91m1YFsiM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdouble/v3/K2EvfY5Wn-tBSVxaDL6DUOXQJ26dEAnh698zMFjGZaPCtbJHl1TFmDKfGe4_bKUh3sC1Q7DxZ5-3PQRHsSZEX9ctiFN1ZosZvKyl3LzeFmQvK5hIm0nBWUk_Kx91m1YFsiM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bitcountpropdouble/v3/K2EvfY5Wn-tBSVxaDL6DUOXQJ26dEAnh698zMFjGZaPCtbJHl1TFmDKfGe4_bKUh3sC1Q7DxZ5-3PQRHsSZEX9ctiFN1ZosZvKyl3LzeFmQvK5hIm0nBWWA_Kx91m1YFsiM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bitcount-prop-double-ink",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("434d5d10-4627-409c-a7a5-a5ed3aa7792c",399960357),$APP.$cljs$cst$2675$family$$,"Bitcount Prop Double Ink",$APP.$cljs$cst$725$name$$,"Bitcount Prop Double Ink",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdoubleink/v2/Y4EraqgqeCwyoeHYKJOMnRRAOHVHr-2bKnsgKOU1mvV-Vk5S_hxGNApRqvOsLjMS7TL7U6J7vsT0x86f1E_MhJ7Fc8CNp0DtWIOPIdLKGVtyw2WU1OmnzDEO5QVqngZewgsX32-qkruHpLpXeSB4hOOrFaY6I-9oLQWBuD4CtdBkkmqV6mdr8M41Shcr_DYnIqojkFlhekgcGiaIMOm7DY3-ibiJFY5uuJUAz5--C4pTNcOH4A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdoubleink/v2/Y4EraqgqeCwyoeHYKJOMnRRAOHVHr-2bKnsgKOU1mvV-Vk5S_hxGNApRqvOsLjMS7TL7U6J7vsT0x86f1E_MhJ7Fc8CNp0DtWIOPIdLKGVtyw2WU1OmnzDEO5QVqngZewgsX32-qkruHpLpXeSB4hOOrFaY6I-9oLQWBuD4CtdBkkmqV6mdr8M41Shcr_DYnIqojkFlhekgcGiaIMOm7DY3-ibiJFY5uuJUAT56-C4pTNcOH4A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdoubleink/v2/Y4EraqgqeCwyoeHYKJOMnRRAOHVHr-2bKnsgKOU1mvV-Vk5S_hxGNApRqvOsLjMS7TL7U6J7vsT0x86f1E_MhJ7Fc8CNp0DtWIOPIdLKGVtyw2WU1OmnzDEO5QVqngZewgsX32-qkruHpLpXeSB4hOOrFaY6I-9oLQWBuD4CtdBkkmqV6mdr8M41Shcr_DYnIqojkFlhekgcGiaIMOm7DY3-ibiJFY5uuJUAkZ6-C4pTNcOH4A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdoubleink/v2/Y4EraqgqeCwyoeHYKJOMnRRAOHVHr-2bKnsgKOU1mvV-Vk5S_hxGNApRqvOsLjMS7TL7U6J7vsT0x86f1E_MhJ7Fc8CNp0DtWIOPIdLKGVtyw2WU1OmnzDEO5QVqngZewgsX32-qkruHpLpXeSB4hOOrFaY6I-9oLQWBuD4CtdBkkmqV6mdr8M41Shcr_DYnIqojkFlhekgcGiaIMOm7DY3-ibiJFY5uuJUAz56-C4pTNcOH4A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdoubleink/v2/Y4EraqgqeCwyoeHYKJOMnRRAOHVHr-2bKnsgKOU1mvV-Vk5S_hxGNApRqvOsLjMS7TL7U6J7vsT0x86f1E_MhJ7Fc8CNp0DtWIOPIdLKGVtyw2WU1OmnzDEO5QVqngZewgsX32-qkruHpLpXeSB4hOOrFaY6I-9oLQWBuD4CtdBkkmqV6mdr8M41Shcr_DYnIqojkFlhekgcGiaIMOm7DY3-ibiJFY5uuJUA_Z6-C4pTNcOH4A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdoubleink/v2/Y4EraqgqeCwyoeHYKJOMnRRAOHVHr-2bKnsgKOU1mvV-Vk5S_hxGNApRqvOsLjMS7TL7U6J7vsT0x86f1E_MhJ7Fc8CNp0DtWIOPIdLKGVtyw2WU1OmnzDEO5QVqngZewgsX32-qkruHpLpXeSB4hOOrFaY6I-9oLQWBuD4CtdBkkmqV6mdr8M41Shcr_DYnIqojkFlhekgcGiaIMOm7DY3-ibiJFY5uuJUAEZm-C4pTNcOH4A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdoubleink/v2/Y4EraqgqeCwyoeHYKJOMnRRAOHVHr-2bKnsgKOU1mvV-Vk5S_hxGNApRqvOsLjMS7TL7U6J7vsT0x86f1E_MhJ7Fc8CNp0DtWIOPIdLKGVtyw2WU1OmnzDEO5QVqngZewgsX32-qkruHpLpXeSB4hOOrFaY6I-9oLQWBuD4CtdBkkmqV6mdr8M41Shcr_DYnIqojkFlhekgcGiaIMOm7DY3-ibiJFY5uuJUAKJm-C4pTNcOH4A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdoubleink/v2/Y4EraqgqeCwyoeHYKJOMnRRAOHVHr-2bKnsgKOU1mvV-Vk5S_hxGNApRqvOsLjMS7TL7U6J7vsT0x86f1E_MhJ7Fc8CNp0DtWIOPIdLKGVtyw2WU1OmnzDEO5QVqngZewgsX32-qkruHpLpXeSB4hOOrFaY6I-9oLQWBuD4CtdBkkmqV6mdr8M41Shcr_DYnIqojkFlhekgcGiaIMOm7DY3-ibiJFY5uuJUAT5m-C4pTNcOH4A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropdoubleink/v2/Y4EraqgqeCwyoeHYKJOMnRRAOHVHr-2bKnsgKOU1mvV-Vk5S_hxGNApRqvOsLjMS7TL7U6J7vsT0x86f1E_MhJ7Fc8CNp0DtWIOPIdLKGVtyw2WU1OmnzDEO5QVqngZewgsX32-qkruHpLpXeSB4hOOrFaY6I-9oLQWBuD4CtdBkkmqV6mdr8M41Shcr_DYnIqojkFlhekgcGiaIMOm7DY3-ibiJFY5uuJUAZpm-C4pTNcOH4A.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bitcount-prop-single",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e14d5d5a-ede1-42fc-914a-26a7045d645d",-1274833055),$APP.$cljs$cst$2675$family$$,"Bitcount Prop Single",$APP.$cljs$cst$725$name$$,"Bitcount Prop Single",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingle/v3/-W-gXIv9SyXT0xz0E9pIHCxbW8ZMGEVdhz4VoumsGFhzYseFqK9f_KOwYjYsHSocfu1DlxztzQH877SgJ2SUzQ4SJdODLz0JoLU3vXFrqXQooCdbs921GXZkLGUYg0NjZiU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingle/v3/-W-gXIv9SyXT0xz0E9pIHCxbW8ZMGEVdhz4VoumsGFhzYseFqK9f_KOwYjYsHSocfu1DlxztzQH877SgJ2SUzQ4SJdODLz0JoLU3vXFrqXQooCdbs921GfZlLGUYg0NjZiU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingle/v3/-W-gXIv9SyXT0xz0E9pIHCxbW8ZMGEVdhz4VoumsGFhzYseFqK9f_KOwYjYsHSocfu1DlxztzQH877SgJ2SUzQ4SJdODLz0JoLU3vXFrqXQooCdbs921GShlLGUYg0NjZiU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingle/v3/-W-gXIv9SyXT0xz0E9pIHCxbW8ZMGEVdhz4VoumsGFhzYseFqK9f_KOwYjYsHSocfu1DlxztzQH877SgJ2SUzQ4SJdODLz0JoLU3vXFrqXQooCdbs921GXZlLGUYg0NjZiU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingle/v3/-W-gXIv9SyXT0xz0E9pIHCxbW8ZMGEVdhz4VoumsGFhzYseFqK9f_KOwYjYsHSocfu1DlxztzQH877SgJ2SUzQ4SJdODLz0JoLU3vXFrqXQooCdbs921GURlLGUYg0NjZiU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bitcountpropsingle/v3/-W-gXIv9SyXT0xz0E9pIHCxbW8ZMGEVdhz4VoumsGFhzYseFqK9f_KOwYjYsHSocfu1DlxztzQH877SgJ2SUzQ4SJdODLz0JoLU3vXFrqXQooCdbs921GahiLGUYg0NjZiU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingle/v3/-W-gXIv9SyXT0xz0E9pIHCxbW8ZMGEVdhz4VoumsGFhzYseFqK9f_KOwYjYsHSocfu1DlxztzQH877SgJ2SUzQ4SJdODLz0JoLU3vXFrqXQooCdbs921GZFiLGUYg0NjZiU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingle/v3/-W-gXIv9SyXT0xz0E9pIHCxbW8ZMGEVdhz4VoumsGFhzYseFqK9f_KOwYjYsHSocfu1DlxztzQH877SgJ2SUzQ4SJdODLz0JoLU3vXFrqXQooCdbs921GfZiLGUYg0NjZiU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,
"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingle/v3/-W-gXIv9SyXT0xz0E9pIHCxbW8ZMGEVdhz4VoumsGFhzYseFqK9f_KOwYjYsHSocfu1DlxztzQH877SgJ2SUzQ4SJdODLz0JoLU3vXFrqXQooCdbs921Gd9iLGUYg0NjZiU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bitcount-prop-single-ink",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e14e287d-4f8b-434b-b35d-ccbbabada20e",2135446949),
$APP.$cljs$cst$2675$family$$,"Bitcount Prop Single Ink",$APP.$cljs$cst$725$name$$,"Bitcount Prop Single Ink",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingleink/v4/wXILGHRJhY4pqVPamSvcVZZF7Vdg3La14u9PlzzO1nQEbZPzF-4gWjUKyDXV8KJN2EmG9tnR1UwPVIktRU7KfRvK49YKhcKoqpd0qENrktXGo3hmFUX9oJiQ_cI3D53uhksE9rntl1PkS1IjdhAg77zMwnnLO7zJ5bZKR5MO8LRFFwWr-XrNplyw2CuD3tEnNissrzK7ZCnsz5HReNrx9v6MX009gC5TFm4u37HDRGOJzIi0xg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingleink/v4/wXILGHRJhY4pqVPamSvcVZZF7Vdg3La14u9PlzzO1nQEbZPzF-4gWjUKyDXV8KJN2EmG9tnR1UwPVIktRU7KfRvK49YKhcKoqpd0qENrktXGo3hmFUX9oJiQ_cI3D53uhksE9rntl1PkS1IjdhAg77zMwnnLO7zJ5bZKR5MO8LRFFwWr-XrNplyw2CuD3tEnNissrzK7ZCnsz5HReNrx9v6MX009gC5TFm4uX7DDRGOJzIi0xg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingleink/v4/wXILGHRJhY4pqVPamSvcVZZF7Vdg3La14u9PlzzO1nQEbZPzF-4gWjUKyDXV8KJN2EmG9tnR1UwPVIktRU7KfRvK49YKhcKoqpd0qENrktXGo3hmFUX9oJiQ_cI3D53uhksE9rntl1PkS1IjdhAg77zMwnnLO7zJ5bZKR5MO8LRFFwWr-XrNplyw2CuD3tEnNissrzK7ZCnsz5HReNrx9v6MX009gC5TFm4ugbDDRGOJzIi0xg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingleink/v4/wXILGHRJhY4pqVPamSvcVZZF7Vdg3La14u9PlzzO1nQEbZPzF-4gWjUKyDXV8KJN2EmG9tnR1UwPVIktRU7KfRvK49YKhcKoqpd0qENrktXGo3hmFUX9oJiQ_cI3D53uhksE9rntl1PkS1IjdhAg77zMwnnLO7zJ5bZKR5MO8LRFFwWr-XrNplyw2CuD3tEnNissrzK7ZCnsz5HReNrx9v6MX009gC5TFm4u37DDRGOJzIi0xg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingleink/v4/wXILGHRJhY4pqVPamSvcVZZF7Vdg3La14u9PlzzO1nQEbZPzF-4gWjUKyDXV8KJN2EmG9tnR1UwPVIktRU7KfRvK49YKhcKoqpd0qENrktXGo3hmFUX9oJiQ_cI3D53uhksE9rntl1PkS1IjdhAg77zMwnnLO7zJ5bZKR5MO8LRFFwWr-XrNplyw2CuD3tEnNissrzK7ZCnsz5HReNrx9v6MX009gC5TFm4u7bDDRGOJzIi0xg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingleink/v4/wXILGHRJhY4pqVPamSvcVZZF7Vdg3La14u9PlzzO1nQEbZPzF-4gWjUKyDXV8KJN2EmG9tnR1UwPVIktRU7KfRvK49YKhcKoqpd0qENrktXGo3hmFUX9oJiQ_cI3D53uhksE9rntl1PkS1IjdhAg77zMwnnLO7zJ5bZKR5MO8LRFFwWr-XrNplyw2CuD3tEnNissrzK7ZCnsz5HReNrx9v6MX009gC5TFm4uAbfDRGOJzIi0xg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingleink/v4/wXILGHRJhY4pqVPamSvcVZZF7Vdg3La14u9PlzzO1nQEbZPzF-4gWjUKyDXV8KJN2EmG9tnR1UwPVIktRU7KfRvK49YKhcKoqpd0qENrktXGo3hmFUX9oJiQ_cI3D53uhksE9rntl1PkS1IjdhAg77zMwnnLO7zJ5bZKR5MO8LRFFwWr-XrNplyw2CuD3tEnNissrzK7ZCnsz5HReNrx9v6MX009gC5TFm4uOLfDRGOJzIi0xg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingleink/v4/wXILGHRJhY4pqVPamSvcVZZF7Vdg3La14u9PlzzO1nQEbZPzF-4gWjUKyDXV8KJN2EmG9tnR1UwPVIktRU7KfRvK49YKhcKoqpd0qENrktXGo3hmFUX9oJiQ_cI3D53uhksE9rntl1PkS1IjdhAg77zMwnnLO7zJ5bZKR5MO8LRFFwWr-XrNplyw2CuD3tEnNissrzK7ZCnsz5HReNrx9v6MX009gC5TFm4uX7fDRGOJzIi0xg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountpropsingleink/v4/wXILGHRJhY4pqVPamSvcVZZF7Vdg3La14u9PlzzO1nQEbZPzF-4gWjUKyDXV8KJN2EmG9tnR1UwPVIktRU7KfRvK49YKhcKoqpd0qENrktXGo3hmFUX9oJiQ_cI3D53uhksE9rntl1PkS1IjdhAg77zMwnnLO7zJ5bZKR5MO8LRFFwWr-XrNplyw2CuD3tEnNissrzK7ZCnsz5HReNrx9v6MX009gC5TFm4udrfDRGOJzIi0xg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bitcount-single",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1d59e420-4137-46e0-bba5-038615b47457",-1193835805),$APP.$cljs$cst$2675$family$$,"Bitcount Single",$APP.$cljs$cst$725$name$$,"Bitcount Single",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingle/v3/or25Q6T72-iP2RY6OLSkb95a817cjULDyyhvb6tTxCxtAOObpH9NnfLjSWiXv_OGqtjRD0BNzrItMZWC-9SK8R6EpA2l9RAyOs8BbxT7gd3xw8jKC4tYzXjwevWm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingle/v3/or25Q6T72-iP2RY6OLSkb95a817cjULDyyhvb6tTxCxtAOObpH9NnfLjSWiXv_OGqtjRD0BNzrItMZWC-9SK8R6EpA2l9RAyOs8BbxT7gd3xw8hKCotYzXjwevWm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingle/v3/or25Q6T72-iP2RY6OLSkb95a817cjULDyyhvb6tTxCxtAOObpH9NnfLjSWiXv_OGqtjRD0BNzrItMZWC-9SK8R6EpA2l9RAyOs8BbxT7gd3xw8iUCotYzXjwevWm.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingle/v3/or25Q6T72-iP2RY6OLSkb95a817cjULDyyhvb6tTxCxtAOObpH9NnfLjSWiXv_OGqtjRD0BNzrItMZWC-9SK8R6EpA2l9RAyOs8BbxT7gd3xw8jKCotYzXjwevWm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingle/v3/or25Q6T72-iP2RY6OLSkb95a817cjULDyyhvb6tTxCxtAOObpH9NnfLjSWiXv_OGqtjRD0BNzrItMZWC-9SK8R6EpA2l9RAyOs8BbxT7gd3xw8j4CotYzXjwevWm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingle/v3/or25Q6T72-iP2RY6OLSkb95a817cjULDyyhvb6tTxCxtAOObpH9NnfLjSWiXv_OGqtjRD0BNzrItMZWC-9SK8R6EpA2l9RAyOs8BbxT7gd3xw8gUDYtYzXjwevWm.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingle/v3/or25Q6T72-iP2RY6OLSkb95a817cjULDyyhvb6tTxCxtAOObpH9NnfLjSWiXv_OGqtjRD0BNzrItMZWC-9SK8R6EpA2l9RAyOs8BbxT7gd3xw8gtDYtYzXjwevWm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingle/v3/or25Q6T72-iP2RY6OLSkb95a817cjULDyyhvb6tTxCxtAOObpH9NnfLjSWiXv_OGqtjRD0BNzrItMZWC-9SK8R6EpA2l9RAyOs8BbxT7gd3xw8hKDYtYzXjwevWm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingle/v3/or25Q6T72-iP2RY6OLSkb95a817cjULDyyhvb6tTxCxtAOObpH9NnfLjSWiXv_OGqtjRD0BNzrItMZWC-9SK8R6EpA2l9RAyOs8BbxT7gd3xw8hjDYtYzXjwevWm.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bitcount-single-ink",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("24d1b2ac-880e-4ce4-9dd0-32dddbc4d579",1842641146),$APP.$cljs$cst$2675$family$$,"Bitcount Single Ink",$APP.$cljs$cst$725$name$$,"Bitcount Single Ink",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingleink/v4/Fwb25OZl6FQz81GlJoqgm6XFwi_b1Oat-linM3eIpWvrZ9yhd874qjc72qi5T1IMgiBoydD3bDjJgnXIJ9Cr_oGr36FB5R5iKLRfpSXGN3dP9opQwU38v-r6dJk-vDaziAhRxAxKG59HJAjcNGNBlalyPEmoi939mIWU-GaeCu-JxR9Tn0k2TuKy0CJqQ-Jyh2beggR6Zmt0ewICe5TepUFVly3QN0T8ugz0rbvZS6k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingleink/v4/Fwb25OZl6FQz81GlJoqgm6XFwi_b1Oat-linM3eIpWvrZ9yhd874qjc72qi5T1IMgiBoydD3bDjJgnXIJ9Cr_oGr36FB5R5iKLRfpSXGN3dP9opQwU38v-r6dJk-vDaziAhRxAxKG59HJAjcNGNBlalyPEmoi939mIWU-GaeCu-JxR9Tn0k2TuKy0CJqQ-Jyh2beggR6Zmt0ewICe5TepUFVly3QN8T9ugz0rbvZS6k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingleink/v4/Fwb25OZl6FQz81GlJoqgm6XFwi_b1Oat-linM3eIpWvrZ9yhd874qjc72qi5T1IMgiBoydD3bDjJgnXIJ9Cr_oGr36FB5R5iKLRfpSXGN3dP9opQwU38v-r6dJk-vDaziAhRxAxKG59HJAjcNGNBlalyPEmoi939mIWU-GaeCu-JxR9Tn0k2TuKy0CJqQ-Jyh2beggR6Zmt0ewICe5TepUFVly3QNxr9ugz0rbvZS6k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingleink/v4/Fwb25OZl6FQz81GlJoqgm6XFwi_b1Oat-linM3eIpWvrZ9yhd874qjc72qi5T1IMgiBoydD3bDjJgnXIJ9Cr_oGr36FB5R5iKLRfpSXGN3dP9opQwU38v-r6dJk-vDaziAhRxAxKG59HJAjcNGNBlalyPEmoi939mIWU-GaeCu-JxR9Tn0k2TuKy0CJqQ-Jyh2beggR6Zmt0ewICe5TepUFVly3QN0T9ugz0rbvZS6k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingleink/v4/Fwb25OZl6FQz81GlJoqgm6XFwi_b1Oat-linM3eIpWvrZ9yhd874qjc72qi5T1IMgiBoydD3bDjJgnXIJ9Cr_oGr36FB5R5iKLRfpSXGN3dP9opQwU38v-r6dJk-vDaziAhRxAxKG59HJAjcNGNBlalyPEmoi939mIWU-GaeCu-JxR9Tn0k2TuKy0CJqQ-Jyh2beggR6Zmt0ewICe5TepUFVly3QN3b9ugz0rbvZS6k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingleink/v4/Fwb25OZl6FQz81GlJoqgm6XFwi_b1Oat-linM3eIpWvrZ9yhd874qjc72qi5T1IMgiBoydD3bDjJgnXIJ9Cr_oGr36FB5R5iKLRfpSXGN3dP9opQwU38v-r6dJk-vDaziAhRxAxKG59HJAjcNGNBlalyPEmoi939mIWU-GaeCu-JxR9Tn0k2TuKy0CJqQ-Jyh2beggR6Zmt0ewICe5TepUFVly3QN5r6ugz0rbvZS6k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingleink/v4/Fwb25OZl6FQz81GlJoqgm6XFwi_b1Oat-linM3eIpWvrZ9yhd874qjc72qi5T1IMgiBoydD3bDjJgnXIJ9Cr_oGr36FB5R5iKLRfpSXGN3dP9opQwU38v-r6dJk-vDaziAhRxAxKG59HJAjcNGNBlalyPEmoi939mIWU-GaeCu-JxR9Tn0k2TuKy0CJqQ-Jyh2beggR6Zmt0ewICe5TepUFVly3QN6P6ugz0rbvZS6k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingleink/v4/Fwb25OZl6FQz81GlJoqgm6XFwi_b1Oat-linM3eIpWvrZ9yhd874qjc72qi5T1IMgiBoydD3bDjJgnXIJ9Cr_oGr36FB5R5iKLRfpSXGN3dP9opQwU38v-r6dJk-vDaziAhRxAxKG59HJAjcNGNBlalyPEmoi939mIWU-GaeCu-JxR9Tn0k2TuKy0CJqQ-Jyh2beggR6Zmt0ewICe5TepUFVly3QN8T6ugz0rbvZS6k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitcountsingleink/v4/Fwb25OZl6FQz81GlJoqgm6XFwi_b1Oat-linM3eIpWvrZ9yhd874qjc72qi5T1IMgiBoydD3bDjJgnXIJ9Cr_oGr36FB5R5iKLRfpSXGN3dP9opQwU38v-r6dJk-vDaziAhRxAxKG59HJAjcNGNBlalyPEmoi939mIWU-GaeCu-JxR9Tn0k2TuKy0CJqQ-Jyh2beggR6Zmt0ewICe5TepUFVly3QN-36ugz0rbvZS6k.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-bitter",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("da00e83c-899c-4185-84e3-a269fd7014e3",1596901033),$APP.$cljs$cst$2675$family$$,"Bitter",$APP.$cljs$cst$725$name$$,"Bitter",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bitter/v40/raxhHiqOu8IVPmnRc6SY1KXhnF_Y8fbeCL_EXFh2reU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxhHiqOu8IVPmnRc6SY1KXhnF_Y8XbfCL_EXFh2reU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxhHiqOu8IVPmnRc6SY1KXhnF_Y8ajfCL_EXFh2reU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxhHiqOu8IVPmnRc6SY1KXhnF_Y8fbfCL_EXFh2reU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxhHiqOu8IVPmnRc6SY1KXhnF_Y8cTfCL_EXFh2reU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bitter/v40/raxhHiqOu8IVPmnRc6SY1KXhnF_Y8SjYCL_EXFh2reU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxhHiqOu8IVPmnRc6SY1KXhnF_Y8RHYCL_EXFh2reU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxhHiqOu8IVPmnRc6SY1KXhnF_Y8XbYCL_EXFh2reU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxhHiqOu8IVPmnRc6SY1KXhnF_Y8V_YCL_EXFh2reU.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxjHiqOu8IVPmn7epZnDMyKBvHf5D6c4P3OWHpzveWxBw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxjHiqOu8IVPmn7epZnDMyKBvHf5D6cYPzOWHpzveWxBw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxjHiqOu8IVPmn7epZnDMyKBvHf5D6cvvzOWHpzveWxBw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxjHiqOu8IVPmn7epZnDMyKBvHf5D6c4PzOWHpzveWxBw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxjHiqOu8IVPmn7epZnDMyKBvHf5D6c0vzOWHpzveWxBw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxjHiqOu8IVPmn7epZnDMyKBvHf5D6cPvvOWHpzveWxBw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxjHiqOu8IVPmn7epZnDMyKBvHf5D6cB_vOWHpzveWxBw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxjHiqOu8IVPmn7epZnDMyKBvHf5D6cYPvOWHpzveWxBw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bitter/v40/raxjHiqOu8IVPmn7epZnDMyKBvHf5D6cSfvOWHpzveWxBw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-black-and-white-picture",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f68bdaf1-81e4-41cf-8000-ff5b9fcc9b37",914519563),$APP.$cljs$cst$2675$family$$,
"Black And White Picture",$APP.$cljs$cst$725$name$$,"Black And White Picture",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/blackandwhitepicture/v30/TwMe-JAERlQd3ooUHBUXGmrmioKjjnRSFO-NqI5HbcMi-yWY.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-black-han-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ba97f937-947b-462e-b497-6a04885fc64c",851357763),$APP.$cljs$cst$2675$family$$,"Black Han Sans",$APP.$cljs$cst$725$name$$,"Black Han Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/blackhansans/v24/ea8Aad44WunzF9a-dL6toA8r8nqVIXSkH-Hc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-black-ops-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e25a07e4-60bb-4c78-93e6-9495f1dd67c0",937512234),$APP.$cljs$cst$2675$family$$,"Black Ops One",$APP.$cljs$cst$725$name$$,"Black Ops One",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/blackopsone/v21/qWcsB6-ypo7xBdr6Xshe96H3WDzRtjkho4M.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-blaka",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("abe646f8-20a5-441b-9a38-66ba1568eda0",-1153458066),$APP.$cljs$cst$2675$family$$,"Blaka",$APP.$cljs$cst$725$name$$,"Blaka",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/blaka/v8/8vIG7w8722p_6kdr20D2FV5e.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-blaka-hollow",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("56e550bc-8484-45bf-a232-a311ae7703fa",1964431229),$APP.$cljs$cst$2675$family$$,"Blaka Hollow",$APP.$cljs$cst$725$name$$,"Blaka Hollow",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/blakahollow/v8/MCoUzAL91sjRE2FsKsxUtezYB9oFyW_-oA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-blaka-ink",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4ec617fa-8e86-47b2-9a84-3fd54d00eb65",883235708),$APP.$cljs$cst$2675$family$$,"Blaka Ink",$APP.$cljs$cst$725$name$$,
"Blaka Ink",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/blakaink/v10/AlZy_zVVtpj22Znag2chdXf4XB0Tow.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-blinker",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("751c7eb6-c148-4b42-8e99-57e161d1e0af",1436245655),$APP.$cljs$cst$2675$family$$,"Blinker",$APP.$cljs$cst$725$name$$,"Blinker",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/blinker/v14/cIf_MaFatEE-VTaP_E2hZEsCkIt9QQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/blinker/v14/cIf4MaFatEE-VTaP_OGARGEsnIJkWL4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/blinker/v14/cIf4MaFatEE-VTaP_IWDRGEsnIJkWL4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/blinker/v14/cIf9MaFatEE-VTaPxCmrYGkHgIs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/blinker/v14/cIf4MaFatEE-VTaP_PGFRGEsnIJkWL4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/blinker/v14/cIf4MaFatEE-VTaP_JWERGEsnIJkWL4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/blinker/v14/cIf4MaFatEE-VTaP_ImHRGEsnIJkWL4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/blinker/v14/cIf4MaFatEE-VTaP_K2GRGEsnIJkWL4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bodoni-moda",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a8c8b1b8-698d-4362-927b-5eb1d4cb14ce",932812016),$APP.$cljs$cst$2675$family$$,"Bodoni Moda",$APP.$cljs$cst$725$name$$,"Bodoni Moda",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimoda/v28/aFT67PxzY382XsXX63LUYL6GYFcan6NJrKp-VPjfJMShrpsGFUt8oU7awIBytVjMYwE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimoda/v28/aFT67PxzY382XsXX63LUYL6GYFcan6NJrKp-VPjfJMShrpsGFUt8oXzawIBytVjMYwE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimoda/v28/aFT67PxzY382XsXX63LUYL6GYFcan6NJrKp-VPjfJMShrpsGFUt8oZDdwIBytVjMYwE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimoda/v28/aFT67PxzY382XsXX63LUYL6GYFcan6NJrKp-VPjfJMShrpsGFUt8oandwIBytVjMYwE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimoda/v28/aFT67PxzY382XsXX63LUYL6GYFcan6NJrKp-VPjfJMShrpsGFUt8oc7dwIBytVjMYwE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimoda/v28/aFT67PxzY382XsXX63LUYL6GYFcan6NJrKp-VPjfJMShrpsGFUt8oefdwIBytVjMYwE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bodonimoda/v28/aFT07PxzY382XsXX63LUYJSPUqb0pL6OQqxrZLnVbvZedvJtj-V7tIaZKMN4sXrJcwHqoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimoda/v28/aFT07PxzY382XsXX63LUYJSPUqb0pL6OQqxrZLnVbvZedvJtj-V7tIaZGsN4sXrJcwHqoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimoda/v28/aFT07PxzY382XsXX63LUYJSPUqb0pL6OQqxrZLnVbvZedvJtj-V7tIaZ9sR4sXrJcwHqoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bodonimoda/v28/aFT07PxzY382XsXX63LUYJSPUqb0pL6OQqxrZLnVbvZedvJtj-V7tIaZz8R4sXrJcwHqoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimoda/v28/aFT07PxzY382XsXX63LUYJSPUqb0pL6OQqxrZLnVbvZedvJtj-V7tIaZqMR4sXrJcwHqoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimoda/v28/aFT07PxzY382XsXX63LUYJSPUqb0pL6OQqxrZLnVbvZedvJtj-V7tIaZgcR4sXrJcwHqoQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bodoni-moda-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c661db9d-5cdd-4a01-9753-c34d68c35f38",1298233729),
$APP.$cljs$cst$2675$family$$,"Bodoni Moda SC",$APP.$cljs$cst$725$name$$,"Bodoni Moda SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimodasc/v3/LYjhdGTykkIgA8197UwkzHp8F-XUUG5UNs2KqliEb-g_DaUdIA6SfiYHbA7uXJyb9N7yr8E.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimodasc/v3/LYjhdGTykkIgA8197UwkzHp8F-XUUG5UNs2KqliEb-g_DaUdIA6SfiYHbDzuXJyb9N7yr8E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimodasc/v3/LYjhdGTykkIgA8197UwkzHp8F-XUUG5UNs2KqliEb-g_DaUdIA6SfiYHbNDpXJyb9N7yr8E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimodasc/v3/LYjhdGTykkIgA8197UwkzHp8F-XUUG5UNs2KqliEb-g_DaUdIA6SfiYHbOnpXJyb9N7yr8E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimodasc/v3/LYjhdGTykkIgA8197UwkzHp8F-XUUG5UNs2KqliEb-g_DaUdIA6SfiYHbI7pXJyb9N7yr8E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimodasc/v3/LYjhdGTykkIgA8197UwkzHp8F-XUUG5UNs2KqliEb-g_DaUdIA6SfiYHbKfpXJyb9N7yr8E.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimodasc/v3/LYjndGTykkIgA8197UwkzHp8F8_dYp-6DdBNRF6RX6k1R5fi-Gf55IgAecattN-R8Pz3v8Etew.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimodasc/v3/LYjndGTykkIgA8197UwkzHp8F8_dYp-6DdBNRF6RX6k1R5fi-Gf55IgAecatht-R8Pz3v8Etew.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimodasc/v3/LYjndGTykkIgA8197UwkzHp8F8_dYp-6DdBNRF6RX6k1R5fi-Gf55IgAecatatiR8Pz3v8Etew.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimodasc/v3/LYjndGTykkIgA8197UwkzHp8F8_dYp-6DdBNRF6RX6k1R5fi-Gf55IgAecatU9iR8Pz3v8Etew.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,
"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimodasc/v3/LYjndGTykkIgA8197UwkzHp8F8_dYp-6DdBNRF6RX6k1R5fi-Gf55IgAecatNNiR8Pz3v8Etew.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bodonimodasc/v3/LYjndGTykkIgA8197UwkzHp8F8_dYp-6DdBNRF6RX6k1R5fi-Gf55IgAecatHdiR8Pz3v8Etew.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bokor",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8adb7b97-be8f-4d3b-8418-3a05fd3f7132",1757583446),$APP.$cljs$cst$2675$family$$,"Bokor",$APP.$cljs$cst$725$name$$,"Bokor",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bokor/v32/m8JcjfpeeaqTiR2WdInbcaxE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-boldonse",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("338e0b78-1181-4f7d-9e5f-661373904fdf",1033444156),$APP.$cljs$cst$2675$family$$,"Boldonse",$APP.$cljs$cst$725$name$$,"Boldonse",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/boldonse/v1/ZgNQjPxGPbbJUZemjC38hmHmNpCO.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bona-nova",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1ae72d7c-1db1-44fd-b3b8-053c15e36cb1",
2078128424),$APP.$cljs$cst$2675$family$$,"Bona Nova",$APP.$cljs$cst$725$name$$,"Bona Nova",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bonanova/v12/B50NF7ZCpX7fcHfvIUBJi6hqHK-CLA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bonanova/v12/B50LF7ZCpX7fcHfvIUB5iaJuPqqSLJYf.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bonanova/v12/B50IF7ZCpX7fcHfvIUBxN4dOFISeJY8GgQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bona-nova-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6e17ce1f-51d4-4ed5-b394-a96fe662094d",1574246905),$APP.$cljs$cst$2675$family$$,"Bona Nova SC",$APP.$cljs$cst$725$name$$,"Bona Nova SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bonanovasc/v1/mem5YaShyGWDiYdPG_c1Af4-VeJoCqeDjg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bonanovasc/v1/memnYaShyGWDiYdPG_c1Af4OV-hsKKKTjrPW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bonanovasc/v1/memmYaShyGWDiYdPG_c1Af4G6c1MAoyfh6rPXA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bonbon",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("89fa9465-5a39-440c-b0b7-5534cc9f00cd",90183868),$APP.$cljs$cst$2675$family$$,"Bonbon",$APP.$cljs$cst$725$name$$,"Bonbon",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bonbon/v32/0FlVVPeVlFec4ee_cDEAbQY5-A.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bonheur-royale",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a3dd639b-d8da-4d69-8aee-444143f464d1",1598212410),$APP.$cljs$cst$2675$family$$,"Bonheur Royale",$APP.$cljs$cst$725$name$$,"Bonheur Royale",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bonheurroyale/v15/c4m51nt_GMTrtX-b9GcG4-YRmYK_c0f1N5Ij.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-boogaloo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("afe87a6f-bc03-45cd-9b33-0c7bdfc4ac5c",-1651480019),$APP.$cljs$cst$2675$family$$,"Boogaloo",$APP.$cljs$cst$725$name$$,"Boogaloo",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/boogaloo/v25/kmK-Zq45GAvOdnaW6x1F_SrQo_1K.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-borel",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("62763b24-b587-4643-a9c3-f63f6f7ba73e",1190780943),$APP.$cljs$cst$2675$family$$,"Borel",$APP.$cljs$cst$725$name$$,"Borel",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/borel/v9/6qLOKZsftAPisgshYyMnOjwE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bowlby-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bc7f0e72-27a9-4d01-8f82-3cde0bea4c6a",1722770723),$APP.$cljs$cst$2675$family$$,"Bowlby One",$APP.$cljs$cst$725$name$$,"Bowlby One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bowlbyone/v25/taiPGmVuC4y96PFeqp8smo6C_Z0wcK4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bowlby-one-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f7be1f10-80d2-41a9-b0fe-213b84036369",354296201),$APP.$cljs$cst$2675$family$$,"Bowlby One SC",$APP.$cljs$cst$725$name$$,
"Bowlby One SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bowlbyonesc/v27/DtVlJxerQqQm37tzN3wMug9Pzgj8owhNjuE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-braah-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f3367aef-09be-438f-b54f-eca3b120e2bb",-2129538094),$APP.$cljs$cst$2675$family$$,"Braah One",$APP.$cljs$cst$725$name$$,"Braah One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/braahone/v8/KFOlCnWUpt6LsxxxiylvAx05IsDqlA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-brawler",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("922c9e21-47f5-4290-a791-629713b0673b",1843580173),$APP.$cljs$cst$2675$family$$,"Brawler",$APP.$cljs$cst$725$name$$,"Brawler",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/brawler/v20/xn7gYHE3xXewAscGsgC7S9XdZN8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/brawler/v20/xn7lYHE3xXewAscGiryUb932eNaPfk8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bree-serif",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2d42f132-9545-4c15-af70-f167718ca1d5",-1478166809),$APP.$cljs$cst$2675$family$$,"Bree Serif",$APP.$cljs$cst$725$name$$,"Bree Serif",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/breeserif/v18/4UaHrEJCrhhnVA3DgluAx63j5pN1MwI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bricolage-grotesque",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e9acc065-551e-4292-a709-c26dda6b5bc3",-1598368710),$APP.$cljs$cst$2675$family$$,"Bricolage Grotesque",
$APP.$cljs$cst$725$name$$,"Bricolage Grotesque",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bricolagegrotesque/v9/3y9U6as8bTXq_nANBjzKo3IeZx8z6up5BeSl5jBNz_19PpbpMXuECpwUxJBOm_OJWiaaD30YfKfjZZoLvZviyM0vs-wJDtw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bricolagegrotesque/v9/3y9U6as8bTXq_nANBjzKo3IeZx8z6up5BeSl5jBNz_19PpbpMXuECpwUxJBOm_OJWiaaD30YfKfjZZoLvUXiyM0vs-wJDtw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bricolagegrotesque/v9/3y9U6as8bTXq_nANBjzKo3IeZx8z6up5BeSl5jBNz_19PpbpMXuECpwUxJBOm_OJWiaaD30YfKfjZZoLvRviyM0vs-wJDtw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bricolagegrotesque/v9/3y9U6as8bTXq_nANBjzKo3IeZx8z6up5BeSl5jBNz_19PpbpMXuECpwUxJBOm_OJWiaaD30YfKfjZZoLvSniyM0vs-wJDtw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bricolagegrotesque/v9/3y9U6as8bTXq_nANBjzKo3IeZx8z6up5BeSl5jBNz_19PpbpMXuECpwUxJBOm_OJWiaaD30YfKfjZZoLvcXlyM0vs-wJDtw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bricolagegrotesque/v9/3y9U6as8bTXq_nANBjzKo3IeZx8z6up5BeSl5jBNz_19PpbpMXuECpwUxJBOm_OJWiaaD30YfKfjZZoLvfzlyM0vs-wJDtw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bricolagegrotesque/v9/3y9U6as8bTXq_nANBjzKo3IeZx8z6up5BeSl5jBNz_19PpbpMXuECpwUxJBOm_OJWiaaD30YfKfjZZoLvZvlyM0vs-wJDtw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bruno-ace",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3f150939-75ed-4fdd-a13c-e490eb0d5fe6",-414215697),$APP.$cljs$cst$2675$family$$,"Bruno Ace",$APP.$cljs$cst$725$name$$,"Bruno Ace",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/brunoace/v7/WwkcxPa2E06x4trkOj_kMKoMWNMg3Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bruno-ace-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3bf21f21-a133-412f-a754-c6c588730714",-1311248805),$APP.$cljs$cst$2675$family$$,"Bruno Ace SC",$APP.$cljs$cst$725$name$$,"Bruno Ace SC",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/brunoacesc/v7/ptROTiycffFLBuiHjdJDl634LSFrpe8uZA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-brygada-1918",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("75490b52-35b6-49cd-8d48-f3ce588db3aa",-1416561241),$APP.$cljs$cst$2675$family$$,"Brygada 1918",$APP.$cljs$cst$725$name$$,"Brygada 1918",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/brygada1918/v27/pe08MI6eKpdGqlF5LANrM--ACNaeo8mTUIR_y2-f-V8Wu5O3gbo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/brygada1918/v27/pe08MI6eKpdGqlF5LANrM--ACNaeo8mTUIR_y12f-V8Wu5O3gbo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",
$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/brygada1918/v27/pe08MI6eKpdGqlF5LANrM--ACNaeo8mTUIR_y7GY-V8Wu5O3gbo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/brygada1918/v27/pe08MI6eKpdGqlF5LANrM--ACNaeo8mTUIR_y4iY-V8Wu5O3gbo.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/brygada1918/v27/pe06MI6eKpdGqlF5LANrM--qAeRhe6D4yip43qfcERwcv7GykboaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/brygada1918/v27/pe06MI6eKpdGqlF5LANrM--qAeRhe6D4yip43qfcIxwcv7GykboaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/brygada1918/v27/pe06MI6eKpdGqlF5LANrM--qAeRhe6D4yip43qfczxscv7GykboaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/brygada1918/v27/pe06MI6eKpdGqlF5LANrM--qAeRhe6D4yip43qfc9hscv7GykboaLg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bubblegum-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("af3ac20f-8171-4260-8b56-bafc56c984ae",776287191),$APP.$cljs$cst$2675$family$$,
"Bubblegum Sans",$APP.$cljs$cst$725$name$$,"Bubblegum Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bubblegumsans/v22/AYCSpXb_Z9EORv1M5QTjEzMEtdaHzoPPb7R4.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bubbler-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("47c4d560-4b4a-47bf-b42b-0a463ef1f889",1384832381),$APP.$cljs$cst$2675$family$$,"Bubbler One",$APP.$cljs$cst$725$name$$,"Bubbler One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bubblerone/v22/f0Xy0eqj68ppQV9KBLmAouHH26MPePkt.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-buda",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e2dd150d-a718-4f42-97b7-831cb8ca4a3c",-1953603127),$APP.$cljs$cst$2675$family$$,"Buda",$APP.$cljs$cst$725$name$$,"Buda",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/buda/v31/GFDqWAN8mnyIJSSrG7UBr7pZKA0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-buenard",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cc80bf87-b176-4266-b69d-5bc4a9bca712",
-211652385),$APP.$cljs$cst$2675$family$$,"Buenard",$APP.$cljs$cst$725$name$$,"Buenard",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/buenard/v22/OD5cuM6Cyma8FnnsJTzfWLAhv7i92sqpK0_3iBYVfsc4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/buenard/v22/OD5cuM6Cyma8FnnsJTzfWLAhv7i92sqbK0_3iBYVfsc4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/buenard/v22/OD5cuM6Cyma8FnnsJTzfWLAhv7i92sp3LE_3iBYVfsc4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/buenard/v22/OD5cuM6Cyma8FnnsJTzfWLAhv7i92spOLE_3iBYVfsc4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bungee",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b7fcf2cf-f15d-48fe-bff4-13db2f05849b",-4642250),$APP.$cljs$cst$2675$family$$,"Bungee",$APP.$cljs$cst$725$name$$,"Bungee",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/bungee/v17/N0bU2SZBIuF2PU_ECn50Kd_PmA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bungee-hairline",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f417be31-fec3-4527-8dcc-7d49ec14c84d",981900927),$APP.$cljs$cst$2675$family$$,"Bungee Hairline",$APP.$cljs$cst$725$name$$,"Bungee Hairline",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bungeehairline/v26/snfys0G548t04270a_ljTLUVrv-7YB2dQ5ZPqQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bungee-inline",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3ac07094-f159-469a-aeb3-9444c870c78a",-800367787),$APP.$cljs$cst$2675$family$$,"Bungee Inline",
$APP.$cljs$cst$725$name$$,"Bungee Inline",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bungeeinline/v19/Gg8zN58UcgnlCweMrih332VuDGJ1-FEglsc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-bungee-outline",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f29d08f5-22b9-4e7f-ab4a-d21a58f2b5d3",-364401288),$APP.$cljs$cst$2675$family$$,"Bungee Outline",$APP.$cljs$cst$725$name$$,"Bungee Outline",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bungeeoutline/v24/_6_mEDvmVP24UvU2MyiGDslL3Qg3YhJqPXxo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bungee-shade",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f7587d8b-afe6-4a1f-b455-1c6ef2f9f759",-1899749412),$APP.$cljs$cst$2675$family$$,"Bungee Shade",$APP.$cljs$cst$725$name$$,"Bungee Shade",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bungeeshade/v17/DtVkJxarWL0t2KdzK3oI_jks7iLSrwFUlw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bungee-spice",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9e32edb1-7905-43c9-93f0-60850b57d05f",
-320874566),$APP.$cljs$cst$2675$family$$,"Bungee Spice",$APP.$cljs$cst$725$name$$,"Bungee Spice",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bungeespice/v15/nwpTtK2nIhxE0q-IwgSpZBqCzyI-aMPF7Q.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bungee-tint",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f35ece44-65b8-46b5-bbc6-d09200f0b600",-1393853034),$APP.$cljs$cst$2675$family$$,"Bungee Tint",$APP.$cljs$cst$725$name$$,"Bungee Tint",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bungeetint/v3/J7abnpl_EGtUEuAJwN9WmrtKMDwTpTkB.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-butcherman",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ac0778e3-04a6-42e5-83fa-bdf9745cc0d1",-211325362),$APP.$cljs$cst$2675$family$$,"Butcherman",$APP.$cljs$cst$725$name$$,"Butcherman",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/butcherman/v25/2EbiL-thF0loflXUBOdb1zWzq_5uT84.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-butterfly-kids",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6ff2a995-e2c5-42bd-9521-aaf5f7969415",-1716166654),$APP.$cljs$cst$2675$family$$,"Butterfly Kids",$APP.$cljs$cst$725$name$$,"Butterfly Kids",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/butterflykids/v27/ll8lK2CWTjuqAsXDqlnIbMNs5S4arxFrAX1D.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-bytesized",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3e785957-2bc2-4049-85cb-c6e20fa979ea",-1487673916),$APP.$cljs$cst$2675$family$$,"Bytesized",$APP.$cljs$cst$725$name$$,"Bytesized",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/bytesized/v1/goksH6L8FkdnROln8XBTS0CjkP1Yog.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cabin",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("52444f28-4767-41bf-a926-4ce2884db2d2",-1229026102),$APP.$cljs$cst$2675$family$$,"Cabin",$APP.$cljs$cst$725$name$$,
"Cabin",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cabin/v35/u-4X0qWljRw-PfU81xCKCpdpbgZJl6XFpfEd7eA9BIxxkV2EL7Gvxm7rE_s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cabin/v35/u-4X0qWljRw-PfU81xCKCpdpbgZJl6XFpfEd7eA9BIxxkW-EL7Gvxm7rE_s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cabin/v35/u-4X0qWljRw-PfU81xCKCpdpbgZJl6XFpfEd7eA9BIxxkYODL7Gvxm7rE_s.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cabin/v35/u-4X0qWljRw-PfU81xCKCpdpbgZJl6XFpfEd7eA9BIxxkbqDL7Gvxm7rE_s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cabin/v35/u-4V0qWljRw-Pd815fNqc8T_wAFcX-c37MPiNYlWniJ2hJXHx_KlwkzuA_u1Bg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cabin/v35/u-4V0qWljRw-Pd815fNqc8T_wAFcX-c37MPiNYlWniJ2hJXH9fKlwkzuA_u1Bg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cabin/v35/u-4V0qWljRw-Pd815fNqc8T_wAFcX-c37MPiNYlWniJ2hJXHGfWlwkzuA_u1Bg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/cabin/v35/u-4V0qWljRw-Pd815fNqc8T_wAFcX-c37MPiNYlWniJ2hJXHIPWlwkzuA_u1Bg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cabin-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ca850f4e-6491-4a23-b433-bd350ce40d3c",-1872286958),$APP.$cljs$cst$2675$family$$,"Cabin Condensed",$APP.$cljs$cst$725$name$$,"Cabin Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cabincondensed/v21/nwpMtK6mNhBK2err_hqkYhHRqmwaYOjZ5HZl8Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/cabincondensed/v21/nwpJtK6mNhBK2err_hqkYhHRqmwilMH97F15-K1oqQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cabincondensed/v21/nwpJtK6mNhBK2err_hqkYhHRqmwiuMb97F15-K1oqQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cabincondensed/v21/nwpJtK6mNhBK2err_hqkYhHRqmwi3Mf97F15-K1oqQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cabin-sketch",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ddb3dbb4-d026-45dc-a84a-06b812d0115b",-1030038568),$APP.$cljs$cst$2675$family$$,"Cabin Sketch",$APP.$cljs$cst$725$name$$,"Cabin Sketch",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cabinsketch/v23/QGYpz_kZZAGCONcK2A4bGOjMn9JM6fnuKg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cabinsketch/v23/QGY2z_kZZAGCONcK2A4bGOj0I_1o4dLyI4CMFw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cactus-classical-serif",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("648aea92-1b67-4d2c-b225-5dd326ee6308",-211870978),$APP.$cljs$cst$2675$family$$,"Cactus Classical Serif",$APP.$cljs$cst$725$name$$,"Cactus Classical Serif",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cactusclassicalserif/v13/sZlVdQ6K-zJOCzUaS90zMNN-Ep-OoC8dZr0JFuBIFX-pv-E.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-caesar-dressing",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("67b4cf2d-8db5-4306-b19f-73f5e9d9f712",-968045895),$APP.$cljs$cst$2675$family$$,"Caesar Dressing",$APP.$cljs$cst$725$name$$,"Caesar Dressing",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/caesardressing/v22/yYLx0hLa3vawqtwdswbotmK4vrR3cbb6LZttyg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cagliostro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("280628c1-12e3-44e1-9478-f0e332c3b1c7",2034554742),$APP.$cljs$cst$2675$family$$,"Cagliostro",$APP.$cljs$cst$725$name$$,"Cagliostro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cagliostro/v22/ZgNWjP5HM73BV5amnX-TjGXEM4COoE4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cairo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bbac3134-4df0-449a-b315-c6e3d6fcee68",
-522314414),$APP.$cljs$cst$2675$family$$,"Cairo",$APP.$cljs$cst$725$name$$,"Cairo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairo/v31/SLXgc1nY6HkvangtZmpQdkhzfH5lkSs2SgRjCAGMQ1z0hGA-W1ToLQ-HmkA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairo/v31/SLXgc1nY6HkvangtZmpQdkhzfH5lkSs2SgRjCAGMQ1z0hL4-W1ToLQ-HmkA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairo/v31/SLXgc1nY6HkvangtZmpQdkhzfH5lkSs2SgRjCAGMQ1z0hOA-W1ToLQ-HmkA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairo/v31/SLXgc1nY6HkvangtZmpQdkhzfH5lkSs2SgRjCAGMQ1z0hNI-W1ToLQ-HmkA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairo/v31/SLXgc1nY6HkvangtZmpQdkhzfH5lkSs2SgRjCAGMQ1z0hD45W1ToLQ-HmkA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairo/v31/SLXgc1nY6HkvangtZmpQdkhzfH5lkSs2SgRjCAGMQ1z0hAc5W1ToLQ-HmkA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairo/v31/SLXgc1nY6HkvangtZmpQdkhzfH5lkSs2SgRjCAGMQ1z0hGA5W1ToLQ-HmkA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairo/v31/SLXgc1nY6HkvangtZmpQdkhzfH5lkSs2SgRjCAGMQ1z0hEk5W1ToLQ-HmkA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cairo-play",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c160d845-adb0-408b-a159-b844b083c97f",-326689819),$APP.$cljs$cst$2675$family$$,"Cairo Play",$APP.$cljs$cst$725$name$$,"Cairo Play",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairoplay/v13/wXKEE3QSpo4vpRz_mz6FP-8iaauCLt_Hjopv3miu5IvcJo49mOo1EnYq9yXa8GvzaA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairoplay/v13/wXKEE3QSpo4vpRz_mz6FP-8iaauCLt_Hjopv3miu5IvcJo49mOo1zHYq9yXa8GvzaA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairoplay/v13/wXKEE3QSpo4vpRz_mz6FP-8iaauCLt_Hjopv3miu5IvcJo49mOo1knYq9yXa8GvzaA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairoplay/v13/wXKEE3QSpo4vpRz_mz6FP-8iaauCLt_Hjopv3miu5IvcJo49mOo1oHYq9yXa8GvzaA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairoplay/v13/wXKEE3QSpo4vpRz_mz6FP-8iaauCLt_Hjopv3miu5IvcJo49mOo1THEq9yXa8GvzaA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairoplay/v13/wXKEE3QSpo4vpRz_mz6FP-8iaauCLt_Hjopv3miu5IvcJo49mOo1dXEq9yXa8GvzaA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairoplay/v13/wXKEE3QSpo4vpRz_mz6FP-8iaauCLt_Hjopv3miu5IvcJo49mOo1EnEq9yXa8GvzaA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cairoplay/v13/wXKEE3QSpo4vpRz_mz6FP-8iaauCLt_Hjopv3miu5IvcJo49mOo1O3Eq9yXa8GvzaA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-cal-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2bec6af0-36eb-4e6f-94b8-a5ddda45abdb",1636878407),$APP.$cljs$cst$2675$family$$,"Cal Sans",$APP.$cljs$cst$725$name$$,"Cal Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/calsans/v2/fdN99sWUv3gWqXxqqSBbvloE4LZx.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-caladea",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a20cfabd-06b0-485f-b742-db1141b6c67b",1240458406),$APP.$cljs$cst$2675$family$$,"Caladea",$APP.$cljs$cst$725$name$$,"Caladea",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/caladea/v8/kJEzBugZ7AAjhybUjR93-9IztOc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/caladea/v8/kJExBugZ7AAjhybUvR19__A2pOdvDA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/caladea/v8/kJE2BugZ7AAjhybUtaNY39oYqO52FZ0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/caladea/v8/kJE0BugZ7AAjhybUvR1FQ98SrMxzBZ2lDA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-calistoga",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f4035766-b338-4dbf-93de-81f7180bab53",-202005202),$APP.$cljs$cst$2675$family$$,"Calistoga",$APP.$cljs$cst$725$name$$,"Calistoga",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/calistoga/v18/6NUU8F2OJg6MeR7l4e0vtMYAwdRZfw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-calligraffitti",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("176735c3-040f-42fc-926c-3d2db2af801c",
556591892),$APP.$cljs$cst$2675$family$$,"Calligraffitti",$APP.$cljs$cst$725$name$$,"Calligraffitti",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/calligraffitti/v20/46k2lbT3XjDVqJw3DCmCFjE0vnFZM5ZBpYN-.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cambay",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("873430ff-1dde-4de5-bb97-d95bab2e8567",1168362023),$APP.$cljs$cst$2675$family$$,"Cambay",$APP.$cljs$cst$725$name$$,"Cambay",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cambay/v14/SLXJc1rY6H0_ZDsGbrSIz9JsaA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cambay/v14/SLXLc1rY6H0_ZDs2bL6M7dd8aGZk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cambay/v14/SLXKc1rY6H0_ZDs-0pusx_lwYX99kA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cambay/v14/SLXMc1rY6H0_ZDs2bIYwwvN0Q3ptkDMN.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cambo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7e0e0afa-e065-452a-83e9-7175be1a77e2",-496985361),$APP.$cljs$cst$2675$family$$,"Cambo",$APP.$cljs$cst$725$name$$,"Cambo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cambo/v19/IFSqHeNEk8FJk416ok7xkPm8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-candal",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4bfb1f51-66a9-4f08-ae65-986667a951ba",-1479559057),$APP.$cljs$cst$2675$family$$,"Candal",$APP.$cljs$cst$725$name$$,"Candal",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/candal/v16/XoHn2YH6T7-t_8cNAR4Jt9Yxlw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cantarell",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fec5070a-63b6-411c-bf09-85614b0ab542",
-1649667369),$APP.$cljs$cst$2675$family$$,"Cantarell",$APP.$cljs$cst$725$name$$,"Cantarell",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cantarell/v18/B50NF7ZDq37KMUvlO01Ji6hqHK-CLA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cantarell/v18/B50LF7ZDq37KMUvlO015iaJuPqqSLJYf.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/cantarell/v18/B50IF7ZDq37KMUvlO01xN4dOFISeJY8GgQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cantarell/v18/B50WF7ZDq37KMUvlO015iZrSEY6aB4oWgWHB.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cantata-one",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("79ad4444-4f43-4591-8d48-1488fcbb377b",-1022534839),$APP.$cljs$cst$2675$family$$,"Cantata One",$APP.$cljs$cst$725$name$$,"Cantata One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/cantataone/v16/PlI5Fl60Nb5obNzNe2jslVxEt8CwfGaD.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cantora-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cf75a8f6-2610-4b40-b1dc-f280f653be6d",-594419508),$APP.$cljs$cst$2675$family$$,"Cantora One",$APP.$cljs$cst$725$name$$,"Cantora One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cantoraone/v20/gyB4hws1JdgnKy56GB_JX6zdZ4vZVbgZ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-caprasimo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6fc85cdc-67ab-4d7c-a3ac-29a956473850",891773854),$APP.$cljs$cst$2675$family$$,"Caprasimo",$APP.$cljs$cst$725$name$$,
"Caprasimo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/caprasimo/v6/esDT31JQOPuXIUGBp72klZUCGpG-GQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-capriola",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("245bc7ca-e6d8-4b52-8f96-568cd9fd6d7d",1279031611),$APP.$cljs$cst$2675$family$$,"Capriola",$APP.$cljs$cst$725$name$$,"Capriola",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/capriola/v15/wXKoE3YSppcvo1PDln_8L-AinG8y.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-caramel",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2e54691a-5394-4ed2-bb99-f6848ffc1baf",-203916917),$APP.$cljs$cst$2675$family$$,"Caramel",$APP.$cljs$cst$725$name$$,"Caramel",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/caramel/v8/P5sCzZKBbMTf_ShyxCRuiZ-uydg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-carattere",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("420c2962-a397-4464-8d13-14caf023f93f",-1970653980),$APP.$cljs$cst$2675$family$$,
"Carattere",$APP.$cljs$cst$725$name$$,"Carattere",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/carattere/v8/4iCv6Kp1b9dXlgt_CkvTt2aMH4V_gg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-cardo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b7cf8679-d1fd-4cc6-9f07-b9fe411cc1e0",-752568732),$APP.$cljs$cst$2675$family$$,"Cardo",$APP.$cljs$cst$725$name$$,"Cardo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cardo/v21/wlp_gwjKBV1pqiv_1oAZ2H5O.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cardo/v21/wlpxgwjKBV1pqhv93IQ73W5OcCk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cardo/v21/wlpygwjKBV1pqhND-aQR82JHaTBX.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-carlito",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7be0f9ad-cb8d-4691-927b-cd63e18bbebf",886399623),$APP.$cljs$cst$2675$family$$,"Carlito",$APP.$cljs$cst$725$name$$,"Carlito",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/carlito/v4/3Jn9SDPw3m-pk039PDCLTXUETuE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/carlito/v4/3Jn_SDPw3m-pk039DDKBSVcBXuFb0Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/carlito/v4/3Jn4SDPw3m-pk039BIykaX0vUuhCyOo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,
"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/carlito/v4/3Jn6SDPw3m-pk039DDK59XglVspH2OprMQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-carme",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c0f492b2-c2fe-4a1e-98d1-2c27b71890f3",1498817081),$APP.$cljs$cst$2675$family$$,"Carme",$APP.$cljs$cst$725$name$$,"Carme",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/carme/v17/ptRHTiWdbvZIDOjGxLNrxfbZ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-carrois-gothic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("88738c2c-8947-4972-a289-e9bcb28f0e25",
2055948812),$APP.$cljs$cst$2675$family$$,"Carrois Gothic",$APP.$cljs$cst$725$name$$,"Carrois Gothic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/carroisgothic/v17/Z9XPDmFATg-N1PLtLOOxvIHl9ZmD3i7ajcJ-.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-carrois-gothic-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e09ebc4a-29fd-4ccb-8cad-e4ee894b5336",-261842182),$APP.$cljs$cst$2675$family$$,"Carrois Gothic SC",$APP.$cljs$cst$725$name$$,"Carrois Gothic SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/carroisgothicsc/v16/ZgNJjOVHM6jfUZCmyUqT2A2HVKjc-28nNHabY4dN.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-carter-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1abf8733-1386-4c3a-b640-4bf68cf280ba",-667339888),$APP.$cljs$cst$2675$family$$,"Carter One",$APP.$cljs$cst$725$name$$,
"Carter One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/carterone/v18/q5uCsoe5IOB2-pXv9UcNIxR2hYxREMs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-cascadia-code",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f83d0efc-23fd-4d9c-8dae-0b761d492f06",1724394667),$APP.$cljs$cst$2675$family$$,"Cascadia Code",$APP.$cljs$cst$725$name$$,"Cascadia Code",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiacode/v5/qWc_B6-zq5zxD57cT5s916v3QjfzRuG9AIUcXuWMOaDPb9pHaHCA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiacode/v5/qWc_B6-zq5zxD57cT5s916v3QjfzRuG9AIUcXuVSOaDPb9pHaHCA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiacode/v5/qWc_B6-zq5zxD57cT5s916v3QjfzRuG9AIUcXuUMOaDPb9pHaHCA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiacode/v5/qWc_B6-zq5zxD57cT5s916v3QjfzRuG9AIUcXuU-OaDPb9pHaHCA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiacode/v5/qWc_B6-zq5zxD57cT5s916v3QjfzRuG9AIUcXuXSPqDPb9pHaHCA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiacode/v5/qWc_B6-zq5zxD57cT5s916v3QjfzRuG9AIUcXuXrPqDPb9pHaHCA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiacode/v5/qWc9B6-zq5zxD57cT5s916v3aD7BuTnUax-yWfDEesiMZd5lbWCAUXU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiacode/v5/qWc9B6-zq5zxD57cT5s916v3aD7BuTnUax-yWfDEehaMZd5lbWCAUXU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/cascadiacode/v5/qWc9B6-zq5zxD57cT5s916v3aD7BuTnUax-yWfDEekiMZd5lbWCAUXU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiacode/v5/qWc9B6-zq5zxD57cT5s916v3aD7BuTnUax-yWfDEenqMZd5lbWCAUXU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiacode/v5/qWc9B6-zq5zxD57cT5s916v3aD7BuTnUax-yWfDEepaLZd5lbWCAUXU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiacode/v5/qWc9B6-zq5zxD57cT5s916v3aD7BuTnUax-yWfDEeq-LZd5lbWCAUXU.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cascadia-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("137cddc0-d390-4cd0-919d-0a1bb407d634",-731030132),$APP.$cljs$cst$2675$family$$,"Cascadia Mono",$APP.$cljs$cst$725$name$$,"Cascadia Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",
$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiamono/v5/TUZlzw5pquJF3iuizJDZYqr1Q54PIbV3QmZsSTadsWVkNot27AYk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiamono/v5/TUZlzw5pquJF3iuizJDZYqr1Q54PIbV3QmZsSTZDsWVkNot27AYk.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiamono/v5/TUZlzw5pquJF3iuizJDZYqr1Q54PIbV3QmZsSTYdsWVkNot27AYk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiamono/v5/TUZlzw5pquJF3iuizJDZYqr1Q54PIbV3QmZsSTYvsWVkNot27AYk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiamono/v5/TUZlzw5pquJF3iuizJDZYqr1Q54PIbV3QmZsSTbDtmVkNot27AYk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiamono/v5/TUZlzw5pquJF3iuizJDZYqr1Q54PIbV3QmZsSTb6tmVkNot27AYk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiamono/v5/TUZnzw5pquJF3iuizJDZYqr1aZc93m0eKfzCTiPV8g0nPI9U6RYkQrY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiamono/v5/TUZnzw5pquJF3iuizJDZYqr1aZc93m0eKfzCTiPV8tMnPI9U6RYkQrY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiamono/v5/TUZnzw5pquJF3iuizJDZYqr1aZc93m0eKfzCTiPV8o0nPI9U6RYkQrY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiamono/v5/TUZnzw5pquJF3iuizJDZYqr1aZc93m0eKfzCTiPV8r8nPI9U6RYkQrY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cascadiamono/v5/TUZnzw5pquJF3iuizJDZYqr1aZc93m0eKfzCTiPV8lMgPI9U6RYkQrY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/cascadiamono/v5/TUZnzw5pquJF3iuizJDZYqr1aZc93m0eKfzCTiPV8mogPI9U6RYkQrY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-castoro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("67cfe4ef-1d6f-49d5-8b15-a6c89729a7ec",-174680063),$APP.$cljs$cst$2675$family$$,"Castoro",$APP.$cljs$cst$725$name$$,"Castoro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/castoro/v20/1q2GY5yMCld3-O4cHYhEzOYenEU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/castoro/v20/1q2EY5yMCld3-O4cLYpOyMQbjEX5fw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-castoro-titling",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("01b37c30-067e-4ee5-a39d-b2cb49e52750",1687116150),$APP.$cljs$cst$2675$family$$,"Castoro Titling",$APP.$cljs$cst$725$name$$,"Castoro Titling",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/castorotitling/v10/buEupouwccj03leTfjUAhEZWlrNqYgckeo9RMw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-catamaran",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c23e67ef-0bfe-4052-8de8-b1671099da19",597313546),
$APP.$cljs$cst$2675$family$$,"Catamaran",$APP.$cljs$cst$725$name$$,"Catamaran",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/catamaran/v28/o-0bIpQoyXQa2RxT7-5B6Ryxs2E_6n1iPHjc1anXuluiLyw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/catamaran/v28/o-0bIpQoyXQa2RxT7-5B6Ryxs2E_6n1iPPjd1anXuluiLyw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/catamaran/v28/o-0bIpQoyXQa2RxT7-5B6Ryxs2E_6n1iPCbd1anXuluiLyw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/catamaran/v28/o-0bIpQoyXQa2RxT7-5B6Ryxs2E_6n1iPHjd1anXuluiLyw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/catamaran/v28/o-0bIpQoyXQa2RxT7-5B6Ryxs2E_6n1iPErd1anXuluiLyw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/catamaran/v28/o-0bIpQoyXQa2RxT7-5B6Ryxs2E_6n1iPKba1anXuluiLyw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/catamaran/v28/o-0bIpQoyXQa2RxT7-5B6Ryxs2E_6n1iPJ_a1anXuluiLyw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/catamaran/v28/o-0bIpQoyXQa2RxT7-5B6Ryxs2E_6n1iPPja1anXuluiLyw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/catamaran/v28/o-0bIpQoyXQa2RxT7-5B6Ryxs2E_6n1iPNHa1anXuluiLyw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-caudex",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("64af9eee-8a3c-4c1c-9095-1a6b5b0660bc",-453938767),$APP.$cljs$cst$2675$family$$,"Caudex",$APP.$cljs$cst$725$name$$,"Caudex",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/caudex/v19/esDQ311QOP6BJUrIyviAnb4eEw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/caudex/v19/esDS311QOP6BJUr4yPKEv7sOE4in.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/caudex/v19/esDT311QOP6BJUrwdteklZUCGpG-GQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/caudex/v19/esDV311QOP6BJUr4yMo4kJ8GOJSuGdLB.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-caveat",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dac55250-47f6-48a8-b730-756720757679",1047936909),$APP.$cljs$cst$2675$family$$,"Caveat",$APP.$cljs$cst$725$name$$,"Caveat",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/caveat/v23/WnznHAc5bAfYB2QRah7pcpNvOx-pjfJ9SIKjYBxPigs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/caveat/v23/WnznHAc5bAfYB2QRah7pcpNvOx-pjcB9SIKjYBxPigs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/caveat/v23/WnznHAc5bAfYB2QRah7pcpNvOx-pjSx6SIKjYBxPigs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/caveat/v23/WnznHAc5bAfYB2QRah7pcpNvOx-pjRV6SIKjYBxPigs.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-caveat-brush",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fd67d09d-9d9a-4ef5-ade7-bb59635033bd",-357286208),$APP.$cljs$cst$2675$family$$,"Caveat Brush",$APP.$cljs$cst$725$name$$,"Caveat Brush",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/caveatbrush/v12/EYq0maZfwr9S9-ETZc3fKXtMW7mT03pdQw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cedarville-cursive",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("300d0261-1fd4-4f6e-b8e0-976116192dd9",-1108855083),$APP.$cljs$cst$2675$family$$,"Cedarville Cursive",$APP.$cljs$cst$725$name$$,
"Cedarville Cursive",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cedarvillecursive/v18/yYL00g_a2veiudhUmxjo5VKkoqA-B_neJbBxw8BeTg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-ceviche-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e1deab92-f1db-4987-b0e9-21f0d34d9a68",-221510173),$APP.$cljs$cst$2675$family$$,"Ceviche One",$APP.$cljs$cst$725$name$$,"Ceviche One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cevicheone/v17/gyB4hws1IcA6JzR-GB_JX6zdZ4vZVbgZ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chakra-petch",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("89fae93a-19ab-4ada-a937-0cd4b473a73f",-956327303),$APP.$cljs$cst$2675$family$$,"Chakra Petch",$APP.$cljs$cst$725$name$$,"Chakra Petch",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chakrapetch/v13/cIflMapbsEk7TDLdtEz1BwkeNIhFQJXE3AY00g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chakrapetch/v13/cIfnMapbsEk7TDLdtEz1BwkWmpLJQp_A_gMk0izH.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chakrapetch/v13/cIf6MapbsEk7TDLdtEz1BwkmmKBhSL7Y1Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",
$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chakrapetch/v13/cIfkMapbsEk7TDLdtEz1BwkWmqplarvI1R8t.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chakrapetch/v13/cIflMapbsEk7TDLdtEz1BwkebIlFQJXE3AY00g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chakrapetch/v13/cIfnMapbsEk7TDLdtEz1BwkWmpKRQ5_A_gMk0izH.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chakrapetch/v13/cIflMapbsEk7TDLdtEz1BwkeQI5FQJXE3AY00g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chakrapetch/v13/cIfnMapbsEk7TDLdtEz1BwkWmpK9RJ_A_gMk0izH.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chakrapetch/v13/cIflMapbsEk7TDLdtEz1BwkeJI9FQJXE3AY00g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chakrapetch/v13/cIfnMapbsEk7TDLdtEz1BwkWmpLZRZ_A_gMk0izH.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-changa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("805c25ae-4f92-49c1-a993-c018df034afe",1325987781),$APP.$cljs$cst$2675$family$$,"Changa",$APP.$cljs$cst$725$name$$,"Changa",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/changa/v29/2-c79JNi2YuVOUcOarRPgnNGooxCZy2xQjDp9htf1ZM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/changa/v29/2-c79JNi2YuVOUcOarRPgnNGooxCZ_OxQjDp9htf1ZM.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/changa/v29/2-c79JNi2YuVOUcOarRPgnNGooxCZ62xQjDp9htf1ZM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/changa/v29/2-c79JNi2YuVOUcOarRPgnNGooxCZ5-xQjDp9htf1ZM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/changa/v29/2-c79JNi2YuVOUcOarRPgnNGooxCZ3O2QjDp9htf1ZM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/changa/v29/2-c79JNi2YuVOUcOarRPgnNGooxCZ0q2QjDp9htf1ZM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/changa/v29/2-c79JNi2YuVOUcOarRPgnNGooxCZy22QjDp9htf1ZM.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-changa-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fa790017-2579-4743-a0ab-f37aa680278d",-1107959352),$APP.$cljs$cst$2675$family$$,"Changa One",$APP.$cljs$cst$725$name$$,"Changa One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/changaone/v22/xfu00W3wXn3QLUJXhzq46AbouLfbK64.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/changaone/v22/xfu20W3wXn3QLUJXhzq42ATivJXeO67ISw.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chango",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e21c186f-db32-4b4f-8361-35fa5e576a8a",-1252278200),$APP.$cljs$cst$2675$family$$,"Chango",$APP.$cljs$cst$725$name$$,"Chango",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chango/v29/2V0cKI0OB5U7WaJyz324TFUaAw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-charis-sil",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8e08237e-44c8-4bf7-ba0e-0a50c7845ac3",-469910563),$APP.$cljs$cst$2675$family$$,"Charis SIL",$APP.$cljs$cst$725$name$$,"Charis SIL",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/charissil/v2/oPWK_kV3l-s-Q8govXvKrPrmYjZ2Xn0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/charissil/v2/oPWI_kV3l-s-Q8govXvKnPjsZhRzTn2Ozw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/charissil/v2/oPWJ_kV3l-s-Q8govXvKlEbJRj5dQnSX1ko.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/charissil/v2/oPWX_kV3l-s-Q8govXvKnPjU2jtXRlaSxkrMCQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-charm",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("58f6208e-e020-4cc9-9a44-db8463d6eb72",-1660945812),$APP.$cljs$cst$2675$family$$,"Charm",$APP.$cljs$cst$725$name$$,"Charm",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/charm/v14/7cHmv4oii5K0MeYvIe804WIo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/charm/v14/7cHrv4oii5K0Md6TDss8yn4hnCci.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-charmonman",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0fae08d1-045b-4e3a-8459-ce6b758b2867",308122474),$APP.$cljs$cst$2675$family$$,"Charmonman",$APP.$cljs$cst$725$name$$,"Charmonman",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/charmonman/v20/MjQDmiR3vP_nuxDv47jiWJGovLdh6OE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/charmonman/v20/MjQAmiR3vP_nuxDv47jiYC2HmL9K9OhmGnY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chathura",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("985de044-febc-4130-baad-ff8b654774f5",1590204465),$APP.$cljs$cst$2675$family$$,"Chathura",$APP.$cljs$cst$725$name$$,"Chathura",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chathura/v22/_gP91R7-rzUuVjim42dEq0SbTvZyuDo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/chathura/v22/_gP81R7-rzUuVjim42eMiWSxYPp7oSNy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chathura/v22/_gP71R7-rzUuVjim418goUC5S-Zy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chathura/v22/_gP81R7-rzUuVjim42ecjmSxYPp7oSNy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chathura/v22/_gP81R7-rzUuVjim42eAjWSxYPp7oSNy.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-chau-philomene-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b308e660-2cb1-4be7-adee-d6988f6e7389",-1443383818),$APP.$cljs$cst$2675$family$$,"Chau Philomene One",$APP.$cljs$cst$725$name$$,"Chau Philomene One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chauphilomeneone/v16/55xxezRsPtfie1vPY49qzdgSlJiHRQFsnIx7QMISdQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chauphilomeneone/v16/55xzezRsPtfie1vPY49qzdgSlJiHRQFcnoZ_YscCdXQB.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chela-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6ab2baf4-acfc-49f2-903f-da3a79bc6caa",1390819935),$APP.$cljs$cst$2675$family$$,"Chela One",$APP.$cljs$cst$725$name$$,"Chela One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chelaone/v22/6ae-4KC7Uqgdz_JZdPIy31vWNTMwoQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chelsea-market",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d60d3f9b-e225-4b63-b796-72a8c1aeac55",1540630618),$APP.$cljs$cst$2675$family$$,"Chelsea Market",$APP.$cljs$cst$725$name$$,"Chelsea Market",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chelseamarket/v14/BCawqZsHqfr89WNP_IApC8tzKBhlLA4uKkWk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chenla",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1f66bdc1-2569-43bb-8e3c-71cc5a3540a9",-564440978),$APP.$cljs$cst$2675$family$$,"Chenla",$APP.$cljs$cst$725$name$$,"Chenla",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/chenla/v25/SZc43FDpIKu8WZ9eXxfonUPL6Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cherish",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("176ca68d-6c03-427a-b6d4-5ff2ccf938dd",309526641),$APP.$cljs$cst$2675$family$$,"Cherish",$APP.$cljs$cst$725$name$$,"Cherish",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cherish/v9/ll88K2mXUyqsDsTN5iDCI6IJjg8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cherry-bomb-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1ce13cf8-18c6-48ea-9efd-9a78ae3c07da",-503381620),$APP.$cljs$cst$2675$family$$,"Cherry Bomb One",$APP.$cljs$cst$725$name$$,
"Cherry Bomb One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cherrybombone/v11/y83DW4od1h6KlV3c6JJhRhGOdhrKDNpF41fr-w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-cherry-cream-soda",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5c5cd0bc-bb91-4194-8f27-e82da6990431",1476814151),$APP.$cljs$cst$2675$family$$,"Cherry Cream Soda",$APP.$cljs$cst$725$name$$,"Cherry Cream Soda",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cherrycreamsoda/v21/UMBIrOxBrW6w2FFyi9paG0fdVdRciTd6Cd47DJ7G.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cherry-swash",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6e69e8d2-6dae-4e94-b9c0-1f3f448a3895",-804207094),$APP.$cljs$cst$2675$family$$,"Cherry Swash",$APP.$cljs$cst$725$name$$,"Cherry Swash",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cherryswash/v22/i7dNIFByZjaNAMxtZcnfAy58QHi-EwWMbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cherryswash/v22/i7dSIFByZjaNAMxtZcnfAy5E_FeaGy6QZ3WfYg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chewy",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("31864444-237d-4f2d-9ab6-76369f09fafa",-1541578898),$APP.$cljs$cst$2675$family$$,"Chewy",$APP.$cljs$cst$725$name$$,"Chewy",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chewy/v18/uK_94ruUb-k-wk5xIDMfO-ed.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chicle",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a2d36355-a98d-4adc-bc41-e4e4dd38d7c5",
-1852714533),$APP.$cljs$cst$2675$family$$,"Chicle",$APP.$cljs$cst$725$name$$,"Chicle",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chicle/v27/lJwG-pw9i2dqU-BDyWKuobYSxw.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chilanka",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("43d2d3c4-08e3-48db-bd7c-c8171aa8139d",354234325),$APP.$cljs$cst$2675$family$$,"Chilanka",$APP.$cljs$cst$725$name$$,"Chilanka",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chilanka/v23/WWXRlj2DZQiMJYaYRrJQI9EAZhTO.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chiron-goround-tc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b6d2c34a-d764-4a49-b0ac-a1abc7123b7a",306176222),$APP.$cljs$cst$2675$family$$,"Chiron GoRound TC",$APP.$cljs$cst$725$name$$,"Chiron GoRound TC",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chirongoroundtc/v2/tssEAopDbiwZ4xauFDX3yQ3Ywoaj6kNR0yP4oqNo8RKq7BqJHA8n4CeB1Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",
$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chirongoroundtc/v2/tssEAopDbiwZ4xauFDX3yQ3Ywoaj6kNR0yP4oqNo8RKqMhqJHA8n4CeB1Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chirongoroundtc/v2/tssEAopDbiwZ4xauFDX3yQ3Ywoaj6kNR0yP4oqNo8RKqbBqJHA8n4CeB1Q.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chirongoroundtc/v2/tssEAopDbiwZ4xauFDX3yQ3Ywoaj6kNR0yP4oqNo8RKqXhqJHA8n4CeB1Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chirongoroundtc/v2/tssEAopDbiwZ4xauFDX3yQ3Ywoaj6kNR0yP4oqNo8RKqsh2JHA8n4CeB1Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chirongoroundtc/v2/tssEAopDbiwZ4xauFDX3yQ3Ywoaj6kNR0yP4oqNo8RKqix2JHA8n4CeB1Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chirongoroundtc/v2/tssEAopDbiwZ4xauFDX3yQ3Ywoaj6kNR0yP4oqNo8RKq7B2JHA8n4CeB1Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chirongoroundtc/v2/tssEAopDbiwZ4xauFDX3yQ3Ywoaj6kNR0yP4oqNo8RKqxR2JHA8n4CeB1Q.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chiron-hei-hk",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8060b1fb-e6a3-4fd2-8b9c-f511201047e7",991434595),$APP.$cljs$cst$2675$family$$,"Chiron Hei HK",$APP.$cljs$cst$725$name$$,"Chiron Hei HK",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",
$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK-E3MSr44vpVKPvzqVJaxhp3w7QQhPNY163lLtr18MkTEyjPI0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK-E3MSr44vpVKPvzqVJaxhp3w7QQhPNY163lIzr18MkTEyjPI0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK-E3MSr44vpVKPvzqVJaxhp3w7QQhPNY163lJtr18MkTEyjPI0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK-E3MSr44vpVKPvzqVJaxhp3w7QQhPNY163lJfr18MkTEyjPI0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK-E3MSr44vpVKPvzqVJaxhp3w7QQhPNY163lKzqF8MkTEyjPI0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK-E3MSr44vpVKPvzqVJaxhp3w7QQhPNY163lKKqF8MkTEyjPI0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK-E3MSr44vpVKPvzqVJaxhp3w7QQhPNY163lLtqF8MkTEyjPI0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK-E3MSr44vpVKPvzqVJaxhp3w7QQhPNY163lLEqF8MkTEyjPI0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK8E3MSr44vpVKPvzqVJaxhjXUJvtAmXhfU2Uel7DdPmzUQieI0QjQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK8E3MSr44vpVKPvzqVJaxhjXUJvtAmXhfU2Uel7OlPmzUQieI0QjQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK8E3MSr44vpVKPvzqVJaxhjXUJvtAmXhfU2Uel7LdPmzUQieI0QjQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/chironheihk/v3/wXK8E3MSr44vpVKPvzqVJaxhjXUJvtAmXhfU2Uel7IVPmzUQieI0QjQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK8E3MSr44vpVKPvzqVJaxhjXUJvtAmXhfU2Uel7GlImzUQieI0QjQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK8E3MSr44vpVKPvzqVJaxhjXUJvtAmXhfU2Uel7FBImzUQieI0QjQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK8E3MSr44vpVKPvzqVJaxhjXUJvtAmXhfU2Uel7DdImzUQieI0QjQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironheihk/v3/wXK8E3MSr44vpVKPvzqVJaxhjXUJvtAmXhfU2Uel7B5ImzUQieI0QjQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chiron-sung-hk",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8c0c0ec9-3b23-4101-bbea-f4bbf801bfdc",
2012514619),$APP.$cljs$cst$2675$family$$,"Chiron Sung HK",$APP.$cljs$cst$725$name$$,"Chiron Sung HK",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFtD_XLTZPpXIpS3-3dhGzHTSilFc8oGNI59hRjdOSt_krURtf4_Q.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFtD_XLTZPpXIpS3-3dhGzHTSilFc8oGNI59hRjquSt_krURtf4_Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFtD_XLTZPpXIpS3-3dhGzHTSilFc8oGNI59hRj9OSt_krURtf4_Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFtD_XLTZPpXIpS3-3dhGzHTSilFc8oGNI59hRjxuSt_krURtf4_Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFtD_XLTZPpXIpS3-3dhGzHTSilFc8oGNI59hRjKuOt_krURtf4_Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFtD_XLTZPpXIpS3-3dhGzHTSilFc8oGNI59hRjE-Ot_krURtf4_Q.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFtD_XLTZPpXIpS3-3dhGzHTSilFc8oGNI59hRjdOOt_krURtf4_Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFtD_XLTZPpXIpS3-3dhGzHTSilFc8oGNI59hRjXeOt_krURtf4_Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFvD_XLTZPpXIpS3-3dhGzHTQKsJzDwcbmjWBN2PKfFvUDQZNLo_U2r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFvD_XLTZPpXIpS3-3dhGzHTQKsJzDwcbmjWBN2PKcbvUDQZNLo_U2r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/chironsunghk/v1/nuFvD_XLTZPpXIpS3-3dhGzHTQKsJzDwcbmjWBN2PKdFvUDQZNLo_U2r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFvD_XLTZPpXIpS3-3dhGzHTQKsJzDwcbmjWBN2PKd3vUDQZNLo_U2r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFvD_XLTZPpXIpS3-3dhGzHTQKsJzDwcbmjWBN2PKebukDQZNLo_U2r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFvD_XLTZPpXIpS3-3dhGzHTQKsJzDwcbmjWBN2PKeiukDQZNLo_U2r.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFvD_XLTZPpXIpS3-3dhGzHTQKsJzDwcbmjWBN2PKfFukDQZNLo_U2r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chironsunghk/v1/nuFvD_XLTZPpXIpS3-3dhGzHTQKsJzDwcbmjWBN2PKfsukDQZNLo_U2r.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chivo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4764f748-7b56-4e70-8cb6-0dc73e2e80da",1310820098),$APP.$cljs$cst$2675$family$$,"Chivo",$APP.$cljs$cst$725$name$$,"Chivo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9b4kzIxd1KFppkaRKvDRPJVDf_vB7ul2DSFXjQiQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/chivo/v21/va9b4kzIxd1KFppkaRKvDRPJVDf_PB_ul2DSFXjQiQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9b4kzIxd1KFppkaRKvDRPJVDf_4h_ul2DSFXjQiQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9b4kzIxd1KFppkaRKvDRPJVDf_vB_ul2DSFXjQiQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9b4kzIxd1KFppkaRKvDRPJVDf_jh_ul2DSFXjQiQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9b4kzIxd1KFppkaRKvDRPJVDf_Yhjul2DSFXjQiQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9b4kzIxd1KFppkaRKvDRPJVDf_Wxjul2DSFXjQiQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9b4kzIxd1KFppkaRKvDRPJVDf_PBjul2DSFXjQiQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/chivo/v21/va9b4kzIxd1KFppkaRKvDRPJVDf_FRjul2DSFXjQiQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9Z4kzIxd1KFrBtW-13ZHhT-jDqdFwG1WrWN33AiasJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,
"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9Z4kzIxd1KFrBtW-13ZHhT-jDqdFyG1GrWN33AiasJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9Z4kzIxd1KFrBtW-13ZHhT-jDqdFxY1GrWN33AiasJ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9Z4kzIxd1KFrBtW-13ZHhT-jDqdFwG1GrWN33AiasJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9Z4kzIxd1KFrBtW-13ZHhT-jDqdFw01GrWN33AiasJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9Z4kzIxd1KFrBtW-13ZHhT-jDqdFzY02rWN33AiasJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9Z4kzIxd1KFrBtW-13ZHhT-jDqdFzh02rWN33AiasJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9Z4kzIxd1KFrBtW-13ZHhT-jDqdFyG02rWN33AiasJ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivo/v21/va9Z4kzIxd1KFrBtW-13ZHhT-jDqdFyv02rWN33AiasJ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chivo-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cf100579-903a-46e4-b7b6-05e7bee511f3",
1701129592),$APP.$cljs$cst$2675$family$$,"Chivo Mono",$APP.$cljs$cst$725$name$$,"Chivo Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFThWbgRxKvF_Z5eQMO9qRMrJJrnKNtC3D7hrqfVKphL03l4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFThWbgRxKvF_Z5eQMO9qRMrJJrnKNtC3D5hr6fVKphL03l4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFThWbgRxKvF_Z5eQMO9qRMrJJrnKNtC3D6_r6fVKphL03l4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFThWbgRxKvF_Z5eQMO9qRMrJJrnKNtC3D7hr6fVKphL03l4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFThWbgRxKvF_Z5eQMO9qRMrJJrnKNtC3D7Tr6fVKphL03l4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFThWbgRxKvF_Z5eQMO9qRMrJJrnKNtC3D4_qKfVKphL03l4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFThWbgRxKvF_Z5eQMO9qRMrJJrnKNtC3D4GqKfVKphL03l4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFThWbgRxKvF_Z5eQMO9qRMrJJrnKNtC3D5hqKfVKphL03l4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFThWbgRxKvF_Z5eQMO9qRMrJJrnKNtC3D5IqKfVKphL03l4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFTjWbgRxKvF_Z5eQMO9gxoZ20KOQ0Hs2ysp7E-XIJxp1ml4imo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFTjWbgRxKvF_Z5eQMO9gxoZ20KOQ0Hs2ysp7M-WIJxp1ml4imo.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFTjWbgRxKvF_Z5eQMO9gxoZ20KOQ0Hs2ysp7BGWIJxp1ml4imo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFTjWbgRxKvF_Z5eQMO9gxoZ20KOQ0Hs2ysp7E-WIJxp1ml4imo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFTjWbgRxKvF_Z5eQMO9gxoZ20KOQ0Hs2ysp7H2WIJxp1ml4imo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFTjWbgRxKvF_Z5eQMO9gxoZ20KOQ0Hs2ysp7JGRIJxp1ml4imo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/chivomono/v11/mFTjWbgRxKvF_Z5eQMO9gxoZ20KOQ0Hs2ysp7KiRIJxp1ml4imo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFTjWbgRxKvF_Z5eQMO9gxoZ20KOQ0Hs2ysp7M-RIJxp1ml4imo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chivomono/v11/mFTjWbgRxKvF_Z5eQMO9gxoZ20KOQ0Hs2ysp7OaRIJxp1ml4imo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chocolate-classical-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7d3d3901-d8e7-4cf0-9ec9-34a18708caa2",-1500159587),$APP.$cljs$cst$2675$family$$,"Chocolate Classical Sans",
$APP.$cljs$cst$725$name$$,"Chocolate Classical Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chocolateclassicalsans/v14/nuFqD-PLTZX4XIgT-P2ToCDudWHHflqUpTpfjWdDPI2J9mHITw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chokokutai",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("160ff7dc-d6be-46a3-9ff6-bd41210e4376",1501832155),$APP.$cljs$cst$2675$family$$,"Chokokutai",$APP.$cljs$cst$725$name$$,"Chokokutai",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chokokutai/v12/kmK4Zqw4HwvCeHGM8Fws9y7ypu1Kr7I.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-chonburi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a470b50e-9465-4a88-8017-246c4afa5048",64430655),$APP.$cljs$cst$2675$family$$,"Chonburi",$APP.$cljs$cst$725$name$$,"Chonburi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/chonburi/v14/8AtqGs-wOpGRTBq66IWaFr3biAfZ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cinzel",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("16bfadf9-62ad-4193-94b8-761c3907d812",
817277509),$APP.$cljs$cst$2675$family$$,"Cinzel",$APP.$cljs$cst$725$name$$,"Cinzel",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cinzel/v26/8vIU7ww63mVu7gtR-kwKxNvkNOjw-tbnTYrvDE5ZdqU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cinzel/v26/8vIU7ww63mVu7gtR-kwKxNvkNOjw-uTnTYrvDE5ZdqU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/cinzel/v26/8vIU7ww63mVu7gtR-kwKxNvkNOjw-gjgTYrvDE5ZdqU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cinzel/v26/8vIU7ww63mVu7gtR-kwKxNvkNOjw-jHgTYrvDE5ZdqU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cinzel/v26/8vIU7ww63mVu7gtR-kwKxNvkNOjw-lbgTYrvDE5ZdqU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cinzel/v26/8vIU7ww63mVu7gtR-kwKxNvkNOjw-n_gTYrvDE5ZdqU.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cinzel-decorative",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("eb7842ad-9944-4b8b-8ce2-d36ad6377a98",-440785137),$APP.$cljs$cst$2675$family$$,"Cinzel Decorative",$APP.$cljs$cst$725$name$$,"Cinzel Decorative",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cinzeldecorative/v19/daaCSScvJGqLYhG8nNt8KPPswUAPnh7URs1LaCyC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cinzeldecorative/v19/daaHSScvJGqLYhG8nNt8KPPswUAPniZoaelDQzCLlQXE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cinzeldecorative/v19/daaHSScvJGqLYhG8nNt8KPPswUAPniZQa-lDQzCLlQXE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-clicker-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5baac3f1-a917-4a97-856d-b66f58ade457",
-94249440),$APP.$cljs$cst$2675$family$$,"Clicker Script",$APP.$cljs$cst$725$name$$,"Clicker Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/clickerscript/v14/raxkHiKPvt8CMH6ZWP8PdlEq72rY2zqUKafv.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-climate-crisis",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7f46567a-f343-4759-91a8-c18f09ffd3a1",1561830427),$APP.$cljs$cst$2675$family$$,"Climate Crisis",$APP.$cljs$cst$725$name$$,"Climate Crisis",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/climatecrisis/v14/wEOpEB3AntNeKCPBVW9XOKlmp3AUgWFN1DvIvcM0gFp6jaUrGb7PsQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-coda",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5ba8eb70-156c-4000-ab6c-2707d2bd1c3b",-2042557328),$APP.$cljs$cst$2675$family$$,"Coda",$APP.$cljs$cst$725$name$$,"Coda",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/coda/v22/SLXHc1jY5nQ8JUIMapaN39I.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/coda/v22/SLXIc1jY5nQ8HeIgTp6mw9t1cX8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-codystar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3ad3f59a-e76c-477c-971e-15919616ed70",959153293),$APP.$cljs$cst$2675$family$$,"Codystar",$APP.$cljs$cst$725$name$$,"Codystar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/codystar/v19/FwZf7-Q1xVk-40qxOuYsyuyrj0e29bfC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/codystar/v19/FwZY7-Q1xVk-40qxOt6A4sijpFu_.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-coiny",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("63041da3-1272-4ba1-a98d-ac34bc973f90",-1064920695),$APP.$cljs$cst$2675$family$$,"Coiny",$APP.$cljs$cst$725$name$$,"Coiny",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/coiny/v17/gyByhwU1K989PXwbElSvO5Tc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-combo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("78b6e84d-6885-42eb-bfef-3446ba39d1c4",-192055359),$APP.$cljs$cst$2675$family$$,
"Combo",$APP.$cljs$cst$725$name$$,"Combo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/combo/v22/BXRlvF3Jh_fIhg0iBu9y8Hf0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-comfortaa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("34725b57-2f56-4266-a886-46288e691848",-169250919),$APP.$cljs$cst$2675$family$$,"Comfortaa",$APP.$cljs$cst$725$name$$,"Comfortaa",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comfortaa/v47/1Pt_g8LJRfWJmhDAuUsSQamb1W0lwk4S4TbMPrQVIT9c2c8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comfortaa/v47/1Pt_g8LJRfWJmhDAuUsSQamb1W0lwk4S4WjMPrQVIT9c2c8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comfortaa/v47/1Pt_g8LJRfWJmhDAuUsSQamb1W0lwk4S4VrMPrQVIT9c2c8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comfortaa/v47/1Pt_g8LJRfWJmhDAuUsSQamb1W0lwk4S4bbLPrQVIT9c2c8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comfortaa/v47/1Pt_g8LJRfWJmhDAuUsSQamb1W0lwk4S4Y_LPrQVIT9c2c8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-comforter",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("20ff8fb7-a038-42cf-85f5-4ea17d3df0c0",
1185929709),$APP.$cljs$cst$2675$family$$,"Comforter",$APP.$cljs$cst$725$name$$,"Comforter",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comforter/v9/H4clBXOCl8nQnlaql3Qa6JG8iqeuag.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-comforter-brush",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6927d01f-4e62-4c03-b29f-fe75c4b10666",289689027),$APP.$cljs$cst$2675$family$$,"Comforter Brush",$APP.$cljs$cst$725$name$$,"Comforter Brush",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comforterbrush/v9/Y4GTYa1xVSggrfzZI5WMjxRaOz0jwLL9Th8YYA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-comic-neue",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4a504541-3339-431d-866d-a80bdb5921f1",1884921633),$APP.$cljs$cst$2675$family$$,"Comic Neue",$APP.$cljs$cst$725$name$$,"Comic Neue",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comicneue/v9/4UaErEJDsxBrF37olUeD_wHLwpteLwtHJlc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",
$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comicneue/v9/4UaarEJDsxBrF37olUeD96_RTplUKylCNlcw_Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comicneue/v9/4UaHrEJDsxBrF37olUeDx63j5pN1MwI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comicneue/v9/4UaFrEJDsxBrF37olUeD96_p4rFwIwJePw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/comicneue/v9/4UaErEJDsxBrF37olUeD_xHMwpteLwtHJlc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comicneue/v9/4UaarEJDsxBrF37olUeD96_RXp5UKylCNlcw_Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-comic-relief",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9e3856d4-ebf0-4a2b-ac24-7bfa8606dfe9",1948911385),$APP.$cljs$cst$2675$family$$,"Comic Relief",$APP.$cljs$cst$725$name$$,"Comic Relief",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/comicrelief/v2/BCauqZkHrvL55SZ8uaEhHMY2XBJhDgs-Kg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comicrelief/v2/BCaxqZkHrvL55SZ8uaEhHMYO4D1FBiAiI1y92w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-coming-soon",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e7cd71c3-b8b4-45fc-87bd-2faf8b517b3e",192837921),$APP.$cljs$cst$2675$family$$,"Coming Soon",$APP.$cljs$cst$725$name$$,"Coming Soon",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/comingsoon/v20/qWcuB6mzpYL7AJ2VfdQR1u-SUjjzsykh.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-comme",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("51321d9b-b93f-433f-a0ca-6bb876482704",1012347842),$APP.$cljs$cst$2675$family$$,"Comme",$APP.$cljs$cst$725$name$$,"Comme",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comme/v4/8QIUdirKhMbn-uG1kHz0MgviDe1z5cBr644fWsRO9w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comme/v4/8QIUdirKhMbn-uG1kHz0MgviDe1zZcFr644fWsRO9w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comme/v4/8QIUdirKhMbn-uG1kHz0MgviDe1zu8Fr644fWsRO9w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/comme/v4/8QIUdirKhMbn-uG1kHz0MgviDe1z5cFr644fWsRO9w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comme/v4/8QIUdirKhMbn-uG1kHz0MgviDe1z18Fr644fWsRO9w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",
$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comme/v4/8QIUdirKhMbn-uG1kHz0MgviDe1zO8Zr644fWsRO9w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comme/v4/8QIUdirKhMbn-uG1kHz0MgviDe1zAsZr644fWsRO9w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comme/v4/8QIUdirKhMbn-uG1kHz0MgviDe1zZcZr644fWsRO9w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/comme/v4/8QIUdirKhMbn-uG1kHz0MgviDe1zTMZr644fWsRO9w.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-commissioner",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("99d03f54-5c93-4ab9-b250-d634ff96a01c",367756851),$APP.$cljs$cst$2675$family$$,"Commissioner",$APP.$cljs$cst$725$name$$,"Commissioner",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/commissioner/v24/tDaH2o2WnlgI0FNDgduEk4jAhwgumbU1SVfU5BD8OuRL8OstC6KOhgvBYWSFJ-Mgdrgiju6fF8meZm0rk4eF-ZugTMNcGPe7Fu0jUdk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/commissioner/v24/tDaH2o2WnlgI0FNDgduEk4jAhwgumbU1SVfU5BD8OuRL8OstC6KOhgvBYWSFJ-Mgdrgiju6fF8meZm0rk4eF-ZugTENdGPe7Fu0jUdk.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/commissioner/v24/tDaH2o2WnlgI0FNDgduEk4jAhwgumbU1SVfU5BD8OuRL8OstC6KOhgvBYWSFJ-Mgdrgiju6fF8meZm0rk4eF-ZugTJ1dGPe7Fu0jUdk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/commissioner/v24/tDaH2o2WnlgI0FNDgduEk4jAhwgumbU1SVfU5BD8OuRL8OstC6KOhgvBYWSFJ-Mgdrgiju6fF8meZm0rk4eF-ZugTMNdGPe7Fu0jUdk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/commissioner/v24/tDaH2o2WnlgI0FNDgduEk4jAhwgumbU1SVfU5BD8OuRL8OstC6KOhgvBYWSFJ-Mgdrgiju6fF8meZm0rk4eF-ZugTPFdGPe7Fu0jUdk.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/commissioner/v24/tDaH2o2WnlgI0FNDgduEk4jAhwgumbU1SVfU5BD8OuRL8OstC6KOhgvBYWSFJ-Mgdrgiju6fF8meZm0rk4eF-ZugTB1aGPe7Fu0jUdk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/commissioner/v24/tDaH2o2WnlgI0FNDgduEk4jAhwgumbU1SVfU5BD8OuRL8OstC6KOhgvBYWSFJ-Mgdrgiju6fF8meZm0rk4eF-ZugTCRaGPe7Fu0jUdk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/commissioner/v24/tDaH2o2WnlgI0FNDgduEk4jAhwgumbU1SVfU5BD8OuRL8OstC6KOhgvBYWSFJ-Mgdrgiju6fF8meZm0rk4eF-ZugTENaGPe7Fu0jUdk.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/commissioner/v24/tDaH2o2WnlgI0FNDgduEk4jAhwgumbU1SVfU5BD8OuRL8OstC6KOhgvBYWSFJ-Mgdrgiju6fF8meZm0rk4eF-ZugTGpaGPe7Fu0jUdk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-concert-one",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("b598a507-e5ea-4190-b4c7-a5aa3116f79f",-1161180368),$APP.$cljs$cst$2675$family$$,"Concert One",$APP.$cljs$cst$725$name$$,"Concert One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/concertone/v24/VEM1Ro9xs5PjtzCu-srDqRTlhv-CuVAQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-condiment",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cd530f7c-517d-4ca9-936f-13227c8b7d40",1390387530),$APP.$cljs$cst$2675$family$$,"Condiment",$APP.$cljs$cst$725$name$$,"Condiment",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/condiment/v26/pONk1hggFNmwvXALyH6Sq4n4o1vyCQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-content",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3150c77a-b2d3-4f3f-b29d-3d718ca7058d",186132770),$APP.$cljs$cst$2675$family$$,"Content",$APP.$cljs$cst$725$name$$,"Content",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/content/v27/zrfl0HLayePhU_AwUaDyIiL0RCg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/content/v27/zrfg0HLayePhU_AwaRzdBirfWCHvkAI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-contrail-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2c4f8ad3-6b80-46c4-8598-97beb5f0ba90",1897426837),$APP.$cljs$cst$2675$family$$,"Contrail One",$APP.$cljs$cst$725$name$$,"Contrail One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/contrailone/v21/eLGbP-j_JA-kG0_Zo51noafdZUvt_c092w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-convergence",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8118593d-e4f3-40ea-981e-4d6568270e09",1461065859),
$APP.$cljs$cst$2675$family$$,"Convergence",$APP.$cljs$cst$725$name$$,"Convergence",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/convergence/v16/rax5HiePvdgXPmmMHcIPYRhasU7Q8Cad.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cookie",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8823b5ac-9bd5-47f8-9952-603f1714d734",-331125095),$APP.$cljs$cst$2675$family$$,"Cookie",$APP.$cljs$cst$725$name$$,"Cookie",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cookie/v23/syky-y18lb0tSbfNlQCT9tPdpw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-copse",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a4629c43-9942-401c-b378-effed37c7486",-1662137595),$APP.$cljs$cst$2675$family$$,"Copse",$APP.$cljs$cst$725$name$$,"Copse",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/copse/v16/11hPGpDKz1rGb0djHkihUb-A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-coral-pixels",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d2a38326-98f3-4eaa-94a9-121eb54f947f",
-1719013179),$APP.$cljs$cst$2675$family$$,"Coral Pixels",$APP.$cljs$cst$725$name$$,"Coral Pixels",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/coralpixels/v1/qWctB66zpZ3zAtrlR8Mb1LyyeBb_ujA4ug.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-corben",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8d49ea17-ea0b-408e-8a77-011875f62143",-2024559750),$APP.$cljs$cst$2675$family$$,"Corben",$APP.$cljs$cst$725$name$$,"Corben",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/corben/v23/LYjDdGzzklQtCMp9oAlEpVs3VQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/corben/v23/LYjAdGzzklQtCMpFHCZgrXArXN7HWQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-corinthia",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("065f5fb2-a88c-4ea5-b60a-28919d1f43fc",-2134072003),$APP.$cljs$cst$2675$family$$,"Corinthia",$APP.$cljs$cst$725$name$$,"Corinthia",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/corinthia/v13/wEO_EBrAnchaJyPMHE0FUfAL3EsHiA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/corinthia/v13/wEO6EBrAnchaJyPMHE097d8v1GAbgbLXQA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-cormorant",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("96b052af-4c43-4ec4-b9ed-26c21b882243",286368945),$APP.$cljs$cst$2675$family$$,"Cormorant",$APP.$cljs$cst$725$name$$,"Cormorant",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/cormorant/v24/H4c2BXOCl9bbnla_nHIA47NMUjsNbCVrFk9TQ7Rg7A2uwYs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorant/v24/H4c2BXOCl9bbnla_nHIA47NMUjsNbCVrFhFTQ7Rg7A2uwYs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorant/v24/H4c2BXOCl9bbnla_nHIA47NMUjsNbCVrFiNTQ7Rg7A2uwYs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorant/v24/H4c2BXOCl9bbnla_nHIA47NMUjsNbCVrFs9UQ7Rg7A2uwYs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorant/v24/H4c2BXOCl9bbnla_nHIA47NMUjsNbCVrFvZUQ7Rg7A2uwYs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorant/v24/H4c0BXOCl9bbnla_nHIq6oGzilJm9otsA9kQ9fdq6C-r0YvxdA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorant/v24/H4c0BXOCl9bbnla_nHIq6oGzilJm9otsA9kQq_dq6C-r0YvxdA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorant/v24/H4c0BXOCl9bbnla_nHIq6oGzilJm9otsA9kQmfdq6C-r0YvxdA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/cormorant/v24/H4c0BXOCl9bbnla_nHIq6oGzilJm9otsA9kQdfBq6C-r0YvxdA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorant/v24/H4c0BXOCl9bbnla_nHIq6oGzilJm9otsA9kQTPBq6C-r0YvxdA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-cormorant-garamond",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c3bc064f-4306-4b98-8c32-54be80a5736c",1031609764),$APP.$cljs$cst$2675$family$$,"Cormorant Garamond",$APP.$cljs$cst$725$name$$,"Cormorant Garamond",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantgaramond/v21/co3umX5slCNuHLi8bLeY9MK7whWMhyjypVO7abI26QOD_qE6GnPEi_s4Mfs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantgaramond/v21/co3umX5slCNuHLi8bLeY9MK7whWMhyjypVO7abI26QOD_v86GnPEi_s4Mfs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantgaramond/v21/co3umX5slCNuHLi8bLeY9MK7whWMhyjypVO7abI26QOD_s06GnPEi_s4Mfs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantgaramond/v21/co3umX5slCNuHLi8bLeY9MK7whWMhyjypVO7abI26QOD_iE9GnPEi_s4Mfs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantgaramond/v21/co3umX5slCNuHLi8bLeY9MK7whWMhyjypVO7abI26QOD_hg9GnPEi_s4Mfs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantgaramond/v21/co3smX5slCNuHLi8bLeY9MK7whWMhyjYrGFEsdtdc62E6zd5rDDOj9k9Ifu5UQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantgaramond/v21/co3smX5slCNuHLi8bLeY9MK7whWMhyjYrGFEsdtdc62E6zd58jDOj9k9Ifu5UQ.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantgaramond/v21/co3smX5slCNuHLi8bLeY9MK7whWMhyjYrGFEsdtdc62E6zd5wDDOj9k9Ifu5UQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",
$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantgaramond/v21/co3smX5slCNuHLi8bLeY9MK7whWMhyjYrGFEsdtdc62E6zd5LDfOj9k9Ifu5UQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantgaramond/v21/co3smX5slCNuHLi8bLeY9MK7whWMhyjYrGFEsdtdc62E6zd5FTfOj9k9Ifu5UQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cormorant-infant",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("47de91a0-30ea-47ef-a1fc-ca1a45b5b979",2055262172),$APP.$cljs$cst$2675$family$$,"Cormorant Infant",$APP.$cljs$cst$725$name$$,"Cormorant Infant",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantinfant/v22/HhyCU44g9vKiM1sORYSiWeAsLN99xfs9KOOc_agJPrhxYOWThDlDkWSy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantinfant/v22/HhyCU44g9vKiM1sORYSiWeAsLN99xfs9KOOc_agJPrgvYOWThDlDkWSy.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantinfant/v22/HhyCU44g9vKiM1sORYSiWeAsLN99xfs9KOOc_agJPrgdYOWThDlDkWSy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantinfant/v22/HhyCU44g9vKiM1sORYSiWeAsLN99xfs9KOOc_agJPrjxZ-WThDlDkWSy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantinfant/v22/HhyCU44g9vKiM1sORYSiWeAsLN99xfs9KOOc_agJPrjIZ-WThDlDkWSy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantinfant/v22/Hhy8U44g9vKiM1sORYSiWeAsLN997_IP1zv1ljKnOa3nI1PQjj1hlHSyazs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/cormorantinfant/v22/Hhy8U44g9vKiM1sORYSiWeAsLN997_IP1zv1ljKnOa3nIw3Qjj1hlHSyazs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantinfant/v22/Hhy8U44g9vKiM1sORYSiWeAsLN997_IP1zv1ljKnOa3nIz_Qjj1hlHSyazs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantinfant/v22/Hhy8U44g9vKiM1sORYSiWeAsLN997_IP1zv1ljKnOa3nI9PXjj1hlHSyazs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/cormorantinfant/v22/Hhy8U44g9vKiM1sORYSiWeAsLN997_IP1zv1ljKnOa3nI-rXjj1hlHSyazs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cormorant-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0afe5b96-b1be-4410-8daf-b373c2cdfbe6",974361253),$APP.$cljs$cst$2675$family$$,"Cormorant SC",$APP.$cljs$cst$725$name$$,"Cormorant SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantsc/v19/0ybmGD4kxqXBmOVLG30OGwsmABIU_R3y8DOWGA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/cormorantsc/v19/0yb5GD4kxqXBmOVLG30OGwserDow9Tbu-Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantsc/v19/0ybmGD4kxqXBmOVLG30OGwsmWBMU_R3y8DOWGA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantsc/v19/0ybmGD4kxqXBmOVLG30OGwsmdBQU_R3y8DOWGA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantsc/v19/0ybmGD4kxqXBmOVLG30OGwsmEBUU_R3y8DOWGA.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cormorant-unicase",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fe9c04b9-cb2d-4b78-b9cb-07f78d512570",510322289),$APP.$cljs$cst$2675$family$$,"Cormorant Unicase",$APP.$cljs$cst$725$name$$,"Cormorant Unicase",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",
$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantunicase/v25/HI_ViZUaILtOqhqgDeXoF_n1_fTGX9N_tucv7Gy0DRzS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantunicase/v25/HI_QiZUaILtOqhqgDeXoF_n1_fTGX-vTnsMnx3C9.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantunicase/v25/HI_ViZUaILtOqhqgDeXoF_n1_fTGX9Mnt-cv7Gy0DRzS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantunicase/v25/HI_ViZUaILtOqhqgDeXoF_n1_fTGX9MLsOcv7Gy0DRzS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantunicase/v25/HI_ViZUaILtOqhqgDeXoF_n1_fTGX9Nvsecv7Gy0DRzS.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-cormorant-upright",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0a59cb24-54d5-43bc-ac97-30390cbcd0ff",-1345213712),$APP.$cljs$cst$2675$family$$,"Cormorant Upright",$APP.$cljs$cst$725$name$$,"Cormorant Upright",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantupright/v19/VuJudM3I2Y35poFONtLdafkUCHw1y1N5phDsU9X6RPzQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantupright/v19/VuJrdM3I2Y35poFONtLdafkUCHw1y2vVjjTkeMnz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantupright/v19/VuJudM3I2Y35poFONtLdafkUCHw1y1MhpxDsU9X6RPzQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantupright/v19/VuJudM3I2Y35poFONtLdafkUCHw1y1MNoBDsU9X6RPzQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cormorantupright/v19/VuJudM3I2Y35poFONtLdafkUCHw1y1NpoRDsU9X6RPzQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cossette-texte",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5086c492-28b9-4f4e-a309-f62e50e807c3",
53037020),$APP.$cljs$cst$2675$family$$,"Cossette Texte",$APP.$cljs$cst$725$name$$,"Cossette Texte",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cossettetexte/v3/S6ukw4pDXzTb-m1kPi_7eV-ciP01xPBQ19bE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cossettetexte/v3/S6unw4pDXzTb-m1kPi_7eV-ciMWJ69RY_MrNDZes.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cossette-titre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("906b879a-bde6-406e-9ae6-c3500f6d4117",
-1609394922),$APP.$cljs$cst$2675$family$$,"Cossette Titre",$APP.$cljs$cst$725$name$$,"Cossette Titre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cossettetitre/v3/11hYGpvKz1nGbxMXUWz9OdPzuiEZrPeE8cA2.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cossettetitre/v3/11hbGpvKz1nGbxMXUWz9OdPzuhmlg9OM2tw_RXR-.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-courgette",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b924d49a-e049-4234-b540-ae44ac305de4",-1725621226),
$APP.$cljs$cst$2675$family$$,"Courgette",$APP.$cljs$cst$725$name$$,"Courgette",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/courgette/v19/wEO_EBrAnc9BLjLQAUkFUfAL3EsHiA.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-courier-prime",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("01269014-1205-470c-a24e-d35efa4bc1a6",-716816120),$APP.$cljs$cst$2675$family$$,"Courier Prime",$APP.$cljs$cst$725$name$$,"Courier Prime",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/courierprime/v11/u-450q2lgwslOqpF_6gQ8kELWwZjW-_-tvg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/courierprime/v11/u-4n0q2lgwslOqpF_6gQ8kELawRpX837pvjxPA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/courierprime/v11/u-4k0q2lgwslOqpF_6gQ8kELY7pMf-fVqvHoJXw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/courierprime/v11/u-4i0q2lgwslOqpF_6gQ8kELawRR4-LfrtPtNXyeAg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cousine",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("479c498f-3855-4a02-8b9b-96dce0dff873",1527479429),$APP.$cljs$cst$2675$family$$,"Cousine",$APP.$cljs$cst$725$name$$,"Cousine",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cousine/v29/d6lIkaiiRdih4SpPzSMlzTbtz9k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/cousine/v29/d6lKkaiiRdih4SpP_SEvyRTo39l8hw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cousine/v29/d6lNkaiiRdih4SpP9Z8K6T7G09BlnmQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",
$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cousine/v29/d6lPkaiiRdih4SpP_SEXdTvM1_JgjmRpOA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-coustard",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("568c068e-667a-4748-8d9b-b84ef83cf271",2048336325),$APP.$cljs$cst$2675$family$$,"Coustard",$APP.$cljs$cst$725$name$$,"Coustard",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/coustard/v17/3XFpErgg3YsZ5fqUU9UPvWXuROTd.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/coustard/v17/3XFuErgg3YsZ5fqUU-2LkEHmb_jU3eRL.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-covered-by-your-grace",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a0543112-cb1e-45e0-9854-f7447417b428",918496110),$APP.$cljs$cst$2675$family$$,"Covered By Your Grace",$APP.$cljs$cst$725$name$$,"Covered By Your Grace",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/coveredbyyourgrace/v17/QGYwz-AZahWOJJI9kykWW9mD6opopoqXSOS0FgItq6bFIg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-crafty-girls",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("a2ec537b-eeea-4f0f-8e9e-a51a7634c0f0",-1471937235),$APP.$cljs$cst$2675$family$$,"Crafty Girls",$APP.$cljs$cst$725$name$$,"Crafty Girls",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/craftygirls/v16/va9B4kXI39VaDdlPJo8N_NvuQR37fF3Wlg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-creepster",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("85d8024f-f0bf-4b4f-8ac4-cf2fbabe7917",-1804068791),$APP.$cljs$cst$2675$family$$,"Creepster",$APP.$cljs$cst$725$name$$,"Creepster",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/creepster/v13/AlZy_zVUqJz4yMrniH4hdXf4XB0Tow.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-crete-round",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("27ebc9c0-c1d7-4fff-bd00-9d2159ca7b1d",-463828534),$APP.$cljs$cst$2675$family$$,"Crete Round",$APP.$cljs$cst$725$name$$,"Crete Round",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/creteround/v16/55xoey1sJNPjPiv1ZZZrxJ1827zAKnxN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,
"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/creteround/v16/55xqey1sJNPjPiv1ZZZrxK1-0bjiL2xNhKc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-crimson-pro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bb20e862-a148-47d5-9796-5d016d830186",1993225526),$APP.$cljs$cst$2675$family$$,"Crimson Pro",$APP.$cljs$cst$725$name$$,"Crimson Pro",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uUsoa5M_tv7IihmnkabC5XiXCAlXGks1WZTm18OJE_VNWoyQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uUsoa5M_tv7IihmnkabC5XiXCAlXGks1WZkG18OJE_VNWoyQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uUsoa5M_tv7IihmnkabC5XiXCAlXGks1WZzm18OJE_VNWoyQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uUsoa5M_tv7IihmnkabC5XiXCAlXGks1WZ_G18OJE_VNWoyQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uUsoa5M_tv7IihmnkabC5XiXCAlXGks1WZEGp8OJE_VNWoyQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uUsoa5M_tv7IihmnkabC5XiXCAlXGks1WZKWp8OJE_VNWoyQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uUsoa5M_tv7IihmnkabC5XiXCAlXGks1WZTmp8OJE_VNWoyQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uUsoa5M_tv7IihmnkabC5XiXCAlXGks1WZZ2p8OJE_VNWoyQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uSsoa5M_tv7IihmnkabAReu49Y_Bo-HVKMBi4Ue5s7dtC4yZNE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uSsoa5M_tv7IihmnkabAReu49Y_Bo-HVKMBi7Ke5s7dtC4yZNE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uSsoa5M_tv7IihmnkabAReu49Y_Bo-HVKMBi6Ue5s7dtC4yZNE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uSsoa5M_tv7IihmnkabAReu49Y_Bo-HVKMBi6me5s7dtC4yZNE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/crimsonpro/v28/q5uSsoa5M_tv7IihmnkabAReu49Y_Bo-HVKMBi5KfJs7dtC4yZNE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uSsoa5M_tv7IihmnkabAReu49Y_Bo-HVKMBi5zfJs7dtC4yZNE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uSsoa5M_tv7IihmnkabAReu49Y_Bo-HVKMBi4UfJs7dtC4yZNE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsonpro/v28/q5uSsoa5M_tv7IihmnkabAReu49Y_Bo-HVKMBi49fJs7dtC4yZNE.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-crimson-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("40210a84-49f4-478f-b668-aca23df96d4d",-816295560),$APP.$cljs$cst$2675$family$$,"Crimson Text",$APP.$cljs$cst$725$name$$,"Crimson Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsontext/v19/wlp2gwHKFkZgtmSR3NB0oRJvaAJSA_JN3Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsontext/v19/wlpogwHKFkZgtmSR3NB0oRJfaghWIfdd3ahG.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsontext/v19/wlppgwHKFkZgtmSR3NB0oRJXsCx2C9lR1LFffg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsontext/v19/wlprgwHKFkZgtmSR3NB0oRJfajCOD9NV9rRPfrKu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsontext/v19/wlppgwHKFkZgtmSR3NB0oRJX1C12C9lR1LFffg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",
$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crimsontext/v19/wlprgwHKFkZgtmSR3NB0oRJfajDqDtNV9rRPfrKu.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-croissant-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b232981f-68d7-4791-9fd9-6b702bd9eb6d",573953646),$APP.$cljs$cst$2675$family$$,"Croissant One",$APP.$cljs$cst$725$name$$,
"Croissant One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/croissantone/v28/3y9n6bU9bTPg4m8NDy3Kq24UM3pqn5cdJ-4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-crushed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3346e796-3a0d-488b-8bba-5ecf055a8f6f",788846886),$APP.$cljs$cst$2675$family$$,"Crushed",$APP.$cljs$cst$725$name$$,"Crushed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/crushed/v32/U9Mc6dym6WXImTlFT1kfuIqyLzA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cuprum",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5e15d3b1-e127-41c3-92c4-cfe970dba2ca",643277555),$APP.$cljs$cst$2675$family$$,"Cuprum",$APP.$cljs$cst$725$name$$,"Cuprum",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cuprum/v29/dg45_pLmvrkcOkBnKsOzXyGWTBcmg-X6ZjzSJjQjgnU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/cuprum/v29/dg45_pLmvrkcOkBnKsOzXyGWTBcmg9f6ZjzSJjQjgnU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cuprum/v29/dg45_pLmvrkcOkBnKsOzXyGWTBcmgzv9ZjzSJjQjgnU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cuprum/v29/dg45_pLmvrkcOkBnKsOzXyGWTBcmgwL9ZjzSJjQjgnU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cuprum/v29/dg47_pLmvrkcOkBNI_FMh0j91rkhli25jn_YIhYmknUPEA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cuprum/v29/dg47_pLmvrkcOkBNI_FMh0j91rkhli25vH_YIhYmknUPEA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cuprum/v29/dg47_pLmvrkcOkBNI_FMh0j91rkhli25UHjYIhYmknUPEA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cuprum/v29/dg47_pLmvrkcOkBNI_FMh0j91rkhli25aXjYIhYmknUPEA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-cute-font",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9250c674-3a02-47bb-8d5c-8e82fb6869b7",1836755353),$APP.$cljs$cst$2675$family$$,"Cute Font",$APP.$cljs$cst$725$name$$,"Cute Font",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cutefont/v28/Noaw6Uny2oWPbSHMrY6vmJNVNC9hkw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cutive",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cce600cc-62c5-4aa5-981f-1782131be1c6",1561702975),$APP.$cljs$cst$2675$family$$,"Cutive",$APP.$cljs$cst$725$name$$,"Cutive",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cutive/v24/NaPZcZ_fHOhV3Ip7T_hDoyqlZQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-cutive-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("56fe0837-f135-4d91-b2d2-8184183d5ee6",-1901015868),$APP.$cljs$cst$2675$family$$,
"Cutive Mono",$APP.$cljs$cst$725$name$$,"Cutive Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/cutivemono/v23/m8JWjfRfY7WVjVi2E-K9H5RFRG-K3Mud.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-dm-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e4b9fd72-6bfe-4cd9-b490-060055cc099e",-431958945),$APP.$cljs$cst$2675$family$$,"DM Mono",$APP.$cljs$cst$725$name$$,"DM Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmmono/v16/aFTR7PB1QTsUX8KYvrGyIYSnbKX9Rlk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmmono/v16/aFTT7PB1QTsUX8KYth-orYataIf4VllXuA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmmono/v16/aFTU7PB1QTsUX8KYhh2aBYyMcKw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmmono/v16/aFTW7PB1QTsUX8KYth-QAa6JYKzkXw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmmono/v16/aFTR7PB1QTsUX8KYvumzIYSnbKX9Rlk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/dmmono/v16/aFTT7PB1QTsUX8KYth-o9YetaIf4VllXuA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dm-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6a4b8136-2709-4547-86e7-529277963937",1619125826),$APP.$cljs$cst$2675$family$$,"DM Sans",$APP.$cljs$cst$725$name$$,"DM Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2tp2ywxg089UriI5-g4vlH9VoD8CmcqZG40F9JadbnoEwAop1hTmf3ZGMZpg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2tp2ywxg089UriI5-g4vlH9VoD8CmcqZG40F9JadbnoEwAIpxhTmf3ZGMZpg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2tp2ywxg089UriI5-g4vlH9VoD8CmcqZG40F9JadbnoEwA_JxhTmf3ZGMZpg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2tp2ywxg089UriI5-g4vlH9VoD8CmcqZG40F9JadbnoEwAopxhTmf3ZGMZpg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2tp2ywxg089UriI5-g4vlH9VoD8CmcqZG40F9JadbnoEwAkJxhTmf3ZGMZpg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2tp2ywxg089UriI5-g4vlH9VoD8CmcqZG40F9JadbnoEwAfJthTmf3ZGMZpg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2tp2ywxg089UriI5-g4vlH9VoD8CmcqZG40F9JadbnoEwARZthTmf3ZGMZpg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2tp2ywxg089UriI5-g4vlH9VoD8CmcqZG40F9JadbnoEwAIpthTmf3ZGMZpg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2tp2ywxg089UriI5-g4vlH9VoD8CmcqZG40F9JadbnoEwAC5thTmf3ZGMZpg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2rp2ywxg089UriCZaSExd86J3t9jz86Mvy4qCRAL19DksVat-JDG3zRmYJpso5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2rp2ywxg089UriCZaSExd86J3t9jz86Mvy4qCRAL19DksVat8JDW3zRmYJpso5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/dmsans/v17/rP2rp2ywxg089UriCZaSExd86J3t9jz86Mvy4qCRAL19DksVat_XDW3zRmYJpso5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2rp2ywxg089UriCZaSExd86J3t9jz86Mvy4qCRAL19DksVat-JDW3zRmYJpso5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2rp2ywxg089UriCZaSExd86J3t9jz86Mvy4qCRAL19DksVat-7DW3zRmYJpso5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2rp2ywxg089UriCZaSExd86J3t9jz86Mvy4qCRAL19DksVat9XCm3zRmYJpso5.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2rp2ywxg089UriCZaSExd86J3t9jz86Mvy4qCRAL19DksVat9uCm3zRmYJpso5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",
$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2rp2ywxg089UriCZaSExd86J3t9jz86Mvy4qCRAL19DksVat8JCm3zRmYJpso5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmsans/v17/rP2rp2ywxg089UriCZaSExd86J3t9jz86Mvy4qCRAL19DksVat8gCm3zRmYJpso5.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dm-serif-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fe56b7b3-da3c-4082-9fa5-2cdb24e0cb50",1805481760),$APP.$cljs$cst$2675$family$$,"DM Serif Display",$APP.$cljs$cst$725$name$$,"DM Serif Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmserifdisplay/v17/-nFnOHM81r4j6k0gjAW3mujVU2B2K_d709jy92k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmserifdisplay/v17/-nFhOHM81r4j6k0gjAW3mujVU2B2G_Vx1_r352np3Q.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dm-serif-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("11135223-edd9-4cbf-97ef-b0eb5dbe8d84",955088713),$APP.$cljs$cst$2675$family$$,"DM Serif Text",$APP.$cljs$cst$725$name$$,"DM Serif Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmseriftext/v13/rnCu-xZa_krGokauCeNq1wWyafOPXHIJErY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dmseriftext/v13/rnCw-xZa_krGokauCeNq1wWyWfGFWFAMArZKqQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dai-banna-sil",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dc139d95-8cc5-4843-a857-5c579525c0f3",2139696170),$APP.$cljs$cst$2675$family$$,"Dai Banna SIL",$APP.$cljs$cst$725$name$$,"Dai Banna SIL",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",
$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/daibannasil/v2/lW-lwj0AJWmpwGyJ2uEoA4I7tYKoDsrKOgMX95A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/daibannasil/v2/lW-jwj0AJWmpwGyJ2uEoA4I7vSyygsjAPiES55D3Vg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/daibannasil/v2/lW-4wj0AJWmpwGyJ2uEoA4I7jS6AKsLhJgo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/daibannasil/v2/lW-mwj0AJWmpwGyJ2uEoA4I7vSyKLuDkNgoO7g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/daibannasil/v2/lW-lwj0AJWmpwGyJ2uEoA4I7tdqpDsrKOgMX95A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",
$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/daibannasil/v2/lW-jwj0AJWmpwGyJ2uEoA4I7vSyy2snAPiES55D3Vg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/daibannasil/v2/lW-lwj0AJWmpwGyJ2uEoA4I7tfauDsrKOgMX95A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/daibannasil/v2/lW-jwj0AJWmpwGyJ2uEoA4I7vSyy9s7APiES55D3Vg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/daibannasil/v2/lW-lwj0AJWmpwGyJ2uEoA4I7tZKvDsrKOgMX95A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/daibannasil/v2/lW-jwj0AJWmpwGyJ2uEoA4I7vSyyks_APiES55D3Vg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-damion",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8375ad07-78f5-4f7b-a3ae-9a33b607d6de",-137711943),$APP.$cljs$cst$2675$family$$,"Damion",$APP.$cljs$cst$725$name$$,"Damion",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/damion/v15/hv-XlzJ3KEUe_YZUbWY3MTFgVg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dancing-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bc91b866-7b4b-4d7a-9e74-25222f2f862b",-1289072282),$APP.$cljs$cst$2675$family$$,"Dancing Script",$APP.$cljs$cst$725$name$$,"Dancing Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dancingscript/v29/If2cXTr6YS-zF4S-kcSWSVi_sxjsohD9F50Ruu7BMSoHTeB9ptDqpw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dancingscript/v29/If2cXTr6YS-zF4S-kcSWSVi_sxjsohD9F50Ruu7BAyoHTeB9ptDqpw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dancingscript/v29/If2cXTr6YS-zF4S-kcSWSVi_sxjsohD9F50Ruu7B7y0HTeB9ptDqpw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dancingscript/v29/If2cXTr6YS-zF4S-kcSWSVi_sxjsohD9F50Ruu7B1i0HTeB9ptDqpw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-danfo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8c0da0d9-7251-4ad7-ba5b-6c31f5d1d449",1395972376),$APP.$cljs$cst$2675$family$$,"Danfo",
$APP.$cljs$cst$725$name$$,"Danfo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/danfo/v5/snf3s0u_98t16THfK1Csj3N41ZqbYDe5S71ToPrNKQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-dangrek",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6e1d0b18-5125-42cd-870e-fb25f51fa7cb",-2116576034),$APP.$cljs$cst$2675$family$$,"Dangrek",$APP.$cljs$cst$725$name$$,"Dangrek",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dangrek/v33/LYjCdG30nEgoH8E2gCNqqVIuTN4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-darker-grotesque",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ab4971b6-9921-4772-8908-5b94116c28b0",1187549491),$APP.$cljs$cst$2675$family$$,"Darker Grotesque",$APP.$cljs$cst$725$name$$,"Darker Grotesque",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/darkergrotesque/v10/U9MK6cuh-mLQlC4BKCtayOfARkSVgb381b-W8-QDqXxpqn7y-XFyZFUB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/darkergrotesque/v10/U9MK6cuh-mLQlC4BKCtayOfARkSVgb381b-W8-QDqXw3qn7y-XFyZFUB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/darkergrotesque/v10/U9MK6cuh-mLQlC4BKCtayOfARkSVgb381b-W8-QDqXwFqn7y-XFyZFUB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/darkergrotesque/v10/U9MK6cuh-mLQlC4BKCtayOfARkSVgb381b-W8-QDqXzprX7y-XFyZFUB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/darkergrotesque/v10/U9MK6cuh-mLQlC4BKCtayOfARkSVgb381b-W8-QDqXzQrX7y-XFyZFUB.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/darkergrotesque/v10/U9MK6cuh-mLQlC4BKCtayOfARkSVgb381b-W8-QDqXy3rX7y-XFyZFUB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/darkergrotesque/v10/U9MK6cuh-mLQlC4BKCtayOfARkSVgb381b-W8-QDqXyerX7y-XFyZFUB.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-darumadrop-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7e1ce2fb-9679-47cd-a3fb-d765e08a7f58",1822554971),$APP.$cljs$cst$2675$family$$,"Darumadrop One",$APP.$cljs$cst$725$name$$,"Darumadrop One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/darumadropone/v14/cY9cfjeIW11dpCKgRLi675a87IhHBJOxZQPp.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-david-libre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bbf22e19-099b-4227-8a1a-bbf69552a4a1",
-1202506486),$APP.$cljs$cst$2675$family$$,"David Libre",$APP.$cljs$cst$725$name$$,"David Libre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/davidlibre/v17/snfus0W_99N64iuYSvp4W_l86p6TYS-Y.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/davidlibre/v17/snfzs0W_99N64iuYSvp4W8GIw7qbSjORSo9W.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/davidlibre/v17/snfzs0W_99N64iuYSvp4W8HAxbqbSjORSo9W.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dawning-of-a-new-day",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2b9f51c6-e5c8-4bb4-8f17-f01a4b67dfc5",855684547),$APP.$cljs$cst$2675$family$$,"Dawning of a New Day",$APP.$cljs$cst$725$name$$,"Dawning of a New Day",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dawningofanewday/v22/t5t_IQMbOp2SEwuncwLRjMfIg1yYit_nAz8bhWJGNoBE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-days-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("586210a4-e162-4941-95c0-05246681ec86",
497358093),$APP.$cljs$cst$2675$family$$,"Days One",$APP.$cljs$cst$725$name$$,"Days One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/daysone/v19/mem9YaCnxnKRiYZOCLYVeLkWVNBt.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dekko",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("41f6b131-fecf-4f13-bbe0-3dbf333bcf8b",413923704),$APP.$cljs$cst$2675$family$$,"Dekko",$APP.$cljs$cst$725$name$$,"Dekko",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dekko/v23/46khlb_wWjfSrttFR0vsfl1B.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dela-gothic-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5ec6f700-b3b7-4344-b0e2-d43184c1e29b",-413215937),$APP.$cljs$cst$2675$family$$,"Dela Gothic One",$APP.$cljs$cst$725$name$$,"Dela Gothic One",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/delagothicone/v19/hESp6XxvMDRA-2eD0lXpDa6QkBAGRUsJQAlbUA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-delicious-handrawn",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0dabf8f2-9a05-4b2d-ac66-30d88dce47f8",880962164),$APP.$cljs$cst$2675$family$$,"Delicious Handrawn",$APP.$cljs$cst$725$name$$,"Delicious Handrawn",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/delicioushandrawn/v10/wlpsgx_NAUNkpmKQifcxkQchDFo3fJ113JpDd6u3AQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-delius",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cd1fa029-0a6f-495e-919f-ddd5e2531f25",1849714531),$APP.$cljs$cst$2675$family$$,"Delius",$APP.$cljs$cst$725$name$$,"Delius",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/delius/v21/PN_xRfK0pW_9e1rtYcI-jT3L_w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-delius-swash-caps",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ddfcbf47-af7e-4644-8894-9d74ea135924",1160827317),$APP.$cljs$cst$2675$family$$,
"Delius Swash Caps",$APP.$cljs$cst$725$name$$,"Delius Swash Caps",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/deliusswashcaps/v25/oY1E8fPLr7v4JWCExZpWebxVKORpXXedKmeBvEYs.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-delius-unicase",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fdfbb73d-b9a6-44d4-8bb7-ca8d64278741",695072744),$APP.$cljs$cst$2675$family$$,"Delius Unicase",$APP.$cljs$cst$725$name$$,"Delius Unicase",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/deliusunicase/v30/845BNMEwEIOVT8BmgfSzIr_6mmLHd-73LXWs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/deliusunicase/v30/845CNMEwEIOVT8BmgfSzIr_6mlp7WMr_BmmlS5aw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-della-respira",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ce42ed49-5e26-4552-97cf-55479a1881d0",-511243697),$APP.$cljs$cst$2675$family$$,"Della Respira",$APP.$cljs$cst$725$name$$,"Della Respira",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dellarespira/v24/RLp5K5v44KaueWI6iEJQBiGPRfkSu6EuTHo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-denk-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("da86a7ca-3923-40f5-8913-ecacdc34af25",1533090078),$APP.$cljs$cst$2675$family$$,"Denk One",$APP.$cljs$cst$725$name$$,"Denk One",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/denkone/v21/dg4m_pzhrqcFb2IzROtHpbglShon.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-devonshire",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("9afd845d-35d8-446e-b4a5-8fac11ead152",1452281444),$APP.$cljs$cst$2675$family$$,"Devonshire",$APP.$cljs$cst$725$name$$,"Devonshire",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/devonshire/v29/46kqlbDwWirWr4gtBD2BX0Vq01lYAZM.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dhurjati",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6b3e4e0e-79a1-4698-8e6c-d80609f51b54",-2029110201),$APP.$cljs$cst$2675$family$$,"Dhurjati",$APP.$cljs$cst$725$name$$,"Dhurjati",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dhurjati/v27/_6_8ED3gSeatXfFiFX3ySKQtuTA2.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-didact-gothic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("36126604-2aa3-4c4a-beec-7902643cf679",936321357),$APP.$cljs$cst$2675$family$$,"Didact Gothic",$APP.$cljs$cst$725$name$$,"Didact Gothic",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/didactgothic/v21/ahcfv8qz1zt6hCC5G4F_P4ASpUySp0LlcyQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-diphylleia",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1e1416ce-aaf1-42b0-a579-072543e3dc2b",1511071315),$APP.$cljs$cst$2675$family$$,"Diphylleia",$APP.$cljs$cst$725$name$$,"Diphylleia",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/diphylleia/v2/DtVmJxCtRKMixK4_HXsIulwm6gDXvwE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-diplomata",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("54ad1357-62cf-46a9-b007-d9f9a33c35c4",-1378677843),$APP.$cljs$cst$2675$family$$,"Diplomata",$APP.$cljs$cst$725$name$$,"Diplomata",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/diplomata/v33/Cn-0JtiMXwhNwp-wKxyfYGxYrdM9Sg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-diplomata-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("13086779-9a12-4048-a068-af1156b9e7ec",-725628738),$APP.$cljs$cst$2675$family$$,"Diplomata SC",$APP.$cljs$cst$725$name$$,
"Diplomata SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/diplomatasc/v30/buExpoi3ecvs3kidKgBJo2kf-P5Oaiw4cw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-do-hyeon",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cabfbdef-6325-4d51-bb8e-9e913ed2e410",1176326742),$APP.$cljs$cst$2675$family$$,"Do Hyeon",$APP.$cljs$cst$725$name$$,"Do Hyeon",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dohyeon/v21/TwMN-I8CRRU2zM86HFE3ZwaH__-C.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dokdo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2cb1388f-e267-4126-a02e-257f9535544c",737459230),$APP.$cljs$cst$2675$family$$,"Dokdo",$APP.$cljs$cst$725$name$$,"Dokdo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dokdo/v23/esDf315XNuCBLxLo4NaMlKcH.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-domine",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d84a5d2c-5420-4e74-9728-496ffdcd93f7",-1372708547),$APP.$cljs$cst$2675$family$$,
"Domine",$APP.$cljs$cst$725$name$$,"Domine",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/domine/v25/L0xhDFMnlVwD4h3Lt9JWnbX3jG-2X3LAI10VErGuW8Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/domine/v25/L0xhDFMnlVwD4h3Lt9JWnbX3jG-2X0DAI10VErGuW8Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/domine/v25/L0xhDFMnlVwD4h3Lt9JWnbX3jG-2X6zHI10VErGuW8Q.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/domine/v25/L0xhDFMnlVwD4h3Lt9JWnbX3jG-2X5XHI10VErGuW8Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-donegal-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cd3522b2-a81b-4f7e-b421-548a0f9d1d75",-51380769),
$APP.$cljs$cst$2675$family$$,"Donegal One",$APP.$cljs$cst$725$name$$,"Donegal One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/donegalone/v22/m8JWjfRYea-ZnFz6fsK9FZRFRG-K3Mud.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dongle",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b6a48fa1-9855-4d0f-8fa0-b56ca51152b3",572146528),$APP.$cljs$cst$2675$family$$,"Dongle",$APP.$cljs$cst$725$name$$,"Dongle",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dongle/v16/sJoG3Ltdjt6VPkqeEcxrYjWNzXvVPA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dongle/v16/sJoF3Ltdjt6VPkqmveRPah6RxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dongle/v16/sJoG3Ltdjt6VPkqeActrYjWNzXvVPA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-doppio-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f06172b2-d342-41d4-bd49-00f2db15d19e",1403909749),$APP.$cljs$cst$2675$family$$,"Doppio One",$APP.$cljs$cst$725$name$$,
"Doppio One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/doppioone/v14/Gg8wN5gSaBfyBw2MqCh-lgshKGpe5Fg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-dorsa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d7868285-5d54-4e44-b658-1ccb9c181a83",1116831358),$APP.$cljs$cst$2675$family$$,"Dorsa",$APP.$cljs$cst$725$name$$,"Dorsa",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/dorsa/v29/yYLn0hjd0OGwqo493XCFxAnQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dosis",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("319a9e06-d0ad-4cc6-95d9-c76042bad009",681419676),$APP.$cljs$cst$2675$family$$,"Dosis",$APP.$cljs$cst$725$name$$,"Dosis",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dosis/v34/HhyJU5sn9vOmLxNkIwRSjTVNWLEJt7MV3BkFTq4EPw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dosis/v34/HhyJU5sn9vOmLxNkIwRSjTVNWLEJabMV3BkFTq4EPw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dosis/v34/HhyJU5sn9vOmLxNkIwRSjTVNWLEJN7MV3BkFTq4EPw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/dosis/v34/HhyJU5sn9vOmLxNkIwRSjTVNWLEJBbMV3BkFTq4EPw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dosis/v34/HhyJU5sn9vOmLxNkIwRSjTVNWLEJ6bQV3BkFTq4EPw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dosis/v34/HhyJU5sn9vOmLxNkIwRSjTVNWLEJ0LQV3BkFTq4EPw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dosis/v34/HhyJU5sn9vOmLxNkIwRSjTVNWLEJt7QV3BkFTq4EPw.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dotgothic16",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d76d2eb0-ec66-45f8-b348-71d42c11a245",-676241379),$APP.$cljs$cst$2675$family$$,"DotGothic16",$APP.$cljs$cst$725$name$$,"DotGothic16",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dotgothic16/v21/v6-QGYjBJFKgyw5nSoDAGE7L435YPFrT.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-doto",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2a28f86a-15c5-4e5b-99c3-796870e5a902",1164501283),$APP.$cljs$cst$2675$family$$,"Doto",$APP.$cljs$cst$725$name$$,"Doto",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/doto/v3/t5tJIRMbNJ6TQG7Il_EKPqP9zTnvqqGNcuvLMt1JIphFOOOez0WSvrlpgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/doto/v3/t5tJIRMbNJ6TQG7Il_EKPqP9zTnvqqGNcuvLMt1JIphFuOKez0WSvrlpgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/doto/v3/t5tJIRMbNJ6TQG7Il_EKPqP9zTnvqqGNcuvLMt1JIphFZuKez0WSvrlpgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/doto/v3/t5tJIRMbNJ6TQG7Il_EKPqP9zTnvqqGNcuvLMt1JIphFOOKez0WSvrlpgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/doto/v3/t5tJIRMbNJ6TQG7Il_EKPqP9zTnvqqGNcuvLMt1JIphFCuKez0WSvrlpgw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/doto/v3/t5tJIRMbNJ6TQG7Il_EKPqP9zTnvqqGNcuvLMt1JIphF5uWez0WSvrlpgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/doto/v3/t5tJIRMbNJ6TQG7Il_EKPqP9zTnvqqGNcuvLMt1JIphF3-Wez0WSvrlpgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/doto/v3/t5tJIRMbNJ6TQG7Il_EKPqP9zTnvqqGNcuvLMt1JIphFuOWez0WSvrlpgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/doto/v3/t5tJIRMbNJ6TQG7Il_EKPqP9zTnvqqGNcuvLMt1JIphFkeWez0WSvrlpgw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dr-sugiyama",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5f7ef19b-e472-4d6e-b246-0c39e0e617ef",-986810881),$APP.$cljs$cst$2675$family$$,"Dr Sugiyama",$APP.$cljs$cst$725$name$$,
"Dr Sugiyama",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/drsugiyama/v30/HTxoL2k4N3O9n5I1boGI7abRM4-t-g7y.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-duru-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7589ddfe-b32b-4c4b-932f-aa1fcf695139",700652921),$APP.$cljs$cst$2675$family$$,"Duru Sans",$APP.$cljs$cst$725$name$$,"Duru Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/durusans/v21/xn7iYH8xwmSyTvEV_HOxT_fYdN-WZw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dynapuff",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2fd26d56-216b-4111-9ac3-b57d2c54de34",-1791124730),$APP.$cljs$cst$2675$family$$,"DynaPuff",$APP.$cljs$cst$725$name$$,"DynaPuff",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dynapuff/v9/z7N5dRvsZDIVHbYPMhZJ3HQ83UaSu4uhr7-ZFeoYkgAr1x8RSxYu6YjrSRs4wn8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dynapuff/v9/z7N5dRvsZDIVHbYPMhZJ3HQ83UaSu4uhr7-ZFeoYkgAr1x8RSyQu6YjrSRs4wn8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dynapuff/v9/z7N5dRvsZDIVHbYPMhZJ3HQ83UaSu4uhr7-ZFeoYkgAr1x8RS8gp6YjrSRs4wn8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dynapuff/v9/z7N5dRvsZDIVHbYPMhZJ3HQ83UaSu4uhr7-ZFeoYkgAr1x8RS_Ep6YjrSRs4wn8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-dynalight",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f1c65498-31a6-4bbe-9797-928178809a44",-945970967),$APP.$cljs$cst$2675$family$$,
"Dynalight",$APP.$cljs$cst$725$name$$,"Dynalight",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/dynalight/v24/1Ptsg8LOU_aOmQvTsF4ISotrDfGGxA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-eb-garamond",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a1d1726b-35b4-4f78-b7aa-af62f8ea9918",618320821),$APP.$cljs$cst$2675$family$$,"EB Garamond",$APP.$cljs$cst$725$name$$,"EB Garamond",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ebgaramond/v32/SlGDmQSNjdsmc35JDF1K5E55YMjF_7DPuGi-6_RUA4V-e6yHgQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ebgaramond/v32/SlGDmQSNjdsmc35JDF1K5E55YMjF_7DPuGi-2fRUA4V-e6yHgQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ebgaramond/v32/SlGDmQSNjdsmc35JDF1K5E55YMjF_7DPuGi-NfNUA4V-e6yHgQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ebgaramond/v32/SlGDmQSNjdsmc35JDF1K5E55YMjF_7DPuGi-DPNUA4V-e6yHgQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ebgaramond/v32/SlGDmQSNjdsmc35JDF1K5E55YMjF_7DPuGi-a_NUA4V-e6yHgQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ebgaramond/v32/SlGFmQSNjdsmc35JDF1K5GRwUjcdlttVFm-rI7e8QI96WamXgXFI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ebgaramond/v32/SlGFmQSNjdsmc35JDF1K5GRwUjcdlttVFm-rI7eOQI96WamXgXFI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ebgaramond/v32/SlGFmQSNjdsmc35JDF1K5GRwUjcdlttVFm-rI7diR496WamXgXFI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ebgaramond/v32/SlGFmQSNjdsmc35JDF1K5GRwUjcdlttVFm-rI7dbR496WamXgXFI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ebgaramond/v32/SlGFmQSNjdsmc35JDF1K5GRwUjcdlttVFm-rI7c8R496WamXgXFI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"gfont-eagle-lake",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("80369a24-5e7e-4f3c-9d88-393740805d3f",-1522095453),$APP.$cljs$cst$2675$family$$,"Eagle Lake",$APP.$cljs$cst$725$name$$,"Eagle Lake",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eaglelake/v26/ptRMTiqbbuNJDOiKj9wG5O7yKQNute8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-east-sea-dokdo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("14fe11a6-bb8a-4f0c-94bf-23146371a1db",-1381669303),$APP.$cljs$cst$2675$family$$,"East Sea Dokdo",$APP.$cljs$cst$725$name$$,"East Sea Dokdo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eastseadokdo/v26/xfuo0Wn2V2_KanASqXSZp22m05_aGavYS18y.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-eater",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f9448df4-279b-43a4-a038-41fa021a678e",-1821304984),
$APP.$cljs$cst$2675$family$$,"Eater",$APP.$cljs$cst$725$name$$,"Eater",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eater/v27/mtG04_FCK7bOvpu2u3FwsXsR.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-economica",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9abdb4a5-0468-41a4-a4af-7752786ae0e9",-512311798),$APP.$cljs$cst$2675$family$$,"Economica",$APP.$cljs$cst$725$name$$,"Economica",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/economica/v17/Qw3fZQZaHCLgIWa29ZBrMcgAAl1lfQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/economica/v17/Qw3ZZQZaHCLgIWa29ZBbM8IEIFh1fWUl.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",
$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/economica/v17/Qw3aZQZaHCLgIWa29ZBTjeckCnZ5dHw8iw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/economica/v17/Qw3EZQZaHCLgIWa29ZBbM_q4D3x9Vnksi4M7.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-eczar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d4658c79-a5e8-496a-b8e9-a68bdee8573a",-1154315382),$APP.$cljs$cst$2675$family$$,"Eczar",$APP.$cljs$cst$725$name$$,"Eczar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eczar/v27/BXR2vF3Pi-DLmxcpJB-qbNTyTMDXHd6WqTIVKWJKWg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eczar/v27/BXR2vF3Pi-DLmxcpJB-qbNTyTMDXL96WqTIVKWJKWg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eczar/v27/BXR2vF3Pi-DLmxcpJB-qbNTyTMDXw9mWqTIVKWJKWg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eczar/v27/BXR2vF3Pi-DLmxcpJB-qbNTyTMDX-tmWqTIVKWJKWg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eczar/v27/BXR2vF3Pi-DLmxcpJB-qbNTyTMDXndmWqTIVKWJKWg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-edu-au-vic-wa-nt-arrows",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("af8e17dc-d870-4401-9ed5-dbe3046d17aa",
-1509351235),$APP.$cljs$cst$2675$family$$,"Edu AU VIC WA NT Arrows",$APP.$cljs$cst$725$name$$,"Edu AU VIC WA NT Arrows",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantarrows/v4/z7N7dQTteSlUDJZJAmUB9MuVbLPBjsrTFZLUbdjnSmlATbEWXt5tAcvhTTk90n91Vw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantarrows/v4/z7N7dQTteSlUDJZJAmUB9MuVbLPBjsrTFZLUbdjnSmlATbEWXt5tM8vhTTk90n91Vw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantarrows/v4/z7N7dQTteSlUDJZJAmUB9MuVbLPBjsrTFZLUbdjnSmlATbEWXt5t38zhTTk90n91Vw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantarrows/v4/z7N7dQTteSlUDJZJAmUB9MuVbLPBjsrTFZLUbdjnSmlATbEWXt5t5szhTTk90n91Vw.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-edu-au-vic-wa-nt-dots",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c4ec79a8-47b8-415d-ac86-aaeecb584ae8",-1760704579),$APP.$cljs$cst$2675$family$$,"Edu AU VIC WA NT Dots",$APP.$cljs$cst$725$name$$,"Edu AU VIC WA NT Dots",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantdots/v4/S6uQw5FFVDKI3kwwDUbsPHCpzZNhzrA3or3_B4dZ6MmTX8QNLvtYEtmT2SB3_5U.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantdots/v4/S6uQw5FFVDKI3kwwDUbsPHCpzZNhzrA3or3_B4dZ6MmTX8QNLslYEtmT2SB3_5U.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantdots/v4/S6uQw5FFVDKI3kwwDUbsPHCpzZNhzrA3or3_B4dZ6MmTX8QNLiVfEtmT2SB3_5U.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantdots/v4/S6uQw5FFVDKI3kwwDUbsPHCpzZNhzrA3or3_B4dZ6MmTX8QNLhxfEtmT2SB3_5U.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-edu-au-vic-wa-nt-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d5be9e1e-137b-4a55-af94-095bc6e22794",164904012),$APP.$cljs$cst$2675$family$$,"Edu AU VIC WA NT Guides",$APP.$cljs$cst$725$name$$,"Edu AU VIC WA NT Guides",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantguides/v3/TuG-UUJ4V48KZ9Nr3ZV46JQkJxtkFIKnvy00LCZuAcLMeb8FnyPdK1ZazoF08FsYlA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantguides/v3/TuG-UUJ4V48KZ9Nr3ZV46JQkJxtkFIKnvy00LCZuAcLMeb8FnyPdGVZazoF08FsYlA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantguides/v3/TuG-UUJ4V48KZ9Nr3ZV46JQkJxtkFIKnvy00LCZuAcLMeb8FnyPd9VFazoF08FsYlA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantguides/v3/TuG-UUJ4V48KZ9Nr3ZV46JQkJxtkFIKnvy00LCZuAcLMeb8FnyPdzFFazoF08FsYlA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-edu-au-vic-wa-nt-hand",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f88ecbb9-6de6-46a2-ab9e-d9073ee7a15b",
-1526570048),$APP.$cljs$cst$2675$family$$,"Edu AU VIC WA NT Hand",$APP.$cljs$cst$725$name$$,"Edu AU VIC WA NT Hand",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwanthand/v3/C8cO4dY1tX2x0uuiUHFS4y7ERV-jfqJ6x063HfvcsxiYKifhtCJ1lKtFbYfTEUU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwanthand/v3/C8cO4dY1tX2x0uuiUHFS4y7ERV-jfqJ6x063HfvcsxiYKifhtBB1lKtFbYfTEUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwanthand/v3/C8cO4dY1tX2x0uuiUHFS4y7ERV-jfqJ6x063HfvcsxiYKifhtPxylKtFbYfTEUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwanthand/v3/C8cO4dY1tX2x0uuiUHFS4y7ERV-jfqJ6x063HfvcsxiYKifhtMVylKtFbYfTEUU.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-edu-au-vic-wa-nt-pre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d8b9146c-b428-4d31-af88-fefa08953a8a",1707903675),$APP.$cljs$cst$2675$family$$,"Edu AU VIC WA NT Pre",$APP.$cljs$cst$725$name$$,"Edu AU VIC WA NT Pre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantpre/v3/f0Xc0fWk-t0rbG8Ycr-t55aG0elTWbFeXaYI98CnuNLeosIyJmkwr6MhKkg6nw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantpre/v3/f0Xc0fWk-t0rbG8Ycr-t55aG0elTWbFeXaYI98CnuNLeosIyFGkwr6MhKkg6nw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantpre/v3/f0Xc0fWk-t0rbG8Ycr-t55aG0elTWbFeXaYI98CnuNLeosIy-G4wr6MhKkg6nw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduauvicwantpre/v3/f0Xc0fWk-t0rbG8Ycr-t55aG0elTWbFeXaYI98CnuNLeosIywW4wr6MhKkg6nw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-edu-nsw-act-cursive",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2e15c6ff-f798-4523-9356-d987d63816ab",-1817117165),$APP.$cljs$cst$2675$family$$,"Edu NSW ACT Cursive",$APP.$cljs$cst$725$name$$,"Edu NSW ACT Cursive",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edunswactcursive/v3/xn7LYGUw02PnIPEjskHSG_2fCaz9DzhQbcTNLWxkwsHVCrd5giiVjXBs6BMb.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edunswactcursive/v3/xn7LYGUw02PnIPEjskHSG_2fCaz9DzhQbcTNLWxkwsHVCrdLgiiVjXBs6BMb.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edunswactcursive/v3/xn7LYGUw02PnIPEjskHSG_2fCaz9DzhQbcTNLWxkwsHVCrenhSiVjXBs6BMb.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edunswactcursive/v3/xn7LYGUw02PnIPEjskHSG_2fCaz9DzhQbcTNLWxkwsHVCreehSiVjXBs6BMb.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-edu-nsw-act-foundation",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("67d2a730-3985-40ea-b7ca-3227f779f9d5",
-312535075),$APP.$cljs$cst$2675$family$$,"Edu NSW ACT Foundation",$APP.$cljs$cst$725$name$$,"Edu NSW ACT Foundation",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edunswactfoundation/v5/raxRHjqJtsNBFUi8WO0vUBgc9D-2lV_oQdCAYlt_QTQ0vUxJki9tovGLeC-sfguJ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edunswactfoundation/v5/raxRHjqJtsNBFUi8WO0vUBgc9D-2lV_oQdCAYlt_QTQ0vUxJki9fovGLeC-sfguJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edunswactfoundation/v5/raxRHjqJtsNBFUi8WO0vUBgc9D-2lV_oQdCAYlt_QTQ0vUxJki-zpfGLeC-sfguJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edunswactfoundation/v5/raxRHjqJtsNBFUi8WO0vUBgc9D-2lV_oQdCAYlt_QTQ0vUxJki-KpfGLeC-sfguJ.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-edu-nsw-act-hand-pre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7c2b3d4d-9a35-492e-b62d-4e8f7c67f2db",1736052124),$APP.$cljs$cst$2675$family$$,"Edu NSW ACT Hand Pre",$APP.$cljs$cst$725$name$$,"Edu NSW ACT Hand Pre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edunswacthandpre/v3/kmKXZrI-ExGJWUmupHwGgw6Qw4svl-MsLiw7ATFEXwCkLE0ywWBqtsjedKEHuQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edunswacthandpre/v3/kmKXZrI-ExGJWUmupHwGgw6Qw4svl-MsLiw7ATFEXwCkLE0y82BqtsjedKEHuQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edunswacthandpre/v3/kmKXZrI-ExGJWUmupHwGgw6Qw4svl-MsLiw7ATFEXwCkLE0yH2dqtsjedKEHuQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edunswacthandpre/v3/kmKXZrI-ExGJWUmupHwGgw6Qw4svl-MsLiw7ATFEXwCkLE0yJmdqtsjedKEHuQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-edu-qld-beginner",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7f6500f6-3b0e-4314-b87e-ac08c2940dee",1021347416),$APP.$cljs$cst$2675$family$$,"Edu QLD Beginner",$APP.$cljs$cst$725$name$$,"Edu QLD Beginner",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduqldbeginner/v5/AMOHz5iUuHLEMNXyohhc_Y56PR3A8dNLF_w3Ka4HKE4E3oebi6vyVWCN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduqldbeginner/v5/AMOHz5iUuHLEMNXyohhc_Y56PR3A8dNLF_w3Ka4HKE423oebi6vyVWCN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduqldbeginner/v5/AMOHz5iUuHLEMNXyohhc_Y56PR3A8dNLF_w3Ka4HKE7a2Yebi6vyVWCN.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduqldbeginner/v5/AMOHz5iUuHLEMNXyohhc_Y56PR3A8dNLF_w3Ka4HKE7j2Yebi6vyVWCN.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-edu-qld-hand",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("acc47a8c-3768-4587-8d9f-e31c104a5102",
-1377340502),$APP.$cljs$cst$2675$family$$,"Edu QLD Hand",$APP.$cljs$cst$725$name$$,"Edu QLD Hand",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduqldhand/v3/d6lakaOkTtjy2QhuzWtup1rW3NCQVvjKPjPjngAUeRt5gGCzkrs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduqldhand/v3/d6lakaOkTtjy2QhuzWtup1rW3NCQVvjKPjPjnjIUeRt5gGCzkrs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduqldhand/v3/d6lakaOkTtjy2QhuzWtup1rW3NCQVvjKPjPjnt4TeRt5gGCzkrs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduqldhand/v3/d6lakaOkTtjy2QhuzWtup1rW3NCQVvjKPjPjnucTeRt5gGCzkrs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-edu-sa-beginner",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7243183c-fc13-4a72-a8e5-1e20ac453273",-591846620),$APP.$cljs$cst$2675$family$$,"Edu SA Beginner",$APP.$cljs$cst$725$name$$,"Edu SA Beginner",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edusabeginner/v5/rnC_-xRb1x-1lHXnLaZZ2xOoLIGfU3L82irpr_3C9989fo1yBydUEDs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edusabeginner/v5/rnC_-xRb1x-1lHXnLaZZ2xOoLIGfU3L82irpr_3C9-09fo1yBydUEDs.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edusabeginner/v5/rnC_-xRb1x-1lHXnLaZZ2xOoLIGfU3L82irpr_3C9wE6fo1yBydUEDs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edusabeginner/v5/rnC_-xRb1x-1lHXnLaZZ2xOoLIGfU3L82irpr_3C9zg6fo1yBydUEDs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-edu-sa-hand",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9a12d8a4-1c07-4d6a-bf61-742d41f8e4ee",2011664462),$APP.$cljs$cst$2675$family$$,"Edu SA Hand",$APP.$cljs$cst$725$name$$,"Edu SA Hand",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edusahand/v3/memtYaOmw37C-ogAJfd7NocVXTy8nx2cmqvXlWumvkSE55OZgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edusahand/v3/memtYaOmw37C-ogAJfd7NocVXTy8nx2cmqvXp2umvkSE55OZgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edusahand/v3/memtYaOmw37C-ogAJfd7NocVXTy8nx2cmqvXS2ymvkSE55OZgw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edusahand/v3/memtYaOmw37C-ogAJfd7NocVXTy8nx2cmqvXcmymvkSE55OZgw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-edu-tas-beginner",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e841e064-4cc2-4e1c-badd-e7ebb8d0bb3e",-31692287),$APP.$cljs$cst$2675$family$$,
"Edu TAS Beginner",$APP.$cljs$cst$725$name$$,"Edu TAS Beginner",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edutasbeginner/v5/ZXuwe04WubHfGVY-1TcNg7AFUmshg8jIUTzK3r34f_HwemkrBWRhvk02.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edutasbeginner/v5/ZXuwe04WubHfGVY-1TcNg7AFUmshg8jIUTzK3r34f_HCemkrBWRhvk02.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edutasbeginner/v5/ZXuwe04WubHfGVY-1TcNg7AFUmshg8jIUTzK3r34f_EufWkrBWRhvk02.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/edutasbeginner/v5/ZXuwe04WubHfGVY-1TcNg7AFUmshg8jIUTzK3r34f_EXfWkrBWRhvk02.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-edu-vic-wa-nt-beginner",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6a0d038b-6a4d-4124-9b3d-30407db49a20",450140382),$APP.$cljs$cst$2675$family$$,"Edu VIC WA NT Beginner",$APP.$cljs$cst$725$name$$,"Edu VIC WA NT Beginner",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduvicwantbeginner/v6/jiz2RF1BuW9OwcnNPxLl4KfZCHd9nFtd5Tu7stCpElYpvPfZZ-OXlPmFXwnpkeGR.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduvicwantbeginner/v6/jiz2RF1BuW9OwcnNPxLl4KfZCHd9nFtd5Tu7stCpElYpvPfZZ-OllPmFXwnpkeGR.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduvicwantbeginner/v6/jiz2RF1BuW9OwcnNPxLl4KfZCHd9nFtd5Tu7stCpElYpvPfZZ-NJk_mFXwnpkeGR.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduvicwantbeginner/v6/jiz2RF1BuW9OwcnNPxLl4KfZCHd9nFtd5Tu7stCpElYpvPfZZ-Nwk_mFXwnpkeGR.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-edu-vic-wa-nt-hand",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9704cd66-fffc-4641-9b09-88fb407a27b8",484168437),$APP.$cljs$cst$2675$family$$,"Edu VIC WA NT Hand",$APP.$cljs$cst$725$name$$,"Edu VIC WA NT Hand",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduvicwanthand/v3/UcCO3EsnIXnOaZKmY1Ry0wZjP9YVRBcw2boKoduKmMEVuLyfMZhrib2Bg-4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduvicwanthand/v3/UcCO3EsnIXnOaZKmY1Ry0wZjP9YVRBcw2boKoduKmMEVuI6fMZhrib2Bg-4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduvicwanthand/v3/UcCO3EsnIXnOaZKmY1Ry0wZjP9YVRBcw2boKoduKmMEVuGKYMZhrib2Bg-4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduvicwanthand/v3/UcCO3EsnIXnOaZKmY1Ry0wZjP9YVRBcw2boKoduKmMEVuFuYMZhrib2Bg-4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-edu-vic-wa-nt-hand-pre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f3fa5120-1092-49b6-ad8a-c6e7fabd29e3",
1039954504),$APP.$cljs$cst$2675$family$$,"Edu VIC WA NT Hand Pre",$APP.$cljs$cst$725$name$$,"Edu VIC WA NT Hand Pre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduvicwanthandpre/v3/neInzDmioZxjkInM_tLHFudmcN2Uxxc-9Vnv-4YmimMq127-YLTo4dgUBS1Nzqn8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduvicwanthandpre/v3/neInzDmioZxjkInM_tLHFudmcN2Uxxc-9Vnv-4YmimMq127-YLTa4dgUBS1Nzqn8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduvicwanthandpre/v3/neInzDmioZxjkInM_tLHFudmcN2Uxxc-9Vnv-4YmimMq127-YLQ25tgUBS1Nzqn8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/eduvicwanthandpre/v3/neInzDmioZxjkInM_tLHFudmcN2Uxxc-9Vnv-4YmimMq127-YLQP5tgUBS1Nzqn8.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-el-messiri",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8ffd3ca6-5b2f-4e48-baaa-a95e71a5bb91",2003197771),$APP.$cljs$cst$2675$family$$,"El Messiri",$APP.$cljs$cst$725$name$$,"El Messiri",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmessiri/v25/K2FhfZBRmr9vQ1pHEey6GIGo8_pv3myYjuXwe65ghj3OoapG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmessiri/v25/K2FhfZBRmr9vQ1pHEey6GIGo8_pv3myYjuXCe65ghj3OoapG.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmessiri/v25/K2FhfZBRmr9vQ1pHEey6GIGo8_pv3myYjuUufK5ghj3OoapG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmessiri/v25/K2FhfZBRmr9vQ1pHEey6GIGo8_pv3myYjuUXfK5ghj3OoapG.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-electrolize",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("faa489c0-c6db-465f-8809-4aaec25bd33f",2003772686),$APP.$cljs$cst$2675$family$$,"Electrolize",$APP.$cljs$cst$725$name$$,"Electrolize",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/electrolize/v20/cIf5Ma1dtE0zSiGSiED7AUEGso5tQafB.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-elms-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7cfcea59-1bdc-469d-a057-8a1878492b91",752184286),
$APP.$cljs$cst$2675$family$$,"Elms Sans",$APP.$cljs$cst$725$name$$,"Elms Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uWsoS_Lf9xv7Su1FpSCByoURnrD9-jpp3bJi52PLM6RNU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uWsoS_Lf9xv7Su1FpSCByoURnrD9-jph3aJi52PLM6RNU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/elmssans/v5/q5uWsoS_Lf9xv7Su1FpSCByoURnrD9-jpsPaJi52PLM6RNU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uWsoS_Lf9xv7Su1FpSCByoURnrD9-jpp3aJi52PLM6RNU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uWsoS_Lf9xv7Su1FpSCByoURnrD9-jpq_aJi52PLM6RNU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uWsoS_Lf9xv7Su1FpSCByoURnrD9-jpkPdJi52PLM6RNU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uWsoS_Lf9xv7Su1FpSCByoURnrD9-jpnrdJi52PLM6RNU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/elmssans/v5/q5uWsoS_Lf9xv7Su1FpSCByoURnrD9-jph3dJi52PLM6RNU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uWsoS_Lf9xv7Su1FpSCByoURnrD9-jpjTdJi52PLM6RNU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,
"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uUsoS_Lf9xv7Su1Fp4AS5XiXCAlXGks1WZzmx8OJE_VNWoyQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uUsoS_Lf9xv7Su1Fp4AS5XiXCAlXGks1WZTm18OJE_VNWoyQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uUsoS_Lf9xv7Su1Fp4AS5XiXCAlXGks1WZkG18OJE_VNWoyQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uUsoS_Lf9xv7Su1Fp4AS5XiXCAlXGks1WZzm18OJE_VNWoyQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uUsoS_Lf9xv7Su1Fp4AS5XiXCAlXGks1WZ_G18OJE_VNWoyQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uUsoS_Lf9xv7Su1Fp4AS5XiXCAlXGks1WZEGp8OJE_VNWoyQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uUsoS_Lf9xv7Su1Fp4AS5XiXCAlXGks1WZKWp8OJE_VNWoyQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uUsoS_Lf9xv7Su1Fp4AS5XiXCAlXGks1WZTmp8OJE_VNWoyQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elmssans/v5/q5uUsoS_Lf9xv7Su1Fp4AS5XiXCAlXGks1WZZ2p8OJE_VNWoyQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-elsie",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dece153f-11b0-4cba-bc1d-fe7daad94d7d",-671772786),$APP.$cljs$cst$2675$family$$,"Elsie",$APP.$cljs$cst$725$name$$,"Elsie",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elsie/v26/BCanqZABrez54yYu9slAeLgX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elsie/v26/BCaqqZABrez54x6q2-1IU6QeXSBk.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-elsie-swash-caps",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e3a17424-c4f8-476b-b1aa-1cafbcb4b19e",1180268286),$APP.$cljs$cst$2675$family$$,"Elsie Swash Caps",$APP.$cljs$cst$725$name$$,"Elsie Swash Caps",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elsieswashcaps/v25/845DNN8xGZyVX5MVo_upKf7KnjK0ferVKGWsUo8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/elsieswashcaps/v25/845ENN8xGZyVX5MVo_upKf7KnjK0RW74DG2HToawrdU.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-emblema-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("02100e36-3348-42a9-99ff-05c9f5de9fb3",1895252849),$APP.$cljs$cst$2675$family$$,"Emblema One",$APP.$cljs$cst$725$name$$,"Emblema One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/emblemaone/v22/nKKT-GQ0F5dSY8vzG0rOEIRBHl57G_f_.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-emilys-candy",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d37c3244-4562-4c15-9dbf-e00408b51e4f",-1154005733),$APP.$cljs$cst$2675$family$$,"Emilys Candy",$APP.$cljs$cst$725$name$$,"Emilys Candy",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/emilyscandy/v21/2EbgL-1mD1Rnb0OGKudbk0y5r9xrX84JjA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-encode-sans",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d48e1c69-36c7-4240-9119-c704822d581d",-1594181281),$APP.$cljs$cst$2675$family$$,"Encode Sans",$APP.$cljs$cst$725$name$$,"Encode Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/encodesans/v23/LDIcapOFNxEwR-Bd1O9uYNmnUQomAgE25imKSbHhROjLsZBWTSrQGGHiZtWP7FJCt2c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesans/v23/LDIcapOFNxEwR-Bd1O9uYNmnUQomAgE25imKSbHhROjLsZBWTSrQGOHjZtWP7FJCt2c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesans/v23/LDIcapOFNxEwR-Bd1O9uYNmnUQomAgE25imKSbHhROjLsZBWTSrQGD_jZtWP7FJCt2c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesans/v23/LDIcapOFNxEwR-Bd1O9uYNmnUQomAgE25imKSbHhROjLsZBWTSrQGGHjZtWP7FJCt2c.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesans/v23/LDIcapOFNxEwR-Bd1O9uYNmnUQomAgE25imKSbHhROjLsZBWTSrQGFPjZtWP7FJCt2c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesans/v23/LDIcapOFNxEwR-Bd1O9uYNmnUQomAgE25imKSbHhROjLsZBWTSrQGL_kZtWP7FJCt2c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesans/v23/LDIcapOFNxEwR-Bd1O9uYNmnUQomAgE25imKSbHhROjLsZBWTSrQGIbkZtWP7FJCt2c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesans/v23/LDIcapOFNxEwR-Bd1O9uYNmnUQomAgE25imKSbHhROjLsZBWTSrQGOHkZtWP7FJCt2c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesans/v23/LDIcapOFNxEwR-Bd1O9uYNmnUQomAgE25imKSbHhROjLsZBWTSrQGMjkZtWP7FJCt2c.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-encode-sans-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b08a2b23-f6b7-4b66-a971-e9f287a7b94f",-740452110),$APP.$cljs$cst$2675$family$$,"Encode Sans Condensed",$APP.$cljs$cst$725$name$$,"Encode Sans Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanscondensed/v11/j8_76_LD37rqfuwxyIuaZhE6cRXOLtm2gfT-5a-JLQoFI2KR.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanscondensed/v11/j8_46_LD37rqfuwxyIuaZhE6cRXOLtm2gfT-SY6pByQJKnuIFA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanscondensed/v11/j8_46_LD37rqfuwxyIuaZhE6cRXOLtm2gfT-LY2pByQJKnuIFA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanscondensed/v11/j8_16_LD37rqfuwxyIuaZhE6cRXOLtm2gfTGgaWNDw8VIw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanscondensed/v11/j8_46_LD37rqfuwxyIuaZhE6cRXOLtm2gfT-dYypByQJKnuIFA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanscondensed/v11/j8_46_LD37rqfuwxyIuaZhE6cRXOLtm2gfT-WYupByQJKnuIFA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanscondensed/v11/j8_46_LD37rqfuwxyIuaZhE6cRXOLtm2gfT-PYqpByQJKnuIFA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanscondensed/v11/j8_46_LD37rqfuwxyIuaZhE6cRXOLtm2gfT-IYmpByQJKnuIFA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanscondensed/v11/j8_46_LD37rqfuwxyIuaZhE6cRXOLtm2gfT-BYipByQJKnuIFA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-encode-sans-expanded",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e71eca8c-d788-45e1-955a-ef8979e9192d",-1575609919),$APP.$cljs$cst$2675$family$$,"Encode Sans Expanded",$APP.$cljs$cst$725$name$$,"Encode Sans Expanded",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesansexpanded/v12/c4mx1mF4GcnstG_Jh1QH6ac4hNLeNyeYUpJGKQNicoAbJlw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesansexpanded/v12/c4mw1mF4GcnstG_Jh1QH6ac4hNLeNyeYUpLqCCNIXIwSP0XD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesansexpanded/v12/c4mw1mF4GcnstG_Jh1QH6ac4hNLeNyeYUpKOCyNIXIwSP0XD.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesansexpanded/v12/c4m_1mF4GcnstG_Jh1QH6ac4hNLeNyeYUqoiIwdAd5Ab.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesansexpanded/v12/c4mw1mF4GcnstG_Jh1QH6ac4hNLeNyeYUpLWCiNIXIwSP0XD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesansexpanded/v12/c4mw1mF4GcnstG_Jh1QH6ac4hNLeNyeYUpL6DSNIXIwSP0XD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesansexpanded/v12/c4mw1mF4GcnstG_Jh1QH6ac4hNLeNyeYUpKeDCNIXIwSP0XD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesansexpanded/v12/c4mw1mF4GcnstG_Jh1QH6ac4hNLeNyeYUpKCDyNIXIwSP0XD.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesansexpanded/v12/c4mw1mF4GcnstG_Jh1QH6ac4hNLeNyeYUpKmDiNIXIwSP0XD.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-encode-sans-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9c2cd0bc-9711-458a-a8f7-8605f7ff3992",
535705223),$APP.$cljs$cst$2675$family$$,"Encode Sans SC",$APP.$cljs$cst$725$name$$,"Encode Sans SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssc/v14/jVyp7nLwCGzQ9zE7ZyRg0QRXHPZc_uUA6Kb3VJWLE_Pdtm7lcD6qvXT1HHhn8c9NOEEClIc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssc/v14/jVyp7nLwCGzQ9zE7ZyRg0QRXHPZc_uUA6Kb3VJWLE_Pdtm7lcD6qvXT1HPhm8c9NOEEClIc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssc/v14/jVyp7nLwCGzQ9zE7ZyRg0QRXHPZc_uUA6Kb3VJWLE_Pdtm7lcD6qvXT1HCZm8c9NOEEClIc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssc/v14/jVyp7nLwCGzQ9zE7ZyRg0QRXHPZc_uUA6Kb3VJWLE_Pdtm7lcD6qvXT1HHhm8c9NOEEClIc.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssc/v14/jVyp7nLwCGzQ9zE7ZyRg0QRXHPZc_uUA6Kb3VJWLE_Pdtm7lcD6qvXT1HEpm8c9NOEEClIc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssc/v14/jVyp7nLwCGzQ9zE7ZyRg0QRXHPZc_uUA6Kb3VJWLE_Pdtm7lcD6qvXT1HKZh8c9NOEEClIc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssc/v14/jVyp7nLwCGzQ9zE7ZyRg0QRXHPZc_uUA6Kb3VJWLE_Pdtm7lcD6qvXT1HJ9h8c9NOEEClIc.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssc/v14/jVyp7nLwCGzQ9zE7ZyRg0QRXHPZc_uUA6Kb3VJWLE_Pdtm7lcD6qvXT1HPhh8c9NOEEClIc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssc/v14/jVyp7nLwCGzQ9zE7ZyRg0QRXHPZc_uUA6Kb3VJWLE_Pdtm7lcD6qvXT1HNFh8c9NOEEClIc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-encode-sans-semi-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("563b3f7e-e16a-429b-b452-107a912164ad",-1004014666),$APP.$cljs$cst$2675$family$$,"Encode Sans Semi Condensed",$APP.$cljs$cst$725$name$$,"Encode Sans Semi Condensed",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemicondensed/v11/3qT6oiKqnDuUtQUEHMoXcmspmy55SFWrXFRp9FTOG1T19MFtQ9jpVUA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemicondensed/v11/3qT7oiKqnDuUtQUEHMoXcmspmy55SFWrXFRp9FTOG1RZ1eFHbdTgTFmr.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemicondensed/v11/3qT7oiKqnDuUtQUEHMoXcmspmy55SFWrXFRp9FTOG1Q91uFHbdTgTFmr.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemicondensed/v11/3qT4oiKqnDuUtQUEHMoXcmspmy55SFWrXFRp9FTOG2yR_sVPRsjp.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemicondensed/v11/3qT7oiKqnDuUtQUEHMoXcmspmy55SFWrXFRp9FTOG1Rl1-FHbdTgTFmr.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemicondensed/v11/3qT7oiKqnDuUtQUEHMoXcmspmy55SFWrXFRp9FTOG1RJ0OFHbdTgTFmr.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemicondensed/v11/3qT7oiKqnDuUtQUEHMoXcmspmy55SFWrXFRp9FTOG1Qt0eFHbdTgTFmr.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemicondensed/v11/3qT7oiKqnDuUtQUEHMoXcmspmy55SFWrXFRp9FTOG1Qx0uFHbdTgTFmr.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemicondensed/v11/3qT7oiKqnDuUtQUEHMoXcmspmy55SFWrXFRp9FTOG1QV0-FHbdTgTFmr.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-encode-sans-semi-expanded",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b717cfdb-a776-4db8-9a2c-014a4cd2abe7",
-196451651),$APP.$cljs$cst$2675$family$$,"Encode Sans Semi Expanded",$APP.$cljs$cst$725$name$$,"Encode Sans Semi Expanded",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemiexpanded/v20/ke8xOhAPMEZs-BDuzwftTNJ85JvwMOzE9d9Cca5TM-41KwrlKXeOEA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemiexpanded/v20/ke8yOhAPMEZs-BDuzwftTNJ85JvwMOzE9d9Cca5TM0IUCyDLJX6XCWU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemiexpanded/v20/ke8yOhAPMEZs-BDuzwftTNJ85JvwMOzE9d9Cca5TMyYXCyDLJX6XCWU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemiexpanded/v20/ke83OhAPMEZs-BDuzwftTNJ85JvwMOzE9d9Cca5TC4o_LyjgOXc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemiexpanded/v20/ke8yOhAPMEZs-BDuzwftTNJ85JvwMOzE9d9Cca5TM34WCyDLJX6XCWU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemiexpanded/v20/ke8yOhAPMEZs-BDuzwftTNJ85JvwMOzE9d9Cca5TM1IRCyDLJX6XCWU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemiexpanded/v20/ke8yOhAPMEZs-BDuzwftTNJ85JvwMOzE9d9Cca5TMzYQCyDLJX6XCWU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemiexpanded/v20/ke8yOhAPMEZs-BDuzwftTNJ85JvwMOzE9d9Cca5TMyoTCyDLJX6XCWU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/encodesanssemiexpanded/v20/ke8yOhAPMEZs-BDuzwftTNJ85JvwMOzE9d9Cca5TMw4SCyDLJX6XCWU.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-engagement",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1fd75f23-5e0a-4e60-bdad-0f9091e11bce",1624425799),$APP.$cljs$cst$2675$family$$,"Engagement",$APP.$cljs$cst$725$name$$,"Engagement",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/engagement/v29/x3dlckLDZbqa7RUs9MFVXNossybsHQI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-englebert",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0606aa9b-c6ca-4a75-9e25-ca67ee6ea2af",908130987),$APP.$cljs$cst$2675$family$$,"Englebert",$APP.$cljs$cst$725$name$$,"Englebert",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/englebert/v24/xn7iYH8w2XGrC8AR4HSxT_fYdN-WZw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-enriqueta",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cd5459ea-4d4e-4132-ab09-617c882590e6",
86926255),$APP.$cljs$cst$2675$family$$,"Enriqueta",$APP.$cljs$cst$725$name$$,"Enriqueta",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/enriqueta/v19/goksH6L7AUFrRvV44HVTS0CjkP1Yog.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/enriqueta/v19/gokpH6L7AUFrRvV44HVrv2mHmNZEq6TTFw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/enriqueta/v19/gokpH6L7AUFrRvV44HVrk26HmNZEq6TTFw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/enriqueta/v19/gokpH6L7AUFrRvV44HVr92-HmNZEq6TTFw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ephesis",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("43f32d7a-4725-436b-9039-20f4c445b9fb",-496708509),$APP.$cljs$cst$2675$family$$,"Ephesis",$APP.$cljs$cst$725$name$$,"Ephesis",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ephesis/v11/uU9PCBUS8IerL2VG7xPb3vyHmlI.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-epilogue",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d9f4f3c8-357a-4038-b5f2-e9b0fe99e8e6",231366886),$APP.$cljs$cst$2675$family$$,"Epilogue",$APP.$cljs$cst$725$name$$,"Epilogue",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZMFGj5hxF0EhjimngomvnCCtqb30OXMDLiDJXVigHPVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZMFGj5hxF0EhjimngomvnCCtqb30OXsDPiDJXVigHPVA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZMFGj5hxF0EhjimngomvnCCtqb30OXbjPiDJXVigHPVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZMFGj5hxF0EhjimngomvnCCtqb30OXMDPiDJXVigHPVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZMFGj5hxF0EhjimngomvnCCtqb30OXAjPiDJXVigHPVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZMFGj5hxF0EhjimngomvnCCtqb30OX7jTiDJXVigHPVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZMFGj5hxF0EhjimngomvnCCtqb30OX1zTiDJXVigHPVA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZMFGj5hxF0EhjimngomvnCCtqb30OXsDTiDJXVigHPVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/epilogue/v20/O4ZMFGj5hxF0EhjimngomvnCCtqb30OXmTTiDJXVigHPVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZCFGj5hxF0EhjimlIhqAYaY7EBcUSC-HAKTp_RqATfVHNU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",
$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZCFGj5hxF0EhjimlIhqAYaY7EBcUSC-HCKT5_RqATfVHNU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZCFGj5hxF0EhjimlIhqAYaY7EBcUSC-HBUT5_RqATfVHNU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZCFGj5hxF0EhjimlIhqAYaY7EBcUSC-HAKT5_RqATfVHNU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZCFGj5hxF0EhjimlIhqAYaY7EBcUSC-HA4T5_RqATfVHNU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZCFGj5hxF0EhjimlIhqAYaY7EBcUSC-HDUSJ_RqATfVHNU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZCFGj5hxF0EhjimlIhqAYaY7EBcUSC-HDtSJ_RqATfVHNU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZCFGj5hxF0EhjimlIhqAYaY7EBcUSC-HCKSJ_RqATfVHNU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epilogue/v20/O4ZCFGj5hxF0EhjimlIhqAYaY7EBcUSC-HCjSJ_RqATfVHNU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-epunda-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d24118d1-11c3-4114-997e-7c297fec6c53",
48226622),$APP.$cljs$cst$2675$family$$,"Epunda Sans",$APP.$cljs$cst$725$name$$,"Epunda Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundasans/v5/ea8Kads_Rv3-GJfWRrHjgFROia5FlsurC_ndMlT7Sb54PQAqcA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundasans/v5/ea8Kads_Rv3-GJfWRrHjgFROia5FlsurC_ndbFT7Sb54PQAqcA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundasans/v5/ea8Kads_Rv3-GJfWRrHjgFROia5FlsurC_ndXlT7Sb54PQAqcA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundasans/v5/ea8Kads_Rv3-GJfWRrHjgFROia5FlsurC_ndslP7Sb54PQAqcA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundasans/v5/ea8Kads_Rv3-GJfWRrHjgFROia5FlsurC_ndi1P7Sb54PQAqcA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundasans/v5/ea8Kads_Rv3-GJfWRrHjgFROia5FlsurC_nd7FP7Sb54PQAqcA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundasans/v5/ea8Kads_Rv3-GJfWRrHjgFROia5FlsurC_ndxVP7Sb54PQAqcA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundasans/v5/ea8Mads_Rv3-GJfWRrHjgH5Hu1Gd_6Axpf7IpBdNCrR8HwU6cADD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundasans/v5/ea8Mads_Rv3-GJfWRrHjgH5Hu1Gd_6Axpf7IpBcTCrR8HwU6cADD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundasans/v5/ea8Mads_Rv3-GJfWRrHjgH5Hu1Gd_6Axpf7IpBchCrR8HwU6cADD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/epundasans/v5/ea8Mads_Rv3-GJfWRrHjgH5Hu1Gd_6Axpf7IpBfNDbR8HwU6cADD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundasans/v5/ea8Mads_Rv3-GJfWRrHjgH5Hu1Gd_6Axpf7IpBf0DbR8HwU6cADD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundasans/v5/ea8Mads_Rv3-GJfWRrHjgH5Hu1Gd_6Axpf7IpBeTDbR8HwU6cADD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundasans/v5/ea8Mads_Rv3-GJfWRrHjgH5Hu1Gd_6Axpf7IpBe6DbR8HwU6cADD.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-epunda-slab",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b559aa7b-00b1-4cbb-b542-0020bef3a365",-1694752799),$APP.$cljs$cst$2675$family$$,"Epunda Slab",$APP.$cljs$cst$725$name$$,"Epunda Slab",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundaslab/v2/46k8lbHxTynXpZplPiOFHX9L36WJhClOsZt_JjNVoU4Q_2eOpA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundaslab/v2/46k8lbHxTynXpZplPiOFHX9L36WJhClOsZt_eDNVoU4Q_2eOpA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundaslab/v2/46k8lbHxTynXpZplPiOFHX9L36WJhClOsZt_SjNVoU4Q_2eOpA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundaslab/v2/46k8lbHxTynXpZplPiOFHX9L36WJhClOsZt_pjRVoU4Q_2eOpA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundaslab/v2/46k8lbHxTynXpZplPiOFHX9L36WJhClOsZt_nzRVoU4Q_2eOpA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundaslab/v2/46k8lbHxTynXpZplPiOFHX9L36WJhClOsZt_-DRVoU4Q_2eOpA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundaslab/v2/46k8lbHxTynXpZplPiOFHX9L36WJhClOsZt_0TRVoU4Q_2eOpA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundaslab/v2/46k6lbHxTynXpZplPiOFHVVC7VpR7ULUH5xqsHDj4kQU3WKepN0B.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundaslab/v2/46k6lbHxTynXpZplPiOFHVVC7VpR7ULUH5xqsHC94kQU3WKepN0B.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundaslab/v2/46k6lbHxTynXpZplPiOFHVVC7VpR7ULUH5xqsHCP4kQU3WKepN0B.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundaslab/v2/46k6lbHxTynXpZplPiOFHVVC7VpR7ULUH5xqsHBj5UQU3WKepN0B.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/epundaslab/v2/46k6lbHxTynXpZplPiOFHVVC7VpR7ULUH5xqsHBa5UQU3WKepN0B.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundaslab/v2/46k6lbHxTynXpZplPiOFHVVC7VpR7ULUH5xqsHA95UQU3WKepN0B.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/epundaslab/v2/46k6lbHxTynXpZplPiOFHVVC7VpR7ULUH5xqsHAU5UQU3WKepN0B.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-erica-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a9247328-e6ad-403d-b492-879c02a9e6a0",930273282),$APP.$cljs$cst$2675$family$$,"Erica One",$APP.$cljs$cst$725$name$$,
"Erica One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ericaone/v29/WBLnrEXccV9VGrOKmGD1W0_MJMGxiQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-esteban",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c77d5362-f922-46cc-8c62-e4aa18a5c325",1060446619),$APP.$cljs$cst$2675$family$$,"Esteban",$APP.$cljs$cst$725$name$$,"Esteban",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/esteban/v16/r05bGLZE-bdGdN-GdOuD5jokU8E.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-estonia",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a32c7a60-d6c5-4f3d-903e-326e6b9b2229",-1943627755),$APP.$cljs$cst$2675$family$$,"Estonia",$APP.$cljs$cst$725$name$$,"Estonia",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/estonia/v13/7Au_p_4ijSecA1yHCCL8zkwMIFg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-euphoria-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d2c540e0-d3fd-4587-b2e9-f00841389cba",70282291),$APP.$cljs$cst$2675$family$$,"Euphoria Script",$APP.$cljs$cst$725$name$$,
"Euphoria Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/euphoriascript/v22/mFTpWb0X2bLb_cx6To2B8GpKoD5ak_ZT1D8x7Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-ewert",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bedef5da-f7f9-4f88-98de-56fcdded4c5f",-2023895953),$APP.$cljs$cst$2675$family$$,"Ewert",$APP.$cljs$cst$725$name$$,"Ewert",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ewert/v27/va9I4kzO2tFODYBvS-J3kbDP.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-exile",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6f5649e4-cde3-4e74-9342-41953678e8a3",1092064314),$APP.$cljs$cst$2675$family$$,"Exile",$APP.$cljs$cst$725$name$$,"Exile",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exile/v1/pxiKyp0xqNtbjBsYHpT2dkNE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-exo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7bf1afd8-abe0-4b14-abea-4666c3d4540e",-2087512428),$APP.$cljs$cst$2675$family$$,
"Exo",$APP.$cljs$cst$725$name$$,"Exo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UaZrEtFpBI4f1ZSIK9d4LjJ4lM2CwNsOl4p5Is.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UaZrEtFpBI4f1ZSIK9d4LjJ4tM3CwNsOl4p5Is.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UaZrEtFpBI4f1ZSIK9d4LjJ4g03CwNsOl4p5Is.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UaZrEtFpBI4f1ZSIK9d4LjJ4lM3CwNsOl4p5Is.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/exo/v25/4UaZrEtFpBI4f1ZSIK9d4LjJ4mE3CwNsOl4p5Is.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UaZrEtFpBI4f1ZSIK9d4LjJ4o0wCwNsOl4p5Is.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UaZrEtFpBI4f1ZSIK9d4LjJ4rQwCwNsOl4p5Is.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UaZrEtFpBI4f1ZSIK9d4LjJ4tMwCwNsOl4p5Is.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UaZrEtFpBI4f1ZSIK9d4LjJ4vowCwNsOl4p5Is.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UafrEtFpBISdmSt-MY2ehbO95t040FmPnws9Iu-uA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UafrEtFpBISdmSt-MY2ehbO95t0Y0BmPnws9Iu-uA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UafrEtFpBISdmSt-MY2ehbO95t0vUBmPnws9Iu-uA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UafrEtFpBISdmSt-MY2ehbO95t040BmPnws9Iu-uA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UafrEtFpBISdmSt-MY2ehbO95t00UBmPnws9Iu-uA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UafrEtFpBISdmSt-MY2ehbO95t0PUdmPnws9Iu-uA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UafrEtFpBISdmSt-MY2ehbO95t0BEdmPnws9Iu-uA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UafrEtFpBISdmSt-MY2ehbO95t0Y0dmPnws9Iu-uA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo/v25/4UafrEtFpBISdmSt-MY2ehbO95t0SkdmPnws9Iu-uA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"gfont-exo-2",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f48f4d96-04f0-4c28-a1d9-d464be9ed2a2",-92937722),$APP.$cljs$cst$2675$family$$,"Exo 2",$APP.$cljs$cst$725$name$$,"Exo 2",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH1v4okm5zmbvwkAx_sfcEuiD8jvvOcPtq-rpvLpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH1v4okm5zmbvwkAx_sfcEuiD8jPvKcPtq-rpvLpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH1v4okm5zmbvwkAx_sfcEuiD8j4PKcPtq-rpvLpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH1v4okm5zmbvwkAx_sfcEuiD8jvvKcPtq-rpvLpQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH1v4okm5zmbvwkAx_sfcEuiD8jjPKcPtq-rpvLpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/exo2/v26/7cH1v4okm5zmbvwkAx_sfcEuiD8jYPWcPtq-rpvLpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH1v4okm5zmbvwkAx_sfcEuiD8jWfWcPtq-rpvLpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",
$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH1v4okm5zmbvwkAx_sfcEuiD8jPvWcPtq-rpvLpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH1v4okm5zmbvwkAx_sfcEuiD8jF_WcPtq-rpvLpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH3v4okm5zmbtYtMeA0FKq0Jjg2drF0fNC6jJ7bpQBL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH3v4okm5zmbtYtMeA0FKq0Jjg2drH0fdC6jJ7bpQBL.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH3v4okm5zmbtYtMeA0FKq0Jjg2drEqfdC6jJ7bpQBL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH3v4okm5zmbtYtMeA0FKq0Jjg2drF0fdC6jJ7bpQBL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH3v4okm5zmbtYtMeA0FKq0Jjg2drFGfdC6jJ7bpQBL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH3v4okm5zmbtYtMeA0FKq0Jjg2drGqetC6jJ7bpQBL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH3v4okm5zmbtYtMeA0FKq0Jjg2drGTetC6jJ7bpQBL.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH3v4okm5zmbtYtMeA0FKq0Jjg2drH0etC6jJ7bpQBL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/exo2/v26/7cH3v4okm5zmbtYtMeA0FKq0Jjg2drHdetC6jJ7bpQBL.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-expletus-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5ab381b1-0dc6-4a53-8474-733086fda322",1603579734),$APP.$cljs$cst$2675$family$$,"Expletus Sans",$APP.$cljs$cst$725$name$$,"Expletus Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/expletussans/v31/RLpqK5v5_bqufTYdnhFzDj2dX_IwS3my73zcDaSY2s1oFQTcXfMm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/expletussans/v31/RLpqK5v5_bqufTYdnhFzDj2dX_IwS3my73zcDaSq2s1oFQTcXfMm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/expletussans/v31/RLpqK5v5_bqufTYdnhFzDj2dX_IwS3my73zcDaRG3c1oFQTcXfMm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/expletussans/v31/RLpqK5v5_bqufTYdnhFzDj2dX_IwS3my73zcDaR_3c1oFQTcXfMm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/expletussans/v31/RLpoK5v5_bqufTYdnhFzDj2ddfsCtKHbhOZyCrFQmSUrHwD-WOMmKKY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/expletussans/v31/RLpoK5v5_bqufTYdnhFzDj2ddfsCtKHbhOZyCrFQmRcrHwD-WOMmKKY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/expletussans/v31/RLpoK5v5_bqufTYdnhFzDj2ddfsCtKHbhOZyCrFQmfssHwD-WOMmKKY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/expletussans/v31/RLpoK5v5_bqufTYdnhFzDj2ddfsCtKHbhOZyCrFQmcIsHwD-WOMmKKY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-explora",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c15420ad-e6a8-48a0-bd31-66b84e94c879",-194781476),$APP.$cljs$cst$2675$family$$,"Explora",$APP.$cljs$cst$725$name$$,"Explora",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/explora/v11/tsstApxFfjUH4wrvc1qPonC3vqc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-faculty-glyphic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("73d45aff-71b6-4a77-89d1-4b6426b9a530",-581462506),$APP.$cljs$cst$2675$family$$,"Faculty Glyphic",$APP.$cljs$cst$725$name$$,"Faculty Glyphic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/facultyglyphic/v4/RrQIbot2-iBvI2mYSyKIrcgoBuQIG-eFNVmULg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fahkwang",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5a91756d-b449-4630-b030-7aec2276c0d0",1455874504),
$APP.$cljs$cst$2675$family$$,"Fahkwang",$APP.$cljs$cst$725$name$$,"Fahkwang",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fahkwang/v18/Noa26Uj3zpmBOgbNpOJHmZlRFipxkwjx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fahkwang/v18/Noa06Uj3zpmBOgbNpOqNgHFQHC5Tlhjxdw4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fahkwang/v18/Noa26Uj3zpmBOgbNpOIjmplRFipxkwjx.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fahkwang/v18/Noa06Uj3zpmBOgbNpOqNgBVTHC5Tlhjxdw4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fahkwang/v18/Noax6Uj3zpmBOgbNpNqPsr1ZPTZ4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fahkwang/v18/Noa36Uj3zpmBOgbNpOqNuLl7OCZ4ihE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fahkwang/v18/Noa26Uj3zpmBOgbNpOJ7m5lRFipxkwjx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fahkwang/v18/Noa06Uj3zpmBOgbNpOqNgE1SHC5Tlhjxdw4.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fahkwang/v18/Noa26Uj3zpmBOgbNpOJXnJlRFipxkwjx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/fahkwang/v18/Noa06Uj3zpmBOgbNpOqNgGFVHC5Tlhjxdw4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fahkwang/v18/Noa26Uj3zpmBOgbNpOIznZlRFipxkwjx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",
$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fahkwang/v18/Noa06Uj3zpmBOgbNpOqNgAVUHC5Tlhjxdw4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-familjen-grotesk",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("600016ad-8ac8-471e-9243-0d6597d8f0c1",-1801153578),$APP.$cljs$cst$2675$family$$,"Familjen Grotesk",$APP.$cljs$cst$725$name$$,"Familjen Grotesk",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/familjengrotesk/v11/Qw3LZR9ZHiDnImG6-NEMQ41wby8WRnYsfkunR_eGfMGJaSztc1jcEYq2.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",
$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/familjengrotesk/v11/Qw3LZR9ZHiDnImG6-NEMQ41wby8WRnYsfkunR_eGfMG7aSztc1jcEYq2.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/familjengrotesk/v11/Qw3LZR9ZHiDnImG6-NEMQ41wby8WRnYsfkunR_eGfMFXbiztc1jcEYq2.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/familjengrotesk/v11/Qw3LZR9ZHiDnImG6-NEMQ41wby8WRnYsfkunR_eGfMFubiztc1jcEYq2.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/familjengrotesk/v11/Qw31ZR9ZHiDnImG6-NEMQ41wby8WbH8egZPOLG0oe9RBKsSueVz-FJq2Rv4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/familjengrotesk/v11/Qw31ZR9ZHiDnImG6-NEMQ41wby8WbH8egZPOLG0oe9RBKvaueVz-FJq2Rv4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/familjengrotesk/v11/Qw31ZR9ZHiDnImG6-NEMQ41wby8WbH8egZPOLG0oe9RBKhqpeVz-FJq2Rv4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/familjengrotesk/v11/Qw31ZR9ZHiDnImG6-NEMQ41wby8WbH8egZPOLG0oe9RBKiOpeVz-FJq2Rv4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fanwood-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6d1f184e-d7a4-46c1-86ee-8052c766876f",1946270726),$APP.$cljs$cst$2675$family$$,"Fanwood Text",$APP.$cljs$cst$725$name$$,"Fanwood Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fanwoodtext/v17/3XFtErwl05Ad_vSCF6Fq7xXGRdbY1P1Sbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/fanwoodtext/v17/3XFzErwl05Ad_vSCF6Fq7xX2R9zc9vhCblye.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-farro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d154f366-4921-43ab-8d8a-0fef0b799946",-1876885112),$APP.$cljs$cst$2675$family$$,"Farro",$APP.$cljs$cst$725$name$$,"Farro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/farro/v15/i7dJIFl3byGNHa3hNJ6-WkJUQUq7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/farro/v15/i7dEIFl3byGNHZVNHLq2cV5d.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/farro/v15/i7dJIFl3byGNHa25NZ6-WkJUQUq7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/farro/v15/i7dJIFl3byGNHa3xM56-WkJUQUq7.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-farsan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("47de4234-831b-42cd-9efb-457c314080ea",-1930457464),$APP.$cljs$cst$2675$family$$,"Farsan",$APP.$cljs$cst$725$name$$,"Farsan",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/farsan/v24/VEMwRoJ0vY_zsyz62q-pxDX9rQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fascinate",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6d40f461-3261-4713-a8ee-0523e5d9d68d",1252242289),$APP.$cljs$cst$2675$family$$,"Fascinate",$APP.$cljs$cst$725$name$$,
"Fascinate",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fascinate/v23/z7NWdRrufC8XJK0IIEli1LbQRPyNrw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-fascinate-inline",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cc6621b1-7e75-430e-b065-985eda8d4898",657863489),$APP.$cljs$cst$2675$family$$,"Fascinate Inline",$APP.$cljs$cst$725$name$$,"Fascinate Inline",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fascinateinline/v24/jVyR7mzzB3zc-jp6QCAu60poNqIy1g3CfRXxWZQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-faster-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("65c75143-dabf-44d0-b0f5-f4222b7171a6",2052285872),$APP.$cljs$cst$2675$family$$,"Faster One",$APP.$cljs$cst$725$name$$,"Faster One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fasterone/v20/H4ciBXCHmdfClFb-vWhfyLuShq63czE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fasthand",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("042d3aaf-a6d4-4155-88a2-b50a2e325c4e",-1431091178),$APP.$cljs$cst$2675$family$$,
"Fasthand",$APP.$cljs$cst$725$name$$,"Fasthand",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fasthand/v33/0yb9GDohyKTYn_ZEESkuYkw2rQg1.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-fauna-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d89fdae5-4e81-4581-8a73-4acdb236bce1",-865405860),$APP.$cljs$cst$2675$family$$,"Fauna One",$APP.$cljs$cst$725$name$$,"Fauna One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/faunaone/v16/wlpzgwTPBVpjpCuwkuEx2UxLYClOCg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-faustina",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2ff7d51b-84fb-437e-a79d-1ce8857e22d0",1896295475),$APP.$cljs$cst$2675$family$$,"Faustina",$APP.$cljs$cst$725$name$$,"Faustina",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/faustina/v23/XLY4IZPxYpJfTbZAFXWzNT2SO8wpWHls3IEvGVWWe8tbEg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/faustina/v23/XLY4IZPxYpJfTbZAFXWzNT2SO8wpWHlsgoEvGVWWe8tbEg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/faustina/v23/XLY4IZPxYpJfTbZAFXWzNT2SO8wpWHlssIEvGVWWe8tbEg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/faustina/v23/XLY4IZPxYpJfTbZAFXWzNT2SO8wpWHlsXIYvGVWWe8tbEg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/faustina/v23/XLY4IZPxYpJfTbZAFXWzNT2SO8wpWHlsZYYvGVWWe8tbEg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/faustina/v23/XLY4IZPxYpJfTbZAFXWzNT2SO8wpWHlsAoYvGVWWe8tbEg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/faustina/v23/XLY2IZPxYpJfTbZAFV-6B8JKUqez9n55SsKZWl-SWc5LEnoF.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/faustina/v23/XLY2IZPxYpJfTbZAFV-6B8JKUqez9n55SsLHWl-SWc5LEnoF.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/faustina/v23/XLY2IZPxYpJfTbZAFV-6B8JKUqez9n55SsL1Wl-SWc5LEnoF.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/faustina/v23/XLY2IZPxYpJfTbZAFV-6B8JKUqez9n55SsIZXV-SWc5LEnoF.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/faustina/v23/XLY2IZPxYpJfTbZAFV-6B8JKUqez9n55SsIgXV-SWc5LEnoF.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/faustina/v23/XLY2IZPxYpJfTbZAFV-6B8JKUqez9n55SsJHXV-SWc5LEnoF.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-federant",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7b7917b6-95bf-4796-b0b7-8ea0e843bdf1",-1707922219),$APP.$cljs$cst$2675$family$$,"Federant",$APP.$cljs$cst$725$name$$,"Federant",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/federant/v31/2sDdZGNfip_eirT0_U0jRUG0AqUc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-federo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("75f5fb5f-2e55-4dc9-8371-f1e376e637e5",1655869825),$APP.$cljs$cst$2675$family$$,
"Federo",$APP.$cljs$cst$725$name$$,"Federo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/federo/v20/iJWFBX-cbD_ETsbmjVOe2WTG7Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-felipa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0dbac069-164c-4f91-b634-8c7b981fec09",1413256599),$APP.$cljs$cst$2675$family$$,"Felipa",$APP.$cljs$cst$725$name$$,"Felipa",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/felipa/v27/FwZa7-owz1Eu4F_wSNSEwM2zpA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fenix",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a2139b12-d017-44f3-82aa-82cab26f96a0",-1063578667),$APP.$cljs$cst$2675$family$$,"Fenix",$APP.$cljs$cst$725$name$$,"Fenix",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fenix/v21/XoHo2YL_S7-g5ostKzAFvs8o.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-festive",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bbfeccf1-b2f7-4394-b6e9-53cf248f1a83",-670269319),$APP.$cljs$cst$2675$family$$,
"Festive",$APP.$cljs$cst$725$name$$,"Festive",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/festive/v11/cY9Ffj6KX1xcoDWhFtfgy9HTkak.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-figtree",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d9b7e4b3-8215-43d2-b3c1-85337a84dea6",-1642179029),$APP.$cljs$cst$2675$family$$,"Figtree",$APP.$cljs$cst$725$name$$,"Figtree",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/figtree/v9/_Xmz-HUzqDCFdgfMsYiV_F7wfS-Bs_chQF5ewkEU4HTy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/figtree/v9/_Xmz-HUzqDCFdgfMsYiV_F7wfS-Bs_d_QF5ewkEU4HTy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/figtree/v9/_Xmz-HUzqDCFdgfMsYiV_F7wfS-Bs_dNQF5ewkEU4HTy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/figtree/v9/_Xmz-HUzqDCFdgfMsYiV_F7wfS-Bs_ehR15ewkEU4HTy.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/figtree/v9/_Xmz-HUzqDCFdgfMsYiV_F7wfS-Bs_eYR15ewkEU4HTy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/figtree/v9/_Xmz-HUzqDCFdgfMsYiV_F7wfS-Bs_f_R15ewkEU4HTy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/figtree/v9/_Xmz-HUzqDCFdgfMsYiV_F7wfS-Bs_fWR15ewkEU4HTy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,
"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/figtree/v9/_Xm9-HUzqDCFdgfMm4GnA4aZFrUvtOK3A-gdyEU25WTybO8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/figtree/v9/_Xm9-HUzqDCFdgfMm4GnA4aZFrUvtOK3A7YdyEU25WTybO8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/figtree/v9/_Xm9-HUzqDCFdgfMm4GnA4aZFrUvtOK3A4QdyEU25WTybO8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/figtree/v9/_Xm9-HUzqDCFdgfMm4GnA4aZFrUvtOK3A2gayEU25WTybO8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/figtree/v9/_Xm9-HUzqDCFdgfMm4GnA4aZFrUvtOK3A1EayEU25WTybO8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/figtree/v9/_Xm9-HUzqDCFdgfMm4GnA4aZFrUvtOK3AzYayEU25WTybO8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/figtree/v9/_Xm9-HUzqDCFdgfMm4GnA4aZFrUvtOK3Ax8ayEU25WTybO8.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-finger-paint",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1579aeef-0083-4a78-8509-3d4d4720cad1",-543958280),$APP.$cljs$cst$2675$family$$,"Finger Paint",$APP.$cljs$cst$725$name$$,"Finger Paint",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fingerpaint/v21/0QInMXVJ-o-oRn_7dron8YWO85bS8ANesw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-finlandica",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d037dbcf-3155-42ba-b476-db2630d8f570",-570671212),$APP.$cljs$cst$2675$family$$,"Finlandica",$APP.$cljs$cst$725$name$$,"Finlandica",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/finlandica/v10/-nFsOGk-8vAc7lEtg0aSyZCty9GSsPBE19A7rEjx9i5ss3a3.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/finlandica/v10/-nFsOGk-8vAc7lEtg0aSyZCty9GSsPBE19AJrEjx9i5ss3a3.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/finlandica/v10/-nFsOGk-8vAc7lEtg0aSyZCty9GSsPBE19Dlq0jx9i5ss3a3.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/finlandica/v10/-nFsOGk-8vAc7lEtg0aSyZCty9GSsPBE19Dcq0jx9i5ss3a3.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/finlandica/v10/-nFuOGk-8vAc7lEtg0aS45mfNAn722rq0MXz76Cy_CpOtma3uNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/finlandica/v10/-nFuOGk-8vAc7lEtg0aS45mfNAn722rq0MXz75Ky_CpOtma3uNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/finlandica/v10/-nFuOGk-8vAc7lEtg0aS45mfNAn722rq0MXz7361_CpOtma3uNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/finlandica/v10/-nFuOGk-8vAc7lEtg0aS45mfNAn722rq0MXz70e1_CpOtma3uNQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fira-code",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e67960c9-1cb9-4a68-91ba-60bc7ef39d9c",-1713908875),$APP.$cljs$cst$2675$family$$,"Fira Code",$APP.$cljs$cst$725$name$$,"Fira Code",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firacode/v27/uU9eCBsR6Z2vfE9aq3bL0fxyUs4tcw4W_GNsFVfxN87gsj0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/firacode/v27/uU9eCBsR6Z2vfE9aq3bL0fxyUs4tcw4W_D1sFVfxN87gsj0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firacode/v27/uU9eCBsR6Z2vfE9aq3bL0fxyUs4tcw4W_A9sFVfxN87gsj0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firacode/v27/uU9eCBsR6Z2vfE9aq3bL0fxyUs4tcw4W_ONrFVfxN87gsj0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firacode/v27/uU9eCBsR6Z2vfE9aq3bL0fxyUs4tcw4W_NprFVfxN87gsj0.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fira-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b1ddea53-942a-45a8-a45e-7de1e1a1effe",1898920065),$APP.$cljs$cst$2675$family$$,"Fira Mono",$APP.$cljs$cst$725$name$$,"Fira Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firamono/v16/N0bX2SlFPv1weGeLZDtQIfTTkdbJYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firamono/v16/N0bS2SlFPv1weGeLZDto1d33mf3VaZBRBQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firamono/v16/N0bS2SlFPv1weGeLZDtondv3mf3VaZBRBQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fira-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("526b71cf-2308-4ae7-9a42-6ce1a59f3470",-1278093834),$APP.$cljs$cst$2675$family$$,"Fira Sans",$APP.$cljs$cst$725$name$$,
"Fira Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9C4kDNxMZdWfMOD5Vn9IjOazP3dUTP.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9A4kDNxMZdWfMOD5VvkrCqYTfVcFTPj0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9B4kDNxMZdWfMOD5VnWKnuQR37fF3Wlg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9f4kDNxMZdWfMOD5VvkrAGQBf_XljGllLX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9B4kDNxMZdWfMOD5VnPKruQR37fF3Wlg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9f4kDNxMZdWfMOD5VvkrBiQxf_XljGllLX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9E4kDNxMZdWfMOD5VfkILKSTbndQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9C4kDNxMZdWfMOD5VvkojOazP3dUTP.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9B4kDNxMZdWfMOD5VnZKvuQR37fF3Wlg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/firasans/v18/va9f4kDNxMZdWfMOD5VvkrA6Qhf_XljGllLX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9B4kDNxMZdWfMOD5VnSKzuQR37fF3Wlg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",
$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9f4kDNxMZdWfMOD5VvkrAWRRf_XljGllLX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9B4kDNxMZdWfMOD5VnLK3uQR37fF3Wlg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9f4kDNxMZdWfMOD5VvkrByRBf_XljGllLX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9B4kDNxMZdWfMOD5VnMK7uQR37fF3Wlg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9f4kDNxMZdWfMOD5VvkrBuRxf_XljGllLX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9B4kDNxMZdWfMOD5VnFK_uQR37fF3Wlg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasans/v18/va9f4kDNxMZdWfMOD5VvkrBKRhf_XljGllLX.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-fira-sans-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1650fcdc-ca98-42e9-82c3-362e3931e054",-1213802934),$APP.$cljs$cst$2675$family$$,"Fira Sans Condensed",$APP.$cljs$cst$725$name$$,"Fira Sans Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOjEADFm8hSaQTFG18FErVhsC9x-tarWZXtqOlQfx9CjA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOtEADFm8hSaQTFG18FErVhsC9x-tarUfPVzONUXRpSjJcu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOsEADFm8hSaQTFG18FErVhsC9x-tarWTnMiMN-cxZblY4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOuEADFm8hSaQTFG18FErVhsC9x-tarUfPVYMJ0dzRehY43EA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOsEADFm8hSaQTFG18FErVhsC9x-tarWV3PiMN-cxZblY4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOuEADFm8hSaQTFG18FErVhsC9x-tarUfPVBMF0dzRehY43EA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOhEADFm8hSaQTFG18FErVhsC9x-tarYfHnrMtVbx8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOjEADFm8hSaQTFG18FErVhsC9x-tarUfPtqOlQfx9CjA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOsEADFm8hSaQTFG18FErVhsC9x-tarWQXOiMN-cxZblY4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOuEADFm8hSaQTFG18FErVhsC9x-tarUfPVXMB0dzRehY43EA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOsEADFm8hSaQTFG18FErVhsC9x-tarWSnJiMN-cxZblY4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOuEADFm8hSaQTFG18FErVhsC9x-tarUfPVcMd0dzRehY43EA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOsEADFm8hSaQTFG18FErVhsC9x-tarWU3IiMN-cxZblY4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOuEADFm8hSaQTFG18FErVhsC9x-tarUfPVFMZ0dzRehY43EA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOsEADFm8hSaQTFG18FErVhsC9x-tarWVHLiMN-cxZblY4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOuEADFm8hSaQTFG18FErVhsC9x-tarUfPVCMV0dzRehY43EA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOsEADFm8hSaQTFG18FErVhsC9x-tarWXXKiMN-cxZblY4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasanscondensed/v11/wEOuEADFm8hSaQTFG18FErVhsC9x-tarUfPVLMR0dzRehY43EA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fira-sans-extra-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f16df08a-b9d6-4042-95c5-332cfa8d815f",1689742864),
$APP.$cljs$cst$2675$family$$,"Fira Sans Extra Condensed",$APP.$cljs$cst$725$name$$,"Fira Sans Extra Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPMcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda3Zyuv1WarE9ncg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPOcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda1fqW21-ejkp3cn22.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPPcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda3TCPn3-0oEZ-a2Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPxcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda1fqWd36-pGR7e2SvJQ.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPPcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda3VSMn3-0oEZ-a2Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPxcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda1fqWE32-pGR7e2SvJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPKcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda5fiku3efvE8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPMcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda1fquv1WarE9ncg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPPcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda3QyNn3-0oEZ-a2Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPxcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda1fqWS3y-pGR7e2SvJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPPcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda3SCKn3-0oEZ-a2Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPxcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda1fqWZ3u-pGR7e2SvJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPPcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda3USLn3-0oEZ-a2Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPxcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda1fqWA3q-pGR7e2SvJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPPcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda3ViIn3-0oEZ-a2Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPxcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda1fqWH3m-pGR7e2SvJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPPcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda3XyJn3-0oEZ-a2Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/firasansextracondensed/v11/NaPxcYDaAO5dirw6IaFn7lPJFqXmS-M9Atn3wgda1fqWO3i-pGR7e2SvJQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fjalla-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("54e93022-aaa1-4f96-a86a-2cf660bc9f10",-2143019819),$APP.$cljs$cst$2675$family$$,"Fjalla One",$APP.$cljs$cst$725$name$$,"Fjalla One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fjallaone/v16/Yq6R-LCAWCX3-6Ky7FAFnOZwkxgtUb8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fjord-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("877df89c-e15b-4757-9355-948e9bd46f83",616290183),$APP.$cljs$cst$2675$family$$,
"Fjord One",$APP.$cljs$cst$725$name$$,"Fjord One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fjordone/v22/zOL-4pbEnKBY_9S1jNKr6e5As-FeiQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-flamenco",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("51c36c46-b97f-408d-8d6b-339a20fc64ab",-197259080),$APP.$cljs$cst$2675$family$$,"Flamenco",$APP.$cljs$cst$725$name$$,"Flamenco",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/flamenco/v19/neIPzCehqYguo67ssZ0qNIkyepH9qGsf.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/flamenco/v19/neIIzCehqYguo67ssaWGHK06UY30.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-flavors",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ba40b4c8-8bc8-4cd8-945f-a0bcd5d1d153",-985370662),$APP.$cljs$cst$2675$family$$,"Flavors",$APP.$cljs$cst$725$name$$,"Flavors",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/flavors/v28/FBV2dDrhxqmveJTpbkzlNqkG9UY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fleur-de-leah",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("05937660-2c6f-4709-b02c-694fb75ea8f0",1686004634),$APP.$cljs$cst$2675$family$$,"Fleur De Leah",$APP.$cljs$cst$725$name$$,"Fleur De Leah",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fleurdeleah/v11/AYCNpXX7ftYZWLhv9UmPJTMC5vat4I_Gdq0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-flow-block",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ca9e97cd-a5cd-4039-a9a2-3d2383761bbf",1520181223),$APP.$cljs$cst$2675$family$$,"Flow Block",
$APP.$cljs$cst$725$name$$,"Flow Block",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/flowblock/v15/wlp0gwfPCEB65UmTk-d6-WZlbCBXE_I.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-flow-circular",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f7f9bd1f-6c3a-4f41-b179-275f3d19b1af",-1643584667),$APP.$cljs$cst$2675$family$$,"Flow Circular",$APP.$cljs$cst$725$name$$,"Flow Circular",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/flowcircular/v15/lJwB-pc4j2F-H8YKuyvfxdZ45ifpWdr2rIg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-flow-rounded",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d1f3838e-b242-4c2b-aafa-038c55e8f6a3",-482759559),$APP.$cljs$cst$2675$family$$,"Flow Rounded",$APP.$cljs$cst$725$name$$,"Flow Rounded",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/flowrounded/v15/-zki91mtwsU9qlLiGwD4oQX3oZX-Xup87g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-foldit",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("67baa6b3-258d-4982-8095-e5cca626428f",
-1497369746),$APP.$cljs$cst$2675$family$$,"Foldit",$APP.$cljs$cst$725$name$$,"Foldit",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/foldit/v8/aFTI7PF3Y3c9WdjNrRVE0Rk2b7j8XpANmapUYLHkN80.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/foldit/v8/aFTI7PF3Y3c9WdjNrRVE0Rk2b7j8XhAMmapUYLHkN80.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/foldit/v8/aFTI7PF3Y3c9WdjNrRVE0Rk2b7j8Xs4MmapUYLHkN80.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/foldit/v8/aFTI7PF3Y3c9WdjNrRVE0Rk2b7j8XpAMmapUYLHkN80.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/foldit/v8/aFTI7PF3Y3c9WdjNrRVE0Rk2b7j8XqIMmapUYLHkN80.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/foldit/v8/aFTI7PF3Y3c9WdjNrRVE0Rk2b7j8Xk4LmapUYLHkN80.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/foldit/v8/aFTI7PF3Y3c9WdjNrRVE0Rk2b7j8XncLmapUYLHkN80.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/foldit/v8/aFTI7PF3Y3c9WdjNrRVE0Rk2b7j8XhALmapUYLHkN80.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/foldit/v8/aFTI7PF3Y3c9WdjNrRVE0Rk2b7j8XjkLmapUYLHkN80.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fondamento",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("83e67ae5-fe34-4cd4-b265-18fe6712c681",-669659258),$APP.$cljs$cst$2675$family$$,"Fondamento",$APP.$cljs$cst$725$name$$,"Fondamento",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/fondamento/v22/4UaHrEJGsxNmFTPDnkaJx63j5pN1MwI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fondamento/v22/4UaFrEJGsxNmFTPDnkaJ96_p4rFwIwJePw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fontdiner-swanky",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b6b0f388-1de9-4d0a-99c4-9eae4bb39175",895710929),$APP.$cljs$cst$2675$family$$,"Fontdiner Swanky",$APP.$cljs$cst$725$name$$,"Fontdiner Swanky",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/fontdinerswanky/v24/ijwOs4XgRNsiaI5-hcVb4hQgMvCD4uEfKiGvxts.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-forum",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a488c7c9-3c0c-4f83-8713-949042ef7647",-1942900155),$APP.$cljs$cst$2675$family$$,"Forum",$APP.$cljs$cst$725$name$$,"Forum",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/forum/v19/6aey4Ky-Vb8Ew_IWMJMa3mnT.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fragment-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9ca344b5-4fc8-4205-815a-2322def57db4",-781408866),$APP.$cljs$cst$2675$family$$,"Fragment Mono",$APP.$cljs$cst$725$name$$,
"Fragment Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fragmentmono/v6/4iCr6K5wfMRRjxp0DA6-2CLnN4RNh4UI_1U.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fragmentmono/v6/4iC16K5wfMRRjxp0DA6-2CLnB4ZHg6cN71URtQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-francois-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2b549f4f-5dc0-4a55-b394-41f8e3a9ac33",-2056013113),$APP.$cljs$cst$2675$family$$,"Francois One",$APP.$cljs$cst$725$name$$,
"Francois One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/francoisone/v22/_Xmr-H4zszafZw3A-KPSZutNxgKQu_avAg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-frank-ruhl-libre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e6d76dce-e97b-4909-8b88-9fe0a1633816",-1960391917),$APP.$cljs$cst$2675$family$$,"Frank Ruhl Libre",$APP.$cljs$cst$725$name$$,"Frank Ruhl Libre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/frankruhllibre/v23/j8_96_fAw7jrcalD7oKYNX0QfAnPcbzNEEB7OoicBw6bYVqQPxR2EUR_.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/frankruhllibre/v23/j8_96_fAw7jrcalD7oKYNX0QfAnPcbzNEEB7OoicBw7FYVqQPxR2EUR_.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/frankruhllibre/v23/j8_96_fAw7jrcalD7oKYNX0QfAnPcbzNEEB7OoicBw73YVqQPxR2EUR_.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/frankruhllibre/v23/j8_96_fAw7jrcalD7oKYNX0QfAnPcbzNEEB7OoicBw4bZlqQPxR2EUR_.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/frankruhllibre/v23/j8_96_fAw7jrcalD7oKYNX0QfAnPcbzNEEB7OoicBw4iZlqQPxR2EUR_.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/frankruhllibre/v23/j8_96_fAw7jrcalD7oKYNX0QfAnPcbzNEEB7OoicBw5FZlqQPxR2EUR_.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/frankruhllibre/v23/j8_96_fAw7jrcalD7oKYNX0QfAnPcbzNEEB7OoicBw5sZlqQPxR2EUR_.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fraunces",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ea1ac2dd-69b6-4e5c-9403-5e2ac96aeaca",-1841359754),$APP.$cljs$cst$2675$family$$,"Fraunces",$APP.$cljs$cst$725$name$$,"Fraunces",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NUh8FyLNQOQZAnv9bYEvDiIdE9Ea92uemAk_WBq8U_9v0c2Wa0K7iN7hzFUPJH58nib1603gg7S2nfgRYIctxqjDvTShUtWNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NUh8FyLNQOQZAnv9bYEvDiIdE9Ea92uemAk_WBq8U_9v0c2Wa0K7iN7hzFUPJH58nib1603gg7S2nfgRYIcNxujDvTShUtWNg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NUh8FyLNQOQZAnv9bYEvDiIdE9Ea92uemAk_WBq8U_9v0c2Wa0K7iN7hzFUPJH58nib1603gg7S2nfgRYIc6RujDvTShUtWNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NUh8FyLNQOQZAnv9bYEvDiIdE9Ea92uemAk_WBq8U_9v0c2Wa0K7iN7hzFUPJH58nib1603gg7S2nfgRYIctxujDvTShUtWNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NUh8FyLNQOQZAnv9bYEvDiIdE9Ea92uemAk_WBq8U_9v0c2Wa0K7iN7hzFUPJH58nib1603gg7S2nfgRYIchRujDvTShUtWNg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NUh8FyLNQOQZAnv9bYEvDiIdE9Ea92uemAk_WBq8U_9v0c2Wa0K7iN7hzFUPJH58nib1603gg7S2nfgRYIcaRyjDvTShUtWNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NUh8FyLNQOQZAnv9bYEvDiIdE9Ea92uemAk_WBq8U_9v0c2Wa0K7iN7hzFUPJH58nib1603gg7S2nfgRYIcUByjDvTShUtWNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NUh8FyLNQOQZAnv9bYEvDiIdE9Ea92uemAk_WBq8U_9v0c2Wa0K7iN7hzFUPJH58nib1603gg7S2nfgRYIcNxyjDvTShUtWNg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NUh8FyLNQOQZAnv9bYEvDiIdE9Ea92uemAk_WBq8U_9v0c2Wa0K7iN7hzFUPJH58nib1603gg7S2nfgRYIcHhyjDvTShUtWNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NVf8FyLNQOQZAnv9ZwNjucMHVn85Ni7emAe9lKqZTnbB-gzTK0K1ChJdt9vIVYX9G37lvd9sPEKsxx664UJf1hLTP7Wp05GNi3k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NVf8FyLNQOQZAnv9ZwNjucMHVn85Ni7emAe9lKqZTnbB-gzTK0K1ChJdt9vIVYX9G37lvd9sPEKsxx664UJf1jLTf7Wp05GNi3k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NVf8FyLNQOQZAnv9ZwNjucMHVn85Ni7emAe9lKqZTnbB-gzTK0K1ChJdt9vIVYX9G37lvd9sPEKsxx664UJf1gVTf7Wp05GNi3k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NVf8FyLNQOQZAnv9ZwNjucMHVn85Ni7emAe9lKqZTnbB-gzTK0K1ChJdt9vIVYX9G37lvd9sPEKsxx664UJf1hLTf7Wp05GNi3k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NVf8FyLNQOQZAnv9ZwNjucMHVn85Ni7emAe9lKqZTnbB-gzTK0K1ChJdt9vIVYX9G37lvd9sPEKsxx664UJf1h5Tf7Wp05GNi3k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NVf8FyLNQOQZAnv9ZwNjucMHVn85Ni7emAe9lKqZTnbB-gzTK0K1ChJdt9vIVYX9G37lvd9sPEKsxx664UJf1iVSv7Wp05GNi3k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",
$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NVf8FyLNQOQZAnv9ZwNjucMHVn85Ni7emAe9lKqZTnbB-gzTK0K1ChJdt9vIVYX9G37lvd9sPEKsxx664UJf1isSv7Wp05GNi3k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NVf8FyLNQOQZAnv9ZwNjucMHVn85Ni7emAe9lKqZTnbB-gzTK0K1ChJdt9vIVYX9G37lvd9sPEKsxx664UJf1jLSv7Wp05GNi3k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fraunces/v38/6NVf8FyLNQOQZAnv9ZwNjucMHVn85Ni7emAe9lKqZTnbB-gzTK0K1ChJdt9vIVYX9G37lvd9sPEKsxx664UJf1jiSv7Wp05GNi3k.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-freckle-face",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("676d8893-8f75-42ab-a0cb-ce1e38f6d74b",-1198148286),$APP.$cljs$cst$2675$family$$,"Freckle Face",$APP.$cljs$cst$725$name$$,"Freckle Face",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/freckleface/v16/AMOWz4SXrmKHCvXTohxY-YI0U1K2w9lb4g.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fredericka-the-great",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("60be9bcd-3465-4ef4-b016-eec729311ad9",-289405680),$APP.$cljs$cst$2675$family$$,"Fredericka the Great",$APP.$cljs$cst$725$name$$,"Fredericka the Great",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/frederickathegreat/v23/9Bt33CxNwt7aOctW2xjbCstzwVKsIBVV-9Skz7Ylch2L.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fredoka",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f56d76ad-a335-45c0-a732-b820c5e09715",84093565),$APP.$cljs$cst$2675$family$$,"Fredoka",$APP.$cljs$cst$725$name$$,
"Fredoka",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fredoka/v17/X7nP4b87HvSqjb_WIi2yDCRwoQ_k7367_B-i2yQag0-mac3OryLMFuOLlNldbw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fredoka/v17/X7nP4b87HvSqjb_WIi2yDCRwoQ_k7367_B-i2yQag0-mac3O8SLMFuOLlNldbw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fredoka/v17/X7nP4b87HvSqjb_WIi2yDCRwoQ_k7367_B-i2yQag0-mac3OwyLMFuOLlNldbw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fredoka/v17/X7nP4b87HvSqjb_WIi2yDCRwoQ_k7367_B-i2yQag0-mac3OLyXMFuOLlNldbw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fredoka/v17/X7nP4b87HvSqjb_WIi2yDCRwoQ_k7367_B-i2yQag0-mac3OFiXMFuOLlNldbw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-freehand",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bbe20730-1b5a-4d7e-9107-e6e4df820112",-167756285),$APP.$cljs$cst$2675$family$$,"Freehand",$APP.$cljs$cst$725$name$$,"Freehand",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/freehand/v34/cIf-Ma5eqk01VjKTgAmBTmUOmZJk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-freeman",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c6f7582b-ad8a-422c-85f3-6ec1274427d5",
-434687217),$APP.$cljs$cst$2675$family$$,"Freeman",$APP.$cljs$cst$725$name$$,"Freeman",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/freeman/v1/S6u9w4NGQiLN8nh-ew-FGC_p9dw.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fresca",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b50bf4f4-3e3e-4679-98e0-5b002102930d",765548290),$APP.$cljs$cst$2675$family$$,"Fresca",$APP.$cljs$cst$725$name$$,"Fresca",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fresca/v24/6ae94K--SKgCzbM2Gr0W13DKPA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-frijole",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("47c99553-18a2-4457-9b62-43290cc4ca23",-1367398664),$APP.$cljs$cst$2675$family$$,"Frijole",$APP.$cljs$cst$725$name$$,"Frijole",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/frijole/v15/uU9PCBUR8oakM2BQ7xPb3vyHmlI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fruktur",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("58f54190-5f8d-442f-aae6-2809d3f366e1",
356533136),$APP.$cljs$cst$2675$family$$,"Fruktur",$APP.$cljs$cst$725$name$$,"Fruktur",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fruktur/v28/SZc53FHsOru5QYsMfz3GkUrS8DI.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fruktur/v28/SZc73FHsOru5QYsMTz_MlWjX4DJXgQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fugaz-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2e1269c0-3e18-45e1-924b-bfcd8606079d",-1416515587),
$APP.$cljs$cst$2675$family$$,"Fugaz One",$APP.$cljs$cst$725$name$$,"Fugaz One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fugazone/v21/rax_HiWKp9EAITukFslMBBJek0vA8A.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fuggles",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("814ea131-4197-419d-9b2c-213e53ff34ca",-1017439401),$APP.$cljs$cst$2675$family$$,"Fuggles",$APP.$cljs$cst$725$name$$,"Fuggles",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fuggles/v14/k3kQo8UEJOlD1hpOTd7iL0nAMaM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-funnel-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1aa0a09f-b5db-4824-bdef-343844b2271d",494157466),$APP.$cljs$cst$2675$family$$,"Funnel Display",$APP.$cljs$cst$725$name$$,"Funnel Display",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funneldisplay/v3/B50bF7FGv37QNVWgE0ga--4PbZSRJXrOHcLHLoAYxGPXWMVwIZDKFA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funneldisplay/v3/B50bF7FGv37QNVWgE0ga--4PbZSRJXrOHcLHLoAYmmPXWMVwIZDKFA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funneldisplay/v3/B50bF7FGv37QNVWgE0ga--4PbZSRJXrOHcLHLoAYqGPXWMVwIZDKFA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funneldisplay/v3/B50bF7FGv37QNVWgE0ga--4PbZSRJXrOHcLHLoAYRGTXWMVwIZDKFA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funneldisplay/v3/B50bF7FGv37QNVWgE0ga--4PbZSRJXrOHcLHLoAYfWTXWMVwIZDKFA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funneldisplay/v3/B50bF7FGv37QNVWgE0ga--4PbZSRJXrOHcLHLoAYGmTXWMVwIZDKFA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-funnel-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("11511cd9-43a5-4958-b654-7345f0afb9b9",1641676663),$APP.$cljs$cst$2675$family$$,"Funnel Sans",$APP.$cljs$cst$725$name$$,"Funnel Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funnelsans/v3/OpNfno8Dg9bX6Bsp3Wq69RB-VukSVv3aISFAy3mEfm9NnDyL7w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funnelsans/v3/OpNfno8Dg9bX6Bsp3Wq69RB-VukSVv3aISFAlXmEfm9NnDyL7w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funnelsans/v3/OpNfno8Dg9bX6Bsp3Wq69RB-VukSVv3aISFAp3mEfm9NnDyL7w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funnelsans/v3/OpNfno8Dg9bX6Bsp3Wq69RB-VukSVv3aISFAS36Efm9NnDyL7w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funnelsans/v3/OpNfno8Dg9bX6Bsp3Wq69RB-VukSVv3aISFAcn6Efm9NnDyL7w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funnelsans/v3/OpNfno8Dg9bX6Bsp3Wq69RB-VukSVv3aISFAFX6Efm9NnDyL7w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funnelsans/v3/OpNZno8Dg9bX6Bsp3Wq69Tp3ZBbKP5ZAjyZVXToyPWVJvjmb76XZ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funnelsans/v3/OpNZno8Dg9bX6Bsp3Wq69Tp3ZBbKP5ZAjyZVXTpsPWVJvjmb76XZ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/funnelsans/v3/OpNZno8Dg9bX6Bsp3Wq69Tp3ZBbKP5ZAjyZVXTpePWVJvjmb76XZ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funnelsans/v3/OpNZno8Dg9bX6Bsp3Wq69Tp3ZBbKP5ZAjyZVXTqyOmVJvjmb76XZ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funnelsans/v3/OpNZno8Dg9bX6Bsp3Wq69Tp3ZBbKP5ZAjyZVXTqLOmVJvjmb76XZ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/funnelsans/v3/OpNZno8Dg9bX6Bsp3Wq69Tp3ZBbKP5ZAjyZVXTrsOmVJvjmb76XZ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fustat",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6444535e-05ee-4d8a-be12-426c59f810ee",-359437207),$APP.$cljs$cst$2675$family$$,"Fustat",$APP.$cljs$cst$725$name$$,"Fustat",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fustat/v4/NaPEcZ_aHO9Iy5thRNqze7YGY9HGCMQQRryztWo_3fk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fustat/v4/NaPEcZ_aHO9Iy5thRNqze7YGY9HGCBoQRryztWo_3fk.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fustat/v4/NaPEcZ_aHO9Iy5thRNqze7YGY9HGCEQQRryztWo_3fk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/fustat/v4/NaPEcZ_aHO9Iy5thRNqze7YGY9HGCHYQRryztWo_3fk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fustat/v4/NaPEcZ_aHO9Iy5thRNqze7YGY9HGCJoXRryztWo_3fk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fustat/v4/NaPEcZ_aHO9Iy5thRNqze7YGY9HGCKMXRryztWo_3fk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fustat/v4/NaPEcZ_aHO9Iy5thRNqze7YGY9HGCMQXRryztWo_3fk.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-fuzzy-bubbles",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("eee08467-db95-495a-8fde-f291a6e33510",-179162480),$APP.$cljs$cst$2675$family$$,"Fuzzy Bubbles",$APP.$cljs$cst$725$name$$,"Fuzzy Bubbles",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fuzzybubbles/v9/6qLGKZMbrgv9pwtjPEVNV0F2NnP5Zxsreko.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/fuzzybubbles/v9/6qLbKZMbrgv9pwtjPEVNV0F2Ds_WQxMAZkM1pn4.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gfs-didot",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d77f0191-6a04-43a8-80cd-df0da03727ef",43312796),$APP.$cljs$cst$2675$family$$,"GFS Didot",$APP.$cljs$cst$725$name$$,"GFS Didot",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gfsdidot/v18/Jqzh5TybZ9vZMWFssvwiF-fGFSCGAA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gfs-neohellenic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a4931aa5-62c5-4dcc-b29d-12de988ca91f",239580752),$APP.$cljs$cst$2675$family$$,"GFS Neohellenic",$APP.$cljs$cst$725$name$$,"GFS Neohellenic",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gfsneohellenic/v27/8QIRdiDOrfiq0b7R8O1Iw9WLcY5TLahP46UDUw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,
"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gfsneohellenic/v27/8QITdiDOrfiq0b7R8O1Iw9WLcY5jL6JLwaATU91X.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gfsneohellenic/v27/8QIUdiDOrfiq0b7R8O1Iw9WLcY5rkYdr644fWsRO9w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gfsneohellenic/v27/8QIWdiDOrfiq0b7R8O1Iw9WLcY5jL5r37oQbeMFe985V.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ga-maamli",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a393ec7c-6d06-4201-a132-f9f34fa23724",
801239746),$APP.$cljs$cst$2675$family$$,"Ga Maamli",$APP.$cljs$cst$725$name$$,"Ga Maamli",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gamaamli/v3/uU9NCBsQ4c-DPW1Yo3rR2t6CilKOdQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gabarito",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c7d28606-c319-46fd-bc82-9d956dda1fe5",1361244241),$APP.$cljs$cst$2675$family$$,"Gabarito",$APP.$cljs$cst$725$name$$,"Gabarito",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gabarito/v9/QGYwz_0dZAGKJJ4t3FFkc3Q8AkNP9Pj248K0FgItq6bFIg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gabarito/v9/QGYwz_0dZAGKJJ4t3FFkc3Q8AkNP9Pj20cK0FgItq6bFIg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gabarito/v9/QGYwz_0dZAGKJJ4t3FFkc3Q8AkNP9Pj2PcW0FgItq6bFIg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/gabarito/v9/QGYwz_0dZAGKJJ4t3FFkc3Q8AkNP9Pj2BMW0FgItq6bFIg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gabarito/v9/QGYwz_0dZAGKJJ4t3FFkc3Q8AkNP9Pj2Y8W0FgItq6bFIg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,
"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gabarito/v9/QGYwz_0dZAGKJJ4t3FFkc3Q8AkNP9Pj2SsW0FgItq6bFIg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gabriela",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("283d4c5a-0a70-465b-b37d-27a11e0ea5bd",-1777047489),$APP.$cljs$cst$2675$family$$,"Gabriela",$APP.$cljs$cst$725$name$$,"Gabriela",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gabriela/v23/qkBWXvsO6sreR8E-b_m-zrpHmRzC.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gaegu",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("b2a4addd-dfbb-4000-8c8e-141c9b87e283",-764066453),$APP.$cljs$cst$2675$family$$,"Gaegu",$APP.$cljs$cst$725$name$$,"Gaegu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gaegu/v23/TuGSUVB6Up9NU57nifw74sdtBk0x.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gaegu/v23/TuGfUVB6Up9NU6ZLodgzydtk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/gaegu/v23/TuGSUVB6Up9NU573jvw74sdtBk0x.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gafata",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5dc33a5a-de02-40d3-9876-26e278f8eb9f",-942857540),$APP.$cljs$cst$2675$family$$,"Gafata",$APP.$cljs$cst$725$name$$,"Gafata",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gafata/v22/XRXV3I6Cn0VJKon4MuyAbsrVcA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gajraj-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("18dafeae-86fd-4ec9-9e44-293f0892f8ab",154095823),$APP.$cljs$cst$2675$family$$,"Gajraj One",$APP.$cljs$cst$725$name$$,
"Gajraj One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gajrajone/v7/1cX2aUDCDpXsuWVb1jIjr1GqhcitzeM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-galada",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("78dec822-9288-4836-b203-1df359df377a",191571047),$APP.$cljs$cst$2675$family$$,"Galada",$APP.$cljs$cst$725$name$$,"Galada",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/galada/v21/H4cmBXyGmcjXlUX-8iw-4Lqggw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-galdeano",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("89eb0f65-bb31-4294-a896-da0ea313fa1d",1055564500),$APP.$cljs$cst$2675$family$$,"Galdeano",$APP.$cljs$cst$725$name$$,"Galdeano",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/galdeano/v23/uU9MCBoQ4YOqOW1boDPx8PCOg0uX.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-galindo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f5406917-1f0b-4e47-9270-9c1b1dbfaf70",-1345588578),$APP.$cljs$cst$2675$family$$,"Galindo",$APP.$cljs$cst$725$name$$,
"Galindo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/galindo/v26/HI_KiYMeLqVKqwyuQ5HiRp-dhpQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-gamja-flower",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c1352af3-08fa-4576-8c43-b6eff601f882",-1535811795),$APP.$cljs$cst$2675$family$$,"Gamja Flower",$APP.$cljs$cst$725$name$$,"Gamja Flower",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gamjaflower/v26/6NUR8FiKJg-Pa0rM6uN40Z4kyf9Fdty2ew.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gantari",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("10b1e56f-8a83-4386-82b1-003dae38cc4d",-1190601929),$APP.$cljs$cst$2675$family$$,"Gantari",$APP.$cljs$cst$725$name$$,"Gantari",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyV7nvyB2HL8iZyDk4GVvSZ5MtC9g0gOz3wa5GD2qnm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/gantari/v4/jVyV7nvyB2HL8iZyDk4GVvSZ5MtC9g2gOj3wa5GD2qnm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyV7nvyB2HL8iZyDk4GVvSZ5MtC9g1-Oj3wa5GD2qnm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyV7nvyB2HL8iZyDk4GVvSZ5MtC9g0gOj3wa5GD2qnm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyV7nvyB2HL8iZyDk4GVvSZ5MtC9g0SOj3wa5GD2qnm.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyV7nvyB2HL8iZyDk4GVvSZ5MtC9g3-PT3wa5GD2qnm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/gantari/v4/jVyV7nvyB2HL8iZyDk4GVvSZ5MtC9g3HPT3wa5GD2qnm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyV7nvyB2HL8iZyDk4GVvSZ5MtC9g2gPT3wa5GD2qnm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,
"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyV7nvyB2HL8iZyDk4GVvSZ5MtC9g2JPT3wa5GD2qnm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyb7nvyB2HL8iZyJEc0qSzwj1Hs8RjoedWyYZWh37nmpWc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyb7nvyB2HL8iZyJEc0qSzwj1Hs8RjoeVWzYZWh37nmpWc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyb7nvyB2HL8iZyJEc0qSzwj1Hs8RjoeYuzYZWh37nmpWc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyb7nvyB2HL8iZyJEc0qSzwj1Hs8RjoedWzYZWh37nmpWc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyb7nvyB2HL8iZyJEc0qSzwj1Hs8RjoeeezYZWh37nmpWc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyb7nvyB2HL8iZyJEc0qSzwj1Hs8RjoeQu0YZWh37nmpWc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyb7nvyB2HL8iZyJEc0qSzwj1Hs8RjoeTK0YZWh37nmpWc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyb7nvyB2HL8iZyJEc0qSzwj1Hs8RjoeVW0YZWh37nmpWc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gantari/v4/jVyb7nvyB2HL8iZyJEc0qSzwj1Hs8RjoeXy0YZWh37nmpWc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-gasoek-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("35512cd4-8f5e-47a2-a868-96f0eb7ae7b4",1748057199),$APP.$cljs$cst$2675$family$$,"Gasoek One",$APP.$cljs$cst$725$name$$,"Gasoek One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gasoekone/v3/EJRTQgQ_UMUKvDgnlX80zrq_cyb-vco.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gayathri",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ef4e6bf9-8bfc-46b6-9a0f-1b0de08214d7",1224968197),$APP.$cljs$cst$2675$family$$,"Gayathri",$APP.$cljs$cst$725$name$$,"Gayathri",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gayathri/v20/MCoWzAb429DbBilWLLhc-pvSA_gA2W8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/gayathri/v20/MCoQzAb429DbBilWLIA48J_wBugA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gayathri/v20/MCoXzAb429DbBilWLLiE37v4LfQJwHbn.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-geist",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("48627041-8cc8-4234-94bf-f4c161fb6af9",
-467905248),$APP.$cljs$cst$2675$family$$,"Geist",$APP.$cljs$cst$725$name$$,"Geist",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geist/v4/gyBhhwUxId8gMGYQMKR3pzfaWI_RnOI4nZPby1QNtA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geist/v4/gyBhhwUxId8gMGYQMKR3pzfaWI_RHOM4nZPby1QNtA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/geist/v4/gyBhhwUxId8gMGYQMKR3pzfaWI_RwuM4nZPby1QNtA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geist/v4/gyBhhwUxId8gMGYQMKR3pzfaWI_RnOM4nZPby1QNtA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geist/v4/gyBhhwUxId8gMGYQMKR3pzfaWI_RruM4nZPby1QNtA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geist/v4/gyBhhwUxId8gMGYQMKR3pzfaWI_RQuQ4nZPby1QNtA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geist/v4/gyBhhwUxId8gMGYQMKR3pzfaWI_Re-Q4nZPby1QNtA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geist/v4/gyBhhwUxId8gMGYQMKR3pzfaWI_RHOQ4nZPby1QNtA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geist/v4/gyBhhwUxId8gMGYQMKR3pzfaWI_RNeQ4nZPby1QNtA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-geist-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("872c1186-741b-44dd-9398-01abd348f0cf",-373327383),
$APP.$cljs$cst$2675$family$$,"Geist Mono",$APP.$cljs$cst$725$name$$,"Geist Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geistmono/v4/or3yQ6H-1_WfwkMZI_qYPLs1a-t7PU0AbeE9KZ5T7ihaO_CS.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geistmono/v4/or3yQ6H-1_WfwkMZI_qYPLs1a-t7PU0AbeG9KJ5T7ihaO_CS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/geistmono/v4/or3yQ6H-1_WfwkMZI_qYPLs1a-t7PU0AbeFjKJ5T7ihaO_CS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geistmono/v4/or3yQ6H-1_WfwkMZI_qYPLs1a-t7PU0AbeE9KJ5T7ihaO_CS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geistmono/v4/or3yQ6H-1_WfwkMZI_qYPLs1a-t7PU0AbeEPKJ5T7ihaO_CS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geistmono/v4/or3yQ6H-1_WfwkMZI_qYPLs1a-t7PU0AbeHjL55T7ihaO_CS.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geistmono/v4/or3yQ6H-1_WfwkMZI_qYPLs1a-t7PU0AbeHaL55T7ihaO_CS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/geistmono/v4/or3yQ6H-1_WfwkMZI_qYPLs1a-t7PU0AbeG9L55T7ihaO_CS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geistmono/v4/or3yQ6H-1_WfwkMZI_qYPLs1a-t7PU0AbeGUL55T7ihaO_CS.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-gelasio",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b806ff3f-fd24-4967-9ca6-834cc56b79b0",-80556437),$APP.$cljs$cst$2675$family$$,"Gelasio",$APP.$cljs$cst$725$name$$,"Gelasio",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/gelasio/v14/cIfiMaFfvUQxTTqS3iKJkLGbI41wQL8Ilycs-TDO8Aba.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gelasio/v14/cIfiMaFfvUQxTTqS3iKJkLGbI41wQL86lycs-TDO8Aba.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gelasio/v14/cIfiMaFfvUQxTTqS3iKJkLGbI41wQL_WkCcs-TDO8Aba.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gelasio/v14/cIfiMaFfvUQxTTqS3iKJkLGbI41wQL_vkCcs-TDO8Aba.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gelasio/v14/cIfsMaFfvUQxTTqS9Cu7b2nySBfeR6rA1M9v8zTs9RbanYs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gelasio/v14/cIfsMaFfvUQxTTqS9Cu7b2nySBfeR6rA1P1v8zTs9RbanYs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gelasio/v14/cIfsMaFfvUQxTTqS9Cu7b2nySBfeR6rA1BFo8zTs9RbanYs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gelasio/v14/cIfsMaFfvUQxTTqS9Cu7b2nySBfeR6rA1Cho8zTs9RbanYs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gemunu-libre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9310daff-6029-4732-8f94-5cc6002ad642",1426491935),$APP.$cljs$cst$2675$family$$,
"Gemunu Libre",$APP.$cljs$cst$725$name$$,"Gemunu Libre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gemunulibre/v18/X7n34bQ6Cfy7jKGXVE_YlqnbEQAFP-PIuTCp05iJPvSLeMXPIWA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gemunulibre/v18/X7n34bQ6Cfy7jKGXVE_YlqnbEQAFP-PIuTCp00aJPvSLeMXPIWA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gemunulibre/v18/X7n34bQ6Cfy7jKGXVE_YlqnbEQAFP-PIuTCp0xiJPvSLeMXPIWA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gemunulibre/v18/X7n34bQ6Cfy7jKGXVE_YlqnbEQAFP-PIuTCp0yqJPvSLeMXPIWA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gemunulibre/v18/X7n34bQ6Cfy7jKGXVE_YlqnbEQAFP-PIuTCp08aOPvSLeMXPIWA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gemunulibre/v18/X7n34bQ6Cfy7jKGXVE_YlqnbEQAFP-PIuTCp0_-OPvSLeMXPIWA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gemunulibre/v18/X7n34bQ6Cfy7jKGXVE_YlqnbEQAFP-PIuTCp05iOPvSLeMXPIWA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-genos",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("88934f0a-44a2-403c-addd-ff80773cc9a2",-1771600367),$APP.$cljs$cst$2675$family$$,"Genos",$APP.$cljs$cst$725$name$$,
"Genos",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGNmQqPqpUOYTYjacb0Hc91fTwVqknorUK6K7ZsAg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGNmQqPqpUOYTYjacb0Hc91fTwVKkjorUK6K7ZsAg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGNmQqPqpUOYTYjacb0Hc91fTwV9EjorUK6K7ZsAg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGNmQqPqpUOYTYjacb0Hc91fTwVqkjorUK6K7ZsAg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/genos/v16/SlGNmQqPqpUOYTYjacb0Hc91fTwVmEjorUK6K7ZsAg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGNmQqPqpUOYTYjacb0Hc91fTwVdE_orUK6K7ZsAg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGNmQqPqpUOYTYjacb0Hc91fTwVTU_orUK6K7ZsAg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGNmQqPqpUOYTYjacb0Hc91fTwVKk_orUK6K7ZsAg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGNmQqPqpUOYTYjacb0Hc91fTwVA0_orUK6K7ZsAg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGPmQqPqpUOYRwqWzksdKTv0zsAYgsA70i-CbN8Ard7.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGPmQqPqpUOYRwqWzksdKTv0zsAYguA7ki-CbN8Ard7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGPmQqPqpUOYRwqWzksdKTv0zsAYgte7ki-CbN8Ard7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGPmQqPqpUOYRwqWzksdKTv0zsAYgsA7ki-CbN8Ard7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGPmQqPqpUOYRwqWzksdKTv0zsAYgsy7ki-CbN8Ard7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGPmQqPqpUOYRwqWzksdKTv0zsAYgve6Ui-CbN8Ard7.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGPmQqPqpUOYRwqWzksdKTv0zsAYgvn6Ui-CbN8Ard7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGPmQqPqpUOYRwqWzksdKTv0zsAYguA6Ui-CbN8Ard7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/genos/v16/SlGPmQqPqpUOYRwqWzksdKTv0zsAYgup6Ui-CbN8Ard7.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-gentium-book-plus",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("84ca49d0-e8c7-4df4-a176-5e6edf4ba1d8",871493963),$APP.$cljs$cst$2675$family$$,"Gentium Book Plus",$APP.$cljs$cst$725$name$$,"Gentium Book Plus",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gentiumbookplus/v1/vEFL2-RHBgUK5fbjKxRpbBtJPyRpofKfdbLOrdPV.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gentiumbookplus/v1/vEFN2-RHBgUK5fbjKxRpbBtJPyRpocKdf7bsqMPVZb4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gentiumbookplus/v1/vEFO2-RHBgUK5fbjKxRpbBtJPyRpocojWpbGhs_cfKe1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gentiumbookplus/v1/vEFA2-RHBgUK5fbjKxRpbBtJPyRpocKdRwrDjMv-ebe1Els.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gentium-plus",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5205c0bd-d7ab-470f-930d-76f7dd59143b",856155244),$APP.$cljs$cst$2675$family$$,"Gentium Plus",$APP.$cljs$cst$725$name$$,"Gentium Plus",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gentiumplus/v2/Iurd6Ytw-oSPaZ00r2bNe8VpjJtM6G0t9w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gentiumplus/v2/IurD6Ytw-oSPaZ00r2bNe8VZjpFIymg9957e.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gentiumplus/v2/IurC6Ytw-oSPaZ00r2bNe8VRMLRo4EYx_ofHsw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gentiumplus/v2/IurA6Ytw-oSPaZ00r2bNe8VZjqn05Uw13ILXs-h6.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-geo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5d65112d-3a94-44eb-b178-690d774f4d0e",553943218),$APP.$cljs$cst$2675$family$$,"Geo",$APP.$cljs$cst$725$name$$,"Geo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geo/v23/CSRz4zRZlufVL3BmQjlCbQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/geo/v23/CSRx4zRZluflLXpiYDxSbf8r.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-geologica",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b67c732b-c396-4cb2-a4d8-1329f54bdfad",-1017259958),$APP.$cljs$cst$2675$family$$,"Geologica",$APP.$cljs$cst$725$name$$,"Geologica",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geologica/v5/oY1o8evIr7j9P3TN9YwNAdyjzUyDKkKdAGOJh1UlCDUIhAIdhCZOn1fLsig7jfvCCPHZckU8H3G11_z-_OZqDx_qQ-MYAXWnqFs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/geologica/v5/oY1o8evIr7j9P3TN9YwNAdyjzUyDKkKdAGOJh1UlCDUIhAIdhCZOn1fLsig7jfvCCPHZckU8H3G11_z-_OZqD5_rQ-MYAXWnqFs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geologica/v5/oY1o8evIr7j9P3TN9YwNAdyjzUyDKkKdAGOJh1UlCDUIhAIdhCZOn1fLsig7jfvCCPHZckU8H3G11_z-_OZqD0HrQ-MYAXWnqFs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geologica/v5/oY1o8evIr7j9P3TN9YwNAdyjzUyDKkKdAGOJh1UlCDUIhAIdhCZOn1fLsig7jfvCCPHZckU8H3G11_z-_OZqDx_rQ-MYAXWnqFs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geologica/v5/oY1o8evIr7j9P3TN9YwNAdyjzUyDKkKdAGOJh1UlCDUIhAIdhCZOn1fLsig7jfvCCPHZckU8H3G11_z-_OZqDy3rQ-MYAXWnqFs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geologica/v5/oY1o8evIr7j9P3TN9YwNAdyjzUyDKkKdAGOJh1UlCDUIhAIdhCZOn1fLsig7jfvCCPHZckU8H3G11_z-_OZqD8HsQ-MYAXWnqFs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geologica/v5/oY1o8evIr7j9P3TN9YwNAdyjzUyDKkKdAGOJh1UlCDUIhAIdhCZOn1fLsig7jfvCCPHZckU8H3G11_z-_OZqD_jsQ-MYAXWnqFs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,
"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geologica/v5/oY1o8evIr7j9P3TN9YwNAdyjzUyDKkKdAGOJh1UlCDUIhAIdhCZOn1fLsig7jfvCCPHZckU8H3G11_z-_OZqD5_sQ-MYAXWnqFs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geologica/v5/oY1o8evIr7j9P3TN9YwNAdyjzUyDKkKdAGOJh1UlCDUIhAIdhCZOn1fLsig7jfvCCPHZckU8H3G11_z-_OZqD7bsQ-MYAXWnqFs.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-georama",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("458ed9d9-2e30-456d-80dc-de32e86d1b89",-581765162),$APP.$cljs$cst$2675$family$$,"Georama",$APP.$cljs$cst$725$name$$,"Georama",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo5zAn438bIEyxFf6swMnNpvPcUwW4u4yRcDh-ZjxApn9K5GvktmQsL5_tgbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo5zAn438bIEyxFf6swMnNpvPcUwW4u4yRcDh-ZjxApn9K5mvgtmQsL5_tgbg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo5zAn438bIEyxFf6swMnNpvPcUwW4u4yRcDh-ZjxApn9K5RPgtmQsL5_tgbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo5zAn438bIEyxFf6swMnNpvPcUwW4u4yRcDh-ZjxApn9K5GvgtmQsL5_tgbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo5zAn438bIEyxFf6swMnNpvPcUwW4u4yRcDh-ZjxApn9K5KPgtmQsL5_tgbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo5zAn438bIEyxFf6swMnNpvPcUwW4u4yRcDh-ZjxApn9K5xP8tmQsL5_tgbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo5zAn438bIEyxFf6swMnNpvPcUwW4u4yRcDh-ZjxApn9K5_f8tmQsL5_tgbg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo5zAn438bIEyxFf6swMnNpvPcUwW4u4yRcDh-ZjxApn9K5mv8tmQsL5_tgbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo5zAn438bIEyxFf6swMnNpvPcUwW4u4yRcDh-ZjxApn9K5s_8tmQsL5_tgbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo_zAn438bIEyxFVaIC0ZMQ72G6xnvmodYVPOBB5nuzMdWs0rvF2wEPxf5wbh3T.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo_zAn438bIEyxFVaIC0ZMQ72G6xnvmodYVPOBB5nuzMdWs0rtF2gEPxf5wbh3T.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/georama/v15/MCo_zAn438bIEyxFVaIC0ZMQ72G6xnvmodYVPOBB5nuzMdWs0rub2gEPxf5wbh3T.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo_zAn438bIEyxFVaIC0ZMQ72G6xnvmodYVPOBB5nuzMdWs0rvF2gEPxf5wbh3T.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo_zAn438bIEyxFVaIC0ZMQ72G6xnvmodYVPOBB5nuzMdWs0rv32gEPxf5wbh3T.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/georama/v15/MCo_zAn438bIEyxFVaIC0ZMQ72G6xnvmodYVPOBB5nuzMdWs0rsb3QEPxf5wbh3T.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo_zAn438bIEyxFVaIC0ZMQ72G6xnvmodYVPOBB5nuzMdWs0rsi3QEPxf5wbh3T.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/georama/v15/MCo_zAn438bIEyxFVaIC0ZMQ72G6xnvmodYVPOBB5nuzMdWs0rtF3QEPxf5wbh3T.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/georama/v15/MCo_zAn438bIEyxFVaIC0ZMQ72G6xnvmodYVPOBB5nuzMdWs0rts3QEPxf5wbh3T.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-geostar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a44a6384-3049-479e-ad0e-039940c2639f",-342822005),$APP.$cljs$cst$2675$family$$,"Geostar",$APP.$cljs$cst$725$name$$,"Geostar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geostar/v27/sykz-yx4n701VLOftSq9-trEvlQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-geostar-fill",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9c51271e-3ec3-4e30-89b2-e5f1dcd672f6",1725843546),$APP.$cljs$cst$2675$family$$,
"Geostar Fill",$APP.$cljs$cst$725$name$$,"Geostar Fill",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/geostarfill/v27/AMOWz4SWuWiXFfjEohxQ9os0U1K2w9lb4g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-germania-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("03480fbb-6f0f-47b0-9726-8c9fa4c50284",-1610393442),$APP.$cljs$cst$2675$family$$,"Germania One",$APP.$cljs$cst$725$name$$,"Germania One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/germaniaone/v21/Fh4yPjrqIyv2ucM2qzBjeS3ezAJONau6ew.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gideon-roman",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("476c7a60-a091-450e-94ba-c291a42fa8a0",-1475030589),$APP.$cljs$cst$2675$family$$,"Gideon Roman",$APP.$cljs$cst$725$name$$,"Gideon Roman",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gideonroman/v13/e3tmeuGrVOys8sxzZgWlmXoge0PWovdU4w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gidole",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("451ce82e-2370-40bc-9326-afb4cd6cd23e",
351193716),$APP.$cljs$cst$2675$family$$,"Gidole",$APP.$cljs$cst$725$name$$,"Gidole",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gidole/v24/sZlFdR6O8zVVEiMaCJtWS6EPcA.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gidugu",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4a50d226-5252-4370-886e-a7036fec9b76",1811267262),$APP.$cljs$cst$2675$family$$,"Gidugu",$APP.$cljs$cst$725$name$$,"Gidugu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gidugu/v28/L0x8DFMkk1Uf6w3RvPCmRSlUig.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gilda-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8c234b4d-f585-4589-bfb9-c62e7ae0ebea",817255622),$APP.$cljs$cst$2675$family$$,"Gilda Display",$APP.$cljs$cst$725$name$$,"Gilda Display",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gildadisplay/v20/t5tmIRoYMoaYG0WEOh7HwMeR7TnFrpOHYh4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-girassol",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5df4627b-16db-40f3-b46b-d8d00c9b9c1f",-1130942633),$APP.$cljs$cst$2675$family$$,"Girassol",$APP.$cljs$cst$725$name$$,"Girassol",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/girassol/v24/JTUUjIo_-DK48laaNC9Nz2pJzxbi.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-give-you-glory",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f614b274-f2ff-4b47-a403-298ce2383721",1182576004),$APP.$cljs$cst$2675$family$$,"Give You Glory",$APP.$cljs$cst$725$name$$,"Give You Glory",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/giveyouglory/v17/8QIQdiHOgt3vv4LR7ahjw9-XYc1zB4ZD6rwa.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-glass-antiqua",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b66fe7ba-0332-4d9f-99aa-f93fa927e5f9",256414031),
$APP.$cljs$cst$2675$family$$,"Glass Antiqua",$APP.$cljs$cst$725$name$$,"Glass Antiqua",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glassantiqua/v26/xfu30Wr0Wn3NOQM2piC0uXOjnL_wN6fRUkY.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-glegoo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f20d504b-d093-4921-800d-d6fb93d1061d",-710049218),$APP.$cljs$cst$2675$family$$,"Glegoo",$APP.$cljs$cst$725$name$$,"Glegoo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glegoo/v17/_Xmt-HQyrTKWaw2Ji6mZAI91xw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glegoo/v17/_Xmu-HQyrTKWaw2xN4a9CKRpzimMsg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-gloock",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("22c1388b-1a60-485e-a9d9-0b2daa7683d0",1640501272),$APP.$cljs$cst$2675$family$$,"Gloock",$APP.$cljs$cst$725$name$$,"Gloock",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gloock/v8/Iurb6YFw84WUY4N5jxylBrdRjQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gloria-hallelujah",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("51c69bf2-f198-4053-bcf8-63c7969c9c84",1635832847),$APP.$cljs$cst$2675$family$$,"Gloria Hallelujah",$APP.$cljs$cst$725$name$$,"Gloria Hallelujah",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gloriahallelujah/v24/LYjYdHv3kUk9BMV96EIswT9DIbW-MLSy3TKEvkCF.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-glory",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6ecd88cb-0174-407c-9313-d03ab0cf8f36",916826417),
$APP.$cljs$cst$2675$family$$,"Glory",$APP.$cljs$cst$725$name$$,"Glory",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uasoi9Lf1w5t3Est24nq9blIRQwIiDpn-dDi9EOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uasoi9Lf1w5t3Est24nq9blIRQQImDpn-dDi9EOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uasoi9Lf1w5t3Est24nq9blIRQnomDpn-dDi9EOQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uasoi9Lf1w5t3Est24nq9blIRQwImDpn-dDi9EOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/glory/v18/q5uasoi9Lf1w5t3Est24nq9blIRQ8omDpn-dDi9EOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uasoi9Lf1w5t3Est24nq9blIRQHo6Dpn-dDi9EOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uasoi9Lf1w5t3Est24nq9blIRQJ46Dpn-dDi9EOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uasoi9Lf1w5t3Est24nq9blIRQQI6Dpn-dDi9EOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uYsoi9Lf1w5vfNgCJg98TBOoNFCMpr5HWZLCpUOaM6.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uYsoi9Lf1w5vfNgCJg98TBOoNFCMrr5XWZLCpUOaM6.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uYsoi9Lf1w5vfNgCJg98TBOoNFCMo15XWZLCpUOaM6.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uYsoi9Lf1w5vfNgCJg98TBOoNFCMpr5XWZLCpUOaM6.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uYsoi9Lf1w5vfNgCJg98TBOoNFCMpZ5XWZLCpUOaM6.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uYsoi9Lf1w5vfNgCJg98TBOoNFCMq14nWZLCpUOaM6.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uYsoi9Lf1w5vfNgCJg98TBOoNFCMqM4nWZLCpUOaM6.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/glory/v18/q5uYsoi9Lf1w5vfNgCJg98TBOoNFCMrr4nWZLCpUOaM6.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gluten",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d80d161c-c4f3-4a37-a0a2-a27e41089ed3",
1911339846),$APP.$cljs$cst$2675$family$$,"Gluten",$APP.$cljs$cst$725$name$$,"Gluten",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gluten/v18/Hhy_U5gk9fW7OUdVIPh2zD_RSqQJ__A15jgJsn-Bhb_yI8Vb7B1Luni7ciJh.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gluten/v18/Hhy_U5gk9fW7OUdVIPh2zD_RSqQJ__A15jgJsn-Bhb_yI8Xb7R1Luni7ciJh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gluten/v18/Hhy_U5gk9fW7OUdVIPh2zD_RSqQJ__A15jgJsn-Bhb_yI8UF7R1Luni7ciJh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gluten/v18/Hhy_U5gk9fW7OUdVIPh2zD_RSqQJ__A15jgJsn-Bhb_yI8Vb7R1Luni7ciJh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gluten/v18/Hhy_U5gk9fW7OUdVIPh2zD_RSqQJ__A15jgJsn-Bhb_yI8Vp7R1Luni7ciJh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gluten/v18/Hhy_U5gk9fW7OUdVIPh2zD_RSqQJ__A15jgJsn-Bhb_yI8WF6h1Luni7ciJh.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gluten/v18/Hhy_U5gk9fW7OUdVIPh2zD_RSqQJ__A15jgJsn-Bhb_yI8W86h1Luni7ciJh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gluten/v18/Hhy_U5gk9fW7OUdVIPh2zD_RSqQJ__A15jgJsn-Bhb_yI8Xb6h1Luni7ciJh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gluten/v18/Hhy_U5gk9fW7OUdVIPh2zD_RSqQJ__A15jgJsn-Bhb_yI8Xy6h1Luni7ciJh.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-goblin-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("762dd813-8df3-4be5-bfde-0abe18a4917b",-685614584),$APP.$cljs$cst$2675$family$$,"Goblin One",$APP.$cljs$cst$725$name$$,"Goblin One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/goblinone/v28/CSR64z1ZnOqZRjRCBVY_TOcATNt_pOU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gochi-hand",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("201aef26-e525-4a99-b9c0-3b0fe44fe3fd",450823371),$APP.$cljs$cst$2675$family$$,"Gochi Hand",$APP.$cljs$cst$725$name$$,"Gochi Hand",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gochihand/v25/hES06XlsOjtJsgCkx1PkTo71-n0nXWA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-goldman",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3da1c946-2cf9-41c1-9531-29e19b8033a8",810440755),$APP.$cljs$cst$2675$family$$,
"Goldman",$APP.$cljs$cst$725$name$$,"Goldman",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/goldman/v21/pe0uMIWbN4JFplR2LDJ4Bt-7G98.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/goldman/v21/pe0rMIWbN4JFplR2FI5XIteQB9Zra1U.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-golos-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b05c926e-36ed-446c-9601-72892ae917fe",121373462),$APP.$cljs$cst$2675$family$$,"Golos Text",$APP.$cljs$cst$725$name$$,
"Golos Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/golostext/v7/q5uXsoe9Lv5t7Meb31EcOR9UdVTNs822plVRRQ5cEr8zXcyx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/golostext/v7/q5uXsoe9Lv5t7Meb31EcOR9UdVTNs822plVjRQ5cEr8zXcyx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/golostext/v7/q5uXsoe9Lv5t7Meb31EcOR9UdVTNs822plWPQg5cEr8zXcyx.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/golostext/v7/q5uXsoe9Lv5t7Meb31EcOR9UdVTNs822plW2Qg5cEr8zXcyx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/golostext/v7/q5uXsoe9Lv5t7Meb31EcOR9UdVTNs822plXRQg5cEr8zXcyx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/golostext/v7/q5uXsoe9Lv5t7Meb31EcOR9UdVTNs822plX4Qg5cEr8zXcyx.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-google-sans-code",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e7cefb42-1782-40ed-98e0-13dfc5f9ca9e",-950350212),$APP.$cljs$cst$2675$family$$,"Google Sans Code",$APP.$cljs$cst$725$name$$,"Google Sans Code",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/googlesanscode/v14/pxiSyogzv91QhV44Z_GQBHsGf5PuckJMXr41HfVaiXE_ggF--rWcgmBz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/googlesanscode/v14/pxiSyogzv91QhV44Z_GQBHsGf5PuckJMXr41HfVaiXFhggF--rWcgmBz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/googlesanscode/v14/pxiSyogzv91QhV44Z_GQBHsGf5PuckJMXr41HfVaiXFTggF--rWcgmBz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/googlesanscode/v14/pxiSyogzv91QhV44Z_GQBHsGf5PuckJMXr41HfVaiXG_hQF--rWcgmBz.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/googlesanscode/v14/pxiSyogzv91QhV44Z_GQBHsGf5PuckJMXr41HfVaiXGGhQF--rWcgmBz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/googlesanscode/v14/pxiSyogzv91QhV44Z_GQBHsGf5PuckJMXr41HfVaiXHhhQF--rWcgmBz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/googlesanscode/v14/pxisyogzv91QhV44Z_GQBHsGf5PuWEt-oWZcdm_0jmSpwbc98LG-h3BzvSU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/googlesanscode/v14/pxisyogzv91QhV44Z_GQBHsGf5PuWEt-oWZcdm_0jmSpwek98LG-h3BzvSU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/googlesanscode/v14/pxisyogzv91QhV44Z_GQBHsGf5PuWEt-oWZcdm_0jmSpwds98LG-h3BzvSU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/googlesanscode/v14/pxisyogzv91QhV44Z_GQBHsGf5PuWEt-oWZcdm_0jmSpwTc68LG-h3BzvSU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/googlesanscode/v14/pxisyogzv91QhV44Z_GQBHsGf5PuWEt-oWZcdm_0jmSpwQ468LG-h3BzvSU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/googlesanscode/v14/pxisyogzv91QhV44Z_GQBHsGf5PuWEt-oWZcdm_0jmSpwWk68LG-h3BzvSU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-google-sans-flex",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("570cd3c8-3cde-4a54-899f-7d751567de3d",-2087149279),$APP.$cljs$cst$2675$family$$,"Google Sans Flex",$APP.$cljs$cst$725$name$$,"Google Sans Flex",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/googlesansflex/v15/t5sJIQcYNIWbFgDgAAzZ34auoVyXkJCOvp3SFWJbN5hF8Ju1x6sKCyp0l9sI40swNJwInycYAJzz0m7kJ4qFQOJBOjLvDSndo0SKMpKSTzwliVdHAy4bxTDHg_ugnAakp8ubyctqU4LBMUM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-gorditas",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9eba100c-7c89-4389-b359-15445d5c47b5",1782575459),$APP.$cljs$cst$2675$family$$,"Gorditas",$APP.$cljs$cst$725$name$$,"Gorditas",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gorditas/v24/ll8_K2aTVD26DsPEtQDoDa4AlxYb.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gorditas/v24/ll84K2aTVD26DsPEtThUIooIvAoShA1i.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gothic-a1",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2f20dc30-4931-4143-b8c6-224cb402cedc",-1809713489),$APP.$cljs$cst$2675$family$$,"Gothic A1",$APP.$cljs$cst$725$name$$,"Gothic A1",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/gothica1/v18/CSR74z5ZnPydRjlCCwlCCMcqYtd2vfwk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gothica1/v18/CSR44z5ZnPydRjlCCwlCpOYKSPl6tOU9Eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gothica1/v18/CSR44z5ZnPydRjlCCwlCwOUKSPl6tOU9Eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gothica1/v18/CSR94z5ZnPydRjlCCwl6bM0uQNJmvQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gothica1/v18/CSR44z5ZnPydRjlCCwlCmOQKSPl6tOU9Eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gothica1/v18/CSR44z5ZnPydRjlCCwlCtOMKSPl6tOU9Eg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gothica1/v18/CSR44z5ZnPydRjlCCwlC0OIKSPl6tOU9Eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/gothica1/v18/CSR44z5ZnPydRjlCCwlCzOEKSPl6tOU9Eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gothica1/v18/CSR44z5ZnPydRjlCCwlC6OAKSPl6tOU9Eg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gotu",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("bc2c3fc9-7147-4a36-9ff5-82217fa1d2c8",1528945234),$APP.$cljs$cst$2675$family$$,"Gotu",$APP.$cljs$cst$725$name$$,"Gotu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gotu/v18/o-0FIpksx3QOlH0Lioh6-hU.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-goudy-bookletter-1911",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9d8a27cc-b3a2-4efb-859b-9dd63c801790",-1044845762),$APP.$cljs$cst$2675$family$$,"Goudy Bookletter 1911",$APP.$cljs$cst$725$name$$,"Goudy Bookletter 1911",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/goudybookletter1911/v21/sykt-z54laciWfKv-kX8krex0jDiD2HbY6I5tRbXZ4IXAA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gowun-batang",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("088621a5-2632-4c79-9173-6539389382c4",8060633),$APP.$cljs$cst$2675$family$$,"Gowun Batang",$APP.$cljs$cst$725$name$$,
"Gowun Batang",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gowunbatang/v12/ijwSs5nhRMIjYsdSgcMa3wRhXLH-yuAtLw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gowunbatang/v12/ijwNs5nhRMIjYsdSgcMa3wRZ4J7awssxJii23w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gowun-dodum",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c548cdc8-64a9-4c16-8bc5-bf28c6203942",-1067471043),$APP.$cljs$cst$2675$family$$,"Gowun Dodum",$APP.$cljs$cst$725$name$$,
"Gowun Dodum",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gowundodum/v12/3Jn5SD_00GqwlBnWc1TUJF0FfORL0fNy.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-graduate",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f8c46fb0-1634-4f2c-b80e-865fdfae275b",-1424885905),$APP.$cljs$cst$2675$family$$,"Graduate",$APP.$cljs$cst$725$name$$,"Graduate",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/graduate/v19/C8cg4cs3o2n15t_2YxgR6X2NZAn2.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-grand-hotel",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("796b80f6-5c1f-49db-a0ca-86beffcf1902",-1671182631),$APP.$cljs$cst$2675$family$$,"Grand Hotel",$APP.$cljs$cst$725$name$$,"Grand Hotel",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandhotel/v21/7Au7p_IgjDKdCRWuR1azpmQNEl0O0kEx.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-grandiflora-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6c197489-bced-43d1-9748-cf710b3969e6",-1502210724),
$APP.$cljs$cst$2675$family$$,"Grandiflora One",$APP.$cljs$cst$725$name$$,"Grandiflora One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandifloraone/v3/0ybmGD0g27bCk_5MGWZcKWhxwnUU_R3y8DOWGA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-grandstander",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ba746f84-73cd-4649-99b9-477893698edf",1121586079),$APP.$cljs$cst$2675$family$$,"Grandstander",$APP.$cljs$cst$725$name$$,"Grandstander",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6fawtA-GpSsTWrnNHPCSIMZhhKpFjyNZIQD1-_D3jWttFGmQk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6fawtA-GpSsTWrnNHPCSIMZhhKpFjyNZIQD9--D3jWttFGmQk.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6fawtA-GpSsTWrnNHPCSIMZhhKpFjyNZIQDwG-D3jWttFGmQk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6fawtA-GpSsTWrnNHPCSIMZhhKpFjyNZIQD1--D3jWttFGmQk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6fawtA-GpSsTWrnNHPCSIMZhhKpFjyNZIQD22-D3jWttFGmQk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6fawtA-GpSsTWrnNHPCSIMZhhKpFjyNZIQD4G5D3jWttFGmQk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6fawtA-GpSsTWrnNHPCSIMZhhKpFjyNZIQD7i5D3jWttFGmQk.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6fawtA-GpSsTWrnNHPCSIMZhhKpFjyNZIQD9-5D3jWttFGmQk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6fawtA-GpSsTWrnNHPCSIMZhhKpFjyNZIQD_a5D3jWttFGmQk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6ZawtA-GpSsTWrnNHPCSImbyq1fDGZrzwXGpf95zrcsvNDiQlBYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6ZawtA-GpSsTWrnNHPCSImbyq1fDGZrzwXGpf9ZzvcsvNDiQlBYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/grandstander/v20/ga6ZawtA-GpSsTWrnNHPCSImbyq1fDGZrzwXGpf9uTvcsvNDiQlBYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6ZawtA-GpSsTWrnNHPCSImbyq1fDGZrzwXGpf95zvcsvNDiQlBYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6ZawtA-GpSsTWrnNHPCSImbyq1fDGZrzwXGpf91TvcsvNDiQlBYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6ZawtA-GpSsTWrnNHPCSImbyq1fDGZrzwXGpf9OTzcsvNDiQlBYQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6ZawtA-GpSsTWrnNHPCSImbyq1fDGZrzwXGpf9ADzcsvNDiQlBYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6ZawtA-GpSsTWrnNHPCSImbyq1fDGZrzwXGpf9ZzzcsvNDiQlBYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grandstander/v20/ga6ZawtA-GpSsTWrnNHPCSImbyq1fDGZrzwXGpf9TjzcsvNDiQlBYQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-grape-nuts",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ec561ec8-fded-4ac6-9abc-04b58df23927",-305216684),$APP.$cljs$cst$2675$family$$,"Grape Nuts",$APP.$cljs$cst$725$name$$,"Grape Nuts",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grapenuts/v7/syk2-yF4iLM2RfKj4F7k3tLvol2RN1E.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gravitas-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("027c725b-242a-4b25-a90a-1341b187ef42",-1194845338),$APP.$cljs$cst$2675$family$$,"Gravitas One",$APP.$cljs$cst$725$name$$,"Gravitas One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gravitasone/v21/5h1diZ4hJ3cblKy3LWakKQmaDWRNr3DzbQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-great-vibes",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e671ad9f-dfd5-4695-970e-1a39b571c2bf",-159934560),
$APP.$cljs$cst$2675$family$$,"Great Vibes",$APP.$cljs$cst$725$name$$,"Great Vibes",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/greatvibes/v21/RWmMoKWR9v4ksMfaWd_JN-XCg6UKDXlq.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-grechen-fuemen",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f8de9fd1-9c54-4fc4-b3b6-4bbb9c5ed0ec",-1945336678),$APP.$cljs$cst$2675$family$$,"Grechen Fuemen",$APP.$cljs$cst$725$name$$,"Grechen Fuemen",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grechenfuemen/v11/vEFI2_tHEQ4d5ObgKxBzZh0MAWgc-NaXXq7H.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-grenze",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("67720489-3900-49c1-8cc1-39084cd6aa6f",-16670281),$APP.$cljs$cst$2675$family$$,"Grenze",$APP.$cljs$cst$725$name$$,"Grenze",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZRFGb7hR12BxqPm2IjuAkalnmd.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",
$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZXFGb7hR12BxqH_VpHsg04k2md0kI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZQFGb7hR12BxqPN0MDkicWn2CEyw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZWFGb7hR12BxqH_Vrrky0SvWWUy1uW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZQFGb7hR12BxqPU0ADkicWn2CEyw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZWFGb7hR12BxqH_VqPkC0SvWWUy1uW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/grenze/v16/O4ZTFGb7hR12Bxq3_2gnmgwKlg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZRFGb7hR12BxqH_WIjuAkalnmd.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZQFGb7hR12BxqPC0EDkicWn2CEyw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZWFGb7hR12BxqH_VrXkS0SvWWUy1uW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZQFGb7hR12BxqPJ0YDkicWn2CEyw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZWFGb7hR12BxqH_Vr7li0SvWWUy1uW.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZQFGb7hR12BxqPQ0cDkicWn2CEyw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/grenze/v16/O4ZWFGb7hR12BxqH_Vqfly0SvWWUy1uW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZQFGb7hR12BxqPX0QDkicWn2CEyw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,
"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZWFGb7hR12BxqH_VqDlC0SvWWUy1uW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZQFGb7hR12BxqPe0UDkicWn2CEyw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenze/v16/O4ZWFGb7hR12BxqH_VqnlS0SvWWUy1uW.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-grenze-gotisch",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a622843b-cf49-4901-a288-13381eb07b6f",1231555332),$APP.$cljs$cst$2675$family$$,"Grenze Gotisch",$APP.$cljs$cst$725$name$$,
"Grenze Gotisch",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenzegotisch/v20/Fh4hPjjqNDz1osh_jX9YfjudpBJBNV5y5wf_k1i5Lz5UcICdYPSd_w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenzegotisch/v20/Fh4hPjjqNDz1osh_jX9YfjudpBJBNV5y5wf_k1i5rz9UcICdYPSd_w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenzegotisch/v20/Fh4hPjjqNDz1osh_jX9YfjudpBJBNV5y5wf_k1i5cT9UcICdYPSd_w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenzegotisch/v20/Fh4hPjjqNDz1osh_jX9YfjudpBJBNV5y5wf_k1i5Lz9UcICdYPSd_w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenzegotisch/v20/Fh4hPjjqNDz1osh_jX9YfjudpBJBNV5y5wf_k1i5HT9UcICdYPSd_w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenzegotisch/v20/Fh4hPjjqNDz1osh_jX9YfjudpBJBNV5y5wf_k1i58ThUcICdYPSd_w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenzegotisch/v20/Fh4hPjjqNDz1osh_jX9YfjudpBJBNV5y5wf_k1i5yDhUcICdYPSd_w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenzegotisch/v20/Fh4hPjjqNDz1osh_jX9YfjudpBJBNV5y5wf_k1i5rzhUcICdYPSd_w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/grenzegotisch/v20/Fh4hPjjqNDz1osh_jX9YfjudpBJBNV5y5wf_k1i5hjhUcICdYPSd_w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-grey-qo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dc97abaa-6d4c-4464-b8ab-ede15290acd0",
1517796870),$APP.$cljs$cst$2675$family$$,"Grey Qo",$APP.$cljs$cst$725$name$$,"Grey Qo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/greyqo/v11/BXRrvF_Nmv_TyXxNDOtQ9Wf0QcE.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-griffy",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("09932146-0416-4202-a4ae-a8a015c80e8e",-1198651777),$APP.$cljs$cst$2675$family$$,"Griffy",$APP.$cljs$cst$725$name$$,"Griffy",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/griffy/v23/FwZa7-ox2FQh9kfwSNSEwM2zpA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gruppo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("268eacaa-d292-4399-93ef-f30adfb9fcb4",-2084426581),$APP.$cljs$cst$2675$family$$,"Gruppo",$APP.$cljs$cst$725$name$$,"Gruppo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gruppo/v23/WwkfxPmzE06v_ZWFWXDAOIEQUQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gudea",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("00f4c25d-7435-4454-8391-069433165bef",
557063829),$APP.$cljs$cst$2675$family$$,"Gudea",$APP.$cljs$cst$725$name$$,"Gudea",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gudea/v16/neIFzCqgsI0mp-CP9IGON7Ez.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gudea/v16/neILzCqgsI0mp9CN_oWsMqEzSJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gudea/v16/neIIzCqgsI0mp9gz26WGHK06UY30.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gugi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9c6f1360-5bbd-423e-93ac-6200227e301c",-1462849224),$APP.$cljs$cst$2675$family$$,"Gugi",$APP.$cljs$cst$725$name$$,"Gugi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gugi/v21/A2BVn5dXywshVA6A9DEfgqM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gulzar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8120fffa-4fd9-4192-8828-47b0fffddd37",-1151529545),$APP.$cljs$cst$2675$family$$,"Gulzar",$APP.$cljs$cst$725$name$$,"Gulzar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gulzar/v14/Wnz6HAc9eB3HB2ILYTwZqg_MPQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gupter",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fb21280c-6877-4a0c-b36f-589e32277b80",
1745104118),$APP.$cljs$cst$2675$family$$,"Gupter",$APP.$cljs$cst$725$name$$,"Gupter",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gupter/v18/2-cm9JNmxJqPO1QUYZa_Wu_lpA.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gupter/v18/2-cl9JNmxJqPO1Qslb-bUsT5rZhaZg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gupter/v18/2-cl9JNmxJqPO1Qs3bmbUsT5rZhaZg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gurajada",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("74bc640c-e2a3-4a86-a1e9-a6684b6d00a6",491131091),$APP.$cljs$cst$2675$family$$,"Gurajada",$APP.$cljs$cst$725$name$$,"Gurajada",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gurajada/v22/FwZY7-Qx308m-l-0Kd6A4sijpFu_.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-gwendolyn",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ca783d67-a806-4347-867d-5db390f02867",-1281407818),$APP.$cljs$cst$2675$family$$,"Gwendolyn",$APP.$cljs$cst$725$name$$,"Gwendolyn",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gwendolyn/v9/qkBXXvoO_M3CSss-d7ee5JRLkAXbMQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/gwendolyn/v9/qkBSXvoO_M3CSss-d7emWLtvmC7HONiSFQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-habibi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8c6ca398-9a84-41fd-8774-3337932d2826",-1723889758),$APP.$cljs$cst$2675$family$$,"Habibi",$APP.$cljs$cst$725$name$$,"Habibi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/habibi/v22/CSR-4zFWkuqcTTNCShJeZOYySQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hachi-maru-pop",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2ec187d9-1b00-4389-913b-7150b0854b46",605406053),$APP.$cljs$cst$2675$family$$,
"Hachi Maru Pop",$APP.$cljs$cst$725$name$$,"Hachi Maru Pop",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hachimarupop/v23/HI_TiYoRLqpLrEiMAuO9Ysfz7rW1EM_btd8u.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hahmlet",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bdff9e21-5426-4640-be53-823bada0a687",-1574208071),$APP.$cljs$cst$2675$family$$,"Hahmlet",$APP.$cljs$cst$725$name$$,"Hahmlet",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",
$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hahmlet/v21/BngXUXpCQ3nKpIo0TfPyfCdXfaeU4RhKOdjobsO-aVxn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hahmlet/v21/BngXUXpCQ3nKpIo0TfPyfCdXfaeU4RjKONjobsO-aVxn.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hahmlet/v21/BngXUXpCQ3nKpIo0TfPyfCdXfaeU4RgUONjobsO-aVxn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/hahmlet/v21/BngXUXpCQ3nKpIo0TfPyfCdXfaeU4RhKONjobsO-aVxn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hahmlet/v21/BngXUXpCQ3nKpIo0TfPyfCdXfaeU4Rh4ONjobsO-aVxn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hahmlet/v21/BngXUXpCQ3nKpIo0TfPyfCdXfaeU4RiUP9jobsO-aVxn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hahmlet/v21/BngXUXpCQ3nKpIo0TfPyfCdXfaeU4RitP9jobsO-aVxn.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hahmlet/v21/BngXUXpCQ3nKpIo0TfPyfCdXfaeU4RjKP9jobsO-aVxn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/hahmlet/v21/BngXUXpCQ3nKpIo0TfPyfCdXfaeU4RjjP9jobsO-aVxn.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-halant",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1ca89a23-ceaa-45f7-95a6-f65e14b07a65",-1848868568),$APP.$cljs$cst$2675$family$$,"Halant",$APP.$cljs$cst$725$name$$,"Halant",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/halant/v17/u-490qaujRI2Pbsvc_pCmwZqcwdRXg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/halant/v17/u-4-0qaujRI2PbsX39Jmky12eg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/halant/v17/u-490qaujRI2PbsvK_tCmwZqcwdRXg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/halant/v17/u-490qaujRI2PbsvB_xCmwZqcwdRXg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/halant/v17/u-490qaujRI2PbsvY_1CmwZqcwdRXg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hammersmith-one",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("f5a2c4cd-f35c-4c45-b852-11331d1fdef7",549634126),$APP.$cljs$cst$2675$family$$,"Hammersmith One",$APP.$cljs$cst$725$name$$,"Hammersmith One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/hammersmithone/v18/qWcyB624q4L_C4jGQ9IK0O_dFlnbshsks4MRXw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hanalei",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c80a9bad-501e-4d1c-a13e-1ce8ad350e33",-1422433977),$APP.$cljs$cst$2675$family$$,"Hanalei",$APP.$cljs$cst$725$name$$,"Hanalei",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hanalei/v24/E21n_dD8iufIjBRHXzgmVydREus.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hanalei-fill",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1bdeef7c-4706-4244-b97b-b10ca0041410",1766350674),$APP.$cljs$cst$2675$family$$,"Hanalei Fill",$APP.$cljs$cst$725$name$$,
"Hanalei Fill",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hanaleifill/v23/fC1mPYtObGbfyQznIaQzPQiMVwLBplm9aw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-handjet",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fd41ada3-14c9-4465-aac1-78a8a4bad392",2121327874),$APP.$cljs$cst$2675$family$$,"Handjet",$APP.$cljs$cst$725$name$$,"Handjet",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/handjet/v22/oY1n8eXHq7n1OnbQrOY_2FrEwYEMLlcdP1mCtZaLaTutCwcIhGZ0lGU0akFcO3XFHTmbUkUsEHFAH2A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/handjet/v22/oY1n8eXHq7n1OnbQrOY_2FrEwYEMLlcdP1mCtZaLaTutCwcIhGZ0lGU0akFcO3XFHbmaUkUsEHFAH2A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/handjet/v22/oY1n8eXHq7n1OnbQrOY_2FrEwYEMLlcdP1mCtZaLaTutCwcIhGZ0lGU0akFcO3XFHWeaUkUsEHFAH2A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/handjet/v22/oY1n8eXHq7n1OnbQrOY_2FrEwYEMLlcdP1mCtZaLaTutCwcIhGZ0lGU0akFcO3XFHTmaUkUsEHFAH2A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/handjet/v22/oY1n8eXHq7n1OnbQrOY_2FrEwYEMLlcdP1mCtZaLaTutCwcIhGZ0lGU0akFcO3XFHQuaUkUsEHFAH2A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/handjet/v22/oY1n8eXHq7n1OnbQrOY_2FrEwYEMLlcdP1mCtZaLaTutCwcIhGZ0lGU0akFcO3XFHeedUkUsEHFAH2A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/handjet/v22/oY1n8eXHq7n1OnbQrOY_2FrEwYEMLlcdP1mCtZaLaTutCwcIhGZ0lGU0akFcO3XFHd6dUkUsEHFAH2A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/handjet/v22/oY1n8eXHq7n1OnbQrOY_2FrEwYEMLlcdP1mCtZaLaTutCwcIhGZ0lGU0akFcO3XFHbmdUkUsEHFAH2A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/handjet/v22/oY1n8eXHq7n1OnbQrOY_2FrEwYEMLlcdP1mCtZaLaTutCwcIhGZ0lGU0akFcO3XFHZCdUkUsEHFAH2A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-handlee",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("318eceb8-4e2e-4cb5-abe3-1f0516eb9a5a",
-1115701906),$APP.$cljs$cst$2675$family$$,"Handlee",$APP.$cljs$cst$725$name$$,"Handlee",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/handlee/v20/-F6xfjBsISg9aMakDmr6oilJ3ik.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hanken-grotesk",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0458a193-1f94-4ddb-aa47-05e19e0f8cf0",-1337077887),$APP.$cljs$cst$2675$family$$,"Hanken Grotesk",$APP.$cljs$cst$725$name$$,"Hanken Grotesk",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",
$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVq2YZDLWuGJpnzaiwFXS9tYvBRzyFLlZg_f_Ncs2da4fpNzXhRKA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVq2YZDLWuGJpnzaiwFXS9tYvBRzyFLlZg_f_NcM2Za4fpNzXhRKA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVq2YZDLWuGJpnzaiwFXS9tYvBRzyFLlZg_f_Nc7WZa4fpNzXhRKA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVq2YZDLWuGJpnzaiwFXS9tYvBRzyFLlZg_f_Ncs2Za4fpNzXhRKA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVq2YZDLWuGJpnzaiwFXS9tYvBRzyFLlZg_f_NcgWZa4fpNzXhRKA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVq2YZDLWuGJpnzaiwFXS9tYvBRzyFLlZg_f_NcbWFa4fpNzXhRKA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVq2YZDLWuGJpnzaiwFXS9tYvBRzyFLlZg_f_NcVGFa4fpNzXhRKA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVq2YZDLWuGJpnzaiwFXS9tYvBRzyFLlZg_f_NcM2Fa4fpNzXhRKA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVq2YZDLWuGJpnzaiwFXS9tYvBRzyFLlZg_f_NcGmFa4fpNzXhRKA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVo2YZDLWuGJpnzaiwFXS9tYtpY_d6T_POl0fRJeyWyo_BJ731BKMSK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVo2YZDLWuGJpnzaiwFXS9tYtpY_d6T_POl0fRJeyUyovBJ731BKMSK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVo2YZDLWuGJpnzaiwFXS9tYtpY_d6T_POl0fRJeyXsovBJ731BKMSK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVo2YZDLWuGJpnzaiwFXS9tYtpY_d6T_POl0fRJeyWyovBJ731BKMSK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVo2YZDLWuGJpnzaiwFXS9tYtpY_d6T_POl0fRJeyWAovBJ731BKMSK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVo2YZDLWuGJpnzaiwFXS9tYtpY_d6T_POl0fRJeyVspfBJ731BKMSK.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVo2YZDLWuGJpnzaiwFXS9tYtpY_d6T_POl0fRJeyVVpfBJ731BKMSK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",
$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVo2YZDLWuGJpnzaiwFXS9tYtpY_d6T_POl0fRJeyUypfBJ731BKMSK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hankengrotesk/v12/ieVo2YZDLWuGJpnzaiwFXS9tYtpY_d6T_POl0fRJeyUbpfBJ731BKMSK.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hanuman",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("46305b4f-1c82-4a85-b538-04c89e2f631d",1698171175),$APP.$cljs$cst$2675$family$$,"Hanuman",$APP.$cljs$cst$725$name$$,"Hanuman",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hanuman/v24/VuJudNvD15HhpJJBYq31yFn72hxIv0sd5hDsU9X6RPzQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hanuman/v24/VuJudNvD15HhpJJBYq31yFn72hxIv0ud5xDsU9X6RPzQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hanuman/v24/VuJudNvD15HhpJJBYq31yFn72hxIv0tD5xDsU9X6RPzQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/hanuman/v24/VuJudNvD15HhpJJBYq31yFn72hxIv0sd5xDsU9X6RPzQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hanuman/v24/VuJudNvD15HhpJJBYq31yFn72hxIv0sv5xDsU9X6RPzQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hanuman/v24/VuJudNvD15HhpJJBYq31yFn72hxIv0vD4BDsU9X6RPzQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hanuman/v24/VuJudNvD15HhpJJBYq31yFn72hxIv0v64BDsU9X6RPzQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hanuman/v24/VuJudNvD15HhpJJBYq31yFn72hxIv0ud4BDsU9X6RPzQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/hanuman/v24/VuJudNvD15HhpJJBYq31yFn72hxIv0u04BDsU9X6RPzQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-happy-monkey",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e5cd7da9-30f2-4e65-b71a-e7c1d29a584d",1290010835),$APP.$cljs$cst$2675$family$$,"Happy Monkey",$APP.$cljs$cst$725$name$$,"Happy Monkey",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/happymonkey/v15/K2F2fZZcl-9SXwl5F_C4R_OABwD2bWqVjw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-harmattan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2c0d262d-c083-42b3-9527-7b16f6aaca11",-1515311612),
$APP.$cljs$cst$2675$family$$,"Harmattan",$APP.$cljs$cst$725$name$$,"Harmattan",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/harmattan/v24/goksH6L2DkFvVvRp9XpTS0CjkP1Yog.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/harmattan/v24/gokpH6L2DkFvVvRp9Xprv2mHmNZEq6TTFw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/harmattan/v24/gokpH6L2DkFvVvRp9Xprk26HmNZEq6TTFw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/harmattan/v24/gokpH6L2DkFvVvRp9Xpr92-HmNZEq6TTFw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-headland-one",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("fe03f5c6-004d-41a2-b3ca-e423dfa12cef",579478158),$APP.$cljs$cst$2675$family$$,"Headland One",$APP.$cljs$cst$725$name$$,"Headland One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/headlandone/v17/yYLu0hHR2vKnp89Tk1TCq3Tx0PlTeZ3mJA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hedvig-letters-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("83b42cd0-9afc-4926-9e34-fba1b6062743",586173170),$APP.$cljs$cst$2675$family$$,"Hedvig Letters Sans",$APP.$cljs$cst$725$name$$,"Hedvig Letters Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hedvigletterssans/v2/CHy_V_PfGVjobSBkihHWDT98RVp37w8jQJ1N3Twgi1w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hedvig-letters-serif",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f7f807ec-dea7-431c-9419-de0b59f82261",-248905057),$APP.$cljs$cst$2675$family$$,"Hedvig Letters Serif",
$APP.$cljs$cst$725$name$$,"Hedvig Letters Serif",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hedviglettersserif/v4/OD5puN2I2mekHmyoU1Kj2AXOd5_7v7gIDlX8quj7viQ_N1HixEAZf7fcvSGpZg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-heebo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("04479d12-ef28-4fda-bb42-9954f2417972",-1253072456),$APP.$cljs$cst$2675$family$$,"Heebo",$APP.$cljs$cst$725$name$$,"Heebo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heebo/v28/NGSpv5_NC0k9P_v6ZUCbLRAHxK1EiS2cckOnz02SXQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heebo/v28/NGSpv5_NC0k9P_v6ZUCbLRAHxK1ECSycckOnz02SXQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heebo/v28/NGSpv5_NC0k9P_v6ZUCbLRAHxK1E1yycckOnz02SXQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heebo/v28/NGSpv5_NC0k9P_v6ZUCbLRAHxK1EiSycckOnz02SXQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heebo/v28/NGSpv5_NC0k9P_v6ZUCbLRAHxK1EuyycckOnz02SXQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/heebo/v28/NGSpv5_NC0k9P_v6ZUCbLRAHxK1EVyucckOnz02SXQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heebo/v28/NGSpv5_NC0k9P_v6ZUCbLRAHxK1EbiucckOnz02SXQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heebo/v28/NGSpv5_NC0k9P_v6ZUCbLRAHxK1ECSucckOnz02SXQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heebo/v28/NGSpv5_NC0k9P_v6ZUCbLRAHxK1EICucckOnz02SXQ.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-henny-penny",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("eff91948-d90f-4613-863f-0187f2a56ac5",884023189),$APP.$cljs$cst$2675$family$$,"Henny Penny",$APP.$cljs$cst$725$name$$,"Henny Penny",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hennypenny/v18/wXKvE3UZookzsxz_kjGSfMQqt3M7tMDT.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hepta-slab",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c9685ee0-ebcb-41c7-96f0-19be5f0b827b",1256985875),$APP.$cljs$cst$2675$family$$,"Hepta Slab",$APP.$cljs$cst$725$name$$,"Hepta Slab",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heptaslab/v25/ea8JadoyU_jkHdalebHvyWVNdYoIsHe5HvkV5jfbY5B0NBkz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heptaslab/v25/ea8JadoyU_jkHdalebHvyWVNdYoIsHe5HvmV5zfbY5B0NBkz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heptaslab/v25/ea8JadoyU_jkHdalebHvyWVNdYoIsHe5HvlL5zfbY5B0NBkz.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heptaslab/v25/ea8JadoyU_jkHdalebHvyWVNdYoIsHe5HvkV5zfbY5B0NBkz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heptaslab/v25/ea8JadoyU_jkHdalebHvyWVNdYoIsHe5Hvkn5zfbY5B0NBkz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heptaslab/v25/ea8JadoyU_jkHdalebHvyWVNdYoIsHe5HvnL4DfbY5B0NBkz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heptaslab/v25/ea8JadoyU_jkHdalebHvyWVNdYoIsHe5Hvny4DfbY5B0NBkz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heptaslab/v25/ea8JadoyU_jkHdalebHvyWVNdYoIsHe5HvmV4DfbY5B0NBkz.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/heptaslab/v25/ea8JadoyU_jkHdalebHvyWVNdYoIsHe5Hvm84DfbY5B0NBkz.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-herr-von-muellerhoff",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("263478d0-d6a0-41e3-8f0a-23aae10d38ce",
761855391),$APP.$cljs$cst$2675$family$$,"Herr Von Muellerhoff",$APP.$cljs$cst$725$name$$,"Herr Von Muellerhoff",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/herrvonmuellerhoff/v23/WBL6rFjRZkREW8WqmCWYLgCkQKXb4CAft3c6_qJY3QPQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hi-melody",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f8b91900-38c2-40f1-92e5-dcea616b80d2",309450890),$APP.$cljs$cst$2675$family$$,"Hi Melody",$APP.$cljs$cst$725$name$$,"Hi Melody",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/himelody/v19/46ktlbP8Vnz0pJcqCTbEf29E31BBGA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hina-mincho",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("40a90085-b8cb-4293-8925-f3b61adb6d73",1814715479),$APP.$cljs$cst$2675$family$$,"Hina Mincho",$APP.$cljs$cst$725$name$$,"Hina Mincho",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hinamincho/v16/2sDaZGBRhpXa2Jjz5w5LAGW8KbkVZTHR.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hind",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("a450aad8-cfb5-447d-9e8d-129a58024c23",-2140434804),$APP.$cljs$cst$2675$family$$,"Hind",$APP.$cljs$cst$725$name$$,"Hind",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hind/v18/5aU19_a8oxmIfMJaIRuYjDpf5Vw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hind/v18/5aU69_a8oxmIRG5yBROzkDM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hind/v18/5aU19_a8oxmIfJpbIRuYjDpf5Vw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hind/v18/5aU19_a8oxmIfLZcIRuYjDpf5Vw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hind/v18/5aU19_a8oxmIfNJdIRuYjDpf5Vw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hind-guntur",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("803788aa-7f82-46fa-9fc0-5db43f56bec9",1958852791),$APP.$cljs$cst$2675$family$$,"Hind Guntur",$APP.$cljs$cst$725$name$$,"Hind Guntur",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindguntur/v14/wXKyE3UZrok56nvamSuJd_yGn1czn9zaj5Ju.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindguntur/v14/wXKvE3UZrok56nvamSuJd8Qqt3M7tMDT.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindguntur/v14/wXKyE3UZrok56nvamSuJd_zenlczn9zaj5Ju.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindguntur/v14/wXKyE3UZrok56nvamSuJd_zymVczn9zaj5Ju.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindguntur/v14/wXKyE3UZrok56nvamSuJd_yWmFczn9zaj5Ju.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hind-madurai",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7d9723b8-5295-45aa-b028-6309f05f45fe",-291937060),
$APP.$cljs$cst$2675$family$$,"Hind Madurai",$APP.$cljs$cst$725$name$$,"Hind Madurai",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindmadurai/v13/f0Xu0e2p98ZvDXdZQIOcpqjfXaUnecsoMJ0b_g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindmadurai/v13/f0Xx0e2p98ZvDXdZQIOcpqjn8Y0DceA0OQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/hindmadurai/v13/f0Xu0e2p98ZvDXdZQIOcpqjfBaQnecsoMJ0b_g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindmadurai/v13/f0Xu0e2p98ZvDXdZQIOcpqjfKaMnecsoMJ0b_g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindmadurai/v13/f0Xu0e2p98ZvDXdZQIOcpqjfTaInecsoMJ0b_g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hind-mysuru",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("92ae4340-9deb-47fc-a708-11922a62e33c",-985569953),$APP.$cljs$cst$2675$family$$,"Hind Mysuru",$APP.$cljs$cst$725$name$$,"Hind Mysuru",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindmysuru/v1/sykq-yB3k7wiAJ-U5l_li8pppHWQBVTqU4sY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindmysuru/v1/syk3-yB3k7wiAJ-U5l_li_LFjFGYLkjj.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindmysuru/v1/sykq-yB3k7wiAJ-U5l_li8oxpXWQBVTqU4sY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindmysuru/v1/sykq-yB3k7wiAJ-U5l_li8odonWQBVTqU4sY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindmysuru/v1/sykq-yB3k7wiAJ-U5l_li8p5o3WQBVTqU4sY.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hind-siliguri",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7920e6a8-0ace-44e9-af12-ff715a80b633",377289661),$APP.$cljs$cst$2675$family$$,"Hind Siliguri",$APP.$cljs$cst$725$name$$,"Hind Siliguri",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindsiliguri/v14/ijwOs5juQtsyLLR5jN4cxBEoRDf44uEfKiGvxts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindsiliguri/v14/ijwTs5juQtsyLLR5jN4cxBEofJvQxuk0Nig.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindsiliguri/v14/ijwOs5juQtsyLLR5jN4cxBEoRG_54uEfKiGvxts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/hindsiliguri/v14/ijwOs5juQtsyLLR5jN4cxBEoREP-4uEfKiGvxts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindsiliguri/v14/ijwOs5juQtsyLLR5jN4cxBEoRCf_4uEfKiGvxts.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hind-vadodara",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("768d4b10-9f28-4dbc-b877-7d1d6bc73455",-883409826),$APP.$cljs$cst$2675$family$$,"Hind Vadodara",$APP.$cljs$cst$725$name$$,"Hind Vadodara",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/hindvadodara/v16/neIQzCKvrIcn5pbuuuriV9tTSDn3iXM0oSOL2Yw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindvadodara/v16/neINzCKvrIcn5pbuuuriV9tTcJXfrXsfvSo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindvadodara/v16/neIQzCKvrIcn5pbuuuriV9tTSGH2iXM0oSOL2Yw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindvadodara/v16/neIQzCKvrIcn5pbuuuriV9tTSE3xiXM0oSOL2Yw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hindvadodara/v16/neIQzCKvrIcn5pbuuuriV9tTSCnwiXM0oSOL2Yw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-holtwood-one-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("68b3691e-6841-4c02-8249-35d1f16f1f26",
1821803439),$APP.$cljs$cst$2675$family$$,"Holtwood One SC",$APP.$cljs$cst$725$name$$,"Holtwood One SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/holtwoodonesc/v23/yYLx0hLR0P-3vMFSk1TCq3Txg5B3cbb6LZttyg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-homemade-apple",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e262c26d-baa9-43ab-9309-56fb776e76b3",2010815092),$APP.$cljs$cst$2675$family$$,"Homemade Apple",$APP.$cljs$cst$725$name$$,"Homemade Apple",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/homemadeapple/v24/Qw3EZQFXECDrI2q789EKQZJob3x9Vnksi4M7.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-homenaje",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("06a018c6-fb33-46e6-a683-8bc9b153fc52",223773380),$APP.$cljs$cst$2675$family$$,"Homenaje",$APP.$cljs$cst$725$name$$,"Homenaje",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/homenaje/v17/FwZY7-Q-xVAi_l-6Ld6A4sijpFu_.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-honk",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("db543736-089e-4580-8798-ab8b8b0a39a9",-2110556127),$APP.$cljs$cst$2675$family$$,"Honk",$APP.$cljs$cst$725$name$$,"Honk",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/honk/v6/m8J7jftUea-XwTaemClumrBQbmvynOmXBji9zFhHRr8WFgVLo7tNepQKvg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-host-grotesk",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b66898c9-2615-4789-9c71-d8e0ad80207b",-1804384224),$APP.$cljs$cst$2675$family$$,"Host Grotesk",$APP.$cljs$cst$725$name$$,"Host Grotesk",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hostgrotesk/v5/co3UmWBnlCJ3U42vbbfdwMjzqHAXOdFzqU5PubnOzhap-j94InI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hostgrotesk/v5/co3UmWBnlCJ3U42vbbfdwMjzqHAXOdFzqU5PuefOzhap-j94InI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hostgrotesk/v5/co3UmWBnlCJ3U42vbbfdwMjzqHAXOdFzqU5PudXOzhap-j94InI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hostgrotesk/v5/co3UmWBnlCJ3U42vbbfdwMjzqHAXOdFzqU5PuTnJzhap-j94InI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hostgrotesk/v5/co3UmWBnlCJ3U42vbbfdwMjzqHAXOdFzqU5PuQDJzhap-j94InI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hostgrotesk/v5/co3UmWBnlCJ3U42vbbfdwMjzqHAXOdFzqU5PuWfJzhap-j94InI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hostgrotesk/v5/co3SmWBnlCJ3U42vbbfdwMjZoULo4bgYM-BIrC-NeFWj_h19MnL2jg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hostgrotesk/v5/co3SmWBnlCJ3U42vbbfdwMjZoULo4bgYM-BIrC-NJlWj_h19MnL2jg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hostgrotesk/v5/co3SmWBnlCJ3U42vbbfdwMjZoULo4bgYM-BIrC-NFFWj_h19MnL2jg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hostgrotesk/v5/co3SmWBnlCJ3U42vbbfdwMjZoULo4bgYM-BIrC-N-FKj_h19MnL2jg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hostgrotesk/v5/co3SmWBnlCJ3U42vbbfdwMjZoULo4bgYM-BIrC-NwVKj_h19MnL2jg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/hostgrotesk/v5/co3SmWBnlCJ3U42vbbfdwMjZoULo4bgYM-BIrC-NplKj_h19MnL2jg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hubballi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c24e99cf-59d9-4dde-b7c0-e46ced62e77f",-1389686921),$APP.$cljs$cst$2675$family$$,"Hubballi",$APP.$cljs$cst$725$name$$,"Hubballi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubballi/v10/o-0JIpUj3WIZ1RFN56B7yBBNYuSF.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-hubot-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c52def63-e0ae-4af1-8355-5ea2392a3c71",374898927),$APP.$cljs$cst$2675$family$$,
"Hubot Sans",$APP.$cljs$cst$725$name$$,"Hubot Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubotsans/v5/pe0BMIiULYxOvxVLbVwhONyy6zb7yFM9V5G3iZ3X0avsIiCxjLsCZ7ZdgLDVwVqcXQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubotsans/v5/pe0BMIiULYxOvxVLbVwhONyy6zb7yFM9V5G3iZ3X0avsIiCxjLsCubZdgLDVwVqcXQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubotsans/v5/pe0BMIiULYxOvxVLbVwhONyy6zb7yFM9V5G3iZ3X0avsIiCxjLsC57ZdgLDVwVqcXQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubotsans/v5/pe0BMIiULYxOvxVLbVwhONyy6zb7yFM9V5G3iZ3X0avsIiCxjLsC1bZdgLDVwVqcXQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubotsans/v5/pe0BMIiULYxOvxVLbVwhONyy6zb7yFM9V5G3iZ3X0avsIiCxjLsCObFdgLDVwVqcXQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubotsans/v5/pe0BMIiULYxOvxVLbVwhONyy6zb7yFM9V5G3iZ3X0avsIiCxjLsCALFdgLDVwVqcXQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubotsans/v5/pe0BMIiULYxOvxVLbVwhONyy6zb7yFM9V5G3iZ3X0avsIiCxjLsCZ7FdgLDVwVqcXQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubotsans/v5/pe0BMIiULYxOvxVLbVwhONyy6zb7yFM9V5G3iZ3X0avsIiCxjLsCTrFdgLDVwVqcXQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubotsans/v5/pe0PMIiULYxOvxVLbVwhEtWACNaCm8WTUIR_y2-e41Q0S0srIrwXL_U1w7rR41-MXUss.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubotsans/v5/pe0PMIiULYxOvxVLbVwhEtWACNaCm8WTUIR_y2-e41Q0S0srIrwXL_Xrw7rR41-MXUss.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/hubotsans/v5/pe0PMIiULYxOvxVLbVwhEtWACNaCm8WTUIR_y2-e41Q0S0srIrwXL_W1w7rR41-MXUss.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubotsans/v5/pe0PMIiULYxOvxVLbVwhEtWACNaCm8WTUIR_y2-e41Q0S0srIrwXL_WHw7rR41-MXUss.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubotsans/v5/pe0PMIiULYxOvxVLbVwhEtWACNaCm8WTUIR_y2-e41Q0S0srIrwXL_VrxLrR41-MXUss.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/hubotsans/v5/pe0PMIiULYxOvxVLbVwhEtWACNaCm8WTUIR_y2-e41Q0S0srIrwXL_VSxLrR41-MXUss.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubotsans/v5/pe0PMIiULYxOvxVLbVwhEtWACNaCm8WTUIR_y2-e41Q0S0srIrwXL_U1xLrR41-MXUss.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hubotsans/v5/pe0PMIiULYxOvxVLbVwhEtWACNaCm8WTUIR_y2-e41Q0S0srIrwXL_UcxLrR41-MXUss.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-huninn",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1aa26572-73ba-41ff-815d-9d4a27d04a99",-1033420240),$APP.$cljs$cst$2675$family$$,
"Huninn",$APP.$cljs$cst$725$name$$,"Huninn",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/huninn/v2/OpNNnoINg9bQ4xkpjiHQjittXw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-hurricane",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("241681dc-3d87-4d37-b9d9-740dd5c7a838",1166533806),$APP.$cljs$cst$2675$family$$,"Hurricane",$APP.$cljs$cst$725$name$$,"Hurricane",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/hurricane/v9/pe0sMIuULZxTolZ5YldyAv2-C99ycg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ibm-plex-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e9ed200d-31ca-42d6-a0ad-79bceae92678",-841851465),$APP.$cljs$cst$2675$family$$,"IBM Plex Mono",$APP.$cljs$cst$725$name$$,"IBM Plex Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexmono/v20/-F6pfjptAgt5VM-kVkqdyU8n3kwq0n1hj-sNFQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexmono/v20/-F6rfjptAgt5VM-kVkqdyU8n1ioStndlre4dFcFh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexmono/v20/-F6qfjptAgt5VM-kVkqdyU8n3uAL8ldPg-IUDNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexmono/v20/-F6sfjptAgt5VM-kVkqdyU8n1ioSGlZFh8ARHNh4zg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexmono/v20/-F6qfjptAgt5VM-kVkqdyU8n3oQI8ldPg-IUDNg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexmono/v20/-F6sfjptAgt5VM-kVkqdyU8n1ioSflVFh8ARHNh4zg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexmono/v20/-F63fjptAgt5VM-kVkqdyU8n5igg1l9kn-s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexmono/v20/-F6pfjptAgt5VM-kVkqdyU8n1ioq0n1hj-sNFQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexmono/v20/-F6qfjptAgt5VM-kVkqdyU8n3twJ8ldPg-IUDNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexmono/v20/-F6sfjptAgt5VM-kVkqdyU8n1ioSJlRFh8ARHNh4zg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexmono/v20/-F6qfjptAgt5VM-kVkqdyU8n3vAO8ldPg-IUDNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexmono/v20/-F6sfjptAgt5VM-kVkqdyU8n1ioSClNFh8ARHNh4zg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexmono/v20/-F6qfjptAgt5VM-kVkqdyU8n3pQP8ldPg-IUDNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexmono/v20/-F6sfjptAgt5VM-kVkqdyU8n1ioSblJFh8ARHNh4zg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ibm-plex-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8a982fe2-8dcb-401f-8834-55a796a6a45b",1371246002),$APP.$cljs$cst$2675$family$$,"IBM Plex Sans",$APP.$cljs$cst$725$name$$,
"IBM Plex Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsans/v23/zYXGKVElMYYaJe8bpLHnCwDKr932-G7dytD-Dmu1swZSAXcomDVmadSD6lhzAKI5loa26g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsans/v23/zYXGKVElMYYaJe8bpLHnCwDKr932-G7dytD-Dmu1swZSAXcomDVmadSDallzAKI5loa26g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsans/v23/zYXGKVElMYYaJe8bpLHnCwDKr932-G7dytD-Dmu1swZSAXcomDVmadSDtFlzAKI5loa26g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsans/v23/zYXGKVElMYYaJe8bpLHnCwDKr932-G7dytD-Dmu1swZSAXcomDVmadSD6llzAKI5loa26g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsans/v23/zYXGKVElMYYaJe8bpLHnCwDKr932-G7dytD-Dmu1swZSAXcomDVmadSD2FlzAKI5loa26g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsans/v23/zYXGKVElMYYaJe8bpLHnCwDKr932-G7dytD-Dmu1swZSAXcomDVmadSDNF5zAKI5loa26g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsans/v23/zYXGKVElMYYaJe8bpLHnCwDKr932-G7dytD-Dmu1swZSAXcomDVmadSDDV5zAKI5loa26g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ibmplexsans/v23/zYXEKVElMYYaJe8bpLHnCwDKhdTEG46kmUZQCX598fQbM4jw8V78x9OWIhqbQqg9tIOm6vje.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsans/v23/zYXEKVElMYYaJe8bpLHnCwDKhdTEG46kmUZQCX598fQbM4jw8V78x9OWIhobQ6g9tIOm6vje.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsans/v23/zYXEKVElMYYaJe8bpLHnCwDKhdTEG46kmUZQCX598fQbM4jw8V78x9OWIhrFQ6g9tIOm6vje.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ibmplexsans/v23/zYXEKVElMYYaJe8bpLHnCwDKhdTEG46kmUZQCX598fQbM4jw8V78x9OWIhqbQ6g9tIOm6vje.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsans/v23/zYXEKVElMYYaJe8bpLHnCwDKhdTEG46kmUZQCX598fQbM4jw8V78x9OWIhqpQ6g9tIOm6vje.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsans/v23/zYXEKVElMYYaJe8bpLHnCwDKhdTEG46kmUZQCX598fQbM4jw8V78x9OWIhpFRKg9tIOm6vje.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsans/v23/zYXEKVElMYYaJe8bpLHnCwDKhdTEG46kmUZQCX598fQbM4jw8V78x9OWIhp8RKg9tIOm6vje.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ibm-plex-sans-arabic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("34f00b30-37ad-4611-a893-30b10dfded38",-1380607068),$APP.$cljs$cst$2675$family$$,"IBM Plex Sans Arabic",$APP.$cljs$cst$725$name$$,"IBM Plex Sans Arabic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansarabic/v14/Qw3MZRtWPQCuHme67tEYUIx3Kh0PHR9N6YNe3PC5eMlAMg0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansarabic/v14/Qw3NZRtWPQCuHme67tEYUIx3Kh0PHR9N6YPy_dCTVsVJKxTs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansarabic/v14/Qw3NZRtWPQCuHme67tEYUIx3Kh0PHR9N6YOW_tCTVsVJKxTs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansarabic/v14/Qw3CZRtWPQCuHme67tEYUIx3Kh0PHR9N6bs61vSbfdlA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansarabic/v14/Qw3NZRtWPQCuHme67tEYUIx3Kh0PHR9N6YPO_9CTVsVJKxTs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansarabic/v14/Qw3NZRtWPQCuHme67tEYUIx3Kh0PHR9N6YPi-NCTVsVJKxTs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansarabic/v14/Qw3NZRtWPQCuHme67tEYUIx3Kh0PHR9N6YOG-dCTVsVJKxTs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ibm-plex-sans-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8b1a5c98-8a5b-4701-a545-3a629e0573d2",1581692450),$APP.$cljs$cst$2675$family$$,"IBM Plex Sans Condensed",$APP.$cljs$cst$725$name$$,"IBM Plex Sans Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanscondensed/v15/Gg8nN4UfRSqiPg7Jn2ZI12V4DCEwkj1E4LVeHY7KyKvBgYsMDhM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",
$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanscondensed/v15/Gg8hN4UfRSqiPg7Jn2ZI12V4DCEwkj1E4LVeHYas8M_LhakJHhOgBg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanscondensed/v15/Gg8gN4UfRSqiPg7Jn2ZI12V4DCEwkj1E4LVeHY5m6Yvrr4cFFwq5.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanscondensed/v15/Gg8iN4UfRSqiPg7Jn2ZI12V4DCEwkj1E4LVeHYas8GPqpYMnEhq5H1w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanscondensed/v15/Gg8gN4UfRSqiPg7Jn2ZI12V4DCEwkj1E4LVeHY4C6ovrr4cFFwq5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanscondensed/v15/Gg8iN4UfRSqiPg7Jn2ZI12V4DCEwkj1E4LVeHYas8AfppYMnEhq5H1w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanscondensed/v15/Gg8lN4UfRSqiPg7Jn2ZI12V4DCEwkj1E4LVeHbauwq_jhJsM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanscondensed/v15/Gg8nN4UfRSqiPg7Jn2ZI12V4DCEwkj1E4LVeHYasyKvBgYsMDhM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanscondensed/v15/Gg8gN4UfRSqiPg7Jn2ZI12V4DCEwkj1E4LVeHY5a64vrr4cFFwq5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanscondensed/v15/Gg8iN4UfRSqiPg7Jn2ZI12V4DCEwkj1E4LVeHYas8F_opYMnEhq5H1w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanscondensed/v15/Gg8gN4UfRSqiPg7Jn2ZI12V4DCEwkj1E4LVeHY527Ivrr4cFFwq5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanscondensed/v15/Gg8iN4UfRSqiPg7Jn2ZI12V4DCEwkj1E4LVeHYas8HPvpYMnEhq5H1w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ibmplexsanscondensed/v15/Gg8gN4UfRSqiPg7Jn2ZI12V4DCEwkj1E4LVeHY4S7Yvrr4cFFwq5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanscondensed/v15/Gg8iN4UfRSqiPg7Jn2ZI12V4DCEwkj1E4LVeHYas8BfupYMnEhq5H1w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-ibm-plex-sans-devanagari",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a4e58045-0329-45af-967d-61e7ebe3f241",-1723537191),$APP.$cljs$cst$2675$family$$,"IBM Plex Sans Devanagari",$APP.$cljs$cst$725$name$$,"IBM Plex Sans Devanagari",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",
$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansdevanagari/v12/XRXB3JCMvG4IDoS9SubXB6W-UX5iehIMBFR2-O_HMUjwUcjwCEQq.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansdevanagari/v12/XRXA3JCMvG4IDoS9SubXB6W-UX5iehIMBFR2-O_HnWnQe-b8AV0z0w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansdevanagari/v12/XRXA3JCMvG4IDoS9SubXB6W-UX5iehIMBFR2-O_H-WrQe-b8AV0z0w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansdevanagari/v12/XRXH3JCMvG4IDoS9SubXB6W-UX5iehIMBFR2-O__VUL0c83gCA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansdevanagari/v12/XRXA3JCMvG4IDoS9SubXB6W-UX5iehIMBFR2-O_HoWvQe-b8AV0z0w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansdevanagari/v12/XRXA3JCMvG4IDoS9SubXB6W-UX5iehIMBFR2-O_HjWzQe-b8AV0z0w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansdevanagari/v12/XRXA3JCMvG4IDoS9SubXB6W-UX5iehIMBFR2-O_H6W3Qe-b8AV0z0w.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ibm-plex-sans-hebrew",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a7c8edde-2b30-40c4-9414-464e9f83c701",-2011002721),$APP.$cljs$cst$2675$family$$,"IBM Plex Sans Hebrew",$APP.$cljs$cst$725$name$$,"IBM Plex Sans Hebrew",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanshebrew/v12/BCa4qYENg9Kw1mpLpO0bGM5lfHAAZHhDXEXB-l0VqDaM7C4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanshebrew/v12/BCa5qYENg9Kw1mpLpO0bGM5lfHAAZHhDXEVt230_hjqF9Tc2.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanshebrew/v12/BCa5qYENg9Kw1mpLpO0bGM5lfHAAZHhDXEUJ2H0_hjqF9Tc2.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanshebrew/v12/BCa2qYENg9Kw1mpLpO0bGM5lfHAAZHhDXH2l8Fk3rSaM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanshebrew/v12/BCa5qYENg9Kw1mpLpO0bGM5lfHAAZHhDXEVR2X0_hjqF9Tc2.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanshebrew/v12/BCa5qYENg9Kw1mpLpO0bGM5lfHAAZHhDXEV93n0_hjqF9Tc2.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanshebrew/v12/BCa5qYENg9Kw1mpLpO0bGM5lfHAAZHhDXEUZ330_hjqF9Tc2.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ibm-plex-sans-jp",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("66a64e01-6061-48e1-a830-5f08e3ef101e",1410651590),$APP.$cljs$cst$2675$family$$,"IBM Plex Sans JP",$APP.$cljs$cst$725$name$$,"IBM Plex Sans JP",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansjp/v7/Z9XLDn9KbTDf6_f7dISNqYf_tvPT7E7yjPB7twdmHQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansjp/v7/Z9XKDn9KbTDf6_f7dISNqYf_tvPT7OLTrNpVuw5_BAM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansjp/v7/Z9XKDn9KbTDf6_f7dISNqYf_tvPT7IbQrNpVuw5_BAM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansjp/v7/Z9XNDn9KbTDf6_f7dISNqYf_tvPT1Cr4iNJ-pwc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansjp/v7/Z9XKDn9KbTDf6_f7dISNqYf_tvPT7N7RrNpVuw5_BAM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansjp/v7/Z9XKDn9KbTDf6_f7dISNqYf_tvPT7PLWrNpVuw5_BAM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansjp/v7/Z9XKDn9KbTDf6_f7dISNqYf_tvPT7JbXrNpVuw5_BAM.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ibm-plex-sans-kr",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("12fdd47d-3aff-4cb9-989d-30014fd5ca02",2121234755),$APP.$cljs$cst$2675$family$$,"IBM Plex Sans KR",$APP.$cljs$cst$725$name$$,"IBM Plex Sans KR",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanskr/v11/vEFM2-VJISZe3O_rc3ZVYh4aTwNOyra_X5zCpMrMfA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanskr/v11/vEFN2-VJISZe3O_rc3ZVYh4aTwNOyhqef7bsqMPVZb4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanskr/v11/vEFN2-VJISZe3O_rc3ZVYh4aTwNOyn6df7bsqMPVZb4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanskr/v11/vEFK2-VJISZe3O_rc3ZVYh4aTwNO8tK1W77HtMo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanskr/v11/vEFN2-VJISZe3O_rc3ZVYh4aTwNOyiacf7bsqMPVZb4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanskr/v11/vEFN2-VJISZe3O_rc3ZVYh4aTwNOygqbf7bsqMPVZb4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsanskr/v11/vEFN2-VJISZe3O_rc3ZVYh4aTwNOym6af7bsqMPVZb4.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ibm-plex-sans-thai",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4f8bf857-5f8c-435a-8efb-dd3a68965213",347083172),$APP.$cljs$cst$2675$family$$,"IBM Plex Sans Thai",$APP.$cljs$cst$725$name$$,"IBM Plex Sans Thai",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansthai/v11/m8JNje1VVIzcq1HzJq2AEdo2Tj_qvLqEatYlR8ZKUqcX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansthai/v11/m8JMje1VVIzcq1HzJq2AEdo2Tj_qvLqExvcFbehGW74OXw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansthai/v11/m8JMje1VVIzcq1HzJq2AEdo2Tj_qvLqEovQFbehGW74OXw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansthai/v11/m8JPje1VVIzcq1HzJq2AEdo2Tj_qvLq8DtwhZcNaUg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansthai/v11/m8JMje1VVIzcq1HzJq2AEdo2Tj_qvLqE-vUFbehGW74OXw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansthai/v11/m8JMje1VVIzcq1HzJq2AEdo2Tj_qvLqE1vIFbehGW74OXw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansthai/v11/m8JMje1VVIzcq1HzJq2AEdo2Tj_qvLqEsvMFbehGW74OXw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ibm-plex-sans-thai-looped",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6cb4e08b-57e3-45ed-998f-3fa812b61e54",1889424134),$APP.$cljs$cst$2675$family$$,"IBM Plex Sans Thai Looped",$APP.$cljs$cst$725$name$$,"IBM Plex Sans Thai Looped",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansthailooped/v12/tss5AoJJRAhL3BTrK3r2xxbFhvKfyBB6l7hHT30L_HaKpHOtFCQ76Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansthailooped/v12/tss6AoJJRAhL3BTrK3r2xxbFhvKfyBB6l7hHT30L_NqrhFmDGC0i8Cc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansthailooped/v12/tss6AoJJRAhL3BTrK3r2xxbFhvKfyBB6l7hHT30L_L6ohFmDGC0i8Cc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansthailooped/v12/tss_AoJJRAhL3BTrK3r2xxbFhvKfyBB6l7hHT30LxBKAoFGoBCQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansthailooped/v12/tss6AoJJRAhL3BTrK3r2xxbFhvKfyBB6l7hHT30L_OaphFmDGC0i8Cc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansthailooped/v12/tss6AoJJRAhL3BTrK3r2xxbFhvKfyBB6l7hHT30L_MquhFmDGC0i8Cc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexsansthailooped/v12/tss6AoJJRAhL3BTrK3r2xxbFhvKfyBB6l7hHT30L_K6vhFmDGC0i8Cc.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ibm-plex-serif",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d28c1f16-b0a4-4fdd-8505-392a88965795",-1266512576),$APP.$cljs$cst$2675$family$$,"IBM Plex Serif",$APP.$cljs$cst$725$name$$,"IBM Plex Serif",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",
$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexserif/v20/jizBREVNn1dOx-zrZ2X3pZvkTi182zIZj1bIkNo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexserif/v20/jizHREVNn1dOx-zrZ2X3pZvkTiUa41YTi3TNgNq55w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexserif/v20/jizAREVNn1dOx-zrZ2X3pZvkTi3Q-hIzoVrBicOg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexserif/v20/jizGREVNn1dOx-zrZ2X3pZvkTiUa4_oyq17jjNOg_oc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexserif/v20/jizAREVNn1dOx-zrZ2X3pZvkTi20-RIzoVrBicOg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexserif/v20/jizGREVNn1dOx-zrZ2X3pZvkTiUa454xq17jjNOg_oc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexserif/v20/jizDREVNn1dOx-zrZ2X3pZvkThUY0TY7ikbI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexserif/v20/jizBREVNn1dOx-zrZ2X3pZvkTiUa2zIZj1bIkNo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexserif/v20/jizAREVNn1dOx-zrZ2X3pZvkTi3s-BIzoVrBicOg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexserif/v20/jizGREVNn1dOx-zrZ2X3pZvkTiUa48Ywq17jjNOg_oc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexserif/v20/jizAREVNn1dOx-zrZ2X3pZvkTi3A_xIzoVrBicOg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexserif/v20/jizGREVNn1dOx-zrZ2X3pZvkTiUa4-o3q17jjNOg_oc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexserif/v20/jizAREVNn1dOx-zrZ2X3pZvkTi2k_hIzoVrBicOg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibmplexserif/v20/jizGREVNn1dOx-zrZ2X3pZvkTiUa4442q17jjNOg_oc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-im-fell-dw-pica",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("945d3c64-fef6-437a-a5f3-dd38a8ed6617",1554452982),$APP.$cljs$cst$2675$family$$,"IM Fell DW Pica",$APP.$cljs$cst$725$name$$,"IM Fell DW Pica",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfelldwpica/v16/2sDGZGRQotv9nbn2qSl0TxXVYNw9ZAPUvi88MQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfelldwpica/v16/2sDEZGRQotv9nbn2qSl0TxXVYNwNZgnQnCosMXm0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-im-fell-dw-pica-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("33f8277d-833e-4f6c-8c6c-6d6e2173a6da",777146779),$APP.$cljs$cst$2675$family$$,"IM Fell DW Pica SC",$APP.$cljs$cst$725$name$$,"IM Fell DW Pica SC",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfelldwpicasc/v21/0ybjGCAu5PfqkvtGVU15aBhXz3EUrnTW-BiKEUiBGA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-im-fell-double-pica",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("730bceea-e66b-4fa5-9f2b-6921452cb0f2",-689978282),$APP.$cljs$cst$2675$family$$,"IM Fell Double Pica",$APP.$cljs$cst$725$name$$,"IM Fell Double Pica",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfelldoublepica/v14/3XF2EqMq_94s9PeKF7Fg4gOKINyMtZ8rT0S1UL5Ayp0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfelldoublepica/v14/3XF0EqMq_94s9PeKF7Fg4gOKINyMtZ8rf0a_VJxF2p2G8g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-im-fell-double-pica-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dbdb25b4-6af3-4a5d-b794-0e0c6f3f768f",2049265892),$APP.$cljs$cst$2675$family$$,"IM Fell Double Pica SC",$APP.$cljs$cst$725$name$$,"IM Fell Double Pica SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfelldoublepicasc/v21/neIazDmuiMkFo6zj_sHpQ8teNbWlwBB_hXjJ4Y0Eeru2dGg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-im-fell-english",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7cd8e274-dfab-4dca-ae04-d21abd86327f",-565514366),$APP.$cljs$cst$2675$family$$,"IM Fell English",$APP.$cljs$cst$725$name$$,"IM Fell English",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfellenglish/v14/Ktk1ALSLW8zDe0rthJysWrnLsAz3F6mZVY9Y5w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,
"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfellenglish/v14/Ktk3ALSLW8zDe0rthJysWrnLsAzHFaOdd4pI59zg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-im-fell-english-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("41e0beb7-0ebf-4ea0-8399-f4135d70a795",-528700197),$APP.$cljs$cst$2675$family$$,"IM Fell English SC",$APP.$cljs$cst$725$name$$,"IM Fell English SC",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfellenglishsc/v16/a8IENpD3CDX-4zrWfr1VY879qFF05pZLO4gOg0shzA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-im-fell-french-canon",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0d3119ad-8826-46c6-8a9c-9f96669b6fbc",-1100522972),$APP.$cljs$cst$2675$family$$,"IM Fell French Canon",$APP.$cljs$cst$725$name$$,"IM Fell French Canon",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfellfrenchcanon/v21/-F6ufiNtDWYfYc-tDiyiw08rrghJszkK6coVPt1ozoPz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfellfrenchcanon/v21/-F6gfiNtDWYfYc-tDiyiw08rrghJszkK6foXNNlKy5PzzrU.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-im-fell-french-canon-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("05594521-7e9e-4066-886b-3e7f3fd9bfa8",-1300222457),$APP.$cljs$cst$2675$family$$,"IM Fell French Canon SC",$APP.$cljs$cst$725$name$$,"IM Fell French Canon SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfellfrenchcanonsc/v23/FBVmdCru5-ifcor2bgq9V89khWcmQghEURY7H3c0UBCVIVqH.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-im-fell-great-primer",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("94f83122-53cf-4464-a497-836fd5de4d8a",579931544),$APP.$cljs$cst$2675$family$$,"IM Fell Great Primer",
$APP.$cljs$cst$725$name$$,"IM Fell Great Primer",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfellgreatprimer/v21/bx6aNwSJtayYxOkbYFsT6hMsLzX7u85rJorXvDo3SQY1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfellgreatprimer/v21/bx6UNwSJtayYxOkbYFsT6hMsLzX7u85rJrrVtj4VTBY1N6U.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-im-fell-great-primer-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3b083ecd-c7c6-446b-a505-6cbb53fa4ffe",423048241),$APP.$cljs$cst$2675$family$$,
"IM Fell Great Primer SC",$APP.$cljs$cst$725$name$$,"IM Fell Great Primer SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imfellgreatprimersc/v21/ga6daxBOxyt6sCqz3fjZCTFCTUDMHagsQKdDTLf9BXz0s8FG.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-iansui",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("476224f9-49a3-4b79-88d2-8b6ead202a2d",-1018002305),$APP.$cljs$cst$2675$family$$,"Iansui",$APP.$cljs$cst$725$name$$,"Iansui",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/iansui/v7/w8gbH2UoTuUp5bOajSGD1FcXoQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ibarra-real-nova",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7903b310-2ebf-4a12-b27a-817bca4298f8",-330930562),$APP.$cljs$cst$2675$family$$,"Ibarra Real Nova",$APP.$cljs$cst$725$name$$,"Ibarra Real Nova",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibarrarealnova/v30/sZlSdQiA-DBIDCcaWtQzL4BZHoiDundw4ATyjed3EXdg5MDtVT9TWIvS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",
$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibarrarealnova/v30/sZlSdQiA-DBIDCcaWtQzL4BZHoiDundw4ATyjed3EXdS5MDtVT9TWIvS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibarrarealnova/v30/sZlSdQiA-DBIDCcaWtQzL4BZHoiDundw4ATyjed3EXe-48DtVT9TWIvS.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibarrarealnova/v30/sZlSdQiA-DBIDCcaWtQzL4BZHoiDundw4ATyjed3EXeH48DtVT9TWIvS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibarrarealnova/v30/sZlsdQiA-DBIDCcaWtQzL4BZHoiDkH5CH9yb5n3ZFmKopyiuXztxXZvSkTo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibarrarealnova/v30/sZlsdQiA-DBIDCcaWtQzL4BZHoiDkH5CH9yb5n3ZFmKopxquXztxXZvSkTo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ibarrarealnova/v30/sZlsdQiA-DBIDCcaWtQzL4BZHoiDkH5CH9yb5n3ZFmKop_apXztxXZvSkTo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ibarrarealnova/v30/sZlsdQiA-DBIDCcaWtQzL4BZHoiDkH5CH9yb5n3ZFmKop8-pXztxXZvSkTo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-iceberg",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1abda4fc-b6b9-483d-9ba3-3d94fa1946a4",-1362414504),$APP.$cljs$cst$2675$family$$,"Iceberg",$APP.$cljs$cst$725$name$$,"Iceberg",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/iceberg/v26/8QIJdijAiM7o-qnZuIgOq7jkAOw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-iceland",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4ed306f2-f6ad-41f2-89bf-4eec0e92f3a2",1210812023),$APP.$cljs$cst$2675$family$$,
"Iceland",$APP.$cljs$cst$725$name$$,"Iceland",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/iceland/v22/rax9HiuFsdMNOnWPWKxGADBbg0s.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-imbue",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d1f8b48c-1d8a-4ff5-8c6d-493930e3bb15",514207538),$APP.$cljs$cst$2675$family$$,"Imbue",$APP.$cljs$cst$725$name$$,"Imbue",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imbue/v29/RLpXK5P16Ki3fXhj5cvGrqjocPk4n-gVX3M93TnrnvhoP8iWfOsNNK-Q4xY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imbue/v29/RLpXK5P16Ki3fXhj5cvGrqjocPk4n-gVX3M93TnrnvhoP0iXfOsNNK-Q4xY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imbue/v29/RLpXK5P16Ki3fXhj5cvGrqjocPk4n-gVX3M93TnrnvhoP5aXfOsNNK-Q4xY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imbue/v29/RLpXK5P16Ki3fXhj5cvGrqjocPk4n-gVX3M93TnrnvhoP8iXfOsNNK-Q4xY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imbue/v29/RLpXK5P16Ki3fXhj5cvGrqjocPk4n-gVX3M93TnrnvhoP_qXfOsNNK-Q4xY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imbue/v29/RLpXK5P16Ki3fXhj5cvGrqjocPk4n-gVX3M93TnrnvhoPxaQfOsNNK-Q4xY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imbue/v29/RLpXK5P16Ki3fXhj5cvGrqjocPk4n-gVX3M93TnrnvhoPy-QfOsNNK-Q4xY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imbue/v29/RLpXK5P16Ki3fXhj5cvGrqjocPk4n-gVX3M93TnrnvhoP0iQfOsNNK-Q4xY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imbue/v29/RLpXK5P16Ki3fXhj5cvGrqjocPk4n-gVX3M93TnrnvhoP2GQfOsNNK-Q4xY.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-imperial-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dd96222d-27b8-47e2-bae6-8b0c9e13b50b",-1393989488),$APP.$cljs$cst$2675$family$$,"Imperial Script",$APP.$cljs$cst$725$name$$,"Imperial Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imperialscript/v8/5DCPAKrpzy_H98IV2ISnZBbGrVNvPenlvttWNg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-imprima",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("718afb5a-1380-488f-9899-0883ed844d01",477630447),$APP.$cljs$cst$2675$family$$,"Imprima",$APP.$cljs$cst$725$name$$,"Imprima",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/imprima/v19/VEMxRoN7sY3yuy-7-oWHyDzktPo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-inclusive-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("493a14e0-c75d-4d97-a46f-617669db8e73",-515585311),$APP.$cljs$cst$2675$family$$,"Inclusive Sans",$APP.$cljs$cst$725$name$$,"Inclusive Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inclusivesans/v4/0nk8C9biPuwflXcJ46P4PGWE08T-gfZusL0kQqtfLhtN7mxtc0bIsQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inclusivesans/v4/0nk8C9biPuwflXcJ46P4PGWE08T-gfZusL0kQqtfcBtN7mxtc0bIsQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inclusivesans/v4/0nk8C9biPuwflXcJ46P4PGWE08T-gfZusL0kQqtfQhtN7mxtc0bIsQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inclusivesans/v4/0nk8C9biPuwflXcJ46P4PGWE08T-gfZusL0kQqtfrhxN7mxtc0bIsQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inclusivesans/v4/0nk8C9biPuwflXcJ46P4PGWE08T-gfZusL0kQqtflxxN7mxtc0bIsQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inclusivesans/v4/0nk-C9biPuwflXcJ46P4PGWE0-73swm22da-7KxKuFj7rWZpUUPYsTVx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inclusivesans/v4/0nk-C9biPuwflXcJ46P4PGWE0-73swm22da-7KxKuFilrWZpUUPYsTVx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inclusivesans/v4/0nk-C9biPuwflXcJ46P4PGWE0-73swm22da-7KxKuFiXrWZpUUPYsTVx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/inclusivesans/v4/0nk-C9biPuwflXcJ46P4PGWE0-73swm22da-7KxKuFh7qmZpUUPYsTVx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inclusivesans/v4/0nk-C9biPuwflXcJ46P4PGWE0-73swm22da-7KxKuFhCqmZpUUPYsTVx.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-inconsolata",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2335c5ef-ee56-4e92-8c58-9fb520d3010f",-1603485771),$APP.$cljs$cst$2675$family$$,"Inconsolata",$APP.$cljs$cst$725$name$$,"Inconsolata",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inconsolata/v37/QldgNThLqRwH-OJ1UHjlKENVzkWGVkL3GZQmAwLYxYWI2qfdm7LppwU8aRr8lleY2co.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inconsolata/v37/QldgNThLqRwH-OJ1UHjlKENVzkWGVkL3GZQmAwLYxYWI2qfdm7Lpp9s8aRr8lleY2co.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inconsolata/v37/QldgNThLqRwH-OJ1UHjlKENVzkWGVkL3GZQmAwLYxYWI2qfdm7Lpp4U8aRr8lleY2co.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inconsolata/v37/QldgNThLqRwH-OJ1UHjlKENVzkWGVkL3GZQmAwLYxYWI2qfdm7Lpp7c8aRr8lleY2co.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inconsolata/v37/QldgNThLqRwH-OJ1UHjlKENVzkWGVkL3GZQmAwLYxYWI2qfdm7Lpp1s7aRr8lleY2co.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inconsolata/v37/QldgNThLqRwH-OJ1UHjlKENVzkWGVkL3GZQmAwLYxYWI2qfdm7Lpp2I7aRr8lleY2co.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inconsolata/v37/QldgNThLqRwH-OJ1UHjlKENVzkWGVkL3GZQmAwLYxYWI2qfdm7LppwU7aRr8lleY2co.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inconsolata/v37/QldgNThLqRwH-OJ1UHjlKENVzkWGVkL3GZQmAwLYxYWI2qfdm7Lppyw7aRr8lleY2co.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-inder",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f6b818fd-70da-4a83-a0b3-71ea16e62cf7",-417844760),$APP.$cljs$cst$2675$family$$,
"Inder",$APP.$cljs$cst$725$name$$,"Inder",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inder/v15/w8gUH2YoQe8_4vq6pw-P3U4O.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-indie-flower",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9a5348fa-6ac7-4c6c-bd7b-d3f0de5bad4f",-1665964207),$APP.$cljs$cst$2675$family$$,"Indie Flower",$APP.$cljs$cst$725$name$$,"Indie Flower",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/indieflower/v24/m8JVjfNVeKWVnh3QMuKkFcZlbkGG1dKEDw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ingrid-darling",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("20911e67-e802-4b01-943a-f9882e932ab3",1036648332),$APP.$cljs$cst$2675$family$$,"Ingrid Darling",$APP.$cljs$cst$725$name$$,"Ingrid Darling",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ingriddarling/v7/LDIrapaJNxUtSuFdw-9yf4rCPsLOub458jGL.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-inika",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9727d0a6-acf6-4414-ace5-16a3da1b7c6e",
1414398092),$APP.$cljs$cst$2675$family$$,"Inika",$APP.$cljs$cst$725$name$$,"Inika",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inika/v22/rnCm-x5X3QP-phTHRcc2s2XH.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inika/v22/rnCr-x5X3QP-pix7auM-mHnOSOuk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-inknut-antiqua",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("baa20519-14f1-413d-9be3-8e35b2961879",-1136483049),$APP.$cljs$cst$2675$family$$,"Inknut Antiqua",$APP.$cljs$cst$725$name$$,
"Inknut Antiqua",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inknutantiqua/v16/Y4GRYax7VC4ot_qNB4nYpBdaKU2vwrj5bBoIYJNf.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inknutantiqua/v16/Y4GSYax7VC4ot_qNB4nYpBdaKXUD6pzxRwYB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inknutantiqua/v16/Y4GRYax7VC4ot_qNB4nYpBdaKU33w7j5bBoIYJNf.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inknutantiqua/v16/Y4GRYax7VC4ot_qNB4nYpBdaKU3bxLj5bBoIYJNf.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/inknutantiqua/v16/Y4GRYax7VC4ot_qNB4nYpBdaKU2_xbj5bBoIYJNf.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inknutantiqua/v16/Y4GRYax7VC4ot_qNB4nYpBdaKU2jxrj5bBoIYJNf.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,
"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inknutantiqua/v16/Y4GRYax7VC4ot_qNB4nYpBdaKU2Hx7j5bBoIYJNf.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-inria-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5b77e274-be21-4055-acb0-61a268537609",2144783450),$APP.$cljs$cst$2675$family$$,"Inria Sans",$APP.$cljs$cst$725$name$$,"Inria Sans",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inriasans/v15/ptRPTiqXYfZMCOiVj9kQ3ELaDQtFqeY3fX4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,
"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inriasans/v15/ptRRTiqXYfZMCOiVj9kQ1OzAgQlPrcQybX4pQA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inriasans/v15/ptRMTiqXYfZMCOiVj9kQ5O7yKQNute8.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inriasans/v15/ptROTiqXYfZMCOiVj9kQ1Oz4LSFrpe8uZA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/inriasans/v15/ptRPTiqXYfZMCOiVj9kQ3FLdDQtFqeY3fX4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inriasans/v15/ptRRTiqXYfZMCOiVj9kQ1OzAkQ5PrcQybX4pQA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-inria-serif",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7168ebcd-a1fd-442f-b063-ae1a1e3e609c",-1928887342),$APP.$cljs$cst$2675$family$$,"Inria Serif",$APP.$cljs$cst$725$name$$,"Inria Serif",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/inriaserif/v18/fC14PYxPY3rXxEndZJAzN3wAVQjFhFyta3xN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inriaserif/v18/fC16PYxPY3rXxEndZJAzN3SuT4THjliPbmxN0_E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inriaserif/v18/fC1lPYxPY3rXxEndZJAzN0SsfSzNr0Ck.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inriaserif/v18/fC1nPYxPY3rXxEndZJAzN3SudyjvqlCkcmU.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inriaserif/v18/fC14PYxPY3rXxEndZJAzN3wQUgjFhFyta3xN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/inriaserif/v18/fC16PYxPY3rXxEndZJAzN3SuT5TAjliPbmxN0_E.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-inspiration",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("67abb4ef-7221-4b77-aef6-4b3a0fe8c7fe",2052483879),$APP.$cljs$cst$2675$family$$,"Inspiration",$APP.$cljs$cst$725$name$$,"Inspiration",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inspiration/v7/x3dkckPPZa6L4wIg5cZOEvoGnSrlBBsy.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-instrument-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4bfa2d09-77cc-4de2-8d68-5f1129860d38",1357266484),
$APP.$cljs$cst$2675$family$$,"Instrument Sans",$APP.$cljs$cst$725$name$$,"Instrument Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/instrumentsans/v4/pximypc9vsFDm051Uf6KVwgkfoSxQ0GsQv8ToedPibnr-yp2JGEJOH9npSTF-Qf1mS0v3_7Y.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/instrumentsans/v4/pximypc9vsFDm051Uf6KVwgkfoSxQ0GsQv8ToedPibnr-yp2JGEJOH9npST3-Qf1mS0v3_7Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/instrumentsans/v4/pximypc9vsFDm051Uf6KVwgkfoSxQ0GsQv8ToedPibnr-yp2JGEJOH9npSQb_gf1mS0v3_7Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/instrumentsans/v4/pximypc9vsFDm051Uf6KVwgkfoSxQ0GsQv8ToedPibnr-yp2JGEJOH9npSQi_gf1mS0v3_7Y.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/instrumentsans/v4/pxigypc9vsFDm051Uf6KVwgkfoSbSnNPooZAN0lInHGpCWNE27lgU-XJojENuu-2kykN2u7YUwU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/instrumentsans/v4/pxigypc9vsFDm051Uf6KVwgkfoSbSnNPooZAN0lInHGpCWNE27lgU-XJojENut22kykN2u7YUwU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/instrumentsans/v4/pxigypc9vsFDm051Uf6KVwgkfoSbSnNPooZAN0lInHGpCWNE27lgU-XJojENujGxkykN2u7YUwU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/instrumentsans/v4/pxigypc9vsFDm051Uf6KVwgkfoSbSnNPooZAN0lInHGpCWNE27lgU-XJojENugixkykN2u7YUwU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-instrument-serif",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3933e9df-b9ae-480f-8942-7bb38f86f81f",
1032625596),$APP.$cljs$cst$2675$family$$,"Instrument Serif",$APP.$cljs$cst$725$name$$,"Instrument Serif",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/instrumentserif/v5/jizBRFtNs2ka5fXjeivQ4LroWlx-2zIZj1bIkNo.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/instrumentserif/v5/jizHRFtNs2ka5fXjeivQ4LroWlx-6zATi3TNgNq55w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-intel-one-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3d8bd850-2a14-4684-a811-ad881bb91ced",
532186205),$APP.$cljs$cst$2675$family$$,"Intel One Mono",$APP.$cljs$cst$725$name$$,"Intel One Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intelonemono/v2/P5sWzZuLY8Lb_G1RikFkwPjBvuM8LXucmoHDSAMg__cRnD9TMr2nYA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intelonemono/v2/P5sUzZuLY8Lb_G1RikFkwPjBvsk1H4RE8-pZ5gQ1abSn3zVXELi3YD27.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intelonemono/v2/P5sWzZuLY8Lb_G1RikFkwPjBvuM8LXucmoHDSAMgofcRnD9TMr2nYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intelonemono/v2/P5sUzZuLY8Lb_G1RikFkwPjBvsk1H4RE8-pZ5gQ1abT53zVXELi3YD27.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intelonemono/v2/P5sWzZuLY8Lb_G1RikFkwPjBvuM8LXucmoHDSAMgk_cRnD9TMr2nYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intelonemono/v2/P5sUzZuLY8Lb_G1RikFkwPjBvsk1H4RE8-pZ5gQ1abTL3zVXELi3YD27.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intelonemono/v2/P5sWzZuLY8Lb_G1RikFkwPjBvuM8LXucmoHDSAMgf_ARnD9TMr2nYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intelonemono/v2/P5sUzZuLY8Lb_G1RikFkwPjBvsk1H4RE8-pZ5gQ1abQn2DVXELi3YD27.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intelonemono/v2/P5sWzZuLY8Lb_G1RikFkwPjBvuM8LXucmoHDSAMgRvARnD9TMr2nYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intelonemono/v2/P5sUzZuLY8Lb_G1RikFkwPjBvsk1H4RE8-pZ5gQ1abQe2DVXELi3YD27.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-inter",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b66f794e-1455-4f81-81e8-56988b657e41",1169574838),$APP.$cljs$cst$2675$family$$,
"Inter",$APP.$cljs$cst$725$name$$,"Inter",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCO3FwrK3iLTeHuS_nVMrMxCp50SjIw2boKoduKmMEVuLyeMZhrib2Bg-4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCO3FwrK3iLTeHuS_nVMrMxCp50SjIw2boKoduKmMEVuDyfMZhrib2Bg-4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCO3FwrK3iLTeHuS_nVMrMxCp50SjIw2boKoduKmMEVuOKfMZhrib2Bg-4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCO3FwrK3iLTeHuS_nVMrMxCp50SjIw2boKoduKmMEVuLyfMZhrib2Bg-4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCO3FwrK3iLTeHuS_nVMrMxCp50SjIw2boKoduKmMEVuI6fMZhrib2Bg-4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCO3FwrK3iLTeHuS_nVMrMxCp50SjIw2boKoduKmMEVuGKYMZhrib2Bg-4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCO3FwrK3iLTeHuS_nVMrMxCp50SjIw2boKoduKmMEVuFuYMZhrib2Bg-4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCO3FwrK3iLTeHuS_nVMrMxCp50SjIw2boKoduKmMEVuDyYMZhrib2Bg-4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCO3FwrK3iLTeHuS_nVMrMxCp50SjIw2boKoduKmMEVuBWYMZhrib2Bg-4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCM3FwrK3iLTcvneQg7Ca725JhhKnNqk4j1ebLhAm8SrXTc2dphjZ-Ek-7MeA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCM3FwrK3iLTcvneQg7Ca725JhhKnNqk4j1ebLhAm8SrXTcWdthjZ-Ek-7MeA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCM3FwrK3iLTcvneQg7Ca725JhhKnNqk4j1ebLhAm8SrXTch9thjZ-Ek-7MeA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/inter/v20/UcCM3FwrK3iLTcvneQg7Ca725JhhKnNqk4j1ebLhAm8SrXTc2dthjZ-Ek-7MeA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCM3FwrK3iLTcvneQg7Ca725JhhKnNqk4j1ebLhAm8SrXTc69thjZ-Ek-7MeA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCM3FwrK3iLTcvneQg7Ca725JhhKnNqk4j1ebLhAm8SrXTcB9xhjZ-Ek-7MeA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCM3FwrK3iLTcvneQg7Ca725JhhKnNqk4j1ebLhAm8SrXTcPtxhjZ-Ek-7MeA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCM3FwrK3iLTcvneQg7Ca725JhhKnNqk4j1ebLhAm8SrXTcWdxhjZ-Ek-7MeA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/inter/v20/UcCM3FwrK3iLTcvneQg7Ca725JhhKnNqk4j1ebLhAm8SrXTccNxhjZ-Ek-7MeA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-inter-tight",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("02516fcd-e9e3-4b22-bc28-e7ba0958cfc8",1634261587),$APP.$cljs$cst$2675$family$$,"Inter Tight",$APP.$cljs$cst$725$name$$,"Inter Tight",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGSnv5HMAFg6IuGlBNMjxJEL2VmU3NS7Z2mjDw6qXCRToK8EPg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGSnv5HMAFg6IuGlBNMjxJEL2VmU3NS7Z2mjjw-qXCRToK8EPg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGSnv5HMAFg6IuGlBNMjxJEL2VmU3NS7Z2mjUQ-qXCRToK8EPg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGSnv5HMAFg6IuGlBNMjxJEL2VmU3NS7Z2mjDw-qXCRToK8EPg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGSnv5HMAFg6IuGlBNMjxJEL2VmU3NS7Z2mjPQ-qXCRToK8EPg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGSnv5HMAFg6IuGlBNMjxJEL2VmU3NS7Z2mj0QiqXCRToK8EPg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGSnv5HMAFg6IuGlBNMjxJEL2VmU3NS7Z2mj6AiqXCRToK8EPg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGSnv5HMAFg6IuGlBNMjxJEL2VmU3NS7Z2mjjwiqXCRToK8EPg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGSnv5HMAFg6IuGlBNMjxJEL2VmU3NS7Z2mjpgiqXCRToK8EPg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGShv5HMAFg6IuGlBNMjxLsC66ZMtb8hyW62x0xCHi5XgqoUPvi5.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGShv5HMAFg6IuGlBNMjxLsC66ZMtb8hyW62x0zCHy5XgqoUPvi5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGShv5HMAFg6IuGlBNMjxLsC66ZMtb8hyW62x0wcHy5XgqoUPvi5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGShv5HMAFg6IuGlBNMjxLsC66ZMtb8hyW62x0xCHy5XgqoUPvi5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGShv5HMAFg6IuGlBNMjxLsC66ZMtb8hyW62x0xwHy5XgqoUPvi5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/intertight/v9/NGShv5HMAFg6IuGlBNMjxLsC66ZMtb8hyW62x0ycGC5XgqoUPvi5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGShv5HMAFg6IuGlBNMjxLsC66ZMtb8hyW62x0ylGC5XgqoUPvi5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGShv5HMAFg6IuGlBNMjxLsC66ZMtb8hyW62x0zCGC5XgqoUPvi5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/intertight/v9/NGShv5HMAFg6IuGlBNMjxLsC66ZMtb8hyW62x0zrGC5XgqoUPvi5.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-irish-grover",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7887a1ef-0228-47ee-aec3-d9a6309a515d",835941800),$APP.$cljs$cst$2675$family$$,"Irish Grover",$APP.$cljs$cst$725$name$$,"Irish Grover",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/irishgrover/v23/buExpoi6YtLz2QW7LA4flVgf-P5Oaiw4cw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-island-moments",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("56b33611-b72f-49df-96bd-ef9d67ee2cec",244773783),$APP.$cljs$cst$2675$family$$,"Island Moments",$APP.$cljs$cst$725$name$$,"Island Moments",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/islandmoments/v8/NaPBcZfVGvBdxIt7Ar0qzkXJF-TGIohbZ6SY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-istok-web",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("22d63fcf-243f-41b4-8e93-56f616fa88f1",791229540),$APP.$cljs$cst$2675$family$$,"Istok Web",$APP.$cljs$cst$725$name$$,"Istok Web",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/istokweb/v26/3qTvojGmgSyUukBzKslZAWF-9kIIaQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/istokweb/v26/3qTpojGmgSyUukBzKslpA2t61EcYaQ7F.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/istokweb/v26/3qTqojGmgSyUukBzKslhvU5a_mkUYBfcMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/istokweb/v26/3qT0ojGmgSyUukBzKslpA1PG-2MQQhLMMygN.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-italiana",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d62c2d23-772f-45eb-84f7-7a6025a46f53",-1841261912),$APP.$cljs$cst$2675$family$$,"Italiana",$APP.$cljs$cst$725$name$$,"Italiana",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/italiana/v21/QldNNTtLsx4E__B0XTmRY31Wx7Vv.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-italianno",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d18e3fbf-cda5-4ef8-9434-1d8b0adc929b",-330537709),$APP.$cljs$cst$2675$family$$,"Italianno",$APP.$cljs$cst$725$name$$,"Italianno",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/italianno/v18/dg4n_p3sv6gCJkwzT6Rnj5YpQwM-gg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-itim",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3fe4a5fa-cb21-4503-9cf5-dadc8df4437b",
-1573587412),$APP.$cljs$cst$2675$family$$,"Itim",$APP.$cljs$cst$725$name$$,"Itim",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/itim/v16/0nknC9ziJOYewARKkc7ZdwU.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jacquard-12",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("85000c99-eb0b-46a5-8a21-6349f45534b9",-288038468),$APP.$cljs$cst$2675$family$$,"Jacquard 12",$APP.$cljs$cst$725$name$$,"Jacquard 12",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jacquard12/v8/vm8ydRLuXETEweL79J4rGc3JUnr34c9-.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jacquard-12-charted",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("da56542c-d2ca-42e3-934a-f03ea836dd9f",956745266),$APP.$cljs$cst$2675$family$$,"Jacquard 12 Charted",$APP.$cljs$cst$725$name$$,"Jacquard 12 Charted",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jacquard12charted/v4/i7dWIE97bzCOB9Q_Up6PQmYfKDPIb2HwT3StZ9jetKY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jacquard-24",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("24efc2a2-08de-41ef-b32e-d3e5e9d75dbe",967826337),$APP.$cljs$cst$2675$family$$,"Jacquard 24",$APP.$cljs$cst$725$name$$,"Jacquard 24",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/jacquard24/v4/jVyO7nf_B2zO5jVpUGU8lgQEdchf9xXp.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jacquard-24-charted",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7b0a9c10-aa80-43f1-9dc2-3598f32c93a2",-159631898),$APP.$cljs$cst$2675$family$$,"Jacquard 24 Charted",$APP.$cljs$cst$725$name$$,"Jacquard 24 Charted",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jacquard24charted/v5/mtGm4-dNK6HaudrE9VVKhENTsEXEYish0iRrMYJ_K-4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jacquarda-bastarda-9",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3fefcedb-56be-469f-8e03-c8df918a25d4",
-1171910621),$APP.$cljs$cst$2675$family$$,"Jacquarda Bastarda 9",$APP.$cljs$cst$725$name$$,"Jacquarda Bastarda 9",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jacquardabastarda9/v6/f0Xp0fWr_8t6WFtKQJfOhaC0hcZ1HYAMAbwD1TB_JHHY.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jacquarda-bastarda-9-charted",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("73e1a229-114b-451a-b196-96ed2ccc7b8b",-1867801308),$APP.$cljs$cst$2675$family$$,"Jacquarda Bastarda 9 Charted",$APP.$cljs$cst$725$name$$,"Jacquarda Bastarda 9 Charted",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jacquardabastarda9charted/v4/Yq6D-KaMUyfq4qLgx19A_ocp43FeLd9m0vDxm-yf8JPuf0cPaL8pmQg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jacques-francois",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("753c17db-1892-4e77-9cf6-c40d8f953bf5",860948642),$APP.$cljs$cst$2675$family$$,
"Jacques Francois",$APP.$cljs$cst$725$name$$,"Jacques Francois",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jacquesfrancois/v26/ZXu9e04ZvKeOOHIe1TMahbcIU2cgmcPqoeRWfbs.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jacques-francois-shadow",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d9e34d23-d819-4e1d-a6f6-096102c00b16",-438298195),$APP.$cljs$cst$2675$family$$,"Jacques Francois Shadow",$APP.$cljs$cst$725$name$$,"Jacques Francois Shadow",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jacquesfrancoisshadow/v27/KR1FBtOz8PKTMk-kqdkLVrvR0ECFrB6Pin-2_q8VsHuV5ULS.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jaini",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("35488a88-00f4-404f-9bf6-84c242f7aa01",46159840),$APP.$cljs$cst$2675$family$$,"Jaini",$APP.$cljs$cst$725$name$$,
"Jaini",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jaini/v1/fC1vPYJMbGHQzEmOK-ZSUHyt.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-jaini-purva",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("56336593-d7be-43b4-91b8-34233c31c814",-247086828),$APP.$cljs$cst$2675$family$$,"Jaini Purva",$APP.$cljs$cst$725$name$$,"Jaini Purva",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jainipurva/v1/CHynV-vdHVXwbWcUswbUGHoOHH4sj3lR.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jaldi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3d66db29-17c5-409f-9059-fc1e59c12f46",-1077336672),$APP.$cljs$cst$2675$family$$,"Jaldi",$APP.$cljs$cst$725$name$$,"Jaldi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jaldi/v14/or3sQ67z0_CI30NUZpD_B6g8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jaldi/v14/or3hQ67z0_CI33voSbT3LLQ1niPn.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jaro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c100829f-7156-4c85-8b00-53c7abc75292",-1895766435),$APP.$cljs$cst$2675$family$$,"Jaro",$APP.$cljs$cst$725$name$$,"Jaro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jaro/v8/ea8DadQwV_r_Rv3-7zZMCGhQgVr1SlCsNP3VpQ_a.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jersey-10",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("368d63fe-22f9-4bf5-906d-838a898847e7",-1397889488),$APP.$cljs$cst$2675$family$$,"Jersey 10",$APP.$cljs$cst$725$name$$,"Jersey 10",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jersey10/v4/GftH7vZKsggXMf9n_J5X-JLgy1wtSw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jersey-10-charted",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9a3ed1a4-f5ba-44d5-94df-d3c0a7a5949a",-1438622452),$APP.$cljs$cst$2675$family$$,"Jersey 10 Charted",$APP.$cljs$cst$725$name$$,"Jersey 10 Charted",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jersey10charted/v4/oY1E8fPFr6XiNWqEp90XSbwUGfF8SnedKmeBvEYs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jersey-15",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("57ff96c6-c9ce-4dcf-9138-332ed27e446b",243104440),$APP.$cljs$cst$2675$family$$,"Jersey 15",$APP.$cljs$cst$725$name$$,"Jersey 15",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jersey15/v4/_6_9EDzuROGsUuk2TWjSYoohsCkvSQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jersey-15-charted",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2921673a-0acb-4c28-bf49-18c08c983811",-332785636),
$APP.$cljs$cst$2675$family$$,"Jersey 15 Charted",$APP.$cljs$cst$725$name$$,"Jersey 15 Charted",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jersey15charted/v4/nuFjD-rCQIjoVp1Sva2ToCTudGbLeRv4r2024gxi.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jersey-20",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3fdeecaa-195c-4dda-8eb5-170f7312d47b",1831360861),$APP.$cljs$cst$2675$family$$,"Jersey 20",$APP.$cljs$cst$725$name$$,"Jersey 20",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jersey20/v4/ZgNRjP1ON6jeW4D12z3crE_qP4mXuQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jersey-20-charted",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3dc8a3ed-e281-48cb-b411-c69e0ae9fa42",-1413715834),$APP.$cljs$cst$2675$family$$,"Jersey 20 Charted",$APP.$cljs$cst$725$name$$,"Jersey 20 Charted",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jersey20charted/v4/JTUNjJMy9DKq5FzVaj9tpgYgvHqGn_Z1ji-rqnQ_.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jersey-25",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("61724ac2-888f-4bf2-946e-c7c9edb26fb8",295864191),$APP.$cljs$cst$2675$family$$,"Jersey 25",$APP.$cljs$cst$725$name$$,"Jersey 25",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/jersey25/v4/ll8-K2eeXj2tAs6F9BXIJ4AMng8ChA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jersey-25-charted",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("61895825-28f1-4d72-bac2-63fb81d1c95b",-1180801783),$APP.$cljs$cst$2675$family$$,"Jersey 25 Charted",$APP.$cljs$cst$725$name$$,"Jersey 25 Charted",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jersey25charted/v3/6NUM8EWHIhCWbxOqtLkv94Rlu6EkGv2uUGQW93Cg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jetbrains-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("78510b0f-e81e-410c-8ad6-1437297fb1d5",
-2126799625),$APP.$cljs$cst$2675$family$$,"JetBrains Mono",$APP.$cljs$cst$725$name$$,"JetBrains Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDbY2o-flEEny0FZhsfKu5WU4zr3E_BX0PnT8RD8yK1jPVmUsaaDhw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDbY2o-flEEny0FZhsfKu5WU4zr3E_BX0PnT8RD8SKxjPVmUsaaDhw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDbY2o-flEEny0FZhsfKu5WU4zr3E_BX0PnT8RD8lqxjPVmUsaaDhw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDbY2o-flEEny0FZhsfKu5WU4zr3E_BX0PnT8RD8yKxjPVmUsaaDhw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDbY2o-flEEny0FZhsfKu5WU4zr3E_BX0PnT8RD8-qxjPVmUsaaDhw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDbY2o-flEEny0FZhsfKu5WU4zr3E_BX0PnT8RD8FqtjPVmUsaaDhw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDbY2o-flEEny0FZhsfKu5WU4zr3E_BX0PnT8RD8L6tjPVmUsaaDhw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDbY2o-flEEny0FZhsfKu5WU4zr3E_BX0PnT8RD8SKtjPVmUsaaDhw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDba2o-flEEny0FZhsfKu5WU4xD-IQ-PuZJJXxfpAO-Lf1OQk6OThxPA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDba2o-flEEny0FZhsfKu5WU4xD-IQ-PuZJJXxfpAO8LflOQk6OThxPA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDba2o-flEEny0FZhsfKu5WU4xD-IQ-PuZJJXxfpAO_VflOQk6OThxPA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDba2o-flEEny0FZhsfKu5WU4xD-IQ-PuZJJXxfpAO-LflOQk6OThxPA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDba2o-flEEny0FZhsfKu5WU4xD-IQ-PuZJJXxfpAO-5flOQk6OThxPA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDba2o-flEEny0FZhsfKu5WU4xD-IQ-PuZJJXxfpAO9VeVOQk6OThxPA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDba2o-flEEny0FZhsfKu5WU4xD-IQ-PuZJJXxfpAO9seVOQk6OThxPA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",
$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jetbrainsmono/v24/tDba2o-flEEny0FZhsfKu5WU4xD-IQ-PuZJJXxfpAO8LeVOQk6OThxPA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jim-nightshade",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d97c9626-a77d-4830-81c3-1d209c217a37",377987889),$APP.$cljs$cst$2675$family$$,"Jim Nightshade",$APP.$cljs$cst$725$name$$,"Jim Nightshade",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jimnightshade/v21/PlIkFlu9Pb08Q8HLM1PxmB0g-OS4V3qKaMxD.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-joan",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("67dc2690-3333-4662-9b54-d606889b6831",150797771),$APP.$cljs$cst$2675$family$$,"Joan",$APP.$cljs$cst$725$name$$,"Joan",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/joan/v12/ZXupe1oZsqWRbRdH8X1p_Ng.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jockey-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4bd9783c-70bc-4953-b2d4-f86358698a4c",-704888257),$APP.$cljs$cst$2675$family$$,"Jockey One",$APP.$cljs$cst$725$name$$,"Jockey One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jockeyone/v23/HTxpL2g2KjCFj4x8WI6ArIb7HYOk4xc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jolly-lodger",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4b5bdb50-57cd-459d-a4cf-779ce96d9739",1204781295),$APP.$cljs$cst$2675$family$$,"Jolly Lodger",$APP.$cljs$cst$725$name$$,"Jolly Lodger",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jollylodger/v21/BXRsvFTAh_bGkA1uQ48dlB3VWerT3ZyuqA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jomhuria",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ad95b8a3-22db-4c4c-bab9-2f2d851d6666",2130512216),$APP.$cljs$cst$2675$family$$,"Jomhuria",$APP.$cljs$cst$725$name$$,"Jomhuria",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/jomhuria/v22/Dxxp8j-TMXf-llKur2b1MOGbC3Dh.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jomolhari",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("45c93637-e81e-4431-9bc9-c1a162f6f927",-999301360),$APP.$cljs$cst$2675$family$$,"Jomolhari",$APP.$cljs$cst$725$name$$,"Jomolhari",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jomolhari/v21/EvONzA1M1Iw_CBd2hsQCF1IZKq5INg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-josefin-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c02d8247-b5a1-498d-beac-24771a431471",-508389923),$APP.$cljs$cst$2675$family$$,"Josefin Sans",$APP.$cljs$cst$725$name$$,
"Josefin Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinsans/v34/Qw3PZQNVED7rKGKxtqIqX5E-AVSJrOCfjY46_DjRXMFrLgTsQV0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinsans/v34/Qw3PZQNVED7rKGKxtqIqX5E-AVSJrOCfjY46_LjQXMFrLgTsQV0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinsans/v34/Qw3PZQNVED7rKGKxtqIqX5E-AVSJrOCfjY46_GbQXMFrLgTsQV0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinsans/v34/Qw3PZQNVED7rKGKxtqIqX5E-AVSJrOCfjY46_DjQXMFrLgTsQV0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinsans/v34/Qw3PZQNVED7rKGKxtqIqX5E-AVSJrOCfjY46_ArQXMFrLgTsQV0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinsans/v34/Qw3PZQNVED7rKGKxtqIqX5E-AVSJrOCfjY46_ObXXMFrLgTsQV0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinsans/v34/Qw3PZQNVED7rKGKxtqIqX5E-AVSJrOCfjY46_N_XXMFrLgTsQV0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinsans/v34/Qw3JZQNVED7rKGKxtqIqX5EUCGZ2dIn0FyA96fCTtINhKibpUV3MEQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinsans/v34/Qw3JZQNVED7rKGKxtqIqX5EUCGZ2dIn0FyA96fCTNIJhKibpUV3MEQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinsans/v34/Qw3JZQNVED7rKGKxtqIqX5EUCGZ2dIn0FyA96fCT6oJhKibpUV3MEQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinsans/v34/Qw3JZQNVED7rKGKxtqIqX5EUCGZ2dIn0FyA96fCTtIJhKibpUV3MEQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinsans/v34/Qw3JZQNVED7rKGKxtqIqX5EUCGZ2dIn0FyA96fCThoJhKibpUV3MEQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/josefinsans/v34/Qw3JZQNVED7rKGKxtqIqX5EUCGZ2dIn0FyA96fCTaoVhKibpUV3MEQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinsans/v34/Qw3JZQNVED7rKGKxtqIqX5EUCGZ2dIn0FyA96fCTU4VhKibpUV3MEQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-josefin-slab",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0f894779-490e-42ff-a39b-e8fe1bc24a06",-1963691105),$APP.$cljs$cst$2675$family$$,"Josefin Slab",$APP.$cljs$cst$725$name$$,"Josefin Slab",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinslab/v29/lW-swjwOK3Ps5GSJlNNkMalNpiZe_ldbOR4W71mtd3k3K6CcEyI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinslab/v29/lW-swjwOK3Ps5GSJlNNkMalNpiZe_ldbOR4W79msd3k3K6CcEyI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinslab/v29/lW-swjwOK3Ps5GSJlNNkMalNpiZe_ldbOR4W7wesd3k3K6CcEyI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinslab/v29/lW-swjwOK3Ps5GSJlNNkMalNpiZe_ldbOR4W71msd3k3K6CcEyI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinslab/v29/lW-swjwOK3Ps5GSJlNNkMalNpiZe_ldbOR4W72usd3k3K6CcEyI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinslab/v29/lW-swjwOK3Ps5GSJlNNkMalNpiZe_ldbOR4W74erd3k3K6CcEyI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinslab/v29/lW-swjwOK3Ps5GSJlNNkMalNpiZe_ldbOR4W776rd3k3K6CcEyI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinslab/v29/lW-qwjwOK3Ps5GSJlNNkMalnrxShJj4wo7AR-pHvnzs9L4KZAyK43w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinslab/v29/lW-qwjwOK3Ps5GSJlNNkMalnrxShJj4wo7AR-pHvHzo9L4KZAyK43w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinslab/v29/lW-qwjwOK3Ps5GSJlNNkMalnrxShJj4wo7AR-pHvwTo9L4KZAyK43w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinslab/v29/lW-qwjwOK3Ps5GSJlNNkMalnrxShJj4wo7AR-pHvnzo9L4KZAyK43w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinslab/v29/lW-qwjwOK3Ps5GSJlNNkMalnrxShJj4wo7AR-pHvrTo9L4KZAyK43w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/josefinslab/v29/lW-qwjwOK3Ps5GSJlNNkMalnrxShJj4wo7AR-pHvQT09L4KZAyK43w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/josefinslab/v29/lW-qwjwOK3Ps5GSJlNNkMalnrxShJj4wo7AR-pHveD09L4KZAyK43w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jost",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9784c817-9161-4b14-a9b1-90b2467a94bf",-1312701634),$APP.$cljs$cst$2675$family$$,"Jost",$APP.$cljs$cst$725$name$$,"Jost",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zPtBhPNqw79Ij1E865zBUv7myjJAVGPokMmuHL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/jost/v20/92zPtBhPNqw79Ij1E865zBUv7mwjJQVGPokMmuHL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zPtBhPNqw79Ij1E865zBUv7mz9JQVGPokMmuHL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zPtBhPNqw79Ij1E865zBUv7myjJQVGPokMmuHL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zPtBhPNqw79Ij1E865zBUv7myRJQVGPokMmuHL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zPtBhPNqw79Ij1E865zBUv7mx9IgVGPokMmuHL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zPtBhPNqw79Ij1E865zBUv7mxEIgVGPokMmuHL.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zPtBhPNqw79Ij1E865zBUv7mwjIgVGPokMmuHL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/jost/v20/92zPtBhPNqw79Ij1E865zBUv7mwKIgVGPokMmuHL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zJtBhPNqw73oHH7BbQp4-B6XlrZu0ENI0un_HLMEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,
"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zJtBhPNqw73oHH7BbQp4-B6XlrZm0FNI0un_HLMEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zJtBhPNqw73oHH7BbQp4-B6XlrZrMFNI0un_HLMEo.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zJtBhPNqw73oHH7BbQp4-B6XlrZu0FNI0un_HLMEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zJtBhPNqw73oHH7BbQp4-B6XlrZt8FNI0un_HLMEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zJtBhPNqw73oHH7BbQp4-B6XlrZjMCNI0un_HLMEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zJtBhPNqw73oHH7BbQp4-B6XlrZgoCNI0un_HLMEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zJtBhPNqw73oHH7BbQp4-B6XlrZm0CNI0un_HLMEo.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jost/v20/92zJtBhPNqw73oHH7BbQp4-B6XlrZkQCNI0un_HLMEo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-joti-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("223e77be-5685-4cd4-9c9d-39d956c2d26b",
229539239),$APP.$cljs$cst$2675$family$$,"Joti One",$APP.$cljs$cst$725$name$$,"Joti One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jotione/v28/Z9XVDmdJQAmWm9TwaYTe4u2El6GC.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-jua",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c84bd96c-10b6-439a-aea9-ce3328b413ea",-1947266264),$APP.$cljs$cst$2675$family$$,"Jua",$APP.$cljs$cst$725$name$$,"Jua",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jua/v18/co3KmW9ljjAjc-DZCsKgsg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-judson",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("38b64525-1bd4-4c7f-9c57-a9c56ecca44a",-376927259),$APP.$cljs$cst$2675$family$$,"Judson",$APP.$cljs$cst$725$name$$,"Judson",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/judson/v20/FeVRS0Fbvbc14VxRD7N01bV7kg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/judson/v20/FeVTS0Fbvbc14VxhDblw97BrknZf.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/judson/v20/FeVSS0Fbvbc14Vxps5xQ3Z5nm29Gww.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-julee",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dafb46f6-887c-499f-a396-e6788ad07b1b",-1799989371),$APP.$cljs$cst$2675$family$$,"Julee",$APP.$cljs$cst$725$name$$,"Julee",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/julee/v26/TuGfUVB3RpZPQ6ZLodgzydtk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-julius-sans-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cec60d7f-1e5c-4e8b-851e-ac23c61f3a0f",1817545944),$APP.$cljs$cst$2675$family$$,"Julius Sans One",$APP.$cljs$cst$725$name$$,"Julius Sans One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/juliussansone/v20/1Pt2g8TAX_SGgBGUi0tGOYEga5W-xXEW6aGXHw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-junge",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("96bc17ec-ed02-46d4-b5f0-fb295d85d7a7",-2083910192),$APP.$cljs$cst$2675$family$$,"Junge",$APP.$cljs$cst$725$name$$,
"Junge",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/junge/v26/gokgH670Gl1lUqAdvhB7SnKm.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-jura",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c09da207-5cdc-4b98-963d-8787c7ecc1a3",-1020386587),$APP.$cljs$cst$2675$family$$,"Jura",$APP.$cljs$cst$725$name$$,"Jura",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/jura/v34/z7NOdRfiaC4Vd8hhoPzfb5vBTP0D7auhTfmrH_rt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jura/v34/z7NOdRfiaC4Vd8hhoPzfb5vBTP1d7auhTfmrH_rt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",
$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jura/v34/z7NOdRfiaC4Vd8hhoPzfb5vBTP1v7auhTfmrH_rt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jura/v34/z7NOdRfiaC4Vd8hhoPzfb5vBTP2D6quhTfmrH_rt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/jura/v34/z7NOdRfiaC4Vd8hhoPzfb5vBTP266quhTfmrH_rt.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-just-another-hand",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6b3588e8-1bdb-419c-8ae1-d04f878fccdc",210828032),$APP.$cljs$cst$2675$family$$,"Just Another Hand",
$APP.$cljs$cst$725$name$$,"Just Another Hand",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/justanotherhand/v21/845CNN4-AJyIGvIou-6yJKyptyOpOcr_BmmlS5aw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-just-me-again-down-here",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6e4a6c82-c458-4009-ba3f-5e891ad80d86",892798927),$APP.$cljs$cst$2675$family$$,"Just Me Again Down Here",$APP.$cljs$cst$725$name$$,"Just Me Again Down Here",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/justmeagaindownhere/v25/MwQmbgXtz-Wc6RUEGNMc0QpRrfUh2hSdBBMoAuwHvqDwc_fg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-k2d",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f24ffe5c-ea02-424a-8774-0b5bd1df84b0",2033036046),$APP.$cljs$cst$2675$family$$,"K2D",$APP.$cljs$cst$725$name$$,"K2D",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/k2d/v13/J7aRnpF2V0ErE6UpvrIw74NL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/k2d/v13/J7afnpF2V0EjdZ1NtLYS6pNLAjk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/k2d/v13/J7aenpF2V0Erv4QJlJw85ppSGw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,
"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/k2d/v13/J7acnpF2V0EjdZ3hlZY4xJ9CGyAa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/k2d/v13/J7aenpF2V0Er24cJlJw85ppSGw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/k2d/v13/J7acnpF2V0EjdZ2FlpY4xJ9CGyAa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/k2d/v13/J7aTnpF2V0ETd68tnLcg7w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/k2d/v13/J7aRnpF2V0EjdaUpvrIw74NL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/k2d/v13/J7aenpF2V0Erg4YJlJw85ppSGw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/k2d/v13/J7acnpF2V0EjdZ3dl5Y4xJ9CGyAa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/k2d/v13/J7aenpF2V0Err4EJlJw85ppSGw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/k2d/v13/J7acnpF2V0EjdZ3xkJY4xJ9CGyAa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/k2d/v13/J7aenpF2V0Ery4AJlJw85ppSGw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/k2d/v13/J7acnpF2V0EjdZ2VkZY4xJ9CGyAa.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/k2d/v13/J7aenpF2V0Er14MJlJw85ppSGw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/k2d/v13/J7acnpF2V0EjdZ2JkpY4xJ9CGyAa.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kablammo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("aef8d54e-808d-4052-a5e5-30f4bde2355e",1394385208),$APP.$cljs$cst$2675$family$$,"Kablammo",$APP.$cljs$cst$725$name$$,"Kablammo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kablammo/v4/bWtm7fHPcgrhC-J3lcXhcQTY5Ixs6Au9YgCjjx0Rf4YDKw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kadwa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ae3bf5ea-7acc-4767-ba18-0f249af53a24",284595422),$APP.$cljs$cst$2675$family$$,"Kadwa",$APP.$cljs$cst$725$name$$,
"Kadwa",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kadwa/v13/rnCm-x5V0g7iphTHRcc2s2XH.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",
$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kadwa/v13/rnCr-x5V0g7ipix7auM-mHnOSOuk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kaisei-decol",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1a736826-36ee-4c25-967a-30594806bc08",1495109617),$APP.$cljs$cst$2675$family$$,"Kaisei Decol",$APP.$cljs$cst$725$name$$,"Kaisei Decol",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kaiseidecol/v11/bMrwmSqP45sidWf3QmfFW6iyW1EP22OjoA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kaiseidecol/v11/bMrvmSqP45sidWf3QmfFW6iKr3gr00i_qb57kA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kaiseidecol/v11/bMrvmSqP45sidWf3QmfFW6iK534r00i_qb57kA.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kaisei-harunoumi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bfa266e6-9d3e-4af5-acf7-39e6dd3a9d35",-1984817511),$APP.$cljs$cst$2675$family$$,"Kaisei HarunoUmi",$APP.$cljs$cst$725$name$$,"Kaisei HarunoUmi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kaiseiharunoumi/v11/HI_RiZQSLqBQoAHhK_C6N_nzy_jcGsv5sM8u3mk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kaiseiharunoumi/v11/HI_WiZQSLqBQoAHhK_C6N_nzy_jcIj_QlMcFwmC9FAU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kaiseiharunoumi/v11/HI_WiZQSLqBQoAHhK_C6N_nzy_jcInfWlMcFwmC9FAU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kaisei-opti",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9f4a94b9-329d-45f1-a8fe-ce9b4a769f22",
-1683278605),$APP.$cljs$cst$2675$family$$,"Kaisei Opti",$APP.$cljs$cst$725$name$$,"Kaisei Opti",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kaiseiopti/v11/QldKNThJphYb8_g6c2nlIFle7KlmxuHx.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kaiseiopti/v11/QldXNThJphYb8_g6c2nlIGGqxY1u7f34DYwn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/kaiseiopti/v11/QldXNThJphYb8_g6c2nlIGHiw41u7f34DYwn.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kaisei-tokumin",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b3c819c0-c593-4e70-ace2-20e356b509cd",785951596),$APP.$cljs$cst$2675$family$$,"Kaisei Tokumin",$APP.$cljs$cst$725$name$$,"Kaisei Tokumin",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kaiseitokumin/v11/Gg8sN5wdZg7xCwuMsylww2ZiQkJf1l0pj946.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/kaiseitokumin/v11/Gg8vN5wdZg7xCwuMsylww2ZiQnqr_3khpMIzeI6v.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kaiseitokumin/v11/Gg8vN5wdZg7xCwuMsylww2ZiQnrj-XkhpMIzeI6v.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kaiseitokumin/v11/Gg8vN5wdZg7xCwuMsylww2ZiQnr_-nkhpMIzeI6v.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kalam",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("39ea99df-6501-4997-a9bf-d0f548671bf2",83115650),$APP.$cljs$cst$2675$family$$,"Kalam",$APP.$cljs$cst$725$name$$,"Kalam",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalam/v18/YA9Qr0Wd4kDdMtD6GgLLmCUItqGt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalam/v18/YA9dr0Wd4kDdMuhWMibDszkB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalam/v18/YA9Qr0Wd4kDdMtDqHQLLmCUItqGt.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kalnia",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("7b454676-c506-4706-a79a-a98eab28b15b",266850193),$APP.$cljs$cst$2675$family$$,"Kalnia",$APP.$cljs$cst$725$name$$,"Kalnia",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalnia/v6/11hqGpPCwUbbYwZZP0RBuDY62BQZhjvOytM_sLzi-TFWAW9il2xRGNcykIZc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalnia/v6/11hqGpPCwUbbYwZZP0RBuDY62BQZhjvOytM_sLzi-TFWAW_ilmxRGNcykIZc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalnia/v6/11hqGpPCwUbbYwZZP0RBuDY62BQZhjvOytM_sLzi-TFWAW88lmxRGNcykIZc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalnia/v6/11hqGpPCwUbbYwZZP0RBuDY62BQZhjvOytM_sLzi-TFWAW9ilmxRGNcykIZc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalnia/v6/11hqGpPCwUbbYwZZP0RBuDY62BQZhjvOytM_sLzi-TFWAW9QlmxRGNcykIZc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalnia/v6/11hqGpPCwUbbYwZZP0RBuDY62BQZhjvOytM_sLzi-TFWAW-8kWxRGNcykIZc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalnia/v6/11hqGpPCwUbbYwZZP0RBuDY62BQZhjvOytM_sLzi-TFWAW-FkWxRGNcykIZc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kalnia-glaze",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a6f82e12-3dab-46ea-abea-d38f62330b5e",
-76340607),$APP.$cljs$cst$2675$family$$,"Kalnia Glaze",$APP.$cljs$cst$725$name$$,"Kalnia Glaze",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalniaglaze/v5/wlpQgwHCBUNjrGrfu-hwowN1YyC-42Lu26VHf2LtOkAod0wTxm2tFYdL63nZKfhpVTvN.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalniaglaze/v5/wlpQgwHCBUNjrGrfu-hwowN1YyC-42Lu26VHf2LtOkAod0wTxm2tFYfL6nnZKfhpVTvN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalniaglaze/v5/wlpQgwHCBUNjrGrfu-hwowN1YyC-42Lu26VHf2LtOkAod0wTxm2tFYcV6nnZKfhpVTvN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalniaglaze/v5/wlpQgwHCBUNjrGrfu-hwowN1YyC-42Lu26VHf2LtOkAod0wTxm2tFYdL6nnZKfhpVTvN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalniaglaze/v5/wlpQgwHCBUNjrGrfu-hwowN1YyC-42Lu26VHf2LtOkAod0wTxm2tFYd56nnZKfhpVTvN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalniaglaze/v5/wlpQgwHCBUNjrGrfu-hwowN1YyC-42Lu26VHf2LtOkAod0wTxm2tFYeV7XnZKfhpVTvN.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kalniaglaze/v5/wlpQgwHCBUNjrGrfu-hwowN1YyC-42Lu26VHf2LtOkAod0wTxm2tFYes7XnZKfhpVTvN.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kameron",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c96d3bd2-2275-4dc2-a051-1c1c5c87f035",
362767188),$APP.$cljs$cst$2675$family$$,"Kameron",$APP.$cljs$cst$725$name$$,"Kameron",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kameron/v18/vm8pdR7vXErQxuznqrUS3z1Uw3nq4Ne3cbcbvZPxCDLR.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kameron/v18/vm8pdR7vXErQxuznqrUS3z1Uw3nq4NeFcbcbvZPxCDLR.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/kameron/v18/vm8pdR7vXErQxuznqrUS3z1Uw3nq4NdpdrcbvZPxCDLR.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kameron/v18/vm8pdR7vXErQxuznqrUS3z1Uw3nq4NdQdrcbvZPxCDLR.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kanchenjunga",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c5c99b7f-080d-47ac-8c27-e0c741781029",1983661270),$APP.$cljs$cst$2675$family$$,"Kanchenjunga",$APP.$cljs$cst$725$name$$,"Kanchenjunga",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/kanchenjunga/v2/RWmPoKKd5fUmrILiWsjCI6TiqYsGBGBzCw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanchenjunga/v2/RWmQoKKd5fUmrILiWsjCI6TaXaIiDEtvAlaMKw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanchenjunga/v2/RWmQoKKd5fUmrILiWsjCI6TacaUiDEtvAlaMKw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanchenjunga/v2/RWmQoKKd5fUmrILiWsjCI6TaFaQiDEtvAlaMKw.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kanit",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("01f65371-1116-4397-bb3a-b790d588f673",1079760451),$APP.$cljs$cst$2675$family$$,"Kanit",$APP.$cljs$cst$725$name$$,"Kanit",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",
$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKX-Go6G5tXcr72GwWKcaxALFs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKV-Go6G5tXcraQI2GAdY5FPFtrGw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKU-Go6G5tXcr5aOiWgX6BJNUJy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKS-Go6G5tXcraQI82hVaRrMFJyAu4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKU-Go6G5tXcr4-OSWgX6BJNUJy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/kanit/v17/nKKS-Go6G5tXcraQI6miVaRrMFJyAu4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKZ-Go6G5tXcoaSEQGodLxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKX-Go6G5tXcraQGwWKcaxALFs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKU-Go6G5tXcr5mOCWgX6BJNUJy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKS-Go6G5tXcraQI_GjVaRrMFJyAu4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKU-Go6G5tXcr5KPyWgX6BJNUJy.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKS-Go6G5tXcraQI92kVaRrMFJyAu4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/kanit/v17/nKKU-Go6G5tXcr4uPiWgX6BJNUJy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKS-Go6G5tXcraQI7mlVaRrMFJyAu4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,
"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKU-Go6G5tXcr4yPSWgX6BJNUJy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKS-Go6G5tXcraQI6WmVaRrMFJyAu4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKU-Go6G5tXcr4WPCWgX6BJNUJy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kanit/v17/nKKS-Go6G5tXcraQI4GnVaRrMFJyAu4.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kantumruy-pro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f4800085-bf2d-4490-9cf2-8701dd95c951",1327825979),$APP.$cljs$cst$2675$family$$,"Kantumruy Pro",$APP.$cljs$cst$725$name$$,"Kantumruy Pro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",
$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kantumruypro/v12/1q2TY5aECkp34vEBSPFOmJxwvk_pilU8OGNfyg1urUs0M34dR6dW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kantumruypro/v12/1q2TY5aECkp34vEBSPFOmJxwvk_pilU8OGNfyg3urEs0M34dR6dW.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kantumruypro/v12/1q2TY5aECkp34vEBSPFOmJxwvk_pilU8OGNfyg0wrEs0M34dR6dW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kantumruypro/v12/1q2TY5aECkp34vEBSPFOmJxwvk_pilU8OGNfyg1urEs0M34dR6dW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kantumruypro/v12/1q2TY5aECkp34vEBSPFOmJxwvk_pilU8OGNfyg1crEs0M34dR6dW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kantumruypro/v12/1q2TY5aECkp34vEBSPFOmJxwvk_pilU8OGNfyg2wq0s0M34dR6dW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kantumruypro/v12/1q2TY5aECkp34vEBSPFOmJxwvk_pilU8OGNfyg2Jq0s0M34dR6dW.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kantumruypro/v12/1q2RY5aECkp34vEBSPFOmJxwlEbbdY1VU_nxzRim76N2OXo_QrdWlcU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kantumruypro/v12/1q2RY5aECkp34vEBSPFOmJxwlEbbdY1VU_nxzRim7yN3OXo_QrdWlcU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kantumruypro/v12/1q2RY5aECkp34vEBSPFOmJxwlEbbdY1VU_nxzRim7_13OXo_QrdWlcU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kantumruypro/v12/1q2RY5aECkp34vEBSPFOmJxwlEbbdY1VU_nxzRim76N3OXo_QrdWlcU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/kantumruypro/v12/1q2RY5aECkp34vEBSPFOmJxwlEbbdY1VU_nxzRim75F3OXo_QrdWlcU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kantumruypro/v12/1q2RY5aECkp34vEBSPFOmJxwlEbbdY1VU_nxzRim731wOXo_QrdWlcU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kantumruypro/v12/1q2RY5aECkp34vEBSPFOmJxwlEbbdY1VU_nxzRim70RwOXo_QrdWlcU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kapakana",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f99f83c4-126e-4c59-9c20-fa29dd62396e",1876029570),$APP.$cljs$cst$2675$family$$,"Kapakana",$APP.$cljs$cst$725$name$$,
"Kapakana",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kapakana/v19/sykt-yN0m6InS7OD9BCc9iYVO-6XOlDixNA5tRbXZ4IXAA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kapakana/v19/sykt-yN0m6InS7OD9BCc9iYVO-6XOlDimtA5tRbXZ4IXAA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-karantina",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3105f31b-6f0a-4715-a997-27ed832e6ebf",1751334359),$APP.$cljs$cst$2675$family$$,"Karantina",$APP.$cljs$cst$725$name$$,
"Karantina",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karantina/v13/buExpo24ccnh31GVMABxXCgf-P5Oaiw4cw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karantina/v13/buE0po24ccnh31GVMABJ8AA78NVSYw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karantina/v13/buExpo24ccnh31GVMABxTC8f-P5Oaiw4cw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-karla",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cc03e831-eb05-4b6e-918e-c040f8d8412c",1718309794),$APP.$cljs$cst$2675$family$$,"Karla",$APP.$cljs$cst$725$name$$,"Karla",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karla/v33/qkBIXvYC6trAT55ZBi1ueQVIjQTDeJqqFENLR7fHGw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karla/v33/qkBIXvYC6trAT55ZBi1ueQVIjQTDppqqFENLR7fHGw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karla/v33/qkBIXvYC6trAT55ZBi1ueQVIjQTD-JqqFENLR7fHGw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karla/v33/qkBIXvYC6trAT55ZBi1ueQVIjQTDypqqFENLR7fHGw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karla/v33/qkBIXvYC6trAT55ZBi1ueQVIjQTDJp2qFENLR7fHGw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/karla/v33/qkBIXvYC6trAT55ZBi1ueQVIjQTDH52qFENLR7fHGw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karla/v33/qkBIXvYC6trAT55ZBi1ueQVIjQTDeJ2qFENLR7fHGw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,
"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karla/v33/qkBKXvYC6trAT7RQNNK2EG7SIwPWMNnCV0lPZbLXGxGR.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karla/v33/qkBKXvYC6trAT7RQNNK2EG7SIwPWMNkcV0lPZbLXGxGR.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karla/v33/qkBKXvYC6trAT7RQNNK2EG7SIwPWMNlCV0lPZbLXGxGR.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karla/v33/qkBKXvYC6trAT7RQNNK2EG7SIwPWMNlwV0lPZbLXGxGR.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karla/v33/qkBKXvYC6trAT7RQNNK2EG7SIwPWMNmcUElPZbLXGxGR.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karla/v33/qkBKXvYC6trAT7RQNNK2EG7SIwPWMNmlUElPZbLXGxGR.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karla/v33/qkBKXvYC6trAT7RQNNK2EG7SIwPWMNnCUElPZbLXGxGR.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-karla-tamil-inclined",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f8ef1670-d767-4b5f-8ff1-f08811a9b1f4",952537799),$APP.$cljs$cst$2675$family$$,"Karla Tamil Inclined",$APP.$cljs$cst$725$name$$,"Karla Tamil Inclined",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karlatamilinclined/v2/vm8pdQ3vXFXZ1aPd8dNzR82AFh2TibkaVrcbvZPxCDLR.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karlatamilinclined/v2/vm8mdQ3vXFXZ1aPd8dNzR82AFh2TibkaVo-nkrf5Iy7YGkI1.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-karla-tamil-upright",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dcfeb899-7ea6-439d-863e-6bc470c0ae6e",-377834133),$APP.$cljs$cst$2675$family$$,"Karla Tamil Upright",$APP.$cljs$cst$725$name$$,"Karla Tamil Upright",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karlatamilupright/v2/IFS4HfVMk95HnY0u6SeQ_cHoozW_3U5XoBJ9hK8kMK4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karlatamilupright/v2/IFS1HfVMk95HnY0u6SeQ_cHoozW_3U5XmK5SoKcPLKclE4o.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-karma",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b22944f4-9efc-4ac0-9f6e-368d44fbb7c6",1338137260),$APP.$cljs$cst$2675$family$$,"Karma",$APP.$cljs$cst$725$name$$,"Karma",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karma/v18/va9F4kzAzMZRGLjDY8Z_uqzGQC_-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karma/v18/va9I4kzAzMZRGIBvS-J3kbDP.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karma/v18/va9F4kzAzMZRGLibYsZ_uqzGQC_-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karma/v18/va9F4kzAzMZRGLi3ZcZ_uqzGQC_-.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/karma/v18/va9F4kzAzMZRGLjTZMZ_uqzGQC_-.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-katibeh",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("90e7909d-e422-4cd1-991e-c7a80842ab2f",1372740862),$APP.$cljs$cst$2675$family$$,
"Katibeh",$APP.$cljs$cst$725$name$$,"Katibeh",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/katibeh/v22/ZGjXol5MQJog4bxDaC1RVDNdGDs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-kaushan-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("905e4afa-072a-493e-94a2-4107970ae4cf",-1184588828),$APP.$cljs$cst$2675$family$$,"Kaushan Script",$APP.$cljs$cst$725$name$$,"Kaushan Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kaushanscript/v19/vm8vdRfvXFLG3OLnsO15WYS5DF7_ytN3M48a.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kavivanar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b51a0453-b5ba-48f5-a6c6-c95c8b842711",-1889126153),$APP.$cljs$cst$2675$family$$,"Kavivanar",$APP.$cljs$cst$725$name$$,"Kavivanar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kavivanar/v22/o-0IIpQgyXYSwhxP7_Jb4j5Ba_2c7A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kavoon",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9db40350-b688-4ed1-ba09-eece90306ee7",
-1147447331),$APP.$cljs$cst$2675$family$$,"Kavoon",$APP.$cljs$cst$725$name$$,"Kavoon",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kavoon/v25/pxiFyp4_scRYhlU4NLr6f1pdEQ.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kay-pho-du",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3b4be1da-15d3-41c7-a0c2-bed620119089",-2079601849),$APP.$cljs$cst$2675$family$$,"Kay Pho Du",$APP.$cljs$cst$725$name$$,"Kay Pho Du",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kayphodu/v2/jizfREFPvGNOx-jhPwHR4OmnLD0Z4zM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kayphodu/v2/jizcREFPvGNOx-jhPwHR2B2OCDUy_zoyk18.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kayphodu/v2/jizcREFPvGNOx-jhPwHR2DGJCDUy_zoyk18.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kayphodu/v2/jizcREFPvGNOx-jhPwHR2FWICDUy_zoyk18.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kdam-thmor-pro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("70c00c38-a372-40d9-bf55-1f9f78fbb0a9",2082231439),$APP.$cljs$cst$2675$family$$,"Kdam Thmor Pro",$APP.$cljs$cst$725$name$$,"Kdam Thmor Pro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kdamthmorpro/v7/EJRPQgAzVdcI-Qdvt34jzurnGA7_j89I8ZWb.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-keania-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ce628ba4-d45d-47c2-8c09-83565ef2c4ec",653382643),$APP.$cljs$cst$2675$family$$,"Keania One",$APP.$cljs$cst$725$name$$,"Keania One",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/keaniaone/v26/zOL54pXJk65E8pXardnuycRuv-hHkOs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-kedebideri",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("94898698-b86e-4a5d-8321-01b2ba902e63",1972639112),$APP.$cljs$cst$2675$family$$,"Kedebideri",$APP.$cljs$cst$725$name$$,"Kedebideri",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kedebideri/v2/t5tlIR0UPo6ZGAykNh_ejKbCyTHuspo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kedebideri/v2/t5tmIR0UPo6ZGAykNh_etFLr7TnFrpOHYh4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kedebideri/v2/t5tmIR0UPo6ZGAykNh_etH7s7TnFrpOHYh4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kedebideri/v2/t5tmIR0UPo6ZGAykNh_etBrt7TnFrpOHYh4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kedebideri/v2/t5tmIR0UPo6ZGAykNh_etAbu7TnFrpOHYh4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kedebideri/v2/t5tmIR0UPo6ZGAykNh_etCLv7TnFrpOHYh4.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kelly-slab",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("45b23457-6307-4604-a529-e51f6db8635e",-1787742530),$APP.$cljs$cst$2675$family$$,"Kelly Slab",$APP.$cljs$cst$725$name$$,"Kelly Slab",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kellyslab/v18/-W_7XJX0Rz3cxUnJC5t6TkMBf50kbiM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kenia",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("966e09d0-a9e1-4b74-ad0c-8630b24a8dad",-1401210552),$APP.$cljs$cst$2675$family$$,"Kenia",$APP.$cljs$cst$725$name$$,"Kenia",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kenia/v30/jizURE5PuHQH9qCONUGswfGM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-khand",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2f962f61-5238-4e49-b97a-dce50cb7b6c4",
-909525854),$APP.$cljs$cst$2675$family$$,"Khand",$APP.$cljs$cst$725$name$$,"Khand",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/khand/v22/TwMN-IINQlQQ0bL5cFE3ZwaH__-C.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/khand/v22/TwMA-IINQlQQ0YpVWHU_TBqO.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/khand/v22/TwMN-IINQlQQ0bKhcVE3ZwaH__-C.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/khand/v22/TwMN-IINQlQQ0bKNdlE3ZwaH__-C.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/khand/v22/TwMN-IINQlQQ0bLpd1E3ZwaH__-C.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-khmer",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b16b0b8c-4400-4e60-b320-e523be615cea",-217594519),$APP.$cljs$cst$2675$family$$,"Khmer",$APP.$cljs$cst$725$name$$,"Khmer",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/khmer/v38/MjQImit_vPPwpF-BpN2EeYmD.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-khula",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("408bfbe9-804c-4300-a279-e669e118ee5b",-1854688860),$APP.$cljs$cst$2675$family$$,"Khula",$APP.$cljs$cst$725$name$$,
"Khula",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/khula/v17/OpNPnoEOns3V7G-ljCvUrC59XwXD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/khula/v17/OpNCnoEOns3V7FcJpA_chzJ0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/khula/v17/OpNPnoEOns3V7G_RiivUrC59XwXD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/khula/v17/OpNPnoEOns3V7G-1iyvUrC59XwXD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/khula/v17/OpNPnoEOns3V7G-piCvUrC59XwXD.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kings",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f0e7e1d8-fc47-4fdf-8a94-b116e90919f0",1437528559),$APP.$cljs$cst$2675$family$$,"Kings",$APP.$cljs$cst$725$name$$,"Kings",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kings/v9/8AtnGsK4O5CYXU_Iq6GSPaHS.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kirang-haerang",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f7fb34ce-0c9c-4616-8a67-04ca1baba7aa",1827286403),$APP.$cljs$cst$2675$family$$,"Kirang Haerang",$APP.$cljs$cst$725$name$$,"Kirang Haerang",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kiranghaerang/v22/E21-_dn_gvvIjhYON1lpIU4-bcqvWPaJq4no.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kite-one",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("36291bd9-5570-4bb7-85db-aa72c8ee1d8b",-1472897508),$APP.$cljs$cst$2675$family$$,"Kite One",$APP.$cljs$cst$725$name$$,"Kite One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/kiteone/v23/70lQu7shLnA_E02vyq1b6HnGO4uA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kiwi-maru",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5f912843-6564-4a91-8400-24811e54aa8f",-919015942),$APP.$cljs$cst$2675$family$$,"Kiwi Maru",$APP.$cljs$cst$725$name$$,"Kiwi Maru",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kiwimaru/v20/R70djykGkuuDep-hRg6gNCi0Vxn9R5ShnA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kiwimaru/v20/R70YjykGkuuDep-hRg6YmACQXzLhTg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kiwimaru/v20/R70djykGkuuDep-hRg6gbCm0Vxn9R5ShnA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-klee-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a5887e40-a28a-404e-a871-569476c6b3fd",-1022629450),
$APP.$cljs$cst$2675$family$$,"Klee One",$APP.$cljs$cst$725$name$$,"Klee One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kleeone/v13/LDIxapCLNRc6A8oT4q4AOeekWPrP.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kleeone/v13/LDI2apCLNRc6A8oT4pbYF8Osc-bGkqIw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-knewave",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ff1c85c2-d6d0-479b-b680-3ecd74382f9a",589146520),$APP.$cljs$cst$2675$family$$,"Knewave",$APP.$cljs$cst$725$name$$,
"Knewave",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/knewave/v15/sykz-yx0lLcxQaSItSq9-trEvlQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-koho",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6071ebee-dab9-4ced-994a-64b538e1300d",1019536547),$APP.$cljs$cst$2675$family$$,"KoHo",$APP.$cljs$cst$725$name$$,"KoHo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/koho/v18/K2FxfZ5fmddNPuE1WJ75JoKhHys.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/koho/v18/K2FzfZ5fmddNNisssJ_zIqCkDyvqZA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/koho/v18/K2FxfZ5fmddNPoU2WJ75JoKhHys.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/koho/v18/K2FzfZ5fmddNNiss1JzzIqCkDyvqZA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/koho/v18/K2F-fZ5fmddNBikefJbSOos.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/koho/v18/K2FwfZ5fmddNNisUeLTXKou4Bg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/koho/v18/K2FxfZ5fmddNPt03WJ75JoKhHys.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/koho/v18/K2FzfZ5fmddNNissjJ3zIqCkDyvqZA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/koho/v18/K2FxfZ5fmddNPvEwWJ75JoKhHys.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/koho/v18/K2FzfZ5fmddNNissoJrzIqCkDyvqZA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/koho/v18/K2FxfZ5fmddNPpUxWJ75JoKhHys.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/koho/v18/K2FzfZ5fmddNNissxJvzIqCkDyvqZA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kodchasan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8396d5dd-9f23-4688-9314-825afa3c2d9e",-1871253450),$APP.$cljs$cst$2675$family$$,"Kodchasan",$APP.$cljs$cst$725$name$$,"Kodchasan",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodchasan/v20/1cX0aUPOAJv9sG4I-DJeR1Cggeqo3eMeoA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",
$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodchasan/v20/1cXqaUPOAJv9sG4I-DJWjUlIgOCs_-YOoIgN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodchasan/v20/1cX0aUPOAJv9sG4I-DJeI1Oggeqo3eMeoA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodchasan/v20/1cXqaUPOAJv9sG4I-DJWjUksg-Cs_-YOoIgN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodchasan/v20/1cXxaUPOAJv9sG4I-DJmj3uEicG01A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodchasan/v20/1cX3aUPOAJv9sG4I-DJWjXGAq8Sk1PoH.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodchasan/v20/1cX0aUPOAJv9sG4I-DJee1Kggeqo3eMeoA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodchasan/v20/1cXqaUPOAJv9sG4I-DJWjUl0guCs_-YOoIgN.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodchasan/v20/1cX0aUPOAJv9sG4I-DJeV1Wggeqo3eMeoA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/kodchasan/v20/1cXqaUPOAJv9sG4I-DJWjUlYheCs_-YOoIgN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodchasan/v20/1cX0aUPOAJv9sG4I-DJeM1Sggeqo3eMeoA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,
"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodchasan/v20/1cXqaUPOAJv9sG4I-DJWjUk8hOCs_-YOoIgN.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kode-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3b6f5dde-1c7f-4430-860d-a065646c9bdc",-2076043268),$APP.$cljs$cst$2675$family$$,"Kode Mono",$APP.$cljs$cst$725$name$$,"Kode Mono",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodemono/v4/A2BLn5pb0QgtVEPFnlYkkaoBgw4qv9odq5my9DqTaOW2A3k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodemono/v4/A2BLn5pb0QgtVEPFnlYkkaoBgw4qv9odq6uy9DqTaOW2A3k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodemono/v4/A2BLn5pb0QgtVEPFnlYkkaoBgw4qv9odq0e19DqTaOW2A3k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kodemono/v4/A2BLn5pb0QgtVEPFnlYkkaoBgw4qv9odq3619DqTaOW2A3k.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-koh-santepheap",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f78dea7d-358d-4e9a-bbde-45b6f4ff40fe",
1537898257),$APP.$cljs$cst$2675$family$$,"Koh Santepheap",$APP.$cljs$cst$725$name$$,"Koh Santepheap",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kohsantepheap/v15/gNMfW3p6SJbwyGj2rBZyeOrTjNuFHVyTtjNJUWU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kohsantepheap/v15/gNMeW3p6SJbwyGj2rBZyeOrTjNtNP3y5mD9ASHz5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kohsantepheap/v15/gNMdW3p6SJbwyGj2rBZyeOrTjOPhF1ixsyNJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kohsantepheap/v15/gNMeW3p6SJbwyGj2rBZyeOrTjNtdOHy5mD9ASHz5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kohsantepheap/v15/gNMeW3p6SJbwyGj2rBZyeOrTjNtlOny5mD9ASHz5.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kolker-brush",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c1a0756f-2113-4360-b730-49aa9300b388",53858826),$APP.$cljs$cst$2675$family$$,"Kolker Brush",$APP.$cljs$cst$725$name$$,
"Kolker Brush",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kolkerbrush/v8/iJWDBXWRZjfKWdvmzwvvog3-7KJ6x8qNUQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-konkhmer-sleokchher",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7ca79986-67fe-42cc-afff-edffb625b9ed",-1296350602),$APP.$cljs$cst$2675$family$$,"Konkhmer Sleokchher",$APP.$cljs$cst$725$name$$,"Konkhmer Sleokchher",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/konkhmersleokchher/v3/_Xmw-GE-rjmabA_M-aPOZOsCrUv825LFI3507E0d-W0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kosugi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("60fc6cfb-6f5b-4828-96ed-e693fea74b41",402020325),$APP.$cljs$cst$2675$family$$,"Kosugi",$APP.$cljs$cst$725$name$$,"Kosugi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kosugi/v19/pxiFyp4_v8FCjlI4NLr6f1pdEQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kosugi-maru",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d399c94b-3126-49b0-a750-744831f014f2",
-689926654),$APP.$cljs$cst$2675$family$$,"Kosugi Maru",$APP.$cljs$cst$725$name$$,"Kosugi Maru",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kosugimaru/v17/0nksC9PgP_wGh21A2KeqGiTqivr9iBq_.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kotta-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5ef82ccd-99a7-4291-8730-1d3bf72825b6",1066264066),$APP.$cljs$cst$2675$family$$,"Kotta One",$APP.$cljs$cst$725$name$$,"Kotta One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kottaone/v21/S6u_w41LXzPc_jlfNWqPHA3s5dwt7w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-koulen",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b6c76f09-5d6f-4b8f-8954-9aea4ae6da52",1691620269),$APP.$cljs$cst$2675$family$$,"Koulen",$APP.$cljs$cst$725$name$$,"Koulen",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/koulen/v30/AMOQz46as3KIBPeWgnA9kuYMUg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kranky",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a2cbf256-1781-47fc-9308-a672e89e69c1",
1325477102),$APP.$cljs$cst$2675$family$$,"Kranky",$APP.$cljs$cst$725$name$$,"Kranky",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kranky/v29/hESw6XVgJzlPsFnMpheEZo_H_w.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kreon",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dd070bbc-a98d-41f2-8c58-dc42cf50364e",-1258814470),$APP.$cljs$cst$2675$family$$,"Kreon",$APP.$cljs$cst$725$name$$,"Kreon",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",
$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kreon/v40/t5t9IRIUKY-TFF_LW5lnMR3v2DnvPNimejUfp2dWNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kreon/v40/t5t9IRIUKY-TFF_LW5lnMR3v2DnvYtimejUfp2dWNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kreon/v40/t5t9IRIUKY-TFF_LW5lnMR3v2DnvUNimejUfp2dWNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kreon/v40/t5t9IRIUKY-TFF_LW5lnMR3v2DnvvN-mejUfp2dWNg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kreon/v40/t5t9IRIUKY-TFF_LW5lnMR3v2Dnvhd-mejUfp2dWNg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kristi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("059e6fa3-ea44-4c0c-a0b4-03dd3f3a84f9",1762015751),
$APP.$cljs$cst$2675$family$$,"Kristi",$APP.$cljs$cst$725$name$$,"Kristi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kristi/v23/uK_y4ricdeU6zwdRCh0TMv6EXw.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-krona-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2154730e-fe23-4ef4-b75a-9d21edbe21c9",-1174016078),$APP.$cljs$cst$2675$family$$,"Krona One",$APP.$cljs$cst$725$name$$,"Krona One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kronaone/v15/jAnEgHdjHcjgfIb1ZcUCMY-h3cWkWg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-krub",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6a6b48af-cd75-47a0-a24a-eeaf4c060fd6",-541180308),$APP.$cljs$cst$2675$family$$,"Krub",$APP.$cljs$cst$725$name$$,"Krub",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/krub/v11/sZlEdRyC6CRYZo47KLF4R6gWaf8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/krub/v11/sZlGdRyC6CRYbkQiwLByQ4oTef_6gQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/krub/v11/sZlEdRyC6CRYZuo4KLF4R6gWaf8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,
"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/krub/v11/sZlGdRyC6CRYbkQipLNyQ4oTef_6gQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/krub/v11/sZlLdRyC6CRYXkYQDLlTW6E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/krub/v11/sZlFdRyC6CRYbkQaCJtWS6EPcA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/krub/v11/sZlEdRyC6CRYZrI5KLF4R6gWaf8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/krub/v11/sZlGdRyC6CRYbkQi_LJyQ4oTef_6gQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/krub/v11/sZlEdRyC6CRYZp4-KLF4R6gWaf8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/krub/v11/sZlGdRyC6CRYbkQi0LVyQ4oTef_6gQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/krub/v11/sZlEdRyC6CRYZvo_KLF4R6gWaf8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/krub/v11/sZlGdRyC6CRYbkQitLRyQ4oTef_6gQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-kufam",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dd869aa1-a626-4c0c-8260-245188fa9697",2084022992),$APP.$cljs$cst$2675$family$$,"Kufam",$APP.$cljs$cst$725$name$$,"Kufam",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kufam/v26/C8c-4cY7pG7w_oSJDszBXsKCcBH3lqk7qQCJHvIwYg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kufam/v26/C8c-4cY7pG7w_oSJDszBXsKCcBH3pKk7qQCJHvIwYg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kufam/v26/C8c-4cY7pG7w_oSJDszBXsKCcBH3SK47qQCJHvIwYg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kufam/v26/C8c-4cY7pG7w_oSJDszBXsKCcBH3ca47qQCJHvIwYg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kufam/v26/C8c-4cY7pG7w_oSJDszBXsKCcBH3Fq47qQCJHvIwYg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/kufam/v26/C8c-4cY7pG7w_oSJDszBXsKCcBH3P647qQCJHvIwYg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kufam/v26/C8c84cY7pG7w_q6APDMZN6kY3hbiXurT6gqNPPcgYp0i.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,
"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kufam/v26/C8c84cY7pG7w_q6APDMZN6kY3hbiXurh6gqNPPcgYp0i.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kufam/v26/C8c84cY7pG7w_q6APDMZN6kY3hbiXuoN7QqNPPcgYp0i.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kufam/v26/C8c84cY7pG7w_q6APDMZN6kY3hbiXuo07QqNPPcgYp0i.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kufam/v26/C8c84cY7pG7w_q6APDMZN6kY3hbiXupT7QqNPPcgYp0i.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kufam/v26/C8c84cY7pG7w_q6APDMZN6kY3hbiXup67QqNPPcgYp0i.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-kulim-park",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("17ffa01d-28fa-425b-8feb-9ff145d535c6",-1629997820),$APP.$cljs$cst$2675$family$$,"Kulim Park",$APP.$cljs$cst$725$name$$,"Kulim Park",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kulimpark/v15/fdN49secq3hflz1Uu3IwjJYNwa5aZbUvGjU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kulimpark/v15/fdNm9secq3hflz1Uu3IwhFwUKa9QYZcqCjVVUA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kulimpark/v15/fdN49secq3hflz1Uu3IwjPIOwa5aZbUvGjU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kulimpark/v15/fdNm9secq3hflz1Uu3IwhFwUTaxQYZcqCjVVUA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kulimpark/v15/fdN79secq3hflz1Uu3IwtF4m5aZxebw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/kulimpark/v15/fdN59secq3hflz1Uu3IwhFws4YR0abw2Aw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kulimpark/v15/fdN49secq3hflz1Uu3IwjIYIwa5aZbUvGjU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",
$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kulimpark/v15/fdNm9secq3hflz1Uu3IwhFwUOapQYZcqCjVVUA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kulimpark/v15/fdN49secq3hflz1Uu3IwjOIJwa5aZbUvGjU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kulimpark/v15/fdNm9secq3hflz1Uu3IwhFwUXatQYZcqCjVVUA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kumar-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("21a185ad-ede9-45d8-8d5b-83827d0652d5",-1650719664),$APP.$cljs$cst$2675$family$$,"Kumar One",
$APP.$cljs$cst$725$name$$,"Kumar One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kumarone/v25/bMr1mS-P958wYi6YaGeGNO6WU3oT0g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-kumar-one-outline",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("480ff9db-708b-49a0-9ca0-c8f83ff1273a",52583172),$APP.$cljs$cst$2675$family$$,"Kumar One Outline",$APP.$cljs$cst$725$name$$,"Kumar One Outline",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kumaroneoutline/v20/Noao6VH62pyLP0fsrZ-v18wlUEcX9zDwRQu8EGKF.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kumbh-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9fffb576-adca-4259-9594-8e6c4e6b9c0a",2092007880),$APP.$cljs$cst$2675$family$$,"Kumbh Sans",$APP.$cljs$cst$725$name$$,"Kumbh Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kumbhsans/v27/c4mP1n92AsfhuCq6tVsaoIx1LQICk0boNoq0SjlDfnzKo-bF3mdQkZcA8bTuUkqaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kumbhsans/v27/c4mP1n92AsfhuCq6tVsaoIx1LQICk0boNoq0SjlDfnzKo-bF3mdQEZYA8bTuUkqaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kumbhsans/v27/c4mP1n92AsfhuCq6tVsaoIx1LQICk0boNoq0SjlDfnzKo-bF3mdQz5YA8bTuUkqaLg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kumbhsans/v27/c4mP1n92AsfhuCq6tVsaoIx1LQICk0boNoq0SjlDfnzKo-bF3mdQkZYA8bTuUkqaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kumbhsans/v27/c4mP1n92AsfhuCq6tVsaoIx1LQICk0boNoq0SjlDfnzKo-bF3mdQo5YA8bTuUkqaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kumbhsans/v27/c4mP1n92AsfhuCq6tVsaoIx1LQICk0boNoq0SjlDfnzKo-bF3mdQT5EA8bTuUkqaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kumbhsans/v27/c4mP1n92AsfhuCq6tVsaoIx1LQICk0boNoq0SjlDfnzKo-bF3mdQdpEA8bTuUkqaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kumbhsans/v27/c4mP1n92AsfhuCq6tVsaoIx1LQICk0boNoq0SjlDfnzKo-bF3mdQEZEA8bTuUkqaLg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kumbhsans/v27/c4mP1n92AsfhuCq6tVsaoIx1LQICk0boNoq0SjlDfnzKo-bF3mdQOJEA8bTuUkqaLg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-kurale",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("60b7edc2-d025-45f0-b6db-57cec99e6c84",
-987815074),$APP.$cljs$cst$2675$family$$,"Kurale",$APP.$cljs$cst$725$name$$,"Kurale",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/kurale/v14/4iCs6KV9e9dXjho6eAT3v02QFg.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lxgw-marker-gothic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("24070934-34e3-498e-a38a-1a4a891221e9",2016491949),$APP.$cljs$cst$2675$family$$,"LXGW Marker Gothic",$APP.$cljs$cst$725$name$$,"LXGW Marker Gothic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lxgwmarkergothic/v1/Gg8oN4AaXyDVTi_NlS1-xCtMQxY3lToBjuw_cZe26Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lxgw-wenkai-mono-tc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("16a50f23-177a-49f7-8a44-f55d5b47cfaf",-2081894091),$APP.$cljs$cst$2675$family$$,"LXGW WenKai Mono TC",
$APP.$cljs$cst$725$name$$,"LXGW WenKai Mono TC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lxgwwenkaimonotc/v9/pxiVyos4iPVgyWx9WtufHnsIf5nkaB0HssKqhvJljXmo2SA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lxgwwenkaimonotc/v9/pxiYyos4iPVgyWx9WtufHnsIf5nkaB0Him6CovpOkXA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lxgwwenkaimonotc/v9/pxiVyos4iPVgyWx9WtufHnsIf5nkaB0HstKthvJljXmo2SA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lxgw-wenkai-tc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d683a656-8160-4ab3-a913-bf9393c416ed",-1564820707),$APP.$cljs$cst$2675$family$$,"LXGW WenKai TC",$APP.$cljs$cst$725$name$$,"LXGW WenKai TC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",
$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lxgwwenkaitc/v9/w8gAH20td8wNsI3f40DmtXZb4_MmBfkpTClICyan.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lxgwwenkaitc/v9/w8gDH20td8wNsI3f40DmtXZb48uKLd0hZzVB.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lxgwwenkaitc/v9/w8gAH20td8wNsI3f40DmtXZb4_M2AvkpTClICyan.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-la-belle-aurore",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("865cd8f9-9753-4291-b9df-b1623821efb1",
-1529359173),$APP.$cljs$cst$2675$family$$,"La Belle Aurore",$APP.$cljs$cst$725$name$$,"La Belle Aurore",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labelleaurore/v23/RrQIbot8-mNYKnGNDkWlocovHeIIG-eFNVmULg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-labrada",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0083e617-f933-45cc-9b9c-dad102d88b1c",445476997),$APP.$cljs$cst$2675$family$$,"Labrada",$APP.$cljs$cst$725$name$$,"Labrada",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVh2Y9HLWefIpOyF1Vi3ZqDss1Px9VTSgM4QPdUej17.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVh2Y9HLWefIpOyF1Vi3ZqDss1Px9XTSwM4QPdUej17.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVh2Y9HLWefIpOyF1Vi3ZqDss1Px9UNSwM4QPdUej17.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/labrada/v4/ieVh2Y9HLWefIpOyF1Vi3ZqDss1Px9VTSwM4QPdUej17.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVh2Y9HLWefIpOyF1Vi3ZqDss1Px9VhSwM4QPdUej17.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVh2Y9HLWefIpOyF1Vi3ZqDss1Px9WNTAM4QPdUej17.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVh2Y9HLWefIpOyF1Vi3ZqDss1Px9W0TAM4QPdUej17.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVh2Y9HLWefIpOyF1Vi3ZqDss1Px9XTTAM4QPdUej17.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/labrada/v4/ieVh2Y9HLWefIpOyF1Vi3ZqDss1Px9X6TAM4QPdUej17.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVv2Y9HLWefIpOyPVxQIkLq2VfhwMCbCOt6SvN2fy17-dE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",
$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVv2Y9HLWefIpOyPVxQIkLq2VfhwMCbCGt7SvN2fy17-dE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVv2Y9HLWefIpOyPVxQIkLq2VfhwMCbCLV7SvN2fy17-dE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVv2Y9HLWefIpOyPVxQIkLq2VfhwMCbCOt7SvN2fy17-dE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVv2Y9HLWefIpOyPVxQIkLq2VfhwMCbCNl7SvN2fy17-dE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVv2Y9HLWefIpOyPVxQIkLq2VfhwMCbCDV8SvN2fy17-dE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVv2Y9HLWefIpOyPVxQIkLq2VfhwMCbCAx8SvN2fy17-dE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVv2Y9HLWefIpOyPVxQIkLq2VfhwMCbCGt8SvN2fy17-dE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/labrada/v4/ieVv2Y9HLWefIpOyPVxQIkLq2VfhwMCbCEJ8SvN2fy17-dE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lacquer",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e79b3e74-0e2b-4272-b042-f438222e1f20",
-1187225983),$APP.$cljs$cst$2675$family$$,"Lacquer",$APP.$cljs$cst$725$name$$,"Lacquer",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lacquer/v16/EYqzma1QwqpG4_BBB7-AXhttQ5I.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-laila",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("77e7baaf-2bb4-44c7-863b-2296c22482d1",993884289),$APP.$cljs$cst$2675$family$$,"Laila",$APP.$cljs$cst$725$name$$,"Laila",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/laila/v20/LYjBdG_8nE8jDLzxogNAh14nVcfe.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/laila/v20/LYjMdG_8nE8jDIRdiidIrEIu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/laila/v20/LYjBdG_8nE8jDLypowNAh14nVcfe.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/laila/v20/LYjBdG_8nE8jDLyFpANAh14nVcfe.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/laila/v20/LYjBdG_8nE8jDLzhpQNAh14nVcfe.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lakki-reddy",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("10e65f95-a3b6-4b96-92cf-214cf8bb8b1d",-691074665),$APP.$cljs$cst$2675$family$$,
"Lakki Reddy",$APP.$cljs$cst$725$name$$,"Lakki Reddy",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lakkireddy/v25/S6u5w49MUSzD9jlCPmvLZQfox9k97-xZ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-lalezar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4d3e0821-9fbc-42d4-92d0-99290c63ccbc",-282242516),$APP.$cljs$cst$2675$family$$,"Lalezar",$APP.$cljs$cst$725$name$$,"Lalezar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lalezar/v16/zrfl0HLVx-HwTP82UaDyIiL0RCg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lancelot",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("59f92f09-d3e6-4414-a91d-e4f3fa04e5c1",1975671266),$APP.$cljs$cst$2675$family$$,"Lancelot",$APP.$cljs$cst$725$name$$,"Lancelot",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lancelot/v28/J7acnppxBGtQEulG4JY4xJ9CGyAa.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-langar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3ab50899-07ba-4f10-ad9f-67d010b45400",1442402439),$APP.$cljs$cst$2675$family$$,
"Langar",$APP.$cljs$cst$725$name$$,"Langar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/langar/v30/kJEyBukW7AIlgjGVrTVZ99sqrQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-lateef",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a04346bf-4625-4832-b565-b15f1397ff82",-1982655127),$APP.$cljs$cst$2675$family$$,"Lateef",$APP.$cljs$cst$725$name$$,"Lateef",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lateef/v35/hESz6XVnNCxEvkb0bjygbqTb9nQ-RA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lateef/v35/hESz6XVnNCxEvkb0Cj-gbqTb9nQ-RA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lateef/v35/hESw6XVnNCxEvkbMpheEZo_H_w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lateef/v35/hESz6XVnNCxEvkb0Uj6gbqTb9nQ-RA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lateef/v35/hESz6XVnNCxEvkb0fjmgbqTb9nQ-RA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lateef/v35/hESz6XVnNCxEvkb0GjigbqTb9nQ-RA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lateef/v35/hESz6XVnNCxEvkb0BjugbqTb9nQ-RA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lato",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f9ca6475-d6db-478c-8d1c-f333619d820e",765366768),$APP.$cljs$cst$2675$family$$,
"Lato",$APP.$cljs$cst$725$name$$,"Lato",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lato/v25/S6u8w4BMUTPHh30wWyWrFCbw7A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lato/v25/S6u-w4BMUTPHjxsIPy-vNiPg7MU0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lato/v25/S6u9w4BMUTPHh7USew-FGC_p9dw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lato/v25/S6u_w4BMUTPHjxsI9w2PHA3s5dwt7w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/lato/v25/S6uyw4BMUTPHvxk6XweuBCY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lato/v25/S6u8w4BMUTPHjxswWyWrFCbw7A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lato/v25/S6u9w4BMUTPHh6UVew-FGC_p9dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lato/v25/S6u_w4BMUTPHjxsI5wqPHA3s5dwt7w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lato/v25/S6u9w4BMUTPHh50Xew-FGC_p9dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lato/v25/S6u_w4BMUTPHjxsI3wiPHA3s5dwt7w.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lavishly-yours",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("198155df-4287-4dcc-92b8-0fdd0be679ea",-660234825),$APP.$cljs$cst$2675$family$$,"Lavishly Yours",$APP.$cljs$cst$725$name$$,"Lavishly Yours",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lavishlyyours/v7/jizDREVIvGwH5OjiZmX9r5z_WxUY0TY7ikbI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-league-gothic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e8e6738b-45cd-42ba-80ad-c01b023c37d8",493725226),$APP.$cljs$cst$2675$family$$,"League Gothic",$APP.$cljs$cst$725$name$$,"League Gothic",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/leaguegothic/v13/qFdR35CBi4tvBz81xy7WG7ep-BQAY7Krj7feObpH_-amidQ6Q9hn.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-league-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("17041902-282e-4f4b-ac3b-a33ccec4d0c3",1687106135),$APP.$cljs$cst$2675$family$$,"League Script",$APP.$cljs$cst$725$name$$,"League Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/leaguescript/v30/CSR54zpSlumSWj9CGVsoBZdeaNNUuOwkC2s.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-league-spartan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("02108e6a-d0c5-44c6-8a89-b516b39e544d",-1022826881),$APP.$cljs$cst$2675$family$$,"League Spartan",$APP.$cljs$cst$725$name$$,"League Spartan",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/leaguespartan/v15/kJEnBuEW6A0lliaV_m88ja5Twtx8BWhtkDVmjZvM_oXpBMdcFguczA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/leaguespartan/v15/kJEnBuEW6A0lliaV_m88ja5Twtx8BWhtkDVmjZvMfoTpBMdcFguczA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/leaguespartan/v15/kJEnBuEW6A0lliaV_m88ja5Twtx8BWhtkDVmjZvMoITpBMdcFguczA.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/leaguespartan/v15/kJEnBuEW6A0lliaV_m88ja5Twtx8BWhtkDVmjZvM_oTpBMdcFguczA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/leaguespartan/v15/kJEnBuEW6A0lliaV_m88ja5Twtx8BWhtkDVmjZvMzITpBMdcFguczA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/leaguespartan/v15/kJEnBuEW6A0lliaV_m88ja5Twtx8BWhtkDVmjZvMIIPpBMdcFguczA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/leaguespartan/v15/kJEnBuEW6A0lliaV_m88ja5Twtx8BWhtkDVmjZvMGYPpBMdcFguczA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/leaguespartan/v15/kJEnBuEW6A0lliaV_m88ja5Twtx8BWhtkDVmjZvMfoPpBMdcFguczA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/leaguespartan/v15/kJEnBuEW6A0lliaV_m88ja5Twtx8BWhtkDVmjZvMV4PpBMdcFguczA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-leckerli-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("25d44421-aa2b-4883-9a94-0c05f7e50ae5",
-1649500899),$APP.$cljs$cst$2675$family$$,"Leckerli One",$APP.$cljs$cst$725$name$$,"Leckerli One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/leckerlione/v22/V8mCoQH8VCsNttEnxnGQ-1itLZxcBtItFw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ledger",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a6942456-a5f7-4fb4-ab5b-7f79dfcec5d5",-623256019),$APP.$cljs$cst$2675$family$$,"Ledger",$APP.$cljs$cst$725$name$$,"Ledger",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ledger/v17/j8_q6-HK1L3if_sxm8DwHTBhHw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lekton",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4fe72042-6b9c-46cc-9646-43431ab53b1f",-1358017104),$APP.$cljs$cst$2675$family$$,"Lekton",$APP.$cljs$cst$725$name$$,"Lekton",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lekton/v21/SZc43FDmLaWmWpBeXxfonUPL6Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lekton/v21/SZc63FDmLaWmWpBuXR3sv0bb6StO.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lekton/v21/SZc73FDmLaWmWpBm4zjMlWjX4DJXgQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lemon",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a6de2ecf-8d4d-42f2-8ce9-57fe18164979",143875782),$APP.$cljs$cst$2675$family$$,"Lemon",$APP.$cljs$cst$725$name$$,"Lemon",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/lemon/v19/HI_EiYEVKqRMq0jBSZXAQ4-d.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lemonada",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7374a925-0838-41f8-9435-eb8a14b82e52",147433997),$APP.$cljs$cst$2675$family$$,"Lemonada",$APP.$cljs$cst$725$name$$,"Lemonada",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lemonada/v31/0QI-MXFD9oygTWy_R-FFlwV-bgfR7QJGJOt2mfWc3Z2pTg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lemonada/v31/0QI-MXFD9oygTWy_R-FFlwV-bgfR7QJGeut2mfWc3Z2pTg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lemonada/v31/0QI-MXFD9oygTWy_R-FFlwV-bgfR7QJGSOt2mfWc3Z2pTg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/lemonada/v31/0QI-MXFD9oygTWy_R-FFlwV-bgfR7QJGpOx2mfWc3Z2pTg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lemonada/v31/0QI-MXFD9oygTWy_R-FFlwV-bgfR7QJGnex2mfWc3Z2pTg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lexend",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("46dc57df-c449-40f7-b29e-faf42fe3289a",-204728505),$APP.$cljs$cst$2675$family$$,"Lexend",$APP.$cljs$cst$725$name$$,"Lexend",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/lexend/v26/wlptgwvFAVdoq2_F94zlCfv0bz1WCzsX_LBte6KuGEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexend/v26/wlptgwvFAVdoq2_F94zlCfv0bz1WC7sW_LBte6KuGEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexend/v26/wlptgwvFAVdoq2_F94zlCfv0bz1WC2UW_LBte6KuGEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexend/v26/wlptgwvFAVdoq2_F94zlCfv0bz1WCzsW_LBte6KuGEo.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexend/v26/wlptgwvFAVdoq2_F94zlCfv0bz1WCwkW_LBte6KuGEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/lexend/v26/wlptgwvFAVdoq2_F94zlCfv0bz1WC-UR_LBte6KuGEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexend/v26/wlptgwvFAVdoq2_F94zlCfv0bz1WC9wR_LBte6KuGEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexend/v26/wlptgwvFAVdoq2_F94zlCfv0bz1WC7sR_LBte6KuGEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexend/v26/wlptgwvFAVdoq2_F94zlCfv0bz1WC5IR_LBte6KuGEo.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lexend-deca",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1b9c137b-bde2-49f9-aa32-1a050b0e5438",-797337551),$APP.$cljs$cst$2675$family$$,"Lexend Deca",$APP.$cljs$cst$725$name$$,"Lexend Deca",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexenddeca/v25/K2FifZFYk-dHSE0UPPuwQ7CrD94i-NCKm-U48MxArBPCqLNflg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexenddeca/v25/K2FifZFYk-dHSE0UPPuwQ7CrD94i-NCKm-U4cM1ArBPCqLNflg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexenddeca/v25/K2FifZFYk-dHSE0UPPuwQ7CrD94i-NCKm-U4rs1ArBPCqLNflg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexenddeca/v25/K2FifZFYk-dHSE0UPPuwQ7CrD94i-NCKm-U48M1ArBPCqLNflg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexenddeca/v25/K2FifZFYk-dHSE0UPPuwQ7CrD94i-NCKm-U4ws1ArBPCqLNflg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexenddeca/v25/K2FifZFYk-dHSE0UPPuwQ7CrD94i-NCKm-U4LspArBPCqLNflg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexenddeca/v25/K2FifZFYk-dHSE0UPPuwQ7CrD94i-NCKm-U4F8pArBPCqLNflg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexenddeca/v25/K2FifZFYk-dHSE0UPPuwQ7CrD94i-NCKm-U4cMpArBPCqLNflg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexenddeca/v25/K2FifZFYk-dHSE0UPPuwQ7CrD94i-NCKm-U4WcpArBPCqLNflg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lexend-exa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b361bf8f-80de-4d6a-a5b2-da7a98cd31cb",-1582513441),$APP.$cljs$cst$2675$family$$,"Lexend Exa",$APP.$cljs$cst$725$name$$,"Lexend Exa",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendexa/v35/UMBCrPdOoHOnxExyjdBeQCH18mulUxBvI9r7T6bHHJ8BRq0b.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/lexendexa/v35/UMBCrPdOoHOnxExyjdBeQCH18mulUxBvI9p7TqbHHJ8BRq0b.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendexa/v35/UMBCrPdOoHOnxExyjdBeQCH18mulUxBvI9qlTqbHHJ8BRq0b.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendexa/v35/UMBCrPdOoHOnxExyjdBeQCH18mulUxBvI9r7TqbHHJ8BRq0b.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendexa/v35/UMBCrPdOoHOnxExyjdBeQCH18mulUxBvI9rJTqbHHJ8BRq0b.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendexa/v35/UMBCrPdOoHOnxExyjdBeQCH18mulUxBvI9olSabHHJ8BRq0b.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendexa/v35/UMBCrPdOoHOnxExyjdBeQCH18mulUxBvI9ocSabHHJ8BRq0b.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendexa/v35/UMBCrPdOoHOnxExyjdBeQCH18mulUxBvI9p7SabHHJ8BRq0b.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendexa/v35/UMBCrPdOoHOnxExyjdBeQCH18mulUxBvI9pSSabHHJ8BRq0b.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lexend-giga",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("20e27d6e-b714-4e66-bf75-2fb9e5187e45",-360494930),$APP.$cljs$cst$2675$family$$,"Lexend Giga",$APP.$cljs$cst$725$name$$,
"Lexend Giga",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendgiga/v27/PlIuFl67Mah5Y8yMHE7lkUZPlTBo4MWFfNRC2LmE68oo6eepYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendgiga/v27/PlIuFl67Mah5Y8yMHE7lkUZPlTBo4MWFfNRCWLiE68oo6eepYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendgiga/v27/PlIuFl67Mah5Y8yMHE7lkUZPlTBo4MWFfNRChriE68oo6eepYQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendgiga/v27/PlIuFl67Mah5Y8yMHE7lkUZPlTBo4MWFfNRC2LiE68oo6eepYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendgiga/v27/PlIuFl67Mah5Y8yMHE7lkUZPlTBo4MWFfNRC6riE68oo6eepYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendgiga/v27/PlIuFl67Mah5Y8yMHE7lkUZPlTBo4MWFfNRCBr-E68oo6eepYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendgiga/v27/PlIuFl67Mah5Y8yMHE7lkUZPlTBo4MWFfNRCP7-E68oo6eepYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendgiga/v27/PlIuFl67Mah5Y8yMHE7lkUZPlTBo4MWFfNRCWL-E68oo6eepYQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendgiga/v27/PlIuFl67Mah5Y8yMHE7lkUZPlTBo4MWFfNRCcb-E68oo6eepYQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lexend-mega",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2d508ca4-2dcd-45fc-824b-42dead7c454d",
2085710886),$APP.$cljs$cst$2675$family$$,"Lexend Mega",$APP.$cljs$cst$725$name$$,"Lexend Mega",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendmega/v27/qFdX35aBi5JtHD41zSTFEuTByuvYFuE9IbDL8fivveyiq9EqQw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendmega/v27/qFdX35aBi5JtHD41zSTFEuTByuvYFuE9IbDLcfmvveyiq9EqQw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendmega/v27/qFdX35aBi5JtHD41zSTFEuTByuvYFuE9IbDLr_mvveyiq9EqQw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendmega/v27/qFdX35aBi5JtHD41zSTFEuTByuvYFuE9IbDL8fmvveyiq9EqQw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendmega/v27/qFdX35aBi5JtHD41zSTFEuTByuvYFuE9IbDLw_mvveyiq9EqQw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendmega/v27/qFdX35aBi5JtHD41zSTFEuTByuvYFuE9IbDLL_6vveyiq9EqQw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendmega/v27/qFdX35aBi5JtHD41zSTFEuTByuvYFuE9IbDLFv6vveyiq9EqQw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendmega/v27/qFdX35aBi5JtHD41zSTFEuTByuvYFuE9IbDLcf6vveyiq9EqQw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendmega/v27/qFdX35aBi5JtHD41zSTFEuTByuvYFuE9IbDLWP6vveyiq9EqQw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-lexend-peta",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a7e41ed7-3de5-4350-8cb5-396b4fd9687b",909060569),$APP.$cljs$cst$2675$family$$,"Lexend Peta",$APP.$cljs$cst$725$name$$,"Lexend Peta",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendpeta/v30/BXR4vFPGjeLPh0kCfI4OkFX-UTQHSCaxvBgR6SFyW1YuRTsnfw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendpeta/v30/BXR4vFPGjeLPh0kCfI4OkFX-UTQHSCaxvBgRaSByW1YuRTsnfw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendpeta/v30/BXR4vFPGjeLPh0kCfI4OkFX-UTQHSCaxvBgRtyByW1YuRTsnfw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendpeta/v30/BXR4vFPGjeLPh0kCfI4OkFX-UTQHSCaxvBgR6SByW1YuRTsnfw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendpeta/v30/BXR4vFPGjeLPh0kCfI4OkFX-UTQHSCaxvBgR2yByW1YuRTsnfw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendpeta/v30/BXR4vFPGjeLPh0kCfI4OkFX-UTQHSCaxvBgRNydyW1YuRTsnfw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendpeta/v30/BXR4vFPGjeLPh0kCfI4OkFX-UTQHSCaxvBgRDidyW1YuRTsnfw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendpeta/v30/BXR4vFPGjeLPh0kCfI4OkFX-UTQHSCaxvBgRaSdyW1YuRTsnfw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendpeta/v30/BXR4vFPGjeLPh0kCfI4OkFX-UTQHSCaxvBgRQCdyW1YuRTsnfw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lexend-tera",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ba2e3445-f491-4589-9867-678ac3c33ffa",-1038666777),$APP.$cljs$cst$2675$family$$,"Lexend Tera",$APP.$cljs$cst$725$name$$,"Lexend Tera",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendtera/v29/RrQDbo98_jt_IXnBPwCWtYJLZ3P4hnaGKFiM5zITdpz0fYxcrQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendtera/v29/RrQDbo98_jt_IXnBPwCWtYJLZ3P4hnaGKFiMZzMTdpz0fYxcrQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendtera/v29/RrQDbo98_jt_IXnBPwCWtYJLZ3P4hnaGKFiMuTMTdpz0fYxcrQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendtera/v29/RrQDbo98_jt_IXnBPwCWtYJLZ3P4hnaGKFiM5zMTdpz0fYxcrQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendtera/v29/RrQDbo98_jt_IXnBPwCWtYJLZ3P4hnaGKFiM1TMTdpz0fYxcrQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendtera/v29/RrQDbo98_jt_IXnBPwCWtYJLZ3P4hnaGKFiMOTQTdpz0fYxcrQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendtera/v29/RrQDbo98_jt_IXnBPwCWtYJLZ3P4hnaGKFiMADQTdpz0fYxcrQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendtera/v29/RrQDbo98_jt_IXnBPwCWtYJLZ3P4hnaGKFiMZzQTdpz0fYxcrQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendtera/v29/RrQDbo98_jt_IXnBPwCWtYJLZ3P4hnaGKFiMTjQTdpz0fYxcrQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lexend-zetta",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4eba0fb8-ebd0-4b67-89cd-a0ae4b47f3a5",-1698640533),$APP.$cljs$cst$2675$family$$,"Lexend Zetta",$APP.$cljs$cst$725$name$$,"Lexend Zetta",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendzetta/v32/ll8uK2KYXje7CdOFnEWcU8synQbuVYjYB3BCy9bH0z5jbs8qbts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendzetta/v32/ll8uK2KYXje7CdOFnEWcU8synQbuVYjYB3BCy1bG0z5jbs8qbts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendzetta/v32/ll8uK2KYXje7CdOFnEWcU8synQbuVYjYB3BCy4jG0z5jbs8qbts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendzetta/v32/ll8uK2KYXje7CdOFnEWcU8synQbuVYjYB3BCy9bG0z5jbs8qbts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendzetta/v32/ll8uK2KYXje7CdOFnEWcU8synQbuVYjYB3BCy-TG0z5jbs8qbts.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendzetta/v32/ll8uK2KYXje7CdOFnEWcU8synQbuVYjYB3BCywjB0z5jbs8qbts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendzetta/v32/ll8uK2KYXje7CdOFnEWcU8synQbuVYjYB3BCyzHB0z5jbs8qbts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendzetta/v32/ll8uK2KYXje7CdOFnEWcU8synQbuVYjYB3BCy1bB0z5jbs8qbts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lexendzetta/v32/ll8uK2KYXje7CdOFnEWcU8synQbuVYjYB3BCy3_B0z5jbs8qbts.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-libertinus-keyboard",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("19c2e6e6-86f9-4c43-b15f-9b1b602f62bc",1521033403),$APP.$cljs$cst$2675$family$$,"Libertinus Keyboard",
$APP.$cljs$cst$725$name$$,"Libertinus Keyboard",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/libertinuskeyboard/v2/NaPEcYrQAP5Z2JsyIac0i2DYHaapaf43RryztWo_3fk.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-libertinus-math",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bec35ef4-f02d-4326-be3b-3d409e36d1ca",283899930),$APP.$cljs$cst$2675$family$$,"Libertinus Math",$APP.$cljs$cst$725$name$$,"Libertinus Math",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/libertinusmath/v1/Gw6iwc3770TVMoHVurPejWtfenRLv_KJt3R-2Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-libertinus-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6c236786-34a5-49b4-883c-6ad7e4d37a69",-1074782586),$APP.$cljs$cst$2675$family$$,"Libertinus Mono",$APP.$cljs$cst$725$name$$,"Libertinus Mono",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/libertinusmono/v1/_gPg1RnxrjY_TDm97ApTqwneJJFToBF3YROW_w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-libertinus-sans",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c1303372-360d-4b4c-bfa6-dc27f91a6018",-1018688450),$APP.$cljs$cst$2675$family$$,"Libertinus Sans",$APP.$cljs$cst$725$name$$,"Libertinus Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/libertinussans/v1/YA9Lr0-a6k7ZLbw_dle4knJh2cqMjt3V_dB0Yw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/libertinussans/v1/YA9Jr0-a6k7ZLbw_dle4knJh2cq8jNfR39VkYzCp.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/libertinussans/v1/YA9Or0-a6k7ZLbw_dle4knJh2cq0MvLx9ftoaimwmw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-libertinus-serif",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cb10efff-c62a-49ad-9f8e-9671a6d86857",794960150),$APP.$cljs$cst$2675$family$$,"Libertinus Serif",$APP.$cljs$cst$725$name$$,"Libertinus Serif",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/libertinusserif/v1/RLpkK4bw7KinajYBg0RTTwCLF5Ben6kFUHPIFaU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/libertinusserif/v1/RLpiK4bw7KinajYBg0RTTwCLF5Ber6sPVFHNBaVImA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/libertinusserif/v1/RLpjK4bw7KinajYBg0RTTwCLF5Bep3ErdHvjCaxRgew.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/libertinusserif/v1/RLphK4bw7KinajYBg0RTTwCLF5Ber6s3jH_pDY5UkexwPg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/libertinusserif/v1/RLpjK4bw7KinajYBg0RTTwCLF5BepxUqdHvjCaxRgew.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/libertinusserif/v1/RLphK4bw7KinajYBg0RTTwCLF5Ber6s36H7pDY5UkexwPg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-libertinus-serif-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8137c1d2-a1db-46d2-b776-a63870b5529f",1318151408),$APP.$cljs$cst$2675$family$$,"Libertinus Serif Display",$APP.$cljs$cst$725$name$$,"Libertinus Serif Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/libertinusserifdisplay/v2/0FlHVOmbklub_P32Hm53RVREi5BsXWudOF_Gpgcrg81gHhVOxQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-libre-barcode-128",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a82b4320-29b5-4ef1-a4df-6f68f1f93499",869247271),$APP.$cljs$cst$2675$family$$,"Libre Barcode 128",$APP.$cljs$cst$725$name$$,"Libre Barcode 128",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebarcode128/v31/cIfnMbdUsUoiW3O_hVviCwVjuLtXeJ_A_gMk0izH.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"gfont-libre-barcode-128-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ef322b53-6cfe-4131-a2e4-17244fd7514c",-1497834178),$APP.$cljs$cst$2675$family$$,"Libre Barcode 128 Text",$APP.$cljs$cst$725$name$$,"Libre Barcode 128 Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebarcode128text/v31/fdNv9tubt3ZEnz1Gu3I4-zppwZ9CWZ16Z0w5cV3Y6M90w4k.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-libre-barcode-39",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7cba130e-397d-4979-9f3c-52735d99464b",387374821),$APP.$cljs$cst$2675$family$$,"Libre Barcode 39",$APP.$cljs$cst$725$name$$,"Libre Barcode 39",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebarcode39/v25/-nFnOHM08vwC6h8Li1eQnP_AHzI2K_d709jy92k.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-libre-barcode-39-extended",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1a9fae43-c897-4a93-a2cc-152d5b613efc",-2130547447),$APP.$cljs$cst$2675$family$$,"Libre Barcode 39 Extended",$APP.$cljs$cst$725$name$$,"Libre Barcode 39 Extended",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebarcode39extended/v30/8At7Gt6_O5yNS0-K4Nf5U922qSzhJ3dUdfJpwNUgfNRCOZ1GOBw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-libre-barcode-39-extended-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("583cfab8-178b-40a2-b7b9-203faafa6036",99640507),$APP.$cljs$cst$2675$family$$,"Libre Barcode 39 Extended Text",$APP.$cljs$cst$725$name$$,"Libre Barcode 39 Extended Text",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebarcode39extendedtext/v30/eLG1P_rwIgOiDA7yrs9LoKaYRVLQ1YldrrOnnL7xPO4jNP68fLIiPopNNA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-libre-barcode-39-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5a63a154-4c82-47b0-81cf-8d1de532b97b",22148942),$APP.$cljs$cst$2675$family$$,"Libre Barcode 39 Text",$APP.$cljs$cst$725$name$$,"Libre Barcode 39 Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebarcode39text/v32/sJoa3KhViNKANw_E3LwoDXvs5Un0HQ1vT-031RRL-9rYaw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-libre-barcode-ean13-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8d924fae-440b-4ac5-bd39-41e3e2cdb451",-984833368),$APP.$cljs$cst$2675$family$$,"Libre Barcode EAN13 Text",$APP.$cljs$cst$725$name$$,"Libre Barcode EAN13 Text",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebarcodeean13text/v25/wlpigxXFDU1_oCu9nfZytgIqSG0XRcJm_OQiB96PAGEki52WfA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-libre-baskerville",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("03109598-0fc2-480a-8855-d1b7e1840045",-260931670),$APP.$cljs$cst$2675$family$$,"Libre Baskerville",$APP.$cljs$cst$725$name$$,"Libre Baskerville",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebaskerville/v24/kmKUZrc3Hgbbcjq75U4uslyuy4kn0olVQ-LglH6T17uj8Q4SCQlOvuPCfQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebaskerville/v24/kmKUZrc3Hgbbcjq75U4uslyuy4kn0olVQ-LglH6T17ujww4SCQlOvuPCfQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebaskerville/v24/kmKUZrc3Hgbbcjq75U4uslyuy4kn0olVQ-LglH6T17ujLwkSCQlOvuPCfQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebaskerville/v24/kmKUZrc3Hgbbcjq75U4uslyuy4kn0olVQ-LglH6T17ujFgkSCQlOvuPCfQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebaskerville/v24/kmKWZrc3Hgbbcjq75U4uslyuy4kn0qNccR04_RUJeby2OU36SgNKnObSfbge.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",
$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebaskerville/v24/kmKWZrc3Hgbbcjq75U4uslyuy4kn0qNccR04_RUJeby2OU3ISgNKnObSfbge.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebaskerville/v24/kmKWZrc3Hgbbcjq75U4uslyuy4kn0qNccR04_RUJeby2OU0kTQNKnObSfbge.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebaskerville/v24/kmKWZrc3Hgbbcjq75U4uslyuy4kn0qNccR04_RUJeby2OU0dTQNKnObSfbge.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-libre-bodoni",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e1238577-95f6-4d86-96e3-d2c7b828c671",
60610264),$APP.$cljs$cst$2675$family$$,"Libre Bodoni",$APP.$cljs$cst$725$name$$,"Libre Bodoni",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebodoni/v9/_Xm--H45qDWDYULr5OfyZudXzSBgY2oMBGte6I1fwWzZcOb3U3s.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebodoni/v9/_Xm--H45qDWDYULr5OfyZudXzSBgY2oMBGte6L9fwWzZcOb3U3s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebodoni/v9/_Xm--H45qDWDYULr5OfyZudXzSBgY2oMBGte6FNYwWzZcOb3U3s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebodoni/v9/_Xm--H45qDWDYULr5OfyZudXzSBgY2oMBGte6GpYwWzZcOb3U3s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebodoni/v9/_Xm4-H45qDWDYULr5OfyZud9xBKfuwNnnsVZ_UUcKS_TdMTyQ3syLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebodoni/v9/_Xm4-H45qDWDYULr5OfyZud9xBKfuwNnnsVZ_UUcGy_TdMTyQ3syLg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebodoni/v9/_Xm4-H45qDWDYULr5OfyZud9xBKfuwNnnsVZ_UUc9yjTdMTyQ3syLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librebodoni/v9/_Xm4-H45qDWDYULr5OfyZud9xBKfuwNnnsVZ_UUczijTdMTyQ3syLg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-libre-caslon-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5cb75dd0-3958-4433-a68b-f1f25a28d756",-245258979),$APP.$cljs$cst$2675$family$$,"Libre Caslon Display",$APP.$cljs$cst$725$name$$,"Libre Caslon Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librecaslondisplay/v18/TuGOUUFxWphYQ6YI6q9Xp61FQzxDRKmzr2lRdRhtCC4d.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-libre-caslon-text",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("b9b0fa70-367d-4ce4-8097-4814d586ecbe",215177982),$APP.$cljs$cst$2675$family$$,"Libre Caslon Text",$APP.$cljs$cst$725$name$$,"Libre Caslon Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/librecaslontext/v5/DdT878IGsGw1aF1JU10PUbTvNNaDMcq_3eNrHgO1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librecaslontext/v5/DdT678IGsGw1aF1JU10PUbTvNNaDMfq91-dJGxO1q9o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",
$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librecaslontext/v5/DdT578IGsGw1aF1JU10PUbTvNNaDMfID8sdjNR-8ssPt.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-libre-franklin",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("efb670df-1e68-4deb-a225-ce3460ca2101",1483244115),$APP.$cljs$cst$2675$family$$,"Libre Franklin",$APP.$cljs$cst$725$name$$,
"Libre Franklin",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizOREVItHgc8qDIbSTKq4XkRg8T88bjFuXOnduhLsSUB9rIb-JH1g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizOREVItHgc8qDIbSTKq4XkRg8T88bjFuXOnduhrsWUB9rIb-JH1g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizOREVItHgc8qDIbSTKq4XkRg8T88bjFuXOnduhcMWUB9rIb-JH1g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizOREVItHgc8qDIbSTKq4XkRg8T88bjFuXOnduhLsWUB9rIb-JH1g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizOREVItHgc8qDIbSTKq4XkRg8T88bjFuXOnduhHMWUB9rIb-JH1g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizOREVItHgc8qDIbSTKq4XkRg8T88bjFuXOnduh8MKUB9rIb-JH1g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizOREVItHgc8qDIbSTKq4XkRg8T88bjFuXOnduhycKUB9rIb-JH1g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizOREVItHgc8qDIbSTKq4XkRg8T88bjFuXOnduhrsKUB9rIb-JH1g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizOREVItHgc8qDIbSTKq4XkRg8T88bjFuXOnduhh8KUB9rIb-JH1g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizMREVItHgc8qDIbSTKq4XkRiUawTk7f45UM9y05oZ8RdDMTedX1sGE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizMREVItHgc8qDIbSTKq4XkRiUawTk7f45UM9y05ob8RNDMTedX1sGE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizMREVItHgc8qDIbSTKq4XkRiUawTk7f45UM9y05oYiRNDMTedX1sGE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/librefranklin/v20/jizMREVItHgc8qDIbSTKq4XkRiUawTk7f45UM9y05oZ8RNDMTedX1sGE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizMREVItHgc8qDIbSTKq4XkRiUawTk7f45UM9y05oZORNDMTedX1sGE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizMREVItHgc8qDIbSTKq4XkRiUawTk7f45UM9y05oaiQ9DMTedX1sGE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/librefranklin/v20/jizMREVItHgc8qDIbSTKq4XkRiUawTk7f45UM9y05oabQ9DMTedX1sGE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizMREVItHgc8qDIbSTKq4XkRiUawTk7f45UM9y05ob8Q9DMTedX1sGE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/librefranklin/v20/jizMREVItHgc8qDIbSTKq4XkRiUawTk7f45UM9y05obVQ9DMTedX1sGE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-licorice",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9f4d0434-2024-44f4-965c-c06c3f002921",1368819018),$APP.$cljs$cst$2675$family$$,
"Licorice",$APP.$cljs$cst$725$name$$,"Licorice",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/licorice/v8/t5tjIR8TMomTCAyjNk23hqLgzCHu.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-life-savers",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6128a265-91a2-41f6-88fb-7e732c41c6e8",-1619410228),$APP.$cljs$cst$2675$family$$,"Life Savers",$APP.$cljs$cst$725$name$$,"Life Savers",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lifesavers/v23/ZXuie1UftKKabUQMgxAal_lrFgpbuNvB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lifesavers/v23/ZXu_e1UftKKabUQMgxAal8HXOS5Tk8fIpPRW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lifesavers/v23/ZXu_e1UftKKabUQMgxAal8HLOi5Tk8fIpPRW.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lilita-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e9eb7036-af8f-4521-864f-291e0d26b6d4",758179320),$APP.$cljs$cst$2675$family$$,"Lilita One",$APP.$cljs$cst$725$name$$,"Lilita One",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lilitaone/v17/i7dPIFZ9Zz-WBtRtedDbUEZ2RFq7AwU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-lily-script-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f6a5d939-ed15-447d-b7f0-e63effaf25bf",262504225),$APP.$cljs$cst$2675$family$$,"Lily Script One",$APP.$cljs$cst$725$name$$,"Lily Script One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lilyscriptone/v16/LhW9MV7ZMfIPdMxeBjBvFN8SXLS4gsSjQNsRMg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-limelight",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("276133ba-2e4e-4963-8132-bd90dc31ad40",255404082),$APP.$cljs$cst$2675$family$$,"Limelight",$APP.$cljs$cst$725$name$$,"Limelight",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/limelight/v21/XLYkIZL7aopJVbZJHDuYPeNGrnY2TA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-linden-hill",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ba1b6015-1b0c-4656-94c1-9fd38801e023",1452354154),$APP.$cljs$cst$2675$family$$,
"Linden Hill",$APP.$cljs$cst$725$name$$,"Linden Hill",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lindenhill/v27/-F61fjxoKSg9Yc3hZgO8ygFI7CwC009k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lindenhill/v27/-F63fjxoKSg9Yc3hZgO8yjFK5igg1l9kn-s.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-linefont",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("94439ab4-c401-4392-b9ad-5b5e64c00c45",1923165070),$APP.$cljs$cst$2675$family$$,"Linefont",
$APP.$cljs$cst$725$name$$,"Linefont",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/linefont/v10/dg4I_pzpoqcLKUIzVfFMh1TF2rkhli25jn7CKTTWSumsFuSnY4UNbu7tmdXux3U.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/linefont/v10/dg4I_pzpoqcLKUIzVfFMh1TF2rkhli25jn7CKTTWSumsFuSnYwUMbu7tmdXux3U.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/linefont/v10/dg4I_pzpoqcLKUIzVfFMh1TF2rkhli25jn7CKTTWSumsFuSnY9sMbu7tmdXux3U.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/linefont/v10/dg4I_pzpoqcLKUIzVfFMh1TF2rkhli25jn7CKTTWSumsFuSnY4UMbu7tmdXux3U.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/linefont/v10/dg4I_pzpoqcLKUIzVfFMh1TF2rkhli25jn7CKTTWSumsFuSnY7cMbu7tmdXux3U.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/linefont/v10/dg4I_pzpoqcLKUIzVfFMh1TF2rkhli25jn7CKTTWSumsFuSnY1sLbu7tmdXux3U.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/linefont/v10/dg4I_pzpoqcLKUIzVfFMh1TF2rkhli25jn7CKTTWSumsFuSnY2ILbu7tmdXux3U.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/linefont/v10/dg4I_pzpoqcLKUIzVfFMh1TF2rkhli25jn7CKTTWSumsFuSnYwULbu7tmdXux3U.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/linefont/v10/dg4I_pzpoqcLKUIzVfFMh1TF2rkhli25jn7CKTTWSumsFuSnYywLbu7tmdXux3U.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lisu-bosa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("110c6016-c10c-4eda-839d-bed7c5932845",
389603196),$APP.$cljs$cst$2675$family$$,"Lisu Bosa",$APP.$cljs$cst$725$name$$,"Lisu Bosa",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lisubosa/v2/3XFtErkv240fsdmJRJQXX2DGRdbY1P1Sbg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lisubosa/v2/3XFzErkv240fsdmJRJQflXkuRNzc9vhCblye.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/lisubosa/v2/3XFtErkv240fsdmJRJQXO2PGRdbY1P1Sbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lisubosa/v2/3XFzErkv240fsdmJRJQflXlKR9zc9vhCblye.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lisubosa/v2/3XFoErkv240fsdmJRJQvl0viTf3E3Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lisubosa/v2/3XFuErkv240fsdmJRJQflUHmb_jU3eRL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lisubosa/v2/3XFtErkv240fsdmJRJQXY2LGRdbY1P1Sbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lisubosa/v2/3XFzErkv240fsdmJRJQflXkSRtzc9vhCblye.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lisubosa/v2/3XFtErkv240fsdmJRJQXT2XGRdbY1P1Sbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/lisubosa/v2/3XFzErkv240fsdmJRJQflXk-Qdzc9vhCblye.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lisubosa/v2/3XFtErkv240fsdmJRJQXK2TGRdbY1P1Sbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",
$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lisubosa/v2/3XFzErkv240fsdmJRJQflXlaQNzc9vhCblye.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lisubosa/v2/3XFtErkv240fsdmJRJQXN2fGRdbY1P1Sbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lisubosa/v2/3XFzErkv240fsdmJRJQflXlGQ9zc9vhCblye.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lisubosa/v2/3XFtErkv240fsdmJRJQXE2bGRdbY1P1Sbg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lisubosa/v2/3XFzErkv240fsdmJRJQflXliQtzc9vhCblye.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-liter",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5ae8e790-64d7-4f36-b3d6-937ef0fe211a",903333982),
$APP.$cljs$cst$2675$family$$,"Liter",$APP.$cljs$cst$725$name$$,"Liter",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/liter/v4/SLXGc1nX4GQ4d2ImRJqExst1.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-literata",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("78e22c97-d25d-42ae-9e72-893a7e63e0f6",901360803),$APP.$cljs$cst$2675$family$$,"Literata",$APP.$cljs$cst$725$name$$,"Literata",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/literata/v40/or3PQ6P12-iJxAIgLa78DkrbXsDgk0oVDaDPYLanFLHpPf2TbJG_F_bcTWCWp8g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/literata/v40/or3PQ6P12-iJxAIgLa78DkrbXsDgk0oVDaDPYLanFLHpPf2TbE-_F_bcTWCWp8g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/literata/v40/or3PQ6P12-iJxAIgLa78DkrbXsDgk0oVDaDPYLanFLHpPf2TbBG_F_bcTWCWp8g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/literata/v40/or3PQ6P12-iJxAIgLa78DkrbXsDgk0oVDaDPYLanFLHpPf2TbCO_F_bcTWCWp8g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/literata/v40/or3PQ6P12-iJxAIgLa78DkrbXsDgk0oVDaDPYLanFLHpPf2TbM-4F_bcTWCWp8g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/literata/v40/or3PQ6P12-iJxAIgLa78DkrbXsDgk0oVDaDPYLanFLHpPf2TbPa4F_bcTWCWp8g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/literata/v40/or3PQ6P12-iJxAIgLa78DkrbXsDgk0oVDaDPYLanFLHpPf2TbJG4F_bcTWCWp8g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/literata/v40/or3PQ6P12-iJxAIgLa78DkrbXsDgk0oVDaDPYLanFLHpPf2TbLi4F_bcTWCWp8g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/literata/v40/or3NQ6P12-iJxAIgLYT1PLs1Zd0nfUwAbeGVKoRYzNiCp1OUedn8f7XWSUKTt8iVow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/literata/v40/or3NQ6P12-iJxAIgLYT1PLs1Zd0nfUwAbeGVKoRYzNiCp1OUedn8obXWSUKTt8iVow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/literata/v40/or3NQ6P12-iJxAIgLYT1PLs1Zd0nfUwAbeGVKoRYzNiCp1OUedn8_7XWSUKTt8iVow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/literata/v40/or3NQ6P12-iJxAIgLYT1PLs1Zd0nfUwAbeGVKoRYzNiCp1OUedn8zbXWSUKTt8iVow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/literata/v40/or3NQ6P12-iJxAIgLYT1PLs1Zd0nfUwAbeGVKoRYzNiCp1OUedn8IbLWSUKTt8iVow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/literata/v40/or3NQ6P12-iJxAIgLYT1PLs1Zd0nfUwAbeGVKoRYzNiCp1OUedn8GLLWSUKTt8iVow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/literata/v40/or3NQ6P12-iJxAIgLYT1PLs1Zd0nfUwAbeGVKoRYzNiCp1OUedn8f7LWSUKTt8iVow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/literata/v40/or3NQ6P12-iJxAIgLYT1PLs1Zd0nfUwAbeGVKoRYzNiCp1OUedn8VrLWSUKTt8iVow.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-liu-jian-mao-cao",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1b931e6b-1142-4400-a7d7-bf165cf8917b",897140595),$APP.$cljs$cst$2675$family$$,"Liu Jian Mao Cao",$APP.$cljs$cst$725$name$$,"Liu Jian Mao Cao",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/liujianmaocao/v24/845DNN84HJrccNonurqXILGpvCOoferVKGWsUo8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-livvic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("33ef7e37-c787-49a0-b9a7-c4fe95284b21",529364106),$APP.$cljs$cst$2675$family$$,"Livvic",$APP.$cljs$cst$725$name$$,"Livvic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/livvic/v15/rnCr-x1S2hzjrlffC-M-mHnOSOuk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/livvic/v15/rnCt-x1S2hzjrlfXbdtakn3sTfukQHs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/livvic/v15/rnCq-x1S2hzjrlffp8IeslfCQfK9WQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,
"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/livvic/v15/rnCs-x1S2hzjrlfXbdv2s13GY_etWWIJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/livvic/v15/rnCq-x1S2hzjrlffw8EeslfCQfK9WQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/livvic/v15/rnCs-x1S2hzjrlfXbduSsF3GY_etWWIJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/livvic/v15/rnCp-x1S2hzjrlfnb-k6unzeSA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/livvic/v15/rnCr-x1S2hzjrlfXbeM-mHnOSOuk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/livvic/v15/rnCq-x1S2hzjrlffm8AeslfCQfK9WQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/livvic/v15/rnCs-x1S2hzjrlfXbdvKsV3GY_etWWIJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/livvic/v15/rnCq-x1S2hzjrlfft8ceslfCQfK9WQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/livvic/v15/rnCs-x1S2hzjrlfXbdvmtl3GY_etWWIJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/livvic/v15/rnCq-x1S2hzjrlff08YeslfCQfK9WQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/livvic/v15/rnCs-x1S2hzjrlfXbduCt13GY_etWWIJ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/livvic/v15/rnCq-x1S2hzjrlff68QeslfCQfK9WQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/livvic/v15/rnCs-x1S2hzjrlfXbdu6tV3GY_etWWIJ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lobster",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4a2ed61b-77e8-4d77-ae9e-6f5c4171f54d",32892073),$APP.$cljs$cst$2675$family$$,"Lobster",$APP.$cljs$cst$725$name$$,"Lobster",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lobster/v32/neILzCirqoswsqX9_oWsMqEzSJQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lobster-two",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("51cf1399-3697-426f-a20b-6fdece20a5e6",-783091319),$APP.$cljs$cst$2675$family$$,"Lobster Two",$APP.$cljs$cst$725$name$$,
"Lobster Two",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lobstertwo/v22/BngMUXZGTXPUvIoyV6yN59fK7KSJ4ACD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lobstertwo/v22/BngOUXZGTXPUvIoyV6yN5-fI5qCr5RCDY_k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lobstertwo/v22/BngRUXZGTXPUvIoyV6yN5-92w4CByxyKeuDp.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lobstertwo/v22/BngTUXZGTXPUvIoyV6yN5-fI3hyEwRiof_DpXMY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-londrina-outline",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5847c23b-3696-4044-b648-351e9755af9d",
-796801035),$APP.$cljs$cst$2675$family$$,"Londrina Outline",$APP.$cljs$cst$725$name$$,"Londrina Outline",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/londrinaoutline/v29/C8c44dM8vmb14dfsZxhetg3pDH-SfuoxrSKMDvI.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-londrina-shadow",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("53f558d3-2475-4750-9832-ddc8f7f3c70b",1153114952),$APP.$cljs$cst$2675$family$$,"Londrina Shadow",$APP.$cljs$cst$725$name$$,"Londrina Shadow",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/londrinashadow/v28/oPWX_kB4kOQoWNJmjxLV5JuoCUlXRlaSxkrMCQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-londrina-sketch",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4139ee8d-5411-4d6f-a59b-cab67aa0dba9",-1211808971),$APP.$cljs$cst$2675$family$$,"Londrina Sketch",$APP.$cljs$cst$725$name$$,
"Londrina Sketch",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/londrinasketch/v27/c4m41npxGMTnomOHtRU68eIJn8qfWWn5Pos6CA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-londrina-solid",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2f9a866b-3484-4899-8c7b-4682327120ed",-1974621400),$APP.$cljs$cst$2675$family$$,"Londrina Solid",$APP.$cljs$cst$725$name$$,"Londrina Solid",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/londrinasolid/v19/flUjRq6sw40kQEJxWNgkLuudGfs9KBYesZHhV64.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/londrinasolid/v19/flUiRq6sw40kQEJxWNgkLuudGfv1CjY0n53oTrcL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/londrinasolid/v19/flUhRq6sw40kQEJxWNgkLuudGcNZIhI8tIHh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/londrinasolid/v19/flUiRq6sw40kQEJxWNgkLuudGfvdDzY0n53oTrcL.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-long-cang",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("29f61717-2e62-475b-b669-287f68a28dbc",-764560572),$APP.$cljs$cst$2675$family$$,"Long Cang",$APP.$cljs$cst$725$name$$,"Long Cang",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/longcang/v21/LYjAdGP8kkgoTec8zkRgrXArXN7HWQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lora",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("70d33f8b-8434-4e6e-b9e0-c34ca130c9af",-1715651158),$APP.$cljs$cst$2675$family$$,"Lora",$APP.$cljs$cst$725$name$$,"Lora",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lora/v37/0QI6MX1D_JOuGQbT0gvTJPa787weuyJGmKxemMeZ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lora/v37/0QI6MX1D_JOuGQbT0gvTJPa787wsuyJGmKxemMeZ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lora/v37/0QI6MX1D_JOuGQbT0gvTJPa787zAvCJGmKxemMeZ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",
$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lora/v37/0QI6MX1D_JOuGQbT0gvTJPa787z5vCJGmKxemMeZ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lora/v37/0QI8MX1D_JOuMw_hLdO6T2wV9KnW-MoFkqh8ndeZzZ0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lora/v37/0QI8MX1D_JOuMw_hLdO6T2wV9KnW-PgFkqh8ndeZzZ0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lora/v37/0QI8MX1D_JOuMw_hLdO6T2wV9KnW-BQCkqh8ndeZzZ0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lora/v37/0QI8MX1D_JOuMw_hLdO6T2wV9KnW-C0Ckqh8ndeZzZ0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-love-light",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7a3b59bd-0923-45d7-a1fb-6a89808ec182",82298013),$APP.$cljs$cst$2675$family$$,"Love Light",$APP.$cljs$cst$725$name$$,"Love Light",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lovelight/v8/t5tlIR0TNJyZWimpNAXDjKbCyTHuspo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-love-ya-like-a-sister",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("30eae9b4-33f5-4cad-afa8-83c6ac35790b",-1018883101),$APP.$cljs$cst$2675$family$$,"Love Ya Like A Sister",$APP.$cljs$cst$725$name$$,"Love Ya Like A Sister",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/loveyalikeasister/v23/R70EjzUBlOqPeouhFDfR80-0FhOqJubN-Be78nZcsGGycA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-loved-by-the-king",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("da2c28a1-04ef-4222-8880-c0d7466efddd",401679299),$APP.$cljs$cst$2675$family$$,"Loved by the King",$APP.$cljs$cst$725$name$$,"Loved by the King",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/lovedbytheking/v24/Gw6gwdP76VDVJNXerebZxUMeRXUF2PiNlXFu2R64.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lovers-quarrel",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("023d8092-2d62-4c61-af97-98b0eacfba57",-506397729),$APP.$cljs$cst$2675$family$$,"Lovers Quarrel",$APP.$cljs$cst$725$name$$,"Lovers Quarrel",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/loversquarrel/v25/Yq6N-LSKXTL-5bCy8ksBzpQ_-zAsY7pO6siz.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-luckiest-guy",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("36110a19-ba02-47d3-bf65-251fb554acc4",1045752800),
$APP.$cljs$cst$2675$family$$,"Luckiest Guy",$APP.$cljs$cst$725$name$$,"Luckiest Guy",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/luckiestguy/v25/_gP_1RrxsjcxVyin9l9n_j2RStR3qDpraA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lugrasimo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3818c8df-14d5-4394-a57d-e5cbcaf28aff",-1488426480),$APP.$cljs$cst$2675$family$$,"Lugrasimo",$APP.$cljs$cst$725$name$$,"Lugrasimo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lugrasimo/v5/qkBXXvoF_s_eT9c7Y7ae5JRLkAXbMQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lumanosimo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("eefeab03-b531-4b8d-b448-c06febf1c608",830479953),$APP.$cljs$cst$2675$family$$,"Lumanosimo",$APP.$cljs$cst$725$name$$,"Lumanosimo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lumanosimo/v5/K2F0fZBYg_JDSEZHEfO8AoqKAyLzfWo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lunasima",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bd4430ea-8081-460f-ae68-8743d902a3b1",
-1648337610),$APP.$cljs$cst$2675$family$$,"Lunasima",$APP.$cljs$cst$725$name$$,"Lunasima",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lunasima/v1/wEO-EBvPh9RSOj7JFAwle94H1VIe.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lunasima/v1/wEO5EBvPh9RSOj7JFDSZVPoP_k4XiKvO.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lusitana",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("65415ab5-11c5-43d5-a1bf-5cec05b26c7f",1598172418),$APP.$cljs$cst$2675$family$$,
"Lusitana",$APP.$cljs$cst$725$name$$,"Lusitana",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lusitana/v14/CSR84z9ShvucWzsMKxhaRuMiSct_.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lusitana/v14/CSR74z9ShvucWzsMKyDmaccqYtd2vfwk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-lustria",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8d09bffd-6c59-4618-b491-719a49027157",-437654377),$APP.$cljs$cst$2675$family$$,"Lustria",$APP.$cljs$cst$725$name$$,
"Lustria",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/lustria/v14/9oRONYodvDEyjuhOrCg5MtPyAcg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-luxurious-roman",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fd6ed44e-8dcc-4f44-aaaa-ca9cb90b721a",865497419),$APP.$cljs$cst$2675$family$$,"Luxurious Roman",$APP.$cljs$cst$725$name$$,"Luxurious Roman",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/luxuriousroman/v10/buEupou_ZcP1w0yTKxJJokVSmbpqYgckeo9RMw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-luxurious-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("def0ec9b-b264-4b90-ad4d-34ccebc648c3",-1755925416),$APP.$cljs$cst$2675$family$$,"Luxurious Script",$APP.$cljs$cst$725$name$$,"Luxurious Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/luxuriousscript/v9/ahcCv9e7yydulT32KZ0rBIoD7DzMg0rOby1JtYk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-m-plus-1",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("157d1bc5-314d-4991-85c3-9807b8d3c283",
-2039693334),$APP.$cljs$cst$2675$family$$,"M PLUS 1",$APP.$cljs$cst$725$name$$,"M PLUS 1",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1/v15/R70EjygA28ymD4HgBUGzkN5Eyoj-WpW5VSe78nZcsGGycA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1/v15/R70EjygA28ymD4HgBUGzkN5Eyoj-WpW51Sa78nZcsGGycA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mplus1/v15/R70EjygA28ymD4HgBUGzkN5Eyoj-WpW5Cya78nZcsGGycA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1/v15/R70EjygA28ymD4HgBUGzkN5Eyoj-WpW5VSa78nZcsGGycA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1/v15/R70EjygA28ymD4HgBUGzkN5Eyoj-WpW5Zya78nZcsGGycA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1/v15/R70EjygA28ymD4HgBUGzkN5Eyoj-WpW5iyG78nZcsGGycA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1/v15/R70EjygA28ymD4HgBUGzkN5Eyoj-WpW5siG78nZcsGGycA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mplus1/v15/R70EjygA28ymD4HgBUGzkN5Eyoj-WpW51SG78nZcsGGycA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1/v15/R70EjygA28ymD4HgBUGzkN5Eyoj-WpW5_CG78nZcsGGycA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-m-plus-1-code",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ca066eb4-ede3-48be-a568-80f2c3aa0cf3",1659037969),$APP.$cljs$cst$2675$family$$,"M PLUS 1 Code",$APP.$cljs$cst$725$name$$,"M PLUS 1 Code",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mplus1code/v16/ypvMbXOOx2xFpzmYJS3N2_J2hBN6RZ5oIp8m_7iN0XHpapwmdZhY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1code/v16/ypvMbXOOx2xFpzmYJS3N2_J2hBN6RZ5oIp8m_7gN0HHpapwmdZhY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",
$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1code/v16/ypvMbXOOx2xFpzmYJS3N2_J2hBN6RZ5oIp8m_7jT0HHpapwmdZhY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1code/v16/ypvMbXOOx2xFpzmYJS3N2_J2hBN6RZ5oIp8m_7iN0HHpapwmdZhY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1code/v16/ypvMbXOOx2xFpzmYJS3N2_J2hBN6RZ5oIp8m_7i_0HHpapwmdZhY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1code/v16/ypvMbXOOx2xFpzmYJS3N2_J2hBN6RZ5oIp8m_7hT13HpapwmdZhY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1code/v16/ypvMbXOOx2xFpzmYJS3N2_J2hBN6RZ5oIp8m_7hq13HpapwmdZhY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-m-plus-1p",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("609047cd-2698-4e4c-8be0-d7f0d9297f98",-458950168),$APP.$cljs$cst$2675$family$$,"M PLUS 1p",$APP.$cljs$cst$725$name$$,"M PLUS 1p",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1p/v32/e3tleuShHdiFyPFzBRrQnDQAUW3aq-5N.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1p/v32/e3tmeuShHdiFyPFzBRrQVBYge0PWovdU4w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1p/v32/e3tjeuShHdiFyPFzBRro-D4Ec2jKqw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1p/v32/e3tmeuShHdiFyPFzBRrQDBcge0PWovdU4w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1p/v32/e3tmeuShHdiFyPFzBRrQRBEge0PWovdU4w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1p/v32/e3tmeuShHdiFyPFzBRrQWBIge0PWovdU4w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus1p/v32/e3tmeuShHdiFyPFzBRrQfBMge0PWovdU4w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-m-plus-2",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("af80a9c7-dba8-448b-bb62-cbea8ffc3607",-1875074367),
$APP.$cljs$cst$2675$family$$,"M PLUS 2",$APP.$cljs$cst$725$name$$,"M PLUS 2",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus2/v15/7Auhp_Eq3gO_OGbGGhjdwrDdpeIBxlkwOa-VxlqHrzNgAw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus2/v15/7Auhp_Eq3gO_OGbGGhjdwrDdpeIBxlkwua6VxlqHrzNgAw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mplus2/v15/7Auhp_Eq3gO_OGbGGhjdwrDdpeIBxlkwZ66VxlqHrzNgAw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus2/v15/7Auhp_Eq3gO_OGbGGhjdwrDdpeIBxlkwOa6VxlqHrzNgAw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus2/v15/7Auhp_Eq3gO_OGbGGhjdwrDdpeIBxlkwC66VxlqHrzNgAw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus2/v15/7Auhp_Eq3gO_OGbGGhjdwrDdpeIBxlkw56mVxlqHrzNgAw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus2/v15/7Auhp_Eq3gO_OGbGGhjdwrDdpeIBxlkw3qmVxlqHrzNgAw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mplus2/v15/7Auhp_Eq3gO_OGbGGhjdwrDdpeIBxlkwuamVxlqHrzNgAw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplus2/v15/7Auhp_Eq3gO_OGbGGhjdwrDdpeIBxlkwkKmVxlqHrzNgAw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-m-plus-code-latin",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8e064cf4-b053-44ae-a275-270e96358a85",-2067793492),$APP.$cljs$cst$2675$family$$,"M PLUS Code Latin",$APP.$cljs$cst$725$name$$,"M PLUS Code Latin",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mpluscodelatin/v16/hv-ylyV-aXg7x7tULiNXXBA0Np4WMS8fDIymHY8fy8wn4_ifLAtrObKDO0Xf1EbB6i5MqF9TRwg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mpluscodelatin/v16/hv-ylyV-aXg7x7tULiNXXBA0Np4WMS8fDIymHY8fy8wn4_ifLAtrObKDO0Xf1MbA6i5MqF9TRwg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mpluscodelatin/v16/hv-ylyV-aXg7x7tULiNXXBA0Np4WMS8fDIymHY8fy8wn4_ifLAtrObKDO0Xf1BjA6i5MqF9TRwg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mpluscodelatin/v16/hv-ylyV-aXg7x7tULiNXXBA0Np4WMS8fDIymHY8fy8wn4_ifLAtrObKDO0Xf1EbA6i5MqF9TRwg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mpluscodelatin/v16/hv-ylyV-aXg7x7tULiNXXBA0Np4WMS8fDIymHY8fy8wn4_ifLAtrObKDO0Xf1HTA6i5MqF9TRwg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mpluscodelatin/v16/hv-ylyV-aXg7x7tULiNXXBA0Np4WMS8fDIymHY8fy8wn4_ifLAtrObKDO0Xf1JjH6i5MqF9TRwg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mpluscodelatin/v16/hv-ylyV-aXg7x7tULiNXXBA0Np4WMS8fDIymHY8fy8wn4_ifLAtrObKDO0Xf1KHH6i5MqF9TRwg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-m-plus-rounded-1c",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("96ec372b-9e1f-4c7e-8e27-fbf2e9f30494",-1170263816),$APP.$cljs$cst$2675$family$$,"M PLUS Rounded 1c",$APP.$cljs$cst$725$name$$,"M PLUS Rounded 1c",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplusrounded1c/v19/VdGCAYIAV6gnpUpoWwNkYvrugw9RuM3ixLsg6-av1x0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplusrounded1c/v19/VdGBAYIAV6gnpUpoWwNkYvrugw9RuM0q5psKxeqmzgRK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplusrounded1c/v19/VdGEAYIAV6gnpUpoWwNkYvrugw9RuPWGzr8C7vav.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplusrounded1c/v19/VdGBAYIAV6gnpUpoWwNkYvrugw9RuM1y55sKxeqmzgRK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplusrounded1c/v19/VdGBAYIAV6gnpUpoWwNkYvrugw9RuM064ZsKxeqmzgRK.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplusrounded1c/v19/VdGBAYIAV6gnpUpoWwNkYvrugw9RuM0m4psKxeqmzgRK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mplusrounded1c/v19/VdGBAYIAV6gnpUpoWwNkYvrugw9RuM0C45sKxeqmzgRK.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ma-shan-zheng",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("640bd5c7-85c0-4cb2-8bc2-8ecdd82af423",2121298272),$APP.$cljs$cst$2675$family$$,"Ma Shan Zheng",$APP.$cljs$cst$725$name$$,"Ma Shan Zheng",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mashanzheng/v14/NaPecZTRCLxvwo41b4gvzkXaRMTsDIRSfr0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-macondo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("698ab651-ac3d-4c0a-90a0-78cd8db38a5b",-499467656),
$APP.$cljs$cst$2675$family$$,"Macondo",$APP.$cljs$cst$725$name$$,"Macondo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/macondo/v27/RrQQboN9-iB1IXmOS2XO0LBBd4Y.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-macondo-swash-caps",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("267b0bcb-d299-4a5f-97b1-0b07624cdc23",709485946),$APP.$cljs$cst$2675$family$$,"Macondo Swash Caps",$APP.$cljs$cst$725$name$$,"Macondo Swash Caps",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/macondoswashcaps/v26/6NUL8EaAJgGKZA7lpt941Z9s6ZYgDq6Oekoa_mm5bA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mada",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8c91fde1-a329-4d3c-80ec-328747f7d297",-233632648),$APP.$cljs$cst$2675$family$$,"Mada",$APP.$cljs$cst$725$name$$,"Mada",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mada/v21/7Aulp_0qnzeSVz7u3PJLcUMYOFlOkHkw2-m9x2iC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",
$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mada/v21/7Aulp_0qnzeSVz7u3PJLcUMYOFmQkHkw2-m9x2iC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mada/v21/7Aulp_0qnzeSVz7u3PJLcUMYOFnOkHkw2-m9x2iC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mada/v21/7Aulp_0qnzeSVz7u3PJLcUMYOFn8kHkw2-m9x2iC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mada/v21/7Aulp_0qnzeSVz7u3PJLcUMYOFkQl3kw2-m9x2iC.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mada/v21/7Aulp_0qnzeSVz7u3PJLcUMYOFkpl3kw2-m9x2iC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mada/v21/7Aulp_0qnzeSVz7u3PJLcUMYOFlOl3kw2-m9x2iC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mada/v21/7Aulp_0qnzeSVz7u3PJLcUMYOFlnl3kw2-m9x2iC.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-madimi-one",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("ef54b078-ed5b-41de-992e-378546cd0010",180329028),$APP.$cljs$cst$2675$family$$,"Madimi One",$APP.$cljs$cst$725$name$$,"Madimi One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/madimione/v1/2V0YKIEADpA8U6RygDnZZFQoBoHMd2U.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-magra",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("89bd5b8f-f9b2-4f9d-b350-bc027fd10fb0",1859725244),$APP.$cljs$cst$2675$family$$,"Magra",$APP.$cljs$cst$725$name$$,"Magra",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/magra/v15/uK_94ruaZus72k5xIDMfO-ed.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/magra/v15/uK_w4ruaZus72nbNDxcXEPuUX1ow.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-maiden-orange",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("882279cd-6873-4d4c-b5f6-5036a16721ff",457923976),$APP.$cljs$cst$2675$family$$,"Maiden Orange",$APP.$cljs$cst$725$name$$,"Maiden Orange",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/maidenorange/v32/kJE1BuIX7AUmhi2V4m08kb1XjOZdCZS8FY8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-maitree",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a919d4dd-e655-42c5-a818-abc749ac10a7",2064840746),$APP.$cljs$cst$2675$family$$,"Maitree",$APP.$cljs$cst$725$name$$,"Maitree",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/maitree/v11/MjQDmil5tffhpBrklhGNWJGovLdh6OE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/maitree/v11/MjQDmil5tffhpBrklnWOWJGovLdh6OE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/maitree/v11/MjQGmil5tffhpBrkrtmmfJmDoL4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/maitree/v11/MjQDmil5tffhpBrkli2PWJGovLdh6OE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/maitree/v11/MjQDmil5tffhpBrklgGIWJGovLdh6OE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/maitree/v11/MjQDmil5tffhpBrklmWJWJGovLdh6OE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-major-mono-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cac7ffc5-485b-4b4a-b550-dfc6b6a392ea",193012924),$APP.$cljs$cst$2675$family$$,"Major Mono Display",
$APP.$cljs$cst$725$name$$,"Major Mono Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/majormonodisplay/v18/RWmVoLyb5fEqtsfBX9PDZIGr2tFubRhLCn2QIndPww.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mako",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a81eeea7-b25d-4abf-ab16-bf0c0366ad71",1530486038),$APP.$cljs$cst$2675$family$$,"Mako",$APP.$cljs$cst$725$name$$,"Mako",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mako/v19/H4coBX6Mmc_Z0ST09g478Lo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mali",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ee377bb6-a6d4-40e8-9193-b851554bbeb8",-304910925),$APP.$cljs$cst$2675$family$$,"Mali",$APP.$cljs$cst$725$name$$,"Mali",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mali/v13/N0bV2SRONuN4QOLlKlRaJdbWgdY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mali/v13/N0bX2SRONuN4SCj8wlVQIfTTkdbJYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mali/v13/N0bV2SRONuN4QIbmKlRaJdbWgdY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mali/v13/N0bX2SRONuN4SCj8plZQIfTTkdbJYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mali/v13/N0ba2SRONuN4eCrODlxxOd8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mali/v13/N0bU2SRONuN4SCjECn50Kd_PmA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mali/v13/N0bV2SRONuN4QN7nKlRaJdbWgdY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mali/v13/N0bX2SRONuN4SCj8_ldQIfTTkdbJYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mali/v13/N0bV2SRONuN4QPLgKlRaJdbWgdY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mali/v13/N0bX2SRONuN4SCj80lBQIfTTkdbJYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mali/v13/N0bV2SRONuN4QJbhKlRaJdbWgdY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mali/v13/N0bX2SRONuN4SCj8tlFQIfTTkdbJYA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-mallanna",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3ccea0f7-2173-4014-9b87-f4d5134222bc",-652790305),$APP.$cljs$cst$2675$family$$,"Mallanna",$APP.$cljs$cst$725$name$$,"Mallanna",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mallanna/v15/hv-Vlzx-KEQb84YaDGwzEzRwVvJ-.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-maname",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("649d894f-2afd-48a6-8c1d-a4eae4debf4f",-1319655256),$APP.$cljs$cst$2675$family$$,"Maname",$APP.$cljs$cst$725$name$$,"Maname",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/maname/v2/gNMFW3J8RpCx9my42FkGGI6q_Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mandali",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("39f8ecdf-ceab-49c5-820c-8bf9375efa8c",1418483825),$APP.$cljs$cst$2675$family$$,
"Mandali",$APP.$cljs$cst$725$name$$,"Mandali",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mandali/v16/LhWlMVbYOfASNfNUVFk1ZPdcKtA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-manjari",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("617772d0-d72a-44c1-90dc-0a11ac379a8a",-363921179),$APP.$cljs$cst$2675$family$$,"Manjari",$APP.$cljs$cst$725$name$$,"Manjari",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manjari/v14/k3kSo8UPMOBO2w1UdbroK2vFIaOV8A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manjari/v14/k3kQo8UPMOBO2w1UTd7iL0nAMaM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manjari/v14/k3kVo8UPMOBO2w1UdWLNC0HrLaqM6Q4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-manrope",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("859348e5-e8ed-4c78-b646-b779a26d8755",385430606),$APP.$cljs$cst$2675$family$$,"Manrope",$APP.$cljs$cst$725$name$$,"Manrope",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manrope/v20/xn7_YHE41ni1AdIRqAuZuw1Bx9mbZk59FO_F87jxeN7B.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manrope/v20/xn7_YHE41ni1AdIRqAuZuw1Bx9mbZk6jFO_F87jxeN7B.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manrope/v20/xn7_YHE41ni1AdIRqAuZuw1Bx9mbZk79FO_F87jxeN7B.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manrope/v20/xn7_YHE41ni1AdIRqAuZuw1Bx9mbZk7PFO_F87jxeN7B.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manrope/v20/xn7_YHE41ni1AdIRqAuZuw1Bx9mbZk4jE-_F87jxeN7B.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manrope/v20/xn7_YHE41ni1AdIRqAuZuw1Bx9mbZk4aE-_F87jxeN7B.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/manrope/v20/xn7_YHE41ni1AdIRqAuZuw1Bx9mbZk59E-_F87jxeN7B.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mansalva",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1ced9d29-8bea-45ba-92c7-13137b3e7242",-496617037),$APP.$cljs$cst$2675$family$$,"Mansalva",$APP.$cljs$cst$725$name$$,"Mansalva",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mansalva/v16/aWB4m0aacbtDfvq5NJllI47vdyBg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-manuale",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9bccf0d8-9c43-482c-8cb6-db7461fcebc1",1219318278),$APP.$cljs$cst$2675$family$$,"Manuale",$APP.$cljs$cst$725$name$$,
"Manuale",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manuale/v31/f0Xp0eas_8Z-TFZdHv3mMxFaSqASeeG6e7wD1TB_JHHY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manuale/v31/f0Xp0eas_8Z-TFZdHv3mMxFaSqASeeHke7wD1TB_JHHY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manuale/v31/f0Xp0eas_8Z-TFZdHv3mMxFaSqASeeHWe7wD1TB_JHHY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manuale/v31/f0Xp0eas_8Z-TFZdHv3mMxFaSqASeeE6fLwD1TB_JHHY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/manuale/v31/f0Xp0eas_8Z-TFZdHv3mMxFaSqASeeEDfLwD1TB_JHHY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manuale/v31/f0Xp0eas_8Z-TFZdHv3mMxFaSqASeeFkfLwD1TB_JHHY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,
"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manuale/v31/f0Xn0eas_8Z-TFZdNPTUzMkzITq8fvQsOApA3zRdIWHYr8M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manuale/v31/f0Xn0eas_8Z-TFZdNPTUzMkzITq8fvQsOFRA3zRdIWHYr8M.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manuale/v31/f0Xn0eas_8Z-TFZdNPTUzMkzITq8fvQsOGZA3zRdIWHYr8M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manuale/v31/f0Xn0eas_8Z-TFZdNPTUzMkzITq8fvQsOIpH3zRdIWHYr8M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manuale/v31/f0Xn0eas_8Z-TFZdNPTUzMkzITq8fvQsOLNH3zRdIWHYr8M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manuale/v31/f0Xn0eas_8Z-TFZdNPTUzMkzITq8fvQsONRH3zRdIWHYr8M.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-manufacturing-consent",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("978063b8-62a9-4cdd-b3f3-362b58e5bfd7",1393032377),$APP.$cljs$cst$2675$family$$,
"Manufacturing Consent",$APP.$cljs$cst$725$name$$,"Manufacturing Consent",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/manufacturingconsent/v1/N0bL2TVONuFkPkuHfiECSLCwuZS-D-IsakikR6QvbfFYLA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-marcellus",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7ea30b88-7f3b-49b7-8d0c-287610ed8735",-227532396),$APP.$cljs$cst$2675$family$$,"Marcellus",$APP.$cljs$cst$725$name$$,"Marcellus",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/marcellus/v14/wEO_EBrOk8hQLDvIAF8FUfAL3EsHiA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-marcellus-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fa74bbd6-6edc-461f-ace5-106733a2e4a6",294971523),$APP.$cljs$cst$2675$family$$,"Marcellus SC",$APP.$cljs$cst$725$name$$,"Marcellus SC",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/marcellussc/v14/ke8iOgUHP1dg-Rmi6RWjbLEPgdydGKikhA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-marck-script",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e086e519-6bb0-4c53-82f6-68413cec1ced",1285247553),$APP.$cljs$cst$2675$family$$,"Marck Script",$APP.$cljs$cst$725$name$$,"Marck Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/marckscript/v22/nwpTtK2oNgBA3Or78gapdwuCzyI-aMPF7Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-margarine",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f595386d-a6e6-40fb-9eb8-61e431e5dba7",1006991323),$APP.$cljs$cst$2675$family$$,"Margarine",$APP.$cljs$cst$725$name$$,"Margarine",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/margarine/v27/qkBXXvoE6trLT9Y7YLye5JRLkAXbMQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-marhey",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a1653866-a7e3-498b-94fb-41f9b0a4a5fa",-2075904133),$APP.$cljs$cst$2675$family$$,"Marhey",$APP.$cljs$cst$725$name$$,
"Marhey",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/marhey/v8/x3d8ck7Laq-T7wl7mqfVrEe9sDvtBZVwO2cXiGevOMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/marhey/v8/x3d8ck7Laq-T7wl7mqfVrEe9sDvtBctwO2cXiGevOMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/marhey/v8/x3d8ck7Laq-T7wl7mqfVrEe9sDvtBflwO2cXiGevOMw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/marhey/v8/x3d8ck7Laq-T7wl7mqfVrEe9sDvtBRV3O2cXiGevOMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/marhey/v8/x3d8ck7Laq-T7wl7mqfVrEe9sDvtBSx3O2cXiGevOMw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-markazi-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9e8e135b-1b27-44b6-8c59-64b37177caee",-107733292),$APP.$cljs$cst$2675$family$$,"Markazi Text",$APP.$cljs$cst$725$name$$,"Markazi Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/markazitext/v28/sykh-ydym6AtQaiEtX7yhqb_rV1k_81ZVYYZtfSQT4MlBekmJLo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/markazitext/v28/sykh-ydym6AtQaiEtX7yhqb_rV1k_81ZVYYZtcaQT4MlBekmJLo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/markazitext/v28/sykh-ydym6AtQaiEtX7yhqb_rV1k_81ZVYYZtSqXT4MlBekmJLo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/markazitext/v28/sykh-ydym6AtQaiEtX7yhqb_rV1k_81ZVYYZtROXT4MlBekmJLo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-marko-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ff8c1622-d712-4948-a0fe-1f017bca0336",-923885870),$APP.$cljs$cst$2675$family$$,"Marko One",$APP.$cljs$cst$725$name$$,
"Marko One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/markoone/v24/9Btq3DFG0cnVM5lw1haaKpUfrHPzUw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-marmelad",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d8468ce6-6a2b-4aa0-9083-379e9d2280cd",991277099),$APP.$cljs$cst$2675$family$$,"Marmelad",$APP.$cljs$cst$725$name$$,"Marmelad",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/marmelad/v19/Qw3eZQdSHj_jK2e-8tFLG-YMC0R8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-martel",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("01b38e91-d0ab-48a3-bb49-83b725def929",362401111),$APP.$cljs$cst$2675$family$$,"Martel",$APP.$cljs$cst$725$name$$,"Martel",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martel/v12/PN_yRfK9oXHga0XVqekahRbX9vnDzw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martel/v12/PN_yRfK9oXHga0XVzeoahRbX9vnDzw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martel/v12/PN_xRfK9oXHga0XtYcI-jT3L_w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/martel/v12/PN_yRfK9oXHga0XVuewahRbX9vnDzw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martel/v12/PN_yRfK9oXHga0XV3e0ahRbX9vnDzw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,
"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martel/v12/PN_yRfK9oXHga0XVwe4ahRbX9vnDzw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martel/v12/PN_yRfK9oXHga0XV5e8ahRbX9vnDzw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-martel-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d5b25ba2-edfd-4640-b7cf-55e34938d223",-892356099),$APP.$cljs$cst$2675$family$$,"Martel Sans",$APP.$cljs$cst$725$name$$,"Martel Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martelsans/v14/h0GxssGi7VdzDgKjM-4d8hAX5suHFUknqMxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martelsans/v14/h0GxssGi7VdzDgKjM-4d8hBz5cuHFUknqMxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martelsans/v14/h0GsssGi7VdzDgKjM-4d8ijfze-PPlUu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martelsans/v14/h0GxssGi7VdzDgKjM-4d8hAH48uHFUknqMxQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martelsans/v14/h0GxssGi7VdzDgKjM-4d8hBj4suHFUknqMxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/martelsans/v14/h0GxssGi7VdzDgKjM-4d8hB_4cuHFUknqMxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martelsans/v14/h0GxssGi7VdzDgKjM-4d8hBb4MuHFUknqMxQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-martian-mono",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("37e02fdf-ca4b-41d3-9851-f7bc76b05b7d",-534024082),$APP.$cljs$cst$2675$family$$,"Martian Mono",$APP.$cljs$cst$725$name$$,"Martian Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/martianmono/v6/2V08KIcADoYhV6w87xrTKjs4CYElh_VS9YA4TlTnQzaVMIE6j15dYY1qus6WD75kdpF2.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martianmono/v6/2V08KIcADoYhV6w87xrTKjs4CYElh_VS9YA4TlTnQzaVMIE6j15dYY3qu86WD75kdpF2.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martianmono/v6/2V08KIcADoYhV6w87xrTKjs4CYElh_VS9YA4TlTnQzaVMIE6j15dYY00u86WD75kdpF2.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martianmono/v6/2V08KIcADoYhV6w87xrTKjs4CYElh_VS9YA4TlTnQzaVMIE6j15dYY1qu86WD75kdpF2.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martianmono/v6/2V08KIcADoYhV6w87xrTKjs4CYElh_VS9YA4TlTnQzaVMIE6j15dYY1Yu86WD75kdpF2.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martianmono/v6/2V08KIcADoYhV6w87xrTKjs4CYElh_VS9YA4TlTnQzaVMIE6j15dYY20vM6WD75kdpF2.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martianmono/v6/2V08KIcADoYhV6w87xrTKjs4CYElh_VS9YA4TlTnQzaVMIE6j15dYY2NvM6WD75kdpF2.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/martianmono/v6/2V08KIcADoYhV6w87xrTKjs4CYElh_VS9YA4TlTnQzaVMIE6j15dYY3qvM6WD75kdpF2.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-marvel",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e57375c5-09ec-4dd6-98b5-b7ab6beaa7cb",1729893102),$APP.$cljs$cst$2675$family$$,
"Marvel",$APP.$cljs$cst$725$name$$,"Marvel",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/marvel/v17/nwpVtKeoNgBV0qaIkV7ED366zg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/marvel/v17/nwpXtKeoNgBV0qa4k1TALXuqzhA7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/marvel/v17/nwpWtKeoNgBV0qawLXHgB1WmxwkiYQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/marvel/v17/nwpQtKeoNgBV0qa4k2x8Al-i5QwyYdrc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-matangi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("48e109ed-24c6-4b7a-805d-00beb8580e81",-1625204332),
$APP.$cljs$cst$2675$family$$,"Matangi",$APP.$cljs$cst$725$name$$,"Matangi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/matangi/v5/kmKiZqE2FhDIeX2QvjZNI_5FGeJet7PICDYwI8Gcw6Oi.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/matangi/v5/kmKiZqE2FhDIeX2QvjZNI_5FGeJet7OWCDYwI8Gcw6Oi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/matangi/v5/kmKiZqE2FhDIeX2QvjZNI_5FGeJet7OkCDYwI8Gcw6Oi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/matangi/v5/kmKiZqE2FhDIeX2QvjZNI_5FGeJet7NIDzYwI8Gcw6Oi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/matangi/v5/kmKiZqE2FhDIeX2QvjZNI_5FGeJet7NxDzYwI8Gcw6Oi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/matangi/v5/kmKiZqE2FhDIeX2QvjZNI_5FGeJet7MWDzYwI8Gcw6Oi.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/matangi/v5/kmKiZqE2FhDIeX2QvjZNI_5FGeJet7M_DzYwI8Gcw6Oi.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mate",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b3aa791a-18a5-4c5f-91f9-5fe8eca53b97",-619985027),$APP.$cljs$cst$2675$family$$,
"Mate",$APP.$cljs$cst$725$name$$,"Mate",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mate/v19/m8JdjftRd7WZ2z28WoXSaLU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mate/v19/m8JTjftRd7WZ6z-2XqfXeLVdbw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mate-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e5473064-49b4-4edf-98ee-bbb9550d0a81",341452701),$APP.$cljs$cst$2675$family$$,"Mate SC",$APP.$cljs$cst$725$name$$,"Mate SC",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/matesc/v23/-nF8OGQ1-uoVr2wKyiXZ95OkJwA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-matemasie",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("b1e5014b-0e19-47c4-b950-07048f4bb986",-1165701731),$APP.$cljs$cst$2675$family$$,"Matemasie",$APP.$cljs$cst$725$name$$,"Matemasie",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/matemasie/v4/OD5BuMCN3ne3Gmr7dlL3rEq4DL6w2w.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-material-icons",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8070e507-ea1e-4617-8a63-1e5489bc27d2",-1314362134),$APP.$cljs$cst$2675$family$$,"Material Icons",$APP.$cljs$cst$725$name$$,"Material Icons",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialicons/v145/flUhRq6tzZclQEJ-Vdg-IuiaDsNZIhI8tIHh.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-material-icons-outlined",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e2748a36-7c3c-4dbf-a601-8c52c895af41",499015418),$APP.$cljs$cst$2675$family$$,"Material Icons Outlined",$APP.$cljs$cst$725$name$$,
"Material Icons Outlined",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialiconsoutlined/v110/gok-H7zzDkdnRel8-DQ6KAXJ69wP1tGnf4ZGhUcdl5GuI2Ze.otf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-material-icons-round",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3ca80da8-30af-46dc-ad5c-3f94cf5f93bf",-1998956456),$APP.$cljs$cst$2675$family$$,"Material Icons Round",$APP.$cljs$cst$725$name$$,"Material Icons Round",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialiconsround/v109/LDItaoyNOAY6Uewc665JcIzCKsKc_M9flwmMq_fTTvg-.otf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-material-icons-sharp",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("516e0871-3599-4bff-87fa-b419e3664610",1788626152),$APP.$cljs$cst$2675$family$$,"Material Icons Sharp",$APP.$cljs$cst$725$name$$,"Material Icons Sharp",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialiconssharp/v110/oPWQ_lt5nv4pWNJpghLP75WiFR4kLh3kvmvSImEyc0vd.otf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-material-icons-two-tone",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dd65ee3e-3872-484c-93ae-c7fe59ce3d62",2072365423),$APP.$cljs$cst$2675$family$$,"Material Icons Two Tone",$APP.$cljs$cst$725$name$$,"Material Icons Two Tone",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialiconstwotone/v113/hESh6WRmNCxEqUmNyh3JDeGxjVVyMg4tHGctNCu3NjDrH_77.otf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-material-symbols",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("db7418df-8c3a-4912-83e6-581c22eb5ad1",2000102460),$APP.$cljs$cst$2675$family$$,"Material Symbols",$APP.$cljs$cst$725$name$$,"Material Symbols",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbols/v27/d6kSkb-sS9m3-i1LgQNcsFOOuLQXvG559b5GLMxCWRtThFK5gn7xw7XblIl2peTfMb7ONaa2_wzcUHR1Ukiw2RYw2vadH3BFk0G4701x-cU0BaNVXEHuRbn3PT2vOA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbols/v27/d6kSkb-sS9m3-i1LgQNcsFOOuLQXvG559b5GLMxCWRtThFK5gn7xw7XblIl2peTfMb7ONaa2_wzcUHR1Ukiw2RYw2vadH3BFk0G4701x-cU0BaNV3EDuRbn3PT2vOA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbols/v27/d6kSkb-sS9m3-i1LgQNcsFOOuLQXvG559b5GLMxCWRtThFK5gn7xw7XblIl2peTfMb7ONaa2_wzcUHR1Ukiw2RYw2vadH3BFk0G4701x-cU0BaNVAkDuRbn3PT2vOA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbols/v27/d6kSkb-sS9m3-i1LgQNcsFOOuLQXvG559b5GLMxCWRtThFK5gn7xw7XblIl2peTfMb7ONaa2_wzcUHR1Ukiw2RYw2vadH3BFk0G4701x-cU0BaNVXEDuRbn3PT2vOA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbols/v27/d6kSkb-sS9m3-i1LgQNcsFOOuLQXvG559b5GLMxCWRtThFK5gn7xw7XblIl2peTfMb7ONaa2_wzcUHR1Ukiw2RYw2vadH3BFk0G4701x-cU0BaNVbkDuRbn3PT2vOA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbols/v27/d6kSkb-sS9m3-i1LgQNcsFOOuLQXvG559b5GLMxCWRtThFK5gn7xw7XblIl2peTfMb7ONaa2_wzcUHR1Ukiw2RYw2vadH3BFk0G4701x-cU0BaNVgkfuRbn3PT2vOA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbols/v27/d6kSkb-sS9m3-i1LgQNcsFOOuLQXvG559b5GLMxCWRtThFK5gn7xw7XblIl2peTfMb7ONaa2_wzcUHR1Ukiw2RYw2vadH3BFk0G4701x-cU0BaNVu0fuRbn3PT2vOA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-material-symbols-outlined",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("73bb7588-0576-4011-9d22-a3e17081ac03",-24317817),$APP.$cljs$cst$2675$family$$,"Material Symbols Outlined",$APP.$cljs$cst$725$name$$,"Material Symbols Outlined",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolsoutlined/v299/kJF1BvYX7BgnkSrUwT8OhrdQw4oELdPIeeII9v6oDMzByHX9rA6RzaxHMPdY43zj-jCxv3fzvRNU22ZXGJpEpjC_1v-p_4MrImHCIJIZrDCvHeembd5zrTgt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolsoutlined/v299/kJF1BvYX7BgnkSrUwT8OhrdQw4oELdPIeeII9v6oDMzByHX9rA6RzaxHMPdY43zj-jCxv3fzvRNU22ZXGJpEpjC_1v-p_4MrImHCIJIZrDAvHOembd5zrTgt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolsoutlined/v299/kJF1BvYX7BgnkSrUwT8OhrdQw4oELdPIeeII9v6oDMzByHX9rA6RzaxHMPdY43zj-jCxv3fzvRNU22ZXGJpEpjC_1v-p_4MrImHCIJIZrDDxHOembd5zrTgt.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolsoutlined/v299/kJF1BvYX7BgnkSrUwT8OhrdQw4oELdPIeeII9v6oDMzByHX9rA6RzaxHMPdY43zj-jCxv3fzvRNU22ZXGJpEpjC_1v-p_4MrImHCIJIZrDCvHOembd5zrTgt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolsoutlined/v299/kJF1BvYX7BgnkSrUwT8OhrdQw4oELdPIeeII9v6oDMzByHX9rA6RzaxHMPdY43zj-jCxv3fzvRNU22ZXGJpEpjC_1v-p_4MrImHCIJIZrDCdHOembd5zrTgt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/materialsymbolsoutlined/v299/kJF1BvYX7BgnkSrUwT8OhrdQw4oELdPIeeII9v6oDMzByHX9rA6RzaxHMPdY43zj-jCxv3fzvRNU22ZXGJpEpjC_1v-p_4MrImHCIJIZrDBxG-embd5zrTgt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolsoutlined/v299/kJF1BvYX7BgnkSrUwT8OhrdQw4oELdPIeeII9v6oDMzByHX9rA6RzaxHMPdY43zj-jCxv3fzvRNU22ZXGJpEpjC_1v-p_4MrImHCIJIZrDBIG-embd5zrTgt.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-material-symbols-rounded",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("966d77f9-266c-4010-8c4d-e8f7be3bf271",215624485),$APP.$cljs$cst$2675$family$$,"Material Symbols Rounded",$APP.$cljs$cst$725$name$$,"Material Symbols Rounded",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolsrounded/v301/syl0-zNym6YjUruM-QrEh7-nyTnjDwKNJ_190FjpZIvDmUSVOK7BDB_Qb9vUSzq3wzLK-P0J-V_Zs-QtQth3-jOcbTCVpeRL2w5rwZu2rIekXxKJKJBjAa8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolsrounded/v301/syl0-zNym6YjUruM-QrEh7-nyTnjDwKNJ_190FjpZIvDmUSVOK7BDB_Qb9vUSzq3wzLK-P0J-V_Zs-QtQth3-jOcbTCVpeRL2w5rwZu2rAelXxKJKJBjAa8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolsrounded/v301/syl0-zNym6YjUruM-QrEh7-nyTnjDwKNJ_190FjpZIvDmUSVOK7BDB_Qb9vUSzq3wzLK-P0J-V_Zs-QtQth3-jOcbTCVpeRL2w5rwZu2rNmlXxKJKJBjAa8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolsrounded/v301/syl0-zNym6YjUruM-QrEh7-nyTnjDwKNJ_190FjpZIvDmUSVOK7BDB_Qb9vUSzq3wzLK-P0J-V_Zs-QtQth3-jOcbTCVpeRL2w5rwZu2rIelXxKJKJBjAa8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolsrounded/v301/syl0-zNym6YjUruM-QrEh7-nyTnjDwKNJ_190FjpZIvDmUSVOK7BDB_Qb9vUSzq3wzLK-P0J-V_Zs-QtQth3-jOcbTCVpeRL2w5rwZu2rLWlXxKJKJBjAa8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolsrounded/v301/syl0-zNym6YjUruM-QrEh7-nyTnjDwKNJ_190FjpZIvDmUSVOK7BDB_Qb9vUSzq3wzLK-P0J-V_Zs-QtQth3-jOcbTCVpeRL2w5rwZu2rFmiXxKJKJBjAa8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolsrounded/v301/syl0-zNym6YjUruM-QrEh7-nyTnjDwKNJ_190FjpZIvDmUSVOK7BDB_Qb9vUSzq3wzLK-P0J-V_Zs-QtQth3-jOcbTCVpeRL2w5rwZu2rGCiXxKJKJBjAa8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-material-symbols-sharp",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0dbe43d5-2d2c-422e-8301-54e4e558bbe5",14771378),$APP.$cljs$cst$2675$family$$,"Material Symbols Sharp",$APP.$cljs$cst$725$name$$,"Material Symbols Sharp",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolssharp/v296/gNNBW2J8Roq16WD5tFNRaeLQk6-SHQ_R00k4c2_whPnoY9ruReaU4bHmz74m0ZkGH-VBYe1x0TV6x4yFH8F-H5OdzEL3sVTgJtfbYxOLozCOJ1H7-knk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolssharp/v296/gNNBW2J8Roq16WD5tFNRaeLQk6-SHQ_R00k4c2_whPnoY9ruReaU4bHmz74m0ZkGH-VBYe1x0TV6x4yFH8F-H5OdzEL3sVTgJtfbYxMLojCOJ1H7-knk.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolssharp/v296/gNNBW2J8Roq16WD5tFNRaeLQk6-SHQ_R00k4c2_whPnoY9ruReaU4bHmz74m0ZkGH-VBYe1x0TV6x4yFH8F-H5OdzEL3sVTgJtfbYxPVojCOJ1H7-knk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolssharp/v296/gNNBW2J8Roq16WD5tFNRaeLQk6-SHQ_R00k4c2_whPnoY9ruReaU4bHmz74m0ZkGH-VBYe1x0TV6x4yFH8F-H5OdzEL3sVTgJtfbYxOLojCOJ1H7-knk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolssharp/v296/gNNBW2J8Roq16WD5tFNRaeLQk6-SHQ_R00k4c2_whPnoY9ruReaU4bHmz74m0ZkGH-VBYe1x0TV6x4yFH8F-H5OdzEL3sVTgJtfbYxO5ojCOJ1H7-knk.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolssharp/v296/gNNBW2J8Roq16WD5tFNRaeLQk6-SHQ_R00k4c2_whPnoY9ruReaU4bHmz74m0ZkGH-VBYe1x0TV6x4yFH8F-H5OdzEL3sVTgJtfbYxNVpTCOJ1H7-knk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/materialsymbolssharp/v296/gNNBW2J8Roq16WD5tFNRaeLQk6-SHQ_R00k4c2_whPnoY9ruReaU4bHmz74m0ZkGH-VBYe1x0TV6x4yFH8F-H5OdzEL3sVTgJtfbYxNspTCOJ1H7-knk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-maven-pro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1c364251-61b8-48d0-8e43-9a403107f869",-82625814),$APP.$cljs$cst$2675$family$$,
"Maven Pro",$APP.$cljs$cst$725$name$$,"Maven Pro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mavenpro/v40/7Auup_AqnyWWAxW2Wk3swUz56MS91Eww8SX25nCpozp5GvU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mavenpro/v40/7Auup_AqnyWWAxW2Wk3swUz56MS91Eww8Rf25nCpozp5GvU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mavenpro/v40/7Auup_AqnyWWAxW2Wk3swUz56MS91Eww8fvx5nCpozp5GvU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mavenpro/v40/7Auup_AqnyWWAxW2Wk3swUz56MS91Eww8cLx5nCpozp5GvU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mavenpro/v40/7Auup_AqnyWWAxW2Wk3swUz56MS91Eww8aXx5nCpozp5GvU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mavenpro/v40/7Auup_AqnyWWAxW2Wk3swUz56MS91Eww8Yzx5nCpozp5GvU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mclaren",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d442ac2c-4a3a-4dd3-986d-9f5c1a495204",1561504548),$APP.$cljs$cst$2675$family$$,"McLaren",$APP.$cljs$cst$725$name$$,"McLaren",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mclaren/v19/2EbnL-ZuAXFqZFXISYYf8z2Yt_c.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mea-culpa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("52e16025-2a40-4cbf-8e4f-c6ca20bc0dfb",1778154590),$APP.$cljs$cst$2675$family$$,"Mea Culpa",$APP.$cljs$cst$725$name$$,"Mea Culpa",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/meaculpa/v8/AMOTz4GcuWbEIuza8jsZms0QW3mqyg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-meddon",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d66d4f5c-20e8-417a-a958-f20d576d0a05",1245188806),$APP.$cljs$cst$2675$family$$,"Meddon",$APP.$cljs$cst$725$name$$,
"Meddon",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/meddon/v27/kmK8ZqA2EgDNeHTZhBdB3y_Aow.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-medievalsharp",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b8c7dae8-30f4-4004-aac3-9bf4834a07eb",-1501590389),$APP.$cljs$cst$2675$family$$,"MedievalSharp",$APP.$cljs$cst$725$name$$,"MedievalSharp",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/medievalsharp/v28/EvOJzAlL3oU5AQl2mP5KdgptAq96MwvXLDk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-medula-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("81da3921-748e-46ea-8cee-19902aeaa603",1616884404),$APP.$cljs$cst$2675$family$$,"Medula One",$APP.$cljs$cst$725$name$$,"Medula One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/medulaone/v20/YA9Wr0qb5kjJM6l2V0yukiEqs7GtlvY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-meera-inimai",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4aa5c655-0675-4c98-9e01-992e2d1e4963",2052378088),
$APP.$cljs$cst$2675$family$$,"Meera Inimai",$APP.$cljs$cst$725$name$$,"Meera Inimai",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/meerainimai/v14/845fNMM5EIqOW5MPuvO3ILep_2jDVevnLQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-megrim",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e30be793-cbf0-492c-aaa3-790e699c78ba",581430561),$APP.$cljs$cst$2675$family$$,"Megrim",$APP.$cljs$cst$725$name$$,"Megrim",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/megrim/v18/46kulbz5WjvLqJZlbWXgd0RY1g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-meie-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a18020b8-1abd-4b59-b223-eb798593dc6f",-1414434107),$APP.$cljs$cst$2675$family$$,"Meie Script",$APP.$cljs$cst$725$name$$,"Meie Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/meiescript/v22/_LOImzDK7erRjhunIspaMjxn5IXg0WDz.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-menbere",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("30998ba5-91e8-4699-b156-fabda796c710",
538879805),$APP.$cljs$cst$2675$family$$,"Menbere",$APP.$cljs$cst$725$name$$,"Menbere",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/menbere/v1/lJwY-p0zhmBrWvcG80OiXWeXfSDWXdI_9qn1UnpeWOQ5.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/menbere/v1/lJwY-p0zhmBrWvcG80OiXWeXfSDWXdK_96n1UnpeWOQ5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/menbere/v1/lJwY-p0zhmBrWvcG80OiXWeXfSDWXdJh96n1UnpeWOQ5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/menbere/v1/lJwY-p0zhmBrWvcG80OiXWeXfSDWXdI_96n1UnpeWOQ5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/menbere/v1/lJwY-p0zhmBrWvcG80OiXWeXfSDWXdIN96n1UnpeWOQ5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/menbere/v1/lJwY-p0zhmBrWvcG80OiXWeXfSDWXdLh8Kn1UnpeWOQ5.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/menbere/v1/lJwY-p0zhmBrWvcG80OiXWeXfSDWXdLY8Kn1UnpeWOQ5.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-meow-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("58758161-cb46-44c5-bf05-b2b051c335e1",-1089618906),
$APP.$cljs$cst$2675$family$$,"Meow Script",$APP.$cljs$cst$725$name$$,"Meow Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/meowscript/v6/0FlQVPqanlaJrtr8AnJ0ESch0_0CfDf1.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-merienda",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9e67e276-e4c3-4b4e-8fe4-e85afa878b2c",-627576814),$APP.$cljs$cst$2675$family$$,"Merienda",$APP.$cljs$cst$725$name$$,"Merienda",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merienda/v22/gNMaW3x8Qoy5_mf8uUkJGHtiYXjmKFy5JHhoSU78QGBV0A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merienda/v22/gNMaW3x8Qoy5_mf8uUkJGHtiYXjmKFy5enhoSU78QGBV0A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merienda/v22/gNMaW3x8Qoy5_mf8uUkJGHtiYXjmKFy5SHhoSU78QGBV0A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/merienda/v22/gNMaW3x8Qoy5_mf8uUkJGHtiYXjmKFy5pH9oSU78QGBV0A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merienda/v22/gNMaW3x8Qoy5_mf8uUkJGHtiYXjmKFy5nX9oSU78QGBV0A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merienda/v22/gNMaW3x8Qoy5_mf8uUkJGHtiYXjmKFy5-n9oSU78QGBV0A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merienda/v22/gNMaW3x8Qoy5_mf8uUkJGHtiYXjmKFy5039oSU78QGBV0A.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-merriweather",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b0fa9f0a-5a83-4e19-9869-e8b266dc6711",-1942070388),$APP.$cljs$cst$2675$family$$,"Merriweather",$APP.$cljs$cst$725$name$$,"Merriweather",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweather/v33/u-4D0qyriQwlOrhSvowK_l5UcA6zuSYEqOzpPe3HOZJ5eX1WtLaQwmYiScCmDxhtNOKl8yDrgCcqE1f0KvXKYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweather/v33/u-4D0qyriQwlOrhSvowK_l5UcA6zuSYEqOzpPe3HOZJ5eX1WtLaQwmYiScCmDxhtNOKl8yDr3icqE1f0KvXKYQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweather/v33/u-4D0qyriQwlOrhSvowK_l5UcA6zuSYEqOzpPe3HOZJ5eX1WtLaQwmYiScCmDxhtNOKl8yDr7CcqE1f0KvXKYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweather/v33/u-4D0qyriQwlOrhSvowK_l5UcA6zuSYEqOzpPe3HOZJ5eX1WtLaQwmYiScCmDxhtNOKl8yDrACAqE1f0KvXKYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweather/v33/u-4D0qyriQwlOrhSvowK_l5UcA6zuSYEqOzpPe3HOZJ5eX1WtLaQwmYiScCmDxhtNOKl8yDrOSAqE1f0KvXKYQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweather/v33/u-4D0qyriQwlOrhSvowK_l5UcA6zuSYEqOzpPe3HOZJ5eX1WtLaQwmYiScCmDxhtNOKl8yDrXiAqE1f0KvXKYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweather/v33/u-4D0qyriQwlOrhSvowK_l5UcA6zuSYEqOzpPe3HOZJ5eX1WtLaQwmYiScCmDxhtNOKl8yDrdyAqE1f0KvXKYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweather/v33/u-4B0qyriQwlOrhSvowK_l5-eTxCVx0ZbwLvKH2Gk9hLmp0v5yA-xXPqCzLvPee1XYk_XSf-FmScUF3wCPDaYa_F.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweather/v33/u-4B0qyriQwlOrhSvowK_l5-eTxCVx0ZbwLvKH2Gk9hLmp0v5yA-xXPqCzLvPee1XYk_XSf-FmTCUF3wCPDaYa_F.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweather/v33/u-4B0qyriQwlOrhSvowK_l5-eTxCVx0ZbwLvKH2Gk9hLmp0v5yA-xXPqCzLvPee1XYk_XSf-FmTwUF3wCPDaYa_F.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweather/v33/u-4B0qyriQwlOrhSvowK_l5-eTxCVx0ZbwLvKH2Gk9hLmp0v5yA-xXPqCzLvPee1XYk_XSf-FmQcV13wCPDaYa_F.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweather/v33/u-4B0qyriQwlOrhSvowK_l5-eTxCVx0ZbwLvKH2Gk9hLmp0v5yA-xXPqCzLvPee1XYk_XSf-FmQlV13wCPDaYa_F.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,
"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweather/v33/u-4B0qyriQwlOrhSvowK_l5-eTxCVx0ZbwLvKH2Gk9hLmp0v5yA-xXPqCzLvPee1XYk_XSf-FmRCV13wCPDaYa_F.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweather/v33/u-4B0qyriQwlOrhSvowK_l5-eTxCVx0ZbwLvKH2Gk9hLmp0v5yA-xXPqCzLvPee1XYk_XSf-FmRrV13wCPDaYa_F.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-merriweather-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f2c0dc72-6884-4d84-879a-cbb77ddc121e",1439565858),$APP.$cljs$cst$2675$family$$,"Merriweather Sans",$APP.$cljs$cst$725$name$$,"Merriweather Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweathersans/v28/2-cO9IRs1JiJN1FRAMjTN5zd9vgsFF_5asQTb6hZ2JKZ_O4ljuEG7xFHnQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweathersans/v28/2-cO9IRs1JiJN1FRAMjTN5zd9vgsFF_5asQTb6hZ2JKZou4ljuEG7xFHnQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweathersans/v28/2-cO9IRs1JiJN1FRAMjTN5zd9vgsFF_5asQTb6hZ2JKZkO4ljuEG7xFHnQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweathersans/v28/2-cO9IRs1JiJN1FRAMjTN5zd9vgsFF_5asQTb6hZ2JKZfOkljuEG7xFHnQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweathersans/v28/2-cO9IRs1JiJN1FRAMjTN5zd9vgsFF_5asQTb6hZ2JKZRekljuEG7xFHnQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweathersans/v28/2-cO9IRs1JiJN1FRAMjTN5zd9vgsFF_5asQTb6hZ2JKZIukljuEG7xFHnQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/merriweathersans/v28/2-cM9IRs1JiJN1FRAMjTN5zd9vgsFHXwWDvLBsPDdpWMaq2TzesCzRRXnaur.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweathersans/v28/2-cM9IRs1JiJN1FRAMjTN5zd9vgsFHXwWDvLBsPDdpWMaq3NzesCzRRXnaur.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweathersans/v28/2-cM9IRs1JiJN1FRAMjTN5zd9vgsFHXwWDvLBsPDdpWMaq3_zesCzRRXnaur.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/merriweathersans/v28/2-cM9IRs1JiJN1FRAMjTN5zd9vgsFHXwWDvLBsPDdpWMaq0TyusCzRRXnaur.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweathersans/v28/2-cM9IRs1JiJN1FRAMjTN5zd9vgsFHXwWDvLBsPDdpWMaq0qyusCzRRXnaur.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/merriweathersans/v28/2-cM9IRs1JiJN1FRAMjTN5zd9vgsFHXwWDvLBsPDdpWMaq1NyusCzRRXnaur.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-metal",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("696b3e95-de52-4cb5-9081-bbc3aad6b282",938172639),$APP.$cljs$cst$2675$family$$,
"Metal",$APP.$cljs$cst$725$name$$,"Metal",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/metal/v32/lW-wwjUJIXTo7i3nnoQAUdN2.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-metal-mania",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a4a5c50f-97d3-4c3e-bd2f-76b0753f0167",-1129280832),$APP.$cljs$cst$2675$family$$,"Metal Mania",$APP.$cljs$cst$725$name$$,"Metal Mania",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/metalmania/v23/RWmMoKWb4e8kqMfBUdPFJeXCg6UKDXlq.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-metamorphous",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4ab560ad-c257-4732-845e-64c52048cc70",-672038277),$APP.$cljs$cst$2675$family$$,"Metamorphous",$APP.$cljs$cst$725$name$$,"Metamorphous",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/metamorphous/v22/Wnz8HA03aAXcC39ZEX5y1330PCCthTsmaQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-metrophobic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("47c46ecd-b2bd-4b0d-8a6c-064ee2d792b1",
465895194),$APP.$cljs$cst$2675$family$$,"Metrophobic",$APP.$cljs$cst$725$name$$,"Metrophobic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/metrophobic/v24/sJoA3LZUhMSAPV_u0qwiAT-J737FPEEL.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-michroma",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("67b65aa7-4c39-4728-86e8-c5d5a846bd23",-609871893),$APP.$cljs$cst$2675$family$$,"Michroma",$APP.$cljs$cst$725$name$$,"Michroma",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/michroma/v21/PN_zRfy9qWD8fEagAMg6rzjb_-Da.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-micro-5",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c9a636f6-6d79-41fe-ba5f-cbc2f616b1ec",858004133),$APP.$cljs$cst$2675$family$$,"Micro 5",$APP.$cljs$cst$725$name$$,"Micro 5",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/micro5/v2/H4cnBX2MkcfEngTr0gYQ7LO5mqc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-micro-5-charted",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("99e4cbff-71fb-4b53-a9c5-94ebf1d18878",
1924988805),$APP.$cljs$cst$2675$family$$,"Micro 5 Charted",$APP.$cljs$cst$725$name$$,"Micro 5 Charted",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/micro5charted/v2/hESp6XxmPDtTtADZhn7oD_yrmxEGRUsJQAlbUA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-milonga",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5d1aa3ec-8ba0-4cb3-ab39-bfcc02806b31",-1264005423),$APP.$cljs$cst$2675$family$$,"Milonga",$APP.$cljs$cst$725$name$$,"Milonga",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/milonga/v24/SZc53FHnIaK9W5kffz3GkUrS8DI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-miltonian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("53ad0ef3-2a03-407b-89fc-0489fc45ef5f",-1765933339),$APP.$cljs$cst$2675$family$$,"Miltonian",$APP.$cljs$cst$725$name$$,"Miltonian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/miltonian/v32/zOL-4pbPn6Ne9JqTg9mr6e5As-FeiQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-miltonian-tattoo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f80f576b-a1b1-4842-b2f3-8d4fbff27da8",
951014064),$APP.$cljs$cst$2675$family$$,"Miltonian Tattoo",$APP.$cljs$cst$725$name$$,"Miltonian Tattoo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/miltoniantattoo/v34/EvOUzBRL0o0kCxF-lcMCQxlpVsA_FwP8MDBku-s.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mina",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d2115b8b-3526-440e-aac8-274e0892b62e",-116414479),$APP.$cljs$cst$2675$family$$,"Mina",$APP.$cljs$cst$725$name$$,"Mina",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mina/v14/-nFzOGc18vARrz9j7i3y65o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mina/v14/-nF8OGc18vARl4NMyiXZ95OkJwA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-mingzat",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("49abab22-18ab-488e-ae5c-01da86e1cd1b",-994874396),$APP.$cljs$cst$2675$family$$,"Mingzat",$APP.$cljs$cst$725$name$$,"Mingzat",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mingzat/v11/0QIgMX5C-o-oWWyvBttkm_mv670.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-miniver",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e5c55795-b92e-44f7-b093-db7b19053774",-1106509513),$APP.$cljs$cst$2675$family$$,"Miniver",$APP.$cljs$cst$725$name$$,"Miniver",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/miniver/v27/eLGcP-PxIg-5H0vC770Cy8r8fWA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-miriam-libre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("13aee533-1903-456a-823a-f370b22b834d",1652763691),$APP.$cljs$cst$2675$family$$,
"Miriam Libre",$APP.$cljs$cst$725$name$$,"Miriam Libre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/miriamlibre/v19/DdT0798HsHwubBAqfkcBTL_1a7sPlXcE8PJjH9P3k9vGL-8tY7Q.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/miriamlibre/v19/DdT0798HsHwubBAqfkcBTL_1a7sPlXcE8PJjH-H3k9vGL-8tY7Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/miriamlibre/v19/DdT0798HsHwubBAqfkcBTL_1a7sPlXcE8PJjHw3wk9vGL-8tY7Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/miriamlibre/v19/DdT0798HsHwubBAqfkcBTL_1a7sPlXcE8PJjHzTwk9vGL-8tY7Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-mirza",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("59fe158d-13d7-4495-9208-9e1988208c95",1205886950),$APP.$cljs$cst$2675$family$$,"Mirza",$APP.$cljs$cst$725$name$$,"Mirza",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mirza/v19/co3ImWlikiN5EurdKMewsrvI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mirza/v19/co3FmWlikiN5EtIpAeO4mafBomDi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mirza/v19/co3FmWlikiN5EtIFBuO4mafBomDi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mirza/v19/co3FmWlikiN5EtJhB-O4mafBomDi.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-miss-fajardose",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ebacac11-5355-4e74-a8f7-30636aa1ede5",1756608727),$APP.$cljs$cst$2675$family$$,"Miss Fajardose",$APP.$cljs$cst$725$name$$,"Miss Fajardose",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/missfajardose/v23/E21-_dn5gvrawDdPFVl-N0Ajb8qvWPaJq4no.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mitr",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2095fa38-5e10-41df-a00c-5294aa613ed8",-1041502301),$APP.$cljs$cst$2675$family$$,"Mitr",$APP.$cljs$cst$725$name$$,"Mitr",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mitr/v13/pxiEypw5ucZF8fMZFJDUc1NECPY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mitr/v13/pxiEypw5ucZF8ZcaFJDUc1NECPY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mitr/v13/pxiLypw5ucZFyTsyMJj_b1o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mitr/v13/pxiEypw5ucZF8c8bFJDUc1NECPY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mitr/v13/pxiEypw5ucZF8eMcFJDUc1NECPY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mitr/v13/pxiEypw5ucZF8YcdFJDUc1NECPY.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mochiy-pop-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6abd2e31-e771-4041-a664-2bdbaf43eaff",2015017170),$APP.$cljs$cst$2675$family$$,"Mochiy Pop One",$APP.$cljs$cst$725$name$$,"Mochiy Pop One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mochiypopone/v12/QdVPSTA9Jh-gg-5XZP2UmU4O9kwwD3s6ZKAi.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mochiy-pop-p-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("996c8f0a-82ae-4432-b67e-8cf801a7084f",481298889),$APP.$cljs$cst$2675$family$$,"Mochiy Pop P One",$APP.$cljs$cst$725$name$$,
"Mochiy Pop P One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mochiypoppone/v12/Ktk2AKuPeY_td1-h9LayHYWCjAqyN4O3WYZB_sU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-modak",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c1e71bc4-4eff-494f-91fb-3ba52093cb0d",-334989872),$APP.$cljs$cst$2675$family$$,"Modak",$APP.$cljs$cst$725$name$$,"Modak",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/modak/v21/EJRYQgs1XtIEsnMH8BVZ76KU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-modern-antiqua",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bafdd5be-8c14-494a-b7ca-a2c8a5575480",-1166031337),$APP.$cljs$cst$2675$family$$,"Modern Antiqua",$APP.$cljs$cst$725$name$$,"Modern Antiqua",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/modernantiqua/v26/NGStv5TIAUg6Iq_RLNo_2dp1sI1Ea2u0c3Gi.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-moderustic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("25554db1-14cb-40c5-a39f-cdf258e59c0e",822236458),
$APP.$cljs$cst$2675$family$$,"Moderustic",$APP.$cljs$cst$725$name$$,"Moderustic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/moderustic/v3/2-c39J9s3o6eLFNHFdXYaOX1UUnf3GLnYjBVsTNe55aRa7UE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/moderustic/v3/2-c39J9s3o6eLFNHFdXYaOX1UUnf3GLnYjALsTNe55aRa7UE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/moderustic/v3/2-c39J9s3o6eLFNHFdXYaOX1UUnf3GLnYjA5sTNe55aRa7UE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/moderustic/v3/2-c39J9s3o6eLFNHFdXYaOX1UUnf3GLnYjDVtjNe55aRa7UE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/moderustic/v3/2-c39J9s3o6eLFNHFdXYaOX1UUnf3GLnYjDstjNe55aRa7UE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/moderustic/v3/2-c39J9s3o6eLFNHFdXYaOX1UUnf3GLnYjCLtjNe55aRa7UE.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mogra",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4fab0832-5059-4519-9794-b6b5ff233ebe",273315804),$APP.$cljs$cst$2675$family$$,"Mogra",$APP.$cljs$cst$725$name$$,"Mogra",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mogra/v22/f0X40eSs8c95TBo4DvLmxtnG.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mohave",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ffb07ba2-b3ff-4dd4-81e9-66aeb262a9f6",717134087),$APP.$cljs$cst$2675$family$$,"Mohave",$APP.$cljs$cst$725$name$$,"Mohave",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mohave/v13/7cH0v4ksjJunKqMVAOPIMOeSmiojdif_HvCQopLSvBk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mohave/v13/7cH0v4ksjJunKqMVAOPIMOeSmiojdnn_HvCQopLSvBk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mohave/v13/7cH0v4ksjJunKqMVAOPIMOeSmiojdkv_HvCQopLSvBk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mohave/v13/7cH0v4ksjJunKqMVAOPIMOeSmiojdqf4HvCQopLSvBk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mohave/v13/7cH0v4ksjJunKqMVAOPIMOeSmiojdp74HvCQopLSvBk.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mohave/v13/7cH2v4ksjJunKqM_CdE36I75AIQkY7G8qLOaprDXrBlSVw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mohave/v13/7cH2v4ksjJunKqM_CdE36I75AIQkY7G89rOaprDXrBlSVw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mohave/v13/7cH2v4ksjJunKqM_CdE36I75AIQkY7G8xLOaprDXrBlSVw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mohave/v13/7cH2v4ksjJunKqM_CdE36I75AIQkY7G8KLSaprDXrBlSVw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mohave/v13/7cH2v4ksjJunKqM_CdE36I75AIQkY7G8EbSaprDXrBlSVw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-moirai-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("100d5847-a4fc-4279-997b-5e69a428cdd5",1125279663),$APP.$cljs$cst$2675$family$$,"Moirai One",$APP.$cljs$cst$725$name$$,"Moirai One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/moiraione/v1/2sDbZGFUgJLJmby6xgNGT0WWB7UcfCg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-molengo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cb6eb37b-052b-41c8-99f3-16a155f84728",1867467505),$APP.$cljs$cst$2675$family$$,"Molengo",$APP.$cljs$cst$725$name$$,"Molengo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/molengo/v17/I_uuMpWeuBzZNBtQbbRQkiCvs5Y.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-molle",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("715c234a-d3c3-433d-b164-ee195fe9607b",
-910075012),$APP.$cljs$cst$2675$family$$,"Molle",$APP.$cljs$cst$725$name$$,"Molle",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/molle/v25/E21n_dL5hOXFhWEsXzgmVydREus.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-momo-signature",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0f2d5c92-072e-43c6-a082-9a8e84f9ae5c",-609232868),$APP.$cljs$cst$2675$family$$,"Momo Signature",$APP.$cljs$cst$725$name$$,"Momo Signature",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/momosignature/v2/RrQJbop99C51b06IDAuFoM0yCqcoMcmJPECN.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-momo-trust-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5de3c433-846b-4bf3-a0ae-2bda86635ddd",1606926187),$APP.$cljs$cst$2675$family$$,"Momo Trust Display",$APP.$cljs$cst$725$name$$,
"Momo Trust Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/momotrustdisplay/v2/WWXPlieNYgyPZLyBUuEkKZFhFHyjqb1un2xNNgNa1A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-momo-trust-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ab89ea0b-8111-4721-bbee-4ee3a4ce3f7c",-874799974),$APP.$cljs$cst$2675$family$$,"Momo Trust Sans",$APP.$cljs$cst$725$name$$,"Momo Trust Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/momotrustsans/v4/BXR8vFfHh_fFyXlQWZgO0TyUN7Pt3pVCeYWqJnZSWzRpbToVehmEa4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/momotrustsans/v4/BXR8vFfHh_fFyXlQWZgO0TyUN7Pt3pVCeYWqJnZSW-ppbToVehmEa4Q.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/momotrustsans/v4/BXR8vFfHh_fFyXlQWZgO0TyUN7Pt3pVCeYWqJnZSW7RpbToVehmEa4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/momotrustsans/v4/BXR8vFfHh_fFyXlQWZgO0TyUN7Pt3pVCeYWqJnZSW4ZpbToVehmEa4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/momotrustsans/v4/BXR8vFfHh_fFyXlQWZgO0TyUN7Pt3pVCeYWqJnZSW2pubToVehmEa4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/momotrustsans/v4/BXR8vFfHh_fFyXlQWZgO0TyUN7Pt3pVCeYWqJnZSW1NubToVehmEa4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/momotrustsans/v4/BXR8vFfHh_fFyXlQWZgO0TyUN7Pt3pVCeYWqJnZSWzRubToVehmEa4Q.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mona-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dcdaff1d-0c54-4836-a9b5-c26d7fb80590",463865850),$APP.$cljs$cst$2675$family$$,"Mona Sans",$APP.$cljs$cst$725$name$$,"Mona Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monasans/v4/o-0mIpQmx24alC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyB9A99d41P6zHtY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monasans/v4/o-0mIpQmx24alC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyCjA99d41P6zHtY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monasans/v4/o-0mIpQmx24alC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyD9A99d41P6zHtY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monasans/v4/o-0mIpQmx24alC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyDPA99d41P6zHtY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monasans/v4/o-0mIpQmx24alC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyAjBN9d41P6zHtY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monasans/v4/o-0mIpQmx24alC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyAaBN9d41P6zHtY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monasans/v4/o-0mIpQmx24alC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyB9BN9d41P6zHtY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monasans/v4/o-0mIpQmx24alC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyBUBN9d41P6zHtY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monasans/v4/o-0kIpQmx24alC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QLce6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monasans/v4/o-0kIpQmx24alC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QGke6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monasans/v4/o-0kIpQmx24alC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QDce6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/monasans/v4/o-0kIpQmx24alC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QAUe6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monasans/v4/o-0kIpQmx24alC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QOkZ6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monasans/v4/o-0kIpQmx24alC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QNAZ6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/monasans/v4/o-0kIpQmx24alC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QLcZ6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monasans/v4/o-0kIpQmx24alC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QJ4Z6VfYyWtY1rI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-monda",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dff63565-5472-4f2a-8c93-085bd0bf8d92",21223160),$APP.$cljs$cst$2675$family$$,"Monda",$APP.$cljs$cst$725$name$$,"Monda",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monda/v19/TK3-WkYFABsmjuBtFuvTIFRAPpWsH3oMoWtGaA-Ijw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monda/v19/TK3-WkYFABsmjuBtFuvTIFRAPpWsLXoMoWtGaA-Ijw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monda/v19/TK3-WkYFABsmjuBtFuvTIFRAPpWswX0MoWtGaA-Ijw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monda/v19/TK3-WkYFABsmjuBtFuvTIFRAPpWs-H0MoWtGaA-Ijw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-monofett",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("02154f37-1403-4aa5-bfcd-478f5c4e7eab",294563924),$APP.$cljs$cst$2675$family$$,"Monofett",$APP.$cljs$cst$725$name$$,"Monofett",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monofett/v24/mFTyWbofw6zc9NtnW43SuRwr0VJ7.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-monomakh",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1e651d32-98ff-445a-bf9e-a52d23cb248c",-1292845344),$APP.$cljs$cst$2675$family$$,"Monomakh",$APP.$cljs$cst$725$name$$,"Monomakh",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monomakh/v1/Wnz4HAk3Yh_SC3FACTYdiArcPRKo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-monomaniac-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c71a1188-c6b2-4539-aea0-750cdbd91ebe",
410936363),$APP.$cljs$cst$2675$family$$,"Monomaniac One",$APP.$cljs$cst$725$name$$,"Monomaniac One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monomaniacone/v15/4iC06K17YctZjx50EU-QlwPmcqRnqYkB5kwI.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-monoton",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5c29dbb7-3e43-44c3-924b-e8f0fd5f092e",320098299),$APP.$cljs$cst$2675$family$$,"Monoton",$APP.$cljs$cst$725$name$$,"Monoton",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monoton/v22/5h1aiZUrOngCibe4fkbBQ2S7FU8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-monsieur-la-doulaise",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a4f68561-3cda-4316-988a-119623516885",-1667880885),$APP.$cljs$cst$2675$family$$,"Monsieur La Doulaise",$APP.$cljs$cst$725$name$$,"Monsieur La Doulaise",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/monsieurladoulaise/v20/_Xmz-GY4rjmCbQfc-aPRaa4pqV340p7EZl5ewkEU4HTy.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-montaga",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b4e23798-5aa2-49f8-bbd6-69f31db03c99",-1664152596),$APP.$cljs$cst$2675$family$$,"Montaga",$APP.$cljs$cst$725$name$$,"Montaga",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/montaga/v14/H4cnBX2Ml8rCkEO_0gYQ7LO5mqc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-montagu-slab",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("160b1376-06cc-4577-80f9-2fe147c61da4",-1072595263),$APP.$cljs$cst$2675$family$$,"Montagu Slab",$APP.$cljs$cst$725$name$$,"Montagu Slab",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montaguslab/v17/6qLhKZIQtB_zv0xUaXRDWkY_HXsphdLRZF40vm_jzR2jhk_n3T6ACkDbE3P9Fs7bOSO7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montaguslab/v17/6qLhKZIQtB_zv0xUaXRDWkY_HXsphdLRZF40vm_jzR2jhk_n3T6ACkBbEnP9Fs7bOSO7.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montaguslab/v17/6qLhKZIQtB_zv0xUaXRDWkY_HXsphdLRZF40vm_jzR2jhk_n3T6ACkCFEnP9Fs7bOSO7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montaguslab/v17/6qLhKZIQtB_zv0xUaXRDWkY_HXsphdLRZF40vm_jzR2jhk_n3T6ACkDbEnP9Fs7bOSO7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montaguslab/v17/6qLhKZIQtB_zv0xUaXRDWkY_HXsphdLRZF40vm_jzR2jhk_n3T6ACkDpEnP9Fs7bOSO7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montaguslab/v17/6qLhKZIQtB_zv0xUaXRDWkY_HXsphdLRZF40vm_jzR2jhk_n3T6ACkAFFXP9Fs7bOSO7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montaguslab/v17/6qLhKZIQtB_zv0xUaXRDWkY_HXsphdLRZF40vm_jzR2jhk_n3T6ACkA8FXP9Fs7bOSO7.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-montecarlo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("33aa20a8-2462-42ad-ae07-92397358d136",1921271572),$APP.$cljs$cst$2675$family$$,"MonteCarlo",$APP.$cljs$cst$725$name$$,"MonteCarlo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montecarlo/v13/buEzpo6-f9X01GadLA0G0CoV_NxLeiw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-montez",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("29b49c26-2a6e-44f5-8654-850a40b39bbb",1673889632),$APP.$cljs$cst$2675$family$$,"Montez",$APP.$cljs$cst$725$name$$,"Montez",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montez/v25/845ZNMk5GoGIX8lm1LDeSd-R_g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-montserrat",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ae255288-01ff-47ae-938c-163f0ed847fa",
-2024455325),$APP.$cljs$cst$2675$family$$,"Montserrat",$APP.$cljs$cst$725$name$$,"Montserrat",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUHjIg1_i6t8kCHKm4532VJOt5-QNFgpCtr6Uw-Y3tcoqK5.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUHjIg1_i6t8kCHKm4532VJOt5-QNFgpCvr6Ew-Y3tcoqK5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUHjIg1_i6t8kCHKm4532VJOt5-QNFgpCs16Ew-Y3tcoqK5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUHjIg1_i6t8kCHKm4532VJOt5-QNFgpCtr6Ew-Y3tcoqK5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUHjIg1_i6t8kCHKm4532VJOt5-QNFgpCtZ6Ew-Y3tcoqK5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUHjIg1_i6t8kCHKm4532VJOt5-QNFgpCu170w-Y3tcoqK5.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUHjIg1_i6t8kCHKm4532VJOt5-QNFgpCuM70w-Y3tcoqK5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUHjIg1_i6t8kCHKm4532VJOt5-QNFgpCvr70w-Y3tcoqK5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUHjIg1_i6t8kCHKm4532VJOt5-QNFgpCvC70w-Y3tcoqK5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUFjIg1_i6t8kCHKm459Wx7xQYXK0vOoz6jq6R8aX9-p7K5ILg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUFjIg1_i6t8kCHKm459Wx7xQYXK0vOoz6jqyR9aX9-p7K5ILg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUFjIg1_i6t8kCHKm459Wx7xQYXK0vOoz6jq_p9aX9-p7K5ILg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUFjIg1_i6t8kCHKm459Wx7xQYXK0vOoz6jq6R9aX9-p7K5ILg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUFjIg1_i6t8kCHKm459Wx7xQYXK0vOoz6jq5Z9aX9-p7K5ILg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUFjIg1_i6t8kCHKm459Wx7xQYXK0vOoz6jq3p6aX9-p7K5ILg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/montserrat/v31/JTUFjIg1_i6t8kCHKm459Wx7xQYXK0vOoz6jq0N6aX9-p7K5ILg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUFjIg1_i6t8kCHKm459Wx7xQYXK0vOoz6jqyR6aX9-p7K5ILg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserrat/v31/JTUFjIg1_i6t8kCHKm459Wx7xQYXK0vOoz6jqw16aX9-p7K5ILg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-montserrat-alternates",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4a2b8b52-ab0c-4f86-a681-2725f2b5ef19",-1394219240),$APP.$cljs$cst$2675$family$$,"Montserrat Alternates",
$APP.$cljs$cst$725$name$$,"Montserrat Alternates",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFThWacfw6zH4dthXcyms1lPpC8I_b0juU0xiKfVKphL03l4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFTjWacfw6zH4dthXcyms1lPpC8I_b0juU057p-xIJxp1ml4imo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/montserratalternates/v18/mFTiWacfw6zH4dthXcyms1lPpC8I_b0juU0xJIb1ALZH2mBhkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFTkWacfw6zH4dthXcyms1lPpC8I_b0juU057p8dAbxD-GVxk3Nd.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFTiWacfw6zH4dthXcyms1lPpC8I_b0juU0xQIX1ALZH2mBhkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFTkWacfw6zH4dthXcyms1lPpC8I_b0juU057p95ArxD-GVxk3Nd.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFTvWacfw6zH4dthXcyms1lPpC8I_b0juU0J7K3RCJ1b0w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFThWacfw6zH4dthXcyms1lPpC8I_b0juU057qfVKphL03l4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFTiWacfw6zH4dthXcyms1lPpC8I_b0juU0xGIT1ALZH2mBhkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFTkWacfw6zH4dthXcyms1lPpC8I_b0juU057p8hA7xD-GVxk3Nd.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/montserratalternates/v18/mFTiWacfw6zH4dthXcyms1lPpC8I_b0juU0xNIP1ALZH2mBhkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFTkWacfw6zH4dthXcyms1lPpC8I_b0juU057p8NBLxD-GVxk3Nd.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFTiWacfw6zH4dthXcyms1lPpC8I_b0juU0xUIL1ALZH2mBhkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFTkWacfw6zH4dthXcyms1lPpC8I_b0juU057p9pBbxD-GVxk3Nd.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFTiWacfw6zH4dthXcyms1lPpC8I_b0juU0xTIH1ALZH2mBhkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFTkWacfw6zH4dthXcyms1lPpC8I_b0juU057p91BrxD-GVxk3Nd.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFTiWacfw6zH4dthXcyms1lPpC8I_b0juU0xaID1ALZH2mBhkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratalternates/v18/mFTkWacfw6zH4dthXcyms1lPpC8I_b0juU057p9RB7xD-GVxk3Nd.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-montserrat-underline",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("efa2f1e1-dbd2-4ce1-99d7-cc4fbd406e08",-895100136),
$APP.$cljs$cst$2675$family$$,"Montserrat Underline",$APP.$cljs$cst$725$name$$,"Montserrat Underline",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTbWaYfw6zH4dthXcyms01NtC8I_7U5uQQi5HMFnSdEx2F5Wil8ubbffHtmMw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTbWaYfw6zH4dthXcyms01NtC8I_7U5uQQi5HMFnSdEx2F52ih8ubbffHtmMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTbWaYfw6zH4dthXcyms01NtC8I_7U5uQQi5HMFnSdEx2F5BCh8ubbffHtmMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTbWaYfw6zH4dthXcyms01NtC8I_7U5uQQi5HMFnSdEx2F5Wih8ubbffHtmMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTbWaYfw6zH4dthXcyms01NtC8I_7U5uQQi5HMFnSdEx2F5aCh8ubbffHtmMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTbWaYfw6zH4dthXcyms01NtC8I_7U5uQQi5HMFnSdEx2F5hC98ubbffHtmMw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTbWaYfw6zH4dthXcyms01NtC8I_7U5uQQi5HMFnSdEx2F5vS98ubbffHtmMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTbWaYfw6zH4dthXcyms01NtC8I_7U5uQQi5HMFnSdEx2F52i98ubbffHtmMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTbWaYfw6zH4dthXcyms01NtC8I_7U5uQQi5HMFnSdEx2F58y98ubbffHtmMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTdWaYfw6zH4dthXcyms01NtC8I_7U5uS4r1ozd9EzeaWZskmuU-7zbXn52M1Mi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/montserratunderline/v3/mFTdWaYfw6zH4dthXcyms01NtC8I_7U5uS4r1ozd9EzeaWZskmsU-rzbXn52M1Mi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTdWaYfw6zH4dthXcyms01NtC8I_7U5uS4r1ozd9EzeaWZskmvK-rzbXn52M1Mi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTdWaYfw6zH4dthXcyms01NtC8I_7U5uS4r1ozd9EzeaWZskmuU-rzbXn52M1Mi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/montserratunderline/v3/mFTdWaYfw6zH4dthXcyms01NtC8I_7U5uS4r1ozd9EzeaWZskmum-rzbXn52M1Mi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTdWaYfw6zH4dthXcyms01NtC8I_7U5uS4r1ozd9EzeaWZskmtK_bzbXn52M1Mi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTdWaYfw6zH4dthXcyms01NtC8I_7U5uS4r1ozd9EzeaWZskmtz_bzbXn52M1Mi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/montserratunderline/v3/mFTdWaYfw6zH4dthXcyms01NtC8I_7U5uS4r1ozd9EzeaWZskmsU_bzbXn52M1Mi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/montserratunderline/v3/mFTdWaYfw6zH4dthXcyms01NtC8I_7U5uS4r1ozd9EzeaWZskms9_bzbXn52M1Mi.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-moo-lah-lah",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c2c03403-e502-49a3-a6e0-703b7d7af04c",1368010496),$APP.$cljs$cst$2675$family$$,"Moo Lah Lah",$APP.$cljs$cst$725$name$$,"Moo Lah Lah",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/moolahlah/v8/dg4h_p_opKZOA0w1AYcm55wtYQYugjW4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mooli",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d06f893f-bcca-4274-af9c-bc534e0cef9f",995149756),$APP.$cljs$cst$2675$family$$,"Mooli",$APP.$cljs$cst$725$name$$,"Mooli",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mooli/v1/-F6_fjJpLyk1bYPBBG7YpzlJ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-moon-dance",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("27647135-74c4-4357-91f1-3b58a87d9a49",108965703),$APP.$cljs$cst$2675$family$$,
"Moon Dance",$APP.$cljs$cst$725$name$$,"Moon Dance",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/moondance/v8/WBLgrEbUbFlYW9ekmGawe2XiKMiokE4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-moul",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ab5e7af5-7287-40ec-8405-54cb463775cf",1007760763),$APP.$cljs$cst$2675$family$$,"Moul",$APP.$cljs$cst$725$name$$,"Moul",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/moul/v30/nuF2D__FSo_3E-RYiJCy-00.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-moulpali",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0fedf648-a11c-4798-9e69-576bf3f425e0",940849382),$APP.$cljs$cst$2675$family$$,"Moulpali",$APP.$cljs$cst$725$name$$,"Moulpali",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/moulpali/v33/H4ckBXKMl9HagUWymyY6wr-wg763.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mountains-of-christmas",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("71ae1306-3caa-4363-96f2-bcf0c6bd24b8",1239214752),
$APP.$cljs$cst$2675$family$$,"Mountains of Christmas",$APP.$cljs$cst$725$name$$,"Mountains of Christmas",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mountainsofchristmas/v24/3y9w6a4zcCnn5X0FDyrKi2ZRUBIy8uxoUo7ePNamMPNpJpc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mountainsofchristmas/v24/3y9z6a4zcCnn5X0FDyrKi2ZRUBIy8uxoUo7eBGqJFPtCOp6IaEA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mouse-memoirs",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0218fc8e-5b41-4184-9a29-b7b39141eb02",
-230945439),$APP.$cljs$cst$2675$family$$,"Mouse Memoirs",$APP.$cljs$cst$725$name$$,"Mouse Memoirs",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mousememoirs/v19/t5tmIRoSNJ-PH0WNNgDYxdSb7TnFrpOHYh4.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mozilla-headline",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7078d788-a4c0-49e9-87b1-1a5e5fec1afd",1554763308),$APP.$cljs$cst$2675$family$$,"Mozilla Headline",$APP.$cljs$cst$725$name$$,"Mozilla Headline",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mozillaheadline/v1/QGYLz-UXahmCOps4kyMKGuSA9pYt2_P-w2kFrS88o6cVYRvBSDSOuerB_FOBYIYVZRxvtcorUQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mozillaheadline/v1/QGYLz-UXahmCOps4kyMKGuSA9pYt2_P-w2kFrS88o6cVYRvBSDSOuerB_FOBvoYVZRxvtcorUQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mozillaheadline/v1/QGYLz-UXahmCOps4kyMKGuSA9pYt2_P-w2kFrS88o6cVYRvBSDSOuerB_FOB4IYVZRxvtcorUQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mozillaheadline/v1/QGYLz-UXahmCOps4kyMKGuSA9pYt2_P-w2kFrS88o6cVYRvBSDSOuerB_FOB0oYVZRxvtcorUQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mozillaheadline/v1/QGYLz-UXahmCOps4kyMKGuSA9pYt2_P-w2kFrS88o6cVYRvBSDSOuerB_FOBPoEVZRxvtcorUQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mozillaheadline/v1/QGYLz-UXahmCOps4kyMKGuSA9pYt2_P-w2kFrS88o6cVYRvBSDSOuerB_FOBB4EVZRxvtcorUQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mozilla-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("81420f50-3781-4e40-be29-c084d6762e59",
27829465),$APP.$cljs$cst$2675$family$$,"Mozilla Text",$APP.$cljs$cst$725$name$$,"Mozilla Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mozillatext/v1/SZcr3FrnJ7S7WZIff2mJ7Tbp4zu7ULu3HkPOBwUcPNBRVYmoOXo.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mozillatext/v1/SZcr3FrnJ7S7WZIff2mJ7Tbp4zu7ULu3HkPOB9scPNBRVYmoOXo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mozillatext/v1/SZcr3FrnJ7S7WZIff2mJ7Tbp4zu7ULu3HkPOB4UcPNBRVYmoOXo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mozillatext/v1/SZcr3FrnJ7S7WZIff2mJ7Tbp4zu7ULu3HkPOB7ccPNBRVYmoOXo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mozillatext/v1/SZcr3FrnJ7S7WZIff2mJ7Tbp4zu7ULu3HkPOB1sbPNBRVYmoOXo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mozillatext/v1/SZcr3FrnJ7S7WZIff2mJ7Tbp4zu7ULu3HkPOB2IbPNBRVYmoOXo.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mr-bedfort",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2cb11a09-e8fa-4765-8c46-c36003df5f81",1408413803),$APP.$cljs$cst$2675$family$$,"Mr Bedfort",$APP.$cljs$cst$725$name$$,"Mr Bedfort",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mrbedfort/v23/MQpR-WCtNZSWAdTMwBicliq0XZe_Iy8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mr-dafoe",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e8a2bc86-daeb-4ae8-b742-dcab6fcc1a10",553404703),$APP.$cljs$cst$2675$family$$,"Mr Dafoe",$APP.$cljs$cst$725$name$$,"Mr Dafoe",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mrdafoe/v15/lJwE-pIzkS5NXuMMrGiqg7MCxz_C.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mr-de-haviland",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e39b88dd-6cca-4302-9ed4-dcad31bde324",
-1421156557),$APP.$cljs$cst$2675$family$$,"Mr De Haviland",$APP.$cljs$cst$725$name$$,"Mr De Haviland",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mrdehaviland/v15/OpNVnooIhJj96FdB73296ksbOj3C4ULVNTlB.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mrs-saint-delafield",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4159a4ec-6025-497c-87e2-7bb3b5cab774",2057608324),$APP.$cljs$cst$2675$family$$,"Mrs Saint Delafield",$APP.$cljs$cst$725$name$$,"Mrs Saint Delafield",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mrssaintdelafield/v14/v6-IGZDIOVXH9xtmTZfRagunqBw5WC62cK4tLsubB2w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mrs-sheppards",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c07ece6f-f25c-4bf2-89d8-18b7df2b3226",1329448568),$APP.$cljs$cst$2675$family$$,"Mrs Sheppards",$APP.$cljs$cst$725$name$$,
"Mrs Sheppards",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mrssheppards/v25/PN_2Rfm9snC0XUGoEZhb91ig3vjxynMix4Y.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-ms-madi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("796d5da6-a050-4a25-9a15-2fe224e4dcc7",207700436),$APP.$cljs$cst$2675$family$$,"Ms Madi",$APP.$cljs$cst$725$name$$,"Ms Madi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/msmadi/v2/HTxsL2UxNnOji5E1N-DPiI7QAYo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mukta",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d6110297-af63-4df3-91e0-d22d76bb8d91",2049204476),$APP.$cljs$cst$2675$family$$,"Mukta",$APP.$cljs$cst$725$name$$,"Mukta",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mukta/v17/iJWHBXyXfDDVXbEOjFma-2HW7ZB_.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mukta/v17/iJWHBXyXfDDVXbFqj1ma-2HW7ZB_.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mukta/v17/iJWKBXyXfDDVXYnGp32S0H3f.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mukta/v17/iJWHBXyXfDDVXbEyjlma-2HW7ZB_.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mukta/v17/iJWHBXyXfDDVXbEeiVma-2HW7ZB_.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mukta/v17/iJWHBXyXfDDVXbF6iFma-2HW7ZB_.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mukta/v17/iJWHBXyXfDDVXbFmi1ma-2HW7ZB_.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-mukta-mahee",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8a836bdc-3d97-4b47-a4e7-618c8003f9ba",843497697),$APP.$cljs$cst$2675$family$$,"Mukta Mahee",$APP.$cljs$cst$725$name$$,"Mukta Mahee",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktamahee/v19/XRXN3IOIi0hcP8iVU67hA9MFcBoHJndqZCsW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktamahee/v19/XRXN3IOIi0hcP8iVU67hA9NhcxoHJndqZCsW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktamahee/v19/XRXQ3IOIi0hcP8iVU67hA-vNWz4PDWtj.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktamahee/v19/XRXN3IOIi0hcP8iVU67hA9M5choHJndqZCsW.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktamahee/v19/XRXN3IOIi0hcP8iVU67hA9MVdRoHJndqZCsW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/muktamahee/v19/XRXN3IOIi0hcP8iVU67hA9NxdBoHJndqZCsW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktamahee/v19/XRXN3IOIi0hcP8iVU67hA9NtdxoHJndqZCsW.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mukta-malar",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4a2fb021-f49e-49e9-8e57-51dddf93d4da",-1160161462),$APP.$cljs$cst$2675$family$$,"Mukta Malar",$APP.$cljs$cst$725$name$$,"Mukta Malar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/muktamalar/v14/MCoKzAXyz8LOE2FpJMxZqIMwBtAB62ruoAZW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktamalar/v14/MCoKzAXyz8LOE2FpJMxZqINUBdAB62ruoAZW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktamalar/v14/MCoXzAXyz8LOE2FpJMxZqLv4LfQJwHbn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktamalar/v14/MCoKzAXyz8LOE2FpJMxZqIMMBNAB62ruoAZW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktamalar/v14/MCoKzAXyz8LOE2FpJMxZqIMgA9AB62ruoAZW.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktamalar/v14/MCoKzAXyz8LOE2FpJMxZqINEAtAB62ruoAZW.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktamalar/v14/MCoKzAXyz8LOE2FpJMxZqINYAdAB62ruoAZW.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mukta-vaani",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c9c7c90b-9281-41e0-a8b6-617ff389241b",-1192006244),
$APP.$cljs$cst$2675$family$$,"Mukta Vaani",$APP.$cljs$cst$725$name$$,"Mukta Vaani",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktavaani/v15/3JnkSD_-ynaxmxnEfVHPIGXNV8BD-u97MW1a.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktavaani/v15/3JnkSD_-ynaxmxnEfVHPIGWpVMBD-u97MW1a.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/muktavaani/v15/3Jn5SD_-ynaxmxnEfVHPIF0FfORL0fNy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktavaani/v15/3JnkSD_-ynaxmxnEfVHPIGXxVcBD-u97MW1a.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",
$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktavaani/v15/3JnkSD_-ynaxmxnEfVHPIGXdUsBD-u97MW1a.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktavaani/v15/3JnkSD_-ynaxmxnEfVHPIGW5U8BD-u97MW1a.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/muktavaani/v15/3JnkSD_-ynaxmxnEfVHPIGWlUMBD-u97MW1a.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mulish",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e368acca-f58c-4fe6-b12c-6f03a029990c",-1763160396),$APP.$cljs$cst$2675$family$$,"Mulish",$APP.$cljs$cst$725$name$$,
"Mulish",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptyg83HX_SGhgqO0yLcmjzUAuWexRNRwaClGrw-PTY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptyg83HX_SGhgqO0yLcmjzUAuWexc1RwaClGrw-PTY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptyg83HX_SGhgqO0yLcmjzUAuWexZNRwaClGrw-PTY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptyg83HX_SGhgqO0yLcmjzUAuWexaFRwaClGrw-PTY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/mulish/v18/1Ptyg83HX_SGhgqO0yLcmjzUAuWexU1WwaClGrw-PTY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptyg83HX_SGhgqO0yLcmjzUAuWexXRWwaClGrw-PTY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptyg83HX_SGhgqO0yLcmjzUAuWexRNWwaClGrw-PTY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptyg83HX_SGhgqO0yLcmjzUAuWexTpWwaClGrw-PTY.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptwg83HX_SGhgqk2hAjQlW_mEuZ0FsSqeOvHp47LTZFwA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptwg83HX_SGhgqk2hAjQlW_mEuZ0FsSd-OvHp47LTZFwA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptwg83HX_SGhgqk2hAjQlW_mEuZ0FsSKeOvHp47LTZFwA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptwg83HX_SGhgqk2hAjQlW_mEuZ0FsSG-OvHp47LTZFwA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptwg83HX_SGhgqk2hAjQlW_mEuZ0FsS9-SvHp47LTZFwA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptwg83HX_SGhgqk2hAjQlW_mEuZ0FsSzuSvHp47LTZFwA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptwg83HX_SGhgqk2hAjQlW_mEuZ0FsSqeSvHp47LTZFwA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mulish/v18/1Ptwg83HX_SGhgqk2hAjQlW_mEuZ0FsSgOSvHp47LTZFwA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-murecho",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5aa9c025-822c-4673-99e3-ed8c1729e5bb",-1214962694),$APP.$cljs$cst$2675$family$$,"Murecho",$APP.$cljs$cst$725$name$$,"Murecho",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/murecho/v17/q5uYsoq3NOBn_I-ggCJg98TBOoNFCMpr5HWZLCpUOaM6.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/murecho/v17/q5uYsoq3NOBn_I-ggCJg98TBOoNFCMrr5XWZLCpUOaM6.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/murecho/v17/q5uYsoq3NOBn_I-ggCJg98TBOoNFCMo15XWZLCpUOaM6.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/murecho/v17/q5uYsoq3NOBn_I-ggCJg98TBOoNFCMpr5XWZLCpUOaM6.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/murecho/v17/q5uYsoq3NOBn_I-ggCJg98TBOoNFCMpZ5XWZLCpUOaM6.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/murecho/v17/q5uYsoq3NOBn_I-ggCJg98TBOoNFCMq14nWZLCpUOaM6.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/murecho/v17/q5uYsoq3NOBn_I-ggCJg98TBOoNFCMqM4nWZLCpUOaM6.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/murecho/v17/q5uYsoq3NOBn_I-ggCJg98TBOoNFCMrr4nWZLCpUOaM6.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/murecho/v17/q5uYsoq3NOBn_I-ggCJg98TBOoNFCMrC4nWZLCpUOaM6.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-museomoderno",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2eb9315e-ca35-4fbd-bb4c-b6c77fba3272",1613517832),$APP.$cljs$cst$2675$family$$,"MuseoModerno",$APP.$cljs$cst$725$name$$,"MuseoModerno",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrf30HnU0_7wWdMrFcWqSEXPVyEaWJ55pTleMlZFuewajeKlCdo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrf30HnU0_7wWdMrFcWqSEXPVyEaWJ55pTleMtZEuewajeKlCdo.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrf30HnU0_7wWdMrFcWqSEXPVyEaWJ55pTleMghEuewajeKlCdo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrf30HnU0_7wWdMrFcWqSEXPVyEaWJ55pTleMlZEuewajeKlCdo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrf30HnU0_7wWdMrFcWqSEXPVyEaWJ55pTleMmREuewajeKlCdo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrf30HnU0_7wWdMrFcWqSEXPVyEaWJ55pTleMohDuewajeKlCdo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrf30HnU0_7wWdMrFcWqSEXPVyEaWJ55pTleMrFDuewajeKlCdo.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrf30HnU0_7wWdMrFcWqSEXPVyEaWJ55pTleMtZDuewajeKlCdo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrf30HnU0_7wWdMrFcWqSEXPVyEaWJ55pTleMv9DuewajeKlCdo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrfx0HnU0_7wWdMrFcWqSEXlXhPlgPcSP5dZJ54HUa4QicCgGdrS3g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrfx0HnU0_7wWdMrFcWqSEXlXhPlgPcSP5dZJ54H0a8QicCgGdrS3g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/museomoderno/v29/zrfx0HnU0_7wWdMrFcWqSEXlXhPlgPcSP5dZJ54HD68QicCgGdrS3g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrfx0HnU0_7wWdMrFcWqSEXlXhPlgPcSP5dZJ54HUa8QicCgGdrS3g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrfx0HnU0_7wWdMrFcWqSEXlXhPlgPcSP5dZJ54HY68QicCgGdrS3g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrfx0HnU0_7wWdMrFcWqSEXlXhPlgPcSP5dZJ54Hj6gQicCgGdrS3g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrfx0HnU0_7wWdMrFcWqSEXlXhPlgPcSP5dZJ54HtqgQicCgGdrS3g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrfx0HnU0_7wWdMrFcWqSEXlXhPlgPcSP5dZJ54H0agQicCgGdrS3g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/museomoderno/v29/zrfx0HnU0_7wWdMrFcWqSEXlXhPlgPcSP5dZJ54H-KgQicCgGdrS3g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-my-soul",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e401b83b-5851-4ac4-acff-e43211660482",-1840692244),$APP.$cljs$cst$2675$family$$,"My Soul",$APP.$cljs$cst$725$name$$,"My Soul",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mysoul/v7/3XFqErcuy945_u6KF_Ulk2nnXf0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mynerve",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7a5a9521-e4e6-4c7a-a5e5-5fbebd53aab2",-278942815),$APP.$cljs$cst$2675$family$$,"Mynerve",$APP.$cljs$cst$725$name$$,"Mynerve",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mynerve/v8/P5sCzZKPdNjb4jt7xCRuiZ-uydg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-mystery-quest",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ded885fb-d677-4d30-b7af-f027e7d96d13",985142650),$APP.$cljs$cst$2675$family$$,
"Mystery Quest",$APP.$cljs$cst$725$name$$,"Mystery Quest",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/mysteryquest/v21/-nF6OG414u0E6k0wynSGlujRHwElD_9Qz9E.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ntr",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8f00801a-23da-4fa9-856a-73a0705a94f3",-406937784),$APP.$cljs$cst$2675$family$$,"NTR",$APP.$cljs$cst$725$name$$,"NTR",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ntr/v19/RLpzK5Xy0ZjiGGhs5TA4bg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nabla",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("104e921b-3307-40f3-b9d2-1c2dc91376e8",979712149),$APP.$cljs$cst$2675$family$$,"Nabla",$APP.$cljs$cst$725$name$$,"Nabla",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nabla/v17/j8_D6-LI0Lvpe7Makz5UhJt9C3uqg_X_75gyGS4jAxsNIjrRNRBUFFR_198.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-namdhinggo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("252524f6-52dc-403e-9640-ac5953bb4fef",
1980020613),$APP.$cljs$cst$2675$family$$,"Namdhinggo",$APP.$cljs$cst$725$name$$,"Namdhinggo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/namdhinggo/v2/uk-mEGe3rbgg8Xzoy5-TDnWj4yxx7o8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/namdhinggo/v2/uk-lEGe3rbgg8Xzoy5-TNoGKxyRa8oZK9I0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/namdhinggo/v2/uk-lEGe3rbgg8Xzoy5-TNq2NxyRa8oZK9I0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/namdhinggo/v2/uk-lEGe3rbgg8Xzoy5-TNsmMxyRa8oZK9I0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",
$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/namdhinggo/v2/uk-lEGe3rbgg8Xzoy5-TNtWPxyRa8oZK9I0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nanum-brush-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("622c9f8e-66b9-4ba8-a279-ce3d9ad23728",-2001011421),$APP.$cljs$cst$2675$family$$,"Nanum Brush Script",$APP.$cljs$cst$725$name$$,"Nanum Brush Script",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nanumbrushscript/v26/wXK2E2wfpokopxzthSqPbcR5_gVaxazyjqBr1lO97Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nanum-gothic",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5801af71-667c-4a58-97c7-8e89c4f35b24",-1188709872),$APP.$cljs$cst$2675$family$$,"Nanum Gothic",$APP.$cljs$cst$725$name$$,"Nanum Gothic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/nanumgothic/v26/PN_3Rfi-oW3hYwmKDpxS7F_z_tLfxno73g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nanumgothic/v26/PN_oRfi-oW3hYwmKDpxS7F_LQv37zlEn14YEUQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nanumgothic/v26/PN_oRfi-oW3hYwmKDpxS7F_LXv77zlEn14YEUQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nanum-gothic-coding",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5be73f93-2d4b-42bc-97ef-e5c1091ba7b2",-1670018825),$APP.$cljs$cst$2675$family$$,"Nanum Gothic Coding",$APP.$cljs$cst$725$name$$,"Nanum Gothic Coding",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nanumgothiccoding/v27/8QIVdjzHisX_8vv59_xMxtPFW4IXROwsy6QxVs1X7tc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nanumgothiccoding/v27/8QIYdjzHisX_8vv59_xMxtPFW4IXROws8xgecsV88t5V9r4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nanum-myeongjo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2e8e146c-fe16-4a83-a956-58c539924a8b",-1971135252),$APP.$cljs$cst$2675$family$$,"Nanum Myeongjo",$APP.$cljs$cst$725$name$$,
"Nanum Myeongjo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nanummyeongjo/v31/9Btx3DZF0dXLMZlywRbVRNhxy1LreHQ8juyl.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nanummyeongjo/v31/9Bty3DZF0dXLMZlywRbVRNhxy2pXV1A0pfCs5Kos.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nanummyeongjo/v31/9Bty3DZF0dXLMZlywRbVRNhxy2pLVFA0pfCs5Kos.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nanum-pen-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("75e5b466-a5bb-4a74-a6f6-b049fd6214bf",802784552),$APP.$cljs$cst$2675$family$$,"Nanum Pen Script",$APP.$cljs$cst$725$name$$,"Nanum Pen Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nanumpenscript/v25/daaDSSYiLGqEal3MvdA_FOL_3FkN2z7-aMFCcTU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-narnoor",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1c43d351-729c-4092-b975-0c6b5b2f0aca",-1127888372),$APP.$cljs$cst$2675$family$$,"Narnoor",$APP.$cljs$cst$725$name$$,
"Narnoor",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/narnoor/v10/cIf9MaFWuVo-UTyPxCmrYGkHgIs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/narnoor/v10/cIf4MaFWuVo-UTyP_N2CRGEsnIJkWL4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/narnoor/v10/cIf4MaFWuVo-UTyP_PGFRGEsnIJkWL4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/narnoor/v10/cIf4MaFWuVo-UTyP_JWERGEsnIJkWL4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/narnoor/v10/cIf4MaFWuVo-UTyP_ImHRGEsnIJkWL4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nata-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a94590ae-e9b2-4493-8999-a2e776b2cd6b",729025332),$APP.$cljs$cst$2675$family$$,"Nata Sans",$APP.$cljs$cst$725$name$$,"Nata Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/natasans/v1/1q2XY5KBClBit88SU_tUw-brVNlaeZChg6wI6g2M62M1AXs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/natasans/v1/1q2XY5KBClBit88SU_tUw-brVNlaeZChgywJ6g2M62M1AXs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/natasans/v1/1q2XY5KBClBit88SU_tUw-brVNlaeZChg_IJ6g2M62M1AXs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/natasans/v1/1q2XY5KBClBit88SU_tUw-brVNlaeZChg6wJ6g2M62M1AXs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/natasans/v1/1q2XY5KBClBit88SU_tUw-brVNlaeZChg54J6g2M62M1AXs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/natasans/v1/1q2XY5KBClBit88SU_tUw-brVNlaeZChg3IO6g2M62M1AXs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/natasans/v1/1q2XY5KBClBit88SU_tUw-brVNlaeZChg0sO6g2M62M1AXs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/natasans/v1/1q2XY5KBClBit88SU_tUw-brVNlaeZChgywO6g2M62M1AXs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/natasans/v1/1q2XY5KBClBit88SU_tUw-brVNlaeZChgwUO6g2M62M1AXs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-national-park",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1c28d492-6c49-4cf3-a924-b86ac6d05cd9",-107444115),$APP.$cljs$cst$2675$family$$,"National Park",$APP.$cljs$cst$725$name$$,"National Park",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nationalpark/v4/GftQ7vJOtg4NO-gmoY4nmcqP-VY9vs1ixcqgHfL_b5XMdoayNUNf.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nationalpark/v4/GftQ7vJOtg4NO-gmoY4nmcqP-VY9vs1ixcqgHfIhb5XMdoayNUNf.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nationalpark/v4/GftQ7vJOtg4NO-gmoY4nmcqP-VY9vs1ixcqgHfJ_b5XMdoayNUNf.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nationalpark/v4/GftQ7vJOtg4NO-gmoY4nmcqP-VY9vs1ixcqgHfJNb5XMdoayNUNf.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nationalpark/v4/GftQ7vJOtg4NO-gmoY4nmcqP-VY9vs1ixcqgHfKhaJXMdoayNUNf.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nationalpark/v4/GftQ7vJOtg4NO-gmoY4nmcqP-VY9vs1ixcqgHfKYaJXMdoayNUNf.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nationalpark/v4/GftQ7vJOtg4NO-gmoY4nmcqP-VY9vs1ixcqgHfL_aJXMdoayNUNf.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-neonderthaw",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("91d413d8-3b08-4c44-9605-2d5a7d77e674",-1598720748),$APP.$cljs$cst$2675$family$$,"Neonderthaw",$APP.$cljs$cst$725$name$$,"Neonderthaw",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/neonderthaw/v8/Iure6Yx5-oWVZI0r-17AeZZJprVA4XQ0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nerko-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5d34a8cf-b723-4f0e-9010-c4947b54047f",435641339),$APP.$cljs$cst$2675$family$$,
"Nerko One",$APP.$cljs$cst$725$name$$,"Nerko One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nerkoone/v17/m8JQjfZSc7OXlB3ZMOjzcJ5BZmqa3A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-neucha",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ea6cd10a-fda5-4662-ab1b-272b0d905ccb",462974551),$APP.$cljs$cst$2675$family$$,"Neucha",$APP.$cljs$cst$725$name$$,"Neucha",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/neucha/v18/q5uGsou0JOdh94bvugNsCxVEgA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-neuton",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0bbc417e-76df-4664-9108-3062eae17988",-1868412519),$APP.$cljs$cst$2675$family$$,"Neuton",$APP.$cljs$cst$725$name$$,"Neuton",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/neuton/v24/UMBQrPtMoH62xUZKAKkfegD5Drog6Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/neuton/v24/UMBQrPtMoH62xUZKZKofegD5Drog6Q.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/neuton/v24/UMBTrPtMoH62xUZyyII7civlBw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/neuton/v24/UMBRrPtMoH62xUZCyog_UC71B6M5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/neuton/v24/UMBQrPtMoH62xUZKdK0fegD5Drog6Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,
"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/neuton/v24/UMBQrPtMoH62xUZKaK4fegD5Drog6Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-new-amsterdam",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b24eafd4-86db-49f9-96da-023a8e3ff220",711545559),$APP.$cljs$cst$2675$family$$,"New Amsterdam",$APP.$cljs$cst$725$name$$,"New Amsterdam",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newamsterdam/v1/YA9Vr02Y5lucHqUlbEe51kBtl7mGiv_Q7dA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-new-rocker",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("769c770c-6a88-4a81-b6f8-b8f5dce71094",
586070403),$APP.$cljs$cst$2675$family$$,"New Rocker",$APP.$cljs$cst$725$name$$,"New Rocker",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newrocker/v17/MwQzbhjp3-HImzcCU_cJkGMViblPtXs.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-new-tegomin",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d0444173-9c1e-4641-9b6e-3657c91921bf",455936791),$APP.$cljs$cst$2675$family$$,"New Tegomin",$APP.$cljs$cst$725$name$$,"New Tegomin",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newtegomin/v13/SLXMc1fV7Gd9USdBAfPlqfN0Q3ptkDMN.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-news-cycle",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6e04af5b-d322-4d81-8e97-74098478f860",722426478),$APP.$cljs$cst$2675$family$$,"News Cycle",$APP.$cljs$cst$725$name$$,"News Cycle",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newscycle/v26/CSR64z1Qlv-GDxkbKVQ_TOcATNt_pOU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",
$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newscycle/v26/CSR54z1Qlv-GDxkbKVQ_dFsvaNNUuOwkC2s.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-newsreader",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5fae4c5e-23ba-49e8-9d02-13c8c2949fb3",569926665),$APP.$cljs$cst$2675$family$$,"Newsreader",$APP.$cljs$cst$725$name$$,"Newsreader",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newsreader/v26/cY9qfjOCX1hbuyalUrK49dLac06G1ZGsZBtoBCzBDXXD9JVF438w-I_ADOxEPjCggA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newsreader/v26/cY9qfjOCX1hbuyalUrK49dLac06G1ZGsZBtoBCzBDXXD9JVF438wJo_ADOxEPjCggA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newsreader/v26/cY9qfjOCX1hbuyalUrK49dLac06G1ZGsZBtoBCzBDXXD9JVF438weI_ADOxEPjCggA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newsreader/v26/cY9qfjOCX1hbuyalUrK49dLac06G1ZGsZBtoBCzBDXXD9JVF438wSo_ADOxEPjCggA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newsreader/v26/cY9qfjOCX1hbuyalUrK49dLac06G1ZGsZBtoBCzBDXXD9JVF438wpojADOxEPjCggA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newsreader/v26/cY9qfjOCX1hbuyalUrK49dLac06G1ZGsZBtoBCzBDXXD9JVF438wn4jADOxEPjCggA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newsreader/v26/cY9qfjOCX1hbuyalUrK49dLac06G1ZGsZBtoBCzBDXXD9JVF438w-IjADOxEPjCggA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/newsreader/v26/cY9kfjOCX1hbuyalUrK439vogqC9yFZCYg7oRZaLP4obnf7fTXglsMyoT-ZAHDWwgECi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newsreader/v26/cY9kfjOCX1hbuyalUrK439vogqC9yFZCYg7oRZaLP4obnf7fTXglsMx2T-ZAHDWwgECi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newsreader/v26/cY9kfjOCX1hbuyalUrK439vogqC9yFZCYg7oRZaLP4obnf7fTXglsMwoT-ZAHDWwgECi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/newsreader/v26/cY9kfjOCX1hbuyalUrK439vogqC9yFZCYg7oRZaLP4obnf7fTXglsMwaT-ZAHDWwgECi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newsreader/v26/cY9kfjOCX1hbuyalUrK439vogqC9yFZCYg7oRZaLP4obnf7fTXglsMz2SOZAHDWwgECi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/newsreader/v26/cY9kfjOCX1hbuyalUrK439vogqC9yFZCYg7oRZaLP4obnf7fTXglsMzPSOZAHDWwgECi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/newsreader/v26/cY9kfjOCX1hbuyalUrK439vogqC9yFZCYg7oRZaLP4obnf7fTXglsMyoSOZAHDWwgECi.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-niconne",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0ba1a953-d8ee-4db6-8214-539bb45dd090",-108769966),$APP.$cljs$cst$2675$family$$,"Niconne",$APP.$cljs$cst$725$name$$,"Niconne",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/niconne/v16/w8gaH2QvRug1_rTfrQut2F4OuOo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-niramit",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dde6a11b-0ee9-4e8c-a1dc-d349581825cd",-1474777498),$APP.$cljs$cst$2675$family$$,
"Niramit",$APP.$cljs$cst$725$name$$,"Niramit",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/niramit/v12/I_urMpWdvgLdNxVLVXx7tiiEr5_BdZ8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/niramit/v12/I_upMpWdvgLdNxVLXbZiXimOq73EZZ_f6w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/niramit/v12/I_urMpWdvgLdNxVLVRh4tiiEr5_BdZ8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/niramit/v12/I_upMpWdvgLdNxVLXbZiOiqOq73EZZ_f6w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/niramit/v12/I_uuMpWdvgLdNxVLbbRQkiCvs5Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/niramit/v12/I_usMpWdvgLdNxVLXbZalgKqo5bYbA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/niramit/v12/I_urMpWdvgLdNxVLVUB5tiiEr5_BdZ8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/niramit/v12/I_upMpWdvgLdNxVLXbZiYiuOq73EZZ_f6w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/niramit/v12/I_urMpWdvgLdNxVLVWx-tiiEr5_BdZ8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/niramit/v12/I_upMpWdvgLdNxVLXbZiTiyOq73EZZ_f6w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/niramit/v12/I_urMpWdvgLdNxVLVQh_tiiEr5_BdZ8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/niramit/v12/I_upMpWdvgLdNxVLXbZiKi2Oq73EZZ_f6w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nixie-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ceadafd4-0b5a-4583-bde8-cd42c17015cb",-992812995),$APP.$cljs$cst$2675$family$$,"Nixie One",$APP.$cljs$cst$725$name$$,"Nixie One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nixieone/v17/lW-8wjkKLXjg5y2o2uUoUOFzpS-yLw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nobile",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bdf5a663-55c0-4e64-a875-50ebd929ead4",-2138511008),$APP.$cljs$cst$2675$family$$,"Nobile",$APP.$cljs$cst$725$name$$,
"Nobile",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nobile/v19/m8JTjflSeaOVl1i2XqfXeLVdbw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",
$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nobile/v19/m8JRjflSeaOVl1iGXK3TWrBNb3OD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nobile/v19/m8JQjflSeaOVl1iOqo7zcJ5BZmqa3A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nobile/v19/m8JWjflSeaOVl1iGXJUnc5RFRG-K3Mud.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/nobile/v19/m8JQjflSeaOVl1iO4ojzcJ5BZmqa3A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nobile/v19/m8JWjflSeaOVl1iGXJVvdZRFRG-K3Mud.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nokora",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("52444a6d-c9f3-46ba-b17f-2d250474d862",1686478700),$APP.$cljs$cst$2675$family$$,"Nokora",$APP.$cljs$cst$725$name$$,"Nokora",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nokora/v34/hYkVPuwgTubzaWxKMBj_emrD9wtMuj1ecbKpdHdrk1k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nokora/v34/hYkVPuwgTubzaWxKMBj_emrD9wtMur1fcbKpdHdrk1k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/nokora/v34/hYkVPuwgTubzaWxKMBj_emrD9wtMumNfcbKpdHdrk1k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nokora/v34/hYkVPuwgTubzaWxKMBj_emrD9wtMuj1fcbKpdHdrk1k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nokora/v34/hYkVPuwgTubzaWxKMBj_emrD9wtMug9fcbKpdHdrk1k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nokora/v34/hYkVPuwgTubzaWxKMBj_emrD9wtMuuNYcbKpdHdrk1k.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nokora/v34/hYkVPuwgTubzaWxKMBj_emrD9wtMutpYcbKpdHdrk1k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/nokora/v34/hYkVPuwgTubzaWxKMBj_emrD9wtMur1YcbKpdHdrk1k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nokora/v34/hYkVPuwgTubzaWxKMBj_emrD9wtMupRYcbKpdHdrk1k.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-norican",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c6c2165b-390b-4b4c-bc9e-0bfadaa4f19d",-479904240),$APP.$cljs$cst$2675$family$$,"Norican",$APP.$cljs$cst$725$name$$,"Norican",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/norican/v16/MwQ2bhXp1eSBqjkPGJJRtGs-lbA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nosifer",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("585367b6-8dec-4cdb-8c19-f1666bf93d03",-745145120),$APP.$cljs$cst$2675$family$$,"Nosifer",$APP.$cljs$cst$725$name$$,"Nosifer",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nosifer/v23/ZGjXol5JTp0g5bxZaC1RVDNdGDs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-notable",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cb571a28-10ed-4966-951c-7a7e01c9a292",889689100),$APP.$cljs$cst$2675$family$$,"Notable",$APP.$cljs$cst$725$name$$,
"Notable",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notable/v20/gNMEW3N_SIqx-WX9-HMoFIez5MI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-nothing-you-could-do",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("becf53a5-9de7-43b2-8216-c2defca29b7a",-142807694),$APP.$cljs$cst$2675$family$$,"Nothing You Could Do",$APP.$cljs$cst$725$name$$,"Nothing You Could Do",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nothingyoucoulddo/v21/oY1B8fbBpaP5OX3DtrRYf_Q2BPB1SnfZb0OJl1ol2Ymo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noticia-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e1502179-2826-4968-9e2f-579bcdae6558",-361356040),$APP.$cljs$cst$2675$family$$,"Noticia Text",$APP.$cljs$cst$725$name$$,"Noticia Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/noticiatext/v16/VuJ2dNDF2Yv9qppOePKYRP1GYTFZt0rNpQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/noticiatext/v16/VuJodNDF2Yv9qppOePKYRP12YztdlU_dpSjt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/noticiatext/v16/VuJpdNDF2Yv9qppOePKYRP1-3R59v2HRrDH0eA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/noticiatext/v16/VuJrdNDF2Yv9qppOePKYRP12YwPhumvVjjTkeMnz.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-color-emoji",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("310ebf4b-2646-48bd-b216-df046777f28d",-627933857),$APP.$cljs$cst$2675$family$$,
"Noto Color Emoji",$APP.$cljs$cst$725$name$$,"Noto Color Emoji",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notocoloremoji/v37/Yq6P-KqIXTD0t4D9z1ESnKM3-HpFab5s79iz64w.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-emoji",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("972e4252-bec0-4fae-a136-f12213d9d83b",-77924908),$APP.$cljs$cst$2675$family$$,"Noto Emoji",$APP.$cljs$cst$725$name$$,"Noto Emoji",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoemoji/v62/bMrnmSyK7YY-MEu6aWjPDs-ar6uWaGWuob_10jwvS-FGJCMY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoemoji/v62/bMrnmSyK7YY-MEu6aWjPDs-ar6uWaGWuob-r0jwvS-FGJCMY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoemoji/v62/bMrnmSyK7YY-MEu6aWjPDs-ar6uWaGWuob-Z0jwvS-FGJCMY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoemoji/v62/bMrnmSyK7YY-MEu6aWjPDs-ar6uWaGWuob911TwvS-FGJCMY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoemoji/v62/bMrnmSyK7YY-MEu6aWjPDs-ar6uWaGWuob9M1TwvS-FGJCMY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-kufi-arabic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e1341f41-a4d7-4afb-9698-ba1460eb66c0",435073536),$APP.$cljs$cst$2675$family$$,"Noto Kufi Arabic",$APP.$cljs$cst$725$name$$,"Noto Kufi Arabic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notokufiarabic/v27/CSRp4ydQnPyaDxEXLFF6LZVLKrodhu8t57o1kDc5Wh5v3obPnLSmf5yD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notokufiarabic/v27/CSRp4ydQnPyaDxEXLFF6LZVLKrodhu8t57o1kDc5Wh7v34bPnLSmf5yD.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notokufiarabic/v27/CSRp4ydQnPyaDxEXLFF6LZVLKrodhu8t57o1kDc5Wh4x34bPnLSmf5yD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notokufiarabic/v27/CSRp4ydQnPyaDxEXLFF6LZVLKrodhu8t57o1kDc5Wh5v34bPnLSmf5yD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notokufiarabic/v27/CSRp4ydQnPyaDxEXLFF6LZVLKrodhu8t57o1kDc5Wh5d34bPnLSmf5yD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notokufiarabic/v27/CSRp4ydQnPyaDxEXLFF6LZVLKrodhu8t57o1kDc5Wh6x2IbPnLSmf5yD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notokufiarabic/v27/CSRp4ydQnPyaDxEXLFF6LZVLKrodhu8t57o1kDc5Wh6I2IbPnLSmf5yD.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notokufiarabic/v27/CSRp4ydQnPyaDxEXLFF6LZVLKrodhu8t57o1kDc5Wh7v2IbPnLSmf5yD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notokufiarabic/v27/CSRp4ydQnPyaDxEXLFF6LZVLKrodhu8t57o1kDc5Wh7G2IbPnLSmf5yD.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-music",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("faf496ea-ed36-4495-9b5f-bbc5a4d4203a",1545394583),$APP.$cljs$cst$2675$family$$,"Noto Music",$APP.$cljs$cst$725$name$$,"Noto Music",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notomusic/v21/pe0rMIiSN5pO63htf1sxIteQB9Zra1U.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-naskh-arabic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("198b1a19-7d3b-4d68-a9e1-55c3d380c251",
-1086132321),$APP.$cljs$cst$2675$family$$,"Noto Naskh Arabic",$APP.$cljs$cst$725$name$$,"Noto Naskh Arabic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notonaskharabic/v43/RrQ5bpV-9Dd1b1OAGA6M9PkyDuVBePeKNaxcsss0Y7bwvc5krK0z9_Mnuw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notonaskharabic/v43/RrQ5bpV-9Dd1b1OAGA6M9PkyDuVBePeKNaxcsss0Y7bwj85krK0z9_Mnuw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notonaskharabic/v43/RrQ5bpV-9Dd1b1OAGA6M9PkyDuVBePeKNaxcsss0Y7bwY8lkrK0z9_Mnuw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notonaskharabic/v43/RrQ5bpV-9Dd1b1OAGA6M9PkyDuVBePeKNaxcsss0Y7bwWslkrK0z9_Mnuw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-nastaliq-urdu",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("22a13602-d48a-443c-a937-987dae1af9bf",751293240),$APP.$cljs$cst$2675$family$$,"Noto Nastaliq Urdu",$APP.$cljs$cst$725$name$$,"Noto Nastaliq Urdu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notonastaliqurdu/v23/LhWNMUPbN-oZdNFcBy1-DJYsEoTq5pudQ9L940pGPkB3Qt_-DK2f2-_8mEw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notonastaliqurdu/v23/LhWNMUPbN-oZdNFcBy1-DJYsEoTq5pudQ9L940pGPkB3Qu3-DK2f2-_8mEw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notonastaliqurdu/v23/LhWNMUPbN-oZdNFcBy1-DJYsEoTq5pudQ9L940pGPkB3QgH5DK2f2-_8mEw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notonastaliqurdu/v23/LhWNMUPbN-oZdNFcBy1-DJYsEoTq5pudQ9L940pGPkB3Qjj5DK2f2-_8mEw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-rashi-hebrew",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0075f3a5-d05d-4004-8e96-36783f5380e8",-478344605),$APP.$cljs$cst$2675$family$$,"Noto Rashi Hebrew",$APP.$cljs$cst$725$name$$,"Noto Rashi Hebrew",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notorashihebrew/v28/EJR_Qh82XsIK-QFmqXk4zvLwFVya0vFL-HlKM5e6C6HZB-DkRyq6Nf2pfA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notorashihebrew/v28/EJR_Qh82XsIK-QFmqXk4zvLwFVya0vFL-HlKM5e6C6HZh-HkRyq6Nf2pfA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notorashihebrew/v28/EJR_Qh82XsIK-QFmqXk4zvLwFVya0vFL-HlKM5e6C6HZWeHkRyq6Nf2pfA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notorashihebrew/v28/EJR_Qh82XsIK-QFmqXk4zvLwFVya0vFL-HlKM5e6C6HZB-HkRyq6Nf2pfA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notorashihebrew/v28/EJR_Qh82XsIK-QFmqXk4zvLwFVya0vFL-HlKM5e6C6HZNeHkRyq6Nf2pfA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notorashihebrew/v28/EJR_Qh82XsIK-QFmqXk4zvLwFVya0vFL-HlKM5e6C6HZ2ebkRyq6Nf2pfA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notorashihebrew/v28/EJR_Qh82XsIK-QFmqXk4zvLwFVya0vFL-HlKM5e6C6HZ4ObkRyq6Nf2pfA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notorashihebrew/v28/EJR_Qh82XsIK-QFmqXk4zvLwFVya0vFL-HlKM5e6C6HZh-bkRyq6Nf2pfA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notorashihebrew/v28/EJR_Qh82XsIK-QFmqXk4zvLwFVya0vFL-HlKM5e6C6HZrubkRyq6Nf2pfA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c8b220a2-a096-48ce-a3ac-96124fd23e12",
1159426157),$APP.$cljs$cst$2675$family$$,"Noto Sans",$APP.$cljs$cst$725$name$$,"Noto Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0mIpQlx3QUlC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyD9At9d41P6zHtY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0mIpQlx3QUlC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyB9A99d41P6zHtY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0mIpQlx3QUlC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyCjA99d41P6zHtY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0mIpQlx3QUlC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyD9A99d41P6zHtY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0mIpQlx3QUlC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyDPA99d41P6zHtY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0mIpQlx3QUlC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyAjBN9d41P6zHtY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0mIpQlx3QUlC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyAaBN9d41P6zHtY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0mIpQlx3QUlC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyB9BN9d41P6zHtY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0mIpQlx3QUlC5A4PNB6Ryti20_6n1iPHjcz6L1SoM-jCpoiyBUBN9d41P6zHtY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0kIpQlx3QUlC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QDcf6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosans/v42/o-0kIpQlx3QUlC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QLce6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0kIpQlx3QUlC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QGke6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0kIpQlx3QUlC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QDce6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosans/v42/o-0kIpQlx3QUlC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QAUe6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0kIpQlx3QUlC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QOkZ6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0kIpQlx3QUlC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QNAZ6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosans/v42/o-0kIpQlx3QUlC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QLcZ6VfYyWtY1rI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosans/v42/o-0kIpQlx3QUlC5A4PNr4C5OaxRsfNNlKbCePevHtVtX57DGjDU1QJ4Z6VfYyWtY1rI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-adlam",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6a066a3d-c8f1-4ff7-a49d-15913f995a7d",1218797685),$APP.$cljs$cst$2675$family$$,"Noto Sans Adlam",$APP.$cljs$cst$725$name$$,"Noto Sans Adlam",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansadlam/v27/neIczCCpqp0s5pPusPamd81eMfjPonvqdbYxxpgufnv0TGnBZLwhuvk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansadlam/v27/neIczCCpqp0s5pPusPamd81eMfjPonvqdbYxxpgufkn0TGnBZLwhuvk.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansadlam/v27/neIczCCpqp0s5pPusPamd81eMfjPonvqdbYxxpgufqXzTGnBZLwhuvk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansadlam/v27/neIczCCpqp0s5pPusPamd81eMfjPonvqdbYxxpgufpzzTGnBZLwhuvk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-adlam-unjoined",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("77a3e258-f02d-4dd7-ae1f-3b9e2e9718a2",1900972055),$APP.$cljs$cst$2675$family$$,"Noto Sans Adlam Unjoined",$APP.$cljs$cst$725$name$$,"Noto Sans Adlam Unjoined",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansadlamunjoined/v28/P5sszY2MYsLRsB5_ildkzPPDsLQXcOEmaFOqOGcaYrzFTIjsPam_Ye35PMEe-E3slUg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansadlamunjoined/v28/P5sszY2MYsLRsB5_ildkzPPDsLQXcOEmaFOqOGcaYrzFTIjsPam_Yd_5PMEe-E3slUg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansadlamunjoined/v28/P5sszY2MYsLRsB5_ildkzPPDsLQXcOEmaFOqOGcaYrzFTIjsPam_YTP-PMEe-E3slUg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansadlamunjoined/v28/P5sszY2MYsLRsB5_ildkzPPDsLQXcOEmaFOqOGcaYrzFTIjsPam_YQr-PMEe-E3slUg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-anatolian-hieroglyphs",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fe2676b8-9a1a-487d-9f11-6c5a6e5f2481",
-2135184837),$APP.$cljs$cst$2675$family$$,"Noto Sans Anatolian Hieroglyphs",$APP.$cljs$cst$725$name$$,"Noto Sans Anatolian Hieroglyphs",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansanatolianhieroglyphs/v17/ijw9s4roRME5LLRxjsRb8A0gKPSWq4BbDmHHu6j2pEtUJzZWXybIymc5QYo.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-arabic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7c7cb8d3-533b-4891-8392-508f1b5f7c19",-2115838701),$APP.$cljs$cst$2675$family$$,"Noto Sans Arabic",$APP.$cljs$cst$725$name$$,"Noto Sans Arabic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarabic/v33/nwpxtLGrOAZMl5nJ_wfgRg3DrWFZWsnVBJ_sS6tlqHHFlhQ5l3sQWIHPqzCfyG2vu3CBFQLaig.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarabic/v33/nwpxtLGrOAZMl5nJ_wfgRg3DrWFZWsnVBJ_sS6tlqHHFlhQ5l3sQWIHPqzCfSGyvu3CBFQLaig.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarabic/v33/nwpxtLGrOAZMl5nJ_wfgRg3DrWFZWsnVBJ_sS6tlqHHFlhQ5l3sQWIHPqzCflmyvu3CBFQLaig.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarabic/v33/nwpxtLGrOAZMl5nJ_wfgRg3DrWFZWsnVBJ_sS6tlqHHFlhQ5l3sQWIHPqzCfyGyvu3CBFQLaig.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarabic/v33/nwpxtLGrOAZMl5nJ_wfgRg3DrWFZWsnVBJ_sS6tlqHHFlhQ5l3sQWIHPqzCf-myvu3CBFQLaig.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarabic/v33/nwpxtLGrOAZMl5nJ_wfgRg3DrWFZWsnVBJ_sS6tlqHHFlhQ5l3sQWIHPqzCfFmuvu3CBFQLaig.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarabic/v33/nwpxtLGrOAZMl5nJ_wfgRg3DrWFZWsnVBJ_sS6tlqHHFlhQ5l3sQWIHPqzCfL2uvu3CBFQLaig.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarabic/v33/nwpxtLGrOAZMl5nJ_wfgRg3DrWFZWsnVBJ_sS6tlqHHFlhQ5l3sQWIHPqzCfSGuvu3CBFQLaig.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarabic/v33/nwpxtLGrOAZMl5nJ_wfgRg3DrWFZWsnVBJ_sS6tlqHHFlhQ5l3sQWIHPqzCfYWuvu3CBFQLaig.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-armenian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4fd3ebb7-7071-4646-b87b-14a8c2d84d28",
741419616),$APP.$cljs$cst$2675$family$$,"Noto Sans Armenian",$APP.$cljs$cst$725$name$$,"Noto Sans Armenian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarmenian/v47/ZgN0jOZKPa7CHqq0h37c7ReDUubm2SEdFXp7ig73qtTY5idb74R9UdM3y2nZLorxbq0iYy6zF3Eg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarmenian/v47/ZgN0jOZKPa7CHqq0h37c7ReDUubm2SEdFXp7ig73qtTY5idb74R9UdM3y2nZLopxb60iYy6zF3Eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarmenian/v47/ZgN0jOZKPa7CHqq0h37c7ReDUubm2SEdFXp7ig73qtTY5idb74R9UdM3y2nZLoqvb60iYy6zF3Eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarmenian/v47/ZgN0jOZKPa7CHqq0h37c7ReDUubm2SEdFXp7ig73qtTY5idb74R9UdM3y2nZLorxb60iYy6zF3Eg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarmenian/v47/ZgN0jOZKPa7CHqq0h37c7ReDUubm2SEdFXp7ig73qtTY5idb74R9UdM3y2nZLorDb60iYy6zF3Eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarmenian/v47/ZgN0jOZKPa7CHqq0h37c7ReDUubm2SEdFXp7ig73qtTY5idb74R9UdM3y2nZLoovaK0iYy6zF3Eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarmenian/v47/ZgN0jOZKPa7CHqq0h37c7ReDUubm2SEdFXp7ig73qtTY5idb74R9UdM3y2nZLooWaK0iYy6zF3Eg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarmenian/v47/ZgN0jOZKPa7CHqq0h37c7ReDUubm2SEdFXp7ig73qtTY5idb74R9UdM3y2nZLopxaK0iYy6zF3Eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansarmenian/v47/ZgN0jOZKPa7CHqq0h37c7ReDUubm2SEdFXp7ig73qtTY5idb74R9UdM3y2nZLopYaK0iYy6zF3Eg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-avestan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2a80360d-45d6-43e9-ab3b-88e906315171",938975827),$APP.$cljs$cst$2675$family$$,"Noto Sans Avestan",$APP.$cljs$cst$725$name$$,"Noto Sans Avestan",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansavestan/v22/bWti7ejKfBziStx7lIzKOLQZKhIJkyu9SASLji8U.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-balinese",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b1e9d97c-b3c5-4bda-ae86-767b9305aec1",2099252768),$APP.$cljs$cst$2675$family$$,"Noto Sans Balinese",$APP.$cljs$cst$725$name$$,"Noto Sans Balinese",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbalinese/v27/NaPwcYvSBuhTirw6IaFn6UrRDaqje-lpbbRtYf-Fwu2Ov7fdhE5Vd222PPY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbalinese/v27/NaPwcYvSBuhTirw6IaFn6UrRDaqje-lpbbRtYf-Fwu2Ov4XdhE5Vd222PPY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbalinese/v27/NaPwcYvSBuhTirw6IaFn6UrRDaqje-lpbbRtYf-Fwu2Ov2nahE5Vd222PPY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbalinese/v27/NaPwcYvSBuhTirw6IaFn6UrRDaqje-lpbbRtYf-Fwu2Ov1DahE5Vd222PPY.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-bamum",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3b188b51-cf88-4aeb-ad3e-3f1e3d1b55d8",1092084042),$APP.$cljs$cst$2675$family$$,"Noto Sans Bamum",$APP.$cljs$cst$725$name$$,"Noto Sans Bamum",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbamum/v35/uk-0EGK3o6EruUbnwovcbBTkkklK_Ya_PBHfNGTPEddO-_gLykxEkxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbamum/v35/uk-0EGK3o6EruUbnwovcbBTkkklK_Ya_PBHfNGTPEeVO-_gLykxEkxA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbamum/v35/uk-0EGK3o6EruUbnwovcbBTkkklK_Ya_PBHfNGTPEQlJ-_gLykxEkxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbamum/v35/uk-0EGK3o6EruUbnwovcbBTkkklK_Ya_PBHfNGTPETBJ-_gLykxEkxA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-bassa-vah",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f23f3590-122b-43bd-b524-135e6d0c5f5e",-1291682254),$APP.$cljs$cst$2675$family$$,"Noto Sans Bassa Vah",$APP.$cljs$cst$725$name$$,"Noto Sans Bassa Vah",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbassavah/v21/PN_bRee-r3f7LnqsD5sax12gjZn7mBpL5YwUpA2MBdcFn4MaAc6p34gH-GD7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbassavah/v21/PN_bRee-r3f7LnqsD5sax12gjZn7mBpL5YwUpA2MBdcFn4MoAc6p34gH-GD7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbassavah/v21/PN_bRee-r3f7LnqsD5sax12gjZn7mBpL5YwUpA2MBdcFn4PEBs6p34gH-GD7.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbassavah/v21/PN_bRee-r3f7LnqsD5sax12gjZn7mBpL5YwUpA2MBdcFn4P9Bs6p34gH-GD7.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-batak",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("65bfdaf8-1ec5-47cc-9841-17f37c1ecc77",
1969789868),$APP.$cljs$cst$2675$family$$,"Noto Sans Batak",$APP.$cljs$cst$725$name$$,"Noto Sans Batak",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbatak/v23/gok2H6TwAEdtF9N8-mdTCQvT-Zdgo4_PHuk74A.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-bengali",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ca33999e-5f0a-4e69-854a-7582d4dd66e0",918061602),$APP.$cljs$cst$2675$family$$,"Noto Sans Bengali",$APP.$cljs$cst$725$name$$,"Noto Sans Bengali",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbengali/v32/Cn-SJsCGWQxOjaGwMQ6fIiMywrNJIky6nvd8BjzVMvJx2mcSPVFpVEqE-6KmsolKudCk8izI0lc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbengali/v32/Cn-SJsCGWQxOjaGwMQ6fIiMywrNJIky6nvd8BjzVMvJx2mcSPVFpVEqE-6KmsglLudCk8izI0lc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbengali/v32/Cn-SJsCGWQxOjaGwMQ6fIiMywrNJIky6nvd8BjzVMvJx2mcSPVFpVEqE-6KmstdLudCk8izI0lc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbengali/v32/Cn-SJsCGWQxOjaGwMQ6fIiMywrNJIky6nvd8BjzVMvJx2mcSPVFpVEqE-6KmsolLudCk8izI0lc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbengali/v32/Cn-SJsCGWQxOjaGwMQ6fIiMywrNJIky6nvd8BjzVMvJx2mcSPVFpVEqE-6KmsrtLudCk8izI0lc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbengali/v32/Cn-SJsCGWQxOjaGwMQ6fIiMywrNJIky6nvd8BjzVMvJx2mcSPVFpVEqE-6KmsldMudCk8izI0lc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbengali/v32/Cn-SJsCGWQxOjaGwMQ6fIiMywrNJIky6nvd8BjzVMvJx2mcSPVFpVEqE-6Kmsm5MudCk8izI0lc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbengali/v32/Cn-SJsCGWQxOjaGwMQ6fIiMywrNJIky6nvd8BjzVMvJx2mcSPVFpVEqE-6KmsglMudCk8izI0lc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbengali/v32/Cn-SJsCGWQxOjaGwMQ6fIiMywrNJIky6nvd8BjzVMvJx2mcSPVFpVEqE-6KmsiBMudCk8izI0lc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-bhaiksuki",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("89990420-3b8a-4e05-bc64-80ffe8f59ad2",
1118268609),$APP.$cljs$cst$2675$family$$,"Noto Sans Bhaiksuki",$APP.$cljs$cst$725$name$$,"Noto Sans Bhaiksuki",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbhaiksuki/v18/UcC63EosKniBH4iELXATsSBWdvUHXxhj8rLUdU4wh9U.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-brahmi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fbc74976-5bfd-4092-9385-31be54771c3c",-1314064061),$APP.$cljs$cst$2675$family$$,"Noto Sans Brahmi",$APP.$cljs$cst$725$name$$,"Noto Sans Brahmi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbrahmi/v20/vEFK2-VODB8RrNDvZSUmQQIIByV18tK1W77HtMo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-buginese",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0ed182bc-558c-4c6e-b1bf-07ab79c20116",149331180),$APP.$cljs$cst$2675$family$$,"Noto Sans Buginese",$APP.$cljs$cst$725$name$$,
"Noto Sans Buginese",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbuginese/v19/esDM30ldNv-KYGGJpKGk18phe_7Da6_gtfuEXLmNtw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-buhid",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("de1cc32b-36b7-40d7-9566-7c682e9674eb",-1447650791),$APP.$cljs$cst$2675$family$$,"Noto Sans Buhid",$APP.$cljs$cst$725$name$$,"Noto Sans Buhid",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansbuhid/v23/Dxxy8jiXMW75w3OmoDXVWJD7YwzAe6tgnaFoGA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-canadian-aboriginal",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f0a0214a-82e0-4cfd-8b5c-ddc9a3c89af2",261212971),$APP.$cljs$cst$2675$family$$,"Noto Sans Canadian Aboriginal",$APP.$cljs$cst$725$name$$,"Noto Sans Canadian Aboriginal",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscanadianaboriginal/v28/4C_TLjTuEqPj-8J01CwaGkiZ9os0iGVkezM1mUT-j_Lmlzda6uH_nnX1bzigWLj_yAsg0q0uhQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscanadianaboriginal/v28/4C_TLjTuEqPj-8J01CwaGkiZ9os0iGVkezM1mUT-j_Lmlzda6uH_nnX1bzig2Ln_yAsg0q0uhQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosanscanadianaboriginal/v28/4C_TLjTuEqPj-8J01CwaGkiZ9os0iGVkezM1mUT-j_Lmlzda6uH_nnX1bzigBrn_yAsg0q0uhQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscanadianaboriginal/v28/4C_TLjTuEqPj-8J01CwaGkiZ9os0iGVkezM1mUT-j_Lmlzda6uH_nnX1bzigWLn_yAsg0q0uhQ.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscanadianaboriginal/v28/4C_TLjTuEqPj-8J01CwaGkiZ9os0iGVkezM1mUT-j_Lmlzda6uH_nnX1bzigarn_yAsg0q0uhQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscanadianaboriginal/v28/4C_TLjTuEqPj-8J01CwaGkiZ9os0iGVkezM1mUT-j_Lmlzda6uH_nnX1bzighr7_yAsg0q0uhQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscanadianaboriginal/v28/4C_TLjTuEqPj-8J01CwaGkiZ9os0iGVkezM1mUT-j_Lmlzda6uH_nnX1bzigv77_yAsg0q0uhQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscanadianaboriginal/v28/4C_TLjTuEqPj-8J01CwaGkiZ9os0iGVkezM1mUT-j_Lmlzda6uH_nnX1bzig2L7_yAsg0q0uhQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,
"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscanadianaboriginal/v28/4C_TLjTuEqPj-8J01CwaGkiZ9os0iGVkezM1mUT-j_Lmlzda6uH_nnX1bzig8b7_yAsg0q0uhQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-carian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b1eb8a75-b9e1-4f64-9259-53256df35a66",1773872292),$APP.$cljs$cst$2675$family$$,"Noto Sans Carian",$APP.$cljs$cst$725$name$$,"Noto Sans Carian",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscarian/v17/LDIpaoiONgYwA9Yc6f0gUILeMIOgs7ob9yGLmfI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-noto-sans-caucasian-albanian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1efd2989-37b2-4da3-b7f8-47a340bf012a",-211141487),$APP.$cljs$cst$2675$family$$,"Noto Sans Caucasian Albanian",$APP.$cljs$cst$725$name$$,"Noto Sans Caucasian Albanian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscaucasianalbanian/v19/nKKA-HM_FYFRJvXzVXaANsU0VzsAc46QGOkWytlTs-TXrYDmoVmRSZo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-chakma",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7e404c0b-5bd4-4a4b-818b-f4833bfc490e",-459277957),$APP.$cljs$cst$2675$family$$,"Noto Sans Chakma",$APP.$cljs$cst$725$name$$,"Noto Sans Chakma",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanschakma/v18/Y4GQYbJ8VTEp4t3MKJSMjg5OIzhi4JjTQhYBeYo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-cham",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b76b6c05-192d-40b4-9c4b-9ab20e8bd177",-772809920),$APP.$cljs$cst$2675$family$$,"Noto Sans Cham",$APP.$cljs$cst$725$name$$,"Noto Sans Cham",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosanscham/v33/pe06MIySN5pO62Z5YkFyQb_bbuRhe6D4yip43qfcER0cv7GykboaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscham/v33/pe06MIySN5pO62Z5YkFyQb_bbuRhe6D4yip43qfckRwcv7GykboaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscham/v33/pe06MIySN5pO62Z5YkFyQb_bbuRhe6D4yip43qfcTxwcv7GykboaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscham/v33/pe06MIySN5pO62Z5YkFyQb_bbuRhe6D4yip43qfcERwcv7GykboaLg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscham/v33/pe06MIySN5pO62Z5YkFyQb_bbuRhe6D4yip43qfcIxwcv7GykboaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscham/v33/pe06MIySN5pO62Z5YkFyQb_bbuRhe6D4yip43qfczxscv7GykboaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscham/v33/pe06MIySN5pO62Z5YkFyQb_bbuRhe6D4yip43qfc9hscv7GykboaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscham/v33/pe06MIySN5pO62Z5YkFyQb_bbuRhe6D4yip43qfckRscv7GykboaLg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscham/v33/pe06MIySN5pO62Z5YkFyQb_bbuRhe6D4yip43qfcuBscv7GykboaLg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-cherokee",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("75303c6d-a330-4de7-8972-adf65561fafb",1120423667),$APP.$cljs$cst$2675$family$$,"Noto Sans Cherokee",$APP.$cljs$cst$725$name$$,"Noto Sans Cherokee",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscherokee/v25/KFOPCm6Yu8uF-29fiz9vQF9YWK6Z8O10cHNA0cSkZCHYWi5ODkm5rAffjl0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscherokee/v25/KFOPCm6Yu8uF-29fiz9vQF9YWK6Z8O10cHNA0cSkZCHYWq5PDkm5rAffjl0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscherokee/v25/KFOPCm6Yu8uF-29fiz9vQF9YWK6Z8O10cHNA0cSkZCHYWnBPDkm5rAffjl0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscherokee/v25/KFOPCm6Yu8uF-29fiz9vQF9YWK6Z8O10cHNA0cSkZCHYWi5PDkm5rAffjl0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscherokee/v25/KFOPCm6Yu8uF-29fiz9vQF9YWK6Z8O10cHNA0cSkZCHYWhxPDkm5rAffjl0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscherokee/v25/KFOPCm6Yu8uF-29fiz9vQF9YWK6Z8O10cHNA0cSkZCHYWvBIDkm5rAffjl0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscherokee/v25/KFOPCm6Yu8uF-29fiz9vQF9YWK6Z8O10cHNA0cSkZCHYWslIDkm5rAffjl0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscherokee/v25/KFOPCm6Yu8uF-29fiz9vQF9YWK6Z8O10cHNA0cSkZCHYWq5IDkm5rAffjl0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscherokee/v25/KFOPCm6Yu8uF-29fiz9vQF9YWK6Z8O10cHNA0cSkZCHYWodIDkm5rAffjl0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-chorasmian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("aaf3abc7-9ced-4c82-a4ab-063e25635ff6",-29917831),$APP.$cljs$cst$2675$family$$,"Noto Sans Chorasmian",$APP.$cljs$cst$725$name$$,"Noto Sans Chorasmian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanschorasmian/v3/MQpL-X6uKMC7ROPLwRnI9ULxK_7NVkf8S5vyoH7w4g9b.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-coptic",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("f1df1093-ca59-4232-a12f-6d90d9241a35",1546433335),$APP.$cljs$cst$2675$family$$,"Noto Sans Coptic",$APP.$cljs$cst$725$name$$,"Noto Sans Coptic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosanscoptic/v22/iJWfBWmUZi_OHPqn4wq6kgqumOEd78u_VG0xR4Y.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-cuneiform",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("50eec576-4d2a-4af0-8049-0ab821b639b3",2091883493),$APP.$cljs$cst$2675$family$$,"Noto Sans Cuneiform",$APP.$cljs$cst$725$name$$,"Noto Sans Cuneiform",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscuneiform/v18/bMrrmTWK7YY-MF22aHGGd7H8PhJtvBDWgb9JlRQueeQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-cypriot",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6f6de87f-e04d-41fc-b4fd-4582209c2f71",
2111918169),$APP.$cljs$cst$2675$family$$,"Noto Sans Cypriot",$APP.$cljs$cst$725$name$$,"Noto Sans Cypriot",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscypriot/v20/8AtzGta9PYqQDjyp79a6f8Cj-3a3cxIsK5MPpahF.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-cypro-minoan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5c7cefc2-107b-480b-a868-bbefe16a2eec",1595747257),$APP.$cljs$cst$2675$family$$,"Noto Sans Cypro Minoan",$APP.$cljs$cst$725$name$$,"Noto Sans Cypro Minoan",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanscyprominoan/v1/2Eb2L_dtDUlkNmPHB_UVtEzp3ZlPGqZ_4nAGq9eSf8_eQSE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-deseret",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("81b9e0f4-5fc8-4ddf-90c3-23b40619d4f7",867288587),$APP.$cljs$cst$2675$family$$,"Noto Sans Deseret",
$APP.$cljs$cst$725$name$$,"Noto Sans Deseret",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdeseret/v18/MwQsbgPp1eKH6QsAVuFb9AZM6MMr2Vq9ZnJSZtQG.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-devanagari",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c1a36d2f-222f-45de-90f9-8ef6e74d1dc7",1001947642),$APP.$cljs$cst$2675$family$$,"Noto Sans Devanagari",$APP.$cljs$cst$725$name$$,"Noto Sans Devanagari",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdevanagari/v30/TuGoUUFzXI5FBtUq5a8bjKYTZjtRU6Sgv3NaV_SNmI0b8QQCQmHn6B2OHjbL_08AlXQky-AzoFoW4Ow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdevanagari/v30/TuGoUUFzXI5FBtUq5a8bjKYTZjtRU6Sgv3NaV_SNmI0b8QQCQmHn6B2OHjbL_08AlfQly-AzoFoW4Ow.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdevanagari/v30/TuGoUUFzXI5FBtUq5a8bjKYTZjtRU6Sgv3NaV_SNmI0b8QQCQmHn6B2OHjbL_08AlSoly-AzoFoW4Ow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdevanagari/v30/TuGoUUFzXI5FBtUq5a8bjKYTZjtRU6Sgv3NaV_SNmI0b8QQCQmHn6B2OHjbL_08AlXQly-AzoFoW4Ow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdevanagari/v30/TuGoUUFzXI5FBtUq5a8bjKYTZjtRU6Sgv3NaV_SNmI0b8QQCQmHn6B2OHjbL_08AlUYly-AzoFoW4Ow.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdevanagari/v30/TuGoUUFzXI5FBtUq5a8bjKYTZjtRU6Sgv3NaV_SNmI0b8QQCQmHn6B2OHjbL_08Alaoiy-AzoFoW4Ow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdevanagari/v30/TuGoUUFzXI5FBtUq5a8bjKYTZjtRU6Sgv3NaV_SNmI0b8QQCQmHn6B2OHjbL_08AlZMiy-AzoFoW4Ow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdevanagari/v30/TuGoUUFzXI5FBtUq5a8bjKYTZjtRU6Sgv3NaV_SNmI0b8QQCQmHn6B2OHjbL_08AlfQiy-AzoFoW4Ow.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdevanagari/v30/TuGoUUFzXI5FBtUq5a8bjKYTZjtRU6Sgv3NaV_SNmI0b8QQCQmHn6B2OHjbL_08Ald0iy-AzoFoW4Ow.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8195305b-3ecb-483d-8240-3b167f71e0a9",
2104272712),$APP.$cljs$cst$2675$family$$,"Noto Sans Display",$APP.$cljs$cst$725$name$$,"Noto Sans Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpbK4fy6r6tOBEJg0IAKzqdFZVZxpMkXJMhnB9XjO1o90LuV-PT4Doq_AKp_3cLVTGQ2iHrvWM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpbK4fy6r6tOBEJg0IAKzqdFZVZxpMkXJMhnB9XjO1o90LuV-PT4Doq_AKp__cKVTGQ2iHrvWM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpbK4fy6r6tOBEJg0IAKzqdFZVZxpMkXJMhnB9XjO1o90LuV-PT4Doq_AKp_ykKVTGQ2iHrvWM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpbK4fy6r6tOBEJg0IAKzqdFZVZxpMkXJMhnB9XjO1o90LuV-PT4Doq_AKp_3cKVTGQ2iHrvWM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpbK4fy6r6tOBEJg0IAKzqdFZVZxpMkXJMhnB9XjO1o90LuV-PT4Doq_AKp_0UKVTGQ2iHrvWM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpbK4fy6r6tOBEJg0IAKzqdFZVZxpMkXJMhnB9XjO1o90LuV-PT4Doq_AKp_6kNVTGQ2iHrvWM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpbK4fy6r6tOBEJg0IAKzqdFZVZxpMkXJMhnB9XjO1o90LuV-PT4Doq_AKp_5ANVTGQ2iHrvWM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpbK4fy6r6tOBEJg0IAKzqdFZVZxpMkXJMhnB9XjO1o90LuV-PT4Doq_AKp__cNVTGQ2iHrvWM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpbK4fy6r6tOBEJg0IAKzqdFZVZxpMkXJMhnB9XjO1o90LuV-PT4Doq_AKp_94NVTGQ2iHrvWM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpZK4fy6r6tOBEJg0IAKzqdFZVZxrktbnDB5UzBIup9PwAcHtEsOFNBZqyu6r9JvXOa3gPurWM9uQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpZK4fy6r6tOBEJg0IAKzqdFZVZxrktbnDB5UzBIup9PwAcHtEsOFNBZqyu6r9JPXKa3gPurWM9uQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpZK4fy6r6tOBEJg0IAKzqdFZVZxrktbnDB5UzBIup9PwAcHtEsOFNBZqyu6r9J43Ka3gPurWM9uQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpZK4fy6r6tOBEJg0IAKzqdFZVZxrktbnDB5UzBIup9PwAcHtEsOFNBZqyu6r9JvXKa3gPurWM9uQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpZK4fy6r6tOBEJg0IAKzqdFZVZxrktbnDB5UzBIup9PwAcHtEsOFNBZqyu6r9Jj3Ka3gPurWM9uQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpZK4fy6r6tOBEJg0IAKzqdFZVZxrktbnDB5UzBIup9PwAcHtEsOFNBZqyu6r9JY3Wa3gPurWM9uQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpZK4fy6r6tOBEJg0IAKzqdFZVZxrktbnDB5UzBIup9PwAcHtEsOFNBZqyu6r9JWnWa3gPurWM9uQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpZK4fy6r6tOBEJg0IAKzqdFZVZxrktbnDB5UzBIup9PwAcHtEsOFNBZqyu6r9JPXWa3gPurWM9uQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,
"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansdisplay/v30/RLpZK4fy6r6tOBEJg0IAKzqdFZVZxrktbnDB5UzBIup9PwAcHtEsOFNBZqyu6r9JFHWa3gPurWM9uQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-duployan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b6ab7bbd-2286-425a-b47e-043a798a8ec6",-977450285),$APP.$cljs$cst$2675$family$$,"Noto Sans Duployan",$APP.$cljs$cst$725$name$$,"Noto Sans Duployan",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansduployan/v19/gokzH7nwAEdtF9N8-mdTDx_X9JM5wsvrFsIn6WYDvA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansduployan/v19/gokwH7nwAEdtF9N8-mdTDx_X9JM5wsvTqu0D4U0ftZS-Iw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-egyptian-hieroglyphs",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bed1f887-3a92-4e0d-863c-497e974f7242",-91174948),$APP.$cljs$cst$2675$family$$,"Noto Sans Egyptian Hieroglyphs",
$APP.$cljs$cst$725$name$$,"Noto Sans Egyptian Hieroglyphs",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansegyptianhieroglyphs/v30/vEF42-tODB8RrNDvZSUmRhcQHzx1s7y_F9-j3qSzEcbEYindSVK8xRg7iw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-elbasan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("60e43b43-82e7-401e-b6f9-d3b28fd04562",1081063910),$APP.$cljs$cst$2675$family$$,"Noto Sans Elbasan",$APP.$cljs$cst$725$name$$,"Noto Sans Elbasan",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanselbasan/v17/-F6rfiZqLzI2JPCgQBnw400qp1trvHdlre4dFcFh.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-elymaic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7b26f355-271a-4d38-a34f-e8cae700bd7d",2000169324),$APP.$cljs$cst$2675$family$$,"Noto Sans Elymaic",$APP.$cljs$cst$725$name$$,
"Noto Sans Elymaic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanselymaic/v18/UqyKK9YTJW5liNMhTMqe9vUFP65ZD4AjWOT0zi2V.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-ethiopic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("93e66fef-c80d-46f2-be0f-b265518d1b1d",-322614589),$APP.$cljs$cst$2675$family$$,"Noto Sans Ethiopic",$APP.$cljs$cst$725$name$$,"Noto Sans Ethiopic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansethiopic/v50/7cHPv50vjIepfJVOZZgcpQ5B9FBTH9KGNfhSTgtoow1KVnIvyBoMSzUMacb-T35OKqDjwmfeaY9u.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansethiopic/v50/7cHPv50vjIepfJVOZZgcpQ5B9FBTH9KGNfhSTgtoow1KVnIvyBoMSzUMacb-T37OK6DjwmfeaY9u.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansethiopic/v50/7cHPv50vjIepfJVOZZgcpQ5B9FBTH9KGNfhSTgtoow1KVnIvyBoMSzUMacb-T34QK6DjwmfeaY9u.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansethiopic/v50/7cHPv50vjIepfJVOZZgcpQ5B9FBTH9KGNfhSTgtoow1KVnIvyBoMSzUMacb-T35OK6DjwmfeaY9u.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansethiopic/v50/7cHPv50vjIepfJVOZZgcpQ5B9FBTH9KGNfhSTgtoow1KVnIvyBoMSzUMacb-T358K6DjwmfeaY9u.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansethiopic/v50/7cHPv50vjIepfJVOZZgcpQ5B9FBTH9KGNfhSTgtoow1KVnIvyBoMSzUMacb-T36QLKDjwmfeaY9u.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansethiopic/v50/7cHPv50vjIepfJVOZZgcpQ5B9FBTH9KGNfhSTgtoow1KVnIvyBoMSzUMacb-T36pLKDjwmfeaY9u.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansethiopic/v50/7cHPv50vjIepfJVOZZgcpQ5B9FBTH9KGNfhSTgtoow1KVnIvyBoMSzUMacb-T37OLKDjwmfeaY9u.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansethiopic/v50/7cHPv50vjIepfJVOZZgcpQ5B9FBTH9KGNfhSTgtoow1KVnIvyBoMSzUMacb-T37nLKDjwmfeaY9u.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-georgian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e98e8d62-3405-46ec-b29c-1fadf5413363",
756784232),$APP.$cljs$cst$2675$family$$,"Noto Sans Georgian",$APP.$cljs$cst$725$name$$,"Noto Sans Georgian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgeorgian/v48/PlIaFke5O6RzLfvNNVSitxkr76PRHBC4Ytyq-Gof7PUs4S7zWn-8YDB09HFNdpvnzVj-f5WK0OQV.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgeorgian/v48/PlIaFke5O6RzLfvNNVSitxkr76PRHBC4Ytyq-Gof7PUs4S7zWn-8YDB09HFNdptnzFj-f5WK0OQV.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgeorgian/v48/PlIaFke5O6RzLfvNNVSitxkr76PRHBC4Ytyq-Gof7PUs4S7zWn-8YDB09HFNdpu5zFj-f5WK0OQV.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgeorgian/v48/PlIaFke5O6RzLfvNNVSitxkr76PRHBC4Ytyq-Gof7PUs4S7zWn-8YDB09HFNdpvnzFj-f5WK0OQV.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgeorgian/v48/PlIaFke5O6RzLfvNNVSitxkr76PRHBC4Ytyq-Gof7PUs4S7zWn-8YDB09HFNdpvVzFj-f5WK0OQV.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgeorgian/v48/PlIaFke5O6RzLfvNNVSitxkr76PRHBC4Ytyq-Gof7PUs4S7zWn-8YDB09HFNdps5y1j-f5WK0OQV.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgeorgian/v48/PlIaFke5O6RzLfvNNVSitxkr76PRHBC4Ytyq-Gof7PUs4S7zWn-8YDB09HFNdpsAy1j-f5WK0OQV.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgeorgian/v48/PlIaFke5O6RzLfvNNVSitxkr76PRHBC4Ytyq-Gof7PUs4S7zWn-8YDB09HFNdptny1j-f5WK0OQV.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgeorgian/v48/PlIaFke5O6RzLfvNNVSitxkr76PRHBC4Ytyq-Gof7PUs4S7zWn-8YDB09HFNdptOy1j-f5WK0OQV.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-glagolitic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4966fbd1-1844-4a37-ba23-dae947c36763",-1277157186),$APP.$cljs$cst$2675$family$$,"Noto Sans Glagolitic",$APP.$cljs$cst$725$name$$,"Noto Sans Glagolitic",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansglagolitic/v19/1q2ZY4-BBFBst88SU_tOj4J-4yuNF_HI4ERK4Amu7nM1.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-noto-sans-gothic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1eb6f65f-9b36-4cbc-bf16-17b7974f9417",-7953838),$APP.$cljs$cst$2675$family$$,"Noto Sans Gothic",$APP.$cljs$cst$725$name$$,"Noto Sans Gothic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgothic/v17/TuGKUUVzXI5FBtUq5a8bj6wRbzxTFMX40kFQRx0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-grantha",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8a38c99e-c4a4-4843-a04d-4378f3a0907b",-1356691159),$APP.$cljs$cst$2675$family$$,"Noto Sans Grantha",$APP.$cljs$cst$725$name$$,"Noto Sans Grantha",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgrantha/v20/3y976akwcCjmsU8NDyrKo3IQfQ4o-r8cFeulHc6N.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-gujarati",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5f017cd2-a3ba-46c2-9bb0-de1c60eee37a",
1430696634),$APP.$cljs$cst$2675$family$$,"Noto Sans Gujarati",$APP.$cljs$cst$725$name$$,"Noto Sans Gujarati",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgujarati/v27/wlpWgx_HC1ti5ViekvcxnhMlCVo3f5pv17ivlzsUB14gg1TMR2Gw4VceEl7MA_ypFgPM_OdiEH0s.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgujarati/v27/wlpWgx_HC1ti5ViekvcxnhMlCVo3f5pv17ivlzsUB14gg1TMR2Gw4VceEl7MA_wpFwPM_OdiEH0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgujarati/v27/wlpWgx_HC1ti5ViekvcxnhMlCVo3f5pv17ivlzsUB14gg1TMR2Gw4VceEl7MA_z3FwPM_OdiEH0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgujarati/v27/wlpWgx_HC1ti5ViekvcxnhMlCVo3f5pv17ivlzsUB14gg1TMR2Gw4VceEl7MA_ypFwPM_OdiEH0s.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgujarati/v27/wlpWgx_HC1ti5ViekvcxnhMlCVo3f5pv17ivlzsUB14gg1TMR2Gw4VceEl7MA_ybFwPM_OdiEH0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgujarati/v27/wlpWgx_HC1ti5ViekvcxnhMlCVo3f5pv17ivlzsUB14gg1TMR2Gw4VceEl7MA_x3EAPM_OdiEH0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgujarati/v27/wlpWgx_HC1ti5ViekvcxnhMlCVo3f5pv17ivlzsUB14gg1TMR2Gw4VceEl7MA_xOEAPM_OdiEH0s.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgujarati/v27/wlpWgx_HC1ti5ViekvcxnhMlCVo3f5pv17ivlzsUB14gg1TMR2Gw4VceEl7MA_wpEAPM_OdiEH0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgujarati/v27/wlpWgx_HC1ti5ViekvcxnhMlCVo3f5pv17ivlzsUB14gg1TMR2Gw4VceEl7MA_wAEAPM_OdiEH0s.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-gunjala-gondi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b93c98d8-84c3-4ff3-8f9c-3bf8a6bdf3d7",-1612035172),$APP.$cljs$cst$2675$family$$,"Noto Sans Gunjala Gondi",$APP.$cljs$cst$725$name$$,"Noto Sans Gunjala Gondi",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgunjalagondi/v21/bWtX7e7KfBziStx7lIzKPrcSMwcEnCv6DW7n5g0ef3PLtymzNxYL4YDE4J4vCTxEJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgunjalagondi/v21/bWtX7e7KfBziStx7lIzKPrcSMwcEnCv6DW7n5g0ef3PLtymzNxYL04DE4J4vCTxEJQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgunjalagondi/v21/bWtX7e7KfBziStx7lIzKPrcSMwcEnCv6DW7n5g0ef3PLtymzNxYLP4fE4J4vCTxEJQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgunjalagondi/v21/bWtX7e7KfBziStx7lIzKPrcSMwcEnCv6DW7n5g0ef3PLtymzNxYLBofE4J4vCTxEJQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-gurmukhi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("62ac1394-4727-4d6a-875b-1200fdda581b",
-341801689),$APP.$cljs$cst$2675$family$$,"Noto Sans Gurmukhi",$APP.$cljs$cst$725$name$$,"Noto Sans Gurmukhi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgurmukhi/v29/w8g9H3EvQP81sInb43inmyN9zZ7hb7ATbSWo4q8dJ74a3cVrYFQ_bogT0-gPeG1Oe3bxZ_trdp7h.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgurmukhi/v29/w8g9H3EvQP81sInb43inmyN9zZ7hb7ATbSWo4q8dJ74a3cVrYFQ_bogT0-gPeG3OenbxZ_trdp7h.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgurmukhi/v29/w8g9H3EvQP81sInb43inmyN9zZ7hb7ATbSWo4q8dJ74a3cVrYFQ_bogT0-gPeG0QenbxZ_trdp7h.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgurmukhi/v29/w8g9H3EvQP81sInb43inmyN9zZ7hb7ATbSWo4q8dJ74a3cVrYFQ_bogT0-gPeG1OenbxZ_trdp7h.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgurmukhi/v29/w8g9H3EvQP81sInb43inmyN9zZ7hb7ATbSWo4q8dJ74a3cVrYFQ_bogT0-gPeG18enbxZ_trdp7h.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgurmukhi/v29/w8g9H3EvQP81sInb43inmyN9zZ7hb7ATbSWo4q8dJ74a3cVrYFQ_bogT0-gPeG2QfXbxZ_trdp7h.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgurmukhi/v29/w8g9H3EvQP81sInb43inmyN9zZ7hb7ATbSWo4q8dJ74a3cVrYFQ_bogT0-gPeG2pfXbxZ_trdp7h.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgurmukhi/v29/w8g9H3EvQP81sInb43inmyN9zZ7hb7ATbSWo4q8dJ74a3cVrYFQ_bogT0-gPeG3OfXbxZ_trdp7h.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansgurmukhi/v29/w8g9H3EvQP81sInb43inmyN9zZ7hb7ATbSWo4q8dJ74a3cVrYFQ_bogT0-gPeG3nfXbxZ_trdp7h.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-hk",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("abce1312-2ba8-41f8-a4b0-0d18ea145f39",-1578978335),$APP.$cljs$cst$2675$family$$,"Noto Sans HK",$APP.$cljs$cst$725$name$$,"Noto Sans HK",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshk/v34/nKKF-GM_FYFRJvXzVXaAPe97P1KHynJFP716qHB_-oWTiYjNvVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshk/v34/nKKF-GM_FYFRJvXzVXaAPe97P1KHynJFP716qPB--oWTiYjNvVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshk/v34/nKKF-GM_FYFRJvXzVXaAPe97P1KHynJFP716qC5--oWTiYjNvVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshk/v34/nKKF-GM_FYFRJvXzVXaAPe97P1KHynJFP716qHB--oWTiYjNvVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshk/v34/nKKF-GM_FYFRJvXzVXaAPe97P1KHynJFP716qEJ--oWTiYjNvVA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshk/v34/nKKF-GM_FYFRJvXzVXaAPe97P1KHynJFP716qK55-oWTiYjNvVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshk/v34/nKKF-GM_FYFRJvXzVXaAPe97P1KHynJFP716qJd5-oWTiYjNvVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshk/v34/nKKF-GM_FYFRJvXzVXaAPe97P1KHynJFP716qPB5-oWTiYjNvVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshk/v34/nKKF-GM_FYFRJvXzVXaAPe97P1KHynJFP716qNl5-oWTiYjNvVA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-hanifi-rohingya",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("51e89edc-0f0b-4e7e-bdff-76a41acc61c0",25669615),$APP.$cljs$cst$2675$family$$,"Noto Sans Hanifi Rohingya",
$APP.$cljs$cst$725$name$$,"Noto Sans Hanifi Rohingya",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshanifirohingya/v30/5h17iYsoOmIC3Yu3MDXLDw3UZCgghyOEBBY7hhLNyo3tiaiuSIAqrIYY4j6vvcudK8rN.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshanifirohingya/v30/5h17iYsoOmIC3Yu3MDXLDw3UZCgghyOEBBY7hhLNyo3tiaiuSIAqrIYq4j6vvcudK8rN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshanifirohingya/v30/5h17iYsoOmIC3Yu3MDXLDw3UZCgghyOEBBY7hhLNyo3tiaiuSIAqrIbG5T6vvcudK8rN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshanifirohingya/v30/5h17iYsoOmIC3Yu3MDXLDw3UZCgghyOEBBY7hhLNyo3tiaiuSIAqrIb_5T6vvcudK8rN.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-hanunoo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e9574b4f-02a9-497b-87cb-dfe48e836d51",-245917969),$APP.$cljs$cst$2675$family$$,"Noto Sans Hanunoo",$APP.$cljs$cst$725$name$$,"Noto Sans Hanunoo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshanunoo/v22/f0Xs0fCv8dxkDWlZSoXOj6CphMloFsEsEpgL_ix2.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-hatran",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1bb2f11c-d812-4a2a-82e9-70aa6171368d",-1994670470),$APP.$cljs$cst$2675$family$$,"Noto Sans Hatran",$APP.$cljs$cst$725$name$$,
"Noto Sans Hatran",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshatran/v17/A2BBn4Ne0RgnVF3Lnko-0sOBIfL_mM83r1nwzDs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-hebrew",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6150cf91-241f-43a8-b8a0-9543a38a728b",-1235994451),$APP.$cljs$cst$2675$family$$,"Noto Sans Hebrew",$APP.$cljs$cst$725$name$$,"Noto Sans Hebrew",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshebrew/v50/or3HQ7v33eiDljA1IufXTtVf7V6RvEEdhQlk0LlGxCyaeNKYZC0sqk3xXGiXd4utoiJltutR2g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshebrew/v50/or3HQ7v33eiDljA1IufXTtVf7V6RvEEdhQlk0LlGxCyaeNKYZC0sqk3xXGiX94qtoiJltutR2g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshebrew/v50/or3HQ7v33eiDljA1IufXTtVf7V6RvEEdhQlk0LlGxCyaeNKYZC0sqk3xXGiXKYqtoiJltutR2g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshebrew/v50/or3HQ7v33eiDljA1IufXTtVf7V6RvEEdhQlk0LlGxCyaeNKYZC0sqk3xXGiXd4qtoiJltutR2g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshebrew/v50/or3HQ7v33eiDljA1IufXTtVf7V6RvEEdhQlk0LlGxCyaeNKYZC0sqk3xXGiXRYqtoiJltutR2g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshebrew/v50/or3HQ7v33eiDljA1IufXTtVf7V6RvEEdhQlk0LlGxCyaeNKYZC0sqk3xXGiXqY2toiJltutR2g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshebrew/v50/or3HQ7v33eiDljA1IufXTtVf7V6RvEEdhQlk0LlGxCyaeNKYZC0sqk3xXGiXkI2toiJltutR2g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshebrew/v50/or3HQ7v33eiDljA1IufXTtVf7V6RvEEdhQlk0LlGxCyaeNKYZC0sqk3xXGiX942toiJltutR2g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanshebrew/v50/or3HQ7v33eiDljA1IufXTtVf7V6RvEEdhQlk0LlGxCyaeNKYZC0sqk3xXGiX3o2toiJltutR2g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-imperial-aramaic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("abd7660d-ddaf-400c-80bc-6cf159c164a1",
-108815768),$APP.$cljs$cst$2675$family$$,"Noto Sans Imperial Aramaic",$APP.$cljs$cst$725$name$$,"Noto Sans Imperial Aramaic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansimperialaramaic/v18/a8IMNpjwKmHXpgXbMIsbTc_kvks91LlLetBr5itQrtdml3YfPNno.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-indic-siyaq-numbers",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0670ccbc-f1fa-4cb5-bd01-6a57bbd5c9d2",-827900431),$APP.$cljs$cst$2675$family$$,"Noto Sans Indic Siyaq Numbers",$APP.$cljs$cst$725$name$$,"Noto Sans Indic Siyaq Numbers",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansindicsiyaqnumbers/v17/6xK5dTJFKcWIu4bpRBjRZRpsIYHabOeZ8UZLubTzpXNHKx2WPOpVd5Iu.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-inscriptional-pahlavi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bba8047f-67fe-42f2-957d-086e6b636944",
1747326574),$APP.$cljs$cst$2675$family$$,"Noto Sans Inscriptional Pahlavi",$APP.$cljs$cst$725$name$$,"Noto Sans Inscriptional Pahlavi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansinscriptionalpahlavi/v18/ll8UK3GaVDuxR-TEqFPIbsR79Xxz9WEKbwsjpz7VklYlC7FCVtqVOAYK0QA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-inscriptional-parthian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("60a0a3da-21f7-425e-862d-7b3afb86ccea",1807950592),$APP.$cljs$cst$2675$family$$,"Noto Sans Inscriptional Parthian",$APP.$cljs$cst$725$name$$,"Noto Sans Inscriptional Parthian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansinscriptionalparthian/v18/k3k7o-IMPvpLmixcA63oYi-yStDkgXuXncL7dzfW3P4TAJ2yklBJ2jNkLlLr.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-jp",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e81854c1-b5a2-4425-9f6d-18af6c9924d9",769332267),
$APP.$cljs$cst$2675$family$$,"Noto Sans JP",$APP.$cljs$cst$725$name$$,"Noto Sans JP",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansjp/v55/-F6jfjtqLzI2JPCgQBnw7HFyzSD-AsregP8VFBEi75vY0rw-oME.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansjp/v55/-F6jfjtqLzI2JPCgQBnw7HFyzSD-AsregP8VFJEj75vY0rw-oME.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansjp/v55/-F6jfjtqLzI2JPCgQBnw7HFyzSD-AsregP8VFE8j75vY0rw-oME.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansjp/v55/-F6jfjtqLzI2JPCgQBnw7HFyzSD-AsregP8VFBEj75vY0rw-oME.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansjp/v55/-F6jfjtqLzI2JPCgQBnw7HFyzSD-AsregP8VFCMj75vY0rw-oME.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansjp/v55/-F6jfjtqLzI2JPCgQBnw7HFyzSD-AsregP8VFM8k75vY0rw-oME.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansjp/v55/-F6jfjtqLzI2JPCgQBnw7HFyzSD-AsregP8VFPYk75vY0rw-oME.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansjp/v55/-F6jfjtqLzI2JPCgQBnw7HFyzSD-AsregP8VFJEk75vY0rw-oME.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansjp/v55/-F6jfjtqLzI2JPCgQBnw7HFyzSD-AsregP8VFLgk75vY0rw-oME.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-javanese",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d231a162-ac3f-436a-a4a6-61fdece8af7e",-1478937073),$APP.$cljs$cst$2675$family$$,"Noto Sans Javanese",$APP.$cljs$cst$725$name$$,"Noto Sans Javanese",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansjavanese/v25/2V01KJkDAIA6Hp4zoSScDjV0Y-eoHAHT-Z3MngEefiidxJnkFFliZYWj4O8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansjavanese/v25/2V01KJkDAIA6Hp4zoSScDjV0Y-eoHAHT-Z3MngEefiidxKvkFFliZYWj4O8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansjavanese/v25/2V01KJkDAIA6Hp4zoSScDjV0Y-eoHAHT-Z3MngEefiidxEfjFFliZYWj4O8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansjavanese/v25/2V01KJkDAIA6Hp4zoSScDjV0Y-eoHAHT-Z3MngEefiidxH7jFFliZYWj4O8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-kr",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("12dbc20e-b78a-4833-8e23-ba2e0d9cd829",1040053187),$APP.$cljs$cst$2675$family$$,"Noto Sans KR",$APP.$cljs$cst$725$name$$,"Noto Sans KR",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskr/v38/PbyxFmXiEBPT4ITbgNA5Cgms3VYcOA-vvnIzzuozeLTq8H4hfeE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskr/v38/PbyxFmXiEBPT4ITbgNA5Cgms3VYcOA-vvnIzzmoyeLTq8H4hfeE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskr/v38/PbyxFmXiEBPT4ITbgNA5Cgms3VYcOA-vvnIzzrQyeLTq8H4hfeE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskr/v38/PbyxFmXiEBPT4ITbgNA5Cgms3VYcOA-vvnIzzuoyeLTq8H4hfeE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskr/v38/PbyxFmXiEBPT4ITbgNA5Cgms3VYcOA-vvnIzztgyeLTq8H4hfeE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskr/v38/PbyxFmXiEBPT4ITbgNA5Cgms3VYcOA-vvnIzzjQ1eLTq8H4hfeE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskr/v38/PbyxFmXiEBPT4ITbgNA5Cgms3VYcOA-vvnIzzg01eLTq8H4hfeE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskr/v38/PbyxFmXiEBPT4ITbgNA5Cgms3VYcOA-vvnIzzmo1eLTq8H4hfeE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskr/v38/PbyxFmXiEBPT4ITbgNA5Cgms3VYcOA-vvnIzzkM1eLTq8H4hfeE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-kaithi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a30c9f5c-cb5f-4e52-95a3-f3658320c62d",1435589728),$APP.$cljs$cst$2675$family$$,"Noto Sans Kaithi",$APP.$cljs$cst$725$name$$,
"Noto Sans Kaithi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskaithi/v23/buEtppS9f8_vkXadMBJJu0tWjLwjQi0KdoZIKlo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-kannada",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0267bb35-5086-4a94-9078-439ce232814e",302822482),$APP.$cljs$cst$2675$family$$,"Noto Sans Kannada",$APP.$cljs$cst$725$name$$,"Noto Sans Kannada",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskannada/v31/8vIs7xs32H97qzQKnzfeXycxXZyUmySvZWItmf1fe6TVmgop9ndpS-BqHEyGrDvMzSIMLsPKrkY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskannada/v31/8vIs7xs32H97qzQKnzfeXycxXZyUmySvZWItmf1fe6TVmgop9ndpS-BqHEyGrLvNzSIMLsPKrkY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskannada/v31/8vIs7xs32H97qzQKnzfeXycxXZyUmySvZWItmf1fe6TVmgop9ndpS-BqHEyGrGXNzSIMLsPKrkY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskannada/v31/8vIs7xs32H97qzQKnzfeXycxXZyUmySvZWItmf1fe6TVmgop9ndpS-BqHEyGrDvNzSIMLsPKrkY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskannada/v31/8vIs7xs32H97qzQKnzfeXycxXZyUmySvZWItmf1fe6TVmgop9ndpS-BqHEyGrAnNzSIMLsPKrkY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskannada/v31/8vIs7xs32H97qzQKnzfeXycxXZyUmySvZWItmf1fe6TVmgop9ndpS-BqHEyGrOXKzSIMLsPKrkY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskannada/v31/8vIs7xs32H97qzQKnzfeXycxXZyUmySvZWItmf1fe6TVmgop9ndpS-BqHEyGrNzKzSIMLsPKrkY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskannada/v31/8vIs7xs32H97qzQKnzfeXycxXZyUmySvZWItmf1fe6TVmgop9ndpS-BqHEyGrLvKzSIMLsPKrkY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskannada/v31/8vIs7xs32H97qzQKnzfeXycxXZyUmySvZWItmf1fe6TVmgop9ndpS-BqHEyGrJLKzSIMLsPKrkY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-kawi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("909e7636-ed1e-4904-98e5-6739a45fb385",
1995363977),$APP.$cljs$cst$2675$family$$,"Noto Sans Kawi",$APP.$cljs$cst$725$name$$,"Noto Sans Kawi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskawi/v5/92zBtBJLNqsg7tCciW0EPHNNh1ZgbtGWiTYDjvnK4AhmCpRyMjXVsQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskawi/v5/92zBtBJLNqsg7tCciW0EPHNNh1ZgbtGWiTYDjvnK0ghmCpRyMjXVsQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskawi/v5/92zBtBJLNqsg7tCciW0EPHNNh1ZgbtGWiTYDjvnKPg9mCpRyMjXVsQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskawi/v5/92zBtBJLNqsg7tCciW0EPHNNh1ZgbtGWiTYDjvnKBw9mCpRyMjXVsQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-kayah-li",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fac56117-39e4-4cea-92d0-f95311ee4350",-654200978),$APP.$cljs$cst$2675$family$$,"Noto Sans Kayah Li",$APP.$cljs$cst$725$name$$,"Noto Sans Kayah Li",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskayahli/v26/B50nF61OpWTRcGrhOVJJwOMXdca6Yecki3E06x2jVTX3WCc3CZH4EXLuKVM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskayahli/v26/B50nF61OpWTRcGrhOVJJwOMXdca6Yecki3E06x2jVTX3WBU3CZH4EXLuKVM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskayahli/v26/B50nF61OpWTRcGrhOVJJwOMXdca6Yecki3E06x2jVTX3WPkwCZH4EXLuKVM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskayahli/v26/B50nF61OpWTRcGrhOVJJwOMXdca6Yecki3E06x2jVTX3WMAwCZH4EXLuKVM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-kharoshthi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e8e16884-9550-44fd-b34c-24b916d52fd7",-1704922236),$APP.$cljs$cst$2675$family$$,"Noto Sans Kharoshthi",$APP.$cljs$cst$725$name$$,"Noto Sans Kharoshthi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskharoshthi/v17/Fh4qPiLjKS30-P4-pGMMXCCfvkc5Vd7KE5z4rFyx5mR1.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-khmer",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("ab8a1abf-0b47-4eea-965a-a63e7c29c1f7",-1074978085),$APP.$cljs$cst$2675$family$$,"Noto Sans Khmer",$APP.$cljs$cst$725$name$$,"Noto Sans Khmer",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskhmer/v29/ijw3s5roRME5LLRxjsRb-gssOenAyendxrgV2c-Zw-9vbVUti_Z_dWgtWYuNAZz4kAbrddiA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskhmer/v29/ijw3s5roRME5LLRxjsRb-gssOenAyendxrgV2c-Zw-9vbVUti_Z_dWgtWYsNAJz4kAbrddiA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskhmer/v29/ijw3s5roRME5LLRxjsRb-gssOenAyendxrgV2c-Zw-9vbVUti_Z_dWgtWYvTAJz4kAbrddiA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskhmer/v29/ijw3s5roRME5LLRxjsRb-gssOenAyendxrgV2c-Zw-9vbVUti_Z_dWgtWYuNAJz4kAbrddiA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskhmer/v29/ijw3s5roRME5LLRxjsRb-gssOenAyendxrgV2c-Zw-9vbVUti_Z_dWgtWYu_AJz4kAbrddiA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskhmer/v29/ijw3s5roRME5LLRxjsRb-gssOenAyendxrgV2c-Zw-9vbVUti_Z_dWgtWYtTB5z4kAbrddiA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskhmer/v29/ijw3s5roRME5LLRxjsRb-gssOenAyendxrgV2c-Zw-9vbVUti_Z_dWgtWYtqB5z4kAbrddiA.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskhmer/v29/ijw3s5roRME5LLRxjsRb-gssOenAyendxrgV2c-Zw-9vbVUti_Z_dWgtWYsNB5z4kAbrddiA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskhmer/v29/ijw3s5roRME5LLRxjsRb-gssOenAyendxrgV2c-Zw-9vbVUti_Z_dWgtWYskB5z4kAbrddiA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-khojki",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a2a3867a-9fac-45cd-a14d-5753441f609c",-588388281),$APP.$cljs$cst$2675$family$$,"Noto Sans Khojki",$APP.$cljs$cst$725$name$$,"Noto Sans Khojki",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskhojki/v20/-nFnOHM29Oofr2wohFbTuPPKVWpmK_d709jy92k.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-khudawadi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6d1636b6-8f8d-4959-9d37-f5af44dec583",
-1739283278),$APP.$cljs$cst$2675$family$$,"Noto Sans Khudawadi",$APP.$cljs$cst$725$name$$,"Noto Sans Khudawadi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanskhudawadi/v23/fdNi9t6ZsWBZ2k5ltHN73zZ5hc8HANlHIjRnVVXz9MY.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-lao",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6a26fd82-d369-4029-8dbe-6b4e0132c17e",419376539),$APP.$cljs$cst$2675$family$$,"Noto Sans Lao",$APP.$cljs$cst$725$name$$,"Noto Sans Lao",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslao/v33/bx6lNx2Ol_ixgdYWLm9BwxM3NW6BOkuf763Clj73CiQ_J1Djx9pidOt4ccfdf5MK3riB2w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslao/v33/bx6lNx2Ol_ixgdYWLm9BwxM3NW6BOkuf763Clj73CiQ_J1Djx9pidOt48cbdf5MK3riB2w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslao/v33/bx6lNx2Ol_ixgdYWLm9BwxM3NW6BOkuf763Clj73CiQ_J1Djx9pidOt4L8bdf5MK3riB2w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslao/v33/bx6lNx2Ol_ixgdYWLm9BwxM3NW6BOkuf763Clj73CiQ_J1Djx9pidOt4ccbdf5MK3riB2w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslao/v33/bx6lNx2Ol_ixgdYWLm9BwxM3NW6BOkuf763Clj73CiQ_J1Djx9pidOt4Q8bdf5MK3riB2w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslao/v33/bx6lNx2Ol_ixgdYWLm9BwxM3NW6BOkuf763Clj73CiQ_J1Djx9pidOt4r8Hdf5MK3riB2w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslao/v33/bx6lNx2Ol_ixgdYWLm9BwxM3NW6BOkuf763Clj73CiQ_J1Djx9pidOt4lsHdf5MK3riB2w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslao/v33/bx6lNx2Ol_ixgdYWLm9BwxM3NW6BOkuf763Clj73CiQ_J1Djx9pidOt48cHdf5MK3riB2w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslao/v33/bx6lNx2Ol_ixgdYWLm9BwxM3NW6BOkuf763Clj73CiQ_J1Djx9pidOt42MHdf5MK3riB2w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-lao-looped",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7e9fa68c-dcd2-4ac1-a6a1-05dac86f0183",-1119276805),$APP.$cljs$cst$2675$family$$,"Noto Sans Lao Looped",$APP.$cljs$cst$725$name$$,"Noto Sans Lao Looped",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslaolooped/v10/a8IgNpbwKmHXpgXbMIsbSMP7-3U72qUOX5gBg6LRXExhqHIX9YPTpvqkW4UthhjomPr2M-Zw5V_T71k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslaolooped/v10/a8IgNpbwKmHXpgXbMIsbSMP7-3U72qUOX5gBg6LRXExhqHIX9YPTpvqkW4UthhjomHr3M-Zw5V_T71k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslaolooped/v10/a8IgNpbwKmHXpgXbMIsbSMP7-3U72qUOX5gBg6LRXExhqHIX9YPTpvqkW4UthhjomKT3M-Zw5V_T71k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslaolooped/v10/a8IgNpbwKmHXpgXbMIsbSMP7-3U72qUOX5gBg6LRXExhqHIX9YPTpvqkW4UthhjomPr3M-Zw5V_T71k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslaolooped/v10/a8IgNpbwKmHXpgXbMIsbSMP7-3U72qUOX5gBg6LRXExhqHIX9YPTpvqkW4UthhjomMj3M-Zw5V_T71k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslaolooped/v10/a8IgNpbwKmHXpgXbMIsbSMP7-3U72qUOX5gBg6LRXExhqHIX9YPTpvqkW4UthhjomCTwM-Zw5V_T71k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslaolooped/v10/a8IgNpbwKmHXpgXbMIsbSMP7-3U72qUOX5gBg6LRXExhqHIX9YPTpvqkW4UthhjomB3wM-Zw5V_T71k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslaolooped/v10/a8IgNpbwKmHXpgXbMIsbSMP7-3U72qUOX5gBg6LRXExhqHIX9YPTpvqkW4UthhjomHrwM-Zw5V_T71k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslaolooped/v10/a8IgNpbwKmHXpgXbMIsbSMP7-3U72qUOX5gBg6LRXExhqHIX9YPTpvqkW4UthhjomFPwM-Zw5V_T71k.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-lepcha",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c9762919-f725-4e0a-b145-fff833d0cd42",492209032),$APP.$cljs$cst$2675$family$$,"Noto Sans Lepcha",$APP.$cljs$cst$725$name$$,"Noto Sans Lepcha",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslepcha/v20/0QI7MWlB_JWgA166SKhu05TekNS32AJstqBXgd4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-limbu",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("14b4144f-66c8-41e9-ba60-b0a70ec1452a",-1838169012),$APP.$cljs$cst$2675$family$$,"Noto Sans Limbu",$APP.$cljs$cst$725$name$$,
"Noto Sans Limbu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslimbu/v26/3JnlSDv90Gmq2mrzckOBBRRoNJVj0MF3OHRDnA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-linear-a",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4ef0ba6c-cf6a-4be6-b0e7-1edd825d73f5",440184104),$APP.$cljs$cst$2675$family$$,"Noto Sans Linear A",$APP.$cljs$cst$725$name$$,"Noto Sans Linear A",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslineara/v19/oPWS_l16kP4jCuhpgEGmwJOiA18FZj22zmHQAGQicw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-linear-b",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ead9bbb2-5ceb-4252-83af-460f16207b54",1159958137),$APP.$cljs$cst$2675$family$$,"Noto Sans Linear B",$APP.$cljs$cst$725$name$$,"Noto Sans Linear B",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslinearb/v18/HhyJU4wt9vSgfHoORYOiXOckKNB737IV3BkFTq4EPw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-lisu",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c55c7add-622a-41c7-9849-f205b0e74278",857188234),$APP.$cljs$cst$2675$family$$,"Noto Sans Lisu",$APP.$cljs$cst$725$name$$,"Noto Sans Lisu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosanslisu/v27/uk-3EGO3o6EruUbnwovcYhz6kh57_nqbcTdjJnHP2Vwt29IlxkVdig.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslisu/v27/uk-3EGO3o6EruUbnwovcYhz6kh57_nqbcTdjJnHP61wt29IlxkVdig.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslisu/v27/uk-3EGO3o6EruUbnwovcYhz6kh57_nqbcTdjJnHPB1st29IlxkVdig.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslisu/v27/uk-3EGO3o6EruUbnwovcYhz6kh57_nqbcTdjJnHPPlst29IlxkVdig.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-lycian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("208b1da9-04c1-4cd6-92cc-364dc15775c7",329878722),$APP.$cljs$cst$2675$family$$,"Noto Sans Lycian",$APP.$cljs$cst$725$name$$,"Noto Sans Lycian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslycian/v16/QldVNSNMqAsHtsJ7UmqxBQA9r8wA5_naCJwn00E.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-lydian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("aafdd804-6e57-46b6-9e8b-3e5edd1d1fcc",-658850419),$APP.$cljs$cst$2675$family$$,"Noto Sans Lydian",$APP.$cljs$cst$725$name$$,
"Noto Sans Lydian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanslydian/v19/c4m71mVzGN7s8FmIukZJ1v4ZlcPReUPXMoIjEQI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-mahajani",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b9ce95fa-4113-4ffe-8e61-1d409a90a5a6",1600687595),$APP.$cljs$cst$2675$family$$,"Noto Sans Mahajani",$APP.$cljs$cst$725$name$$,"Noto Sans Mahajani",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmahajani/v20/-F6sfiVqLzI2JPCgQBnw60Agp0JrvD5Fh8ARHNh4zg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-malayalam",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9781ec3c-99ea-4619-b1c8-2d8d59ff219a",95588757),$APP.$cljs$cst$2675$family$$,"Noto Sans Malayalam",$APP.$cljs$cst$725$name$$,"Noto Sans Malayalam",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmalayalam/v29/sJoi3K5XjsSdcnzn071rL37lpAOsUThnDZIfPdbeSNzVakglNM-Qw8EaeB8Nss-_RuH9BFzEr6HxEA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmalayalam/v29/sJoi3K5XjsSdcnzn071rL37lpAOsUThnDZIfPdbeSNzVakglNM-Qw8EaeB8Nss-_xuD9BFzEr6HxEA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmalayalam/v29/sJoi3K5XjsSdcnzn071rL37lpAOsUThnDZIfPdbeSNzVakglNM-Qw8EaeB8Nss-_GOD9BFzEr6HxEA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmalayalam/v29/sJoi3K5XjsSdcnzn071rL37lpAOsUThnDZIfPdbeSNzVakglNM-Qw8EaeB8Nss-_RuD9BFzEr6HxEA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmalayalam/v29/sJoi3K5XjsSdcnzn071rL37lpAOsUThnDZIfPdbeSNzVakglNM-Qw8EaeB8Nss-_dOD9BFzEr6HxEA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmalayalam/v29/sJoi3K5XjsSdcnzn071rL37lpAOsUThnDZIfPdbeSNzVakglNM-Qw8EaeB8Nss-_mOf9BFzEr6HxEA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmalayalam/v29/sJoi3K5XjsSdcnzn071rL37lpAOsUThnDZIfPdbeSNzVakglNM-Qw8EaeB8Nss-_oef9BFzEr6HxEA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmalayalam/v29/sJoi3K5XjsSdcnzn071rL37lpAOsUThnDZIfPdbeSNzVakglNM-Qw8EaeB8Nss-_xuf9BFzEr6HxEA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmalayalam/v29/sJoi3K5XjsSdcnzn071rL37lpAOsUThnDZIfPdbeSNzVakglNM-Qw8EaeB8Nss-_7-f9BFzEr6HxEA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-mandaic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2638b29c-99d4-492c-b178-09bfddb0fad8",-2036724862),$APP.$cljs$cst$2675$family$$,"Noto Sans Mandaic",$APP.$cljs$cst$725$name$$,"Noto Sans Mandaic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmandaic/v18/cIfnMbdWt1w_HgCcilqhKQBo_OsMI5_A_gMk0izH.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-manichaean",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5a49a5ca-a184-4906-b445-0b6a98990838",-1631485370),$APP.$cljs$cst$2675$family$$,"Noto Sans Manichaean",
$APP.$cljs$cst$725$name$$,"Noto Sans Manichaean",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmanichaean/v19/taiVGntiC4--qtsfi4Jp9-_GkPZZCcrfekqCNTtFCtdX.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-marchen",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("76064266-3f15-406e-a825-0bc10ea23175",-140907012),$APP.$cljs$cst$2675$family$$,"Noto Sans Marchen",$APP.$cljs$cst$725$name$$,"Noto Sans Marchen",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmarchen/v21/aFTO7OZ_Y282EP-WyG6QTOX_C8WZMHhPk652ZaHk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-masaram-gondi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fbd23be6-ce9a-4ff9-87d2-35f9a1426952",-852754655),$APP.$cljs$cst$2675$family$$,"Noto Sans Masaram Gondi",$APP.$cljs$cst$725$name$$,
"Noto Sans Masaram Gondi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmasaramgondi/v18/6xK_dThFKcWIu4bpRBjRYRV7KZCbUq6n_1kPnuGe7RI9WSWX.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-math",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("07f636fa-9dcb-4763-91ef-3ba5663d62d5",-1133160127),$APP.$cljs$cst$2675$family$$,"Noto Sans Math",$APP.$cljs$cst$725$name$$,"Noto Sans Math",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmath/v18/7Aump_cpkSecTWaHRlH2hyV5UHkG-V048PW0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-mayan-numerals",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7eb7a9b2-8abf-4afa-89be-5a527a51698a",-1202801258),$APP.$cljs$cst$2675$family$$,"Noto Sans Mayan Numerals",$APP.$cljs$cst$725$name$$,"Noto Sans Mayan Numerals",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmayannumerals/v17/PlIuFk25O6RzLfvNNVSivR09_KqYMwvvDKYjfIiE68oo6eepYQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-noto-sans-medefaidrin",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("db11a383-6659-4f0c-9b2d-e47c717ad685",-1806606396),$APP.$cljs$cst$2675$family$$,"Noto Sans Medefaidrin",$APP.$cljs$cst$725$name$$,"Noto Sans Medefaidrin",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmedefaidrin/v29/WwkzxOq6Dk-wranENynkfeVsNbRZtbOIdLb1exeM4ZeuabBfmErWlT318e5A3rw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmedefaidrin/v29/WwkzxOq6Dk-wranENynkfeVsNbRZtbOIdLb1exeM4ZeuabBfmHjWlT318e5A3rw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmedefaidrin/v29/WwkzxOq6Dk-wranENynkfeVsNbRZtbOIdLb1exeM4ZeuabBfmJTRlT318e5A3rw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmedefaidrin/v29/WwkzxOq6Dk-wranENynkfeVsNbRZtbOIdLb1exeM4ZeuabBfmK3RlT318e5A3rw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-meetei-mayek",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1196e750-1216-40a6-ba3e-7eb7a934a03a",-1590690676),$APP.$cljs$cst$2675$family$$,"Noto Sans Meetei Mayek",$APP.$cljs$cst$725$name$$,"Noto Sans Meetei Mayek",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmeeteimayek/v20/HTxAL3QyKieByqY9eZPFweO0be7M21uSphSdhqILnmrRfJ8t_1TJ__TW5PgeFYVa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmeeteimayek/v20/HTxAL3QyKieByqY9eZPFweO0be7M21uSphSdhqILnmrRfJ8t_1RJ_vTW5PgeFYVa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmeeteimayek/v20/HTxAL3QyKieByqY9eZPFweO0be7M21uSphSdhqILnmrRfJ8t_1SX_vTW5PgeFYVa.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmeeteimayek/v20/HTxAL3QyKieByqY9eZPFweO0be7M21uSphSdhqILnmrRfJ8t_1TJ_vTW5PgeFYVa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmeeteimayek/v20/HTxAL3QyKieByqY9eZPFweO0be7M21uSphSdhqILnmrRfJ8t_1T7_vTW5PgeFYVa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmeeteimayek/v20/HTxAL3QyKieByqY9eZPFweO0be7M21uSphSdhqILnmrRfJ8t_1QX-fTW5PgeFYVa.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmeeteimayek/v20/HTxAL3QyKieByqY9eZPFweO0be7M21uSphSdhqILnmrRfJ8t_1Qu-fTW5PgeFYVa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmeeteimayek/v20/HTxAL3QyKieByqY9eZPFweO0be7M21uSphSdhqILnmrRfJ8t_1RJ-fTW5PgeFYVa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmeeteimayek/v20/HTxAL3QyKieByqY9eZPFweO0be7M21uSphSdhqILnmrRfJ8t_1Rg-fTW5PgeFYVa.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-mende-kikakui",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f5d7ac7f-b21b-43d3-9938-bc7e31749bd9",-559401253),$APP.$cljs$cst$2675$family$$,"Noto Sans Mende Kikakui",$APP.$cljs$cst$725$name$$,"Noto Sans Mende Kikakui",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmendekikakui/v29/11hRGoLHz17aKjQCWj-JHcLvu2Q5zZrnkbNCLUx_aDJLAHer.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-meroitic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("66d5c72c-ef86-4ea9-8d6e-fd6f1b5664c2",-1516585730),$APP.$cljs$cst$2675$family$$,"Noto Sans Meroitic",
$APP.$cljs$cst$725$name$$,"Noto Sans Meroitic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmeroitic/v19/IFS5HfRJndhE3P4b5jnZ3ITPvC6i00UDgDhTiKY9KQ.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-miao",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("eabb3f55-358e-44cd-8de1-e82f501c23fe",2010457799),$APP.$cljs$cst$2675$family$$,"Noto Sans Miao",$APP.$cljs$cst$725$name$$,"Noto Sans Miao",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmiao/v18/Dxxz8jmXMW75w3OmoDXVV4zyZUjgUYVslLhx.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-modi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("965bbc83-00d2-452a-aaae-c7010a2eb783",910068044),$APP.$cljs$cst$2675$family$$,"Noto Sans Modi",$APP.$cljs$cst$725$name$$,"Noto Sans Modi",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmodi/v25/pe03MIySN5pO62Z5YkFyT7jeav5qWVAgVol-.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-mongolian",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("58b6d7e3-f250-4702-a04d-ed98e1419c7e",2016704050),$APP.$cljs$cst$2675$family$$,"Noto Sans Mongolian",$APP.$cljs$cst$725$name$$,"Noto Sans Mongolian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmongolian/v23/VdGCAYADGIwE0EopZx8xQfHlgEAMsrToxLsg6-av1x0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b0476200-76ba-464b-bb5f-ea43bffcf1a3",-2079393205),$APP.$cljs$cst$2675$family$$,"Noto Sans Mono",$APP.$cljs$cst$725$name$$,"Noto Sans Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmono/v37/BngrUXNETWXI6LwhGYvaxZikqZqK6fBq6kPvUce2oAZcdthSBUsYck4-_FNI49rXVEQQL8Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmono/v37/BngrUXNETWXI6LwhGYvaxZikqZqK6fBq6kPvUce2oAZcdthSBUsYck4-_NNJ49rXVEQQL8Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmono/v37/BngrUXNETWXI6LwhGYvaxZikqZqK6fBq6kPvUce2oAZcdthSBUsYck4-_A1J49rXVEQQL8Y.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmono/v37/BngrUXNETWXI6LwhGYvaxZikqZqK6fBq6kPvUce2oAZcdthSBUsYck4-_FNJ49rXVEQQL8Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmono/v37/BngrUXNETWXI6LwhGYvaxZikqZqK6fBq6kPvUce2oAZcdthSBUsYck4-_GFJ49rXVEQQL8Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmono/v37/BngrUXNETWXI6LwhGYvaxZikqZqK6fBq6kPvUce2oAZcdthSBUsYck4-_I1O49rXVEQQL8Y.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmono/v37/BngrUXNETWXI6LwhGYvaxZikqZqK6fBq6kPvUce2oAZcdthSBUsYck4-_LRO49rXVEQQL8Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmono/v37/BngrUXNETWXI6LwhGYvaxZikqZqK6fBq6kPvUce2oAZcdthSBUsYck4-_NNO49rXVEQQL8Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmono/v37/BngrUXNETWXI6LwhGYvaxZikqZqK6fBq6kPvUce2oAZcdthSBUsYck4-_PpO49rXVEQQL8Y.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-mro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cd6bd04c-7dd9-4657-af69-ab3c706d3f0c",308826799),$APP.$cljs$cst$2675$family$$,"Noto Sans Mro",$APP.$cljs$cst$725$name$$,"Noto Sans Mro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmro/v19/qWcsB6--pZv9TqnUQMhe9b39WDzRtjkho4M.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-multani",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c2e90288-87e6-486d-8a4c-c77a54e88518",1563437315),$APP.$cljs$cst$2675$family$$,"Noto Sans Multani",$APP.$cljs$cst$725$name$$,"Noto Sans Multani",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmultani/v21/9Bty3ClF38_RfOpe1gCaZ8p30BOFO1A0pfCs5Kos.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-myanmar",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b13bcd72-2a3b-446d-b40d-35132941ce1e",1378876691),$APP.$cljs$cst$2675$family$$,"Noto Sans Myanmar",$APP.$cljs$cst$725$name$$,"Noto Sans Myanmar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosansmyanmar/v21/AlZs_y1ZtY3ymOryg38hOCSdOnFq0HGS1uEapkAC3AY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmyanmar/v21/AlZv_y1ZtY3ymOryg38hOCSdOnFq0HE-98EwiEwLxR-r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmyanmar/v21/AlZv_y1ZtY3ymOryg38hOCSdOnFq0HFa9MEwiEwLxR-r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmyanmar/v21/AlZq_y1ZtY3ymOryg38hOCSdOnFq0En23OU4o1AC.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmyanmar/v21/AlZv_y1ZtY3ymOryg38hOCSdOnFq0HEC9cEwiEwLxR-r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmyanmar/v21/AlZv_y1ZtY3ymOryg38hOCSdOnFq0HEu8sEwiEwLxR-r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmyanmar/v21/AlZv_y1ZtY3ymOryg38hOCSdOnFq0HFK88EwiEwLxR-r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmyanmar/v21/AlZv_y1ZtY3ymOryg38hOCSdOnFq0HFW8MEwiEwLxR-r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansmyanmar/v21/AlZv_y1ZtY3ymOryg38hOCSdOnFq0HFy8cEwiEwLxR-r.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-nko",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("090c39e5-a84f-4279-8d37-1d7e6e8c3735",-2139042236),$APP.$cljs$cst$2675$family$$,"Noto Sans NKo",$APP.$cljs$cst$725$name$$,"Noto Sans NKo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnko/v7/esDX31ZdNv-KYGGJpKGk2_RpMpCMHMLBrdA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-nko-unjoined",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("eef2039c-76f3-40e5-9d44-d8bdd712f16c",-24398836),$APP.$cljs$cst$2675$family$$,"Noto Sans NKo Unjoined",$APP.$cljs$cst$725$name$$,
"Noto Sans NKo Unjoined",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnkounjoined/v4/MCo_zBjx1d3VUhJFK9MYlNCXJ6VvqwGPz3szPOBB5nuzMdWs0rvF2gEPxf5wbh3T.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnkounjoined/v4/MCo_zBjx1d3VUhJFK9MYlNCXJ6VvqwGPz3szPOBB5nuzMdWs0rv32gEPxf5wbh3T.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnkounjoined/v4/MCo_zBjx1d3VUhJFK9MYlNCXJ6VvqwGPz3szPOBB5nuzMdWs0rsb3QEPxf5wbh3T.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnkounjoined/v4/MCo_zBjx1d3VUhJFK9MYlNCXJ6VvqwGPz3szPOBB5nuzMdWs0rsi3QEPxf5wbh3T.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-nabataean",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e1ac6053-b55b-4e10-80ae-ece5aab3b3a2",
1052180077),$APP.$cljs$cst$2675$family$$,"Noto Sans Nabataean",$APP.$cljs$cst$725$name$$,"Noto Sans Nabataean",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnabataean/v17/IFS4HfVJndhE3P4b5jnZ34DfsjO330dNoBJ9hK8kMK4.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-nag-mundari",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("83488921-cc83-4796-b3db-e59340dec816",-100367739),$APP.$cljs$cst$2675$family$$,"Noto Sans Nag Mundari",$APP.$cljs$cst$725$name$$,"Noto Sans Nag Mundari",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnagmundari/v4/3qTAoi2hnSyU8TNFIdhZTyod3g5lBnKlQFk2kS9fr9Eq09RHRxirbUGA0whP19M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnagmundari/v4/3qTAoi2hnSyU8TNFIdhZTyod3g5lBnKlQFk2kS9fr9Eq09RHRyqrbUGA0whP19M.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnagmundari/v4/3qTAoi2hnSyU8TNFIdhZTyod3g5lBnKlQFk2kS9fr9Eq09RHR8asbUGA0whP19M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnagmundari/v4/3qTAoi2hnSyU8TNFIdhZTyod3g5lBnKlQFk2kS9fr9Eq09RHR_-sbUGA0whP19M.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-nandinagari",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a154dfd7-1afd-4718-936f-57fa4dd384fd",-189672856),$APP.$cljs$cst$2675$family$$,"Noto Sans Nandinagari",$APP.$cljs$cst$725$name$$,"Noto Sans Nandinagari",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnandinagari/v4/or38Q7733eiDljA1IufXSNFT-1KI5y10H4jVa5RXzC1KOw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-noto-sans-new-tai-lue",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("22543344-1ddb-4e46-b1a0-b53484a449bf",1872704212),$APP.$cljs$cst$2675$family$$,"Noto Sans New Tai Lue",$APP.$cljs$cst$725$name$$,"Noto Sans New Tai Lue",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnewtailue/v24/H4cKBW-Pl9DZ0Xe_nHUapt7PovLXAhAnY7wqaLy-OJgU3p_pdeXAYUbghFPKzeY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnewtailue/v24/H4cKBW-Pl9DZ0Xe_nHUapt7PovLXAhAnY7wqaLy-OJgU3p_pddfAYUbghFPKzeY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnewtailue/v24/H4cKBW-Pl9DZ0Xe_nHUapt7PovLXAhAnY7wqaLy-OJgU3p_pdTvHYUbghFPKzeY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnewtailue/v24/H4cKBW-Pl9DZ0Xe_nHUapt7PovLXAhAnY7wqaLy-OJgU3p_pdQLHYUbghFPKzeY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-newa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9e5df6b6-ecdb-43cd-a334-2f84d83884ec",224106466),$APP.$cljs$cst$2675$family$$,"Noto Sans Newa",$APP.$cljs$cst$725$name$$,"Noto Sans Newa",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnewa/v17/7r3fqXp6utEsO9pI4f8ok8sWg8n_qN4R5lNU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-nushu",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f94b172a-2018-4b84-957d-53295aa9ddd5",
-1269935714),$APP.$cljs$cst$2675$family$$,"Noto Sans Nushu",$APP.$cljs$cst$725$name$$,"Noto Sans Nushu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansnushu/v20/rnCw-xRQ3B7652emAbAe_Ai1IYaFWFAMArZKqQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-ogham",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("84f28a41-1247-4203-8540-d559721b7aca",-2102181502),$APP.$cljs$cst$2675$family$$,"Noto Sans Ogham",$APP.$cljs$cst$725$name$$,"Noto Sans Ogham",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansogham/v18/kmKlZqk1GBDGN0mY6k5lmEmww4hrt5laQxcoCA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-ol-chiki",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("292ae614-19c1-4551-a65f-33aa8f58e52c",-1942861871),$APP.$cljs$cst$2675$family$$,"Noto Sans Ol Chiki",$APP.$cljs$cst$725$name$$,
"Noto Sans Ol Chiki",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansolchiki/v31/N0b92TJNOPt-eHmFZCdQbrL32r-4CvhzDzRwlxOQYuVALWk267I6gVrz5gQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansolchiki/v31/N0b92TJNOPt-eHmFZCdQbrL32r-4CvhzDzRwlxOQYuVALVs267I6gVrz5gQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansolchiki/v31/N0b92TJNOPt-eHmFZCdQbrL32r-4CvhzDzRwlxOQYuVALbcx67I6gVrz5gQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansolchiki/v31/N0b92TJNOPt-eHmFZCdQbrL32r-4CvhzDzRwlxOQYuVALY4x67I6gVrz5gQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-old-hungarian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f71203ed-ee46-4fb1-ab65-bc3d8f742c4b",
698699039),$APP.$cljs$cst$2675$family$$,"Noto Sans Old Hungarian",$APP.$cljs$cst$725$name$$,"Noto Sans Old Hungarian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansoldhungarian/v19/E213_cD6hP3GwCJPEUssHEM0KqLaHJXg2PiIgRfjbg5nCYXt.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-old-italic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("533c4cec-ecf0-4392-bb99-e50b38e21460",-627363529),$APP.$cljs$cst$2675$family$$,"Noto Sans Old Italic",$APP.$cljs$cst$725$name$$,"Noto Sans Old Italic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansolditalic/v18/TuGOUUFzXI5FBtUq5a8bh68BJxxEVam7tWlRdRhtCC4d.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-old-north-arabian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("92a80bb0-263a-40b7-9552-8437638d1942",427585763),$APP.$cljs$cst$2675$family$$,"Noto Sans Old North Arabian",
$APP.$cljs$cst$725$name$$,"Noto Sans Old North Arabian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansoldnortharabian/v17/esDF30BdNv-KYGGJpKGk2tNiMt7Jar6olZDyNdr81zBQmUo_xw4ABw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-old-permic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c6f80e37-713f-4953-ab56-c06714adb9ea",785434831),$APP.$cljs$cst$2675$family$$,"Noto Sans Old Permic",$APP.$cljs$cst$725$name$$,"Noto Sans Old Permic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansoldpermic/v18/snf1s1q1-dF8pli1TesqcbUY4Mr-ElrwKLdXgv_dKYB5.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-old-persian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("86a055b3-76e3-43f7-af2d-3e75ef0159c5",1771964388),$APP.$cljs$cst$2675$family$$,"Noto Sans Old Persian",
$APP.$cljs$cst$725$name$$,"Noto Sans Old Persian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansoldpersian/v17/wEOjEAbNnc5caQTFG18FHrZr9Bp6-8CmIJ_tqOlQfx9CjA.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-old-sogdian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("68c7922d-9cc7-4714-9ede-d267f3097344",1072740012),$APP.$cljs$cst$2675$family$$,"Noto Sans Old Sogdian",$APP.$cljs$cst$725$name$$,"Noto Sans Old Sogdian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansoldsogdian/v18/3JnjSCH90Gmq2mrzckOBBhFhdrMst48aURt7neIqM-9uyg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-old-south-arabian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6537a8d7-90ac-4371-aa3c-95183cd4167c",-616982916),$APP.$cljs$cst$2675$family$$,"Noto Sans Old South Arabian",
$APP.$cljs$cst$725$name$$,"Noto Sans Old South Arabian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansoldsoutharabian/v17/3qT5oiOhnSyU8TNFIdhZTice3hB_HWKsEnF--0XCHiKx1OtDT9HwTA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-old-turkic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0438f7ea-d176-4698-9fc0-f6cdb8bc54d2",-1528814339),$APP.$cljs$cst$2675$family$$,"Noto Sans Old Turkic",$APP.$cljs$cst$725$name$$,"Noto Sans Old Turkic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansoldturkic/v19/yMJNMJVya43H0SUF_WmcGEQVqoEMKDKbsE2RjEw-Vyws.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-oriya",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e0acd5ba-ccfc-42ed-95da-78c6d78d82c4",-1996232151),$APP.$cljs$cst$2675$family$$,"Noto Sans Oriya",$APP.$cljs$cst$725$name$$,
"Noto Sans Oriya",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansoriya/v33/AYCppXfzfccDCstK_hrjDyADv5e9748vhj3CJBLHIARtgD6TJQS0dJT5Ivj0fq_c6LhHBRe-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansoriya/v33/AYCppXfzfccDCstK_hrjDyADv5e9748vhj3CJBLHIARtgD6TJQS0dJT5Ivh0f6_c6LhHBRe-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosansoriya/v33/AYCppXfzfccDCstK_hrjDyADv5e9748vhj3CJBLHIARtgD6TJQS0dJT5Iviqf6_c6LhHBRe-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansoriya/v33/AYCppXfzfccDCstK_hrjDyADv5e9748vhj3CJBLHIARtgD6TJQS0dJT5Ivj0f6_c6LhHBRe-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansoriya/v33/AYCppXfzfccDCstK_hrjDyADv5e9748vhj3CJBLHIARtgD6TJQS0dJT5IvjGf6_c6LhHBRe-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosansoriya/v33/AYCppXfzfccDCstK_hrjDyADv5e9748vhj3CJBLHIARtgD6TJQS0dJT5IvgqeK_c6LhHBRe-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansoriya/v33/AYCppXfzfccDCstK_hrjDyADv5e9748vhj3CJBLHIARtgD6TJQS0dJT5IvgTeK_c6LhHBRe-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansoriya/v33/AYCppXfzfccDCstK_hrjDyADv5e9748vhj3CJBLHIARtgD6TJQS0dJT5Ivh0eK_c6LhHBRe-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosansoriya/v33/AYCppXfzfccDCstK_hrjDyADv5e9748vhj3CJBLHIARtgD6TJQS0dJT5IvhdeK_c6LhHBRe-.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-osage",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("11beb144-47b0-48e1-b8c6-83d1baf746db",-183020344),$APP.$cljs$cst$2675$family$$,"Noto Sans Osage",$APP.$cljs$cst$725$name$$,"Noto Sans Osage",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansosage/v19/oPWX_kB6kP4jCuhpgEGmw4mtAVtXRlaSxkrMCQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-osmanya",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("033be7f5-01cd-448a-aa3e-2e75916c70a6",
874646360),$APP.$cljs$cst$2675$family$$,"Noto Sans Osmanya",$APP.$cljs$cst$725$name$$,"Noto Sans Osmanya",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansosmanya/v19/8vIS7xs32H97qzQKnzfeWzUyUpOJmz6kR47NCV5Z.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-pahawh-hmong",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d230ac7a-c214-4317-9eed-da8884986c74",2016382614),$APP.$cljs$cst$2675$family$$,"Noto Sans Pahawh Hmong",$APP.$cljs$cst$725$name$$,"Noto Sans Pahawh Hmong",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanspahawhhmong/v19/bWtp7e_KfBziStx7lIzKKaMUOBEA3UPQDW7krzc_c48aMpM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-palmyrene",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ba578458-a5aa-41c1-9c8b-0ee957c98bcf",-520393180),$APP.$cljs$cst$2675$family$$,"Noto Sans Palmyrene",
$APP.$cljs$cst$725$name$$,"Noto Sans Palmyrene",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanspalmyrene/v17/ZgNPjOdKPa7CHqq0h37c_ASCWvH93SFCPnK5ZpdNtcA.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-pau-cin-hau",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0332db63-5cc5-490a-9dd7-ef346f0e02e5",1753053142),$APP.$cljs$cst$2675$family$$,"Noto Sans Pau Cin Hau",$APP.$cljs$cst$725$name$$,"Noto Sans Pau Cin Hau",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanspaucinhau/v21/x3d-cl3IZKmUqiMg_9wBLLtzl22EayN7ehIdjEWqKMxsKw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-phagspa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3d1d38cf-3eba-4040-a6e1-b7b0f39c7285",2045155601),$APP.$cljs$cst$2675$family$$,"Noto Sans PhagsPa",
$APP.$cljs$cst$725$name$$,"Noto Sans PhagsPa",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansphagspa/v24/XLY8IYr5bJNDGYxPGjyYbaEjwQR-LFlsYMYHGGeT.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-phoenician",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2d157a04-9709-4472-b46e-078e712dae90",-424657970),$APP.$cljs$cst$2675$family$$,"Noto Sans Phoenician",$APP.$cljs$cst$725$name$$,"Noto Sans Phoenician",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansphoenician/v18/jizFRF9Ksm4Bt9PvcTaEkIHiTVtxmFtS5X7Jot-p5561.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-psalter-pahlavi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1c679b0c-0e65-4ab2-a67d-187fc3425fb5",-1586220044),$APP.$cljs$cst$2675$family$$,"Noto Sans Psalter Pahlavi",$APP.$cljs$cst$725$name$$,"Noto Sans Psalter Pahlavi",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanspsalterpahlavi/v18/rP2Vp3K65FkAtHfwd-eISGznYihzggmsicPfud3w1G3KsUQBct4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-rejang",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2915cea7-f28b-4ccb-ba11-169f2b403856",-1635862397),$APP.$cljs$cst$2675$family$$,"Noto Sans Rejang",$APP.$cljs$cst$725$name$$,"Noto Sans Rejang",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansrejang/v22/Ktk2AKuMeZjqPnXgyqrib7DIogqwN4O3WYZB_sU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-runic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f4065cdf-d234-4a16-8b35-cf29350c7deb",1821750729),$APP.$cljs$cst$2675$family$$,"Noto Sans Runic",$APP.$cljs$cst$725$name$$,"Noto Sans Runic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansrunic/v18/H4c_BXWPl9DZ0Xe_nHUaus7W68WWaxpvHtgIYg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8dd9dc0e-3ede-43ff-b8d0-4c8e569cc9a4",
-1204880215),$APP.$cljs$cst$2675$family$$,"Noto Sans SC",$APP.$cljs$cst$725$name$$,"Noto Sans SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssc/v39/k3kCo84MPvpLmixcA63oeAL7Iqp5IZJF9bmaG9_EnYxNbPzS5HE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssc/v39/k3kCo84MPvpLmixcA63oeAL7Iqp5IZJF9bmaG1_FnYxNbPzS5HE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssc/v39/k3kCo84MPvpLmixcA63oeAL7Iqp5IZJF9bmaG4HFnYxNbPzS5HE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssc/v39/k3kCo84MPvpLmixcA63oeAL7Iqp5IZJF9bmaG9_FnYxNbPzS5HE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssc/v39/k3kCo84MPvpLmixcA63oeAL7Iqp5IZJF9bmaG-3FnYxNbPzS5HE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssc/v39/k3kCo84MPvpLmixcA63oeAL7Iqp5IZJF9bmaGwHCnYxNbPzS5HE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssc/v39/k3kCo84MPvpLmixcA63oeAL7Iqp5IZJF9bmaGzjCnYxNbPzS5HE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssc/v39/k3kCo84MPvpLmixcA63oeAL7Iqp5IZJF9bmaG1_CnYxNbPzS5HE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssc/v39/k3kCo84MPvpLmixcA63oeAL7Iqp5IZJF9bmaG3bCnYxNbPzS5HE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-samaritan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c41c2f32-bece-44ce-bf15-1c13ec0a233a",-1153142022),$APP.$cljs$cst$2675$family$$,"Noto Sans Samaritan",$APP.$cljs$cst$725$name$$,"Noto Sans Samaritan",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssamaritan/v17/buEqppe9f8_vkXadMBJJo0tSmaYjFkxOUo5jNlOVMzQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-saurashtra",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("78c4d404-4be5-44fc-97ef-8e8d4310ba3d",-148216901),$APP.$cljs$cst$2675$family$$,"Noto Sans Saurashtra",$APP.$cljs$cst$725$name$$,"Noto Sans Saurashtra",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssaurashtra/v24/ea8GacQ0Wfz_XKWXe6OtoA8w8zvmYwTef9ndjhPTSIx9.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-noto-sans-sharada",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a86e14c4-085e-45ec-968c-1aca17c448c5",1234204324),$APP.$cljs$cst$2675$family$$,"Noto Sans Sharada",$APP.$cljs$cst$725$name$$,"Noto Sans Sharada",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssharada/v17/gok0H7rwAEdtF9N8-mdTGALG6p0kwoXLPOwr4H8a.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-shavian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("337b7f22-812f-4f3b-9b74-f191fdd48217",-517464639),$APP.$cljs$cst$2675$family$$,"Noto Sans Shavian",$APP.$cljs$cst$725$name$$,"Noto Sans Shavian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansshavian/v18/CHy5V_HZE0jxJBQlqAeCKjJvQBNF4EFQSplv2Cwg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-siddham",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("429f2da8-03ab-48c0-9366-112c61a8b3e2",
936292300),$APP.$cljs$cst$2675$family$$,"Noto Sans Siddham",$APP.$cljs$cst$725$name$$,"Noto Sans Siddham",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssiddham/v21/OZpZg-FwqiNLe9PELUikxTWDoCCeGqndk3Ic92ZH.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-signwriting",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1fb887cf-488e-4041-895b-e84f74026307",-1351593653),$APP.$cljs$cst$2675$family$$,"Noto Sans SignWriting",$APP.$cljs$cst$725$name$$,"Noto Sans SignWriting",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssignwriting/v5/Noas6VX_wIWFbTTCrYmvy9A2UnkL-2SZAWiUEVCARYQemg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-sinhala",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a35d372c-6832-4f83-8b31-c5871dbc1eea",-757361080),$APP.$cljs$cst$2675$family$$,"Noto Sans Sinhala",
$APP.$cljs$cst$725$name$$,"Noto Sans Sinhala",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssinhala/v36/yMJ2MJBya43H0SUF_WmcBEEf4rQVO2P524V5N_MxQzQtb-tf5dJbC30Fu9zUwg2b5lgLpJwbQRM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssinhala/v36/yMJ2MJBya43H0SUF_WmcBEEf4rQVO2P524V5N_MxQzQtb-tf5dJbC30Fu9zUwo2a5lgLpJwbQRM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssinhala/v36/yMJ2MJBya43H0SUF_WmcBEEf4rQVO2P524V5N_MxQzQtb-tf5dJbC30Fu9zUwlOa5lgLpJwbQRM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssinhala/v36/yMJ2MJBya43H0SUF_WmcBEEf4rQVO2P524V5N_MxQzQtb-tf5dJbC30Fu9zUwg2a5lgLpJwbQRM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssinhala/v36/yMJ2MJBya43H0SUF_WmcBEEf4rQVO2P524V5N_MxQzQtb-tf5dJbC30Fu9zUwj-a5lgLpJwbQRM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssinhala/v36/yMJ2MJBya43H0SUF_WmcBEEf4rQVO2P524V5N_MxQzQtb-tf5dJbC30Fu9zUwtOd5lgLpJwbQRM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssinhala/v36/yMJ2MJBya43H0SUF_WmcBEEf4rQVO2P524V5N_MxQzQtb-tf5dJbC30Fu9zUwuqd5lgLpJwbQRM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssinhala/v36/yMJ2MJBya43H0SUF_WmcBEEf4rQVO2P524V5N_MxQzQtb-tf5dJbC30Fu9zUwo2d5lgLpJwbQRM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssinhala/v36/yMJ2MJBya43H0SUF_WmcBEEf4rQVO2P524V5N_MxQzQtb-tf5dJbC30Fu9zUwqSd5lgLpJwbQRM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-sogdian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("db3902a8-7853-4785-bced-7424a139230a",-1685192756),$APP.$cljs$cst$2675$family$$,"Noto Sans Sogdian",$APP.$cljs$cst$725$name$$,"Noto Sans Sogdian",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssogdian/v17/taiQGn5iC4--qtsfi4Jp6eHPnfxQBo--Pm6KHidM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-sora-sompeng",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d851f9e9-ac75-41f0-b334-c8ad41d9422f",-104310781),$APP.$cljs$cst$2675$family$$,"Noto Sans Sora Sompeng",$APP.$cljs$cst$725$name$$,"Noto Sans Sora Sompeng",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssorasompeng/v26/PlIRFkO5O6RzLfvNNVSioxM2_OTrEhPyDLolKvCsHzCxWuGkYHR818DpZXJQd4Mu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssorasompeng/v26/PlIRFkO5O6RzLfvNNVSioxM2_OTrEhPyDLolKvCsHzCxWuGkYHRO18DpZXJQd4Mu.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssorasompeng/v26/PlIRFkO5O6RzLfvNNVSioxM2_OTrEhPyDLolKvCsHzCxWuGkYHSi0MDpZXJQd4Mu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssorasompeng/v26/PlIRFkO5O6RzLfvNNVSioxM2_OTrEhPyDLolKvCsHzCxWuGkYHSb0MDpZXJQd4Mu.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-soyombo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8256b97e-c4bb-47bf-8c8a-f969427be92f",1426954714),$APP.$cljs$cst$2675$family$$,"Noto Sans Soyombo",$APP.$cljs$cst$725$name$$,"Noto Sans Soyombo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssoyombo/v18/RWmSoL-Y6-8q5LTtXs6MF6q7xsxgY0FrIFOcK25W.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-sundanese",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("390ecfca-ed6c-4af1-b6ec-e6762cc7bfa0",-877897911),$APP.$cljs$cst$2675$family$$,"Noto Sans Sundanese",$APP.$cljs$cst$725$name$$,"Noto Sans Sundanese",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosanssundanese/v28/FwZw7_84xUkosG2xJo2gm7nFwSLQkdymq2mkz3Gz1_b6ctxpNNHCizv7fQES.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssundanese/v28/FwZw7_84xUkosG2xJo2gm7nFwSLQkdymq2mkz3Gz1_b6ctxbNNHCizv7fQES.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssundanese/v28/FwZw7_84xUkosG2xJo2gm7nFwSLQkdymq2mkz3Gz1_b6cty3M9HCizv7fQES.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssundanese/v28/FwZw7_84xUkosG2xJo2gm7nFwSLQkdymq2mkz3Gz1_b6ctyOM9HCizv7fQES.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-sunuwar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e7925844-c116-47c7-a2cc-cf7612309e9e",40710017),$APP.$cljs$cst$2675$family$$,"Noto Sans Sunuwar",$APP.$cljs$cst$725$name$$,"Noto Sans Sunuwar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssunuwar/v1/FwZB7_04xUkosG2xJo2gm7nF0DTfho_Du2akOrkv.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-syloti-nagri",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d3822b39-1a40-418d-b28a-fea273446d5f",1724440279),$APP.$cljs$cst$2675$family$$,"Noto Sans Syloti Nagri",
$APP.$cljs$cst$725$name$$,"Noto Sans Syloti Nagri",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssylotinagri/v25/uU9eCAQZ75uhfF9UoWDRiY3q7Sf_VFV3m4dGFVfxN87gsj0.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-symbols",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("396c294b-ab0b-48e8-a60d-14352f8da0b8",776316177),$APP.$cljs$cst$2675$family$$,"Noto Sans Symbols",$APP.$cljs$cst$725$name$$,"Noto Sans Symbols",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",
$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssymbols/v47/rP2up3q65FkAtHfwd-eIS2brbDN6gxP34F9jRRCe4W3gfQ4gavVFRkzrbQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssymbols/v47/rP2up3q65FkAtHfwd-eIS2brbDN6gxP34F9jRRCe4W3g_Q8gavVFRkzrbQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssymbols/v47/rP2up3q65FkAtHfwd-eIS2brbDN6gxP34F9jRRCe4W3gIw8gavVFRkzrbQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssymbols/v47/rP2up3q65FkAtHfwd-eIS2brbDN6gxP34F9jRRCe4W3gfQ8gavVFRkzrbQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssymbols/v47/rP2up3q65FkAtHfwd-eIS2brbDN6gxP34F9jRRCe4W3gTw8gavVFRkzrbQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssymbols/v47/rP2up3q65FkAtHfwd-eIS2brbDN6gxP34F9jRRCe4W3gowggavVFRkzrbQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssymbols/v47/rP2up3q65FkAtHfwd-eIS2brbDN6gxP34F9jRRCe4W3gmgggavVFRkzrbQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssymbols/v47/rP2up3q65FkAtHfwd-eIS2brbDN6gxP34F9jRRCe4W3g_QggavVFRkzrbQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssymbols/v47/rP2up3q65FkAtHfwd-eIS2brbDN6gxP34F9jRRCe4W3g1AggavVFRkzrbQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-symbols-2",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c39a4632-24f6-47b7-94c1-ee2a4269f63c",2057359652),$APP.$cljs$cst$2675$family$$,"Noto Sans Symbols 2",$APP.$cljs$cst$725$name$$,"Noto Sans Symbols 2",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssymbols2/v25/I_uyMoGduATTei9eI8daxVHDyfisHr71ypPqfX71-AI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-syriac",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("f5a4e313-2b1a-44e5-87c0-e4f91b770423",-2034156715),$APP.$cljs$cst$2675$family$$,"Noto Sans Syriac",$APP.$cljs$cst$725$name$$,"Noto Sans Syriac",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosanssyriac/v18/Ktk7AKuMeZjqPnXgyqribqzQqgW0LYiVqV7dXcP0C-VD9caJyZfUL_FC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriac/v18/Ktk7AKuMeZjqPnXgyqribqzQqgW0LYiVqV7dXcP0C-XD9MaJyZfUL_FC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriac/v18/Ktk7AKuMeZjqPnXgyqribqzQqgW0LYiVqV7dXcP0C-Ud9MaJyZfUL_FC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriac/v18/Ktk7AKuMeZjqPnXgyqribqzQqgW0LYiVqV7dXcP0C-VD9MaJyZfUL_FC.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriac/v18/Ktk7AKuMeZjqPnXgyqribqzQqgW0LYiVqV7dXcP0C-Vx9MaJyZfUL_FC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriac/v18/Ktk7AKuMeZjqPnXgyqribqzQqgW0LYiVqV7dXcP0C-Wd88aJyZfUL_FC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriac/v18/Ktk7AKuMeZjqPnXgyqribqzQqgW0LYiVqV7dXcP0C-Wk88aJyZfUL_FC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriac/v18/Ktk7AKuMeZjqPnXgyqribqzQqgW0LYiVqV7dXcP0C-XD88aJyZfUL_FC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriac/v18/Ktk7AKuMeZjqPnXgyqribqzQqgW0LYiVqV7dXcP0C-Xq88aJyZfUL_FC.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-syriac-eastern",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("acbb8e1b-dcfa-4205-b715-3df2bc9ab599",-1652344051),$APP.$cljs$cst$2675$family$$,"Noto Sans Syriac Eastern",$APP.$cljs$cst$725$name$$,"Noto Sans Syriac Eastern",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriaceastern/v3/Noac6Vj_wIWFbTTCrYmvy8AjVU8aslWRHHvRYxS-Ro3yS0FDacnHPi-eszCL5ep1QPQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosanssyriaceastern/v3/Noac6Vj_wIWFbTTCrYmvy8AjVU8aslWRHHvRYxS-Ro3yS0FDacnHPq-fszCL5ep1QPQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriaceastern/v3/Noac6Vj_wIWFbTTCrYmvy8AjVU8aslWRHHvRYxS-Ro3yS0FDacnHPnGfszCL5ep1QPQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriaceastern/v3/Noac6Vj_wIWFbTTCrYmvy8AjVU8aslWRHHvRYxS-Ro3yS0FDacnHPi-fszCL5ep1QPQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosanssyriaceastern/v3/Noac6Vj_wIWFbTTCrYmvy8AjVU8aslWRHHvRYxS-Ro3yS0FDacnHPh2fszCL5ep1QPQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriaceastern/v3/Noac6Vj_wIWFbTTCrYmvy8AjVU8aslWRHHvRYxS-Ro3yS0FDacnHPvGYszCL5ep1QPQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriaceastern/v3/Noac6Vj_wIWFbTTCrYmvy8AjVU8aslWRHHvRYxS-Ro3yS0FDacnHPsiYszCL5ep1QPQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosanssyriaceastern/v3/Noac6Vj_wIWFbTTCrYmvy8AjVU8aslWRHHvRYxS-Ro3yS0FDacnHPq-YszCL5ep1QPQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriaceastern/v3/Noac6Vj_wIWFbTTCrYmvy8AjVU8aslWRHHvRYxS-Ro3yS0FDacnHPoaYszCL5ep1QPQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-syriac-western",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bfe437e8-16c8-4403-b574-1b73eb5f7f26",-1746297263),$APP.$cljs$cst$2675$family$$,"Noto Sans Syriac Western",$APP.$cljs$cst$725$name$$,"Noto Sans Syriac Western",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",
$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriacwestern/v2/ke8LOhEEMVFsvCav8hWjbItd6Jf6MP7Z9spJZ6UNIILh-71aJmOWEaw_X8uP2jTYyH0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriacwestern/v2/ke8LOhEEMVFsvCav8hWjbItd6Jf6MP7Z9spJZ6UNIILh-71aJmOWESw-X8uP2jTYyH0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriacwestern/v2/ke8LOhEEMVFsvCav8hWjbItd6Jf6MP7Z9spJZ6UNIILh-71aJmOWEfI-X8uP2jTYyH0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriacwestern/v2/ke8LOhEEMVFsvCav8hWjbItd6Jf6MP7Z9spJZ6UNIILh-71aJmOWEaw-X8uP2jTYyH0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriacwestern/v2/ke8LOhEEMVFsvCav8hWjbItd6Jf6MP7Z9spJZ6UNIILh-71aJmOWEZ4-X8uP2jTYyH0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriacwestern/v2/ke8LOhEEMVFsvCav8hWjbItd6Jf6MP7Z9spJZ6UNIILh-71aJmOWEXI5X8uP2jTYyH0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriacwestern/v2/ke8LOhEEMVFsvCav8hWjbItd6Jf6MP7Z9spJZ6UNIILh-71aJmOWEUs5X8uP2jTYyH0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriacwestern/v2/ke8LOhEEMVFsvCav8hWjbItd6Jf6MP7Z9spJZ6UNIILh-71aJmOWESw5X8uP2jTYyH0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanssyriacwestern/v2/ke8LOhEEMVFsvCav8hWjbItd6Jf6MP7Z9spJZ6UNIILh-71aJmOWEQU5X8uP2jTYyH0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-tc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("40b0f1ca-f024-4aba-861a-41a8fcdef43a",
-1238216106),$APP.$cljs$cst$2675$family$$,"Noto Sans TC",$APP.$cljs$cst$725$name$$,"Noto Sans TC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstc/v38/-nFuOG829Oofr2wohFbTp9ifNAn722rq0MXz76Cz_CpOtma3uNQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstc/v38/-nFuOG829Oofr2wohFbTp9ifNAn722rq0MXz7yCy_CpOtma3uNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstc/v38/-nFuOG829Oofr2wohFbTp9ifNAn722rq0MXz7_6y_CpOtma3uNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstc/v38/-nFuOG829Oofr2wohFbTp9ifNAn722rq0MXz76Cy_CpOtma3uNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstc/v38/-nFuOG829Oofr2wohFbTp9ifNAn722rq0MXz75Ky_CpOtma3uNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstc/v38/-nFuOG829Oofr2wohFbTp9ifNAn722rq0MXz7361_CpOtma3uNQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstc/v38/-nFuOG829Oofr2wohFbTp9ifNAn722rq0MXz70e1_CpOtma3uNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstc/v38/-nFuOG829Oofr2wohFbTp9ifNAn722rq0MXz7yC1_CpOtma3uNQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstc/v38/-nFuOG829Oofr2wohFbTp9ifNAn722rq0MXz7wm1_CpOtma3uNQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-tagalog",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8355a6c5-ccbc-4867-b4c5-575868381bfa",1199636107),$APP.$cljs$cst$2675$family$$,"Noto Sans Tagalog",$APP.$cljs$cst$725$name$$,"Noto Sans Tagalog",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstagalog/v23/J7aFnoNzCnFcV9ZI-sUYuvote1R0wwEAA8jHexnL.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-tagbanwa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f5bfe99d-1e48-4afa-8e06-4b3a17860dd4",-65575653),$APP.$cljs$cst$2675$family$$,"Noto Sans Tagbanwa",$APP.$cljs$cst$725$name$$,"Noto Sans Tagbanwa",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstagbanwa/v19/Y4GWYbB8VTEp4t3MKJSMmQdIKjRtt_nZRjQEaYpGoQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-tai-le",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("27eefc89-ceb9-4221-87bc-1421051d7732",-1949913804),$APP.$cljs$cst$2675$family$$,"Noto Sans Tai Le",$APP.$cljs$cst$725$name$$,"Noto Sans Tai Le",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstaile/v18/vEFK2-VODB8RrNDvZSUmVxEATwR58tK1W77HtMo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-tai-tham",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2289e2c3-e341-456b-9076-9970228f6596",-1539111364),$APP.$cljs$cst$2675$family$$,"Noto Sans Tai Tham",$APP.$cljs$cst$725$name$$,"Noto Sans Tai Tham",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstaitham/v25/kJEbBv0U4hgtwxDUw2x9q7tbjLIfbPGHBoaVSAZ3MdLJBCUbPgquyaRGKMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstaitham/v25/kJEbBv0U4hgtwxDUw2x9q7tbjLIfbPGHBoaVSAZ3MdLJBBcbPgquyaRGKMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstaitham/v25/kJEbBv0U4hgtwxDUw2x9q7tbjLIfbPGHBoaVSAZ3MdLJBPscPgquyaRGKMw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstaitham/v25/kJEbBv0U4hgtwxDUw2x9q7tbjLIfbPGHBoaVSAZ3MdLJBMIcPgquyaRGKMw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-tai-viet",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d52f5a52-8fe1-4b96-af82-08f7198cebea",
571604885),$APP.$cljs$cst$2675$family$$,"Noto Sans Tai Viet",$APP.$cljs$cst$725$name$$,"Noto Sans Tai Viet",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstaiviet/v20/8QIUdj3HhN_lv4jf9vsE-9GMOLsaSPZr644fWsRO9w.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-takri",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2b865707-1dd1-4734-9b33-f7d7ad250c00",1230634363),$APP.$cljs$cst$2675$family$$,"Noto Sans Takri",$APP.$cljs$cst$725$name$$,"Noto Sans Takri",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstakri/v25/TuGJUVpzXI5FBtUq5a8bnKIOdTwQNO_W3khJXg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-tamil",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f4971cdf-35f1-4488-a025-6563ea57c984",-1346498295),$APP.$cljs$cst$2675$family$$,"Noto Sans Tamil",$APP.$cljs$cst$725$name$$,
"Noto Sans Tamil",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstamil/v31/ieVc2YdFI3GCY6SyQy1KfStzYKZgzN1z4LKDbeZce-0429tBManUktuex7vGor0RqKDt_EvT.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstamil/v31/ieVc2YdFI3GCY6SyQy1KfStzYKZgzN1z4LKDbeZce-0429tBManUktuex7tGo70RqKDt_EvT.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosanstamil/v31/ieVc2YdFI3GCY6SyQy1KfStzYKZgzN1z4LKDbeZce-0429tBManUktuex7uYo70RqKDt_EvT.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstamil/v31/ieVc2YdFI3GCY6SyQy1KfStzYKZgzN1z4LKDbeZce-0429tBManUktuex7vGo70RqKDt_EvT.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstamil/v31/ieVc2YdFI3GCY6SyQy1KfStzYKZgzN1z4LKDbeZce-0429tBManUktuex7v0o70RqKDt_EvT.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosanstamil/v31/ieVc2YdFI3GCY6SyQy1KfStzYKZgzN1z4LKDbeZce-0429tBManUktuex7sYpL0RqKDt_EvT.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstamil/v31/ieVc2YdFI3GCY6SyQy1KfStzYKZgzN1z4LKDbeZce-0429tBManUktuex7shpL0RqKDt_EvT.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstamil/v31/ieVc2YdFI3GCY6SyQy1KfStzYKZgzN1z4LKDbeZce-0429tBManUktuex7tGpL0RqKDt_EvT.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosanstamil/v31/ieVc2YdFI3GCY6SyQy1KfStzYKZgzN1z4LKDbeZce-0429tBManUktuex7tvpL0RqKDt_EvT.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-tamil-supplement",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e171c4a9-9fda-4d5a-a3e7-f362b8f9b351",-1648192072),$APP.$cljs$cst$2675$family$$,"Noto Sans Tamil Supplement",$APP.$cljs$cst$725$name$$,"Noto Sans Tamil Supplement",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstamilsupplement/v23/DdTz78kEtnooLS5rXF1DaruiCd_bFp_Ph4sGcn7ax_vsAeMkeq1x.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-tangsa",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("eae6af09-30d9-4449-8db4-69e8033e851b",752643549),$APP.$cljs$cst$2675$family$$,"Noto Sans Tangsa",$APP.$cljs$cst$725$name$$,"Noto Sans Tangsa",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosanstangsa/v9/z7NCdQPmcigbbZAIOl9igP26K470lICpky0-peX5Qp1YkyoRYdplyJDA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstangsa/v9/z7NCdQPmcigbbZAIOl9igP26K470lICpky0-peX5Qp1qkyoRYdplyJDA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstangsa/v9/z7NCdQPmcigbbZAIOl9igP26K470lICpky0-peX5Qp2GlCoRYdplyJDA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstangsa/v9/z7NCdQPmcigbbZAIOl9igP26K470lICpky0-peX5Qp2_lCoRYdplyJDA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-telugu",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ddeefec3-a0e5-476f-8fbe-ac07029907e8",2025754017),$APP.$cljs$cst$2675$family$$,"Noto Sans Telugu",$APP.$cljs$cst$725$name$$,"Noto Sans Telugu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstelugu/v30/0FlxVOGZlE2Rrtr-HmgkMWJNjJ5_RyT8o8c7fHkeg-esVC5dzHkHIJQqrEntezfqQUbf-3v37w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstelugu/v30/0FlxVOGZlE2Rrtr-HmgkMWJNjJ5_RyT8o8c7fHkeg-esVC5dzHkHIJQqrEnt-zbqQUbf-3v37w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstelugu/v30/0FlxVOGZlE2Rrtr-HmgkMWJNjJ5_RyT8o8c7fHkeg-esVC5dzHkHIJQqrEntJTbqQUbf-3v37w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstelugu/v30/0FlxVOGZlE2Rrtr-HmgkMWJNjJ5_RyT8o8c7fHkeg-esVC5dzHkHIJQqrEntezbqQUbf-3v37w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstelugu/v30/0FlxVOGZlE2Rrtr-HmgkMWJNjJ5_RyT8o8c7fHkeg-esVC5dzHkHIJQqrEntSTbqQUbf-3v37w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstelugu/v30/0FlxVOGZlE2Rrtr-HmgkMWJNjJ5_RyT8o8c7fHkeg-esVC5dzHkHIJQqrEntpTHqQUbf-3v37w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstelugu/v30/0FlxVOGZlE2Rrtr-HmgkMWJNjJ5_RyT8o8c7fHkeg-esVC5dzHkHIJQqrEntnDHqQUbf-3v37w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstelugu/v30/0FlxVOGZlE2Rrtr-HmgkMWJNjJ5_RyT8o8c7fHkeg-esVC5dzHkHIJQqrEnt-zHqQUbf-3v37w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstelugu/v30/0FlxVOGZlE2Rrtr-HmgkMWJNjJ5_RyT8o8c7fHkeg-esVC5dzHkHIJQqrEnt0jHqQUbf-3v37w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-thaana",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("470e34f0-6514-48de-9b47-07d2b65c70e7",
616672438),$APP.$cljs$cst$2675$family$$,"Noto Sans Thaana",$APP.$cljs$cst$725$name$$,"Noto Sans Thaana",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthaana/v26/C8c14dM-vnz-s-3jaEsxlxHkBH-WZOETXfoQrfQ9Y4XrbxLhnu4-tbNu.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthaana/v26/C8c14dM-vnz-s-3jaEsxlxHkBH-WZOETXfoQrfQ9Y4VrbhLhnu4-tbNu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthaana/v26/C8c14dM-vnz-s-3jaEsxlxHkBH-WZOETXfoQrfQ9Y4W1bhLhnu4-tbNu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthaana/v26/C8c14dM-vnz-s-3jaEsxlxHkBH-WZOETXfoQrfQ9Y4XrbhLhnu4-tbNu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthaana/v26/C8c14dM-vnz-s-3jaEsxlxHkBH-WZOETXfoQrfQ9Y4XZbhLhnu4-tbNu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthaana/v26/C8c14dM-vnz-s-3jaEsxlxHkBH-WZOETXfoQrfQ9Y4U1aRLhnu4-tbNu.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthaana/v26/C8c14dM-vnz-s-3jaEsxlxHkBH-WZOETXfoQrfQ9Y4UMaRLhnu4-tbNu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthaana/v26/C8c14dM-vnz-s-3jaEsxlxHkBH-WZOETXfoQrfQ9Y4VraRLhnu4-tbNu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthaana/v26/C8c14dM-vnz-s-3jaEsxlxHkBH-WZOETXfoQrfQ9Y4VCaRLhnu4-tbNu.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-thai",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2843ede2-7fea-47d4-9ac0-bf11746674f4",1343241336),$APP.$cljs$cst$2675$family$$,"Noto Sans Thai",$APP.$cljs$cst$725$name$$,"Noto Sans Thai",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthai/v29/iJWnBXeUZi_OHPqn4wq6hQ2_hbJ1xyN9wd43SofNWcd1MKVQt_So_9CdU5RspzF-QRvzzXg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthai/v29/iJWnBXeUZi_OHPqn4wq6hQ2_hbJ1xyN9wd43SofNWcd1MKVQt_So_9CdUxRtpzF-QRvzzXg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthai/v29/iJWnBXeUZi_OHPqn4wq6hQ2_hbJ1xyN9wd43SofNWcd1MKVQt_So_9CdU8ptpzF-QRvzzXg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthai/v29/iJWnBXeUZi_OHPqn4wq6hQ2_hbJ1xyN9wd43SofNWcd1MKVQt_So_9CdU5RtpzF-QRvzzXg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthai/v29/iJWnBXeUZi_OHPqn4wq6hQ2_hbJ1xyN9wd43SofNWcd1MKVQt_So_9CdU6ZtpzF-QRvzzXg.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthai/v29/iJWnBXeUZi_OHPqn4wq6hQ2_hbJ1xyN9wd43SofNWcd1MKVQt_So_9CdU0pqpzF-QRvzzXg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthai/v29/iJWnBXeUZi_OHPqn4wq6hQ2_hbJ1xyN9wd43SofNWcd1MKVQt_So_9CdU3NqpzF-QRvzzXg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthai/v29/iJWnBXeUZi_OHPqn4wq6hQ2_hbJ1xyN9wd43SofNWcd1MKVQt_So_9CdUxRqpzF-QRvzzXg.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthai/v29/iJWnBXeUZi_OHPqn4wq6hQ2_hbJ1xyN9wd43SofNWcd1MKVQt_So_9CdUz1qpzF-QRvzzXg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-thai-looped",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7cdeaf68-999a-48b1-a09a-a449fcf2aa78",
1942576129),$APP.$cljs$cst$2675$family$$,"Noto Sans Thai Looped",$APP.$cljs$cst$725$name$$,"Noto Sans Thai Looped",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthailooped/v16/B503F6pOpWTRcGrhOVJJ3-oPfY7WQuFu5R36MIjwurFMX_p0KVmQL3HnxYJ8hCVQ-_gtHxJiQo49kz2h.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthailooped/v16/B503F6pOpWTRcGrhOVJJ3-oPfY7WQuFu5R36MIjwurFMX_p0KVmQL3HnxYJ8hCVQ-_itHhJiQo49kz2h.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthailooped/v16/B503F6pOpWTRcGrhOVJJ3-oPfY7WQuFu5R36MIjwurFMX_p0KVmQL3HnxYJ8hCVQ-_hzHhJiQo49kz2h.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthailooped/v16/B503F6pOpWTRcGrhOVJJ3-oPfY7WQuFu5R36MIjwurFMX_p0KVmQL3HnxYJ8hCVQ-_gtHhJiQo49kz2h.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthailooped/v16/B503F6pOpWTRcGrhOVJJ3-oPfY7WQuFu5R36MIjwurFMX_p0KVmQL3HnxYJ8hCVQ-_gfHhJiQo49kz2h.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthailooped/v16/B503F6pOpWTRcGrhOVJJ3-oPfY7WQuFu5R36MIjwurFMX_p0KVmQL3HnxYJ8hCVQ-_jzGRJiQo49kz2h.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthailooped/v16/B503F6pOpWTRcGrhOVJJ3-oPfY7WQuFu5R36MIjwurFMX_p0KVmQL3HnxYJ8hCVQ-_jKGRJiQo49kz2h.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthailooped/v16/B503F6pOpWTRcGrhOVJJ3-oPfY7WQuFu5R36MIjwurFMX_p0KVmQL3HnxYJ8hCVQ-_itGRJiQo49kz2h.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansthailooped/v16/B503F6pOpWTRcGrhOVJJ3-oPfY7WQuFu5R36MIjwurFMX_p0KVmQL3HnxYJ8hCVQ-_iEGRJiQo49kz2h.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-tifinagh",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("479ae411-4cfd-41d8-9296-8ef43d88a5a1",-585843215),$APP.$cljs$cst$2675$family$$,"Noto Sans Tifinagh",$APP.$cljs$cst$725$name$$,"Noto Sans Tifinagh",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstifinagh/v21/I_uzMoCduATTei9eI8dawkHIwvmhCvbn6rnEcXfs4Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-tirhuta",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("801984e4-e41b-451e-bd3a-10340fe9a595",620655743),$APP.$cljs$cst$2675$family$$,"Noto Sans Tirhuta",$APP.$cljs$cst$725$name$$,"Noto Sans Tirhuta",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanstirhuta/v17/t5t6IQYRNJ6TWjahPR6X-M-apUyby7uGUBsTrn5P.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-ugaritic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3bc7acb2-05aa-422a-b96f-4403d779499e",2001538703),$APP.$cljs$cst$2675$family$$,"Noto Sans Ugaritic",$APP.$cljs$cst$725$name$$,"Noto Sans Ugaritic",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansugaritic/v17/3qTwoiqhnSyU8TNFIdhZVCwbjCpkAXXkMhoIkiazfg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-vai",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c1a770fc-19fd-455e-a377-4dcbe7298d43",2037837588),$APP.$cljs$cst$2675$family$$,"Noto Sans Vai",$APP.$cljs$cst$725$name$$,"Noto Sans Vai",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notosansvai/v18/NaPecZTSBuhTirw6IaFn_UrURMTsDIRSfr0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-vithkuqi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d43ddda0-08d9-4e92-acec-07e142c91ef5",1535277897),$APP.$cljs$cst$2675$family$$,"Noto Sans Vithkuqi",$APP.$cljs$cst$725$name$$,"Noto Sans Vithkuqi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansvithkuqi/v3/jVyi7m77CXvQswd6WjYu9E1wN6cih2TSchUEkQgw3KTnva5SgKM7vmn0BLE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansvithkuqi/v3/jVyi7m77CXvQswd6WjYu9E1wN6cih2TSchUEkQgw3KTnvZxSgKM7vmn0BLE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansvithkuqi/v3/jVyi7m77CXvQswd6WjYu9E1wN6cih2TSchUEkQgw3KTnvXBVgKM7vmn0BLE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansvithkuqi/v3/jVyi7m77CXvQswd6WjYu9E1wN6cih2TSchUEkQgw3KTnvUlVgKM7vmn0BLE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-wancho",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3d80971f-7a4b-459c-a3ff-02d638aa4218",-1277977322),$APP.$cljs$cst$2675$family$$,
"Noto Sans Wancho",$APP.$cljs$cst$725$name$$,"Noto Sans Wancho",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanswancho/v18/zrf-0GXXyfn6Fs0lH9P4cUubP0GBqAPopiRfKp8.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-warang-citi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3d605f17-f6e9-414d-b7aa-e2a8996c68a8",-209135095),$APP.$cljs$cst$2675$family$$,"Noto Sans Warang Citi",$APP.$cljs$cst$725$name$$,"Noto Sans Warang Citi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanswarangciti/v18/EYqtmb9SzL1YtsZSScyKDXIeOv3w-zgsNvKRpeVCCXzdgA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-yi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5da6f3c1-6293-4346-afb4-73807233af08",-1211707958),$APP.$cljs$cst$2675$family$$,"Noto Sans Yi",$APP.$cljs$cst$725$name$$,
"Noto Sans Yi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosansyi/v20/sJoD3LFXjsSdcnzn071rO3apxVDJNVgSNg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-sans-zanabazar-square",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0b8a5d7f-3768-45ba-ac33-4f32dbb3edd4",263897339),$APP.$cljs$cst$2675$family$$,"Noto Sans Zanabazar Square",$APP.$cljs$cst$725$name$$,"Noto Sans Zanabazar Square",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notosanszanabazarsquare/v20/Cn-jJsuGWQxOjaGwMQ6fOicyxLBEMRfDtkzl4uagQtJxOCEgN0Gc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("446e5769-c158-4c9e-87dc-120de29cd053",-461042442),$APP.$cljs$cst$2675$family$$,"Noto Serif",$APP.$cljs$cst$725$name$$,"Noto Serif",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6iaw1J5X9T9RW6j9bNVls-hfgvz8JcMofYTa32J4wsL2JAlAhZqFGjwM0Lhq_Szw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6iaw1J5X9T9RW6j9bNVls-hfgvz8JcMofYTa32J4wsL2JAlAhZKFCjwM0Lhq_Szw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6iaw1J5X9T9RW6j9bNVls-hfgvz8JcMofYTa32J4wsL2JAlAhZ9lCjwM0Lhq_Szw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6iaw1J5X9T9RW6j9bNVls-hfgvz8JcMofYTa32J4wsL2JAlAhZqFCjwM0Lhq_Szw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6iaw1J5X9T9RW6j9bNVls-hfgvz8JcMofYTa32J4wsL2JAlAhZmlCjwM0Lhq_Szw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6iaw1J5X9T9RW6j9bNVls-hfgvz8JcMofYTa32J4wsL2JAlAhZdlejwM0Lhq_Szw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6iaw1J5X9T9RW6j9bNVls-hfgvz8JcMofYTa32J4wsL2JAlAhZT1ejwM0Lhq_Szw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6iaw1J5X9T9RW6j9bNVls-hfgvz8JcMofYTa32J4wsL2JAlAhZKFejwM0Lhq_Szw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6iaw1J5X9T9RW6j9bNVls-hfgvz8JcMofYTa32J4wsL2JAlAhZAVejwM0Lhq_Szw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6saw1J5X9T9RW6j9bNfFIMZhhWnFTyNZIQD1-_FXP0RgnaOg9MYBNLgscPpKrCzyUi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6saw1J5X9T9RW6j9bNfFIMZhhWnFTyNZIQD1-_FXP0RgnaOg9MYBPLg8cPpKrCzyUi.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6saw1J5X9T9RW6j9bNfFIMZhhWnFTyNZIQD1-_FXP0RgnaOg9MYBMVg8cPpKrCzyUi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6saw1J5X9T9RW6j9bNfFIMZhhWnFTyNZIQD1-_FXP0RgnaOg9MYBNLg8cPpKrCzyUi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6saw1J5X9T9RW6j9bNfFIMZhhWnFTyNZIQD1-_FXP0RgnaOg9MYBN5g8cPpKrCzyUi.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6saw1J5X9T9RW6j9bNfFIMZhhWnFTyNZIQD1-_FXP0RgnaOg9MYBOVhMcPpKrCzyUi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6saw1J5X9T9RW6j9bNfFIMZhhWnFTyNZIQD1-_FXP0RgnaOg9MYBOshMcPpKrCzyUi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6saw1J5X9T9RW6j9bNfFIMZhhWnFTyNZIQD1-_FXP0RgnaOg9MYBPLhMcPpKrCzyUi.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserif/v33/ga6saw1J5X9T9RW6j9bNfFIMZhhWnFTyNZIQD1-_FXP0RgnaOg9MYBPihMcPpKrCzyUi.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-ahom",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a7791ac9-7335-4a97-9a41-e69ea8fed2a5",
591018668),$APP.$cljs$cst$2675$family$$,"Noto Serif Ahom",$APP.$cljs$cst$725$name$$,"Noto Serif Ahom",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifahom/v21/FeVIS0hfp6cprmEUffAW_fUL_AN-wuYrPFiwaw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-armenian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("43fd0791-4bc7-4d24-a004-5c3fb19d161e",1287091421),$APP.$cljs$cst$2675$family$$,"Noto Serif Armenian",$APP.$cljs$cst$725$name$$,"Noto Serif Armenian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifarmenian/v30/3XFMEqMt3YoFsciDRZxptyCUKJmytZ0kVU-XvF7QaZuL85rnQ_zDNzDe5xNnKxyZi8ObxvXagGdkbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifarmenian/v30/3XFMEqMt3YoFsciDRZxptyCUKJmytZ0kVU-XvF7QaZuL85rnQ_zDNzDe5xNnKxyZC8KbxvXagGdkbg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifarmenian/v30/3XFMEqMt3YoFsciDRZxptyCUKJmytZ0kVU-XvF7QaZuL85rnQ_zDNzDe5xNnKxyZ1cKbxvXagGdkbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifarmenian/v30/3XFMEqMt3YoFsciDRZxptyCUKJmytZ0kVU-XvF7QaZuL85rnQ_zDNzDe5xNnKxyZi8KbxvXagGdkbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifarmenian/v30/3XFMEqMt3YoFsciDRZxptyCUKJmytZ0kVU-XvF7QaZuL85rnQ_zDNzDe5xNnKxyZucKbxvXagGdkbg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifarmenian/v30/3XFMEqMt3YoFsciDRZxptyCUKJmytZ0kVU-XvF7QaZuL85rnQ_zDNzDe5xNnKxyZVcWbxvXagGdkbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifarmenian/v30/3XFMEqMt3YoFsciDRZxptyCUKJmytZ0kVU-XvF7QaZuL85rnQ_zDNzDe5xNnKxyZbMWbxvXagGdkbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifarmenian/v30/3XFMEqMt3YoFsciDRZxptyCUKJmytZ0kVU-XvF7QaZuL85rnQ_zDNzDe5xNnKxyZC8WbxvXagGdkbg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifarmenian/v30/3XFMEqMt3YoFsciDRZxptyCUKJmytZ0kVU-XvF7QaZuL85rnQ_zDNzDe5xNnKxyZIsWbxvXagGdkbg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-balinese",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1007ea6e-4755-4736-b62f-7e72b623bbf4",
449685020),$APP.$cljs$cst$2675$family$$,"Noto Serif Balinese",$APP.$cljs$cst$725$name$$,"Noto Serif Balinese",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifbalinese/v21/QdVKSS0-JginysQSRvuCmUMB_wVeQAxXRbgJdhapcUU.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-bengali",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6a3d25ba-0a91-4c1a-bd1b-651f5b87d375",-1624866197),$APP.$cljs$cst$2675$family$$,"Noto Serif Bengali",$APP.$cljs$cst$725$name$$,"Noto Serif Bengali",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifbengali/v31/hYkuPvggTvnzO14VSXltirUdnnkt1pwmWrprmO7RjE0a5BtdATYU1crFaM_5JfcAH3qn4LjQH8yD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifbengali/v31/hYkuPvggTvnzO14VSXltirUdnnkt1pwmWrprmO7RjE0a5BtdATYU1crFaM_5JfeAHnqn4LjQH8yD.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifbengali/v31/hYkuPvggTvnzO14VSXltirUdnnkt1pwmWrprmO7RjE0a5BtdATYU1crFaM_5JfdeHnqn4LjQH8yD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifbengali/v31/hYkuPvggTvnzO14VSXltirUdnnkt1pwmWrprmO7RjE0a5BtdATYU1crFaM_5JfcAHnqn4LjQH8yD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifbengali/v31/hYkuPvggTvnzO14VSXltirUdnnkt1pwmWrprmO7RjE0a5BtdATYU1crFaM_5JfcyHnqn4LjQH8yD.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifbengali/v31/hYkuPvggTvnzO14VSXltirUdnnkt1pwmWrprmO7RjE0a5BtdATYU1crFaM_5JffeGXqn4LjQH8yD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifbengali/v31/hYkuPvggTvnzO14VSXltirUdnnkt1pwmWrprmO7RjE0a5BtdATYU1crFaM_5JffnGXqn4LjQH8yD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifbengali/v31/hYkuPvggTvnzO14VSXltirUdnnkt1pwmWrprmO7RjE0a5BtdATYU1crFaM_5JfeAGXqn4LjQH8yD.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifbengali/v31/hYkuPvggTvnzO14VSXltirUdnnkt1pwmWrprmO7RjE0a5BtdATYU1crFaM_5JfepGXqn4LjQH8yD.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-devanagari",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c19d7b2c-8166-42e5-8a26-804b05b165bb",
-364623),$APP.$cljs$cst$2675$family$$,"Noto Serif Devanagari",$APP.$cljs$cst$725$name$$,"Noto Serif Devanagari",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdevanagari/v34/x3dYcl3IZKmUqiMk48ZHXJ5jwU-DZGRSaQ4Hh2dGyFzPLcQPVbnRNeFsw0xRWb6uxTA-og-HMUe1u_dv.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdevanagari/v34/x3dYcl3IZKmUqiMk48ZHXJ5jwU-DZGRSaQ4Hh2dGyFzPLcQPVbnRNeFsw0xRWb6uxTC-ow-HMUe1u_dv.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdevanagari/v34/x3dYcl3IZKmUqiMk48ZHXJ5jwU-DZGRSaQ4Hh2dGyFzPLcQPVbnRNeFsw0xRWb6uxTBgow-HMUe1u_dv.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdevanagari/v34/x3dYcl3IZKmUqiMk48ZHXJ5jwU-DZGRSaQ4Hh2dGyFzPLcQPVbnRNeFsw0xRWb6uxTA-ow-HMUe1u_dv.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdevanagari/v34/x3dYcl3IZKmUqiMk48ZHXJ5jwU-DZGRSaQ4Hh2dGyFzPLcQPVbnRNeFsw0xRWb6uxTAMow-HMUe1u_dv.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdevanagari/v34/x3dYcl3IZKmUqiMk48ZHXJ5jwU-DZGRSaQ4Hh2dGyFzPLcQPVbnRNeFsw0xRWb6uxTDgpA-HMUe1u_dv.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdevanagari/v34/x3dYcl3IZKmUqiMk48ZHXJ5jwU-DZGRSaQ4Hh2dGyFzPLcQPVbnRNeFsw0xRWb6uxTDZpA-HMUe1u_dv.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdevanagari/v34/x3dYcl3IZKmUqiMk48ZHXJ5jwU-DZGRSaQ4Hh2dGyFzPLcQPVbnRNeFsw0xRWb6uxTC-pA-HMUe1u_dv.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdevanagari/v34/x3dYcl3IZKmUqiMk48ZHXJ5jwU-DZGRSaQ4Hh2dGyFzPLcQPVbnRNeFsw0xRWb6uxTCXpA-HMUe1u_dv.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("417cd5e2-500b-4433-85e8-12b58b82f948",1743803356),$APP.$cljs$cst$2675$family$$,"Noto Serif Display",$APP.$cljs$cst$725$name$$,"Noto Serif Display",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buERppa9f8_vkXaZLAgP0G5Wi6QmA1QaeYah2sovLCDq_ZgLyt3idQfktOG-PVpd49gKaDU9hvzC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buERppa9f8_vkXaZLAgP0G5Wi6QmA1QaeYah2sovLCDq_ZgLyt3idQfktOG-PVrd4tgKaDU9hvzC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notoserifdisplay/v29/buERppa9f8_vkXaZLAgP0G5Wi6QmA1QaeYah2sovLCDq_ZgLyt3idQfktOG-PVoD4tgKaDU9hvzC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buERppa9f8_vkXaZLAgP0G5Wi6QmA1QaeYah2sovLCDq_ZgLyt3idQfktOG-PVpd4tgKaDU9hvzC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buERppa9f8_vkXaZLAgP0G5Wi6QmA1QaeYah2sovLCDq_ZgLyt3idQfktOG-PVpv4tgKaDU9hvzC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notoserifdisplay/v29/buERppa9f8_vkXaZLAgP0G5Wi6QmA1QaeYah2sovLCDq_ZgLyt3idQfktOG-PVqD5dgKaDU9hvzC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buERppa9f8_vkXaZLAgP0G5Wi6QmA1QaeYah2sovLCDq_ZgLyt3idQfktOG-PVq65dgKaDU9hvzC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buERppa9f8_vkXaZLAgP0G5Wi6QmA1QaeYah2sovLCDq_ZgLyt3idQfktOG-PVrd5dgKaDU9hvzC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/notoserifdisplay/v29/buERppa9f8_vkXaZLAgP0G5Wi6QmA1QaeYah2sovLCDq_ZgLyt3idQfktOG-PVr05dgKaDU9hvzC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buEPppa9f8_vkXaZLAgP0G5Wi6QmA1QwcLRCOrN8uo7t6FBJOJTQit-N33sQOk-VoTBIYjEfg-zCmf4.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buEPppa9f8_vkXaZLAgP0G5Wi6QmA1QwcLRCOrN8uo7t6FBJOJTQit-N33sQOk-VobBJYjEfg-zCmf4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buEPppa9f8_vkXaZLAgP0G5Wi6QmA1QwcLRCOrN8uo7t6FBJOJTQit-N33sQOk-VoW5JYjEfg-zCmf4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buEPppa9f8_vkXaZLAgP0G5Wi6QmA1QwcLRCOrN8uo7t6FBJOJTQit-N33sQOk-VoTBJYjEfg-zCmf4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buEPppa9f8_vkXaZLAgP0G5Wi6QmA1QwcLRCOrN8uo7t6FBJOJTQit-N33sQOk-VoQJJYjEfg-zCmf4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buEPppa9f8_vkXaZLAgP0G5Wi6QmA1QwcLRCOrN8uo7t6FBJOJTQit-N33sQOk-Voe5OYjEfg-zCmf4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buEPppa9f8_vkXaZLAgP0G5Wi6QmA1QwcLRCOrN8uo7t6FBJOJTQit-N33sQOk-VoddOYjEfg-zCmf4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buEPppa9f8_vkXaZLAgP0G5Wi6QmA1QwcLRCOrN8uo7t6FBJOJTQit-N33sQOk-VobBOYjEfg-zCmf4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,
"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdisplay/v29/buEPppa9f8_vkXaZLAgP0G5Wi6QmA1QwcLRCOrN8uo7t6FBJOJTQit-N33sQOk-VoZlOYjEfg-zCmf4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-dives-akuru",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f8a6d3fb-a30c-4748-8a08-691e6b156ed5",226990806),$APP.$cljs$cst$2675$family$$,"Noto Serif Dives Akuru",$APP.$cljs$cst$725$name$$,
"Noto Serif Dives Akuru",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdivesakuru/v8/QldfNSVMqAsHtsJ_TnD3aT03sMgd57ibeeZT60DIyoV9Ejs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-dogra",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8995c487-3986-49c4-87dc-9432ec2074cd",591727736),$APP.$cljs$cst$2675$family$$,"Noto Serif Dogra",$APP.$cljs$cst$725$name$$,"Noto Serif Dogra",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifdogra/v24/MQpP-XquKMC7ROPP3QOOlm7xPu3fGy63IbPzkns.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-ethiopic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2af85023-4626-4db4-a6c3-4cfc33eb0eb6",-225643494),$APP.$cljs$cst$2675$family$$,"Noto Serif Ethiopic",$APP.$cljs$cst$725$name$$,"Noto Serif Ethiopic",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifethiopic/v32/V8mjoR7-XjwJ8_Au3Ti5tXj5Rd83frpWLK4d-taxqWw2HMWjDxBAg5S_0QsrggxCzSQjkaO9UVLyiw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifethiopic/v32/V8mjoR7-XjwJ8_Au3Ti5tXj5Rd83frpWLK4d-taxqWw2HMWjDxBAg5S_0QsrggxCTSUjkaO9UVLyiw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifethiopic/v32/V8mjoR7-XjwJ8_Au3Ti5tXj5Rd83frpWLK4d-taxqWw2HMWjDxBAg5S_0QsrggxCkyUjkaO9UVLyiw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifethiopic/v32/V8mjoR7-XjwJ8_Au3Ti5tXj5Rd83frpWLK4d-taxqWw2HMWjDxBAg5S_0QsrggxCzSUjkaO9UVLyiw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifethiopic/v32/V8mjoR7-XjwJ8_Au3Ti5tXj5Rd83frpWLK4d-taxqWw2HMWjDxBAg5S_0QsrggxC_yUjkaO9UVLyiw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifethiopic/v32/V8mjoR7-XjwJ8_Au3Ti5tXj5Rd83frpWLK4d-taxqWw2HMWjDxBAg5S_0QsrggxCEyIjkaO9UVLyiw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifethiopic/v32/V8mjoR7-XjwJ8_Au3Ti5tXj5Rd83frpWLK4d-taxqWw2HMWjDxBAg5S_0QsrggxCKiIjkaO9UVLyiw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifethiopic/v32/V8mjoR7-XjwJ8_Au3Ti5tXj5Rd83frpWLK4d-taxqWw2HMWjDxBAg5S_0QsrggxCTSIjkaO9UVLyiw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifethiopic/v32/V8mjoR7-XjwJ8_Au3Ti5tXj5Rd83frpWLK4d-taxqWw2HMWjDxBAg5S_0QsrggxCZCIjkaO9UVLyiw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-georgian",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("112aeb4c-f25e-4dc6-ba4a-4588f5818bc8",1489284476),$APP.$cljs$cst$2675$family$$,"Noto Serif Georgian",$APP.$cljs$cst$725$name$$,"Noto Serif Georgian",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgeorgian/v29/VEMXRpd8s4nv8hG_qOzL7HOAw4nt0Sl_XxyaEduNMvi7T6Y4etRnmGhyLop-R3aSTvsfdzTw-FgZxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgeorgian/v29/VEMXRpd8s4nv8hG_qOzL7HOAw4nt0Sl_XxyaEduNMvi7T6Y4etRnmGhyLop-R3aSzvofdzTw-FgZxQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgeorgian/v29/VEMXRpd8s4nv8hG_qOzL7HOAw4nt0Sl_XxyaEduNMvi7T6Y4etRnmGhyLop-R3aSEPofdzTw-FgZxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgeorgian/v29/VEMXRpd8s4nv8hG_qOzL7HOAw4nt0Sl_XxyaEduNMvi7T6Y4etRnmGhyLop-R3aSTvofdzTw-FgZxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgeorgian/v29/VEMXRpd8s4nv8hG_qOzL7HOAw4nt0Sl_XxyaEduNMvi7T6Y4etRnmGhyLop-R3aSfPofdzTw-FgZxQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgeorgian/v29/VEMXRpd8s4nv8hG_qOzL7HOAw4nt0Sl_XxyaEduNMvi7T6Y4etRnmGhyLop-R3aSkP0fdzTw-FgZxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgeorgian/v29/VEMXRpd8s4nv8hG_qOzL7HOAw4nt0Sl_XxyaEduNMvi7T6Y4etRnmGhyLop-R3aSqf0fdzTw-FgZxQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgeorgian/v29/VEMXRpd8s4nv8hG_qOzL7HOAw4nt0Sl_XxyaEduNMvi7T6Y4etRnmGhyLop-R3aSzv0fdzTw-FgZxQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgeorgian/v29/VEMXRpd8s4nv8hG_qOzL7HOAw4nt0Sl_XxyaEduNMvi7T6Y4etRnmGhyLop-R3aS5_0fdzTw-FgZxQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-grantha",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c6783893-df44-451b-892f-d9ccc63f1b5a",
1176250091),$APP.$cljs$cst$2675$family$$,"Noto Serif Grantha",$APP.$cljs$cst$725$name$$,"Noto Serif Grantha",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgrantha/v22/qkBIXuEH5NzDDvc3fLDYxPk9-Wq3WLiqFENLR7fHGw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-gujarati",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("69e472b5-537d-4ffe-a10b-f3c84dd4b6cd",-200999397),$APP.$cljs$cst$2675$family$$,"Noto Serif Gujarati",$APP.$cljs$cst$725$name$$,"Noto Serif Gujarati",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgujarati/v29/hESa6WBlOixO-3OJ1FTmTsmqlBRUJBVkcgNLpdsspzP2HuYycYzuM1Kf-OJu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgujarati/v29/hESa6WBlOixO-3OJ1FTmTsmqlBRUJBVkcgNLpdsspzP2HuaycIzuM1Kf-OJu.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgujarati/v29/hESa6WBlOixO-3OJ1FTmTsmqlBRUJBVkcgNLpdsspzP2HuZscIzuM1Kf-OJu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgujarati/v29/hESa6WBlOixO-3OJ1FTmTsmqlBRUJBVkcgNLpdsspzP2HuYycIzuM1Kf-OJu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgujarati/v29/hESa6WBlOixO-3OJ1FTmTsmqlBRUJBVkcgNLpdsspzP2HuYAcIzuM1Kf-OJu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgujarati/v29/hESa6WBlOixO-3OJ1FTmTsmqlBRUJBVkcgNLpdsspzP2Hubsd4zuM1Kf-OJu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgujarati/v29/hESa6WBlOixO-3OJ1FTmTsmqlBRUJBVkcgNLpdsspzP2HubVd4zuM1Kf-OJu.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgujarati/v29/hESa6WBlOixO-3OJ1FTmTsmqlBRUJBVkcgNLpdsspzP2Huayd4zuM1Kf-OJu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgujarati/v29/hESa6WBlOixO-3OJ1FTmTsmqlBRUJBVkcgNLpdsspzP2Huabd4zuM1Kf-OJu.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-gurmukhi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b666a0ce-b3c3-4d4c-a3c3-6c09c7271076",-516324E3),$APP.$cljs$cst$2675$family$$,"Noto Serif Gurmukhi",$APP.$cljs$cst$725$name$$,"Noto Serif Gurmukhi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgurmukhi/v22/92z-tA9LNqsg7tCYlXdCV1VPnAEeDU0vLoYMbylXk0xTCr6-eBTNmqVU7y6l.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgurmukhi/v22/92z-tA9LNqsg7tCYlXdCV1VPnAEeDU0vLoYMbylXk0xTCr4-eRTNmqVU7y6l.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgurmukhi/v22/92z-tA9LNqsg7tCYlXdCV1VPnAEeDU0vLoYMbylXk0xTCr7geRTNmqVU7y6l.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgurmukhi/v22/92z-tA9LNqsg7tCYlXdCV1VPnAEeDU0vLoYMbylXk0xTCr6-eRTNmqVU7y6l.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgurmukhi/v22/92z-tA9LNqsg7tCYlXdCV1VPnAEeDU0vLoYMbylXk0xTCr6MeRTNmqVU7y6l.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgurmukhi/v22/92z-tA9LNqsg7tCYlXdCV1VPnAEeDU0vLoYMbylXk0xTCr5gfhTNmqVU7y6l.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgurmukhi/v22/92z-tA9LNqsg7tCYlXdCV1VPnAEeDU0vLoYMbylXk0xTCr5ZfhTNmqVU7y6l.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgurmukhi/v22/92z-tA9LNqsg7tCYlXdCV1VPnAEeDU0vLoYMbylXk0xTCr4-fhTNmqVU7y6l.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifgurmukhi/v22/92z-tA9LNqsg7tCYlXdCV1VPnAEeDU0vLoYMbylXk0xTCr4XfhTNmqVU7y6l.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-hk",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b4fcb2b9-baad-4427-8c1a-f358b377cc8b",
-765716028),$APP.$cljs$cst$2675$family$$,"Noto Serif HK",$APP.$cljs$cst$725$name$$,"Noto Serif HK",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhk/v11/BngdUXBETWXI6LwlBZGcqL-B_KuJFcgfwP_9RMf-K2RmV9Su1M6i.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhk/v11/BngdUXBETWXI6LwlBZGcqL-B_KuJFcgfwP_9RMcgK2RmV9Su1M6i.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhk/v11/BngdUXBETWXI6LwlBZGcqL-B_KuJFcgfwP_9RMd-K2RmV9Su1M6i.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhk/v11/BngdUXBETWXI6LwlBZGcqL-B_KuJFcgfwP_9RMdMK2RmV9Su1M6i.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhk/v11/BngdUXBETWXI6LwlBZGcqL-B_KuJFcgfwP_9RMegLGRmV9Su1M6i.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhk/v11/BngdUXBETWXI6LwlBZGcqL-B_KuJFcgfwP_9RMeZLGRmV9Su1M6i.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhk/v11/BngdUXBETWXI6LwlBZGcqL-B_KuJFcgfwP_9RMf-LGRmV9Su1M6i.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhk/v11/BngdUXBETWXI6LwlBZGcqL-B_KuJFcgfwP_9RMfXLGRmV9Su1M6i.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-hebrew",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e2f01172-40c9-4f1a-be16-fbf70aa595ee",1455520246),$APP.$cljs$cst$2675$family$$,"Noto Serif Hebrew",$APP.$cljs$cst$725$name$$,"Noto Serif Hebrew",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhebrew/v30/k3k0o9MMPvpLmixYH7euCwmkS9DohjX1-kRyiqyBqIxnoLbp93i9IKrXKF_qVAwTAG8_vlQxz24.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhebrew/v30/k3k0o9MMPvpLmixYH7euCwmkS9DohjX1-kRyiqyBqIxnoLbp93i9IKrXKF_qVIwSAG8_vlQxz24.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhebrew/v30/k3k0o9MMPvpLmixYH7euCwmkS9DohjX1-kRyiqyBqIxnoLbp93i9IKrXKF_qVFISAG8_vlQxz24.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhebrew/v30/k3k0o9MMPvpLmixYH7euCwmkS9DohjX1-kRyiqyBqIxnoLbp93i9IKrXKF_qVAwSAG8_vlQxz24.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhebrew/v30/k3k0o9MMPvpLmixYH7euCwmkS9DohjX1-kRyiqyBqIxnoLbp93i9IKrXKF_qVD4SAG8_vlQxz24.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhebrew/v30/k3k0o9MMPvpLmixYH7euCwmkS9DohjX1-kRyiqyBqIxnoLbp93i9IKrXKF_qVNIVAG8_vlQxz24.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhebrew/v30/k3k0o9MMPvpLmixYH7euCwmkS9DohjX1-kRyiqyBqIxnoLbp93i9IKrXKF_qVOsVAG8_vlQxz24.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhebrew/v30/k3k0o9MMPvpLmixYH7euCwmkS9DohjX1-kRyiqyBqIxnoLbp93i9IKrXKF_qVIwVAG8_vlQxz24.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhebrew/v30/k3k0o9MMPvpLmixYH7euCwmkS9DohjX1-kRyiqyBqIxnoLbp93i9IKrXKF_qVKUVAG8_vlQxz24.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-hentaigana",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f1a2840b-90bd-4b6f-a4fc-a048f9fa184c",-1084549560),$APP.$cljs$cst$2675$family$$,"Noto Serif Hentaigana",$APP.$cljs$cst$725$name$$,"Noto Serif Hentaigana",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhentaigana/v17/uk-OEHi3o6EruUbj3pGaDj3siVARn-kqgu1eOHk7wYK23O0hzgwGqxEZWEARdDE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhentaigana/v17/uk-OEHi3o6EruUbj3pGaDj3siVARn-kqgu1eOHk7wYK23O0hztIGqxEZWEARdDE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhentaigana/v17/uk-OEHi3o6EruUbj3pGaDj3siVARn-kqgu1eOHk7wYK23O0hzowGqxEZWEARdDE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhentaigana/v17/uk-OEHi3o6EruUbj3pGaDj3siVARn-kqgu1eOHk7wYK23O0hzr4GqxEZWEARdDE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhentaigana/v17/uk-OEHi3o6EruUbj3pGaDj3siVARn-kqgu1eOHk7wYK23O0hzlIBqxEZWEARdDE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhentaigana/v17/uk-OEHi3o6EruUbj3pGaDj3siVARn-kqgu1eOHk7wYK23O0hzmsBqxEZWEARdDE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhentaigana/v17/uk-OEHi3o6EruUbj3pGaDj3siVARn-kqgu1eOHk7wYK23O0hzgwBqxEZWEARdDE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifhentaigana/v17/uk-OEHi3o6EruUbj3pGaDj3siVARn-kqgu1eOHk7wYK23O0hziUBqxEZWEARdDE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-jp",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ee538118-eb90-4a3d-aa7f-1537ac22dc8f",
1284908697),$APP.$cljs$cst$2675$family$$,"Noto Serif JP",$APP.$cljs$cst$725$name$$,"Noto Serif JP",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifjp/v32/xn71YHs72GKoTvER4Gn3b5eMRtWGkp6o7MjQ2byxOubAILO5wBCU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifjp/v32/xn71YHs72GKoTvER4Gn3b5eMRtWGkp6o7MjQ2bxvOubAILO5wBCU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifjp/v32/xn71YHs72GKoTvER4Gn3b5eMRtWGkp6o7MjQ2bwxOubAILO5wBCU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifjp/v32/xn71YHs72GKoTvER4Gn3b5eMRtWGkp6o7MjQ2bwDOubAILO5wBCU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifjp/v32/xn71YHs72GKoTvER4Gn3b5eMRtWGkp6o7MjQ2bzvPebAILO5wBCU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifjp/v32/xn71YHs72GKoTvER4Gn3b5eMRtWGkp6o7MjQ2bzWPebAILO5wBCU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifjp/v32/xn71YHs72GKoTvER4Gn3b5eMRtWGkp6o7MjQ2byxPebAILO5wBCU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifjp/v32/xn71YHs72GKoTvER4Gn3b5eMRtWGkp6o7MjQ2byYPebAILO5wBCU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-kr",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("df97ee6c-1d8e-47c1-bb01-cdb15b44a773",1678130140),$APP.$cljs$cst$2675$family$$,"Noto Serif KR",$APP.$cljs$cst$725$name$$,"Noto Serif KR",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkr/v30/3JnoSDn90Gmq2mr3blnHaTZXbOtLJDvui3JOnchmeM524ZvTePRu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkr/v30/3JnoSDn90Gmq2mr3blnHaTZXbOtLJDvui3JOnci4eM524ZvTePRu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkr/v30/3JnoSDn90Gmq2mr3blnHaTZXbOtLJDvui3JOncjmeM524ZvTePRu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkr/v30/3JnoSDn90Gmq2mr3blnHaTZXbOtLJDvui3JOncjUeM524ZvTePRu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkr/v30/3JnoSDn90Gmq2mr3blnHaTZXbOtLJDvui3JOncg4f8524ZvTePRu.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkr/v30/3JnoSDn90Gmq2mr3blnHaTZXbOtLJDvui3JOncgBf8524ZvTePRu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkr/v30/3JnoSDn90Gmq2mr3blnHaTZXbOtLJDvui3JOnchmf8524ZvTePRu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkr/v30/3JnoSDn90Gmq2mr3blnHaTZXbOtLJDvui3JOnchPf8524ZvTePRu.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-kannada",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9a3f4b11-30f8-4176-9eb1-651bfa355146",631318915),$APP.$cljs$cst$2675$family$$,"Noto Serif Kannada",$APP.$cljs$cst$725$name$$,"Noto Serif Kannada",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkannada/v30/v6-8GZHLJFKIhClqUYqXDiWqpxQxWSPoW6bz-l4hGHiNgcYCceRJ71svgcI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkannada/v30/v6-8GZHLJFKIhClqUYqXDiWqpxQxWSPoW6bz-l4hGHiNgUYDceRJ71svgcI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkannada/v30/v6-8GZHLJFKIhClqUYqXDiWqpxQxWSPoW6bz-l4hGHiNgZgDceRJ71svgcI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkannada/v30/v6-8GZHLJFKIhClqUYqXDiWqpxQxWSPoW6bz-l4hGHiNgcYDceRJ71svgcI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkannada/v30/v6-8GZHLJFKIhClqUYqXDiWqpxQxWSPoW6bz-l4hGHiNgfQDceRJ71svgcI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkannada/v30/v6-8GZHLJFKIhClqUYqXDiWqpxQxWSPoW6bz-l4hGHiNgRgEceRJ71svgcI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkannada/v30/v6-8GZHLJFKIhClqUYqXDiWqpxQxWSPoW6bz-l4hGHiNgSEEceRJ71svgcI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkannada/v30/v6-8GZHLJFKIhClqUYqXDiWqpxQxWSPoW6bz-l4hGHiNgUYEceRJ71svgcI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkannada/v30/v6-8GZHLJFKIhClqUYqXDiWqpxQxWSPoW6bz-l4hGHiNgW8EceRJ71svgcI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-khitan-small-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2626f5d7-1d1e-4460-bda1-cfeef3313b6c",-1858795529),$APP.$cljs$cst$2675$family$$,"Noto Serif Khitan Small Script",$APP.$cljs$cst$725$name$$,"Noto Serif Khitan Small Script",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkhitansmallscript/v4/jizzRFVKsm4Bt9PrbSzC4KLlQUF5lRJg5j-l5PvyhfTdd4TsZ8lb39iddA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-noto-serif-khmer",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("131c6312-05e0-4954-9b07-4a2313b231b0",2104737793),$APP.$cljs$cst$2675$family$$,"Noto Serif Khmer",$APP.$cljs$cst$725$name$$,"Noto Serif Khmer",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkhmer/v29/-F6UfidqLzI2JPCkXAO2hmogq0146FxtbwKEr951z5s6lI40sDRH_AVhUKdN6B4wXEZK9Xo4xg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkhmer/v29/-F6UfidqLzI2JPCkXAO2hmogq0146FxtbwKEr951z5s6lI40sDRH_AVhUKdNaB8wXEZK9Xo4xg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkhmer/v29/-F6UfidqLzI2JPCkXAO2hmogq0146FxtbwKEr951z5s6lI40sDRH_AVhUKdNth8wXEZK9Xo4xg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkhmer/v29/-F6UfidqLzI2JPCkXAO2hmogq0146FxtbwKEr951z5s6lI40sDRH_AVhUKdN6B8wXEZK9Xo4xg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkhmer/v29/-F6UfidqLzI2JPCkXAO2hmogq0146FxtbwKEr951z5s6lI40sDRH_AVhUKdN2h8wXEZK9Xo4xg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkhmer/v29/-F6UfidqLzI2JPCkXAO2hmogq0146FxtbwKEr951z5s6lI40sDRH_AVhUKdNNhgwXEZK9Xo4xg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkhmer/v29/-F6UfidqLzI2JPCkXAO2hmogq0146FxtbwKEr951z5s6lI40sDRH_AVhUKdNDxgwXEZK9Xo4xg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkhmer/v29/-F6UfidqLzI2JPCkXAO2hmogq0146FxtbwKEr951z5s6lI40sDRH_AVhUKdNaBgwXEZK9Xo4xg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkhmer/v29/-F6UfidqLzI2JPCkXAO2hmogq0146FxtbwKEr951z5s6lI40sDRH_AVhUKdNQRgwXEZK9Xo4xg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-khojki",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e2f048f7-c174-438b-a149-b97e2bf2c9cb",
1216062177),$APP.$cljs$cst$2675$family$$,"Noto Serif Khojki",$APP.$cljs$cst$725$name$$,"Noto Serif Khojki",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkhojki/v13/I_uHMoOduATTei9aP90ctmPGxP2rBKTM4mcQ5M3z9QMY0ghvyZ0Qtc5HAQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkhojki/v13/I_uHMoOduATTei9aP90ctmPGxP2rBKTM4mcQ5M3z9QMY4AhvyZ0Qtc5HAQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkhojki/v13/I_uHMoOduATTei9aP90ctmPGxP2rBKTM4mcQ5M3z9QMYDA9vyZ0Qtc5HAQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifkhojki/v13/I_uHMoOduATTei9aP90ctmPGxP2rBKTM4mcQ5M3z9QMYNQ9vyZ0Qtc5HAQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-lao",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("92be93ec-5dd4-42ea-8605-ef0964fdacdc",-2058799634),$APP.$cljs$cst$2675$family$$,"Noto Serif Lao",$APP.$cljs$cst$725$name$$,"Noto Serif Lao",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriflao/v29/3y9C6bYwcCjmsU8JEzCMxEwQfEBLk3f0rlSqCdaM_LlSNZ59oNw0BWH8VeMLrvOjlmyhHHQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriflao/v29/3y9C6bYwcCjmsU8JEzCMxEwQfEBLk3f0rlSqCdaM_LlSNZ59oNw0BWH8VWMKrvOjlmyhHHQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriflao/v29/3y9C6bYwcCjmsU8JEzCMxEwQfEBLk3f0rlSqCdaM_LlSNZ59oNw0BWH8Vb0KrvOjlmyhHHQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriflao/v29/3y9C6bYwcCjmsU8JEzCMxEwQfEBLk3f0rlSqCdaM_LlSNZ59oNw0BWH8VeMKrvOjlmyhHHQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriflao/v29/3y9C6bYwcCjmsU8JEzCMxEwQfEBLk3f0rlSqCdaM_LlSNZ59oNw0BWH8VdEKrvOjlmyhHHQ.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriflao/v29/3y9C6bYwcCjmsU8JEzCMxEwQfEBLk3f0rlSqCdaM_LlSNZ59oNw0BWH8VT0NrvOjlmyhHHQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriflao/v29/3y9C6bYwcCjmsU8JEzCMxEwQfEBLk3f0rlSqCdaM_LlSNZ59oNw0BWH8VQQNrvOjlmyhHHQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriflao/v29/3y9C6bYwcCjmsU8JEzCMxEwQfEBLk3f0rlSqCdaM_LlSNZ59oNw0BWH8VWMNrvOjlmyhHHQ.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriflao/v29/3y9C6bYwcCjmsU8JEzCMxEwQfEBLk3f0rlSqCdaM_LlSNZ59oNw0BWH8VUoNrvOjlmyhHHQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-makasar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6821566a-2f65-40ae-94c2-1ac20ec53033",
1797640928),$APP.$cljs$cst$2675$family$$,"Noto Serif Makasar",$APP.$cljs$cst$725$name$$,"Noto Serif Makasar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmakasar/v1/memjYbqtyH-NiZpFH_9zcvB_PqkfY9S7j4HTVSmevw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-malayalam",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6443319b-26e0-40fc-b44a-368a7e827674",987175835),$APP.$cljs$cst$2675$family$$,"Noto Serif Malayalam",$APP.$cljs$cst$725$name$$,"Noto Serif Malayalam",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmalayalam/v32/JIAZUU5sdmdP_HMcVcZFcH7DeVBeGVgSMEk2cmVDq1ihUXL1t-1fnVwHpQVySg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmalayalam/v32/JIAZUU5sdmdP_HMcVcZFcH7DeVBeGVgSMEk2cmVDq1ihUXL1N-xfnVwHpQVySg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmalayalam/v32/JIAZUU5sdmdP_HMcVcZFcH7DeVBeGVgSMEk2cmVDq1ihUXL16exfnVwHpQVySg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmalayalam/v32/JIAZUU5sdmdP_HMcVcZFcH7DeVBeGVgSMEk2cmVDq1ihUXL1t-xfnVwHpQVySg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmalayalam/v32/JIAZUU5sdmdP_HMcVcZFcH7DeVBeGVgSMEk2cmVDq1ihUXL1hexfnVwHpQVySg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmalayalam/v32/JIAZUU5sdmdP_HMcVcZFcH7DeVBeGVgSMEk2cmVDq1ihUXL1aetfnVwHpQVySg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmalayalam/v32/JIAZUU5sdmdP_HMcVcZFcH7DeVBeGVgSMEk2cmVDq1ihUXL1UOtfnVwHpQVySg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmalayalam/v32/JIAZUU5sdmdP_HMcVcZFcH7DeVBeGVgSMEk2cmVDq1ihUXL1N-tfnVwHpQVySg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmalayalam/v32/JIAZUU5sdmdP_HMcVcZFcH7DeVBeGVgSMEk2cmVDq1ihUXL1HutfnVwHpQVySg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-myanmar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e465a13f-6592-4daf-8b3f-8102fe640ca4",-1966860993),$APP.$cljs$cst$2675$family$$,"Noto Serif Myanmar",$APP.$cljs$cst$725$name$$,"Noto Serif Myanmar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmyanmar/v14/VuJudM7F2Yv76aBKKs-bHMQfAHUw3jnNwBDsU9X6RPzQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmyanmar/v14/VuJvdM7F2Yv76aBKKs-bHMQfAHUw3jnNbDHMefv2TeXJng.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmyanmar/v14/VuJvdM7F2Yv76aBKKs-bHMQfAHUw3jnNCDLMefv2TeXJng.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmyanmar/v14/VuJsdM7F2Yv76aBKKs-bHMQfAHUw3jn1pBrocdDqRA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmyanmar/v14/VuJvdM7F2Yv76aBKKs-bHMQfAHUw3jnNUDPMefv2TeXJng.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmyanmar/v14/VuJvdM7F2Yv76aBKKs-bHMQfAHUw3jnNfDTMefv2TeXJng.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmyanmar/v14/VuJvdM7F2Yv76aBKKs-bHMQfAHUw3jnNGDXMefv2TeXJng.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmyanmar/v14/VuJvdM7F2Yv76aBKKs-bHMQfAHUw3jnNBDbMefv2TeXJng.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifmyanmar/v14/VuJvdM7F2Yv76aBKKs-bHMQfAHUw3jnNIDfMefv2TeXJng.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-np-hmong",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("522b64c8-8efe-4b2a-9771-11769de6fe89",-1970477020),$APP.$cljs$cst$2675$family$$,"Noto Serif NP Hmong",
$APP.$cljs$cst$725$name$$,"Noto Serif NP Hmong",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifnphmong/v5/pONN1gItFMO79E4L1GPUi-2sixKHZyFj9Jy6_KhXPwzdvbjPhFLp3u0rVO-d.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifnphmong/v5/pONN1gItFMO79E4L1GPUi-2sixKHZyFj9Jy6_KhXPwzdvbj9hFLp3u0rVO-d.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifnphmong/v5/pONN1gItFMO79E4L1GPUi-2sixKHZyFj9Jy6_KhXPwzdvbgRg1Lp3u0rVO-d.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifnphmong/v5/pONN1gItFMO79E4L1GPUi-2sixKHZyFj9Jy6_KhXPwzdvbgog1Lp3u0rVO-d.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-old-uyghur",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2f2d9c22-67a9-4efa-b416-ad54a644033e",18641899),$APP.$cljs$cst$2675$family$$,"Noto Serif Old Uyghur",$APP.$cljs$cst$725$name$$,"Noto Serif Old Uyghur",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifolduyghur/v4/v6-KGZbLJFKIhClqUYqXDiGnrVoFRCW6JdwnKumeF2yVgA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-oriya",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ea35ef90-8517-4abe-ae65-1d6c0ac60120",-158852976),$APP.$cljs$cst$2675$family$$,"Noto Serif Oriya",$APP.$cljs$cst$725$name$$,"Noto Serif Oriya",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriforiya/v6/MjQQmj56u-r69izk_LDqWN7w0cYByutv9qeWYrvLaxrc_Hy-v039MF1j.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",
$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriforiya/v6/MjQQmj56u-r69izk_LDqWN7w0cYByutv9qeWYrvLaxru_Hy-v039MF1j.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriforiya/v6/MjQQmj56u-r69izk_LDqWN7w0cYByutv9qeWYrvLaxoC-3y-v039MF1j.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriforiya/v6/MjQQmj56u-r69izk_LDqWN7w0cYByutv9qeWYrvLaxo7-3y-v039MF1j.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-ottoman-siyaq",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("69c37ef6-33ea-46a6-ac82-f612816ef412",
263536148),$APP.$cljs$cst$2675$family$$,"Noto Serif Ottoman Siyaq",$APP.$cljs$cst$725$name$$,"Noto Serif Ottoman Siyaq",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifottomansiyaq/v2/fC1yPZ9IYnzRhTrrc4s8cSvYI0eozzaFOQ01qoHLJrgA00kAdA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8361e08f-89e4-429e-b575-7bd4578ae5c3",-37962136),$APP.$cljs$cst$2675$family$$,"Noto Serif SC",$APP.$cljs$cst$725$name$$,"Noto Serif SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsc/v34/H4cyBXePl9DZ0Xe7gG9cyOj7uK2-n-D2rd4FY7QCqyWv847hdDWC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsc/v34/H4cyBXePl9DZ0Xe7gG9cyOj7uK2-n-D2rd4FY7TcqyWv847hdDWC.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsc/v34/H4cyBXePl9DZ0Xe7gG9cyOj7uK2-n-D2rd4FY7SCqyWv847hdDWC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsc/v34/H4cyBXePl9DZ0Xe7gG9cyOj7uK2-n-D2rd4FY7SwqyWv847hdDWC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsc/v34/H4cyBXePl9DZ0Xe7gG9cyOj7uK2-n-D2rd4FY7RcrCWv847hdDWC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsc/v34/H4cyBXePl9DZ0Xe7gG9cyOj7uK2-n-D2rd4FY7RlrCWv847hdDWC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsc/v34/H4cyBXePl9DZ0Xe7gG9cyOj7uK2-n-D2rd4FY7QCrCWv847hdDWC.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsc/v34/H4cyBXePl9DZ0Xe7gG9cyOj7uK2-n-D2rd4FY7QrrCWv847hdDWC.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-sinhala",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9a1000a5-d10b-4012-8674-0f4ebdb8e32a",
-447258740),$APP.$cljs$cst$2675$family$$,"Noto Serif Sinhala",$APP.$cljs$cst$725$name$$,"Noto Serif Sinhala",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsinhala/v30/DtVEJwinQqclnZE2CnsPug9lgGC3y2F2nehQ7Eg4EdBKWxPiDxMivFLgRXs_-pGxRlMsxaLRn3W-.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsinhala/v30/DtVEJwinQqclnZE2CnsPug9lgGC3y2F2nehQ7Eg4EdBKWxPiDxMivFLgRXs_-pExR1MsxaLRn3W-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsinhala/v30/DtVEJwinQqclnZE2CnsPug9lgGC3y2F2nehQ7Eg4EdBKWxPiDxMivFLgRXs_-pHvR1MsxaLRn3W-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsinhala/v30/DtVEJwinQqclnZE2CnsPug9lgGC3y2F2nehQ7Eg4EdBKWxPiDxMivFLgRXs_-pGxR1MsxaLRn3W-.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsinhala/v30/DtVEJwinQqclnZE2CnsPug9lgGC3y2F2nehQ7Eg4EdBKWxPiDxMivFLgRXs_-pGDR1MsxaLRn3W-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsinhala/v30/DtVEJwinQqclnZE2CnsPug9lgGC3y2F2nehQ7Eg4EdBKWxPiDxMivFLgRXs_-pFvQFMsxaLRn3W-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsinhala/v30/DtVEJwinQqclnZE2CnsPug9lgGC3y2F2nehQ7Eg4EdBKWxPiDxMivFLgRXs_-pFWQFMsxaLRn3W-.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsinhala/v30/DtVEJwinQqclnZE2CnsPug9lgGC3y2F2nehQ7Eg4EdBKWxPiDxMivFLgRXs_-pExQFMsxaLRn3W-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifsinhala/v30/DtVEJwinQqclnZE2CnsPug9lgGC3y2F2nehQ7Eg4EdBKWxPiDxMivFLgRXs_-pEYQFMsxaLRn3W-.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-tc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("04a1243f-14f3-44cd-a050-f2b4da6e7c93",1008743874),$APP.$cljs$cst$2675$family$$,"Noto Serif TC",$APP.$cljs$cst$725$name$$,"Noto Serif TC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftc/v34/XLYzIZb5bJNDGYxLBibeHZ0BnHwmuanx8cUaGX_aMOpDOWYMr2OM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftc/v34/XLYzIZb5bJNDGYxLBibeHZ0BnHwmuanx8cUaGX8EMOpDOWYMr2OM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftc/v34/XLYzIZb5bJNDGYxLBibeHZ0BnHwmuanx8cUaGX9aMOpDOWYMr2OM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftc/v34/XLYzIZb5bJNDGYxLBibeHZ0BnHwmuanx8cUaGX9oMOpDOWYMr2OM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftc/v34/XLYzIZb5bJNDGYxLBibeHZ0BnHwmuanx8cUaGX-EN-pDOWYMr2OM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftc/v34/XLYzIZb5bJNDGYxLBibeHZ0BnHwmuanx8cUaGX-9N-pDOWYMr2OM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftc/v34/XLYzIZb5bJNDGYxLBibeHZ0BnHwmuanx8cUaGX_aN-pDOWYMr2OM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftc/v34/XLYzIZb5bJNDGYxLBibeHZ0BnHwmuanx8cUaGX_zN-pDOWYMr2OM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-tamil",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6b915070-3450-44cf-ae65-e3bfce80a302",-1898892455),$APP.$cljs$cst$2675$family$$,"Noto Serif Tamil",$APP.$cljs$cst$725$name$$,"Noto Serif Tamil",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjndHr-klIgTfc40komjQ5OObazYp-6H94dBF-RX6nNRJfi-Gf55IgAecattN6R8Pz3v8Etew.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjndHr-klIgTfc40komjQ5OObazYp-6H94dBF-RX6nNRJfi-Gf55IgAecatNN-R8Pz3v8Etew.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjndHr-klIgTfc40komjQ5OObazYp-6H94dBF-RX6nNRJfi-Gf55IgAecat6t-R8Pz3v8Etew.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjndHr-klIgTfc40komjQ5OObazYp-6H94dBF-RX6nNRJfi-Gf55IgAecattN-R8Pz3v8Etew.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjndHr-klIgTfc40komjQ5OObazYp-6H94dBF-RX6nNRJfi-Gf55IgAecatht-R8Pz3v8Etew.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjndHr-klIgTfc40komjQ5OObazYp-6H94dBF-RX6nNRJfi-Gf55IgAecatatiR8Pz3v8Etew.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjndHr-klIgTfc40komjQ5OObazYp-6H94dBF-RX6nNRJfi-Gf55IgAecatU9iR8Pz3v8Etew.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjndHr-klIgTfc40komjQ5OObazYp-6H94dBF-RX6nNRJfi-Gf55IgAecatNNiR8Pz3v8Etew.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjndHr-klIgTfc40komjQ5OObazYp-6H94dBF-RX6nNRJfi-Gf55IgAecatHdiR8Pz3v8Etew.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjldHr-klIgTfc40komjQ5OObazSJaI_D5kV8k_WLwFBmWrypghjeOa18G4fJx5svbzncQ9e3wx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjldHr-klIgTfc40komjQ5OObazSJaI_D5kV8k_WLwFBmWrypghjeOa18G4fJz5s_bzncQ9e3wx.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjldHr-klIgTfc40komjQ5OObazSJaI_D5kV8k_WLwFBmWrypghjeOa18G4fJwns_bzncQ9e3wx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjldHr-klIgTfc40komjQ5OObazSJaI_D5kV8k_WLwFBmWrypghjeOa18G4fJx5s_bzncQ9e3wx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjldHr-klIgTfc40komjQ5OObazSJaI_D5kV8k_WLwFBmWrypghjeOa18G4fJxLs_bzncQ9e3wx.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjldHr-klIgTfc40komjQ5OObazSJaI_D5kV8k_WLwFBmWrypghjeOa18G4fJyntPbzncQ9e3wx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjldHr-klIgTfc40komjQ5OObazSJaI_D5kV8k_WLwFBmWrypghjeOa18G4fJyetPbzncQ9e3wx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjldHr-klIgTfc40komjQ5OObazSJaI_D5kV8k_WLwFBmWrypghjeOa18G4fJz5tPbzncQ9e3wx.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftamil/v31/LYjldHr-klIgTfc40komjQ5OObazSJaI_D5kV8k_WLwFBmWrypghjeOa18G4fJzQtPbzncQ9e3wx.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-tangut",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9d785938-737d-494d-aed1-4f448adbec6e",
-2137884857),$APP.$cljs$cst$2675$family$$,"Noto Serif Tangut",$APP.$cljs$cst$725$name$$,"Noto Serif Tangut",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftangut/v19/xn76YGc72GKoTvER4Gn3b4m9Ern7Em41fcvN2KT4.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-telugu",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("606aa064-9fdf-4e2c-abe2-33000b587747",148942853),$APP.$cljs$cst$2675$family$$,"Noto Serif Telugu",$APP.$cljs$cst$725$name$$,"Noto Serif Telugu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftelugu/v29/tDbl2pCbnkEKmXNVmt2M1q6f4HWbbj6MRbYEeav7Fe9D9TGwuY2fjgrZYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftelugu/v29/tDbl2pCbnkEKmXNVmt2M1q6f4HWbbj6MRbYEeav7Fe9DdTCwuY2fjgrZYA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftelugu/v29/tDbl2pCbnkEKmXNVmt2M1q6f4HWbbj6MRbYEeav7Fe9DqzCwuY2fjgrZYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftelugu/v29/tDbl2pCbnkEKmXNVmt2M1q6f4HWbbj6MRbYEeav7Fe9D9TCwuY2fjgrZYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftelugu/v29/tDbl2pCbnkEKmXNVmt2M1q6f4HWbbj6MRbYEeav7Fe9DxzCwuY2fjgrZYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftelugu/v29/tDbl2pCbnkEKmXNVmt2M1q6f4HWbbj6MRbYEeav7Fe9DKzewuY2fjgrZYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftelugu/v29/tDbl2pCbnkEKmXNVmt2M1q6f4HWbbj6MRbYEeav7Fe9DEjewuY2fjgrZYA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftelugu/v29/tDbl2pCbnkEKmXNVmt2M1q6f4HWbbj6MRbYEeav7Fe9DdTewuY2fjgrZYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftelugu/v29/tDbl2pCbnkEKmXNVmt2M1q6f4HWbbj6MRbYEeav7Fe9DXDewuY2fjgrZYA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-thai",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0f954ed1-e57c-4d40-adc7-5a7e9770bded",-273902686),$APP.$cljs$cst$2675$family$$,"Noto Serif Thai",$APP.$cljs$cst$725$name$$,"Noto Serif Thai",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifthai/v28/k3kyo80MPvpLmixYH7euCxWpSMu3-gcWGj0hHAKGvUQlUv_bCKDUSzB5L0oiFuRRCmsdu0Qx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",
$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifthai/v28/k3kyo80MPvpLmixYH7euCxWpSMu3-gcWGj0hHAKGvUQlUv_bCKDUSzB5L0qiF-RRCmsdu0Qx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifthai/v28/k3kyo80MPvpLmixYH7euCxWpSMu3-gcWGj0hHAKGvUQlUv_bCKDUSzB5L0p8F-RRCmsdu0Qx.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifthai/v28/k3kyo80MPvpLmixYH7euCxWpSMu3-gcWGj0hHAKGvUQlUv_bCKDUSzB5L0oiF-RRCmsdu0Qx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifthai/v28/k3kyo80MPvpLmixYH7euCxWpSMu3-gcWGj0hHAKGvUQlUv_bCKDUSzB5L0oQF-RRCmsdu0Qx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifthai/v28/k3kyo80MPvpLmixYH7euCxWpSMu3-gcWGj0hHAKGvUQlUv_bCKDUSzB5L0r8EORRCmsdu0Qx.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifthai/v28/k3kyo80MPvpLmixYH7euCxWpSMu3-gcWGj0hHAKGvUQlUv_bCKDUSzB5L0rFEORRCmsdu0Qx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifthai/v28/k3kyo80MPvpLmixYH7euCxWpSMu3-gcWGj0hHAKGvUQlUv_bCKDUSzB5L0qiEORRCmsdu0Qx.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifthai/v28/k3kyo80MPvpLmixYH7euCxWpSMu3-gcWGj0hHAKGvUQlUv_bCKDUSzB5L0qLEORRCmsdu0Qx.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-tibetan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("30ec5d32-1c30-44c7-8ba4-f6596587a5d0",1208672142),$APP.$cljs$cst$2675$family$$,"Noto Serif Tibetan",$APP.$cljs$cst$725$name$$,"Noto Serif Tibetan",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftibetan/v24/gokGH7nwAEdtF9N45n0Vaz7O-pk0wsvxHeDXMfqguoCmIrYdPS7rdSy_32c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftibetan/v24/gokGH7nwAEdtF9N45n0Vaz7O-pk0wsvxHeDXMfqguoCmIjYcPS7rdSy_32c.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftibetan/v24/gokGH7nwAEdtF9N45n0Vaz7O-pk0wsvxHeDXMfqguoCmIugcPS7rdSy_32c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftibetan/v24/gokGH7nwAEdtF9N45n0Vaz7O-pk0wsvxHeDXMfqguoCmIrYcPS7rdSy_32c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftibetan/v24/gokGH7nwAEdtF9N45n0Vaz7O-pk0wsvxHeDXMfqguoCmIoQcPS7rdSy_32c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftibetan/v24/gokGH7nwAEdtF9N45n0Vaz7O-pk0wsvxHeDXMfqguoCmImgbPS7rdSy_32c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftibetan/v24/gokGH7nwAEdtF9N45n0Vaz7O-pk0wsvxHeDXMfqguoCmIlEbPS7rdSy_32c.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftibetan/v24/gokGH7nwAEdtF9N45n0Vaz7O-pk0wsvxHeDXMfqguoCmIjYbPS7rdSy_32c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftibetan/v24/gokGH7nwAEdtF9N45n0Vaz7O-pk0wsvxHeDXMfqguoCmIh8bPS7rdSy_32c.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-todhri",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2e42b31d-376a-4b7c-9900-7c060da8989c",636733675),$APP.$cljs$cst$2675$family$$,"Noto Serif Todhri",$APP.$cljs$cst$725$name$$,"Noto Serif Todhri",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftodhri/v3/dFalZeyY-aYz1YVbjMoBWml1nBz7N3ByX6n0fnNk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-toto",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("44cea143-faf0-4dd4-8828-103ca425f8a6",
-258752854),$APP.$cljs$cst$2675$family$$,"Noto Serif Toto",$APP.$cljs$cst$725$name$$,"Noto Serif Toto",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftoto/v7/Ktk6ALSMeZjqPnXk1rCkHYHNtwvtHItpjRP74dHhCy3Il-aj55vdNug.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftoto/v7/Ktk6ALSMeZjqPnXk1rCkHYHNtwvtHItpjRP74dHhCx_Il-aj55vdNug.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftoto/v7/Ktk6ALSMeZjqPnXk1rCkHYHNtwvtHItpjRP74dHhC_PPl-aj55vdNug.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoseriftoto/v7/Ktk6ALSMeZjqPnXk1rCkHYHNtwvtHItpjRP74dHhC8rPl-aj55vdNug.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-vithkuqi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("814885a5-5bfc-4df2-bfbd-e41ca61322ec",718950610),$APP.$cljs$cst$2675$family$$,"Noto Serif Vithkuqi",$APP.$cljs$cst$725$name$$,"Noto Serif Vithkuqi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifvithkuqi/v3/YA94r1OY7FjTf5szakutkndpw9HH-4a4z9pklvg1IQSNcRWMdW2Cqy9A4teH.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifvithkuqi/v3/YA94r1OY7FjTf5szakutkndpw9HH-4a4z9pklvg1IQSNcRW-dW2Cqy9A4teH.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifvithkuqi/v3/YA94r1OY7FjTf5szakutkndpw9HH-4a4z9pklvg1IQSNcRVScm2Cqy9A4teH.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifvithkuqi/v3/YA94r1OY7FjTf5szakutkndpw9HH-4a4z9pklvg1IQSNcRVrcm2Cqy9A4teH.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-serif-yezidi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("95e6518b-a0f3-45e5-bb45-1313a6bcec94",172277819),$APP.$cljs$cst$2675$family$$,"Noto Serif Yezidi",$APP.$cljs$cst$725$name$$,"Noto Serif Yezidi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifyezidi/v23/XLYPIYr5bJNDGYxLBibeHZAn3B5KJENnQjbfhMSVZspD2yEkrlGJgmVCqg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifyezidi/v23/XLYPIYr5bJNDGYxLBibeHZAn3B5KJENnQjbfhMSVZspD6SEkrlGJgmVCqg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifyezidi/v23/XLYPIYr5bJNDGYxLBibeHZAn3B5KJENnQjbfhMSVZspDBSYkrlGJgmVCqg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoserifyezidi/v23/XLYPIYr5bJNDGYxLBibeHZAn3B5KJENnQjbfhMSVZspDPCYkrlGJgmVCqg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-traditional-nushu",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("faba3822-69ec-4a8f-9f6b-26eeef696065",
1953269220),$APP.$cljs$cst$2675$family$$,"Noto Traditional Nushu",$APP.$cljs$cst$725$name$$,"Noto Traditional Nushu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nototraditionalnushu/v23/SZcV3EDkJ7q9FaoMPlmF4Su8hlIjoGh5aj67PUZX6ADm6oa8IXvy1tnPa7QoqirI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nototraditionalnushu/v23/SZcV3EDkJ7q9FaoMPlmF4Su8hlIjoGh5aj67PUZX6ADm6oa8IXus1tnPa7QoqirI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nototraditionalnushu/v23/SZcV3EDkJ7q9FaoMPlmF4Su8hlIjoGh5aj67PUZX6ADm6oa8IXue1tnPa7QoqirI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nototraditionalnushu/v23/SZcV3EDkJ7q9FaoMPlmF4Su8hlIjoGh5aj67PUZX6ADm6oa8IXty0dnPa7QoqirI.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nototraditionalnushu/v23/SZcV3EDkJ7q9FaoMPlmF4Su8hlIjoGh5aj67PUZX6ADm6oa8IXtL0dnPa7QoqirI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-noto-znamenny-musical-notation",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1b8db075-947e-4c37-b9c4-f44f78e92f14",
-690727733),$APP.$cljs$cst$2675$family$$,"Noto Znamenny Musical Notation",$APP.$cljs$cst$725$name$$,"Noto Znamenny Musical Notation",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/notoznamennymusicalnotation/v7/CSRW4ylQnPyaDwAMK1U_AolTaJ4Lz41GcgaIZV9YO2rO88jvtpqqdoWa7g.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nova-cut",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bbd8b4b3-823d-482e-a448-b24cb894541c",342372530),$APP.$cljs$cst$2675$family$$,"Nova Cut",$APP.$cljs$cst$725$name$$,"Nova Cut",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/novacut/v26/KFOkCnSYu8mL-39LkWxPKTM1K9nz.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nova-flat",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5e94543c-9dcd-426d-a1fc-b2e39ea921aa",2024358481),$APP.$cljs$cst$2675$family$$,"Nova Flat",$APP.$cljs$cst$725$name$$,"Nova Flat",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/novaflat/v26/QdVUSTc-JgqpytEbVebEuStkm20oJA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nova-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9ad660f1-9dd7-4208-9469-72051bf38677",
-1608327884),$APP.$cljs$cst$2675$family$$,"Nova Mono",$APP.$cljs$cst$725$name$$,"Nova Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/novamono/v23/Cn-0JtiGWQ5Ajb--MRKfYGxYrdM9Sg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nova-oval",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ebe34c7f-214d-473e-aaee-f7a71abc29bf",-663531268),$APP.$cljs$cst$2675$family$$,"Nova Oval",$APP.$cljs$cst$725$name$$,"Nova Oval",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/novaoval/v26/jAnEgHdmANHvPenMaswCMY-h3cWkWg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nova-round",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1725fab0-af92-4a53-9780-dc28d2410578",-563980784),$APP.$cljs$cst$2675$family$$,"Nova Round",$APP.$cljs$cst$725$name$$,"Nova Round",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/novaround/v23/flU9Rqquw5UhEnlwTJYTYYfeeetYEBc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nova-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("97ebeb6b-8451-43e0-9e86-09d0730cb0aa",
540990799),$APP.$cljs$cst$2675$family$$,"Nova Script",$APP.$cljs$cst$725$name$$,"Nova Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/novascript/v27/7Au7p_IpkSWSTWaFWkumvmQNEl0O0kEx.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nova-slim",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c3d498d7-c441-4853-9732-26e150c6a776",-684880763),$APP.$cljs$cst$2675$family$$,"Nova Slim",$APP.$cljs$cst$725$name$$,"Nova Slim",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/novaslim/v26/Z9XUDmZNQAuem8jyZcn-yMOInrib9Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nova-square",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ca88191e-bfc4-4cf8-93b1-83b8d8769502",-209749583),$APP.$cljs$cst$2675$family$$,"Nova Square",$APP.$cljs$cst$725$name$$,"Nova Square",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/novasquare/v27/RrQUbo9-9DV7b06QHgSWsZhARYMgGtWA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-numans",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("2fe72165-f037-424c-aff5-0796ee69c3cc",-762893609),$APP.$cljs$cst$2675$family$$,"Numans",$APP.$cljs$cst$725$name$$,"Numans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/numans/v16/SlGRmQmGupYAfH8IYRggiHVqaQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nunito",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("30a68587-6e7f-4e74-bd4d-6b2c2bc970d7",296691658),$APP.$cljs$cst$2675$family$$,"Nunito",$APP.$cljs$cst$725$name$$,"Nunito",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunito/v32/XRXI3I6Li01BKofiOc5wtlZ2di8HDDshRTM9jo7eTWk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunito/v32/XRXI3I6Li01BKofiOc5wtlZ2di8HDOUhRTM9jo7eTWk.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunito/v32/XRXI3I6Li01BKofiOc5wtlZ2di8HDLshRTM9jo7eTWk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/nunito/v32/XRXI3I6Li01BKofiOc5wtlZ2di8HDIkhRTM9jo7eTWk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunito/v32/XRXI3I6Li01BKofiOc5wtlZ2di8HDGUmRTM9jo7eTWk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunito/v32/XRXI3I6Li01BKofiOc5wtlZ2di8HDFwmRTM9jo7eTWk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunito/v32/XRXI3I6Li01BKofiOc5wtlZ2di8HDDsmRTM9jo7eTWk.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunito/v32/XRXI3I6Li01BKofiOc5wtlZ2di8HDBImRTM9jo7eTWk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/nunito/v32/XRXK3I6Li01BKofIMPyPbj8d7IEAGXNiLXA3iqzbXWnoeg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunito/v32/XRXK3I6Li01BKofIMPyPbj8d7IEAGXNi83A3iqzbXWnoeg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",
$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunito/v32/XRXK3I6Li01BKofIMPyPbj8d7IEAGXNirXA3iqzbXWnoeg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunito/v32/XRXK3I6Li01BKofIMPyPbj8d7IEAGXNin3A3iqzbXWnoeg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunito/v32/XRXK3I6Li01BKofIMPyPbj8d7IEAGXNic3c3iqzbXWnoeg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunito/v32/XRXK3I6Li01BKofIMPyPbj8d7IEAGXNiSnc3iqzbXWnoeg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunito/v32/XRXK3I6Li01BKofIMPyPbj8d7IEAGXNiLXc3iqzbXWnoeg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunito/v32/XRXK3I6Li01BKofIMPyPbj8d7IEAGXNiBHc3iqzbXWnoeg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nunito-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3da9a50f-e529-4b13-8177-ad84a0572ccf",796056258),$APP.$cljs$cst$2675$family$$,
"Nunito Sans",$APP.$cljs$cst$725$name$$,"Nunito Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1mMImSLYBIv1o4X1M8ce2xCx3yop4tQpF_MeTm0lfGWVpNn64CL7U8upHZIbMV51Q42ptCp5F5bxqqtQ1yiU4GVilntF8kA_Ykqw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1mMImSLYBIv1o4X1M8ce2xCx3yop4tQpF_MeTm0lfGWVpNn64CL7U8upHZIbMV51Q42ptCp5F5bxqqtQ1yiU4GiClntF8kA_Ykqw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1mMImSLYBIv1o4X1M8ce2xCx3yop4tQpF_MeTm0lfGWVpNn64CL7U8upHZIbMV51Q42ptCp5F5bxqqtQ1yiU4G1ilntF8kA_Ykqw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1mMImSLYBIv1o4X1M8ce2xCx3yop4tQpF_MeTm0lfGWVpNn64CL7U8upHZIbMV51Q42ptCp5F5bxqqtQ1yiU4G5ClntF8kA_Ykqw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1mMImSLYBIv1o4X1M8ce2xCx3yop4tQpF_MeTm0lfGWVpNn64CL7U8upHZIbMV51Q42ptCp5F5bxqqtQ1yiU4GCC5ntF8kA_Ykqw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1mMImSLYBIv1o4X1M8ce2xCx3yop4tQpF_MeTm0lfGWVpNn64CL7U8upHZIbMV51Q42ptCp5F5bxqqtQ1yiU4GMS5ntF8kA_Ykqw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1mMImSLYBIv1o4X1M8ce2xCx3yop4tQpF_MeTm0lfGWVpNn64CL7U8upHZIbMV51Q42ptCp5F5bxqqtQ1yiU4GVi5ntF8kA_Ykqw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1mMImSLYBIv1o4X1M8ce2xCx3yop4tQpF_MeTm0lfGWVpNn64CL7U8upHZIbMV51Q42ptCp5F5bxqqtQ1yiU4Gfy5ntF8kA_Ykqw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1kMImSLYBIv1o4X1M8cce4OdVisMz5nZRqy6cmmmU3t2FQWEAEOvV9wNvrwlNstMKW3Y6K5WMwXeVy3GboJ0kTHmoP91UgIfM0qxVd.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1kMImSLYBIv1o4X1M8cce4OdVisMz5nZRqy6cmmmU3t2FQWEAEOvV9wNvrwlNstMKW3Y6K5WMwXeVy3GboJ0kTHmrR91UgIfM0qxVd.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1kMImSLYBIv1o4X1M8cce4OdVisMz5nZRqy6cmmmU3t2FQWEAEOvV9wNvrwlNstMKW3Y6K5WMwXeVy3GboJ0kTHmqP91UgIfM0qxVd.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",
$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1kMImSLYBIv1o4X1M8cce4OdVisMz5nZRqy6cmmmU3t2FQWEAEOvV9wNvrwlNstMKW3Y6K5WMwXeVy3GboJ0kTHmq991UgIfM0qxVd.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1kMImSLYBIv1o4X1M8cce4OdVisMz5nZRqy6cmmmU3t2FQWEAEOvV9wNvrwlNstMKW3Y6K5WMwXeVy3GboJ0kTHmpR8FUgIfM0qxVd.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1kMImSLYBIv1o4X1M8cce4OdVisMz5nZRqy6cmmmU3t2FQWEAEOvV9wNvrwlNstMKW3Y6K5WMwXeVy3GboJ0kTHmpo8FUgIfM0qxVd.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",
$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1kMImSLYBIv1o4X1M8cce4OdVisMz5nZRqy6cmmmU3t2FQWEAEOvV9wNvrwlNstMKW3Y6K5WMwXeVy3GboJ0kTHmoP8FUgIfM0qxVd.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nunitosans/v19/pe1kMImSLYBIv1o4X1M8cce4OdVisMz5nZRqy6cmmmU3t2FQWEAEOvV9wNvrwlNstMKW3Y6K5WMwXeVy3GboJ0kTHmom8FUgIfM0qxVd.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-nuosu-sil",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("988dbfd1-eadb-404e-bbcd-22716a156534",2072748718),$APP.$cljs$cst$2675$family$$,"Nuosu SIL",$APP.$cljs$cst$725$name$$,"Nuosu SIL",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/nuosusil/v12/8vIK7wM3wmRn_kc4uAjeFGxbO_zo-w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-odibee-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ee14ae26-c996-4555-bee8-b27633588914",-1981793728),$APP.$cljs$cst$2675$family$$,"Odibee Sans",$APP.$cljs$cst$725$name$$,"Odibee Sans",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/odibeesans/v20/neIPzCSooYAho6WvjeToRYkyepH9qGsf.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-odor-mean-chey",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ce3de8ce-fcfa-410e-b42d-c956eeff4133",1506579171),$APP.$cljs$cst$2675$family$$,"Odor Mean Chey",$APP.$cljs$cst$725$name$$,"Odor Mean Chey",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/odormeanchey/v31/raxkHiKDttkTe1aOGcJMR1A_4mrY2zqUKafv.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-offside",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f2ffbbae-bd3d-412a-93fa-630ac99f2bf5",-2039774954),$APP.$cljs$cst$2675$family$$,"Offside",$APP.$cljs$cst$725$name$$,"Offside",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/offside/v26/HI_KiYMWKa9QrAykQ5HiRp-dhpQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-oi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("288e7b14-c1a3-45d0-9ea5-c2b908e64460",71710767),$APP.$cljs$cst$2675$family$$,"Oi",$APP.$cljs$cst$725$name$$,"Oi",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oi/v21/w8gXH2EuRqtaut6yjBOG.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ojuju",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1bd5db56-7cdc-48e0-a864-07bcbfe115c2",-1018594103),$APP.$cljs$cst$2675$family$$,"Ojuju",$APP.$cljs$cst$725$name$$,"Ojuju",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ojuju/v5/7r3bqXF7v9ApbrMih3jYQBVm9-n_ypk552FRLYeruQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ojuju/v5/7r3bqXF7v9ApbrMih3jYQBVm9-n_FJk552FRLYeruQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ojuju/v5/7r3bqXF7v9ApbrMih3jYQBVm9-n_Spk552FRLYeruQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ojuju/v5/7r3bqXF7v9ApbrMih3jYQBVm9-n_eJk552FRLYeruQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",
$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ojuju/v5/7r3bqXF7v9ApbrMih3jYQBVm9-n_lJ4552FRLYeruQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ojuju/v5/7r3bqXF7v9ApbrMih3jYQBVm9-n_rZ4552FRLYeruQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ojuju/v5/7r3bqXF7v9ApbrMih3jYQBVm9-n_yp4552FRLYeruQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-old-standard-tt",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("86c3f4b1-21f6-4c90-999b-4691408e1cd1",-1099083306),$APP.$cljs$cst$2675$family$$,"Old Standard TT",
$APP.$cljs$cst$725$name$$,"Old Standard TT",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oldstandardtt/v22/MwQubh3o1vLImiwAVvYawgcf2eVurVC5RHdCZg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oldstandardtt/v22/MwQsbh3o1vLImiwAVvYawgcf2eVer1q9ZnJSZtQG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oldstandardtt/v22/MwQrbh3o1vLImiwAVvYawgcf2eVWEX-dTFxeb80flQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-oldenburg",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7e8f8f3c-71e4-4ecf-940b-81b1023b036f",-853512479),$APP.$cljs$cst$2675$family$$,"Oldenburg",$APP.$cljs$cst$725$name$$,"Oldenburg",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oldenburg/v24/fC1jPY5JYWzbywv7c4V6UU6oXyndrw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ole",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("973273ae-fd79-4d44-9958-711aca14874d",1585815160),$APP.$cljs$cst$2675$family$$,"Ole",$APP.$cljs$cst$725$name$$,"Ole",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ole/v3/dFazZf6Z-rd89fw69qJ_ew.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-oleo-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("02fea394-8b1b-4c45-9c49-c354fb5bf400",
-1347698700),$APP.$cljs$cst$2675$family$$,"Oleo Script",$APP.$cljs$cst$725$name$$,"Oleo Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oleoscript/v15/rax5HieDvtMOe0iICsUccBhasU7Q8Cad.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oleoscript/v15/raxkHieDvtMOe0iICsUccCDmnmrY2zqUKafv.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-oleo-script-swash-caps",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6616fa35-a952-4120-91de-6726707389a6",
-769521200),$APP.$cljs$cst$2675$family$$,"Oleo Script Swash Caps",$APP.$cljs$cst$725$name$$,"Oleo Script Swash Caps",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oleoscriptswashcaps/v14/Noaj6Vb-w5SFbTTAsZP_7JkCS08K-jCzDn_HMXquSY0Hg90.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oleoscriptswashcaps/v14/Noag6Vb-w5SFbTTAsZP_7JkCS08K-jCzDn_HCcaBbYUsn9T5dt0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-onest",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ff12f514-7f56-41ad-a841-77d101f80464",
2002284315),$APP.$cljs$cst$2675$family$$,"Onest",$APP.$cljs$cst$725$name$$,"Onest",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/onest/v9/gNMZW3F-SZuj7zOT0IfSjTS16cPh9R6ZshFMQWXgSQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/onest/v9/gNMZW3F-SZuj7zOT0IfSjTS16cPhdR-ZshFMQWXgSQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/onest/v9/gNMZW3F-SZuj7zOT0IfSjTS16cPhqx-ZshFMQWXgSQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/onest/v9/gNMZW3F-SZuj7zOT0IfSjTS16cPh9R-ZshFMQWXgSQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/onest/v9/gNMZW3F-SZuj7zOT0IfSjTS16cPhxx-ZshFMQWXgSQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/onest/v9/gNMZW3F-SZuj7zOT0IfSjTS16cPhKxiZshFMQWXgSQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/onest/v9/gNMZW3F-SZuj7zOT0IfSjTS16cPhEhiZshFMQWXgSQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/onest/v9/gNMZW3F-SZuj7zOT0IfSjTS16cPhdRiZshFMQWXgSQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/onest/v9/gNMZW3F-SZuj7zOT0IfSjTS16cPhXBiZshFMQWXgSQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-oooh-baby",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("06811fee-a92d-4a11-b7e6-1bb5437ca0d0",145500602),
$APP.$cljs$cst$2675$family$$,"Oooh Baby",$APP.$cljs$cst$725$name$$,"Oooh Baby",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ooohbaby/v4/2sDcZGJWgJTT2Jf76xQDb2-4C7wFZQ.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-open-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0bc250f5-6037-4cd6-86bd-6ffec3bdd046",-412866702),$APP.$cljs$cst$2675$family$$,"Open Sans",$APP.$cljs$cst$725$name$$,"Open Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/opensans/v44/memSYaGs126MiZpBA-UvWbX2vVnXBbObj2OVZyOOSr4dVJWUgsiH0C4nY1M2xLER.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/opensans/v44/memSYaGs126MiZpBA-UvWbX2vVnXBbObj2OVZyOOSr4dVJWUgsjZ0C4nY1M2xLER.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/opensans/v44/memSYaGs126MiZpBA-UvWbX2vVnXBbObj2OVZyOOSr4dVJWUgsjr0C4nY1M2xLER.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/opensans/v44/memSYaGs126MiZpBA-UvWbX2vVnXBbObj2OVZyOOSr4dVJWUgsgH1y4nY1M2xLER.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/opensans/v44/memSYaGs126MiZpBA-UvWbX2vVnXBbObj2OVZyOOSr4dVJWUgsg-1y4nY1M2xLER.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/opensans/v44/memSYaGs126MiZpBA-UvWbX2vVnXBbObj2OVZyOOSr4dVJWUgshZ1y4nY1M2xLER.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/opensans/v44/memQYaGs126MiZpBA-UFUIcVXSCEkx2cmqvXlWq8tWZ0Pw86hd0Rk5hkaVcUwaERZjA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/opensans/v44/memQYaGs126MiZpBA-UFUIcVXSCEkx2cmqvXlWq8tWZ0Pw86hd0Rk8ZkaVcUwaERZjA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/opensans/v44/memQYaGs126MiZpBA-UFUIcVXSCEkx2cmqvXlWq8tWZ0Pw86hd0Rk_RkaVcUwaERZjA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/opensans/v44/memQYaGs126MiZpBA-UFUIcVXSCEkx2cmqvXlWq8tWZ0Pw86hd0RkxhjaVcUwaERZjA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/opensans/v44/memQYaGs126MiZpBA-UFUIcVXSCEkx2cmqvXlWq8tWZ0Pw86hd0RkyFjaVcUwaERZjA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/opensans/v44/memQYaGs126MiZpBA-UFUIcVXSCEkx2cmqvXlWq8tWZ0Pw86hd0Rk0ZjaVcUwaERZjA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-oranienbaum",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0e10f159-9146-4a4b-a329-94031eafd178",2110246482),$APP.$cljs$cst$2675$family$$,
"Oranienbaum",$APP.$cljs$cst$725$name$$,"Oranienbaum",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oranienbaum/v16/OZpHg_txtzZKMuXLIVrx-3zn7kz3dpHc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-orbit",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("74d632e7-d393-4be4-8def-025dbf81822c",-1024199996),$APP.$cljs$cst$2675$family$$,"Orbit",$APP.$cljs$cst$725$name$$,"Orbit",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/orbit/v1/_LOCmz7I-uHd2mjEeqciRwRm.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-orbitron",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("13e65563-4b05-45e0-b6b2-bbe216e714cf",742320586),$APP.$cljs$cst$2675$family$$,"Orbitron",$APP.$cljs$cst$725$name$$,"Orbitron",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/orbitron/v35/yMJMMIlzdpvBhQQL_SC3X9yhF25-T1nyGy6xpmIyXjU1pg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/orbitron/v35/yMJMMIlzdpvBhQQL_SC3X9yhF25-T1nyKS6xpmIyXjU1pg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/orbitron/v35/yMJMMIlzdpvBhQQL_SC3X9yhF25-T1nyxSmxpmIyXjU1pg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/orbitron/v35/yMJMMIlzdpvBhQQL_SC3X9yhF25-T1ny_CmxpmIyXjU1pg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/orbitron/v35/yMJMMIlzdpvBhQQL_SC3X9yhF25-T1nymymxpmIyXjU1pg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/orbitron/v35/yMJMMIlzdpvBhQQL_SC3X9yhF25-T1nysimxpmIyXjU1pg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-oregano",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("07260900-7425-46ba-a51b-41fe8aaf909b",946521949),
$APP.$cljs$cst$2675$family$$,"Oregano",$APP.$cljs$cst$725$name$$,"Oregano",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oregano/v17/If2IXTPxciS3H4S2kZffPznO3yM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oregano/v17/If2KXTPxciS3H4S2oZXVOxvLzyP_qw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-orelega-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("30d400dd-3d4b-46aa-bc2c-7674185ffbcd",-1343791746),$APP.$cljs$cst$2675$family$$,"Orelega One",
$APP.$cljs$cst$725$name$$,"Orelega One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/orelegaone/v14/3qTpojOggD2XtAdFb-QXZGt61EcYaQ7F.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-orienta",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("472d94e6-c366-43c2-99fe-bd68870b1651",-1157046569),$APP.$cljs$cst$2675$family$$,"Orienta",$APP.$cljs$cst$725$name$$,"Orienta",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/orienta/v16/PlI9FlK4Jrl5Y9zNeyeo9HRFhcU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-original-surfer",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2ab8268e-f596-411c-b522-67f0f26c31b8",761759452),$APP.$cljs$cst$2675$family$$,"Original Surfer",$APP.$cljs$cst$725$name$$,"Original Surfer",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/originalsurfer/v25/RWmQoKGZ9vIirYntXJ3_MbekzNMiDEtvAlaMKw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-oswald",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("302b9fc7-da9f-42b6-a71b-ab0376f4f59e",-1258776268),
$APP.$cljs$cst$2675$family$$,"Oswald",$APP.$cljs$cst$725$name$$,"Oswald",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oswald/v57/TK3_WkUHHAIjg75cFRf3bXL8LICs13FvgUFoZAaRliE.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oswald/v57/TK3_WkUHHAIjg75cFRf3bXL8LICs169vgUFoZAaRliE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/oswald/v57/TK3_WkUHHAIjg75cFRf3bXL8LICs1_FvgUFoZAaRliE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oswald/v57/TK3_WkUHHAIjg75cFRf3bXL8LICs18NvgUFoZAaRliE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oswald/v57/TK3_WkUHHAIjg75cFRf3bXL8LICs1y9ogUFoZAaRliE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oswald/v57/TK3_WkUHHAIjg75cFRf3bXL8LICs1xZogUFoZAaRliE.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-outfit",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d3e067f0-c001-43b8-871f-ed1671598cde",1190669979),$APP.$cljs$cst$2675$family$$,"Outfit",$APP.$cljs$cst$725$name$$,"Outfit",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",
$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/outfit/v15/QGYyz_MVcBeNP4NjuGObqx1XmO1I4TC0C4G-EiAou6Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/outfit/v15/QGYyz_MVcBeNP4NjuGObqx1XmO1I4bC1C4G-EiAou6Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/outfit/v15/QGYyz_MVcBeNP4NjuGObqx1XmO1I4W61C4G-EiAou6Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/outfit/v15/QGYyz_MVcBeNP4NjuGObqx1XmO1I4TC1C4G-EiAou6Y.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/outfit/v15/QGYyz_MVcBeNP4NjuGObqx1XmO1I4QK1C4G-EiAou6Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/outfit/v15/QGYyz_MVcBeNP4NjuGObqx1XmO1I4e6yC4G-EiAou6Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/outfit/v15/QGYyz_MVcBeNP4NjuGObqx1XmO1I4deyC4G-EiAou6Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/outfit/v15/QGYyz_MVcBeNP4NjuGObqx1XmO1I4bCyC4G-EiAou6Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/outfit/v15/QGYyz_MVcBeNP4NjuGObqx1XmO1I4ZmyC4G-EiAou6Y.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-over-the-rainbow",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("486ca313-c486-4102-a616-8c333ae35b61",687845934),$APP.$cljs$cst$2675$family$$,"Over the Rainbow",$APP.$cljs$cst$725$name$$,"Over the Rainbow",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overtherainbow/v23/11haGoXG1k_HKhMLUWz7Mc7vvW5upvOm9NA2XG0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-overlock",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ed07a3d0-0061-404f-98f7-4f9fa64d6921",932405526),$APP.$cljs$cst$2675$family$$,"Overlock",$APP.$cljs$cst$725$name$$,"Overlock",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overlock/v19/Z9XVDmdMWRiN1_T9Z4Te4u2El6GC.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",
$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overlock/v19/Z9XTDmdMWRiN1_T9Z7Tc6OmmkrGC7Cs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overlock/v19/Z9XSDmdMWRiN1_T9Z7xizcmMvL2L9TLT.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overlock/v19/Z9XQDmdMWRiN1_T9Z7Tc0FWJtrmp8CLTlNs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/overlock/v19/Z9XSDmdMWRiN1_T9Z7xaz8mMvL2L9TLT.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overlock/v19/Z9XQDmdMWRiN1_T9Z7Tc0G2Ltrmp8CLTlNs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-overlock-sc",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d5f8a8e3-e84d-4d36-9c34-6067dc1ad739",1457452117),$APP.$cljs$cst$2675$family$$,"Overlock SC",$APP.$cljs$cst$725$name$$,"Overlock SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/overlocksc/v25/1cX3aUHKGZrstGAY8nwVzHGAq8Sk1PoH.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-overpass",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b2f7f66e-d1dc-4656-a6f7-dc33b3d2476c",-216863851),$APP.$cljs$cst$2675$family$$,"Overpass",$APP.$cljs$cst$725$name$$,"Overpass",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFda35WCmI96Ajtm83upeyoaX6QPnlo6_PLrOZCLtce-og.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFda35WCmI96Ajtm83upeyoaX6QPnlo6fPPrOZCLtce-og.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFda35WCmI96Ajtm83upeyoaX6QPnlo6ovPrOZCLtce-og.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFda35WCmI96Ajtm83upeyoaX6QPnlo6_PPrOZCLtce-og.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFda35WCmI96Ajtm83upeyoaX6QPnlo6zvPrOZCLtce-og.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFda35WCmI96Ajtm83upeyoaX6QPnlo6IvTrOZCLtce-og.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFda35WCmI96Ajtm83upeyoaX6QPnlo6G_TrOZCLtce-og.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFda35WCmI96Ajtm83upeyoaX6QPnlo6fPTrOZCLtce-og.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/overpass/v19/qFda35WCmI96Ajtm83upeyoaX6QPnlo6VfTrOZCLtce-og.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFdU35WCmI96Ajtm81GgSdXCNs-VMF0vNLADe5qPl8Kuosgz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",
$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFdU35WCmI96Ajtm81GgSdXCNs-VMF0vNLCDepqPl8Kuosgz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFdU35WCmI96Ajtm81GgSdXCNs-VMF0vNLBdepqPl8Kuosgz.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFdU35WCmI96Ajtm81GgSdXCNs-VMF0vNLADepqPl8Kuosgz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFdU35WCmI96Ajtm81GgSdXCNs-VMF0vNLAxepqPl8Kuosgz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFdU35WCmI96Ajtm81GgSdXCNs-VMF0vNLDdfZqPl8Kuosgz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFdU35WCmI96Ajtm81GgSdXCNs-VMF0vNLDkfZqPl8Kuosgz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFdU35WCmI96Ajtm81GgSdXCNs-VMF0vNLCDfZqPl8Kuosgz.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpass/v19/qFdU35WCmI96Ajtm81GgSdXCNs-VMF0vNLCqfZqPl8Kuosgz.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-overpass-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("778bcbca-0edd-4ea8-933f-eb779716f9e8",
41621813),$APP.$cljs$cst$2675$family$$,"Overpass Mono",$APP.$cljs$cst$725$name$$,"Overpass Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpassmono/v21/_Xm5-H86tzKDdAPa-KPQZ-AC_COcRycquHlL6EWKokzzXur-SmIr.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpassmono/v21/_Xm5-H86tzKDdAPa-KPQZ-AC_COcRycquHlL6EXUokzzXur-SmIr.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpassmono/v21/_Xm5-H86tzKDdAPa-KPQZ-AC_COcRycquHlL6EXmokzzXur-SmIr.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpassmono/v21/_Xm5-H86tzKDdAPa-KPQZ-AC_COcRycquHlL6EUKpUzzXur-SmIr.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/overpassmono/v21/_Xm5-H86tzKDdAPa-KPQZ-AC_COcRycquHlL6EUzpUzzXur-SmIr.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ovo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("189ffd85-1019-4ff0-9b37-37e3a74c56a7",-1649229591),$APP.$cljs$cst$2675$family$$,"Ovo",
$APP.$cljs$cst$725$name$$,"Ovo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ovo/v18/yYLl0h7Wyfzjy4Q5_3WVxA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-oxanium",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d1808c3b-52f3-41bd-8dad-c49ed32b3f21",-1724987909),$APP.$cljs$cst$2675$family$$,"Oxanium",$APP.$cljs$cst$725$name$$,"Oxanium",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oxanium/v21/RrQPboN_4yJ0JmiMUW7sIGjd1IA9G83JfniMBXQ7d67x.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oxanium/v21/RrQPboN_4yJ0JmiMUW7sIGjd1IA9G80XfniMBXQ7d67x.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oxanium/v21/RrQPboN_4yJ0JmiMUW7sIGjd1IA9G81JfniMBXQ7d67x.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oxanium/v21/RrQPboN_4yJ0JmiMUW7sIGjd1IA9G817fniMBXQ7d67x.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oxanium/v21/RrQPboN_4yJ0JmiMUW7sIGjd1IA9G82XeXiMBXQ7d67x.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/oxanium/v21/RrQPboN_4yJ0JmiMUW7sIGjd1IA9G82ueXiMBXQ7d67x.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oxanium/v21/RrQPboN_4yJ0JmiMUW7sIGjd1IA9G83JeXiMBXQ7d67x.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-oxygen",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("926785e8-9b52-4906-9e2b-1f906025a5c8",-1292072710),$APP.$cljs$cst$2675$family$$,"Oxygen",$APP.$cljs$cst$725$name$$,"Oxygen",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/oxygen/v16/2sDcZG1Wl4LcnbuCJW8Db2-4C7wFZQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oxygen/v16/2sDfZG1Wl4Lcnbu6iUcnZ0SkAg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oxygen/v16/2sDcZG1Wl4LcnbuCNWgDb2-4C7wFZQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-oxygen-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4d9c4cf4-64ae-4f02-84d7-c73d80909fb6",-1355571339),$APP.$cljs$cst$2675$family$$,"Oxygen Mono",$APP.$cljs$cst$725$name$$,"Oxygen Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/oxygenmono/v15/h0GsssGg9FxgDgCjLeAd7ijfze-PPlUu.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pt-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8a925256-5d79-4021-8729-23a7c32c06dc",
1272736509),$APP.$cljs$cst$2675$family$$,"PT Mono",$APP.$cljs$cst$725$name$$,"PT Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptmono/v14/9oRONYoBnWILk-9ArCg5MtPyAcg.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pt-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1d79201e-aedb-41b6-8926-8e14f62f4bd3",1106983548),$APP.$cljs$cst$2675$family$$,"PT Sans",$APP.$cljs$cst$725$name$$,"PT Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptsans/v18/jizaRExUiTo99u79P0WOxOGMMDQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptsans/v18/jizYRExUiTo99u79D0eEwMOJIDQA-g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptsans/v18/jizfRExUiTo99u79B_mh4OmnLD0Z4zM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptsans/v18/jizdRExUiTo99u79D0e8fOytKB8c8zMrig.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pt-sans-caption",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("af9e97eb-f2a1-4b6a-86ca-2d45c55d366f",-1632193817),$APP.$cljs$cst$2675$family$$,"PT Sans Caption",$APP.$cljs$cst$725$name$$,"PT Sans Caption",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptsanscaption/v20/0FlMVP6Hrxmt7-fsUFhlFXNIlpcqfQXwQy6yxg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptsanscaption/v20/0FlJVP6Hrxmt7-fsUFhlFXNIlpcSwSrUSwWuz38Tgg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pt-sans-narrow",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("57815ca4-4d66-489f-a7ae-3ee64dc747a9",902775212),$APP.$cljs$cst$2675$family$$,"PT Sans Narrow",$APP.$cljs$cst$725$name$$,"PT Sans Narrow",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptsansnarrow/v19/BngRUXNadjH0qYEzV7ab-oWlsYCByxyKeuDp.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptsansnarrow/v19/BngSUXNadjH0qYEzV7ab-oWlsbg95DiCUfzgRd-3.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pt-serif",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7b702bcd-8347-4f10-97eb-51a7855966d0",134652054),$APP.$cljs$cst$2675$family$$,"PT Serif",$APP.$cljs$cst$725$name$$,"PT Serif",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptserif/v19/EJRVQgYoZZY2vCFuvDFRxL6ddjb-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptserif/v19/EJRTQgYoZZY2vCFuvAFTzrq_cyb-vco.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptserif/v19/EJRSQgYoZZY2vCFuvAnt65qVXSr3pNNB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptserif/v19/EJRQQgYoZZY2vCFuvAFT9gaQVy7VocNB6Iw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pt-serif-caption",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("848ba635-dd01-4a2e-a3b8-c00bb5187cd9",520794234),$APP.$cljs$cst$2675$family$$,"PT Serif Caption",$APP.$cljs$cst$725$name$$,"PT Serif Caption",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptserifcaption/v18/ieVl2ZhbGCW-JoW6S34pSDpqYKU059WxDCs5cvI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ptserifcaption/v18/ieVj2ZhbGCW-JoW6S34pSDpqYKU019e7CAk8YvJEeg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pacifico",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7c5b93f0-cf38-4ed0-bfb3-5916b927d09c",-216273338),$APP.$cljs$cst$2675$family$$,"Pacifico",$APP.$cljs$cst$725$name$$,"Pacifico",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pacifico/v23/FwZY7-Qmy14u9lezJ96A4sijpFu_.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-padauk",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f2077273-7f98-4da7-b5f6-e474a5cc237a",41148093),$APP.$cljs$cst$2675$family$$,"Padauk",$APP.$cljs$cst$725$name$$,"Padauk",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/padauk/v17/RrQRboJg-id7OnbBa0_g3LlYbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/padauk/v17/RrQSboJg-id7Onb512DE1JJEZ4YwGg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-padyakke-expanded-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d40bd52c-57ea-4bb9-b473-a79faca0e540",176880806),$APP.$cljs$cst$2675$family$$,"Padyakke Expanded One",$APP.$cljs$cst$725$name$$,"Padyakke Expanded One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/padyakkeexpandedone/v8/K2FvfY9El_tbR0JfHb6WWvrBaU6XAUvC4IAYOKRkpDjeoQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-palanquin",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("eeec6073-2231-4660-bad5-b71650a2efa1",
-106375770),$APP.$cljs$cst$2675$family$$,"Palanquin",$APP.$cljs$cst$725$name$$,"Palanquin",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/palanquin/v17/9XUhlJ90n1fBFg7ceXwUEltI7rWmZzTH.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/palanquin/v17/9XUilJ90n1fBFg7ceXwUvnpoxJuqbi3ezg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/palanquin/v17/9XUilJ90n1fBFg7ceXwU2nloxJuqbi3ezg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/palanquin/v17/9XUnlJ90n1fBFg7ceXwsdlFMzLC2Zw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/palanquin/v17/9XUilJ90n1fBFg7ceXwUgnhoxJuqbi3ezg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/palanquin/v17/9XUilJ90n1fBFg7ceXwUrn9oxJuqbi3ezg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/palanquin/v17/9XUilJ90n1fBFg7ceXwUyn5oxJuqbi3ezg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-palanquin-dark",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("24e54b6e-3c96-4321-b791-0b9f10658dfa",1726768433),$APP.$cljs$cst$2675$family$$,"Palanquin Dark",
$APP.$cljs$cst$725$name$$,"Palanquin Dark",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/palanquindark/v17/xn75YHgl1nqmANMB-26xC7yuF_6OTEo9VtfE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/palanquindark/v17/xn76YHgl1nqmANMB-26xC7yuF8Z6ZW41fcvN2KT4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/palanquindark/v17/xn76YHgl1nqmANMB-26xC7yuF8ZWYm41fcvN2KT4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/palanquindark/v17/xn76YHgl1nqmANMB-26xC7yuF8YyY241fcvN2KT4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-palette-mosaic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("df97c140-61ff-44b7-9e52-dde4b681b63b",
-1906273893),$APP.$cljs$cst$2675$family$$,"Palette Mosaic",$APP.$cljs$cst$725$name$$,"Palette Mosaic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/palettemosaic/v13/AMOIz4aBvWuBFe3TohdW6YZ9MFiy4dxL4jSr.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pangolin",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("00245cdb-46eb-4df7-bc69-a25a19907422",127676765),$APP.$cljs$cst$2675$family$$,"Pangolin",$APP.$cljs$cst$725$name$$,"Pangolin",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pangolin/v12/cY9GfjGcW0FPpi-tWPfK5d3aiLBG.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-paprika",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b06805cc-b8a3-4d98-b856-daa4b90e4c92",-685615291),$APP.$cljs$cst$2675$family$$,"Paprika",$APP.$cljs$cst$725$name$$,"Paprika",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/paprika/v24/8QIJdijZitv49rDfuIgOq7jkAOw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-parastoo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("24e04419-a56b-483f-ab62-25b084e888bb",
549194030),$APP.$cljs$cst$2675$family$$,"Parastoo",$APP.$cljs$cst$725$name$$,"Parastoo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/parastoo/v3/-F6vfj90ITQ4d9euQVDbrtWYW5MNx1dlT6k1FPNkx5rq1w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/parastoo/v3/-F6vfj90ITQ4d9euQVDbrtWYW5MNx1dlfak1FPNkx5rq1w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/parastoo/v3/-F6vfj90ITQ4d9euQVDbrtWYW5MNx1dlka41FPNkx5rq1w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/parastoo/v3/-F6vfj90ITQ4d9euQVDbrtWYW5MNx1dlqK41FPNkx5rq1w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-parisienne",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5af83bfa-bf46-4bd5-b943-885f0baa651f",2030636967),$APP.$cljs$cst$2675$family$$,"Parisienne",$APP.$cljs$cst$725$name$$,"Parisienne",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/parisienne/v14/E21i_d3kivvAkxhLEVZpcy96DuKuavM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-parkinsans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f0fed15f-b780-44e8-afbc-51a1beb46c33",845669681),$APP.$cljs$cst$2675$family$$,"Parkinsans",$APP.$cljs$cst$725$name$$,"Parkinsans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/parkinsans/v3/-W_uXJXvQyPb1QfpBpRrVEgjj0W4zSUk4gSI6R8K-8Z_dt-E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/parkinsans/v3/-W_uXJXvQyPb1QfpBpRrVEgjj0W4zSUk4gTW6R8K-8Z_dt-E.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/parkinsans/v3/-W_uXJXvQyPb1QfpBpRrVEgjj0W4zSUk4gTk6R8K-8Z_dt-E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/parkinsans/v3/-W_uXJXvQyPb1QfpBpRrVEgjj0W4zSUk4gQI7h8K-8Z_dt-E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/parkinsans/v3/-W_uXJXvQyPb1QfpBpRrVEgjj0W4zSUk4gQx7h8K-8Z_dt-E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/parkinsans/v3/-W_uXJXvQyPb1QfpBpRrVEgjj0W4zSUk4gRW7h8K-8Z_dt-E.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-passero-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("523304d9-387d-427e-9bf2-f19fca47c05f",-101986546),$APP.$cljs$cst$2675$family$$,"Passero One",$APP.$cljs$cst$725$name$$,
"Passero One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/passeroone/v28/JTUTjIko8DOq5FeaeEAjgE5B5Arr-s50.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-passion-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d8d4a277-27fa-4bf3-8f21-b21847be41e3",1844118493),$APP.$cljs$cst$2675$family$$,"Passion One",$APP.$cljs$cst$725$name$$,"Passion One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/passionone/v20/PbynFmL8HhTPqbjUzux3JHuW_Frg6YoV.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/passionone/v20/Pby6FmL8HhTPqbjUzux3JEMq037owpYcuH8y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",
$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/passionone/v20/Pby6FmL8HhTPqbjUzux3JEMS0X7owpYcuH8y.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-passions-conflict",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a5ce633a-060d-4d06-803d-d1f15497501f",459562235),$APP.$cljs$cst$2675$family$$,"Passions Conflict",$APP.$cljs$cst$725$name$$,
"Passions Conflict",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/passionsconflict/v9/kmKnZrcrFhfafnWX9x0GuEC-zowow5NeYRI4CN2V.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-pathway-extreme",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a9210105-1946-4e49-b16d-46202b52f63e",26020505),$APP.$cljs$cst$2675$family$$,"Pathway Extreme",$APP.$cljs$cst$725$name$$,"Pathway Extreme",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI6zCC3pJ0rsaH2_sD-QttXPfDPonvkQ-pxx5gufvP2VmLjiFyxGf8BLymNjYv2Oy6vkLmw4xak2Nx1Kyw3igP5eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI6zCC3pJ0rsaH2_sD-QttXPfDPonvkQ-pxx5gufvP2VmLjiFyxGf8BLymNjYv2Oy6vkLmw4xakWN11Kyw3igP5eg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI6zCC3pJ0rsaH2_sD-QttXPfDPonvkQ-pxx5gufvP2VmLjiFyxGf8BLymNjYv2Oy6vkLmw4xakht11Kyw3igP5eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI6zCC3pJ0rsaH2_sD-QttXPfDPonvkQ-pxx5gufvP2VmLjiFyxGf8BLymNjYv2Oy6vkLmw4xak2N11Kyw3igP5eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI6zCC3pJ0rsaH2_sD-QttXPfDPonvkQ-pxx5gufvP2VmLjiFyxGf8BLymNjYv2Oy6vkLmw4xak6t11Kyw3igP5eg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI6zCC3pJ0rsaH2_sD-QttXPfDPonvkQ-pxx5gufvP2VmLjiFyxGf8BLymNjYv2Oy6vkLmw4xakBtp1Kyw3igP5eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI6zCC3pJ0rsaH2_sD-QttXPfDPonvkQ-pxx5gufvP2VmLjiFyxGf8BLymNjYv2Oy6vkLmw4xakP9p1Kyw3igP5eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI6zCC3pJ0rsaH2_sD-QttXPfDPonvkQ-pxx5gufvP2VmLjiFyxGf8BLymNjYv2Oy6vkLmw4xakWNp1Kyw3igP5eg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI6zCC3pJ0rsaH2_sD-QttXPfDPonvkQ-pxx5gufvP2VmLjiFyxGf8BLymNjYv2Oy6vkLmw4xakcdp1Kyw3igP5eg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI4zCC3pJ0rsaH2_sD-QttXPfDlq0kVrdFsAHYoa7O3LCjRa7zISmmvKDxFz3m_CdF3-dIqTRGxEJ6daSYzqAbpepnF.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI4zCC3pJ0rsaH2_sD-QttXPfDlq0kVrdFsAHYoa7O3LCjRa7zISmmvKDxFz3m_CdF3-dIqTRGxEJ4daCYzqAbpepnF.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI4zCC3pJ0rsaH2_sD-QttXPfDlq0kVrdFsAHYoa7O3LCjRa7zISmmvKDxFz3m_CdF3-dIqTRGxEJ7DaCYzqAbpepnF.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI4zCC3pJ0rsaH2_sD-QttXPfDlq0kVrdFsAHYoa7O3LCjRa7zISmmvKDxFz3m_CdF3-dIqTRGxEJ6daCYzqAbpepnF.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI4zCC3pJ0rsaH2_sD-QttXPfDlq0kVrdFsAHYoa7O3LCjRa7zISmmvKDxFz3m_CdF3-dIqTRGxEJ6vaCYzqAbpepnF.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI4zCC3pJ0rsaH2_sD-QttXPfDlq0kVrdFsAHYoa7O3LCjRa7zISmmvKDxFz3m_CdF3-dIqTRGxEJ5DbyYzqAbpepnF.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",
$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI4zCC3pJ0rsaH2_sD-QttXPfDlq0kVrdFsAHYoa7O3LCjRa7zISmmvKDxFz3m_CdF3-dIqTRGxEJ56byYzqAbpepnF.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI4zCC3pJ0rsaH2_sD-QttXPfDlq0kVrdFsAHYoa7O3LCjRa7zISmmvKDxFz3m_CdF3-dIqTRGxEJ4dbyYzqAbpepnF.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pathwayextreme/v7/neI4zCC3pJ0rsaH2_sD-QttXPfDlq0kVrdFsAHYoa7O3LCjRa7zISmmvKDxFz3m_CdF3-dIqTRGxEJ40byYzqAbpepnF.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pathway-gothic-one",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("a31ec677-4990-4749-8633-f2e90808071e",-447329894),$APP.$cljs$cst$2675$family$$,"Pathway Gothic One",$APP.$cljs$cst$725$name$$,"Pathway Gothic One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/pathwaygothicone/v16/MwQrbgD32-KAvjkYGNUUxAtW7pEBwx-dTFxeb80flQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-patrick-hand",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("363c0223-807c-4aa5-aa70-001c300f805b",-12054999),$APP.$cljs$cst$2675$family$$,"Patrick Hand",$APP.$cljs$cst$725$name$$,"Patrick Hand",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/patrickhand/v25/LDI1apSQOAYtSuYWp8ZhfYeMWcjKm7sp8g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-patrick-hand-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("909890e6-2724-4644-a7d3-aad44703717e",-1284759399),
$APP.$cljs$cst$2675$family$$,"Patrick Hand SC",$APP.$cljs$cst$725$name$$,"Patrick Hand SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/patrickhandsc/v17/0nkwC9f7MfsBiWcLtY65AWDK873ViSi6JQc7Vg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pattaya",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6a59ee42-b82b-4250-b48e-7b26aa0d3c50",438504804),$APP.$cljs$cst$2675$family$$,"Pattaya",$APP.$cljs$cst$725$name$$,"Pattaya",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pattaya/v18/ea8ZadcqV_zkHY-XNdCn92ZEmVs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-patua-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("240ad946-be6f-447c-b99c-13fbf5ff24d0",554408505),$APP.$cljs$cst$2675$family$$,"Patua One",$APP.$cljs$cst$725$name$$,"Patua One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/patuaone/v22/ZXuke1cDvLCKLDcimxBI5PNvNA9LuA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pavanam",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("760a7377-8d78-4fd3-8e69-7ebd2cd04e03",
-1507855992),$APP.$cljs$cst$2675$family$$,"Pavanam",$APP.$cljs$cst$725$name$$,"Pavanam",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pavanam/v13/BXRrvF_aiezLh0xPDOtQ9Wf0QcE.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-paytone-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0de958cb-1d93-4a91-978e-b24265608f63",-467727498),$APP.$cljs$cst$2675$family$$,"Paytone One",$APP.$cljs$cst$725$name$$,"Paytone One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/paytoneone/v25/0nksC9P7MfYHj2oFtYm2CiTqivr9iBq_.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-peddana",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1fd07b86-881c-4ff2-9dff-10bc55d04014",1194218164),$APP.$cljs$cst$2675$family$$,"Peddana",$APP.$cljs$cst$725$name$$,"Peddana",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/peddana/v24/aFTU7PBhaX89UcKWhh2aBYyMcKw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-peralta",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6c335395-4985-47b2-b859-1a13d942d45e",
2115492982),$APP.$cljs$cst$2675$family$$,"Peralta",$APP.$cljs$cst$725$name$$,"Peralta",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/peralta/v21/hYkJPu0-RP_9d3kRGxAhrv956B8.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-permanent-marker",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f03e4b84-6356-4fb1-b94b-4e9eee67a557",1135530717),$APP.$cljs$cst$2675$family$$,"Permanent Marker",$APP.$cljs$cst$725$name$$,"Permanent Marker",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/permanentmarker/v16/Fh4uPib9Iyv2ucM6pGQMWimMp004HaqIfrT5nlk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-petemoss",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4045856b-271d-4c33-a454-d12d90be257d",1280302073),$APP.$cljs$cst$2675$family$$,"Petemoss",$APP.$cljs$cst$725$name$$,"Petemoss",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petemoss/v9/A2BZn5tA2xgtGWHZgxkesKb9UouQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-petit-formal-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fc81b535-5778-410f-a7ba-01968bb08ed4",-1434917118),$APP.$cljs$cst$2675$family$$,"Petit Formal Script",$APP.$cljs$cst$725$name$$,"Petit Formal Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petitformalscript/v19/B50TF6xQr2TXJBnGOFME6u5OR83oRP5qoHnqP4gZSiE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-petrona",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("89dcc522-52a3-4046-ba0f-b40612281446",-751275032),$APP.$cljs$cst$2675$family$$,"Petrona",$APP.$cljs$cst$725$name$$,"Petrona",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGl4_NXL7bZo9XXq35wRLONYyOjFk6NsARBH452Mvds.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/petrona/v36/mtGl4_NXL7bZo9XXq35wRLONYyOjFk4NsQRBH452Mvds.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGl4_NXL7bZo9XXq35wRLONYyOjFk7TsQRBH452Mvds.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGl4_NXL7bZo9XXq35wRLONYyOjFk6NsQRBH452Mvds.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGl4_NXL7bZo9XXq35wRLONYyOjFk6_sQRBH452Mvds.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGl4_NXL7bZo9XXq35wRLONYyOjFk5TtgRBH452Mvds.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/petrona/v36/mtGl4_NXL7bZo9XXq35wRLONYyOjFk5qtgRBH452Mvds.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGl4_NXL7bZo9XXq35wRLONYyOjFk4NtgRBH452Mvds.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,
"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGl4_NXL7bZo9XXq35wRLONYyOjFk4ktgRBH452Mvds.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGr4_NXL7bZo9XXgXdCu2vkCLkNEVtF8uwDFYpUN-dsIWs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGr4_NXL7bZo9XXgXdCu2vkCLkNEVtF8mwCFYpUN-dsIWs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGr4_NXL7bZo9XXgXdCu2vkCLkNEVtF8rICFYpUN-dsIWs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGr4_NXL7bZo9XXgXdCu2vkCLkNEVtF8uwCFYpUN-dsIWs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGr4_NXL7bZo9XXgXdCu2vkCLkNEVtF8t4CFYpUN-dsIWs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGr4_NXL7bZo9XXgXdCu2vkCLkNEVtF8jIFFYpUN-dsIWs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGr4_NXL7bZo9XXgXdCu2vkCLkNEVtF8gsFFYpUN-dsIWs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGr4_NXL7bZo9XXgXdCu2vkCLkNEVtF8mwFFYpUN-dsIWs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/petrona/v36/mtGr4_NXL7bZo9XXgXdCu2vkCLkNEVtF8kUFFYpUN-dsIWs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-phetsarath",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dc96c0f3-c7b8-4420-b3a6-2eb7ec077403",1668689220),$APP.$cljs$cst$2675$family$$,"Phetsarath",$APP.$cljs$cst$725$name$$,"Phetsarath",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/phetsarath/v3/N0bQ2SpTP-plK0uWayAYAd79nd_QeZA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/phetsarath/v3/N0bT2SpTP-plK0uWayAYOWLSudf7ZZlIHD0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-philosopher",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fb00292a-42de-4d24-b9d3-63fc473c6fab",325923374),$APP.$cljs$cst$2675$family$$,"Philosopher",$APP.$cljs$cst$725$name$$,"Philosopher",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/philosopher/v21/vEFV2_5QCwIS4_Dhez5jcVBpRUwU08qe.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/philosopher/v21/vEFX2_5QCwIS4_Dhez5jcWBrT0g21tqeR7c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",
$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/philosopher/v21/vEFI2_5QCwIS4_Dhez5jcWjVamgc-NaXXq7H.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/philosopher/v21/vEFK2_5QCwIS4_Dhez5jcWBrd_QZ8tK1W77HtMo.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-phudu",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2b835149-42ef-4213-8a23-14fb538e2c8c",1422111374),$APP.$cljs$cst$2675$family$$,"Phudu",$APP.$cljs$cst$725$name$$,"Phudu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/phudu/v6/0FlJVPSHk0ya-7OUeO_U-Lwm7PkK62zUSwWuz38Tgg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/phudu/v6/0FlJVPSHk0ya-7OUeO_U-Lwm7PkKtWzUSwWuz38Tgg.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/phudu/v6/0FlJVPSHk0ya-7OUeO_U-Lwm7PkKh2zUSwWuz38Tgg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/phudu/v6/0FlJVPSHk0ya-7OUeO_U-Lwm7PkKa2vUSwWuz38Tgg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/phudu/v6/0FlJVPSHk0ya-7OUeO_U-Lwm7PkKUmvUSwWuz38Tgg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",
$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/phudu/v6/0FlJVPSHk0ya-7OUeO_U-Lwm7PkKNWvUSwWuz38Tgg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/phudu/v6/0FlJVPSHk0ya-7OUeO_U-Lwm7PkKHGvUSwWuz38Tgg.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-piazzolla",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d88d68be-a8b5-49b5-adbf-c9f0649c32fa",-201554154),$APP.$cljs$cst$2675$family$$,"Piazzolla",$APP.$cljs$cst$725$name$$,"Piazzolla",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",
$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b52SlTPu5rIkWIZjVKKtYtfxYqZ4RJBFzFfYUjkSDdlqZgy7LYx3Ly1AHfAAy5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b52SlTPu5rIkWIZjVKKtYtfxYqZ4RJBFzFfYUjkSDdlqZgy7JYxnLy1AHfAAy5.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b52SlTPu5rIkWIZjVKKtYtfxYqZ4RJBFzFfYUjkSDdlqZgy7KGxnLy1AHfAAy5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b52SlTPu5rIkWIZjVKKtYtfxYqZ4RJBFzFfYUjkSDdlqZgy7LYxnLy1AHfAAy5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b52SlTPu5rIkWIZjVKKtYtfxYqZ4RJBFzFfYUjkSDdlqZgy7LqxnLy1AHfAAy5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b52SlTPu5rIkWIZjVKKtYtfxYqZ4RJBFzFfYUjkSDdlqZgy7IGwXLy1AHfAAy5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b52SlTPu5rIkWIZjVKKtYtfxYqZ4RJBFzFfYUjkSDdlqZgy7I_wXLy1AHfAAy5.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b52SlTPu5rIkWIZjVKKtYtfxYqZ4RJBFzFfYUjkSDdlqZgy7JYwXLy1AHfAAy5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b52SlTPu5rIkWIZjVKKtYtfxYqZ4RJBFzFfYUjkSDdlqZgy7JxwXLy1AHfAAy5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b72SlTPu5rIkWIZjVgI-TckS03oGpPETyEJ88Rbvi0_TzOzKcQhZqw3gX9BRy5m5M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b72SlTPu5rIkWIZjVgI-TckS03oGpPETyEJ88Rbvi0_TzOzKcQhRqx3gX9BRy5m5M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/piazzolla/v40/N0b72SlTPu5rIkWIZjVgI-TckS03oGpPETyEJ88Rbvi0_TzOzKcQhcSx3gX9BRy5m5M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b72SlTPu5rIkWIZjVgI-TckS03oGpPETyEJ88Rbvi0_TzOzKcQhZqx3gX9BRy5m5M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b72SlTPu5rIkWIZjVgI-TckS03oGpPETyEJ88Rbvi0_TzOzKcQhaix3gX9BRy5m5M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/piazzolla/v40/N0b72SlTPu5rIkWIZjVgI-TckS03oGpPETyEJ88Rbvi0_TzOzKcQhUS23gX9BRy5m5M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b72SlTPu5rIkWIZjVgI-TckS03oGpPETyEJ88Rbvi0_TzOzKcQhX223gX9BRy5m5M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piazzolla/v40/N0b72SlTPu5rIkWIZjVgI-TckS03oGpPETyEJ88Rbvi0_TzOzKcQhRq23gX9BRy5m5M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/piazzolla/v40/N0b72SlTPu5rIkWIZjVgI-TckS03oGpPETyEJ88Rbvi0_TzOzKcQhTO23gX9BRy5m5M.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-piedra",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2aff5c61-ab68-484b-8186-ab8f2d072a19",-805809247),$APP.$cljs$cst$2675$family$$,"Piedra",$APP.$cljs$cst$725$name$$,"Piedra",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/piedra/v27/ke8kOg8aN0Bn7hTunEyHN_M3gA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pinyon-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("af5fec35-e94a-4f7d-adec-79fee2c0f3e0",-1735117783),$APP.$cljs$cst$2675$family$$,
"Pinyon Script",$APP.$cljs$cst$725$name$$,"Pinyon Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pinyonscript/v24/6xKpdSJbL9-e9LuoeQiDRQR8aOLQO4bhiDY.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pirata-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("963830fb-5f54-4ec8-9eaa-5bcaf4f4362d",-90918981),$APP.$cljs$cst$2675$family$$,"Pirata One",$APP.$cljs$cst$725$name$$,"Pirata One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pirataone/v23/I_urMpiDvgLdLh0fAtoftiiEr5_BdZ8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pixelify-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b7d97513-b280-45e7-8b9c-728ae9366deb",-1228124938),$APP.$cljs$cst$2675$family$$,"Pixelify Sans",$APP.$cljs$cst$725$name$$,"Pixelify Sans",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pixelifysans/v3/CHy2V-3HFUT7aC4iv1TxGDR9DHEserHN25py2TTp0H1Yb5JagkmX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pixelifysans/v3/CHy2V-3HFUT7aC4iv1TxGDR9DHEserHN25py2TTb0H1Yb5JagkmX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pixelifysans/v3/CHy2V-3HFUT7aC4iv1TxGDR9DHEserHN25py2TQ3131Yb5JagkmX.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pixelifysans/v3/CHy2V-3HFUT7aC4iv1TxGDR9DHEserHN25py2TQO131Yb5JagkmX.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-plaster",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f2cfaa8f-a595-4dee-abc8-f82169e002d8",
-73326617),$APP.$cljs$cst$2675$family$$,"Plaster",$APP.$cljs$cst$725$name$$,"Plaster",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/plaster/v25/DdTm79QatW80eRh4Ei5JOtLOeLI.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-platypi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0ee401e8-21ef-4609-b870-3503e263a2ee",-2091844970),$APP.$cljs$cst$2675$family$$,"Platypi",$APP.$cljs$cst$725$name$$,"Platypi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/platypi/v6/bMromSGU7pMlaX6-PAmuwBQP4Hwe02It4p9juxgnYP1P.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/platypi/v6/bMromSGU7pMlaX6-PAmuwBQP4Hwe02Jz4p9juxgnYP1P.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/platypi/v6/bMromSGU7pMlaX6-PAmuwBQP4Hwe02JB4p9juxgnYP1P.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/platypi/v6/bMromSGU7pMlaX6-PAmuwBQP4Hwe02Kt5Z9juxgnYP1P.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/platypi/v6/bMromSGU7pMlaX6-PAmuwBQP4Hwe02KU5Z9juxgnYP1P.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/platypi/v6/bMromSGU7pMlaX6-PAmuwBQP4Hwe02Lz5Z9juxgnYP1P.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/platypi/v6/bMrmmSGU7pMlaX6-FgCcP8xmi-aw1He7oSkgsRwFZe1PPTo.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/platypi/v6/bMrmmSGU7pMlaX6-FgCcP8xmi-aw1He7oXcgsRwFZe1PPTo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/platypi/v6/bMrmmSGU7pMlaX6-FgCcP8xmi-aw1He7oUUgsRwFZe1PPTo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/platypi/v6/bMrmmSGU7pMlaX6-FgCcP8xmi-aw1He7oaknsRwFZe1PPTo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/platypi/v6/bMrmmSGU7pMlaX6-FgCcP8xmi-aw1He7oZAnsRwFZe1PPTo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/platypi/v6/bMrmmSGU7pMlaX6-FgCcP8xmi-aw1He7ofcnsRwFZe1PPTo.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-play",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e118285c-39f4-477a-93f8-198c11b2fbfd",2132831869),$APP.$cljs$cst$2675$family$$,"Play",$APP.$cljs$cst$725$name$$,"Play",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/play/v21/6aez4K2oVqwIjtI8Hp8Tx3A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/play/v21/6ae84K2oVqwItm4TOpc423nTJTM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-playball",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2e4ebb30-fdba-4225-ba20-70ba4fa23dd6",-936350327),$APP.$cljs$cst$2675$family$$,"Playball",$APP.$cljs$cst$725$name$$,"Playball",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playball/v22/TK3gWksYAxQ7jbsKcj8Dl-tPKo2t.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playfair",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7a88f379-b1d4-4cf6-9069-d47a3a09f263",787092780),$APP.$cljs$cst$2675$family$$,"Playfair",$APP.$cljs$cst$725$name$$,"Playfair",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfair/v10/0nkQC9D7PO4KhmUJ5_zTZ_4MYQXznAK-TUcZXKO3UMnW6VNpe4-SiiZ4b8h5G3GutPlKetgdoSMw5ifm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfair/v10/0nkQC9D7PO4KhmUJ5_zTZ_4MYQXznAK-TUcZXKO3UMnW6VNpe4-SiiZ4b8h5G3GutPkUetgdoSMw5ifm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfair/v10/0nkQC9D7PO4KhmUJ5_zTZ_4MYQXznAK-TUcZXKO3UMnW6VNpe4-SiiZ4b8h5G3GutPkmetgdoSMw5ifm.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfair/v10/0nkQC9D7PO4KhmUJ5_zTZ_4MYQXznAK-TUcZXKO3UMnW6VNpe4-SiiZ4b8h5G3GutPnKfdgdoSMw5ifm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfair/v10/0nkQC9D7PO4KhmUJ5_zTZ_4MYQXznAK-TUcZXKO3UMnW6VNpe4-SiiZ4b8h5G3GutPnzfdgdoSMw5ifm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfair/v10/0nkQC9D7PO4KhmUJ5_zTZ_4MYQXznAK-TUcZXKO3UMnW6VNpe4-SiiZ4b8h5G3GutPmUfdgdoSMw5ifm.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfair/v10/0nkQC9D7PO4KhmUJ5_zTZ_4MYQXznAK-TUcZXKO3UMnW6VNpe4-SiiZ4b8h5G3GutPm9fdgdoSMw5ifm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfair/v10/0nkSC9D7PO4KhmUJ59baVQ_iWhg0cgSrLQZDFpFUsLCFf_1ubkfQeG9KkBAQcOsAs-zcOW5eqycS4zfmNrE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfair/v10/0nkSC9D7PO4KhmUJ59baVQ_iWhg0cgSrLQZDFpFUsLCFf_1ubkfQeG9KkBAQcOsAs-zcOTBeqycS4zfmNrE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfair/v10/0nkSC9D7PO4KhmUJ59baVQ_iWhg0cgSrLQZDFpFUsLCFf_1ubkfQeG9KkBAQcOsAs-zcOQJeqycS4zfmNrE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfair/v10/0nkSC9D7PO4KhmUJ59baVQ_iWhg0cgSrLQZDFpFUsLCFf_1ubkfQeG9KkBAQcOsAs-zcOe5ZqycS4zfmNrE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfair/v10/0nkSC9D7PO4KhmUJ59baVQ_iWhg0cgSrLQZDFpFUsLCFf_1ubkfQeG9KkBAQcOsAs-zcOddZqycS4zfmNrE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfair/v10/0nkSC9D7PO4KhmUJ59baVQ_iWhg0cgSrLQZDFpFUsLCFf_1ubkfQeG9KkBAQcOsAs-zcObBZqycS4zfmNrE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,
"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfair/v10/0nkSC9D7PO4KhmUJ59baVQ_iWhg0cgSrLQZDFpFUsLCFf_1ubkfQeG9KkBAQcOsAs-zcOZlZqycS4zfmNrE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playfair-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("316c11f1-d8fb-4f19-9de4-5c137c3db82b",1271776259),$APP.$cljs$cst$2675$family$$,"Playfair Display",$APP.$cljs$cst$725$name$$,"Playfair Display",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplay/v40/nuFvD-vYSZviVYUb_rj3ij__anPXJzDwcbmjWBN2PKdFvUDQZNLo_U2r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplay/v40/nuFvD-vYSZviVYUb_rj3ij__anPXJzDwcbmjWBN2PKd3vUDQZNLo_U2r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplay/v40/nuFvD-vYSZviVYUb_rj3ij__anPXJzDwcbmjWBN2PKebukDQZNLo_U2r.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplay/v40/nuFvD-vYSZviVYUb_rj3ij__anPXJzDwcbmjWBN2PKeiukDQZNLo_U2r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplay/v40/nuFvD-vYSZviVYUb_rj3ij__anPXJzDwcbmjWBN2PKfFukDQZNLo_U2r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplay/v40/nuFvD-vYSZviVYUb_rj3ij__anPXJzDwcbmjWBN2PKfsukDQZNLo_U2r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplay/v40/nuFRD-vYSZviVYUb_rj3ij__anPXDTnCjmHKM4nYO7KN_qiTbtbK-F2rA0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/playfairdisplay/v40/nuFRD-vYSZviVYUb_rj3ij__anPXDTnCjmHKM4nYO7KN_pqTbtbK-F2rA0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplay/v40/nuFRD-vYSZviVYUb_rj3ij__anPXDTnCjmHKM4nYO7KN_naUbtbK-F2rA0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplay/v40/nuFRD-vYSZviVYUb_rj3ij__anPXDTnCjmHKM4nYO7KN_k-UbtbK-F2rA0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/playfairdisplay/v40/nuFRD-vYSZviVYUb_rj3ij__anPXDTnCjmHKM4nYO7KN_iiUbtbK-F2rA0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplay/v40/nuFRD-vYSZviVYUb_rj3ij__anPXDTnCjmHKM4nYO7KN_gGUbtbK-F2rA0s.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-playfair-display-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("24a4bf0d-bb08-4f42-b612-8e30eb2b307c",370504534),$APP.$cljs$cst$2675$family$$,"Playfair Display SC",$APP.$cljs$cst$725$name$$,"Playfair Display SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplaysc/v18/ke85OhoaMkR6-hSn7kbHVoFf7ZfgMPr_pb4GEcM2M4s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplaysc/v18/ke87OhoaMkR6-hSn7kbHVoFf7ZfgMPr_lbwMFeEzI4sNKg.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplaysc/v18/ke80OhoaMkR6-hSn7kbHVoFf7ZfgMPr_nQIpNcsdL4IUMyE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplaysc/v18/ke82OhoaMkR6-hSn7kbHVoFf7ZfgMPr_lbw0qc4XK6ARIyH5IA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplaysc/v18/ke80OhoaMkR6-hSn7kbHVoFf7ZfgMPr_nTorNcsdL4IUMyE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playfairdisplaysc/v18/ke82OhoaMkR6-hSn7kbHVoFf7ZfgMPr_lbw0kcwXK6ARIyH5IA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playpen-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("540c5710-987e-457a-81a9-1dd9923d9674",-1938637489),$APP.$cljs$cst$2675$family$$,
"Playpen Sans",$APP.$cljs$cst$725$name$$,"Playpen Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensans/v22/dg43_pj1p6gXP0gzAZgm4c8XQArSU7ACQSn4IvRgunQ9Ffmme0w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensans/v22/dg43_pj1p6gXP0gzAZgm4c8XQArSU7ACQSn4InRhunQ9Ffmme0w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensans/v22/dg43_pj1p6gXP0gzAZgm4c8XQArSU7ACQSn4IqphunQ9Ffmme0w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensans/v22/dg43_pj1p6gXP0gzAZgm4c8XQArSU7ACQSn4IvRhunQ9Ffmme0w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensans/v22/dg43_pj1p6gXP0gzAZgm4c8XQArSU7ACQSn4IsZhunQ9Ffmme0w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensans/v22/dg43_pj1p6gXP0gzAZgm4c8XQArSU7ACQSn4IipmunQ9Ffmme0w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensans/v22/dg43_pj1p6gXP0gzAZgm4c8XQArSU7ACQSn4IhNmunQ9Ffmme0w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensans/v22/dg43_pj1p6gXP0gzAZgm4c8XQArSU7ACQSn4InRmunQ9Ffmme0w.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playpen-sans-arabic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("94dcfccf-94ff-4f74-a6b5-8d9352c95f49",-1268412938),$APP.$cljs$cst$2675$family$$,"Playpen Sans Arabic",$APP.$cljs$cst$725$name$$,"Playpen Sans Arabic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansarabic/v8/KtkGAKiSeo38bkPvhIqjU6aCgha2der-Z4VIEhR8sOKet-ZBobPcBO1L0EHE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansarabic/v8/KtkGAKiSeo38bkPvhIqjU6aCgha2der-Z4VIEhR8sOKet-bBoLPcBO1L0EHE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansarabic/v8/KtkGAKiSeo38bkPvhIqjU6aCgha2der-Z4VIEhR8sOKet-YfoLPcBO1L0EHE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansarabic/v8/KtkGAKiSeo38bkPvhIqjU6aCgha2der-Z4VIEhR8sOKet-ZBoLPcBO1L0EHE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansarabic/v8/KtkGAKiSeo38bkPvhIqjU6aCgha2der-Z4VIEhR8sOKet-ZzoLPcBO1L0EHE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansarabic/v8/KtkGAKiSeo38bkPvhIqjU6aCgha2der-Z4VIEhR8sOKet-afp7PcBO1L0EHE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansarabic/v8/KtkGAKiSeo38bkPvhIqjU6aCgha2der-Z4VIEhR8sOKet-amp7PcBO1L0EHE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansarabic/v8/KtkGAKiSeo38bkPvhIqjU6aCgha2der-Z4VIEhR8sOKet-bBp7PcBO1L0EHE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playpen-sans-deva",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("44458dea-6234-474e-b1e0-98af6278e5ae",
2144685086),$APP.$cljs$cst$2675$family$$,"Playpen Sans Deva",$APP.$cljs$cst$725$name$$,"Playpen Sans Deva",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansdeva/v4/vm8fdQj0UUbMxObnsO17RZ7pPBuJge10OmPLCiz-HCrQ0xgUG_5NygdkiQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansdeva/v4/vm8fdQj0UUbMxObnsO17RZ7pPBuJge10OmPLCiz-HCrQUxkUG_5NygdkiQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansdeva/v4/vm8fdQj0UUbMxObnsO17RZ7pPBuJge10OmPLCiz-HCrQjRkUG_5NygdkiQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansdeva/v4/vm8fdQj0UUbMxObnsO17RZ7pPBuJge10OmPLCiz-HCrQ0xkUG_5NygdkiQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansdeva/v4/vm8fdQj0UUbMxObnsO17RZ7pPBuJge10OmPLCiz-HCrQ4RkUG_5NygdkiQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansdeva/v4/vm8fdQj0UUbMxObnsO17RZ7pPBuJge10OmPLCiz-HCrQDR4UG_5NygdkiQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansdeva/v4/vm8fdQj0UUbMxObnsO17RZ7pPBuJge10OmPLCiz-HCrQNB4UG_5NygdkiQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansdeva/v4/vm8fdQj0UUbMxObnsO17RZ7pPBuJge10OmPLCiz-HCrQUx4UG_5NygdkiQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playpen-sans-hebrew",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fa7b4a6b-2c5a-4d03-85a1-f81d3979066e",-621593300),$APP.$cljs$cst$2675$family$$,"Playpen Sans Hebrew",$APP.$cljs$cst$725$name$$,"Playpen Sans Hebrew",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensanshebrew/v8/lJws-okuj29wT-AN6RvLx8QqjkKhL7eAjoL9jK7L4vstDnnp5pC63VFfsRss.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensanshebrew/v8/lJws-okuj29wT-AN6RvLx8QqjkKhL7eAjoL9jK7L4vstDnlp55C63VFfsRss.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensanshebrew/v8/lJws-okuj29wT-AN6RvLx8QqjkKhL7eAjoL9jK7L4vstDnm355C63VFfsRss.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensanshebrew/v8/lJws-okuj29wT-AN6RvLx8QqjkKhL7eAjoL9jK7L4vstDnnp55C63VFfsRss.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensanshebrew/v8/lJws-okuj29wT-AN6RvLx8QqjkKhL7eAjoL9jK7L4vstDnnb55C63VFfsRss.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensanshebrew/v8/lJws-okuj29wT-AN6RvLx8QqjkKhL7eAjoL9jK7L4vstDnk34JC63VFfsRss.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensanshebrew/v8/lJws-okuj29wT-AN6RvLx8QqjkKhL7eAjoL9jK7L4vstDnkO4JC63VFfsRss.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensanshebrew/v8/lJws-okuj29wT-AN6RvLx8QqjkKhL7eAjoL9jK7L4vstDnlp4JC63VFfsRss.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playpen-sans-thai",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7820f334-396a-419d-b010-f1b55d0684ae",1917294741),$APP.$cljs$cst$2675$family$$,"Playpen Sans Thai",$APP.$cljs$cst$725$name$$,"Playpen Sans Thai",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansthai/v8/VdG3AYIdG5kSgHwmKT9wYu2rs0cBsu-N7E_aclWp2hxLghGPoxxAISLTzA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansthai/v8/VdG3AYIdG5kSgHwmKT9wYu2rs0cBsu-N7E_aclWp2hxLAhCPoxxAISLTzA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansthai/v8/VdG3AYIdG5kSgHwmKT9wYu2rs0cBsu-N7E_aclWp2hxL3BCPoxxAISLTzA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansthai/v8/VdG3AYIdG5kSgHwmKT9wYu2rs0cBsu-N7E_aclWp2hxLghCPoxxAISLTzA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansthai/v8/VdG3AYIdG5kSgHwmKT9wYu2rs0cBsu-N7E_aclWp2hxLsBCPoxxAISLTzA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansthai/v8/VdG3AYIdG5kSgHwmKT9wYu2rs0cBsu-N7E_aclWp2hxLXBePoxxAISLTzA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansthai/v8/VdG3AYIdG5kSgHwmKT9wYu2rs0cBsu-N7E_aclWp2hxLZRePoxxAISLTzA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playpensansthai/v8/VdG3AYIdG5kSgHwmKT9wYu2rs0cBsu-N7E_aclWp2hxLAhePoxxAISLTzA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-ar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("18d9b10b-d528-4492-98b7-ad43f421b110",
532975856),$APP.$cljs$cst$2675$family$$,"Playwrite AR",$APP.$cljs$cst$725$name$$,"Playwrite AR",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritear/v6/VEMjRohisJz5pTCzruCNjWbfp_N-aNWqYgKS-fteqf-ES67xIO8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritear/v6/VEMjRohisJz5pTCzruCNjWbfp_N-aNWqYgKS-Xtfqf-ES67xIO8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritear/v6/VEMjRohisJz5pTCzruCNjWbfp_N-aNWqYgKS-aVfqf-ES67xIO8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritear/v6/VEMjRohisJz5pTCzruCNjWbfp_N-aNWqYgKS-ftfqf-ES67xIO8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-ar-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1714fdef-4f5a-4e16-9313-6e4912a839cd",1524849815),$APP.$cljs$cst$2675$family$$,"Playwrite AR Guides",$APP.$cljs$cst$725$name$$,"Playwrite AR Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritearguides/v5/iJWYBWqKZTrYS9uv-Ry6kDf-q_0Xq67mcGUaW4_MiYQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-at",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1843c605-5f13-4532-8cf1-7f217442a846",-1103539137),$APP.$cljs$cst$2675$family$$,"Playwrite AT",$APP.$cljs$cst$725$name$$,"Playwrite AT",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteat/v6/Gw6owc7n6kfJN4fVoKON7HIEBRSfb0U2uGBm2M77d03MLIHJ-rk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteat/v6/Gw6owc7n6kfJN4fVoKON7HIEBRSfb0U2uGBm2E76d03MLIHJ-rk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteat/v6/Gw6owc7n6kfJN4fVoKON7HIEBRSfb0U2uGBm2JD6d03MLIHJ-rk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteat/v6/Gw6owc7n6kfJN4fVoKON7HIEBRSfb0U2uGBm2M76d03MLIHJ-rk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteat/v6/Gw6uwc7n6kfJN4fVoKON7HIuDCZgtyxdIs5hzQa5nw_GKKPM6rkyVg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteat/v6/Gw6uwc7n6kfJN4fVoKON7HIuDCZgtyxdIs5hzQa5Hw7GKKPM6rkyVg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteat/v6/Gw6uwc7n6kfJN4fVoKON7HIuDCZgtyxdIs5hzQa5wQ7GKKPM6rkyVg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteat/v6/Gw6uwc7n6kfJN4fVoKON7HIuDCZgtyxdIs5hzQa5nw7GKKPM6rkyVg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-at-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b19aaab9-83cb-47e2-90a6-7bdc1a089068",1912781531),$APP.$cljs$cst$2675$family$$,"Playwrite AT Guides",$APP.$cljs$cst$725$name$$,"Playwrite AT Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteatguides/v1/QdVKSS0gJR2xneUeQPfE-FVA1BlZQRpBRbgJdhapcUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteatguides/v1/QdVISS0gJR2xneUeQPfE-FVA1BlZQRpBdboDcjSsYUVUjg.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-au-nsw",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("573588c2-b263-49ba-9648-1b914f1bf4b1",-1522456389),$APP.$cljs$cst$2675$family$$,"Playwrite AU NSW",$APP.$cljs$cst$725$name$$,"Playwrite AU NSW",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",
$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteaunsw/v11/6qLWKY4NtxD-qVlIPUIPenElWCCEWRgilpupBXi19xZjML96TD2dC1gS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteaunsw/v11/6qLWKY4NtxD-qVlIPUIPenElWCCEWRgilpupBXi19xbjMb96TD2dC1gS.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteaunsw/v11/6qLWKY4NtxD-qVlIPUIPenElWCCEWRgilpupBXi19xY9Mb96TD2dC1gS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteaunsw/v11/6qLWKY4NtxD-qVlIPUIPenElWCCEWRgilpupBXi19xZjMb96TD2dC1gS.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-au-nsw-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f9297123-740f-4097-a555-8326ac3c3e6a",-1400832552),$APP.$cljs$cst$2675$family$$,"Playwrite AU NSW Guides",$APP.$cljs$cst$725$name$$,"Playwrite AU NSW Guides",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteaunswguides/v1/LDIiao-QNRMmVPcU8-sgUraMF7GZs_1Emk3v8tPbZeQ3YBXs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-playwrite-au-qld",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("71112807-cc38-4a6b-9028-1ea98e289a65",-72291592),$APP.$cljs$cst$2675$family$$,"Playwrite AU QLD",$APP.$cljs$cst$725$name$$,"Playwrite AU QLD",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteauqld/v11/SlGGmR-Yo5oYZX5BFVcEwSFSOXBRWADAWbgjmLBhA6-yMY2fqm1BV-XS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteauqld/v11/SlGGmR-Yo5oYZX5BFVcEwSFSOXBRWADAWbgjmLBhA68yMI2fqm1BV-XS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteauqld/v11/SlGGmR-Yo5oYZX5BFVcEwSFSOXBRWADAWbgjmLBhA6_sMI2fqm1BV-XS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteauqld/v11/SlGGmR-Yo5oYZX5BFVcEwSFSOXBRWADAWbgjmLBhA6-yMI2fqm1BV-XS.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-au-qld-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c3ca501e-5d75-4b10-8ac6-9af080ee05f5",1047271300),$APP.$cljs$cst$2675$family$$,"Playwrite AU QLD Guides",$APP.$cljs$cst$725$name$$,"Playwrite AU QLD Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteauqldguides/v1/TuGBUUJtX5tTUfQi_7kbiZZFVhl0FIKnvy00LDxlIzIU5RwD.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-au-sa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("71b7e118-d478-46a5-9f24-906ca22119b1",1801614039),$APP.$cljs$cst$2675$family$$,"Playwrite AU SA",
$APP.$cljs$cst$725$name$$,"Playwrite AU SA",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteausa/v11/YcmhsZpNS1SdgmHbGgtRuUElnR3CmSC5bVQVlrclpZgQcuVjCoV0bbE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteausa/v11/YcmhsZpNS1SdgmHbGgtRuUElnR3CmSC5bVQVlrclpRgRcuVjCoV0bbE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteausa/v11/YcmhsZpNS1SdgmHbGgtRuUElnR3CmSC5bVQVlrclpcYRcuVjCoV0bbE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteausa/v11/YcmhsZpNS1SdgmHbGgtRuUElnR3CmSC5bVQVlrclpZgRcuVjCoV0bbE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-au-sa-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d2b52988-f065-42af-b9d3-3749c53bdfa9",
-1417804225),$APP.$cljs$cst$2675$family$$,"Playwrite AU SA Guides",$APP.$cljs$cst$725$name$$,"Playwrite AU SA Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteausaguides/v1/3JnsSCLj03y8jUv7aFWBCCglBaFjl54aVBAovcgEP-Z3054.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-au-tas",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3e6f9e3c-759f-46da-a1c6-8168b31cc664",699269573),$APP.$cljs$cst$2675$family$$,"Playwrite AU TAS",$APP.$cljs$cst$725$name$$,"Playwrite AU TAS",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteautas/v11/GftT7u9QuxsdI_QuuctXue3ElxxmcBb3ih0opvWiLLUEHqK6Hl9WrXm4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteautas/v11/GftT7u9QuxsdI_QuuctXue3ElxxmcBb3ih0opvWiLLWEH6K6Hl9WrXm4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteautas/v11/GftT7u9QuxsdI_QuuctXue3ElxxmcBb3ih0opvWiLLVaH6K6Hl9WrXm4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteautas/v11/GftT7u9QuxsdI_QuuctXue3ElxxmcBb3ih0opvWiLLUEH6K6Hl9WrXm4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-au-tas-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0e6eb20b-c504-4304-b24c-2b09076a0286",-1181313261),$APP.$cljs$cst$2675$family$$,"Playwrite AU TAS Guides",$APP.$cljs$cst$725$name$$,"Playwrite AU TAS Guides",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteautasguides/v1/cY9Vfi6cVk5RvjGtQrLqjozy3ekUDtDMDX-NNjbKL4UbaDZD.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-playwrite-au-vic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("03a67e04-a378-460c-ba6c-225d0e84dba5",-1233442910),$APP.$cljs$cst$2675$family$$,"Playwrite AU VIC",$APP.$cljs$cst$725$name$$,"Playwrite AU VIC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteauvic/v11/bWtu7enUfwn0Hf1zjprKOJdcDy8rxwC1ltAeNDAAd4fTaLK0CBIDKNvl.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteauvic/v11/bWtu7enUfwn0Hf1zjprKOJdcDy8rxwC1ltAeNDAAd4dTabK0CBIDKNvl.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteauvic/v11/bWtu7enUfwn0Hf1zjprKOJdcDy8rxwC1ltAeNDAAd4eNabK0CBIDKNvl.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteauvic/v11/bWtu7enUfwn0Hf1zjprKOJdcDy8rxwC1ltAeNDAAd4fTabK0CBIDKNvl.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-au-vic-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("138f3b95-cb9a-4c16-8da0-93e0b3e5b45d",1426992424),$APP.$cljs$cst$2675$family$$,"Playwrite AU VIC Guides",$APP.$cljs$cst$725$name$$,"Playwrite AU VIC Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteauvicguides/v1/ll8sK3mEVy6nEMXMskXIZv8owEdZpVIWaQEnuD6F2TpBa98q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-be-vlg",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("406efcd8-3ef5-4b44-9afd-6e0e49cea115",-2102430157),$APP.$cljs$cst$2675$family$$,"Playwrite BE VLG",
$APP.$cljs$cst$725$name$$,"Playwrite BE VLG",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebevlg/v6/GFD8WBdug3mQSvrAT9AL6fd4ZkB-a2sDmg3dy2W0blL8vfCMMiyBIkNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebevlg/v6/GFD8WBdug3mQSvrAT9AL6fd4ZkB-a2sDmg3dy2W0blJ8vPCMMiyBIkNg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebevlg/v6/GFD8WBdug3mQSvrAT9AL6fd4ZkB-a2sDmg3dy2W0blKivPCMMiyBIkNg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebevlg/v6/GFD8WBdug3mQSvrAT9AL6fd4ZkB-a2sDmg3dy2W0blL8vPCMMiyBIkNg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-be-vlg-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9d9d50a6-607e-4833-8eff-cb1a23bb11d1",
-2058551556),$APP.$cljs$cst$2675$family$$,"Playwrite BE VLG Guides",$APP.$cljs$cst$725$name$$,"Playwrite BE VLG Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebevlgguides/v2/EYqjmb1Mz6hO4edaU9qKGFZMDd_Q-zwwK__U1u9GK3nNgEoc.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-be-wal",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("98fc8279-633b-4730-a538-0d2354dea569",-103809988),$APP.$cljs$cst$2675$family$$,"Playwrite BE WAL",$APP.$cljs$cst$725$name$$,"Playwrite BE WAL",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebewal/v7/DtV1Jwq5QbIzyrA6DHdJ2BksuUmanQtEYjAlv96WFsWCGfugHxwiSZp8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebewal/v7/DtV1Jwq5QbIzyrA6DHdJ2BksuUmanQtEYjAlv96WFsUCGPugHxwiSZp8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebewal/v7/DtV1Jwq5QbIzyrA6DHdJ2BksuUmanQtEYjAlv96WFsXcGPugHxwiSZp8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebewal/v7/DtV1Jwq5QbIzyrA6DHdJ2BksuUmanQtEYjAlv96WFsWCGPugHxwiSZp8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-be-wal-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1f5c3a5f-e5ca-4bc1-b899-612ce2e7f4aa",-1058885180),$APP.$cljs$cst$2675$family$$,"Playwrite BE WAL Guides",$APP.$cljs$cst$725$name$$,"Playwrite BE WAL Guides",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebewalguides/v1/l7gPbiR5yM62ycwevWCt02rrTFoEJvY4kyrrUzHlVJabaOSA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-playwrite-br",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0b399ae3-cb82-40f1-a5ea-9843fbdff199",305379800),$APP.$cljs$cst$2675$family$$,"Playwrite BR",$APP.$cljs$cst$725$name$$,"Playwrite BR",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebr/v11/kJEhBuMK4Q07lDHc2Xp9vYgIp-6D3QEGCpthmFOOFsfjAOVZBgs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebr/v11/kJEhBuMK4Q07lDHc2Xp9vYgIp-6D3QEGCpthmNOPFsfjAOVZBgs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebr/v11/kJEhBuMK4Q07lDHc2Xp9vYgIp-6D3QEGCpthmA2PFsfjAOVZBgs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebr/v11/kJEhBuMK4Q07lDHc2Xp9vYgIp-6D3QEGCpthmFOPFsfjAOVZBgs.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-br-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8d2a00e0-ba86-4fda-b852-5084feccef8d",-1681131110),$APP.$cljs$cst$2675$family$$,"Playwrite BR Guides",$APP.$cljs$cst$725$name$$,"Playwrite BR Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritebrguides/v1/tssxAohQaiQS-wrnJz-F5CqW4dOezRwp-9cCOxBu_BM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-ca",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a2cf906f-b5ab-4137-94ea-1091a86058a6",694629981),$APP.$cljs$cst$2675$family$$,"Playwrite CA",$APP.$cljs$cst$725$name$$,
"Playwrite CA",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteca/v11/z7NGdR_4cT0NOrEAIElil93uR_VhfhYaYOijHiquYp261AIQU98.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteca/v11/z7NGdR_4cT0NOrEAIElil93uR_VhfhYaYOijHqqvYp261AIQU98.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteca/v11/z7NGdR_4cT0NOrEAIElil93uR_VhfhYaYOijHnSvYp261AIQU98.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteca/v11/z7NGdR_4cT0NOrEAIElil93uR_VhfhYaYOijHiqvYp261AIQU98.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-ca-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cc9ceb8c-0afd-4ecd-ac14-d9033c39e153",
166501460),$APP.$cljs$cst$2675$family$$,"Playwrite CA Guides",$APP.$cljs$cst$725$name$$,"Playwrite CA Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecaguides/v1/MjQamj1kuP_soQ3o-rysO9Ci_8oJlIUUInch3bTfcxs.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-cl",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7bbdc86b-6488-4691-99aa-89caa936c526",1068307853),$APP.$cljs$cst$2675$family$$,"Playwrite CL",$APP.$cljs$cst$725$name$$,"Playwrite CL",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecl/v6/-zk391m7wssz_XLkGgu8hy3tqrcOhnbf6ForU8JbvLq3DyPNbus.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecl/v6/-zk391m7wssz_XLkGgu8hy3tqrcOhnbf6ForU0JavLq3DyPNbus.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecl/v6/-zk391m7wssz_XLkGgu8hy3tqrcOhnbf6ForU5xavLq3DyPNbus.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecl/v6/-zk391m7wssz_XLkGgu8hy3tqrcOhnbf6ForU8JavLq3DyPNbus.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-cl-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c6dd8890-ecae-4fb0-83b9-3909047c2fce",-1954027147),$APP.$cljs$cst$2675$family$$,"Playwrite CL Guides",$APP.$cljs$cst$725$name$$,"Playwrite CL Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteclguides/v2/Z9XKDnxTQxyGzOn3eMH-i6Ws0czqkE-hrNpVuw5_BAM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-co",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d2065913-a7d0-46dc-92d3-da2ebcc43cdd",
-1923173502),$APP.$cljs$cst$2675$family$$,"Playwrite CO",$APP.$cljs$cst$725$name$$,"Playwrite CO",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteco/v13/0FlGVP2Hl1iH-fv2BH4kJkgb8vH-rbJPTDqqx7ZJo-dOEhxX3Iw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteco/v13/0FlGVP2Hl1iH-fv2BH4kJkgb8vH-rbJPTDqqxzZIo-dOEhxX3Iw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteco/v13/0FlGVP2Hl1iH-fv2BH4kJkgb8vH-rbJPTDqqx-hIo-dOEhxX3Iw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteco/v13/0FlGVP2Hl1iH-fv2BH4kJkgb8vH-rbJPTDqqx7ZIo-dOEhxX3Iw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-co-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4c6fa70f-d6c9-4091-9fc5-4337027521ea",-63091227),$APP.$cljs$cst$2675$family$$,"Playwrite CO Guides",$APP.$cljs$cst$725$name$$,"Playwrite CO Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecoguides/v5/AYCXpWvtftIVXepC5AzjAx1KgYPugOK0TqxTJw_GOM0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-cu",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("77906d04-11a8-438d-979c-9709129e2d0c",-642287380),$APP.$cljs$cst$2675$family$$,"Playwrite CU",$APP.$cljs$cst$725$name$$,"Playwrite CU",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecu/v6/VuJjdNDb2p7tvoFGLMPdf9xcahOpb9ZuoyXseRmwZeT7m2YIByI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecu/v6/VuJjdNDb2p7tvoFGLMPdf9xcahOpb9ZuoyXseZmxZeT7m2YIByI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecu/v6/VuJjdNDb2p7tvoFGLMPdf9xcahOpb9ZuoyXseUexZeT7m2YIByI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecu/v6/VuJjdNDb2p7tvoFGLMPdf9xcahOpb9ZuoyXseRmxZeT7m2YIByI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-cu-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3c60af51-9365-4b0a-a701-344a1f2e5332",436341576),$APP.$cljs$cst$2675$family$$,
"Playwrite CU Guides",$APP.$cljs$cst$725$name$$,"Playwrite CU Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecuguides/v1/c4m81mZtG8v6p3iAoFBJ2dJdu9fWPSaOFooIDQtJbok.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-cz",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("585ba3e2-7c84-4385-a5c7-6f4e2da8d4a3",-1396464664),$APP.$cljs$cst$2675$family$$,"Playwrite CZ",$APP.$cljs$cst$725$name$$,"Playwrite CZ",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecz/v6/8vIa7wYp22pt_BUChSHeVxxlOPUEKoMfap_FCI4aTqT_VkAS5X4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecz/v6/8vIa7wYp22pt_BUChSHeVxxlOPUEKoMfap_FCA4bTqT_VkAS5X4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecz/v6/8vIa7wYp22pt_BUChSHeVxxlOPUEKoMfap_FCNAbTqT_VkAS5X4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritecz/v6/8vIa7wYp22pt_BUChSHeVxxlOPUEKoMfap_FCI4bTqT_VkAS5X4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-cz-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c1ae36d8-81e0-4cd8-9d79-a51c59258a91",-830278042),$APP.$cljs$cst$2675$family$$,"Playwrite CZ Guides",$APP.$cljs$cst$725$name$$,"Playwrite CZ Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteczguides/v1/6qLcKY0NtxD-qVlIPUIPeH4lUQa6B3ZZQkseuneh7xc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-de-grund",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("5b13eecc-9758-4bbb-8014-3f634c3bb827",825535354),$APP.$cljs$cst$2675$family$$,"Playwrite DE Grund",$APP.$cljs$cst$725$name$$,"Playwrite DE Grund",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/playwritedegrund/v11/EJR-QhwoXdccriFurnRxqv-1MFyKy696-4VufrEGGbTZz2qGZwCUOfSwZTM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedegrund/v11/EJR-QhwoXdccriFurnRxqv-1MFyKy696-4VufrEGGbTZz-qHZwCUOfSwZTM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedegrund/v11/EJR-QhwoXdccriFurnRxqv-1MFyKy696-4VufrEGGbTZzzSHZwCUOfSwZTM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedegrund/v11/EJR-QhwoXdccriFurnRxqv-1MFyKy696-4VufrEGGbTZz2qHZwCUOfSwZTM.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-de-grund-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0df3b7d9-503a-4502-bf8b-57ee4fb58efa",102562787),$APP.$cljs$cst$2675$family$$,"Playwrite DE Grund Guides",$APP.$cljs$cst$725$name$$,"Playwrite DE Grund Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedegrundguides/v1/OD5RuNCQ02KrAHnha1L36CWcQ83dtK5BLxqexnduX98TJlnjHAA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-de-la",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("09c61bb2-18fc-47d5-b49a-9c7c8605fe34",-1398174260),$APP.$cljs$cst$2675$family$$,
"Playwrite DE LA",$APP.$cljs$cst$725$name$$,"Playwrite DE LA",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedela/v11/oY1J8e3fprboJ2HN4ogXTpFVJ8QjJV9p0P4yukst2FnrPgcigC5Ph2w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedela/v11/oY1J8e3fprboJ2HN4ogXTpFVJ8QjJV9p0P4yukst2NnqPgcigC5Ph2w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedela/v11/oY1J8e3fprboJ2HN4ogXTpFVJ8QjJV9p0P4yukst2AfqPgcigC5Ph2w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedela/v11/oY1J8e3fprboJ2HN4ogXTpFVJ8QjJV9p0P4yukst2FnqPgcigC5Ph2w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-de-la-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dc8b61f4-efd2-4956-b8e6-ccd5a38620ca",-1663403155),$APP.$cljs$cst$2675$family$$,"Playwrite DE LA Guides",$APP.$cljs$cst$725$name$$,"Playwrite DE LA Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedelaguides/v2/1q2XY42fB0V64O4aSe1OjKs_yAXBOfDI5wE56g2M62M1AXs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-de-sas",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9af62d52-f1d7-4b21-82cf-110b51e043fe",-2079629317),$APP.$cljs$cst$2675$family$$,"Playwrite DE SAS",$APP.$cljs$cst$725$name$$,"Playwrite DE SAS",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedesas/v11/1Pt4g9vaRvmWghDdrE8IDuRPVrHN_1AaFXASpbMqJTeVg-6lSyVPgRkJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedesas/v11/1Pt4g9vaRvmWghDdrE8IDuRPVrHN_1AaFXASpbMqJTcVgu6lSyVPgRkJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedesas/v11/1Pt4g9vaRvmWghDdrE8IDuRPVrHN_1AaFXASpbMqJTfLgu6lSyVPgRkJ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedesas/v11/1Pt4g9vaRvmWghDdrE8IDuRPVrHN_1AaFXASpbMqJTeVgu6lSyVPgRkJ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-de-sas-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("73c59668-038d-49da-9592-0a9f79302c74",
1968544191),$APP.$cljs$cst$2675$family$$,"Playwrite DE SAS Guides",$APP.$cljs$cst$725$name$$,"Playwrite DE SAS Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedesasguides/v1/8At5GtCjPp-GWR2h9cC6ePzz2l6LJ3VZaPNi15BEdtBgPI1G.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-de-va",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("596e471c-232a-479b-ac1a-d8a656e9b008",1676364463),$APP.$cljs$cst$2675$family$$,"Playwrite DE VA",$APP.$cljs$cst$725$name$$,"Playwrite DE VA",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedeva/v11/VuJmdNPb2p7tvoFGLMPdeMxGN1pntEMhdK1XfsTyRSyTv24jGyvutu4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedeva/v11/VuJmdNPb2p7tvoFGLMPdeMxGN1pntEMhdK1XfsTyRaySv24jGyvutu4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedeva/v11/VuJmdNPb2p7tvoFGLMPdeMxGN1pntEMhdK1XfsTyRXKSv24jGyvutu4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedeva/v11/VuJmdNPb2p7tvoFGLMPdeMxGN1pntEMhdK1XfsTyRSySv24jGyvutu4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-de-va-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("af504936-e72a-4943-bc3b-39a0c4aa6912",612376801),$APP.$cljs$cst$2675$family$$,"Playwrite DE VA Guides",$APP.$cljs$cst$725$name$$,"Playwrite DE VA Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedevaguides/v1/WwkPxOmkDVqm-ojMLT_kdMUoBpMYm6KTeb28UB9SNQIUdqQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-dk-loopet",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("5aea90f3-170e-4936-98a6-8247dc6d9805",-1921505034),$APP.$cljs$cst$2675$family$$,"Playwrite DK Loopet",$APP.$cljs$cst$725$name$$,"Playwrite DK Loopet",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/playwritedkloopet/v6/memVYbuzy2qb3rtJGfM1FvY-GacDcsPvtaDfqfgbBWmV75JJwOgRuQovSE8_.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedkloopet/v6/memVYbuzy2qb3rtJGfM1FvY-GacDcsPvtaDfqfgbBWmV75LJwegRuQovSE8_.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedkloopet/v6/memVYbuzy2qb3rtJGfM1FvY-GacDcsPvtaDfqfgbBWmV75IXwegRuQovSE8_.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedkloopet/v6/memVYbuzy2qb3rtJGfM1FvY-GacDcsPvtaDfqfgbBWmV75JJwegRuQovSE8_.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-dk-loopet-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("716938c7-4c7b-4f8d-8dc3-454931d08c11",-775234007),$APP.$cljs$cst$2675$family$$,"Playwrite DK Loopet Guides",$APP.$cljs$cst$725$name$$,"Playwrite DK Loopet Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedkloopetguides/v1/4iC46LlmYsRPlQ1zDEvT8weoW-sI8-h9xxN83W-Cb5tmElj-b0nB.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-dk-uloopet",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a3a8b91a-33d1-4898-9984-befe997d413f",-2016432529),$APP.$cljs$cst$2675$family$$,
"Playwrite DK Uloopet",$APP.$cljs$cst$725$name$$,"Playwrite DK Uloopet",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedkuloopet/v6/bWtS7e3Ufwn0Hf1zjprKPYlcDAoHknvYFjqIh8PF6jwcP5K06lQrKeng6LUzAA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedkuloopet/v6/bWtS7e3Ufwn0Hf1zjprKPYlcDAoHknvYFjqIh8PF6jwcP5K0alUrKeng6LUzAA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedkuloopet/v6/bWtS7e3Ufwn0Hf1zjprKPYlcDAoHknvYFjqIh8PF6jwcP5K0tFUrKeng6LUzAA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedkuloopet/v6/bWtS7e3Ufwn0Hf1zjprKPYlcDAoHknvYFjqIh8PF6jwcP5K06lUrKeng6LUzAA.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-dk-uloopet-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2e672963-70d1-4bc9-b65f-e2cfde370d8b",-1462967435),$APP.$cljs$cst$2675$family$$,"Playwrite DK Uloopet Guides",$APP.$cljs$cst$725$name$$,"Playwrite DK Uloopet Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritedkuloopetguides/v1/WwkKxOSkDVqm-ojMLT_kdMsoBb5Xs6efafiIBXYcVHk1bo9bkIONtA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-es",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e13ffec0-7250-4ee5-8c26-ab6b98722691",63867382),$APP.$cljs$cst$2675$family$$,"Playwrite ES",
$APP.$cljs$cst$725$name$$,"Playwrite ES",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritees/v11/kJEhBuMK4Q07lDHc2Xp9uokIp-6D3QEGCpthmFOOFsfjAOVZBgs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritees/v11/kJEhBuMK4Q07lDHc2Xp9uokIp-6D3QEGCpthmNOPFsfjAOVZBgs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritees/v11/kJEhBuMK4Q07lDHc2Xp9uokIp-6D3QEGCpthmA2PFsfjAOVZBgs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritees/v11/kJEhBuMK4Q07lDHc2Xp9uokIp-6D3QEGCpthmFOPFsfjAOVZBgs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-es-deco",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("50ef81a3-5866-4d8e-b9b0-cec28366506d",
-1170499234),$APP.$cljs$cst$2675$family$$,"Playwrite ES Deco",$APP.$cljs$cst$725$name$$,"Playwrite ES Deco",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteesdeco/v11/7AuWp-g3kjKKGkePXEf2jxctfDxlvGM7-RllW8uEsjJ4yrZxOQ9p5Cljpw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteesdeco/v11/7AuWp-g3kjKKGkePXEf2jxctfDxlvGM7-RllW8uEsjJ4SrdxOQ9p5Cljpw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteesdeco/v11/7AuWp-g3kjKKGkePXEf2jxctfDxlvGM7-RllW8uEsjJ4lLdxOQ9p5Cljpw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteesdeco/v11/7AuWp-g3kjKKGkePXEf2jxctfDxlvGM7-RllW8uEsjJ4yrdxOQ9p5Cljpw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-es-deco-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("680739f3-203d-43db-973c-6937498cc038",1592987373),$APP.$cljs$cst$2675$family$$,"Playwrite ES Deco Guides",$APP.$cljs$cst$725$name$$,"Playwrite ES Deco Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteesdecoguides/v1/flUrRriwwII5RVl2TZ1XBNTUOYY6ZzZzwPCEKtwqYEyDBQWJ7Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-es-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("46adee81-2e10-4730-83a3-6a1d8a624f93",957585483),$APP.$cljs$cst$2675$family$$,"Playwrite ES Guides",$APP.$cljs$cst$725$name$$,"Playwrite ES Guides",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteesguides/v1/VuJtdM_b2p7tvoFGLMPdedpGJm402y6mhDDGfdnzXeU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-fr-moderne",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("22d8b561-ed6c-4ab5-9394-dbc073e34244",1517342415),$APP.$cljs$cst$2675$family$$,"Playwrite FR Moderne",$APP.$cljs$cst$725$name$$,"Playwrite FR Moderne",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritefrmoderne/v11/3y9L6awucz3w5m4FFTzKolJRXhUk_u1yWtWmFCJcqUBvK5aJuAOvAl74XSpRjw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritefrmoderne/v11/3y9L6awucz3w5m4FFTzKolJRXhUk_u1yWtWmFCJcqUBvK5aJOAKvAl74XSpRjw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritefrmoderne/v11/3y9L6awucz3w5m4FFTzKolJRXhUk_u1yWtWmFCJcqUBvK5aJ5gKvAl74XSpRjw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritefrmoderne/v11/3y9L6awucz3w5m4FFTzKolJRXhUk_u1yWtWmFCJcqUBvK5aJuAKvAl74XSpRjw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-fr-moderne-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("447f9867-2552-462d-a933-1c49feaa0317",1821011852),$APP.$cljs$cst$2675$family$$,"Playwrite FR Moderne Guides",$APP.$cljs$cst$725$name$$,"Playwrite FR Moderne Guides",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritefrmoderneguides/v2/CSRr4yxOn-mMWCgLPl16KrUKBbwa2ZZLdkrvXllIP22HnIzLvrG2fw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-playwrite-fr-trad",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b3a0602d-ff8b-4f05-9936-84b653b0b523",-1750388405),$APP.$cljs$cst$2675$family$$,"Playwrite FR Trad",$APP.$cljs$cst$725$name$$,"Playwrite FR Trad",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritefrtrad/v13/sJot3KxJjdGLJV3vyatrJE2pkQisWWMBP23HSIVI5tvAogrNdt-fwzTS5A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritefrtrad/v13/sJot3KxJjdGLJV3vyatrJE2pkQisWWMBP23HSIVI5tvAIgvNdt-fwzTS5A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritefrtrad/v13/sJot3KxJjdGLJV3vyatrJE2pkQisWWMBP23HSIVI5tvA_AvNdt-fwzTS5A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritefrtrad/v13/sJot3KxJjdGLJV3vyatrJE2pkQisWWMBP23HSIVI5tvAogvNdt-fwzTS5A.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-fr-trad-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e66776e9-8fc6-4a61-8fab-b9f890b184b7",336395271),$APP.$cljs$cst$2675$family$$,"Playwrite FR Trad Guides",$APP.$cljs$cst$725$name$$,"Playwrite FR Trad Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritefrtradguides/v1/l7gMbit5yM62ycwevWCt133rT2kpYpEKjyfqRWLFfriXYf2ZXw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-gb-j",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("997567af-d3b3-4a26-ba1d-853c739f1f27",-1488487634),$APP.$cljs$cst$2675$family$$,
"Playwrite GB J",$APP.$cljs$cst$725$name$$,"Playwrite GB J",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbj/v11/k3kEo8wSPe9dzQ1UGbvobAPhY5iG-fsubxedDheGdc5HaN7X9HFR8Q.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbj/v11/k3kEo8wSPe9dzQ1UGbvobAPhY5iG-fsubxedDheG9c9HaN7X9HFR8Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbj/v11/k3kEo8wSPe9dzQ1UGbvobAPhY5iG-fsubxedDheGK89HaN7X9HFR8Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbj/v11/k3kEo8wSPe9dzQ1UGbvobAPhY5iG-fsubxedDheGdc9HaN7X9HFR8Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbj/v11/k3kGo8wSPe9dzQ1UGbvobAPhY7KPywT2BnwHoBCTvYyvKtTT1nRB8S9t.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/playwritegbj/v11/k3kGo8wSPe9dzQ1UGbvobAPhY7KPywT2BnwHoBCTvYwvK9TT1nRB8S9t.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbj/v11/k3kGo8wSPe9dzQ1UGbvobAPhY7KPywT2BnwHoBCTvYzxK9TT1nRB8S9t.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbj/v11/k3kGo8wSPe9dzQ1UGbvobAPhY7KPywT2BnwHoBCTvYyvK9TT1nRB8S9t.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-gb-j-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("57c97742-1b3b-40d1-b59c-b1123b03d425",1163980008),$APP.$cljs$cst$2675$family$$,"Playwrite GB J Guides",
$APP.$cljs$cst$725$name$$,"Playwrite GB J Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbjguides/v2/CSRh4yJOn-mMWCgLPl16K6UKAvM5yY1BdhmIKxooUh-_nQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbjguides/v2/CSRv4yJOn-mMWCgLPl16K6UKAvM5yY1Bdhm4KRAscBqvnb7O.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-gb-s",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("65347d91-1489-44ac-8189-76c57da6861d",-1431267020),$APP.$cljs$cst$2675$family$$,
"Playwrite GB S",$APP.$cljs$cst$725$name$$,"Playwrite GB S",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbs/v12/oPWb_kFkk-s1Xclhmlemy7jsNQR8TohGU_DTHWU6uhH8x5eMaTk8AQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbs/v12/oPWb_kFkk-s1Xclhmlemy7jsNQR8TohGU_DTHWU6OhD8x5eMaTk8AQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbs/v12/oPWb_kFkk-s1Xclhmlemy7jsNQR8TohGU_DTHWU65BD8x5eMaTk8AQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbs/v12/oPWb_kFkk-s1Xclhmlemy7jsNQR8TohGU_DTHWU6uhD8x5eMaTk8AQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbs/v12/oPWZ_kFkk-s1Xclhmlemy7jsNS51fHeeOptJs2IvclMUhZ2ISzwsAReZ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/playwritegbs/v12/oPWZ_kFkk-s1Xclhmlemy7jsNS51fHeeOptJs2IvclOUhJ2ISzwsAReZ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbs/v12/oPWZ_kFkk-s1Xclhmlemy7jsNS51fHeeOptJs2IvclNKhJ2ISzwsAReZ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbs/v12/oPWZ_kFkk-s1Xclhmlemy7jsNS51fHeeOptJs2IvclMUhJ2ISzwsAReZ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-gb-s-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3d3c2c34-2c4b-47f8-8f13-c91a0a6b126e",-850122717),$APP.$cljs$cst$2675$family$$,"Playwrite GB S Guides",
$APP.$cljs$cst$725$name$$,"Playwrite GB S Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbsguides/v1/0FlKVOSHl1iH-fv2BH4kIkUBqtlNCEaQLlyKx1QPi-Z8Fw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritegbsguides/v1/0FlEVOSHl1iH-fv2BH4kIkUBqtlNCEaQLly6xV4LqeNsFwxX.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-hr",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("45b122b3-c876-4691-9cf3-7e666660a034",-1030483504),$APP.$cljs$cst$2675$family$$,
"Playwrite HR",$APP.$cljs$cst$725$name$$,"Playwrite HR",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehr/v6/WWXAljmQYQCZM5qaU_dwQYcybAQ7GFn1mFNJPsoA9YHXAHC7tvg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehr/v6/WWXAljmQYQCZM5qaU_dwQYcybAQ7GFn1mFNJPkoB9YHXAHC7tvg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehr/v6/WWXAljmQYQCZM5qaU_dwQYcybAQ7GFn1mFNJPpQB9YHXAHC7tvg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehr/v6/WWXAljmQYQCZM5qaU_dwQYcybAQ7GFn1mFNJPsoB9YHXAHC7tvg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-hr-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("64011fb4-c6f7-46c7-b8b1-f1ff02b3900f",
-962296269),$APP.$cljs$cst$2675$family$$,"Playwrite HR Guides",$APP.$cljs$cst$725$name$$,"Playwrite HR Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehrguides/v1/6NUK8EedKwOcfRjj8ukv_L4kjqAoGrjdWmA08mCgdfM.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-hr-lijeva",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4677fac9-d315-4f2d-b912-217aed663e18",196851461),$APP.$cljs$cst$2675$family$$,"Playwrite HR Lijeva",$APP.$cljs$cst$725$name$$,"Playwrite HR Lijeva",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehrlijeva/v6/gNMvW2dhS5-p7HvxrBYiWN2SsKqLWCrYiDBAvbRl82ZY0d4zB8aUy4_lxmKl.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehrlijeva/v6/gNMvW2dhS5-p7HvxrBYiWN2SsKqLWCrYiDBAvbRl82ZY0d6zBsaUy4_lxmKl.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehrlijeva/v6/gNMvW2dhS5-p7HvxrBYiWN2SsKqLWCrYiDBAvbRl82ZY0d5tBsaUy4_lxmKl.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehrlijeva/v6/gNMvW2dhS5-p7HvxrBYiWN2SsKqLWCrYiDBAvbRl82ZY0d4zBsaUy4_lxmKl.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-hr-lijeva-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8708e01e-70f3-4e64-8622-cdc09f3fbca2",-1090522887),$APP.$cljs$cst$2675$family$$,"Playwrite HR Lijeva Guides",$APP.$cljs$cst$725$name$$,"Playwrite HR Lijeva Guides",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehrlijevaguides/v1/uU9aCAgH7I63K35cu3bRkqamzjr8EW133LJaXDO-QObhgDgMKYJO.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-playwrite-hu",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ae9a6e2c-e7a6-4ae2-b4a1-b4bf42045b3a",180991435),$APP.$cljs$cst$2675$family$$,"Playwrite HU",$APP.$cljs$cst$725$name$$,"Playwrite HU",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehu/v6/A2BIn59A0g0xA3zDhFw-0vfPWJtlaFKmrETx1PL7TO2dH3B2Xx4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehu/v6/A2BIn59A0g0xA3zDhFw-0vfPWJtlaFKmrETx1HL6TO2dH3B2Xx4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehu/v6/A2BIn59A0g0xA3zDhFw-0vfPWJtlaFKmrETx1Kz6TO2dH3B2Xx4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehu/v6/A2BIn59A0g0xA3zDhFw-0vfPWJtlaFKmrETx1PL6TO2dH3B2Xx4.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-hu-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f917fc9d-2e06-4abe-8a9c-853049d2cb34",584452845),$APP.$cljs$cst$2675$family$$,"Playwrite HU Guides",$APP.$cljs$cst$725$name$$,"Playwrite HU Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritehuguides/v1/AYCXpWvtftIVXepC5AzjCAdKgYPugOK0TqxTJw_GOM0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-id",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2637b948-8b77-41a7-9bd3-4932b95dc6f1",1973990029),$APP.$cljs$cst$2675$family$$,"Playwrite ID",$APP.$cljs$cst$725$name$$,
"Playwrite ID",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteid/v11/Cn-kJt2YWhlY2oC4KxifKQJmrtrRm-sKkQqUl0-QB_JbFi0pLlg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteid/v11/Cn-kJt2YWhlY2oC4KxifKQJmrtrRm-sKkQqUl8-RB_JbFi0pLlg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteid/v11/Cn-kJt2YWhlY2oC4KxifKQJmrtrRm-sKkQqUlxGRB_JbFi0pLlg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteid/v11/Cn-kJt2YWhlY2oC4KxifKQJmrtrRm-sKkQqUl0-RB_JbFi0pLlg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-id-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d687f55b-8cac-4c30-8d0c-7ebbd38a1a36",
950217792),$APP.$cljs$cst$2675$family$$,"Playwrite ID Guides",$APP.$cljs$cst$725$name$$,"Playwrite ID Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteidguides/v1/MjQamj1kuP_soQ3o-rysMdWi_8oJlIUUInch3bTfcxs.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-ie",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b58e03e5-faee-4b75-8fdd-1c5b9aa3f621",333506960),$APP.$cljs$cst$2675$family$$,"Playwrite IE",$APP.$cljs$cst$725$name$$,"Playwrite IE",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteie/v11/fC1zPYtWYWnH0hvndYd6GCGWXCAxfsUebXFMyzipBpIu30AZbUY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteie/v11/fC1zPYtWYWnH0hvndYd6GCGWXCAxfsUebXFMy7ioBpIu30AZbUY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteie/v11/fC1zPYtWYWnH0hvndYd6GCGWXCAxfsUebXFMy2aoBpIu30AZbUY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteie/v11/fC1zPYtWYWnH0hvndYd6GCGWXCAxfsUebXFMyzioBpIu30AZbUY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-ie-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("48005b5b-342f-4f39-bea6-927806c09261",929093908),$APP.$cljs$cst$2675$family$$,"Playwrite IE Guides",$APP.$cljs$cst$725$name$$,"Playwrite IE Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteieguides/v1/LhW5MULFNP8PI-1UADw_Kbp9daTx5ovUaNojN9_8IVQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-in",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2a867c5c-2a9a-418c-9eae-fa46b547efd9",
598117056),$APP.$cljs$cst$2675$family$$,"Playwrite IN",$APP.$cljs$cst$725$name$$,"Playwrite IN",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritein/v11/uk-xEGGpoLQ97mfv2J3cZzuz7CyEJhPw65lkM7mNMR8n3_Ag1kU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritein/v11/uk-xEGGpoLQ97mfv2J3cZzuz7CyEJhPw65lkMzmMMR8n3_Ag1kU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritein/v11/uk-xEGGpoLQ97mfv2J3cZzuz7CyEJhPw65lkM-eMMR8n3_Ag1kU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritein/v11/uk-xEGGpoLQ97mfv2J3cZzuz7CyEJhPw65lkM7mMMR8n3_Ag1kU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-in-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0df388a8-7b1a-49c5-9caa-b4e307b67347",1446411639),$APP.$cljs$cst$2675$family$$,"Playwrite IN Guides",$APP.$cljs$cst$725$name$$,"Playwrite IN Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteinguides/v1/GFD2WBRug3mQSvrAT9AL4vx4d3lQNQV4Tt1qdGqgdlM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-is",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5e3bd887-0c75-4d52-8f18-14dc9750b244",1120675817),$APP.$cljs$cst$2675$family$$,"Playwrite IS",$APP.$cljs$cst$725$name$$,"Playwrite IS",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteis/v10/JTUFjI4o_SGg9lecLGptrD17xQYXK0vOoz6jq6R8aX9-p7K5ILg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteis/v10/JTUFjI4o_SGg9lecLGptrD17xQYXK0vOoz6jqyR9aX9-p7K5ILg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteis/v10/JTUFjI4o_SGg9lecLGptrD17xQYXK0vOoz6jq_p9aX9-p7K5ILg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteis/v10/JTUFjI4o_SGg9lecLGptrD17xQYXK0vOoz6jq6R9aX9-p7K5ILg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-is-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c7a12342-dc86-485e-954c-20f0d90bbff2",-583810207),$APP.$cljs$cst$2675$family$$,
"Playwrite IS Guides",$APP.$cljs$cst$725$name$$,"Playwrite IS Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteisguides/v1/5aUp9-GkphaVExwxdX6SwWF-uigk3Cglrm9ptxu7HZ0.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-it-moderna",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("24e98223-2c4b-499d-9e74-c941fa3e29b7",-584218543),$APP.$cljs$cst$2675$family$$,"Playwrite IT Moderna",$APP.$cljs$cst$725$name$$,"Playwrite IT Moderna",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteitmoderna/v11/mFTbWaYCwKPK5cx6W8jy2kwDnSUe9q45vQQi5HMFnSdEx2F5Wil8ubbffHtmMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteitmoderna/v11/mFTbWaYCwKPK5cx6W8jy2kwDnSUe9q45vQQi5HMFnSdEx2F52ih8ubbffHtmMw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteitmoderna/v11/mFTbWaYCwKPK5cx6W8jy2kwDnSUe9q45vQQi5HMFnSdEx2F5BCh8ubbffHtmMw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteitmoderna/v11/mFTbWaYCwKPK5cx6W8jy2kwDnSUe9q45vQQi5HMFnSdEx2F5Wih8ubbffHtmMw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-it-moderna-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3407e320-c75c-4c21-9034-1fdebaa070c8",497914748),$APP.$cljs$cst$2675$family$$,"Playwrite IT Moderna Guides",$APP.$cljs$cst$725$name$$,"Playwrite IT Moderna Guides",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteitmodernaguides/v1/2sDKZHBJg5rCj6fz_QgDJhGcTtJ5AVu-1w5jRQjRv9qPpOVtBhB5gQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-playwrite-it-trad",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("afb13fed-9a19-48ef-a91b-133e5c86e37a",360978108),$APP.$cljs$cst$2675$family$$,"Playwrite IT Trad",$APP.$cljs$cst$725$name$$,"Playwrite IT Trad",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteittrad/v11/SlG5mR6Yo5oYZX5BFVcEySBSPE50BjHDpZxuvgxzFq96u--_gENNXvzL2Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteittrad/v11/SlG5mR6Yo5oYZX5BFVcEySBSPE50BjHDpZxuvgxzFq96O-6_gENNXvzL2Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteittrad/v11/SlG5mR6Yo5oYZX5BFVcEySBSPE50BjHDpZxuvgxzFq965e6_gENNXvzL2Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteittrad/v11/SlG5mR6Yo5oYZX5BFVcEySBSPE50BjHDpZxuvgxzFq96u-6_gENNXvzL2Q.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-it-trad-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("21843dd5-0f8e-4a76-b8f6-1b43ad5b96cc",1682286605),$APP.$cljs$cst$2675$family$$,"Playwrite IT Trad Guides",$APP.$cljs$cst$725$name$$,"Playwrite IT Trad Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteittradguides/v2/SlGDmReYo5oYZX5BFVcEySBSPE50BiuP2AHaRsRUA4V-e6yHgQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-mx",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6525d4f1-bf93-4769-a670-ac8b7a4b83ae",1951677267),$APP.$cljs$cst$2675$family$$,
"Playwrite MX",$APP.$cljs$cst$725$name$$,"Playwrite MX",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritemx/v13/6xK9dSNbKtCe7KfhXg7RYSwyQ-oO7xNblyJr9wnc5xYfXDWXDu8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritemx/v13/6xK9dSNbKtCe7KfhXg7RYSwyQ-oO7xNblyJr94nd5xYfXDWXDu8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritemx/v13/6xK9dSNbKtCe7KfhXg7RYSwyQ-oO7xNblyJr91fd5xYfXDWXDu8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritemx/v13/6xK9dSNbKtCe7KfhXg7RYSwyQ-oO7xNblyJr9wnd5xYfXDWXDu8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-mx-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2e6ef904-50ba-437e-8e59-abb1ce2e8b7a",
1218638204),$APP.$cljs$cst$2675$family$$,"Playwrite MX Guides",$APP.$cljs$cst$725$name$$,"Playwrite MX Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritemxguides/v1/k3kMo9ESPe9dzQ1UGbvoZhnhbtfklWqN0qywHx-HpY0.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-ng-modern",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f42c03b6-a9c0-4540-bac2-0d579da4c465",-1667570324),$APP.$cljs$cst$2675$family$$,"Playwrite NG Modern",$APP.$cljs$cst$725$name$$,"Playwrite NG Modern",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritengmodern/v11/ijw-s4b2R9Qve5V5lNJb_yRhEfSep5NbFCKmKgoEeCA4V17tPQbi5GswWJNE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritengmodern/v11/ijw-s4b2R9Qve5V5lNJb_yRhEfSep5NbFCKmKgoEeCA4V15tPAbi5GswWJNE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritengmodern/v11/ijw-s4b2R9Qve5V5lNJb_yRhEfSep5NbFCKmKgoEeCA4V16zPAbi5GswWJNE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritengmodern/v11/ijw-s4b2R9Qve5V5lNJb_yRhEfSep5NbFCKmKgoEeCA4V17tPAbi5GswWJNE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-ng-modern-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9117557d-25ea-41b7-8251-655ba356b727",-1854825267),$APP.$cljs$cst$2675$family$$,"Playwrite NG Modern Guides",$APP.$cljs$cst$725$name$$,"Playwrite NG Modern Guides",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritengmodernguides/v1/6qLVKYQNtxD-qVlIPUIPdWMlWxy3BmFEQgxB1xvFhDarWJtyZyGU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-playwrite-nl",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9faf6eda-fbcb-4a39-9cab-ed9260885861",-439300466),$APP.$cljs$cst$2675$family$$,"Playwrite NL",$APP.$cljs$cst$725$name$$,"Playwrite NL",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritenl/v10/k3kCo84SPe9dzQ1UGbvoZQ37Iqp5IZJF9bmaG9_EnYxNbPzS5HE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritenl/v10/k3kCo84SPe9dzQ1UGbvoZQ37Iqp5IZJF9bmaG1_FnYxNbPzS5HE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritenl/v10/k3kCo84SPe9dzQ1UGbvoZQ37Iqp5IZJF9bmaG4HFnYxNbPzS5HE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritenl/v10/k3kCo84SPe9dzQ1UGbvoZQ37Iqp5IZJF9bmaG9_FnYxNbPzS5HE.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-nl-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("173c6f34-c927-4234-955d-0d5f4d6b0ca6",1735272313),$APP.$cljs$cst$2675$family$$,"Playwrite NL Guides",$APP.$cljs$cst$725$name$$,"Playwrite NL Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritenlguides/v1/FwZH7_8mxlw-50y5PJughoCL4jbXkMqwsWKGP6kvdPA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-no",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fd519933-f1a8-4740-86bc-d8a0fe23e4ab",1996564251),$APP.$cljs$cst$2675$family$$,"Playwrite NO",$APP.$cljs$cst$725$name$$,
"Playwrite NO",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteno/v10/nuFrD_fYSZviRJYb-P2TrQO1DRpazaZDgnw-49whHKen-mjRVtc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteno/v10/nuFrD_fYSZviRJYb-P2TrQO1DRpazaZDgnw-41wgHKen-mjRVtc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteno/v10/nuFrD_fYSZviRJYb-P2TrQO1DRpazaZDgnw-44IgHKen-mjRVtc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteno/v10/nuFrD_fYSZviRJYb-P2TrQO1DRpazaZDgnw-49wgHKen-mjRVtc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-no-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("685ead0e-9c35-4acd-b4cf-50951e07bad8",
344273379),$APP.$cljs$cst$2675$family$$,"Playwrite NO Guides",$APP.$cljs$cst$725$name$$,"Playwrite NO Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritenoguides/v1/DPEwYx-Cyg4cQ2aAcFshOLL79zJKccqHe2-Z2vnLeAs.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-nz",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f517b9b9-92ee-4f01-a595-1ce276c1cfdd",-740294573),$APP.$cljs$cst$2675$family$$,"Playwrite NZ",$APP.$cljs$cst$725$name$$,"Playwrite NZ",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritenz/v11/d6lakaOxRsyr_zZDmUYvh2TW3NCQVvjKPjPjngAVeRt5gGCzkrs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritenz/v11/d6lakaOxRsyr_zZDmUYvh2TW3NCQVvjKPjPjnoAUeRt5gGCzkrs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritenz/v11/d6lakaOxRsyr_zZDmUYvh2TW3NCQVvjKPjPjnl4UeRt5gGCzkrs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritenz/v11/d6lakaOxRsyr_zZDmUYvh2TW3NCQVvjKPjPjngAUeRt5gGCzkrs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-nz-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2bcc28d1-409a-43bd-a178-91ccc5cb48d0",1609423577),$APP.$cljs$cst$2675$family$$,"Playwrite NZ Guides",$APP.$cljs$cst$725$name$$,"Playwrite NZ Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritenzguides/v1/t5t8IQQPN4uFDRepJwiX4vzIikyGzv71Wh8xq25PL5k.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-pe",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2ac4ed7b-7a4f-482f-a0db-5711d46464f0",
1725639200),$APP.$cljs$cst$2675$family$$,"Playwrite PE",$APP.$cljs$cst$725$name$$,"Playwrite PE",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritepe/v6/FwZJ7-Amxlw-50y5PJugmImRrktKJDJ4lnesO2lsTPHFdtSgb_A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritepe/v6/FwZJ7-Amxlw-50y5PJugmImRrktKJDJ4lnesO-ltTPHFdtSgb_A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritepe/v6/FwZJ7-Amxlw-50y5PJugmImRrktKJDJ4lnesOzdtTPHFdtSgb_A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritepe/v6/FwZJ7-Amxlw-50y5PJugmImRrktKJDJ4lnesO2ltTPHFdtSgb_A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-pe-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("360f3009-3f84-4e73-9354-2419a0348b1d",971023134),$APP.$cljs$cst$2675$family$$,"Playwrite PE Guides",$APP.$cljs$cst$725$name$$,"Playwrite PE Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritepeguides/v1/AMONz5uBsGadFuvf9j8ZyqI0FA3br70wwyyAlqETME8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-pl",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cc3fff93-a031-4724-ad88-87de5f46e19e",2071487683),$APP.$cljs$cst$2675$family$$,"Playwrite PL",$APP.$cljs$cst$725$name$$,"Playwrite PL",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritepl/v10/0QIyMXVf_4C2VH-yUr5uz72U-LQiKJ_9tb1WmRfa9ZybSwcVtHQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritepl/v10/0QIyMXVf_4C2VH-yUr5uz72U-LQiKJ_9tb1WmZfb9ZybSwcVtHQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritepl/v10/0QIyMXVf_4C2VH-yUr5uz72U-LQiKJ_9tb1WmUnb9ZybSwcVtHQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritepl/v10/0QIyMXVf_4C2VH-yUr5uz72U-LQiKJ_9tb1WmRfb9ZybSwcVtHQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-pl-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d2b303e9-2fc5-4d26-8d14-e7c4fd35416f",1267936228),$APP.$cljs$cst$2675$family$$,
"Playwrite PL Guides",$APP.$cljs$cst$725$name$$,"Playwrite PL Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteplguides/v1/jVyW7m_lCm7G5CZyQCAu8mgkGLk-kmibWR3aRZ2Kw7A.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-pt",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9d9390d6-e1de-4aaf-a193-cc7e046e9938",1093652183),$APP.$cljs$cst$2675$family$$,"Playwrite PT",$APP.$cljs$cst$725$name$$,"Playwrite PT",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritept/v10/6NUE8FidKwOcfRjj8ukv5Lg-wt21rkAVfXUe9qDjTfJtvlo3Qaw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritept/v10/6NUE8FidKwOcfRjj8ukv5Lg-wt21rkAVfXUe9iDiTfJtvlo3Qaw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritept/v10/6NUE8FidKwOcfRjj8ukv5Lg-wt21rkAVfXUe9v7iTfJtvlo3Qaw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritept/v10/6NUE8FidKwOcfRjj8ukv5Lg-wt21rkAVfXUe9qDiTfJtvlo3Qaw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-pt-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("76324382-9c03-4534-bb27-e182b5d2751e",-1957896137),$APP.$cljs$cst$2675$family$$,"Playwrite PT Guides",$APP.$cljs$cst$725$name$$,"Playwrite PT Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteptguides/v2/sJoY3K5JjdGLJV3vyatrMkupgg-kWTx5F5k90TZO69o.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-ro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5981de8f-36ce-4773-a627-e722351cc088",
-1991352864),$APP.$cljs$cst$2675$family$$,"Playwrite RO",$APP.$cljs$cst$725$name$$,"Playwrite RO",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritero/v10/gok8H6fuA1J7QPJ04HFTGSWdk_S0czhwEf0j4a9ZnZWMJnZeBS8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritero/v10/gok8H6fuA1J7QPJ04HFTGSWdk_S0czhwEf0j4S9YnZWMJnZeBS8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritero/v10/gok8H6fuA1J7QPJ04HFTGSWdk_S0czhwEf0j4fFYnZWMJnZeBS8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritero/v10/gok8H6fuA1J7QPJ04HFTGSWdk_S0czhwEf0j4a9YnZWMJnZeBS8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-ro-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("51963d12-4eff-4a27-96c4-a78d59e66069",1655616849),$APP.$cljs$cst$2675$family$$,"Playwrite RO Guides",$APP.$cljs$cst$725$name$$,"Playwrite RO Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteroguides/v1/wlptgx7ZCE50snmWiOExiylvL10_b5Ym_LBte6KuGEo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-sk",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("97174116-7c18-4108-921b-73563af8b618",-709346805),$APP.$cljs$cst$2675$family$$,"Playwrite SK",$APP.$cljs$cst$725$name$$,"Playwrite SK",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritesk/v10/9XU3lJp0klrZDw3AZHcsJTByz7latrF9yDIlf-2dvsOzdK9OF68.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritesk/v10/9XU3lJp0klrZDw3AZHcsJTByz7latrF9yDIlf22cvsOzdK9OF68.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritesk/v10/9XU3lJp0klrZDw3AZHcsJTByz7latrF9yDIlf7OcvsOzdK9OF68.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritesk/v10/9XU3lJp0klrZDw3AZHcsJTByz7latrF9yDIlf-2cvsOzdK9OF68.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-sk-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3d12c86a-22b0-40e5-86b3-28de134218d9",-1663677236),$APP.$cljs$cst$2675$family$$,
"Playwrite SK Guides",$APP.$cljs$cst$725$name$$,"Playwrite SK Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteskguides/v1/P5sezYaSYdfH5z93kEFk3tyPlqxeQeo_JzruWQshcbU.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-tz",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3f0b6dd8-fb83-4eb4-816d-7dd85f83ccb4",-769815985),$APP.$cljs$cst$2675$family$$,"Playwrite TZ",$APP.$cljs$cst$725$name$$,"Playwrite TZ",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritetz/v11/RLptK5rs6au7bzABmVQAOwnUbvHMbzSUU27JDWwSue1COwjVROo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritetz/v11/RLptK5rs6au7bzABmVQAOwnUbvHMbzSUU27JDewTue1COwjVROo.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritetz/v11/RLptK5rs6au7bzABmVQAOwnUbvHMbzSUU27JDTITue1COwjVROo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritetz/v11/RLptK5rs6au7bzABmVQAOwnUbvHMbzSUU27JDWwTue1COwjVROo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-tz-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f304918d-9016-44c7-911e-453582fd319f",-164173604),$APP.$cljs$cst$2675$family$$,"Playwrite TZ Guides",$APP.$cljs$cst$725$name$$,"Playwrite TZ Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritetzguides/v1/SLXUc0_L5XEkcjBPGvusk4lULgsM9U5_YQy93JQ2XEg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-us-modern",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("09a04141-c7da-4075-9191-91c841c533b4",443633403),$APP.$cljs$cst$2675$family$$,"Playwrite US Modern",$APP.$cljs$cst$725$name$$,"Playwrite US Modern",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/playwriteusmodern/v11/H4cMBWmRlMXPhla3hmMaveiYz8nSDkIFLNIYl2TXUwK62YohNw2Da0LCgUPK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteusmodern/v11/H4cMBWmRlMXPhla3hmMaveiYz8nSDkIFLNIYl2TXUwK62YqhNg2Da0LCgUPK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteusmodern/v11/H4cMBWmRlMXPhla3hmMaveiYz8nSDkIFLNIYl2TXUwK62Yp_Ng2Da0LCgUPK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteusmodern/v11/H4cMBWmRlMXPhla3hmMaveiYz8nSDkIFLNIYl2TXUwK62YohNg2Da0LCgUPK.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-us-modern-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d4efd63f-3975-492a-849e-cb7d30e7b3d5",823208145),$APP.$cljs$cst$2675$family$$,"Playwrite US Modern Guides",$APP.$cljs$cst$725$name$$,"Playwrite US Modern Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteusmodernguides/v1/0QI1MWNf_4C2VH-yUr5uyqKOvtOynXAoku8j8Lv9pryxZQscrW1V.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-us-trad",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("beb6951a-29c2-4799-811e-34da7eefcc67",-1392892269),$APP.$cljs$cst$2675$family$$,
"Playwrite US Trad",$APP.$cljs$cst$725$name$$,"Playwrite US Trad",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteustrad/v11/fdNX9tyHsnVPjW9trmV7wQ0stdwRBYclCsCdzOb1-cd1E8pgj6Kf5uBNig.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteustrad/v11/fdNX9tyHsnVPjW9trmV7wQ0stdwRBYclCsCdzOb1-cd1k8tgj6Kf5uBNig.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteustrad/v11/fdNX9tyHsnVPjW9trmV7wQ0stdwRBYclCsCdzOb1-cd1Tctgj6Kf5uBNig.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteustrad/v11/fdNX9tyHsnVPjW9trmV7wQ0stdwRBYclCsCdzOb1-cd1E8tgj6Kf5uBNig.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-us-trad-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bcade2d4-c8f3-4b54-aec6-198d8429a0f3",-92065610),$APP.$cljs$cst$2675$family$$,"Playwrite US Trad Guides",$APP.$cljs$cst$725$name$$,"Playwrite US Trad Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteustradguides/v1/-zk29027wssz_XLkGgu8kTL39c2bMssjmiZPNnk5nJCZAyrUdw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-vn",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("184bdbac-c0ec-4f6c-95f7-0cb1d5b8e1ef",358122587),$APP.$cljs$cst$2675$family$$,"Playwrite VN",$APP.$cljs$cst$725$name$$,"Playwrite VN",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritevn/v11/mtGo4_hXJqPSu8nf5RBY5i0q0yxCxtP-9TFBNUI8E-9HPWIQtD0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritevn/v11/mtGo4_hXJqPSu8nf5RBY5i0q0yxCxtP-9TFBNcI9E-9HPWIQtD0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritevn/v11/mtGo4_hXJqPSu8nf5RBY5i0q0yxCxtP-9TFBNRw9E-9HPWIQtD0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritevn/v11/mtGo4_hXJqPSu8nf5RBY5i0q0yxCxtP-9TFBNUI9E-9HPWIQtD0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-vn-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bc60e9ec-5300-4b2f-882d-55daf78c9027",
-1414793811),$APP.$cljs$cst$2675$family$$,"Playwrite VN Guides",$APP.$cljs$cst$725$name$$,"Playwrite VN Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritevnguides/v1/JIAvUUlydXJZq1IQU8oDBn2CUkROHFEAfXMXfpmSLuI.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-za",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("aafe8906-7a82-405a-b1b9-3969981c6046",-1265750492),$APP.$cljs$cst$2675$family$$,"Playwrite ZA",$APP.$cljs$cst$725$name$$,"Playwrite ZA",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteza/v11/Noag6Uzhw5CTOhXKt5-vwvhrNyaNQo1LaBq0EbLGbYUsn9T5dt0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteza/v11/Noag6Uzhw5CTOhXKt5-vwvhrNyaNQo1LaBq0ETLHbYUsn9T5dt0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteza/v11/Noag6Uzhw5CTOhXKt5-vwvhrNyaNQo1LaBq0EezHbYUsn9T5dt0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwriteza/v11/Noag6Uzhw5CTOhXKt5-vwvhrNyaNQo1LaBq0EbLHbYUsn9T5dt0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-playwrite-za-guides",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c91bde44-d40c-49f7-adac-1f6af0e23110",1144200207),$APP.$cljs$cst$2675$family$$,"Playwrite ZA Guides",$APP.$cljs$cst$725$name$$,"Playwrite ZA Guides",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/playwritezaguides/v1/O4ZOFHPsmxlhCg3-iycDyEwy0BT1ribk2HDoCLfQmgE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-plus-jakarta-sans",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("e663729d-0244-436b-a13b-013eb140c2c4",1958932267),$APP.$cljs$cst$2675$family$$,"Plus Jakarta Sans",$APP.$cljs$cst$725$name$$,"Plus Jakarta Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/plusjakartasans/v12/LDIbaomQNQcsA88c7O9yZ4KMCoOg4IA6-91aHEjcWuA_KU7NShXUEKi4Rw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/plusjakartasans/v12/LDIbaomQNQcsA88c7O9yZ4KMCoOg4IA6-91aHEjcWuA_907NShXUEKi4Rw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/plusjakartasans/v12/LDIbaomQNQcsA88c7O9yZ4KMCoOg4IA6-91aHEjcWuA_qU7NShXUEKi4Rw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/plusjakartasans/v12/LDIbaomQNQcsA88c7O9yZ4KMCoOg4IA6-91aHEjcWuA_m07NShXUEKi4Rw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/plusjakartasans/v12/LDIbaomQNQcsA88c7O9yZ4KMCoOg4IA6-91aHEjcWuA_d0nNShXUEKi4Rw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/plusjakartasans/v12/LDIbaomQNQcsA88c7O9yZ4KMCoOg4IA6-91aHEjcWuA_TknNShXUEKi4Rw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/plusjakartasans/v12/LDIbaomQNQcsA88c7O9yZ4KMCoOg4IA6-91aHEjcWuA_KUnNShXUEKi4Rw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/plusjakartasans/v12/LDIZaomQNQcsA88c7O9yZ4KMCoOg4KozySKCdSNG9OcqYQ2lCR_QMq2oR82k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/plusjakartasans/v12/LDIZaomQNQcsA88c7O9yZ4KMCoOg4KozySKCdSNG9OcqYQ17CR_QMq2oR82k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/plusjakartasans/v12/LDIZaomQNQcsA88c7O9yZ4KMCoOg4KozySKCdSNG9OcqYQ0lCR_QMq2oR82k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/plusjakartasans/v12/LDIZaomQNQcsA88c7O9yZ4KMCoOg4KozySKCdSNG9OcqYQ0XCR_QMq2oR82k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/plusjakartasans/v12/LDIZaomQNQcsA88c7O9yZ4KMCoOg4KozySKCdSNG9OcqYQ37Dh_QMq2oR82k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/plusjakartasans/v12/LDIZaomQNQcsA88c7O9yZ4KMCoOg4KozySKCdSNG9OcqYQ3CDh_QMq2oR82k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/plusjakartasans/v12/LDIZaomQNQcsA88c7O9yZ4KMCoOg4KozySKCdSNG9OcqYQ2lDh_QMq2oR82k.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pochaevsk",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b918876f-31cb-4759-94b6-146dcebe777e",818558660),$APP.$cljs$cst$2675$family$$,
"Pochaevsk",$APP.$cljs$cst$725$name$$,"Pochaevsk",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pochaevsk/v5/55xuey9_OdX_Om7ReYgloJd4-bnQKg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-podkova",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1a762fc2-3c14-4921-8723-e717239dbf61",-2114569327),$APP.$cljs$cst$2675$family$$,"Podkova",$APP.$cljs$cst$725$name$$,"Podkova",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/podkova/v33/K2FufZ1EmftJSV9VQpXb1lo9vC3nZWtFzcU4EoporSHH.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/podkova/v33/K2FufZ1EmftJSV9VQpXb1lo9vC3nZWt3zcU4EoporSHH.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/podkova/v33/K2FufZ1EmftJSV9VQpXb1lo9vC3nZWubysU4EoporSHH.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/podkova/v33/K2FufZ1EmftJSV9VQpXb1lo9vC3nZWuiysU4EoporSHH.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/podkova/v33/K2FufZ1EmftJSV9VQpXb1lo9vC3nZWvFysU4EoporSHH.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-poetsen-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bb7f397b-be20-484b-83f7-eb3dad0685fc",
-2145001394),$APP.$cljs$cst$2675$family$$,"Poetsen One",$APP.$cljs$cst$725$name$$,"Poetsen One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poetsenone/v3/ke8hOgIaMUB37xCgvCntWtIvq_KREbG9.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-poiret-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5a144bda-5b80-461e-b058-1f1d4ee86bfe",1198925888),$APP.$cljs$cst$2675$family$$,"Poiret One",$APP.$cljs$cst$725$name$$,"Poiret One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poiretone/v18/UqyVK80NJXN4zfRgbdfbk5lWVscxdKE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-poller-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("386dcb49-c1c0-4f57-8ec5-62a2c7002b92",1314762696),$APP.$cljs$cst$2675$family$$,"Poller One",$APP.$cljs$cst$725$name$$,"Poller One",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pollerone/v25/ahccv82n0TN3gia5E4Bud-lbgUS5u0s.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-poltawski-nowy",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("afd717f1-1abe-4e58-b1d8-a197ed6661bd",-1196639635),$APP.$cljs$cst$2675$family$$,"Poltawski Nowy",$APP.$cljs$cst$725$name$$,"Poltawski Nowy",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/poltawskinowy/v5/flUsRq6ww480U1xsUpFXD-iDBNlSAOLkKCLnWq8KqCWnDS6V5CzCoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poltawskinowy/v5/flUsRq6ww480U1xsUpFXD-iDBNlSAOLkKCLnWq8KmiWnDS6V5CzCoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poltawskinowy/v5/flUsRq6ww480U1xsUpFXD-iDBNlSAOLkKCLnWq8KdiKnDS6V5CzCoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poltawskinowy/v5/flUsRq6ww480U1xsUpFXD-iDBNlSAOLkKCLnWq8KTyKnDS6V5CzCoQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poltawskinowy/v5/flUuRq6ww480U1xsUpFXD-iDBPNbMh08QUl99KgfYGZPTiSRxinSoROp.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poltawskinowy/v5/flUuRq6ww480U1xsUpFXD-iDBPNbMh08QUl99KgfYGZ9TiSRxinSoROp.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poltawskinowy/v5/flUuRq6ww480U1xsUpFXD-iDBPNbMh08QUl99KgfYGaRSSSRxinSoROp.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poltawskinowy/v5/flUuRq6ww480U1xsUpFXD-iDBPNbMh08QUl99KgfYGaoSSSRxinSoROp.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-poly",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("705ea33d-b98b-49b2-ae67-ca1ac9e894a1",-1608402652),$APP.$cljs$cst$2675$family$$,
"Poly",$APP.$cljs$cst$725$name$$,"Poly",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poly/v18/MQpb-W6wKNitRLCAq2Lpris.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poly/v18/MQpV-W6wKNitdLKKr0DsviuGWA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pompiere",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1316818c-ca20-4335-a241-c9599d0ff3de",-847837752),$APP.$cljs$cst$2675$family$$,"Pompiere",$APP.$cljs$cst$725$name$$,"Pompiere",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pompiere/v21/VEMyRoxis5Dwuyeov6Wt5jDtreOL.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ponnala",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("a04a4747-ea96-4921-bf35-dd0c311a6e8d",-743619539),$APP.$cljs$cst$2675$family$$,"Ponnala",$APP.$cljs$cst$725$name$$,"Ponnala",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ponnala/v3/w8gaH2QxQOU08bbbrQut2F4OuOo.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ponomar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6e85ed12-dc80-4824-9a48-4ef4c8b585bc",-440764007),$APP.$cljs$cst$2675$family$$,"Ponomar",$APP.$cljs$cst$725$name$$,"Ponomar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ponomar/v5/or3iQ6zp3fKD2wImbJTdArg8hzo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pontano-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b96e781d-3a43-4e9b-8290-79a83821f672",-752865888),$APP.$cljs$cst$2675$family$$,"Pontano Sans",$APP.$cljs$cst$725$name$$,"Pontano Sans",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pontanosans/v19/qFdW35GdgYR8EzR6oBLDHa3wyRf8W8eBM6XLOSzMncaMp9gzWsE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pontanosans/v19/qFdW35GdgYR8EzR6oBLDHa3wyRf8W8eBM6XLOXLMncaMp9gzWsE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pontanosans/v19/qFdW35GdgYR8EzR6oBLDHa3wyRf8W8eBM6XLOUDMncaMp9gzWsE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pontanosans/v19/qFdW35GdgYR8EzR6oBLDHa3wyRf8W8eBM6XLOazLncaMp9gzWsE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pontanosans/v19/qFdW35GdgYR8EzR6oBLDHa3wyRf8W8eBM6XLOZXLncaMp9gzWsE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-poor-story",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d45f4391-8ace-46cf-8f94-1409b3418b3a",-912454),$APP.$cljs$cst$2675$family$$,"Poor Story",$APP.$cljs$cst$725$name$$,"Poor Story",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poorstory/v24/jizfREFUsnUct9P6cDfd4OmnLD0Z4zM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-poppins",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9f03d2fc-853c-412d-aa56-9ce95563bb77",-835420759),$APP.$cljs$cst$2675$family$$,
"Poppins",$APP.$cljs$cst$725$name$$,"Poppins",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiGyp8kv8JHgFVrLPTed3FBGPaTSQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiAyp8kv8JHgFVrJJLmE3tFOvODSVFF.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiByp8kv8JHgFVrLFj_V1tvFP-KUEg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiDyp8kv8JHgFVrJJLmv1plEN2PQEhcqw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/poppins/v24/pxiByp8kv8JHgFVrLDz8V1tvFP-KUEg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiDyp8kv8JHgFVrJJLm21llEN2PQEhcqw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiEyp8kv8JHgFVrFJDUc1NECPY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiGyp8kv8JHgFVrJJLed3FBGPaTSQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiByp8kv8JHgFVrLGT9V1tvFP-KUEg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiDyp8kv8JHgFVrJJLmg1hlEN2PQEhcqw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiByp8kv8JHgFVrLEj6V1tvFP-KUEg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/poppins/v24/pxiDyp8kv8JHgFVrJJLmr19lEN2PQEhcqw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiByp8kv8JHgFVrLCz7V1tvFP-KUEg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",
$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiDyp8kv8JHgFVrJJLmy15lEN2PQEhcqw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiByp8kv8JHgFVrLDD4V1tvFP-KUEg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiDyp8kv8JHgFVrJJLm111lEN2PQEhcqw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiByp8kv8JHgFVrLBT5V1tvFP-KUEg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/poppins/v24/pxiDyp8kv8JHgFVrJJLm81xlEN2PQEhcqw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-port-lligat-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d2ec8b9f-a9e5-45af-a027-4ff550b32987",
-616675606),$APP.$cljs$cst$2675$family$$,"Port Lligat Sans",$APP.$cljs$cst$725$name$$,"Port Lligat Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/portlligatsans/v24/kmKmZrYrGBbdN1aV7Vokow6Lw4s4l7N0Tx4xEcQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-port-lligat-slab",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c76754e7-40d7-48bb-ab17-443a0a57483e",1514730988),$APP.$cljs$cst$2675$family$$,"Port Lligat Slab",$APP.$cljs$cst$725$name$$,"Port Lligat Slab",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/portlligatslab/v27/LDIpaoiQNgArA8kR7ulhZ8P_NYOss7ob9yGLmfI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-potta-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8417cf75-35c7-43cc-a91a-7402dfb777bf",2100880815),$APP.$cljs$cst$2675$family$$,"Potta One",$APP.$cljs$cst$725$name$$,
"Potta One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pottaone/v19/FeVSS05Bp6cy7xI-YfxQ3Z5nm29Gww.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-pragati-narrow",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9a36903c-49b7-46bb-bbb3-2a247057c670",-1636535071),$APP.$cljs$cst$2675$family$$,"Pragati Narrow",$APP.$cljs$cst$725$name$$,"Pragati Narrow",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pragatinarrow/v15/vm8vdRf0T0bS1ffgsPB7WZ-mD17_ytN3M48a.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pragatinarrow/v15/vm8sdRf0T0bS1ffgsPB7WZ-mD2ZD5fd_GJMTlo_4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-praise",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5f9c35a4-e346-4320-9a80-68740adc7fa9",-1701304391),$APP.$cljs$cst$2675$family$$,"Praise",$APP.$cljs$cst$725$name$$,"Praise",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/praise/v9/qkBUXvUZ-cnFXcFyDvO67L9XmQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-prata",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5656d329-60a6-41de-b2c6-94d9190e78f2",-1498932079),$APP.$cljs$cst$2675$family$$,"Prata",$APP.$cljs$cst$725$name$$,"Prata",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prata/v22/6xKhdSpbNNCT-vWIAG_5LWwJ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-preahvihear",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7bc3e2fc-f3ba-43b8-850d-33e776cc107b",-304780350),$APP.$cljs$cst$2675$family$$,"Preahvihear",$APP.$cljs$cst$725$name$$,
"Preahvihear",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/preahvihear/v32/6NUS8F-dNQeEYhzj7uluxswE49FJf8Wv.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-press-start-2p",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9c49f49f-267f-418b-beae-608b643e1056",-361230252),$APP.$cljs$cst$2675$family$$,"Press Start 2P",$APP.$cljs$cst$725$name$$,"Press Start 2P",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pressstart2p/v16/e3t4euO8T-267oIAQAu6jDQyK0nSgPJE4580.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-pridi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ff5d9660-0562-4720-966a-549626ddc366",-1459079693),$APP.$cljs$cst$2675$family$$,"Pridi",$APP.$cljs$cst$725$name$$,"Pridi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pridi/v15/2sDdZG5JnZLfkc1SiE0jRUG0AqUc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pridi/v15/2sDdZG5JnZLfkc02i00jRUG0AqUc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pridi/v15/2sDQZG5JnZLfkfWao2krbl29.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pridi/v15/2sDdZG5JnZLfkc1uik0jRUG0AqUc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pridi/v15/2sDdZG5JnZLfkc1CjU0jRUG0AqUc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/pridi/v15/2sDdZG5JnZLfkc0mjE0jRUG0AqUc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-princess-sofia",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("62745e59-2ee8-46af-a46d-1b4182bf15c6",1039589244),$APP.$cljs$cst$2675$family$$,"Princess Sofia",$APP.$cljs$cst$725$name$$,
"Princess Sofia",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/princesssofia/v27/qWczB6yguIb8DZ_GXZst16n7GRz7mDUoupoI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-prociono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b72ff734-452a-4772-a0e7-baf6c2e6582a",-1287440352),$APP.$cljs$cst$2675$family$$,"Prociono",$APP.$cljs$cst$725$name$$,"Prociono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prociono/v28/r05YGLlR-KxAf9GGO8upyDYtStiJ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-prompt",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c399039b-7744-433b-b141-3786ee8cef71",-1638829115),$APP.$cljs$cst$2675$family$$,"Prompt",$APP.$cljs$cst$725$name$$,"Prompt",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W_9XJnvUD7dzB2CA9oYREcjeo0k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/prompt/v12/-W_7XJnvUD7dzB2KZeJ8TkMBf50kbiM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W_8XJnvUD7dzB2Cr_s4bmkvc5Q9dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W_6XJnvUD7dzB2KZeLQb2MrUZEtdzow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W_8XJnvUD7dzB2Cy_g4bmkvc5Q9dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W_6XJnvUD7dzB2KZeK0bGMrUZEtdzow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W__XJnvUD7dzB26Z9AcZkIzeg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W_9XJnvUD7dzB2KZdoYREcjeo0k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/prompt/v12/-W_8XJnvUD7dzB2Ck_k4bmkvc5Q9dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W_6XJnvUD7dzB2KZeLsbWMrUZEtdzow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W_8XJnvUD7dzB2Cv_44bmkvc5Q9dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W_6XJnvUD7dzB2KZeLAamMrUZEtdzow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W_8XJnvUD7dzB2C2_84bmkvc5Q9dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W_6XJnvUD7dzB2KZeKka2MrUZEtdzow.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W_8XJnvUD7dzB2Cx_w4bmkvc5Q9dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/prompt/v12/-W_6XJnvUD7dzB2KZeK4aGMrUZEtdzow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W_8XJnvUD7dzB2C4_04bmkvc5Q9dw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,
"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prompt/v12/-W_6XJnvUD7dzB2KZeKcaWMrUZEtdzow.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-prosto-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("790e2a32-d8c7-44fc-84a4-eca8ed724864",1137435120),$APP.$cljs$cst$2675$family$$,"Prosto One",$APP.$cljs$cst$725$name$$,"Prosto One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prostoone/v21/OpNJno4VhNfK-RgpwWWxpipfWhXD00c.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-protest-guerrilla",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cf053a8d-8ecc-4c34-a636-38164f85bb6c",
-979286668),$APP.$cljs$cst$2675$family$$,"Protest Guerrilla",$APP.$cljs$cst$725$name$$,"Protest Guerrilla",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/protestguerrilla/v2/Qw3HZR5PDSL6K3irtrY-VJB2YzARHV0koJ8y_eiS.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-protest-revolution",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("892b7b96-d8d7-4a51-9786-b06d4871bb74",1595647102),$APP.$cljs$cst$2675$family$$,"Protest Revolution",$APP.$cljs$cst$725$name$$,"Protest Revolution",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/protestrevolution/v2/11hcGofZ0kXBbxQXFB7MJsjtqnVw6Z2s8PIzTG1nQw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-protest-riot",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("880b0959-269c-4417-8090-44e881922f8e",695145347),$APP.$cljs$cst$2675$family$$,"Protest Riot",$APP.$cljs$cst$725$name$$,
"Protest Riot",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/protestriot/v2/d6lPkaOxWMKm7TdezXFmpkrM1_JgjmRpOA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-protest-strike",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("706e8a79-eddb-4db1-b592-b6d00ff3ed2a",1145763002),$APP.$cljs$cst$2675$family$$,"Protest Strike",$APP.$cljs$cst$725$name$$,"Protest Strike",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/proteststrike/v2/0QI5MXdf4Y67Rn6vBog67ZjFlpzW0gZOs7BX.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-proza-libre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6f02430a-05f1-4c73-8449-89f5214b0d9f",-115496641),$APP.$cljs$cst$2675$family$$,"Proza Libre",$APP.$cljs$cst$725$name$$,"Proza Libre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prozalibre/v9/LYjGdGHgj0k1DIQRyUEyyHovftvXWYyz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prozalibre/v9/LYjEdGHgj0k1DIQRyUEyyEotdN_1XJyz7zc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prozalibre/v9/LYjbdGHgj0k1DIQRyUEyyELbV__fcpC69i6N.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prozalibre/v9/LYjZdGHgj0k1DIQRyUEyyEotTCvceJSY8z6Np1k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prozalibre/v9/LYjbdGHgj0k1DIQRyUEyyEL3UP_fcpC69i6N.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prozalibre/v9/LYjZdGHgj0k1DIQRyUEyyEotTAfbeJSY8z6Np1k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prozalibre/v9/LYjbdGHgj0k1DIQRyUEyyEKTUf_fcpC69i6N.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prozalibre/v9/LYjZdGHgj0k1DIQRyUEyyEotTGPaeJSY8z6Np1k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prozalibre/v9/LYjbdGHgj0k1DIQRyUEyyEKPUv_fcpC69i6N.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/prozalibre/v9/LYjZdGHgj0k1DIQRyUEyyEotTH_ZeJSY8z6Np1k.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-public-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4a8c4efb-26ed-4743-a395-0574029882cc",863740640),$APP.$cljs$cst$2675$family$$,"Public Sans",$APP.$cljs$cst$725$name$$,"Public Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwGs572Xtc6ZYQws9YVwllKVG8qX1oyOymuFpi5ww0pX189fg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwGs572Xtc6ZYQws9YVwllKVG8qX1oyOymulpm5ww0pX189fg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwGs572Xtc6ZYQws9YVwllKVG8qX1oyOymuSJm5ww0pX189fg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwGs572Xtc6ZYQws9YVwllKVG8qX1oyOymuFpm5ww0pX189fg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwGs572Xtc6ZYQws9YVwllKVG8qX1oyOymuJJm5ww0pX189fg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwGs572Xtc6ZYQws9YVwllKVG8qX1oyOymuyJ65ww0pX189fg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwGs572Xtc6ZYQws9YVwllKVG8qX1oyOymu8Z65ww0pX189fg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwGs572Xtc6ZYQws9YVwllKVG8qX1oyOymulp65ww0pX189fg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwGs572Xtc6ZYQws9YVwllKVG8qX1oyOymuv565ww0pX189fg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwAs572Xtc6ZYQws9YVwnNDZpDyNjGolS673tpRgQctfVotfj7j.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwAs572Xtc6ZYQws9YVwnNDZpDyNjGolS673trRgActfVotfj7j.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/publicsans/v21/ijwAs572Xtc6ZYQws9YVwnNDZpDyNjGolS673toPgActfVotfj7j.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwAs572Xtc6ZYQws9YVwnNDZpDyNjGolS673tpRgActfVotfj7j.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwAs572Xtc6ZYQws9YVwnNDZpDyNjGolS673tpjgActfVotfj7j.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwAs572Xtc6ZYQws9YVwnNDZpDyNjGolS673tqPhwctfVotfj7j.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwAs572Xtc6ZYQws9YVwnNDZpDyNjGolS673tq2hwctfVotfj7j.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwAs572Xtc6ZYQws9YVwnNDZpDyNjGolS673trRhwctfVotfj7j.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/publicsans/v21/ijwAs572Xtc6ZYQws9YVwnNDZpDyNjGolS673tr4hwctfVotfj7j.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-puppies-play",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bd4ce318-e9ae-4cc7-8b4f-794f5ed853a4",-2136891472),$APP.$cljs$cst$2675$family$$,"Puppies Play",$APP.$cljs$cst$725$name$$,"Puppies Play",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/puppiesplay/v11/wlp2gwHZEV99rG6M3NR9uB9vaAJSA_JN3Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-puritan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("02ecc248-cdf3-46ba-b148-5d1ba878d9b6",1185315252),$APP.$cljs$cst$2675$family$$,"Puritan",$APP.$cljs$cst$725$name$$,"Puritan",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/puritan/v25/845YNMgkAJ2VTtIo9JrwRdaI50M.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/puritan/v25/845aNMgkAJ2VTtIoxJj6QfSN90PfXA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/puritan/v25/845dNMgkAJ2VTtIozCbfYd6j-0rGRes.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,
"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/puritan/v25/845fNMgkAJ2VTtIoxJjC_dup_2jDVevnLQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-purple-purse",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8733da54-0187-4c43-95f7-5e7cd8a71721",1226194458),$APP.$cljs$cst$2675$family$$,"Purple Purse",$APP.$cljs$cst$725$name$$,"Purple Purse",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/purplepurse/v25/qWctB66gv53iAp-Vfs4My6qyeBb_ujA4ug.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-qahiri",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b9acbde0-dfd6-4ee2-8128-4178f0631aad",1788501286),$APP.$cljs$cst$2675$family$$,"Qahiri",$APP.$cljs$cst$725$name$$,"Qahiri",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/qahiri/v11/tsssAp1RZy0C_hGuU3Chrnmupw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-quando",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("58107ac2-ebfb-4d17-9733-ef8084bbf39c",1373380205),$APP.$cljs$cst$2675$family$$,"Quando",$APP.$cljs$cst$725$name$$,"Quando",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quando/v18/xMQVuFNaVa6YuW0pC6WzKX_QmA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-quantico",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8b102f03-cc12-43c7-b63e-b77d82bd5d8e",1127258509),$APP.$cljs$cst$2675$family$$,"Quantico",$APP.$cljs$cst$725$name$$,
"Quantico",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quantico/v19/rax-HiSdp9cPL3KIF4xsLjxSmlLZ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quantico/v19/rax4HiSdp9cPL3KIF7xuJDhwn0LZ6T8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quantico/v19/rax5HiSdp9cPL3KIF7TQARhasU7Q8Cad.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quantico/v19/rax7HiSdp9cPL3KIF7xuHIRfu0ry9TadML4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-quattrocento",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b8b3e8a1-cc20-4627-9db9-000c66215f80",
-1714408050),$APP.$cljs$cst$2675$family$$,"Quattrocento",$APP.$cljs$cst$725$name$$,"Quattrocento",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quattrocento/v24/OZpEg_xvsDZQL_LKIF7q4jPHxGL7f4jFuA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quattrocento/v24/OZpbg_xvsDZQL_LKIF7q4jP_eE3fd6PZsXcM9w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-quattrocento-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5e450b64-897b-424a-a89d-924863bb7a22",
-553843694),$APP.$cljs$cst$2675$family$$,"Quattrocento Sans",$APP.$cljs$cst$725$name$$,"Quattrocento Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quattrocentosans/v22/va9c4lja2NVIDdIAAoMR5MfuElaRB3zOvU7eHGHJ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quattrocentosans/v22/va9a4lja2NVIDdIAAoMR5MfuElaRB0zMt0r8GXHJkLI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quattrocentosans/v22/va9Z4lja2NVIDdIAAoMR5MfuElaRB0RykmrWN33AiasJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quattrocentosans/v22/va9X4lja2NVIDdIAAoMR5MfuElaRB0zMj_bTPXnijLsJV7E.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-questrial",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6fefb974-f3d2-4fe7-9887-7ad58e6aabfc",-1455492397),$APP.$cljs$cst$2675$family$$,"Questrial",$APP.$cljs$cst$725$name$$,"Questrial",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/questrial/v19/QdVUSTchPBm7nuUeVf7EuStkm20oJA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-quicksand",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("33e4a8ae-5186-4019-8e53-3693257c1067",1752450230),$APP.$cljs$cst$2675$family$$,"Quicksand",$APP.$cljs$cst$725$name$$,"Quicksand",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quicksand/v37/6xK-dSZaM9iE8KbpRA_LJ3z8mH9BOJvgkKEo18G0wx40QDw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/quicksand/v37/6xK-dSZaM9iE8KbpRA_LJ3z8mH9BOJvgkP8o18G0wx40QDw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quicksand/v37/6xK-dSZaM9iE8KbpRA_LJ3z8mH9BOJvgkM0o18G0wx40QDw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quicksand/v37/6xK-dSZaM9iE8KbpRA_LJ3z8mH9BOJvgkCEv18G0wx40QDw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quicksand/v37/6xK-dSZaM9iE8KbpRA_LJ3z8mH9BOJvgkBgv18G0wx40QDw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-quintessential",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("830bf16c-9d20-40a4-a347-0a744b8a2724",-537662855),$APP.$cljs$cst$2675$family$$,"Quintessential",$APP.$cljs$cst$725$name$$,"Quintessential",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/quintessential/v24/fdNn9sOGq31Yjnh3qWU14DdtjY5wS7kmAyxM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-qwigley",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("11ef39cc-bd26-47ff-8a07-fa2546aa118c",628241780),$APP.$cljs$cst$2675$family$$,"Qwigley",$APP.$cljs$cst$725$name$$,"Qwigley",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/qwigley/v20/1cXzaU3UGJb5tGoCuVxsi1mBmcE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-qwitcher-grypen",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("b298e1b0-74f0-4295-9c41-3024c6831eb1",1494076200),$APP.$cljs$cst$2675$family$$,"Qwitcher Grypen",$APP.$cljs$cst$725$name$$,"Qwitcher Grypen",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/qwitchergrypen/v8/pxicypclp9tDilN9RrC5BSI1dZmrSGNAom-wpw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/qwitchergrypen/v8/pxiZypclp9tDilN9RrC5BSI1dZmT9ExkqkSsrvNXiA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rem",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f2fc520b-348a-4dbd-8531-e3f60e4ebfb0",72561938),$APP.$cljs$cst$2675$family$$,"REM",$APP.$cljs$cst$725$name$$,"REM",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzgHAIoSDyHbRjfsYumpRvUPMLrrToUbIqIfBU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzgHAIoSDyHbRjfsYumpRvUPELqrToUbIqIfBU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/rem/v4/WnzgHAIoSDyHbRjfsYumpRvUPJzqrToUbIqIfBU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzgHAIoSDyHbRjfsYumpRvUPMLqrToUbIqIfBU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzgHAIoSDyHbRjfsYumpRvUPPDqrToUbIqIfBU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzgHAIoSDyHbRjfsYumpRvUPBztrToUbIqIfBU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzgHAIoSDyHbRjfsYumpRvUPCXtrToUbIqIfBU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzgHAIoSDyHbRjfsYumpRvUPELtrToUbIqIfBU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzgHAIoSDyHbRjfsYumpRvUPGvtrToUbIqIfBU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/rem/v4/WnzmHAIoSDytZCogaeLNP7XTKQqpRXgeaKiNbBVWkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzmHAIoSDytZCogaeLNP7XTKQqpxXkeaKiNbBVWkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,
"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzmHAIoSDytZCogaeLNP7XTKQqpG3keaKiNbBVWkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzmHAIoSDytZCogaeLNP7XTKQqpRXkeaKiNbBVWkw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzmHAIoSDytZCogaeLNP7XTKQqpd3keaKiNbBVWkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzmHAIoSDytZCogaeLNP7XTKQqpm34eaKiNbBVWkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzmHAIoSDytZCogaeLNP7XTKQqpon4eaKiNbBVWkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzmHAIoSDytZCogaeLNP7XTKQqpxX4eaKiNbBVWkw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rem/v4/WnzmHAIoSDytZCogaeLNP7XTKQqp7H4eaKiNbBVWkw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-racing-sans-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("54481f1d-e88e-448d-85fd-81c9cc076544",-989551489),$APP.$cljs$cst$2675$family$$,"Racing Sans One",$APP.$cljs$cst$725$name$$,"Racing Sans One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/racingsansone/v17/sykr-yRtm7EvTrXNxkv5jfKKyDCwL3rmWpIBtA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-radio-canada",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ba6cde6f-515e-430d-bf79-bb86cfd5a329",-653181635),$APP.$cljs$cst$2675$family$$,"Radio Canada",$APP.$cljs$cst$725$name$$,
"Radio Canada",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanada/v26/XRX13ISXn0dBMcibU6jlAqr3ejLv5OLZYiYXik6db2P4jxxlsls-0nESkQPIJOdSSfOT.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanada/v26/XRX13ISXn0dBMcibU6jlAqr3ejLv5OLZYiYXik6db2P4jxxlsls-0nFMkQPIJOdSSfOT.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanada/v26/XRX13ISXn0dBMcibU6jlAqr3ejLv5OLZYiYXik6db2P4jxxlsls-0nF-kQPIJOdSSfOT.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanada/v26/XRX13ISXn0dBMcibU6jlAqr3ejLv5OLZYiYXik6db2P4jxxlsls-0nGSlgPIJOdSSfOT.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanada/v26/XRX13ISXn0dBMcibU6jlAqr3ejLv5OLZYiYXik6db2P4jxxlsls-0nGrlgPIJOdSSfOT.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanada/v26/XRX33ISXn0dBMcibU6jlAqrdcwAMBJuK9IgQn4bfnSrKcMQM2cGQ1WSE0rWLLuNwTOOTa9k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanada/v26/XRX33ISXn0dBMcibU6jlAqrdcwAMBJuK9IgQn4bfnSrKcMQM2cGQ1WSE0uuLLuNwTOOTa9k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanada/v26/XRX33ISXn0dBMcibU6jlAqrdcwAMBJuK9IgQn4bfnSrKcMQM2cGQ1WSE0tmLLuNwTOOTa9k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanada/v26/XRX33ISXn0dBMcibU6jlAqrdcwAMBJuK9IgQn4bfnSrKcMQM2cGQ1WSE0jWMLuNwTOOTa9k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanada/v26/XRX33ISXn0dBMcibU6jlAqrdcwAMBJuK9IgQn4bfnSrKcMQM2cGQ1WSE0gyMLuNwTOOTa9k.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-radio-canada-big",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0ba59575-c5fc-405f-b749-08575ae2b6eb",
-851221765),$APP.$cljs$cst$2675$family$$,"Radio Canada Big",$APP.$cljs$cst$725$name$$,"Radio Canada Big",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanadabig/v3/LYjUdHrinEImAoQewU0hyTsPFra4Yp-6A-YRBF-RX6nNRY3p2pcheCsG.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanadabig/v3/LYjUdHrinEImAoQewU0hyTsPFra4Yp-6A-YRBF-RX6n_RY3p2pcheCsG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanadabig/v3/LYjUdHrinEImAoQewU0hyTsPFra4Yp-6A-YRBF-RX6kTQo3p2pcheCsG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanadabig/v3/LYjUdHrinEImAoQewU0hyTsPFra4Yp-6A-YRBF-RX6kqQo3p2pcheCsG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanadabig/v3/LYjqdHrinEImAoQewU0hyTsPFra4SJaI_D54b8U_WLwFBmWq0JMDfTsGdMc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/radiocanadabig/v3/LYjqdHrinEImAoQewU0hyTsPFra4SJaI_D54b8U_WLwFBleq0JMDfTsGdMc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanadabig/v3/LYjqdHrinEImAoQewU0hyTsPFra4SJaI_D54b8U_WLwFBrut0JMDfTsGdMc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radiocanadabig/v3/LYjqdHrinEImAoQewU0hyTsPFra4SJaI_D54b8U_WLwFBoKt0JMDfTsGdMc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-radley",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e205152e-2c63-4f13-94e6-8b3402fa56b0",2104879725),$APP.$cljs$cst$2675$family$$,
"Radley",$APP.$cljs$cst$725$name$$,"Radley",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radley/v24/LYjDdGzinEIjCN19oAlEpVs3VQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/radley/v24/LYjBdGzinEIjCN1NogNAh14nVcfe.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rajdhani",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8d9d5bf7-b9f5-439b-abd7-0b6cbde4b042",-1798823458),$APP.$cljs$cst$2675$family$$,"Rajdhani",$APP.$cljs$cst$725$name$$,
"Rajdhani",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rajdhani/v17/LDI2apCSOBg7S-QT7pasEcOsc-bGkqIw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rajdhani/v17/LDIxapCSOBg7S-QT7q4AOeekWPrP.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rajdhani/v17/LDI2apCSOBg7S-QT7pb0EMOsc-bGkqIw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rajdhani/v17/LDI2apCSOBg7S-QT7pbYF8Osc-bGkqIw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/rajdhani/v17/LDI2apCSOBg7S-QT7pa8FsOsc-bGkqIw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rakkas",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d94576fb-8940-495f-8b62-78b08bd36523",1714125315),$APP.$cljs$cst$2675$family$$,"Rakkas",$APP.$cljs$cst$725$name$$,"Rakkas",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rakkas/v22/Qw3cZQlNHiblL3j_lttPOeMcCw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-raleway",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dc910e43-74a0-4c91-ac7d-1bd3d79d9b53",-48469841),$APP.$cljs$cst$2675$family$$,"Raleway",$APP.$cljs$cst$725$name$$,
"Raleway",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Ptxg8zYS_SKggPN4iEgvnHyvveLxVvao4CPNLA3JC9c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Ptxg8zYS_SKggPN4iEgvnHyvveLxVtaooCPNLA3JC9c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Ptxg8zYS_SKggPN4iEgvnHyvveLxVuEooCPNLA3JC9c.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Ptxg8zYS_SKggPN4iEgvnHyvveLxVvaooCPNLA3JC9c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/raleway/v37/1Ptxg8zYS_SKggPN4iEgvnHyvveLxVvoooCPNLA3JC9c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Ptxg8zYS_SKggPN4iEgvnHyvveLxVsEpYCPNLA3JC9c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Ptxg8zYS_SKggPN4iEgvnHyvveLxVs9pYCPNLA3JC9c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Ptxg8zYS_SKggPN4iEgvnHyvveLxVtapYCPNLA3JC9c.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Ptxg8zYS_SKggPN4iEgvnHyvveLxVtzpYCPNLA3JC9c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Pt_g8zYS_SKggPNyCgSQamb1W0lwk4S4WjNPrQVIT9c2c8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Pt_g8zYS_SKggPNyCgSQamb1W0lwk4S4ejMPrQVIT9c2c8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Pt_g8zYS_SKggPNyCgSQamb1W0lwk4S4TbMPrQVIT9c2c8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Pt_g8zYS_SKggPNyCgSQamb1W0lwk4S4WjMPrQVIT9c2c8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Pt_g8zYS_SKggPNyCgSQamb1W0lwk4S4VrMPrQVIT9c2c8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Pt_g8zYS_SKggPNyCgSQamb1W0lwk4S4bbLPrQVIT9c2c8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Pt_g8zYS_SKggPNyCgSQamb1W0lwk4S4Y_LPrQVIT9c2c8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Pt_g8zYS_SKggPNyCgSQamb1W0lwk4S4ejLPrQVIT9c2c8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raleway/v37/1Pt_g8zYS_SKggPNyCgSQamb1W0lwk4S4cHLPrQVIT9c2c8.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-raleway-dots",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f8ae2358-be8e-45a7-8d00-e32632336d80",-617613392),$APP.$cljs$cst$2675$family$$,"Raleway Dots",$APP.$cljs$cst$725$name$$,"Raleway Dots",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ralewaydots/v19/6NUR8FifJg6AfQvzpshgwJ8kyf9Fdty2ew.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ramabhadra",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("77f320d7-072e-473b-be35-ea8874f25967",-1240321284),$APP.$cljs$cst$2675$family$$,"Ramabhadra",$APP.$cljs$cst$725$name$$,"Ramabhadra",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ramabhadra/v17/EYq2maBOwqRW9P1SQ83LehNGX5uWw3o.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-ramaraja",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1d57367f-94ca-4f30-ad86-8a4b0be5d018",288482730),$APP.$cljs$cst$2675$family$$,"Ramaraja",$APP.$cljs$cst$725$name$$,"Ramaraja",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ramaraja/v17/SlGTmQearpYAYG1CABIkqnB6aSQU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rambla",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b28ef4ea-e98a-4eab-8688-2a3577c5e51e",849688074),$APP.$cljs$cst$2675$family$$,"Rambla",$APP.$cljs$cst$725$name$$,"Rambla",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rambla/v14/snfrs0ip98hx6mr0I7IONthkwQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rambla/v14/snfps0ip98hx6mrEIbgKFN10wYKa.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rambla/v14/snfos0ip98hx6mrMn50qPvN4yJuDYQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/rambla/v14/snfus0ip98hx6mrEIYC2O_l86p6TYS-Y.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rammetto-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4493dc3b-c0d9-4df8-a392-bf0932ec69c3",1491165633),$APP.$cljs$cst$2675$family$$,"Rammetto One",$APP.$cljs$cst$725$name$$,"Rammetto One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rammettoone/v21/LhWiMV3HOfMbMetJG3lQDpp9Mvuciu-_SQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rampart-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4445320f-51a3-4051-b8a5-7aee1f30c091",-893897546),$APP.$cljs$cst$2675$family$$,"Rampart One",
$APP.$cljs$cst$725$name$$,"Rampart One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rampartone/v13/K2F1fZFGl_JSR1tAWNG9R6qgLS76ZHOM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-ranchers",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("723d3a66-0311-434d-ac08-6cb0a9bac07c",-1712059687),$APP.$cljs$cst$2675$family$$,"Ranchers",$APP.$cljs$cst$725$name$$,"Ranchers",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ranchers/v19/zrfm0H3Lx-P2Xvs2AoDYDC79XTHv.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rancho",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f142709c-b322-4d41-b61c-2d2921f82721",1645645648),$APP.$cljs$cst$2675$family$$,"Rancho",$APP.$cljs$cst$725$name$$,"Rancho",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rancho/v22/46kulbzmXjLaqZRlbWXgd0RY1g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ranga",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7bff0257-8601-48aa-b06e-82195b8462b1",-1509623093),$APP.$cljs$cst$2675$family$$,
"Ranga",$APP.$cljs$cst$725$name$$,"Ranga",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ranga/v22/C8ct4cYisGb28p6CLDwZwmGE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ranga/v22/C8cg4cYisGb28qY-AxgR6X2NZAn2.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rasa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e68aa305-b368-4459-a436-b913382ceaa8",1980937124),$APP.$cljs$cst$2675$family$$,"Rasa",$APP.$cljs$cst$725$name$$,"Rasa",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rasa/v27/xn76YHIn1mWmVKl8ZtAM9NrJfN4YJW41fcvN2KT4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rasa/v27/xn76YHIn1mWmVKl8ZtAM9NrJfN5GJW41fcvN2KT4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rasa/v27/xn76YHIn1mWmVKl8ZtAM9NrJfN50JW41fcvN2KT4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rasa/v27/xn76YHIn1mWmVKl8ZtAM9NrJfN6YIm41fcvN2KT4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/rasa/v27/xn76YHIn1mWmVKl8ZtAM9NrJfN6hIm41fcvN2KT4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rasa/v27/xn78YHIn1mWmfqBOmQhln0Bne8uOZth2d8_v3bT4Ycc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,
"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rasa/v27/xn78YHIn1mWmfqBOmQhln0Bne8uOZoZ2d8_v3bT4Ycc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rasa/v27/xn78YHIn1mWmfqBOmQhln0Bne8uOZrR2d8_v3bT4Ycc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rasa/v27/xn78YHIn1mWmfqBOmQhln0Bne8uOZlhxd8_v3bT4Ycc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rasa/v27/xn78YHIn1mWmfqBOmQhln0Bne8uOZmFxd8_v3bT4Ycc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rationale",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9c32d357-c0a7-47ce-9e23-33325f70d469",1608934292),$APP.$cljs$cst$2675$family$$,"Rationale",$APP.$cljs$cst$725$name$$,"Rationale",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rationale/v30/9XUnlJ92n0_JFxHIfHcsdlFMzLC2Zw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ravi-prakash",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5ee3a236-de15-4cdb-a36c-f0811f457c38",-665623849),
$APP.$cljs$cst$2675$family$$,"Ravi Prakash",$APP.$cljs$cst$725$name$$,"Ravi Prakash",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/raviprakash/v21/gokpH6fsDkVrF9Bv9X8SOAKHmNZEq6TTFw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-readex-pro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5dd5df05-e242-428f-946a-5a485d59e4c4",1172187820),$APP.$cljs$cst$2675$family$$,"Readex Pro",$APP.$cljs$cst$725$name$$,"Readex Pro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/readexpro/v27/SLXnc1bJ7HE5YDoGPuzj_dh8uc7wUy8ZQQyX2KY8TL0kGZN6blTCYUSmgmsglvjkag.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/readexpro/v27/SLXnc1bJ7HE5YDoGPuzj_dh8uc7wUy8ZQQyX2KY8TL0kGZN6blTCv0Smgmsglvjkag.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/readexpro/v27/SLXnc1bJ7HE5YDoGPuzj_dh8uc7wUy8ZQQyX2KY8TL0kGZN6blTC4USmgmsglvjkag.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/readexpro/v27/SLXnc1bJ7HE5YDoGPuzj_dh8uc7wUy8ZQQyX2KY8TL0kGZN6blTC00Smgmsglvjkag.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/readexpro/v27/SLXnc1bJ7HE5YDoGPuzj_dh8uc7wUy8ZQQyX2KY8TL0kGZN6blTCP0Omgmsglvjkag.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/readexpro/v27/SLXnc1bJ7HE5YDoGPuzj_dh8uc7wUy8ZQQyX2KY8TL0kGZN6blTCBkOmgmsglvjkag.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-recursive",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b3a5a67f-5f58-47df-b26b-395c5ea731b4",1158851977),$APP.$cljs$cst$2675$family$$,
"Recursive",$APP.$cljs$cst$725$name$$,"Recursive",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/recursive/v44/8vJN7wMr0mhh-RQChyHEH06TlXhq_gukbYrFMk1QuAIcyEwG_X-dpEfaE5YaERmK-CImKsvxvU-MXGX2fSqasNfUvz2xbXfn1uEQadDck018vwxjDJCL.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/recursive/v44/8vJN7wMr0mhh-RQChyHEH06TlXhq_gukbYrFMk1QuAIcyEwG_X-dpEfaE5YaERmK-CImKsvxvU-MXGX2fSqasNfUvz2xbXfn1uEQadCCk018vwxjDJCL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",
$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/recursive/v44/8vJN7wMr0mhh-RQChyHEH06TlXhq_gukbYrFMk1QuAIcyEwG_X-dpEfaE5YaERmK-CImKsvxvU-MXGX2fSqasNfUvz2xbXfn1uEQadCwk018vwxjDJCL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/recursive/v44/8vJN7wMr0mhh-RQChyHEH06TlXhq_gukbYrFMk1QuAIcyEwG_X-dpEfaE5YaERmK-CImKsvxvU-MXGX2fSqasNfUvz2xbXfn1uEQadBclE18vwxjDJCL.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/recursive/v44/8vJN7wMr0mhh-RQChyHEH06TlXhq_gukbYrFMk1QuAIcyEwG_X-dpEfaE5YaERmK-CImKsvxvU-MXGX2fSqasNfUvz2xbXfn1uEQadBllE18vwxjDJCL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,
"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/recursive/v44/8vJN7wMr0mhh-RQChyHEH06TlXhq_gukbYrFMk1QuAIcyEwG_X-dpEfaE5YaERmK-CImKsvxvU-MXGX2fSqasNfUvz2xbXfn1uEQadAClE18vwxjDJCL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/recursive/v44/8vJN7wMr0mhh-RQChyHEH06TlXhq_gukbYrFMk1QuAIcyEwG_X-dpEfaE5YaERmK-CImKsvxvU-MXGX2fSqasNfUvz2xbXfn1uEQadArlE18vwxjDJCL.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-red-hat-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d2913651-db1b-4571-9b98-7b3aa1ded07d",-1290681264),$APP.$cljs$cst$2675$family$$,"Red Hat Display",$APP.$cljs$cst$725$name$$,"Red Hat Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatdisplay/v21/8vIf7wUr0m80wwYf0QCXZzYzUoTK8RZQvRd-D1NYbjKWckg5-Xecg3w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatdisplay/v21/8vIf7wUr0m80wwYf0QCXZzYzUoTK8RZQvRd-D1NYbmyWckg5-Xecg3w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatdisplay/v21/8vIf7wUr0m80wwYf0QCXZzYzUoTK8RZQvRd-D1NYbl6Wckg5-Xecg3w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatdisplay/v21/8vIf7wUr0m80wwYf0QCXZzYzUoTK8RZQvRd-D1NYbrKRckg5-Xecg3w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatdisplay/v21/8vIf7wUr0m80wwYf0QCXZzYzUoTK8RZQvRd-D1NYbouRckg5-Xecg3w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatdisplay/v21/8vIf7wUr0m80wwYf0QCXZzYzUoTK8RZQvRd-D1NYbuyRckg5-Xecg3w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatdisplay/v21/8vIf7wUr0m80wwYf0QCXZzYzUoTK8RZQvRd-D1NYbsWRckg5-Xecg3w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatdisplay/v21/8vIh7wUr0m80wwYf0QCXZzYzUoTg-CSvZX4Vlf1fe6TVxAsz_VWZk3zJGg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatdisplay/v21/8vIh7wUr0m80wwYf0QCXZzYzUoTg-CSvZX4Vlf1fe6TVmgsz_VWZk3zJGg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatdisplay/v21/8vIh7wUr0m80wwYf0QCXZzYzUoTg-CSvZX4Vlf1fe6TVqAsz_VWZk3zJGg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatdisplay/v21/8vIh7wUr0m80wwYf0QCXZzYzUoTg-CSvZX4Vlf1fe6TVRAwz_VWZk3zJGg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",
$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatdisplay/v21/8vIh7wUr0m80wwYf0QCXZzYzUoTg-CSvZX4Vlf1fe6TVfQwz_VWZk3zJGg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatdisplay/v21/8vIh7wUr0m80wwYf0QCXZzYzUoTg-CSvZX4Vlf1fe6TVGgwz_VWZk3zJGg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatdisplay/v21/8vIh7wUr0m80wwYf0QCXZzYzUoTg-CSvZX4Vlf1fe6TVMwwz_VWZk3zJGg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-red-hat-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9b749b80-f72e-4338-8969-5d65f56adf85",
587996448),$APP.$cljs$cst$2675$family$$,"Red Hat Mono",$APP.$cljs$cst$725$name$$,"Red Hat Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatmono/v16/jVyY7nDnA2uf2zVvFAhhzEs-VMSjJpBTfgjwQQPI-7HNuW4QuKI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatmono/v16/jVyY7nDnA2uf2zVvFAhhzEs-VMSjJpBTfgjwQV3I-7HNuW4QuKI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatmono/v16/jVyY7nDnA2uf2zVvFAhhzEs-VMSjJpBTfgjwQW_I-7HNuW4QuKI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatmono/v16/jVyY7nDnA2uf2zVvFAhhzEs-VMSjJpBTfgjwQYPP-7HNuW4QuKI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatmono/v16/jVyY7nDnA2uf2zVvFAhhzEs-VMSjJpBTfgjwQbrP-7HNuW4QuKI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatmono/v16/jVye7nDnA2uf2zVvFAhhzEsUXfZc_vk45Kb3VJWLTfLHvUwVqKIJuw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatmono/v16/jVye7nDnA2uf2zVvFAhhzEsUXfZc_vk45Kb3VJWLE_LHvUwVqKIJuw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatmono/v16/jVye7nDnA2uf2zVvFAhhzEsUXfZc_vk45Kb3VJWLIfLHvUwVqKIJuw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatmono/v16/jVye7nDnA2uf2zVvFAhhzEsUXfZc_vk45Kb3VJWLzfXHvUwVqKIJuw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhatmono/v16/jVye7nDnA2uf2zVvFAhhzEsUXfZc_vk45Kb3VJWL9PXHvUwVqKIJuw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-red-hat-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b3125d00-4d10-425d-8fac-2add7e8444c5",-668940879),$APP.$cljs$cst$2675$family$$,
"Red Hat Text",$APP.$cljs$cst$725$name$$,"Red Hat Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhattext/v19/RrQCbohi_ic6B3yVSzGBrMx6ZI_cy1A6Ok2ML-ZwVrbacYVFtIY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhattext/v19/RrQCbohi_ic6B3yVSzGBrMx6ZI_cy1A6Ok2ML7hwVrbacYVFtIY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhattext/v19/RrQCbohi_ic6B3yVSzGBrMx6ZI_cy1A6Ok2ML4pwVrbacYVFtIY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhattext/v19/RrQCbohi_ic6B3yVSzGBrMx6ZI_cy1A6Ok2ML2Z3VrbacYVFtIY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhattext/v19/RrQCbohi_ic6B3yVSzGBrMx6ZI_cy1A6Ok2ML193VrbacYVFtIY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhattext/v19/RrQEbohi_ic6B3yVSzGBrMxQbb0jEzlRoOOLOnAz4PXQdadApIYv_g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhattext/v19/RrQEbohi_ic6B3yVSzGBrMxQbb0jEzlRoOOLOnAzvvXQdadApIYv_g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/redhattext/v19/RrQEbohi_ic6B3yVSzGBrMxQbb0jEzlRoOOLOnAzjPXQdadApIYv_g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhattext/v19/RrQEbohi_ic6B3yVSzGBrMxQbb0jEzlRoOOLOnAzYPLQdadApIYv_g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redhattext/v19/RrQEbohi_ic6B3yVSzGBrMxQbb0jEzlRoOOLOnAzWfLQdadApIYv_g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-red-rose",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("04ffa525-29c4-47ab-b865-116afb789ffc",2027497993),$APP.$cljs$cst$2675$family$$,"Red Rose",$APP.$cljs$cst$725$name$$,
"Red Rose",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redrose/v25/QdVISTYiLBjouPgEUajvsfWwDtc3MH8y8_sDcjSsYUVUjg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redrose/v25/QdVISTYiLBjouPgEUajvsfWwDtc3MH8yrfsDcjSsYUVUjg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redrose/v25/QdVISTYiLBjouPgEUajvsfWwDtc3MH8yn_sDcjSsYUVUjg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redrose/v25/QdVISTYiLBjouPgEUajvsfWwDtc3MH8yc_wDcjSsYUVUjg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/redrose/v25/QdVISTYiLBjouPgEUajvsfWwDtc3MH8ySvwDcjSsYUVUjg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-redacted",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("932059d9-4023-4e9f-817e-966e1ac621c7",1814407716),$APP.$cljs$cst$2675$family$$,"Redacted",$APP.$cljs$cst$725$name$$,"Redacted",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redacted/v11/Z9XVDmdRShme2O_7aITe4u2El6GC.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-redacted-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ac3b4d03-3a52-47cb-930e-081bba79fd2c",-963910168),$APP.$cljs$cst$2675$family$$,"Redacted Script",
$APP.$cljs$cst$725$name$$,"Redacted Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redactedscript/v12/ypvEbXGRglhokR7dcC3d1-R6zmxqHUzVmbI397ldkg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redactedscript/v12/ypvBbXGRglhokR7dcC3d1-R6zmxSsWTxkZkr_g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redactedscript/v12/ypvEbXGRglhokR7dcC3d1-R6zmxqDUvVmbI397ldkg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-reddit-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8d949978-ccee-4230-a8b7-54d492b9f22b",-685066806),$APP.$cljs$cst$2675$family$$,"Reddit Mono",$APP.$cljs$cst$725$name$$,"Reddit Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditmono/v5/oPWc_kRmmu4oQ88oo13o48DHbsqn28eR20vUQCYacnnYz7yQYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditmono/v5/oPWc_kRmmu4oQ88oo13o48DHbsqn28eR20vUniYacnnYz7yQYA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditmono/v5/oPWc_kRmmu4oQ88oo13o48DHbsqn28eR20vUwCYacnnYz7yQYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditmono/v5/oPWc_kRmmu4oQ88oo13o48DHbsqn28eR20vU8iYacnnYz7yQYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditmono/v5/oPWc_kRmmu4oQ88oo13o48DHbsqn28eR20vUHiEacnnYz7yQYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditmono/v5/oPWc_kRmmu4oQ88oo13o48DHbsqn28eR20vUJyEacnnYz7yQYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditmono/v5/oPWc_kRmmu4oQ88oo13o48DHbsqn28eR20vUQCEacnnYz7yQYA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditmono/v5/oPWc_kRmmu4oQ88oo13o48DHbsqn28eR20vUaSEacnnYz7yQYA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-reddit-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a3abbb63-a99d-4f17-8cbe-318036d6028d",
-1499111273),$APP.$cljs$cst$2675$family$$,"Reddit Sans",$APP.$cljs$cst$725$name$$,"Reddit Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqgmaFOxq1T_-ETdN7EKSlnU2dHRsBCV5ux7YxmAVfBiVMFlw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqgmaFOxq1T_-ETdN7EKSlnU2dHRsBCV5uxM4xmAVfBiVMFlw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqgmaFOxq1T_-ETdN7EKSlnU2dHRsBCV5uxbYxmAVfBiVMFlw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqgmaFOxq1T_-ETdN7EKSlnU2dHRsBCV5uxX4xmAVfBiVMFlw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqgmaFOxq1T_-ETdN7EKSlnU2dHRsBCV5uxs4tmAVfBiVMFlw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqgmaFOxq1T_-ETdN7EKSlnU2dHRsBCV5uxiotmAVfBiVMFlw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqgmaFOxq1T_-ETdN7EKSlnU2dHRsBCV5ux7YtmAVfBiVMFlw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqgmaFOxq1T_-ETdN7EKSlnU2dHRsBCV5uxxItmAVfBiVMFlw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqmmaFOxq1T_-ETdN7EKQNuYZifL6vY-Zykpc8OQl3Fq1YVlz5F.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqmmaFOxq1T_-ETdN7EKQNuYZifL6vY-Zykpc_QQl3Fq1YVlz5F.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/redditsans/v6/EYqmmaFOxq1T_-ETdN7EKQNuYZifL6vY-Zykpc-OQl3Fq1YVlz5F.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqmmaFOxq1T_-ETdN7EKQNuYZifL6vY-Zykpc-8Ql3Fq1YVlz5F.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqmmaFOxq1T_-ETdN7EKQNuYZifL6vY-Zykpc9QRV3Fq1YVlz5F.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqmmaFOxq1T_-ETdN7EKQNuYZifL6vY-Zykpc9pRV3Fq1YVlz5F.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqmmaFOxq1T_-ETdN7EKQNuYZifL6vY-Zykpc8ORV3Fq1YVlz5F.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsans/v6/EYqmmaFOxq1T_-ETdN7EKQNuYZifL6vY-Zykpc8nRV3Fq1YVlz5F.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-reddit-sans-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5bd125a2-02bc-4d90-bd87-289f7543af4a",1795661991),$APP.$cljs$cst$2675$family$$,"Reddit Sans Condensed",$APP.$cljs$cst$725$name$$,"Reddit Sans Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsanscondensed/v5/m8J_jepOc6WYkkm2Dey9A5QGAQXmuL3va5IfZsq2gyKtWVJro9kKUpU4u7XDIuc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsanscondensed/v5/m8J_jepOc6WYkkm2Dey9A5QGAQXmuL3va5IfZsq2gyKtWVJrowcKUpU4u7XDIuc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsanscondensed/v5/m8J_jepOc6WYkkm2Dey9A5QGAQXmuL3va5IfZsq2gyKtWVJro1kKUpU4u7XDIuc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsanscondensed/v5/m8J_jepOc6WYkkm2Dey9A5QGAQXmuL3va5IfZsq2gyKtWVJro2sKUpU4u7XDIuc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsanscondensed/v5/m8J_jepOc6WYkkm2Dey9A5QGAQXmuL3va5IfZsq2gyKtWVJro4cNUpU4u7XDIuc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsanscondensed/v5/m8J_jepOc6WYkkm2Dey9A5QGAQXmuL3va5IfZsq2gyKtWVJro74NUpU4u7XDIuc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsanscondensed/v5/m8J_jepOc6WYkkm2Dey9A5QGAQXmuL3va5IfZsq2gyKtWVJro9kNUpU4u7XDIuc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redditsanscondensed/v5/m8J_jepOc6WYkkm2Dey9A5QGAQXmuL3va5IfZsq2gyKtWVJro_ANUpU4u7XDIuc.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-redressed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d5a787f5-2cfc-472a-b01f-7c3500d7129c",-520290669),$APP.$cljs$cst$2675$family$$,"Redressed",$APP.$cljs$cst$725$name$$,"Redressed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/redressed/v32/x3dickHUbrmJ7wMy9MsBfPACvy_1BA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-reem-kufi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c51cdfb7-130e-4e5d-b6ac-f9053358678b",-688109352),$APP.$cljs$cst$2675$family$$,"Reem Kufi",$APP.$cljs$cst$725$name$$,"Reem Kufi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/reemkufi/v28/2sDPZGJLip7W2J7v7wQZZE1I0yCmYzzQtuZnEGGf3qGuvM4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/reemkufi/v28/2sDPZGJLip7W2J7v7wQZZE1I0yCmYzzQttRnEGGf3qGuvM4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/reemkufi/v28/2sDPZGJLip7W2J7v7wQZZE1I0yCmYzzQtjhgEGGf3qGuvM4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/reemkufi/v28/2sDPZGJLip7W2J7v7wQZZE1I0yCmYzzQtgFgEGGf3qGuvM4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-reem-kufi-fun",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("363c2733-5d31-4a5a-89ee-41a021ca205f",-330424713),$APP.$cljs$cst$2675$family$$,"Reem Kufi Fun",
$APP.$cljs$cst$725$name$$,"Reem Kufi Fun",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/reemkufifun/v13/uK_m4rOFYukkmyUEbF43fIryZEk5qRZ8nrKChoYj3nCgrvqZzZXq.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/reemkufifun/v13/uK_m4rOFYukkmyUEbF43fIryZEk5qRZ8nrKChoYR3nCgrvqZzZXq.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/reemkufifun/v13/uK_m4rOFYukkmyUEbF43fIryZEk5qRZ8nrKChob92XCgrvqZzZXq.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/reemkufifun/v13/uK_m4rOFYukkmyUEbF43fIryZEk5qRZ8nrKChobE2XCgrvqZzZXq.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-reem-kufi-ink",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4235bbff-47e3-455e-b346-46161497d8d0",
632486232),$APP.$cljs$cst$2675$family$$,"Reem Kufi Ink",$APP.$cljs$cst$725$name$$,"Reem Kufi Ink",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/reemkufiink/v11/oPWJ_kJmmu8hCvB9iFumxZSnRj5dQnSX1ko.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-reenie-beanie",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a17f93e1-16d1-4fed-a756-9cdf6eb02204",67923803),$APP.$cljs$cst$2675$family$$,"Reenie Beanie",$APP.$cljs$cst$725$name$$,"Reenie Beanie",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/reeniebeanie/v22/z7NSdR76eDkaJKZJFkkjuvWxbP2_qoOgf_w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-reggae-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0c1b8ab1-8394-466e-baac-6114cae1a6e1",-1317047437),$APP.$cljs$cst$2675$family$$,"Reggae One",$APP.$cljs$cst$725$name$$,"Reggae One",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/reggaeone/v19/7r3DqX5msMIkeuwJwOJt_a5L5uH-mts.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-rethink-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cbe1055b-bffc-40eb-88d4-d573691f2c0f",291740327),$APP.$cljs$cst$2675$family$$,"Rethink Sans",$APP.$cljs$cst$725$name$$,"Rethink Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rethinksans/v7/AMODz4SDuXOMCPfdoglY9JQuWHBGG0X45DmqkmFRCE7mma-aua4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rethinksans/v7/AMODz4SDuXOMCPfdoglY9JQuWHBGG0X45DmqklNRCE7mma-aua4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rethinksans/v7/AMODz4SDuXOMCPfdoglY9JQuWHBGG0X45Dmqkr9WCE7mma-aua4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rethinksans/v7/AMODz4SDuXOMCPfdoglY9JQuWHBGG0X45DmqkoZWCE7mma-aua4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rethinksans/v7/AMODz4SDuXOMCPfdoglY9JQuWHBGG0X45DmqkuFWCE7mma-aua4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rethinksans/v7/AMOFz4SDuXOMCPfdoglY9JQEUUK5wyyTfpeth6kS4A3snY2fqa7iVQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rethinksans/v7/AMOFz4SDuXOMCPfdoglY9JQEUUK5wyyTfpeth6kS0g3snY2fqa7iVQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rethinksans/v7/AMOFz4SDuXOMCPfdoglY9JQEUUK5wyyTfpeth6kSPgrsnY2fqa7iVQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/rethinksans/v7/AMOFz4SDuXOMCPfdoglY9JQEUUK5wyyTfpeth6kSBwrsnY2fqa7iVQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rethinksans/v7/AMOFz4SDuXOMCPfdoglY9JQEUUK5wyyTfpeth6kSYArsnY2fqa7iVQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-revalia",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f969ba3f-a403-419b-8fae-58e65efa3c2e",1717582567),$APP.$cljs$cst$2675$family$$,"Revalia",$APP.$cljs$cst$725$name$$,"Revalia",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/revalia/v24/WwkexPimBE2-4ZPEeVruNIgJSNM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rhodium-libre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6411976a-9c78-4f35-9124-7ec187f3b7a4",86974465),$APP.$cljs$cst$2675$family$$,"Rhodium Libre",$APP.$cljs$cst$725$name$$,"Rhodium Libre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rhodiumlibre/v21/1q2AY5adA0tn_ukeHcQHqpx6pETLeo2gm2U.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ribeye",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2655ea1c-49eb-43bc-b21b-96588fcc29ed",-293539593),
$APP.$cljs$cst$2675$family$$,"Ribeye",$APP.$cljs$cst$725$name$$,"Ribeye",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ribeye/v27/L0x8DFMxk1MP9R3RvPCmRSlUig.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ribeye-marrow",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cce956b7-b6a3-433b-aaf0-7aae4bc2084e",897663507),$APP.$cljs$cst$2675$family$$,"Ribeye Marrow",$APP.$cljs$cst$725$name$$,"Ribeye Marrow",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ribeyemarrow/v26/GFDsWApshnqMRO2JdtRZ2d0vEAwTVWgKdtw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-righteous",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ce2a0464-3626-4a67-b737-1c529e2edb89",909496315),$APP.$cljs$cst$2675$family$$,"Righteous",$APP.$cljs$cst$725$name$$,"Righteous",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/righteous/v18/1cXxaUPXBpj2rGoU7C9mj3uEicG01A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-risque",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("ade645b1-f133-4825-ba10-4e22a379f887",1124205908),$APP.$cljs$cst$2675$family$$,"Risque",$APP.$cljs$cst$725$name$$,"Risque",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/risque/v24/VdGfAZUfHosahXxoCUYVBJ-T5g.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-road-rage",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5775af10-0d52-4567-9dbf-defbfe9e1e43",1213423758),$APP.$cljs$cst$2675$family$$,"Road Rage",$APP.$cljs$cst$725$name$$,"Road Rage",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roadrage/v9/6NUU8F2fKAOBKjjr4ekvtMYAwdRZfw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-roboto",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d88494e7-351f-4330-aa00-b6332d6e2959",1185644978),$APP.$cljs$cst$2675$family$$,"Roboto",$APP.$cljs$cst$725$name$$,"Roboto",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOMCnqEu92Fr1ME7kSn66aGLdTylUAMQXC89YmC2DPNWubEbGmTggvWl0Qn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOMCnqEu92Fr1ME7kSn66aGLdTylUAMQXC89YmC2DPNWuZEbWmTggvWl0Qn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOMCnqEu92Fr1ME7kSn66aGLdTylUAMQXC89YmC2DPNWuaabWmTggvWl0Qn.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOMCnqEu92Fr1ME7kSn66aGLdTylUAMQXC89YmC2DPNWubEbWmTggvWl0Qn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOMCnqEu92Fr1ME7kSn66aGLdTylUAMQXC89YmC2DPNWub2bWmTggvWl0Qn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOMCnqEu92Fr1ME7kSn66aGLdTylUAMQXC89YmC2DPNWuYaammTggvWl0Qn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOMCnqEu92Fr1ME7kSn66aGLdTylUAMQXC89YmC2DPNWuYjammTggvWl0Qn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOMCnqEu92Fr1ME7kSn66aGLdTylUAMQXC89YmC2DPNWuZEammTggvWl0Qn.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOMCnqEu92Fr1ME7kSn66aGLdTylUAMQXC89YmC2DPNWuZtammTggvWl0Qn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOKCnqEu92Fr1Mu53ZEC9_Vu3r1gIhOszmOClHrs6ljXfMMLoHRiA_0klQnx24.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOKCnqEu92Fr1Mu53ZEC9_Vu3r1gIhOszmOClHrs6ljXfMMLgHQiA_0klQnx24.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOKCnqEu92Fr1Mu53ZEC9_Vu3r1gIhOszmOClHrs6ljXfMMLt_QiA_0klQnx24.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/roboto/v50/KFOKCnqEu92Fr1Mu53ZEC9_Vu3r1gIhOszmOClHrs6ljXfMMLoHQiA_0klQnx24.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOKCnqEu92Fr1Mu53ZEC9_Vu3r1gIhOszmOClHrs6ljXfMMLrPQiA_0klQnx24.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOKCnqEu92Fr1Mu53ZEC9_Vu3r1gIhOszmOClHrs6ljXfMMLl_XiA_0klQnx24.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/roboto/v50/KFOKCnqEu92Fr1Mu53ZEC9_Vu3r1gIhOszmOClHrs6ljXfMMLmbXiA_0klQnx24.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOKCnqEu92Fr1Mu53ZEC9_Vu3r1gIhOszmOClHrs6ljXfMMLgHXiA_0klQnx24.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/roboto/v50/KFOKCnqEu92Fr1Mu53ZEC9_Vu3r1gIhOszmOClHrs6ljXfMMLijXiA_0klQnx24.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-roboto-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("481e2621-77f4-451a-ab92-5ca3b6f6f4bd",1576388933),$APP.$cljs$cst$2675$family$$,
"Roboto Condensed",$APP.$cljs$cst$725$name$$,"Roboto Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVo2ZhZI2eCN5jzbjEETS9weq8-_d6T_POl0fRJeyWyo_BJ731BKMSK.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVo2ZhZI2eCN5jzbjEETS9weq8-_d6T_POl0fRJeyUyovBJ731BKMSK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVo2ZhZI2eCN5jzbjEETS9weq8-_d6T_POl0fRJeyXsovBJ731BKMSK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVo2ZhZI2eCN5jzbjEETS9weq8-_d6T_POl0fRJeyWyovBJ731BKMSK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVo2ZhZI2eCN5jzbjEETS9weq8-_d6T_POl0fRJeyWAovBJ731BKMSK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVo2ZhZI2eCN5jzbjEETS9weq8-_d6T_POl0fRJeyVspfBJ731BKMSK.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVo2ZhZI2eCN5jzbjEETS9weq8-_d6T_POl0fRJeyVVpfBJ731BKMSK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVo2ZhZI2eCN5jzbjEETS9weq8-_d6T_POl0fRJeyUypfBJ731BKMSK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVo2ZhZI2eCN5jzbjEETS9weq8-_d6T_POl0fRJeyUbpfBJ731BKMSK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVW2ZhZI2eCN5jzbjEETS9weq8-19ehAyvMum7nfDB64RgL5XljLdSK37o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/robotocondensed/v31/ieVW2ZhZI2eCN5jzbjEETS9weq8-19ehAyvMum7nfDB64ZgK5XljLdSK37o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVW2ZhZI2eCN5jzbjEETS9weq8-19ehAyvMum7nfDB64UYK5XljLdSK37o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVW2ZhZI2eCN5jzbjEETS9weq8-19ehAyvMum7nfDB64RgK5XljLdSK37o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/robotocondensed/v31/ieVW2ZhZI2eCN5jzbjEETS9weq8-19ehAyvMum7nfDB64SoK5XljLdSK37o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVW2ZhZI2eCN5jzbjEETS9weq8-19ehAyvMum7nfDB64cYN5XljLdSK37o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVW2ZhZI2eCN5jzbjEETS9weq8-19ehAyvMum7nfDB64f8N5XljLdSK37o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/robotocondensed/v31/ieVW2ZhZI2eCN5jzbjEETS9weq8-19ehAyvMum7nfDB64ZgN5XljLdSK37o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotocondensed/v31/ieVW2ZhZI2eCN5jzbjEETS9weq8-19ehAyvMum7nfDB64bEN5XljLdSK37o.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-roboto-flex",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fc8003e8-f51b-44f0-b198-35edfe65a410",869893561),$APP.$cljs$cst$2675$family$$,"Roboto Flex",$APP.$cljs$cst$725$name$$,"Roboto Flex",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoflex/v30/NaNnepOXO_NexZs0b5QrzlOHb8wCikXpYqmZsWI-__OGbt8jZktqc2V3Zs0KvDLdBP8SBZtOs2IifRuUZQMsPJtUsR4DEK6cULNeUx9XgTnH37Ha_FIAp4Fm0PP1hw45DntW2x0wZGzhPmr1YNMYKYn9_1IQXGwJAiUJVUMdN5YUW4O8HtSoXjC1z3QSabshNFVe3e0O5j3ZjrZCu23Qd4G0EBysQNK-QKavMl1cKq3tHXtXi8mzLjaAQbGunCNCKMY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-roboto-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2c57b25a-4e20-405d-bc56-0607372bf576",
1379403523),$APP.$cljs$cst$2675$family$$,"Roboto Mono",$APP.$cljs$cst$725$name$$,"Roboto Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotomono/v31/L0xuDF4xlVMF-BfR8bXMIhJHg45mwgGEFl0_3vuPQ--5Ip2sSQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotomono/v31/L0xuDF4xlVMF-BfR8bXMIhJHg45mwgGEFl0_XvqPQ--5Ip2sSQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotomono/v31/L0xuDF4xlVMF-BfR8bXMIhJHg45mwgGEFl0_gPqPQ--5Ip2sSQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotomono/v31/L0xuDF4xlVMF-BfR8bXMIhJHg45mwgGEFl0_3vqPQ--5Ip2sSQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotomono/v31/L0xuDF4xlVMF-BfR8bXMIhJHg45mwgGEFl0_7PqPQ--5Ip2sSQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotomono/v31/L0xuDF4xlVMF-BfR8bXMIhJHg45mwgGEFl0_AP2PQ--5Ip2sSQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotomono/v31/L0xuDF4xlVMF-BfR8bXMIhJHg45mwgGEFl0_Of2PQ--5Ip2sSQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotomono/v31/L0xoDF4xlVMF-BfR8bXMIjhOsXG-q2oeuFoqFrlnAeW9AJi8SZwt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotomono/v31/L0xoDF4xlVMF-BfR8bXMIjhOsXG-q2oeuFoqFrnnAOW9AJi8SZwt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotomono/v31/L0xoDF4xlVMF-BfR8bXMIjhOsXG-q2oeuFoqFrk5AOW9AJi8SZwt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/robotomono/v31/L0xoDF4xlVMF-BfR8bXMIjhOsXG-q2oeuFoqFrlnAOW9AJi8SZwt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotomono/v31/L0xoDF4xlVMF-BfR8bXMIjhOsXG-q2oeuFoqFrlVAOW9AJi8SZwt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotomono/v31/L0xoDF4xlVMF-BfR8bXMIjhOsXG-q2oeuFoqFrm5B-W9AJi8SZwt.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotomono/v31/L0xoDF4xlVMF-BfR8bXMIjhOsXG-q2oeuFoqFrmAB-W9AJi8SZwt.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-roboto-serif",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("74cb9675-0550-411d-bc9e-fe3bf2657aae",2065769755),$APP.$cljs$cst$2675$family$$,"Roboto Serif",$APP.$cljs$cst$725$name$$,"Roboto Serif",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71RjywflP6FLr3gZx7K8UyuXDs9zVwDmXCb8lxYgmuii32UGoVldX6UgfjL4-3sMM_kB_qXSEXTJQCFLH5-_bcEliosp6d2Af5fR4k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71RjywflP6FLr3gZx7K8UyuXDs9zVwDmXCb8lxYgmuii32UGoVldX6UgfjL4-3sMM_kB_qXSEXTJQCFLH5-_bcElqotp6d2Af5fR4k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71RjywflP6FLr3gZx7K8UyuXDs9zVwDmXCb8lxYgmuii32UGoVldX6UgfjL4-3sMM_kB_qXSEXTJQCFLH5-_bcElnQtp6d2Af5fR4k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71RjywflP6FLr3gZx7K8UyuXDs9zVwDmXCb8lxYgmuii32UGoVldX6UgfjL4-3sMM_kB_qXSEXTJQCFLH5-_bcEliotp6d2Af5fR4k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71RjywflP6FLr3gZx7K8UyuXDs9zVwDmXCb8lxYgmuii32UGoVldX6UgfjL4-3sMM_kB_qXSEXTJQCFLH5-_bcElhgtp6d2Af5fR4k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71RjywflP6FLr3gZx7K8UyuXDs9zVwDmXCb8lxYgmuii32UGoVldX6UgfjL4-3sMM_kB_qXSEXTJQCFLH5-_bcElvQqp6d2Af5fR4k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71RjywflP6FLr3gZx7K8UyuXDs9zVwDmXCb8lxYgmuii32UGoVldX6UgfjL4-3sMM_kB_qXSEXTJQCFLH5-_bcEls0qp6d2Af5fR4k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71RjywflP6FLr3gZx7K8UyuXDs9zVwDmXCb8lxYgmuii32UGoVldX6UgfjL4-3sMM_kB_qXSEXTJQCFLH5-_bcElqoqp6d2Af5fR4k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71RjywflP6FLr3gZx7K8UyuXDs9zVwDmXCb8lxYgmuii32UGoVldX6UgfjL4-3sMM_kB_qXSEXTJQCFLH5-_bcEloMqp6d2Af5fR4k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71XjywflP6FLr3gZx7K8UyEVQnyR1E7VN-f51xYuGCQepOvB0KLc2v0wKKB0Q4MSZxyqf2CgAchbDJ69BcVZxkDg-JuT-V8BdxaV4nUFw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71XjywflP6FLr3gZx7K8UyEVQnyR1E7VN-f51xYuGCQepOvB0KLc2v0wKKB0Q4MSZxyqf2CgAchbDJ69BcVZxkDg-Juz-R8BdxaV4nUFw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71XjywflP6FLr3gZx7K8UyEVQnyR1E7VN-f51xYuGCQepOvB0KLc2v0wKKB0Q4MSZxyqf2CgAchbDJ69BcVZxkDg-JuEeR8BdxaV4nUFw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71XjywflP6FLr3gZx7K8UyEVQnyR1E7VN-f51xYuGCQepOvB0KLc2v0wKKB0Q4MSZxyqf2CgAchbDJ69BcVZxkDg-JuT-R8BdxaV4nUFw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71XjywflP6FLr3gZx7K8UyEVQnyR1E7VN-f51xYuGCQepOvB0KLc2v0wKKB0Q4MSZxyqf2CgAchbDJ69BcVZxkDg-JufeR8BdxaV4nUFw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71XjywflP6FLr3gZx7K8UyEVQnyR1E7VN-f51xYuGCQepOvB0KLc2v0wKKB0Q4MSZxyqf2CgAchbDJ69BcVZxkDg-JukeN8BdxaV4nUFw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,
"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71XjywflP6FLr3gZx7K8UyEVQnyR1E7VN-f51xYuGCQepOvB0KLc2v0wKKB0Q4MSZxyqf2CgAchbDJ69BcVZxkDg-JuqON8BdxaV4nUFw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71XjywflP6FLr3gZx7K8UyEVQnyR1E7VN-f51xYuGCQepOvB0KLc2v0wKKB0Q4MSZxyqf2CgAchbDJ69BcVZxkDg-Juz-N8BdxaV4nUFw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoserif/v17/R71XjywflP6FLr3gZx7K8UyEVQnyR1E7VN-f51xYuGCQepOvB0KLc2v0wKKB0Q4MSZxyqf2CgAchbDJ69BcVZxkDg-Ju5uN8BdxaV4nUFw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-roboto-slab",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("1ea4e499-2401-45a4-9b1d-59d6873c7a00",1858429056),$APP.$cljs$cst$2675$family$$,"Roboto Slab",$APP.$cljs$cst$725$name$$,"Roboto Slab",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoslab/v36/BngbUXZYTXPIvIBgJJSb6s3BzlRRfKOFbvjojIWWaG5iddG-1A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoslab/v36/BngbUXZYTXPIvIBgJJSb6s3BzlRRfKOFbvjoDISWaG5iddG-1A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoslab/v36/BngbUXZYTXPIvIBgJJSb6s3BzlRRfKOFbvjo0oSWaG5iddG-1A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoslab/v36/BngbUXZYTXPIvIBgJJSb6s3BzlRRfKOFbvjojISWaG5iddG-1A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoslab/v36/BngbUXZYTXPIvIBgJJSb6s3BzlRRfKOFbvjovoSWaG5iddG-1A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoslab/v36/BngbUXZYTXPIvIBgJJSb6s3BzlRRfKOFbvjoUoOWaG5iddG-1A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoslab/v36/BngbUXZYTXPIvIBgJJSb6s3BzlRRfKOFbvjoa4OWaG5iddG-1A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoslab/v36/BngbUXZYTXPIvIBgJJSb6s3BzlRRfKOFbvjoDIOWaG5iddG-1A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/robotoslab/v36/BngbUXZYTXPIvIBgJJSb6s3BzlRRfKOFbvjoJYOWaG5iddG-1A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-rochester",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bab273b0-0d64-4b8c-9af6-a8ffdee8172c",1533273795),$APP.$cljs$cst$2675$family$$,"Rochester",$APP.$cljs$cst$725$name$$,"Rochester",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rochester/v24/6ae-4KCqVa4Zy6Fif-Uy31vWNTMwoQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rock-3d",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e54bde67-0c1f-4ff4-884d-67b3be629435",1194889383),$APP.$cljs$cst$2675$family$$,"Rock 3D",$APP.$cljs$cst$725$name$$,"Rock 3D",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rock3d/v13/yYLp0hrL0PCo651513SnwRnQyNI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rock-salt",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("70d0b886-16bd-40e0-848a-5a0cd61cc38c",1321697808),$APP.$cljs$cst$2675$family$$,
"Rock Salt",$APP.$cljs$cst$725$name$$,"Rock Salt",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rocksalt/v24/MwQ0bhv11fWD6QsAVOZbsEk7hbBWrA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-rocknroll-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7d26227c-a4a3-4381-8cb6-912b12ff22d0",-1060540401),$APP.$cljs$cst$2675$family$$,"RocknRoll One",$APP.$cljs$cst$725$name$$,"RocknRoll One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rocknrollone/v16/kmK7ZqspGAfCeUiW6FFlmEC9guVhs7tfUxc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rokkitt",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c3a9103d-66f5-454a-a385-bb3afe8e39d5",1450091876),$APP.$cljs$cst$2675$family$$,"Rokkitt",$APP.$cljs$cst$725$name$$,"Rokkitt",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdb35qfgYFjGy5hukqqhw5XeRgdi1rydpDLE76HvN6n.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdb35qfgYFjGy5hukqqhw5XeRgdi1pyd5DLE76HvN6n.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdb35qfgYFjGy5hukqqhw5XeRgdi1qsd5DLE76HvN6n.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdb35qfgYFjGy5hukqqhw5XeRgdi1ryd5DLE76HvN6n.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdb35qfgYFjGy5hukqqhw5XeRgdi1rAd5DLE76HvN6n.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdb35qfgYFjGy5hukqqhw5XeRgdi1oscJDLE76HvN6n.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/rokkitt/v39/qFdb35qfgYFjGy5hukqqhw5XeRgdi1oVcJDLE76HvN6n.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdb35qfgYFjGy5hukqqhw5XeRgdi1pycJDLE76HvN6n.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,
"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdb35qfgYFjGy5hukqqhw5XeRgdi1pbcJDLE76HvN6n.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdV35qfgYFjGy5hkEOYeNY-EoKzjE86NHiJGbqluc6nu9E.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdV35qfgYFjGy5hkEOYeNY-EoKzjE86NPiIGbqluc6nu9E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdV35qfgYFjGy5hkEOYeNY-EoKzjE86NCaIGbqluc6nu9E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdV35qfgYFjGy5hkEOYeNY-EoKzjE86NHiIGbqluc6nu9E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdV35qfgYFjGy5hkEOYeNY-EoKzjE86NEqIGbqluc6nu9E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdV35qfgYFjGy5hkEOYeNY-EoKzjE86NKaPGbqluc6nu9E.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdV35qfgYFjGy5hkEOYeNY-EoKzjE86NJ-PGbqluc6nu9E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdV35qfgYFjGy5hkEOYeNY-EoKzjE86NPiPGbqluc6nu9E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rokkitt/v39/qFdV35qfgYFjGy5hkEOYeNY-EoKzjE86NNGPGbqluc6nu9E.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-romanesco",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e7f81e81-6f22-4df5-a1f3-a49812f0ce68",-1007841138),$APP.$cljs$cst$2675$family$$,"Romanesco",$APP.$cljs$cst$725$name$$,"Romanesco",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/romanesco/v22/w8gYH2ozQOY7_r_J7mSn3HwLqOqSBg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ropa-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("622b7c16-4271-4777-a5ef-f05d6ccf0b0a",-1287086631),$APP.$cljs$cst$2675$family$$,"Ropa Sans",$APP.$cljs$cst$725$name$$,"Ropa Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ropasans/v16/EYqxmaNOzLlWtsZSScyKWjloU5KP2g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ropasans/v16/EYq3maNOzLlWtsZSScy6WDNscZef2mNE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rosario",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1d411fe4-4f81-4bdf-9dea-cf410b96622c",-123867810),$APP.$cljs$cst$2675$family$$,"Rosario",$APP.$cljs$cst$725$name$$,"Rosario",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rosario/v35/xfuu0WDhWW_fOEoY8l_VPNZfB7jPM69GCWczd-YnOzUD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rosario/v35/xfuu0WDhWW_fOEoY8l_VPNZfB7jPM68YCWczd-YnOzUD.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rosario/v35/xfuu0WDhWW_fOEoY8l_VPNZfB7jPM68qCWczd-YnOzUD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/rosario/v35/xfuu0WDhWW_fOEoY8l_VPNZfB7jPM6_GDmczd-YnOzUD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rosario/v35/xfuu0WDhWW_fOEoY8l_VPNZfB7jPM6__Dmczd-YnOzUD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,
"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rosario/v35/xfug0WDhWW_fOEoY2Fbnww42bCJhNLrQStFwfeIFPiUDn08.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rosario/v35/xfug0WDhWW_fOEoY2Fbnww42bCJhNLrQSo9wfeIFPiUDn08.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rosario/v35/xfug0WDhWW_fOEoY2Fbnww42bCJhNLrQSr1wfeIFPiUDn08.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rosario/v35/xfug0WDhWW_fOEoY2Fbnww42bCJhNLrQSlF3feIFPiUDn08.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rosario/v35/xfug0WDhWW_fOEoY2Fbnww42bCJhNLrQSmh3feIFPiUDn08.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-rosarivo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c16493ff-72de-495f-a24b-27912d44fd41",-2035238295),$APP.$cljs$cst$2675$family$$,"Rosarivo",$APP.$cljs$cst$725$name$$,"Rosarivo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rosarivo/v24/PlI-Fl2lO6N9f8HaNAeC2nhMnNy5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rosarivo/v24/PlI4Fl2lO6N9f8HaNDeA0Hxumcy5ZX8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-rouge-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("15615b7a-72bb-432e-aeb7-85be1d8e2654",-1272468787),$APP.$cljs$cst$2675$family$$,"Rouge Script",$APP.$cljs$cst$725$name$$,"Rouge Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rougescript/v20/LYjFdGbiklMoCIQOw1Ep3S4PVPXbUJWq9g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rowdies",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3461d9a0-6b14-4382-9125-a13e10c1fd01",854701030),$APP.$cljs$cst$2675$family$$,"Rowdies",$APP.$cljs$cst$725$name$$,"Rowdies",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rowdies/v19/ptRMTieMYPNBAK219hth5O7yKQNute8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/rowdies/v19/ptRJTieMYPNBAK21zrdJwObZNQo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rowdies/v19/ptRMTieMYPNBAK219gtm5O7yKQNute8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rozha-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("26a1a91a-2b50-4a82-abdf-8b23c6bf5583",
569589153),$APP.$cljs$cst$2675$family$$,"Rozha One",$APP.$cljs$cst$725$name$$,"Rozha One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rozhaone/v17/AlZy_zVFtYP12Zncg2khdXf4XB0Tow.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5fd59c59-1dad-4aa6-868b-5a13ebf1dfbe",-1440925022),$APP.$cljs$cst$2675$family$$,"Rubik",$APP.$cljs$cst$725$name$$,"Rubik",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubik/v31/iJWZBXyIfDnIV5PNhY1KTN7Z-Yh-WYi1UE80V4bVkA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubik/v31/iJWZBXyIfDnIV5PNhY1KTN7Z-Yh-B4i1UE80V4bVkA.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubik/v31/iJWZBXyIfDnIV5PNhY1KTN7Z-Yh-NYi1UE80V4bVkA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/rubik/v31/iJWZBXyIfDnIV5PNhY1KTN7Z-Yh-2Y-1UE80V4bVkA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubik/v31/iJWZBXyIfDnIV5PNhY1KTN7Z-Yh-4I-1UE80V4bVkA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubik/v31/iJWZBXyIfDnIV5PNhY1KTN7Z-Yh-h4-1UE80V4bVkA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubik/v31/iJWZBXyIfDnIV5PNhY1KTN7Z-Yh-ro-1UE80V4bVkA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubik/v31/iJWbBXyIfDnIV7nEt3KSJbVDV49rz8sDE0UwdYPFkJ1O.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubik/v31/iJWbBXyIfDnIV7nEt3KSJbVDV49rz8tdE0UwdYPFkJ1O.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubik/v31/iJWbBXyIfDnIV7nEt3KSJbVDV49rz8tvE0UwdYPFkJ1O.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubik/v31/iJWbBXyIfDnIV7nEt3KSJbVDV49rz8uDFEUwdYPFkJ1O.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubik/v31/iJWbBXyIfDnIV7nEt3KSJbVDV49rz8u6FEUwdYPFkJ1O.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubik/v31/iJWbBXyIfDnIV7nEt3KSJbVDV49rz8vdFEUwdYPFkJ1O.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubik/v31/iJWbBXyIfDnIV7nEt3KSJbVDV49rz8v0FEUwdYPFkJ1O.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-80s-fade",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("36608868-6c83-4f98-8b98-015c838855a1",1189957794),$APP.$cljs$cst$2675$family$$,"Rubik 80s Fade",$APP.$cljs$cst$725$name$$,"Rubik 80s Fade",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubik80sfade/v2/U9MF6dW37nLSmnwZXyoV-uPXUhHwkbL8IHcK.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-beastly",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c9416db7-8b47-4995-8803-f6191ad131fa",-266103954),$APP.$cljs$cst$2675$family$$,"Rubik Beastly",$APP.$cljs$cst$725$name$$,"Rubik Beastly",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikbeastly/v11/0QImMXRd5oOmSC2ZQ7o9653X07z8_ApHqqk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-rubik-broken-fax",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("09111a18-537d-4cba-ad92-6f0ef2b47a1a",-1334377841),$APP.$cljs$cst$2675$family$$,"Rubik Broken Fax",$APP.$cljs$cst$725$name$$,"Rubik Broken Fax",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikbrokenfax/v1/NGSvv4rXG042O-GzH9sg1cUgl8w8YW-WdmGi300.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-bubbles",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b5b0edb7-19ba-4213-942e-ce0d3c138ee1",443649010),$APP.$cljs$cst$2675$family$$,"Rubik Bubbles",$APP.$cljs$cst$725$name$$,"Rubik Bubbles",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikbubbles/v3/JIA1UVdwbHFJtwA7Us1BPFbRNTENfDxyRXI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-burned",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("935481c1-645b-43c2-ba79-4310192b26b4",
1170669373),$APP.$cljs$cst$2675$family$$,"Rubik Burned",$APP.$cljs$cst$725$name$$,"Rubik Burned",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikburned/v1/Jqzk5TmOVOqQHihKqPpscqniHQuaCY5ZSg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-dirt",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("aabde5cc-2d6d-433f-b2a2-7acc7784d88d",1131710042),$APP.$cljs$cst$2675$family$$,"Rubik Dirt",$APP.$cljs$cst$725$name$$,"Rubik Dirt",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikdirt/v2/DtVmJxC7WLEj1uIXEWAdulwm6gDXvwE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-distressed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f541c4b0-7822-4148-af8f-350b2936647f",1226501741),$APP.$cljs$cst$2675$family$$,"Rubik Distressed",$APP.$cljs$cst$725$name$$,"Rubik Distressed",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikdistressed/v1/GFDxWBdsmnqAVqjtUsZf2dcrQ2ldcWAhatVBaGM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-doodle-shadow",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("107dcd5a-0413-4b00-8750-f94abddfca6d",1679104735),$APP.$cljs$cst$2675$family$$,"Rubik Doodle Shadow",$APP.$cljs$cst$725$name$$,"Rubik Doodle Shadow",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikdoodleshadow/v1/rP2bp3im_k8G_wTVdvvMdHqmXTR3lEaLyKuZ3KOY7Gw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-doodle-triangles",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ff158fe5-40d1-4988-9f3e-5a20f24fb9c3",1180521565),$APP.$cljs$cst$2675$family$$,"Rubik Doodle Triangles",$APP.$cljs$cst$725$name$$,"Rubik Doodle Triangles",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikdoodletriangles/v1/esDA301BLOmMKxKspb3g-domRuLPeaSn2bTzdLi_slZxgWE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-gemstones",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("77890fdb-de53-4e80-b13b-2b566f7f7ef1",968049995),$APP.$cljs$cst$2675$family$$,"Rubik Gemstones",$APP.$cljs$cst$725$name$$,"Rubik Gemstones",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/rubikgemstones/v1/zrf90HrL0-_8Xb4DFM2rUkWbOVrOiCnGqi1GMw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-glitch",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9e5cf15e-9d12-425d-bf8e-d1d2a06afac7",69840435),$APP.$cljs$cst$2675$family$$,"Rubik Glitch",$APP.$cljs$cst$725$name$$,"Rubik Glitch",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikglitch/v2/qkBSXv8b_srFRYQVYrDKh9ZvmC7HONiSFQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-glitch-pop",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d3b3c3e0-0157-49d0-b593-24f8948b783e",1258741689),
$APP.$cljs$cst$2675$family$$,"Rubik Glitch Pop",$APP.$cljs$cst$725$name$$,"Rubik Glitch Pop",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikglitchpop/v1/tDbX2pGHhFcM0gB3hN2elZLa3G-MOwStSUrV_BE.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-iso",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e8113cd4-5a1a-450c-9b4f-1c598ad46112",-818344226),$APP.$cljs$cst$2675$family$$,"Rubik Iso",$APP.$cljs$cst$725$name$$,"Rubik Iso",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikiso/v2/x3dickHUfr-S4VAI4sABfPACvy_1BA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-lines",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("75f97048-a075-4682-98a1-139858807352",826488651),$APP.$cljs$cst$2675$family$$,"Rubik Lines",$APP.$cljs$cst$725$name$$,"Rubik Lines",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubiklines/v1/_gP81R3vsjYzVW2Y6xFF-GSxYPp7oSNy.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-maps",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dc7de478-a915-4ce8-8c4b-5e948d96ec0b",-1762027142),$APP.$cljs$cst$2675$family$$,"Rubik Maps",$APP.$cljs$cst$725$name$$,"Rubik Maps",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/rubikmaps/v1/Gw6_wcjl80TZK9XxtbbejSYUChRqp9k.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-marker-hatch",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9c6249bc-da0d-4dc6-95df-142dbacdbae6",-1551677778),$APP.$cljs$cst$2675$family$$,"Rubik Marker Hatch",$APP.$cljs$cst$725$name$$,"Rubik Marker Hatch",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikmarkerhatch/v1/QldTNSFQsh0B_bFXXWv6LAt-jswapJHQDL4iw0H6zw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-maze",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fe589f93-fa43-4a75-8524-28659c3de9a9",
-667126061),$APP.$cljs$cst$2675$family$$,"Rubik Maze",$APP.$cljs$cst$725$name$$,"Rubik Maze",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikmaze/v2/xMQRuF9ZVa2ftiJEavXSAX7inS-bxV4.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-microbe",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("044d5d08-d6f6-4b05-8f6b-a4ad660e16e0",-305784177),$APP.$cljs$cst$2675$family$$,"Rubik Microbe",$APP.$cljs$cst$725$name$$,"Rubik Microbe",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikmicrobe/v2/UqyWK8oPP3hjw6ANS9rM3PsZcs8aaKgiauE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-mono-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5008ae5b-4350-4115-af09-230065b9620c",1694829486),$APP.$cljs$cst$2675$family$$,"Rubik Mono One",$APP.$cljs$cst$725$name$$,"Rubik Mono One",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikmonoone/v20/UqyJK8kPP3hjw6ANTdfRk9YSN-8wRqQrc_j9.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-rubik-moonrocks",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d754652d-8dee-4174-a781-c6651757efef",-961268988),$APP.$cljs$cst$2675$family$$,"Rubik Moonrocks",$APP.$cljs$cst$725$name$$,"Rubik Moonrocks",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikmoonrocks/v7/845ANMAmAI2VUZMLu_W0M7HqlDHnXcD7JGy1Sw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-pixels",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4a6ada29-0eca-43ae-8e87-4ed240a0729e",1960375193),$APP.$cljs$cst$2675$family$$,"Rubik Pixels",$APP.$cljs$cst$725$name$$,"Rubik Pixels",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikpixels/v3/SlGXmQOaupkIeSx4CEpB7AdSaBYRagrQrA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-puddles",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8064607c-df44-40d1-b779-ee2438fbff2e",845112812),
$APP.$cljs$cst$2675$family$$,"Rubik Puddles",$APP.$cljs$cst$725$name$$,"Rubik Puddles",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikpuddles/v2/1Ptog8bYX_qGnkLkrU5MJsQcJfC0wVMT-aE.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-scribble",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d7bf2539-e3c4-4ae9-a3c8-6a7c664caec0",1134167623),$APP.$cljs$cst$2675$family$$,"Rubik Scribble",$APP.$cljs$cst$725$name$$,"Rubik Scribble",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikscribble/v1/snfzs0Cp48d67SuHQOpjXLsQpbqbSjORSo9W.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-spray-paint",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("aaa53e57-4b4e-4c9c-bb5c-6af3331e9519",-497843476),$APP.$cljs$cst$2675$family$$,"Rubik Spray Paint",$APP.$cljs$cst$725$name$$,
"Rubik Spray Paint",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikspraypaint/v1/WnzhHBAoeBPUDTB4EWR82y6EXWPH-Ro-QoaBZQxP.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-storm",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1c7036ff-2e4d-45d2-891d-2b2034e56393",-1658629563),$APP.$cljs$cst$2675$family$$,"Rubik Storm",$APP.$cljs$cst$725$name$$,"Rubik Storm",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikstorm/v1/eLGYP-_uPgO5Ag7ju9JaouL9T2Xh9NQk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-vinyl",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c1fbfb73-c2b5-443b-800e-bc6a458fc9cb",-2102610421),$APP.$cljs$cst$2675$family$$,"Rubik Vinyl",$APP.$cljs$cst$725$name$$,"Rubik Vinyl",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikvinyl/v1/iJWABXKIfDnIV4mQ5BfjvUXexox2ztOU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rubik-wet-paint",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("738b2c07-2536-4f93-ac1c-36a768002e2f",
-1260518044),$APP.$cljs$cst$2675$family$$,"Rubik Wet Paint",$APP.$cljs$cst$725$name$$,"Rubik Wet Paint",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rubikwetpaint/v2/HTx0L20uMDGHgdULcpTF3Oe4d_-F-zz313DuvQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ruda",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0ac02f10-95c8-4296-9c60-1d7487a9bb3c",-1536317289),$APP.$cljs$cst$2675$family$$,"Ruda",$APP.$cljs$cst$725$name$$,"Ruda",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ruda/v30/k3kKo8YQJOpFgHQ1mQ5VkEbUKaJFsi_-2KiSGg-H.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ruda/v30/k3kKo8YQJOpFgHQ1mQ5VkEbUKaJ3si_-2KiSGg-H.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ruda/v30/k3kKo8YQJOpFgHQ1mQ5VkEbUKaKbtS_-2KiSGg-H.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ruda/v30/k3kKo8YQJOpFgHQ1mQ5VkEbUKaKitS_-2KiSGg-H.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ruda/v30/k3kKo8YQJOpFgHQ1mQ5VkEbUKaLFtS_-2KiSGg-H.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ruda/v30/k3kKo8YQJOpFgHQ1mQ5VkEbUKaLstS_-2KiSGg-H.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rufina",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3013a216-404a-4f3e-896c-e2ab29ada6c1",-2050027008),$APP.$cljs$cst$2675$family$$,"Rufina",$APP.$cljs$cst$725$name$$,"Rufina",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rufina/v17/Yq6V-LyURyLy-aKyoxRktOdClg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rufina/v17/Yq6W-LyURyLy-aKKHztAvMxenxE0SA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ruge-boogie",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c68bcfef-5dac-41dc-ab59-0e51766def71",-310083901),$APP.$cljs$cst$2675$family$$,"Ruge Boogie",$APP.$cljs$cst$725$name$$,"Ruge Boogie",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rugeboogie/v30/JIA3UVFwbHRF_GIWSMhKNROiPzUveSxy.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ruluko",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("51dcf91b-6ad3-440d-8c4d-49eef05d420b",93931056),$APP.$cljs$cst$2675$family$$,"Ruluko",$APP.$cljs$cst$725$name$$,"Ruluko",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ruluko/v22/xMQVuFNZVaODtm0pC6WzKX_QmA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rum-raisin",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("07fd83b8-1d37-49d5-aebf-66e05aa17ca2",
2057156776),$APP.$cljs$cst$2675$family$$,"Rum Raisin",$APP.$cljs$cst$725$name$$,"Rum Raisin",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rumraisin/v24/nwpRtKu3Ih8D5avB4h2uJ3-IywA7eMM.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ruslan-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("13bb9b3f-0e4b-42a4-ba09-f362f2c3e6a9",-1585826577),$APP.$cljs$cst$2675$family$$,"Ruslan Display",$APP.$cljs$cst$725$name$$,"Ruslan Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ruslandisplay/v27/Gw6jwczl81XcIZuckK_e3UpfdzxrldyFvm1n.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-russo-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a1bb207f-388f-45dd-8eac-b0a96053f8d4",1428718224),$APP.$cljs$cst$2675$family$$,"Russo One",$APP.$cljs$cst$725$name$$,"Russo One",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/russoone/v18/Z9XUDmZRWg6M1LvRYsH-yMOInrib9Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-ruthie",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f1cacdc0-33b5-42b7-afeb-652c921504f2",1650545722),$APP.$cljs$cst$2675$family$$,"Ruthie",$APP.$cljs$cst$725$name$$,"Ruthie",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ruthie/v28/gokvH63sGkdqXuU9lD53Q2u_mQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ruwudu",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4b0239cd-d48d-40aa-92c9-b1b38d3a8aec",-872099266),$APP.$cljs$cst$2675$family$$,"Ruwudu",$APP.$cljs$cst$725$name$$,"Ruwudu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ruwudu/v4/syky-y1tj6UzRKfNlQCT9tPdpw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ruwudu/v4/sykx-y1tj6UzRKf1YSm3_vjBrlSILg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ruwudu/v4/sykx-y1tj6UzRKf1TS63_vjBrlSILg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ruwudu/v4/sykx-y1tj6UzRKf1KS-3_vjBrlSILg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-rye",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("845dbadd-0210-445f-b7a6-8ff79b086f27",-1896502032),$APP.$cljs$cst$2675$family$$,"Rye",$APP.$cljs$cst$725$name$$,"Rye",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/rye/v17/r05XGLJT86YDFpTsXOqx4w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-stix-two-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("94ac0044-5c83-46e8-85c5-0bcde071fc2c",24327939),$APP.$cljs$cst$2675$family$$,"STIX Two Text",$APP.$cljs$cst$725$name$$,
"STIX Two Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stixtwotext/v18/YA9Gr02F12Xkf5whdwKf11l0jbKkeidMTtZ5Yihg2SOYWxFMN1WD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stixtwotext/v18/YA9Gr02F12Xkf5whdwKf11l0jbKkeidMTtZ5YihS2SOYWxFMN1WD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stixtwotext/v18/YA9Gr02F12Xkf5whdwKf11l0jbKkeidMTtZ5Yii-3iOYWxFMN1WD.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stixtwotext/v18/YA9Gr02F12Xkf5whdwKf11l0jbKkeidMTtZ5YiiH3iOYWxFMN1WD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stixtwotext/v18/YA9Er02F12Xkf5whdwKf11l0p7uWhf8lJUzXZT2omsvbURVuMkWDmSo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stixtwotext/v18/YA9Er02F12Xkf5whdwKf11l0p7uWhf8lJUzXZT2omvnbURVuMkWDmSo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stixtwotext/v18/YA9Er02F12Xkf5whdwKf11l0p7uWhf8lJUzXZT2omhXcURVuMkWDmSo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/stixtwotext/v18/YA9Er02F12Xkf5whdwKf11l0p7uWhf8lJUzXZT2omizcURVuMkWDmSo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-suse",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6f2efd1b-6565-4416-9519-b00318785c70",930296441),$APP.$cljs$cst$2675$family$$,"SUSE",$APP.$cljs$cst$725$name$$,"SUSE",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQsbhb078Wt81NpzELmC2QqjbGG71q9ZnJSZtQG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/suse/v4/MwQsbhb078Wt81NpzELmC2QqjbEG7lq9ZnJSZtQG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQsbhb078Wt81NpzELmC2QqjbHY7lq9ZnJSZtQG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQsbhb078Wt81NpzELmC2QqjbGG7lq9ZnJSZtQG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQsbhb078Wt81NpzELmC2QqjbG07lq9ZnJSZtQG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQsbhb078Wt81NpzELmC2QqjbFY6Vq9ZnJSZtQG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQsbhb078Wt81NpzELmC2QqjbFh6Vq9ZnJSZtQG.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQsbhb078Wt81NpzELmC2QqjbEG6Vq9ZnJSZtQG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/suse/v4/MwQsbhb078Wt81NpzELmC2QqjbEv6Vq9ZnJSZtQG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQqbhb078Wt2VpbM5qPYP6EiqROrbL_bHZwY8QGjKU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,
"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQqbhb078Wt2VpbM5qPYP6EiqROrTL-bHZwY8QGjKU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQqbhb078Wt2VpbM5qPYP6EiqROrez-bHZwY8QGjKU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQqbhb078Wt2VpbM5qPYP6EiqROrbL-bHZwY8QGjKU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQqbhb078Wt2VpbM5qPYP6EiqROrYD-bHZwY8QGjKU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQqbhb078Wt2VpbM5qPYP6EiqROrWz5bHZwY8QGjKU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQqbhb078Wt2VpbM5qPYP6EiqROrVX5bHZwY8QGjKU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQqbhb078Wt2VpbM5qPYP6EiqROrTL5bHZwY8QGjKU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suse/v4/MwQqbhb078Wt2VpbM5qPYP6EiqROrRv5bHZwY8QGjKU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-suse-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d3854408-ac4a-462a-b108-89082ff15af0",
-1495180424),$APP.$cljs$cst$2675$family$$,"SUSE Mono",$APP.$cljs$cst$725$name$$,"SUSE Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/susemono/v1/y83KW4wN6yi9x2mTxJI2Lzk1yOJRC-VB656x2gtcobW_gE0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/susemono/v1/y83KW4wN6yi9x2mTxJI2Lzk1yOJRC-VB6x6w2gtcobW_gE0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/susemono/v1/y83KW4wN6yi9x2mTxJI2Lzk1yOJRC-VB68Cw2gtcobW_gE0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/susemono/v1/y83KW4wN6yi9x2mTxJI2Lzk1yOJRC-VB656w2gtcobW_gE0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/susemono/v1/y83KW4wN6yi9x2mTxJI2Lzk1yOJRC-VB66yw2gtcobW_gE0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/susemono/v1/y83KW4wN6yi9x2mTxJI2Lzk1yOJRC-VB60C32gtcobW_gE0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/susemono/v1/y83KW4wN6yi9x2mTxJI2Lzk1yOJRC-VB63m32gtcobW_gE0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/susemono/v1/y83KW4wN6yi9x2mTxJI2Lzk1yOJRC-VB6x632gtcobW_gE0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/susemono/v1/y83IW4wN6yi9x2mTxJIcJgvKEIs6kUtG_lbzMklWpZe6kE2tPw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",
$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/susemono/v1/y83IW4wN6yi9x2mTxJIcJgvKEIs6kUtG_lbzskhWpZe6kE2tPw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/susemono/v1/y83IW4wN6yi9x2mTxJIcJgvKEIs6kUtG_lbzbEhWpZe6kE2tPw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/susemono/v1/y83IW4wN6yi9x2mTxJIcJgvKEIs6kUtG_lbzMkhWpZe6kE2tPw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/susemono/v1/y83IW4wN6yi9x2mTxJIcJgvKEIs6kUtG_lbzAEhWpZe6kE2tPw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/susemono/v1/y83IW4wN6yi9x2mTxJIcJgvKEIs6kUtG_lbz7E9WpZe6kE2tPw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/susemono/v1/y83IW4wN6yi9x2mTxJIcJgvKEIs6kUtG_lbz1U9WpZe6kE2tPw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/susemono/v1/y83IW4wN6yi9x2mTxJIcJgvKEIs6kUtG_lbzsk9WpZe6kE2tPw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sacramento",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("11d0816b-6724-47fb-b201-271fe1b5b661",1332919344),$APP.$cljs$cst$2675$family$$,"Sacramento",$APP.$cljs$cst$725$name$$,"Sacramento",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sacramento/v17/buEzpo6gcdjy0EiZMBUG0CoV_NxLeiw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sahitya",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b69d5360-5442-41d6-a7f9-b45d579a1622",1274786405),$APP.$cljs$cst$2675$family$$,"Sahitya",$APP.$cljs$cst$725$name$$,"Sahitya",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sahitya/v20/6qLAKZkOuhnuqlJAaScFPywEDnI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sahitya/v20/6qLFKZkOuhnuqlJAUZsqGyQvEnvSexI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sail",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("321e52ad-ab96-4ca1-826e-b3e7a319f443",-1366783131),$APP.$cljs$cst$2675$family$$,"Sail",$APP.$cljs$cst$725$name$$,"Sail",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sail/v17/DPEjYwiBxwYJFBTDADYAbvw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-saira",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("18d179d1-fc17-4f52-9852-0b7b17a25f3d",-919368530),$APP.$cljs$cst$2675$family$$,
"Saira",$APP.$cljs$cst$725$name$$,"Saira",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memWYa2wxmKQyPMrZX79wwYZQMhsyuShhKMjjbU9uXuA71rDosg7lwYmUVY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memWYa2wxmKQyPMrZX79wwYZQMhsyuShhKMjjbU9uXuA79rCosg7lwYmUVY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memWYa2wxmKQyPMrZX79wwYZQMhsyuShhKMjjbU9uXuA7wTCosg7lwYmUVY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memWYa2wxmKQyPMrZX79wwYZQMhsyuShhKMjjbU9uXuA71rCosg7lwYmUVY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memWYa2wxmKQyPMrZX79wwYZQMhsyuShhKMjjbU9uXuA72jCosg7lwYmUVY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memWYa2wxmKQyPMrZX79wwYZQMhsyuShhKMjjbU9uXuA74TFosg7lwYmUVY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memWYa2wxmKQyPMrZX79wwYZQMhsyuShhKMjjbU9uXuA773Fosg7lwYmUVY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memWYa2wxmKQyPMrZX79wwYZQMhsyuShhKMjjbU9uXuA79rFosg7lwYmUVY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memWYa2wxmKQyPMrZX79wwYZQMhsyuShhKMjjbU9uXuA7_PFosg7lwYmUVY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memUYa2wxmKQyNkiV50dulWP7s95AqZTzZHcVdxWI9WH-pKBSooxkyQjQVYmxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memUYa2wxmKQyNkiV50dulWP7s95AqZTzZHcVdxWI9WH-pKByosxkyQjQVYmxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memUYa2wxmKQyNkiV50dulWP7s95AqZTzZHcVdxWI9WH-pKBFIsxkyQjQVYmxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/saira/v23/memUYa2wxmKQyNkiV50dulWP7s95AqZTzZHcVdxWI9WH-pKBSosxkyQjQVYmxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memUYa2wxmKQyNkiV50dulWP7s95AqZTzZHcVdxWI9WH-pKBeIsxkyQjQVYmxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memUYa2wxmKQyNkiV50dulWP7s95AqZTzZHcVdxWI9WH-pKBlIwxkyQjQVYmxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memUYa2wxmKQyNkiV50dulWP7s95AqZTzZHcVdxWI9WH-pKBrYwxkyQjQVYmxA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memUYa2wxmKQyNkiV50dulWP7s95AqZTzZHcVdxWI9WH-pKByowxkyQjQVYmxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/saira/v23/memUYa2wxmKQyNkiV50dulWP7s95AqZTzZHcVdxWI9WH-pKB44wxkyQjQVYmxA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-saira-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7382d440-9e57-472e-bdfe-5e1c434eedfe",1715136747),$APP.$cljs$cst$2675$family$$,"Saira Condensed",$APP.$cljs$cst$725$name$$,"Saira Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairacondensed/v12/EJRMQgErUN8XuHNEtX81i9TmEkrnwetA2omSrzS8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairacondensed/v12/EJRLQgErUN8XuHNEtX81i9TmEkrnbcpg8Keepi2lHw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairacondensed/v12/EJRLQgErUN8XuHNEtX81i9TmEkrnCclg8Keepi2lHw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairacondensed/v12/EJROQgErUN8XuHNEtX81i9TmEkrfpeFE-IyCrw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairacondensed/v12/EJRLQgErUN8XuHNEtX81i9TmEkrnUchg8Keepi2lHw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairacondensed/v12/EJRLQgErUN8XuHNEtX81i9TmEkrnfc9g8Keepi2lHw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sairacondensed/v12/EJRLQgErUN8XuHNEtX81i9TmEkrnGc5g8Keepi2lHw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairacondensed/v12/EJRLQgErUN8XuHNEtX81i9TmEkrnBc1g8Keepi2lHw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,
"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairacondensed/v12/EJRLQgErUN8XuHNEtX81i9TmEkrnIcxg8Keepi2lHw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-saira-extra-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c55edc7e-635c-410f-a427-d7c0caa6565c",-691489083),$APP.$cljs$cst$2675$family$$,"Saira Extra Condensed",$APP.$cljs$cst$725$name$$,"Saira Extra Condensed",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairaextracondensed/v15/-nFsOHYr-vcC7h8MklGBkrvmUG9rbpkisrTri0jx9i5ss3a3.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairaextracondensed/v15/-nFvOHYr-vcC7h8MklGBkrvmUG9rbpkisrTrJ2nR3ABgum-uoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairaextracondensed/v15/-nFvOHYr-vcC7h8MklGBkrvmUG9rbpkisrTrQ2rR3ABgum-uoQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairaextracondensed/v15/-nFiOHYr-vcC7h8MklGBkrvmUG9rbpkisrTT70L11Ct8sw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairaextracondensed/v15/-nFvOHYr-vcC7h8MklGBkrvmUG9rbpkisrTrG2vR3ABgum-uoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairaextracondensed/v15/-nFvOHYr-vcC7h8MklGBkrvmUG9rbpkisrTrN2zR3ABgum-uoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairaextracondensed/v15/-nFvOHYr-vcC7h8MklGBkrvmUG9rbpkisrTrU23R3ABgum-uoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairaextracondensed/v15/-nFvOHYr-vcC7h8MklGBkrvmUG9rbpkisrTrT27R3ABgum-uoQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairaextracondensed/v15/-nFvOHYr-vcC7h8MklGBkrvmUG9rbpkisrTra2_R3ABgum-uoQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-saira-semi-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("afe96df3-8cf4-44ae-9122-85910720e571",
-791360235),$APP.$cljs$cst$2675$family$$,"Saira Semi Condensed",$APP.$cljs$cst$725$name$$,"Saira Semi Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairasemicondensed/v15/U9MN6c-2-nnJkHxyCjRcnMHcWVWV1cWRRXdvaOM8rXT-8V8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairasemicondensed/v15/U9MM6c-2-nnJkHxyCjRcnMHcWVWV1cWRRXfDScMWg3j36Ebz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairasemicondensed/v15/U9MM6c-2-nnJkHxyCjRcnMHcWVWV1cWRRXenSsMWg3j36Ebz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairasemicondensed/v15/U9MD6c-2-nnJkHxyCjRcnMHcWVWV1cWRRU8LYuceqGT-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairasemicondensed/v15/U9MM6c-2-nnJkHxyCjRcnMHcWVWV1cWRRXf_S8MWg3j36Ebz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairasemicondensed/v15/U9MM6c-2-nnJkHxyCjRcnMHcWVWV1cWRRXfTTMMWg3j36Ebz.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairasemicondensed/v15/U9MM6c-2-nnJkHxyCjRcnMHcWVWV1cWRRXe3TcMWg3j36Ebz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairasemicondensed/v15/U9MM6c-2-nnJkHxyCjRcnMHcWVWV1cWRRXerTsMWg3j36Ebz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairasemicondensed/v15/U9MM6c-2-nnJkHxyCjRcnMHcWVWV1cWRRXePT8MWg3j36Ebz.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-saira-stencil-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("62a8ce17-a335-43c6-bab9-ff97444cf495",1673542586),$APP.$cljs$cst$2675$family$$,"Saira Stencil One",$APP.$cljs$cst$725$name$$,"Saira Stencil One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sairastencilone/v18/SLXSc03I6HkvZGJ1GvvipLoYSTEL9AsMawif2YQ2.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-salsa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("67001741-7f8b-46a2-bf37-9f6c87f70cae",791308067),$APP.$cljs$cst$2675$family$$,"Salsa",$APP.$cljs$cst$725$name$$,"Salsa",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/salsa/v23/gNMKW3FiRpKj-imY8ncKEZez.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sanchez",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d976cc5b-1377-47b6-8d6a-cbdc4b39bb86",
1811296242),$APP.$cljs$cst$2675$family$$,"Sanchez",$APP.$cljs$cst$725$name$$,"Sanchez",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sanchez/v17/Ycm2sZJORluHnXbITm5b_BwE1l0.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sanchez/v17/Ycm0sZJORluHnXbIfmxR-D4Bxl3gkw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sancreek",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ff61c1c6-deed-4c6d-95a7-2a425e5fbc40",-1242893755),
$APP.$cljs$cst$2675$family$$,"Sancreek",$APP.$cljs$cst$725$name$$,"Sancreek",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sancreek/v27/pxiHypAnsdxUm159X7D-XV9NEe-K.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sankofa-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a4a500d8-b308-4ca8-9e34-e1beff703cb4",1820513599),$APP.$cljs$cst$2675$family$$,"Sankofa Display",$APP.$cljs$cst$725$name$$,"Sankofa Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sankofadisplay/v2/Ktk1ALSRd4LucUDghJ2rTqXOoh33F6mZVY9Y5w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sansation",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4a7db781-3b28-464b-9fa1-2bc856c1152f",252655319),$APP.$cljs$cst$2675$family$$,"Sansation",$APP.$cljs$cst$725$name$$,"Sansation",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansation/v1/LYjFdGPjnEg8DNA0z01YAVgPVPXbUJWq9g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,
"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansation/v1/LYjbdGPjnEg8DNA0z01Qr0KDVv_fcpC69i6N.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansation/v1/LYjAdGPjnEg8DNA0z01grXArXN7HWQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansation/v1/LYjGdGPjnEg8DNA0z01Qr3ovftvXWYyz.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansation/v1/LYjFdGPjnEg8DNA0z01YEV8PVPXbUJWq9g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansation/v1/LYjbdGPjnEg8DNA0z01Qr0KTUf_fcpC69i6N.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sansita",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5f1e14a9-21cf-4b07-9819-109855b54569",
23648278),$APP.$cljs$cst$2675$family$$,"Sansita",$APP.$cljs$cst$725$name$$,"Sansita",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansita/v12/QldONTRRphEb_-V7HBm7TXFf3qw.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansita/v12/QldMNTRRphEb_-V7LBuxSVNazqx2xg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sansita/v12/QldLNTRRphEb_-V7JKWUaXl0wqVv3_g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansita/v12/QldJNTRRphEb_-V7LBuJ9Xx-xodqz_joDQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",
$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansita/v12/QldLNTRRphEb_-V7JLmXaXl0wqVv3_g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansita/v12/QldJNTRRphEb_-V7LBuJ6X9-xodqz_joDQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansita/v12/QldLNTRRphEb_-V7JJ2WaXl0wqVv3_g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansita/v12/QldJNTRRphEb_-V7LBuJzX5-xodqz_joDQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sansita-swashed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9168d8b6-061a-47b7-828f-5c8059089e0b",-1121704890),$APP.$cljs$cst$2675$family$$,"Sansita Swashed",$APP.$cljs$cst$725$name$$,"Sansita Swashed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansitaswashed/v23/BXR8vFfZifTZgFlDDLgNkBydPKTt3pVCeYWqJnZSW-ppbToVehmEa4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansitaswashed/v23/BXR8vFfZifTZgFlDDLgNkBydPKTt3pVCeYWqJnZSW7RpbToVehmEa4Q.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansitaswashed/v23/BXR8vFfZifTZgFlDDLgNkBydPKTt3pVCeYWqJnZSW4ZpbToVehmEa4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansitaswashed/v23/BXR8vFfZifTZgFlDDLgNkBydPKTt3pVCeYWqJnZSW2pubToVehmEa4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansitaswashed/v23/BXR8vFfZifTZgFlDDLgNkBydPKTt3pVCeYWqJnZSW1NubToVehmEa4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansitaswashed/v23/BXR8vFfZifTZgFlDDLgNkBydPKTt3pVCeYWqJnZSWzRubToVehmEa4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sansitaswashed/v23/BXR8vFfZifTZgFlDDLgNkBydPKTt3pVCeYWqJnZSWx1ubToVehmEa4Q.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sarabun",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3393b805-97bd-4ad1-89c5-c34c8139c9a2",-1026925204),$APP.$cljs$cst$2675$family$$,"Sarabun",$APP.$cljs$cst$725$name$$,"Sarabun",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarabun/v17/DtVhJx26TKEr37c9YHZJmnYI5gnOpg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarabun/v17/DtVnJx26TKEr37c9aBBx_nwMxAzephhN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarabun/v17/DtVmJx26TKEr37c9YNpoulwm6gDXvwE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarabun/v17/DtVkJx26TKEr37c9aBBxUl0s7iLSrwFUlw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarabun/v17/DtVmJx26TKEr37c9YL5rulwm6gDXvwE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sarabun/v17/DtVkJx26TKEr37c9aBBxNl4s7iLSrwFUlw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarabun/v17/DtVjJx26TKEr37c9WBJDnlQN9gk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarabun/v17/DtVhJx26TKEr37c9aBBJmnYI5gnOpg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarabun/v17/DtVmJx26TKEr37c9YOZqulwm6gDXvwE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarabun/v17/DtVkJx26TKEr37c9aBBxbl8s7iLSrwFUlw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarabun/v17/DtVmJx26TKEr37c9YMptulwm6gDXvwE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarabun/v17/DtVkJx26TKEr37c9aBBxQlgs7iLSrwFUlw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sarabun/v17/DtVmJx26TKEr37c9YK5sulwm6gDXvwE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarabun/v17/DtVkJx26TKEr37c9aBBxJlks7iLSrwFUlw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",
$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarabun/v17/DtVmJx26TKEr37c9YLJvulwm6gDXvwE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarabun/v17/DtVkJx26TKEr37c9aBBxOlos7iLSrwFUlw.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sarala",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("91d07807-cc45-437d-a304-88d226c43ea4",-86393282),$APP.$cljs$cst$2675$family$$,"Sarala",$APP.$cljs$cst$725$name$$,"Sarala",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarala/v14/uK_y4riEZv4o1w9RCh0TMv6EXw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarala/v14/uK_x4riEZv4o1w9ptjI3OtWYVkMpXA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-sarina",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("655e30a1-f09d-49e5-8ffd-321a3ef35728",23411105),$APP.$cljs$cst$2675$family$$,"Sarina",$APP.$cljs$cst$725$name$$,"Sarina",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sarina/v25/-F6wfjF3ITQwasLhLkDUriBQxw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sarpanch",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d422e382-5b42-4463-85c4-9208ceab11eb",1773266865),$APP.$cljs$cst$2675$family$$,"Sarpanch",$APP.$cljs$cst$725$name$$,"Sarpanch",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarpanch/v15/hESy6Xt4NCpRuk6Pzh2ARIrX_20n.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarpanch/v15/hES16Xt4NCpRuk6PziV0ba7f1HEuRHkM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarpanch/v15/hES16Xt4NCpRuk6PziVYaq7f1HEuRHkM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sarpanch/v15/hES16Xt4NCpRuk6PziU8a67f1HEuRHkM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarpanch/v15/hES16Xt4NCpRuk6PziUgaK7f1HEuRHkM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,
"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sarpanch/v15/hES16Xt4NCpRuk6PziUEaa7f1HEuRHkM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sassy-frass",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f2a26323-ee2c-4821-9ffa-514cb427c322",-598881032),$APP.$cljs$cst$2675$family$$,"Sassy Frass",$APP.$cljs$cst$725$name$$,"Sassy Frass",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sassyfrass/v9/LhWhMVrGOe0FLb97BjhsE99dGNWQg_am.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-satisfy",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2d1520e1-6d20-4fdd-b5cf-6d2f8a18afb9",
2009478342),$APP.$cljs$cst$2675$family$$,"Satisfy",$APP.$cljs$cst$725$name$$,"Satisfy",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/satisfy/v22/rP2Hp2yn6lkG50LoOZSCHBeHFl0.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-savate",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("91892956-ffc9-4073-a14b-d61a969fcbff",1164409776),$APP.$cljs$cst$2675$family$$,"Savate",$APP.$cljs$cst$725$name$$,"Savate",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",
$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVKSTgjKAqpnvJNP5oQaZzblHkwJTdxRbgJdhapcUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVKSTgjKAqpnvJNP5oQaZzblHkwJelxRbgJdhapcUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVKSTgjKAqpnvJNP5oQaZzblHkwJbdxRbgJdhapcUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVKSTgjKAqpnvJNP5oQaZzblHkwJYVxRbgJdhapcUU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVKSTgjKAqpnvJNP5oQaZzblHkwJWl2RbgJdhapcUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/savate/v5/QdVKSTgjKAqpnvJNP5oQaZzblHkwJVB2RbgJdhapcUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVKSTgjKAqpnvJNP5oQaZzblHkwJTd2RbgJdhapcUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,
"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVKSTgjKAqpnvJNP5oQaZzblHkwJR52RbgJdhapcUU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVISTgjKAqpnvJnNqjvsfWwDtc3MH8yLfsDcjSsYUVUjg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVISTgjKAqpnvJnNqjvsfWwDtc3MH8y8_sDcjSsYUVUjg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVISTgjKAqpnvJnNqjvsfWwDtc3MH8yrfsDcjSsYUVUjg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVISTgjKAqpnvJnNqjvsfWwDtc3MH8yn_sDcjSsYUVUjg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVISTgjKAqpnvJnNqjvsfWwDtc3MH8yc_wDcjSsYUVUjg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVISTgjKAqpnvJnNqjvsfWwDtc3MH8ySvwDcjSsYUVUjg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVISTgjKAqpnvJnNqjvsfWwDtc3MH8yLfwDcjSsYUVUjg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/savate/v5/QdVISTgjKAqpnvJnNqjvsfWwDtc3MH8yBPwDcjSsYUVUjg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sawarabi-gothic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fc66ee2d-feec-4ef1-a706-4c00a9d73d0d",757858736),$APP.$cljs$cst$2675$family$$,"Sawarabi Gothic",$APP.$cljs$cst$725$name$$,"Sawarabi Gothic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sawarabigothic/v16/x3d4ckfVaqqa-BEj-I9mE65u3k3NBSk3E2YljQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sawarabi-mincho",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("46291eeb-ddec-4871-aab6-57b4acba0b6f",
-47485930),$APP.$cljs$cst$2675$family$$,"Sawarabi Mincho",$APP.$cljs$cst$725$name$$,"Sawarabi Mincho",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sawarabimincho/v20/8QIRdiDaitzr7brc8ahpxt6GcIJTLahP46UDUw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-scada",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9681d142-2bc7-4f30-be31-c52b38dbd65c",1257500973),$APP.$cljs$cst$2675$family$$,"Scada",$APP.$cljs$cst$725$name$$,"Scada",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/scada/v16/RLpxK5Pv5qumeWJoxzUobkvv.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/scada/v16/RLp_K5Pv5qumeVJqzTEKa1vvffg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/scada/v16/RLp8K5Pv5qumeVrU6BEgRVfmZOE5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/scada/v16/RLp6K5Pv5qumeVJq9Y0lT1PEYfE5p6g.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-scheherazade-new",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("56f7b2c7-9200-4af9-b7b5-759eb2b9dccc",-519958540),$APP.$cljs$cst$2675$family$$,"Scheherazade New",$APP.$cljs$cst$725$name$$,"Scheherazade New",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/scheherazadenew/v20/4UaZrFhTvxVnHDvUkUiHg8jprP4DCwNsOl4p5Is.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/scheherazadenew/v20/4UaerFhTvxVnHDvUkUiHg8jprP4DM_dFHlYC-IKnoSE.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/scheherazadenew/v20/4UaerFhTvxVnHDvUkUiHg8jprP4DM9tCHlYC-IKnoSE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/scheherazadenew/v20/4UaerFhTvxVnHDvUkUiHg8jprP4DM79DHlYC-IKnoSE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-schibsted-grotesk",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("72c50c25-6e55-42ee-93cf-b90e11dc0c1b",1764905225),$APP.$cljs$cst$2675$family$$,"Schibsted Grotesk",$APP.$cljs$cst$725$name$$,"Schibsted Grotesk",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/schibstedgrotesk/v7/JqzK5SSPQuCQF3t8uOwiUL-taUTtarVKQ9vZ6pJJWlMNIsEAT8JuXFGVOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/schibstedgrotesk/v7/JqzK5SSPQuCQF3t8uOwiUL-taUTtarVKQ9vZ6pJJWlMNEMEAT8JuXFGVOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/schibstedgrotesk/v7/JqzK5SSPQuCQF3t8uOwiUL-taUTtarVKQ9vZ6pJJWlMN_MYAT8JuXFGVOQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/schibstedgrotesk/v7/JqzK5SSPQuCQF3t8uOwiUL-taUTtarVKQ9vZ6pJJWlMNxcYAT8JuXFGVOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/schibstedgrotesk/v7/JqzK5SSPQuCQF3t8uOwiUL-taUTtarVKQ9vZ6pJJWlMNosYAT8JuXFGVOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/schibstedgrotesk/v7/JqzK5SSPQuCQF3t8uOwiUL-taUTtarVKQ9vZ6pJJWlMNi8YAT8JuXFGVOQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/schibstedgrotesk/v7/JqzI5SSPQuCQF3t8uOwiUL-taUTtap9DcSQBg_nT9FQY6oLoDMhqflSFOTXs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/schibstedgrotesk/v7/JqzI5SSPQuCQF3t8uOwiUL-taUTtap9DcSQBg_nT9FQY6oLaDMhqflSFOTXs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/schibstedgrotesk/v7/JqzI5SSPQuCQF3t8uOwiUL-taUTtap9DcSQBg_nT9FQY6oI2C8hqflSFOTXs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/schibstedgrotesk/v7/JqzI5SSPQuCQF3t8uOwiUL-taUTtap9DcSQBg_nT9FQY6oIPC8hqflSFOTXs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/schibstedgrotesk/v7/JqzI5SSPQuCQF3t8uOwiUL-taUTtap9DcSQBg_nT9FQY6oJoC8hqflSFOTXs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/schibstedgrotesk/v7/JqzI5SSPQuCQF3t8uOwiUL-taUTtap9DcSQBg_nT9FQY6oJBC8hqflSFOTXs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-schoolbell",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0977153f-3469-4859-9de6-57f2542a77f7",284657516),$APP.$cljs$cst$2675$family$$,"Schoolbell",$APP.$cljs$cst$725$name$$,"Schoolbell",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/schoolbell/v18/92zQtBZWOrcgoe-fgnJIVxIQ6mRqfiQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-science-gothic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2d6a6034-74c6-4e87-855b-8585af87c905",-1281399668),$APP.$cljs$cst$2675$family$$,"Science Gothic",$APP.$cljs$cst$725$name$$,"Science Gothic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sciencegothic/v5/CHzuV-7EH1X7aiQh5jPNDTJnVUAvhrL0sQdjzDQhk11iTp6mX-ANuf1d_83dPfZJ7Lvcvg8EGYzcW57mXiXiVX33c92fNgmo9KvjVVuc-A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sciencegothic/v5/CHzuV-7EH1X7aiQh5jPNDTJnVUAvhrL0sQdjzDQhk11iTp6mX-ANuf1d_83dPfZJ7Lvcvg8EGYzcW57mXiXiVX33c92ftgio9KvjVVuc-A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sciencegothic/v5/CHzuV-7EH1X7aiQh5jPNDTJnVUAvhrL0sQdjzDQhk11iTp6mX-ANuf1d_83dPfZJ7Lvcvg8EGYzcW57mXiXiVX33c92faAio9KvjVVuc-A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sciencegothic/v5/CHzuV-7EH1X7aiQh5jPNDTJnVUAvhrL0sQdjzDQhk11iTp6mX-ANuf1d_83dPfZJ7Lvcvg8EGYzcW57mXiXiVX33c92fNgio9KvjVVuc-A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sciencegothic/v5/CHzuV-7EH1X7aiQh5jPNDTJnVUAvhrL0sQdjzDQhk11iTp6mX-ANuf1d_83dPfZJ7Lvcvg8EGYzcW57mXiXiVX33c92fBAio9KvjVVuc-A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sciencegothic/v5/CHzuV-7EH1X7aiQh5jPNDTJnVUAvhrL0sQdjzDQhk11iTp6mX-ANuf1d_83dPfZJ7Lvcvg8EGYzcW57mXiXiVX33c92f6A-o9KvjVVuc-A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sciencegothic/v5/CHzuV-7EH1X7aiQh5jPNDTJnVUAvhrL0sQdjzDQhk11iTp6mX-ANuf1d_83dPfZJ7Lvcvg8EGYzcW57mXiXiVX33c92f0Q-o9KvjVVuc-A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,
"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sciencegothic/v5/CHzuV-7EH1X7aiQh5jPNDTJnVUAvhrL0sQdjzDQhk11iTp6mX-ANuf1d_83dPfZJ7Lvcvg8EGYzcW57mXiXiVX33c92ftg-o9KvjVVuc-A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sciencegothic/v5/CHzuV-7EH1X7aiQh5jPNDTJnVUAvhrL0sQdjzDQhk11iTp6mX-ANuf1d_83dPfZJ7Lvcvg8EGYzcW57mXiXiVX33c92fnw-o9KvjVVuc-A.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-scope-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4702baf4-3e7c-48f5-a38e-6a1e81f9a3e1",1611861202),$APP.$cljs$cst$2675$family$$,"Scope One",$APP.$cljs$cst$725$name$$,"Scope One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/scopeone/v15/WBLnrEXKYFlGHrOKmGD1W0_MJMGxiQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-seaweed-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fdcb3918-beb0-49d7-8866-a4f64df1e9f1",-2086873324),$APP.$cljs$cst$2675$family$$,"Seaweed Script",$APP.$cljs$cst$725$name$$,"Seaweed Script",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/seaweedscript/v17/bx6cNx6Tne2pxOATYE8C_Rsoe0WJ-KcGVbLW.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-secular-one",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b0405522-c29c-4071-82c8-7bf67bd7208f",-1717788212),$APP.$cljs$cst$2675$family$$,"Secular One",$APP.$cljs$cst$725$name$$,"Secular One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/secularone/v14/8QINdiTajsj_87rMuMdKypDlMul7LJpK.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sedan",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1324bb17-9ba8-42dd-b2ff-eb64cdccee02",1444065550),$APP.$cljs$cst$2675$family$$,"Sedan",$APP.$cljs$cst$725$name$$,"Sedan",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sedan/v1/Yq6a-L-VVyD6-eOSiTpovf5b.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sedan/v1/Yq6U-L-VVyD6-dOQgz5KuO5bjxE.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sedan-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3bce6224-04d4-49e7-af1e-ac67a9493fe9",1774449578),$APP.$cljs$cst$2675$family$$,"Sedan SC",$APP.$cljs$cst$725$name$$,"Sedan SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sedansc/v2/yMJRMIlvYZ3Jn1Y30Dq8fSx5i814.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sedgwick-ave",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e3d9a214-02a9-4176-82d2-b1772cef73ed",-377549995),$APP.$cljs$cst$2675$family$$,"Sedgwick Ave",$APP.$cljs$cst$725$name$$,"Sedgwick Ave",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sedgwickave/v13/uK_04rKEYuguzAcSYRdWTJq8Xmg1Vcf5JA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sedgwick-ave-display",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4801fc45-0704-4e5a-9b62-46ced3ec4299",949841397),$APP.$cljs$cst$2675$family$$,"Sedgwick Ave Display",$APP.$cljs$cst$725$name$$,"Sedgwick Ave Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sedgwickavedisplay/v23/xfuu0XPgU3jZPUoUo3ScvmPi-NapQ8OxM2czd-YnOzUD.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sen",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0f72398a-7885-4e7e-8f23-9a0967e48a23",-1184271545),$APP.$cljs$cst$2675$family$$,"Sen",$APP.$cljs$cst$725$name$$,"Sen",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sen/v12/6xK0dSxYI9_dkN18-vZKK2EISCq5H47KlD9q78A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sen/v12/6xK0dSxYI9_dkN18-vZKK2EISBi5H47KlD9q78A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sen/v12/6xK0dSxYI9_dkN18-vZKK2EISPS-H47KlD9q78A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sen/v12/6xK0dSxYI9_dkN18-vZKK2EISM2-H47KlD9q78A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sen/v12/6xK0dSxYI9_dkN18-vZKK2EISKq-H47KlD9q78A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-send-flowers",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f10f305a-7504-403b-964a-4f79ce92267f",-622238761),$APP.$cljs$cst$2675$family$$,"Send Flowers",$APP.$cljs$cst$725$name$$,"Send Flowers",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sendflowers/v7/If2PXTjtZS-0Xqy13uCQSULvxwjjouU1iw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sevillana",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("323fd15a-401a-434f-814f-76cd46a88ac5",-1696759091),$APP.$cljs$cst$2675$family$$,"Sevillana",$APP.$cljs$cst$725$name$$,"Sevillana",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sevillana/v25/KFOlCnWFscmDt1Bfiy1vAx05IsDqlA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-seymour-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("251c9b28-9d49-45e1-865d-5e4e21182bf9",
-1349856094),$APP.$cljs$cst$2675$family$$,"Seymour One",$APP.$cljs$cst$725$name$$,"Seymour One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/seymourone/v25/4iCp6Khla9xbjQpoWGGd0myIPYBvgpUI.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-shadows-into-light",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2baa0232-6355-4d66-9b51-6feb7a58d9f4",448524694),$APP.$cljs$cst$2675$family$$,"Shadows Into Light",$APP.$cljs$cst$725$name$$,"Shadows Into Light",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shadowsintolight/v22/UqyNK9UOIntux_czAvDQx_ZcHqZXBNQDcsr4xzSMYA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-shadows-into-light-two",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ae800175-511d-411a-a3dc-f35976577ab7",1867505535),$APP.$cljs$cst$2675$family$$,"Shadows Into Light Two",
$APP.$cljs$cst$725$name$$,"Shadows Into Light Two",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shadowsintolighttwo/v19/4iC86LVlZsRSjQhpWGedwyOoW-0A6_kpsyNmlAvNGLNnIF0.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-shafarik",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d0e4397c-2bf8-434c-ad07-31139f67214a",-1274639733),$APP.$cljs$cst$2675$family$$,"Shafarik",$APP.$cljs$cst$725$name$$,"Shafarik",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shafarik/v3/RWmLoKaF7PojpZXlW52sbsHKqLkD.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-shalimar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e20b118a-b9af-4337-9286-fee0ed891be1",1585909753),$APP.$cljs$cst$2675$family$$,"Shalimar",$APP.$cljs$cst$725$name$$,"Shalimar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shalimar/v9/uU9MCBoE6I6iNWFUvTPx8PCOg0uX.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-shantell-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a93c3f05-3758-48c7-a3e7-8e9b1cec2762",
-1715639219),$APP.$cljs$cst$2675$family$$,"Shantell Sans",$APP.$cljs$cst$725$name$$,"Shantell Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shantellsans/v13/FeUaS0pCoLIo-lcdY7kjvNoQqWVWB0qWpl29ajppTuUTu_kJKmHesPOL-maYi4xZeHCNQ09eBlmv2QcUzJ39-rAISYQiS2i2yPwxjyRN.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shantellsans/v13/FeUaS0pCoLIo-lcdY7kjvNoQqWVWB0qWpl29ajppTuUTu_kJKmHesPOL-maYi4xZeHCNQ09eBlmv2QcUzJ39-rAISYR8S2i2yPwxjyRN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shantellsans/v13/FeUaS0pCoLIo-lcdY7kjvNoQqWVWB0qWpl29ajppTuUTu_kJKmHesPOL-maYi4xZeHCNQ09eBlmv2QcUzJ39-rAISYROS2i2yPwxjyRN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shantellsans/v13/FeUaS0pCoLIo-lcdY7kjvNoQqWVWB0qWpl29ajppTuUTu_kJKmHesPOL-maYi4xZeHCNQ09eBlmv2QcUzJ39-rAISYSiTGi2yPwxjyRN.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shantellsans/v13/FeUaS0pCoLIo-lcdY7kjvNoQqWVWB0qWpl29ajppTuUTu_kJKmHesPOL-maYi4xZeHCNQ09eBlmv2QcUzJ39-rAISYSbTGi2yPwxjyRN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,
"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shantellsans/v13/FeUaS0pCoLIo-lcdY7kjvNoQqWVWB0qWpl29ajppTuUTu_kJKmHesPOL-maYi4xZeHCNQ09eBlmv2QcUzJ39-rAISYT8TGi2yPwxjyRN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shantellsans/v13/FeUcS0pCoLIo-lcdY7kjvNoQg2xkycTqsuA6bi9pTt8YiT-NXidjb_ee-maigL6R8nKVh8BbE1mv4wwmM0WUkSqmTpG0CN71wvgTijRNYgQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shantellsans/v13/FeUcS0pCoLIo-lcdY7kjvNoQg2xkycTqsuA6bi9pTt8YiT-NXidjb_ee-maigL6R8nKVh8BbE1mv4wwmM0WUkSqmTpG0CID1wvgTijRNYgQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,
"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shantellsans/v13/FeUcS0pCoLIo-lcdY7kjvNoQg2xkycTqsuA6bi9pTt8YiT-NXidjb_ee-maigL6R8nKVh8BbE1mv4wwmM0WUkSqmTpG0CLL1wvgTijRNYgQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shantellsans/v13/FeUcS0pCoLIo-lcdY7kjvNoQg2xkycTqsuA6bi9pTt8YiT-NXidjb_ee-maigL6R8nKVh8BbE1mv4wwmM0WUkSqmTpG0CF7ywvgTijRNYgQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shantellsans/v13/FeUcS0pCoLIo-lcdY7kjvNoQg2xkycTqsuA6bi9pTt8YiT-NXidjb_ee-maigL6R8nKVh8BbE1mv4wwmM0WUkSqmTpG0CGfywvgTijRNYgQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,
"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shantellsans/v13/FeUcS0pCoLIo-lcdY7kjvNoQg2xkycTqsuA6bi9pTt8YiT-NXidjb_ee-maigL6R8nKVh8BbE1mv4wwmM0WUkSqmTpG0CADywvgTijRNYgQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-shanti",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c719c879-630a-4399-8d46-cfb959332072",-295137952),$APP.$cljs$cst$2675$family$$,
"Shanti",$APP.$cljs$cst$725$name$$,"Shanti",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shanti/v25/t5thIREMM4uSDgzgU0ezpKfwzA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-share",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1aefc087-4399-422a-a42c-47cafe9c1ede",-2105062470),$APP.$cljs$cst$2675$family$$,"Share",$APP.$cljs$cst$725$name$$,"Share",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/share/v20/i7dEIFliZjKNF5VNHLq2cV5d.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/share/v20/i7dKIFliZjKNF6VPFr6UdE5dWFM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/share/v20/i7dJIFliZjKNF63xM56-WkJUQUq7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/share/v20/i7dPIFliZjKNF6VPLgK7UEZ2RFq7AwU.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-share-tech",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f384c7d0-3734-4fc3-80c5-605e14df97e2",1484736713),$APP.$cljs$cst$2675$family$$,"Share Tech",$APP.$cljs$cst$725$name$$,"Share Tech",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sharetech/v23/7cHtv4Uyi5K0OeZ7bohUwHoDmTcibrA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-share-tech-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4f1ac7ee-a666-4fd4-adc2-2f2915f6f5a1",-1909943213),$APP.$cljs$cst$2675$family$$,"Share Tech Mono",$APP.$cljs$cst$725$name$$,"Share Tech Mono",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sharetechmono/v16/J7aHnp1uDWRBEqV98dVQztYldFc7pAsEIc3Xew.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-shippori-antique",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1b2fa469-f90c-4205-b292-77085eda768a",-1350278022),$APP.$cljs$cst$2675$family$$,"Shippori Antique",$APP.$cljs$cst$725$name$$,"Shippori Antique",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shipporiantique/v11/-F6qfid3KC8pdMyzR0qRyFUht11v8ldPg-IUDNg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-shippori-antique-b1",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7c4cc47d-94a3-4ccb-b285-9c206483443b",456900245),$APP.$cljs$cst$2675$family$$,"Shippori Antique B1",$APP.$cljs$cst$725$name$$,"Shippori Antique B1",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shipporiantiqueb1/v11/2Eb7L_JwClR7Zl_UAKZ0mUHw3oMKd40grRFCj9-5Y8Y.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-shippori-mincho",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("9483cc65-2234-4d48-8738-960d7d135f27",189594540),$APP.$cljs$cst$2675$family$$,"Shippori Mincho",$APP.$cljs$cst$725$name$$,"Shippori Mincho",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/shipporimincho/v17/VdGGAZweH5EbgHY6YExcZfDoj0BA2_-C7LoS7g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shipporimincho/v17/VdGDAZweH5EbgHY6YExcZfDoj0B4L9am5JEO5--2zg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shipporimincho/v17/VdGDAZweH5EbgHY6YExcZfDoj0B4A9Gm5JEO5--2zg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shipporimincho/v17/VdGDAZweH5EbgHY6YExcZfDoj0B4Z9Cm5JEO5--2zg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shipporimincho/v17/VdGDAZweH5EbgHY6YExcZfDoj0B4e9Om5JEO5--2zg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-shippori-mincho-b1",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e9e95d4c-fe8f-4ecb-8063-7a37704ac649",
-1404685067),$APP.$cljs$cst$2675$family$$,"Shippori Mincho B1",$APP.$cljs$cst$725$name$$,"Shippori Mincho B1",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shipporiminchob1/v24/wXK2E2wCr44tulPdnn-xbIpJ9RgT9-nyjqBr1lO97Q.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shipporiminchob1/v24/wXK1E2wCr44tulPdnn-xbIpJ9RgT9-nKeolP3nih5H4Uug.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shipporiminchob1/v24/wXK1E2wCr44tulPdnn-xbIpJ9RgT9-nKVo5P3nih5H4Uug.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shipporiminchob1/v24/wXK1E2wCr44tulPdnn-xbIpJ9RgT9-nKMo9P3nih5H4Uug.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shipporiminchob1/v24/wXK1E2wCr44tulPdnn-xbIpJ9RgT9-nKLoxP3nih5H4Uug.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-shizuru",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("764bb984-8746-466a-8088-1d7a6ca3df5c",2129269352),$APP.$cljs$cst$2675$family$$,"Shizuru",$APP.$cljs$cst$725$name$$,
"Shizuru",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shizuru/v13/O4ZSFGfvnxFiCA3i30IJlgUTj2A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-shojumaru",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bc615ebb-450f-458c-8a7e-cc80f9e73c5e",-541068163),$APP.$cljs$cst$2675$family$$,"Shojumaru",$APP.$cljs$cst$725$name$$,"Shojumaru",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shojumaru/v16/rax_HiWfutkLLnaKCtlMBBJek0vA8A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-short-stack",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("52441ac4-1193-4bf3-803f-80c0d0a4afab",1983866119),$APP.$cljs$cst$2675$family$$,"Short Stack",$APP.$cljs$cst$725$name$$,"Short Stack",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shortstack/v16/bMrzmS2X6p0jZC6EcmPFX-SScX8D0nq6.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-shrikhand",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c04de12d-3608-4edd-af4f-fe26f3f28eb4",1213449827),
$APP.$cljs$cst$2675$family$$,"Shrikhand",$APP.$cljs$cst$725$name$$,"Shrikhand",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/shrikhand/v17/a8IbNovtLWfR7T7bMJwbBIiQ0zhMtA.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-siemreap",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6976365a-afd1-42c7-96b5-9b327d1a1c82",420943771),$APP.$cljs$cst$2675$family$$,"Siemreap",$APP.$cljs$cst$725$name$$,"Siemreap",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/siemreap/v30/Gg82N5oFbgLvHAfNl2YbnA8DLXpe.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sigmar",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("084d809c-af7d-43fd-b1ac-b5fae4da3879",-1462511368),$APP.$cljs$cst$2675$family$$,"Sigmar",$APP.$cljs$cst$725$name$$,"Sigmar",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sigmar/v9/hv-XlzJgIE8a85pUbWY3MTFgVg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sigmar-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("06287ea7-11a0-49f2-81c5-0285352a7299",
1373698203),$APP.$cljs$cst$2675$family$$,"Sigmar One",$APP.$cljs$cst$725$name$$,"Sigmar One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sigmarone/v20/co3DmWZ8kjZuErj9Ta3dk6Pjp3Di8U0.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-signika",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9b862a0a-1dd9-4208-ae23-e8268c54ecda",784010521),$APP.$cljs$cst$2675$family$$,"Signika",$APP.$cljs$cst$725$name$$,"Signika",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/signika/v29/vEF72_JTCgwQ5ejvMV0Ox_Kg1UwJ0tKfX4zNpD8E4ASzH1r93zuYzTMngt4xjw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/signika/v29/vEF72_JTCgwQ5ejvMV0Ox_Kg1UwJ0tKfX4zNpD8E4ASzH1r9gTuYzTMngt4xjw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/signika/v29/vEF72_JTCgwQ5ejvMV0Ox_Kg1UwJ0tKfX4zNpD8E4ASzH1r9szuYzTMngt4xjw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/signika/v29/vEF72_JTCgwQ5ejvMV0Ox_Kg1UwJ0tKfX4zNpD8E4ASzH1r9XzyYzTMngt4xjw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/signika/v29/vEF72_JTCgwQ5ejvMV0Ox_Kg1UwJ0tKfX4zNpD8E4ASzH1r9ZjyYzTMngt4xjw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-signika-negative",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("700dadb7-e5e3-46a9-a8e4-0f27aa6515e5",-636051988),$APP.$cljs$cst$2675$family$$,"Signika Negative",$APP.$cljs$cst$725$name$$,"Signika Negative",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/signikanegative/v26/E21x_cfngu7HiRpPX3ZpNE4kY5zKSPmJXkF0VDD2RAr5S73st9hiuEq8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/signikanegative/v26/E21x_cfngu7HiRpPX3ZpNE4kY5zKSPmJXkF0VDD2RAqnS73st9hiuEq8.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/signikanegative/v26/E21x_cfngu7HiRpPX3ZpNE4kY5zKSPmJXkF0VDD2RAqVS73st9hiuEq8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/signikanegative/v26/E21x_cfngu7HiRpPX3ZpNE4kY5zKSPmJXkF0VDD2RAp5TL3st9hiuEq8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/signikanegative/v26/E21x_cfngu7HiRpPX3ZpNE4kY5zKSPmJXkF0VDD2RApATL3st9hiuEq8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-silkscreen",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bbe46be1-a9e4-462d-895b-5add2f50ac60",-34039095),$APP.$cljs$cst$2675$family$$,"Silkscreen",$APP.$cljs$cst$725$name$$,"Silkscreen",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/silkscreen/v6/m8JXjfVPf62XiF7kO-i9ULRvamODxdI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/silkscreen/v6/m8JUjfVPf62XiF7kO-i9aAhATmuo2dudFvc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-simonetta",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("60ffc11c-1d2e-4a7c-bd84-0180f602b773",1858671940),$APP.$cljs$cst$2675$family$$,"Simonetta",$APP.$cljs$cst$725$name$$,"Simonetta",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/simonetta/v29/x3dickHVYrCU5BU15c4BfPACvy_1BA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/simonetta/v29/x3dkckHVYrCU5BU15c4xfvoGnSrlBBsy.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,
"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/simonetta/v29/x3dnckHVYrCU5BU15c45-N0mtwTpDQIrGg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/simonetta/v29/x3d5ckHVYrCU5BU15c4xfsKCsA7tLwc7Gn88.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-single-day",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cb35e868-5bdc-47af-a1bb-126b0e41a116",175972138),$APP.$cljs$cst$2675$family$$,"Single Day",$APP.$cljs$cst$725$name$$,"Single Day",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/singleday/v19/LYjHdGDjlEgoAcF95EI5jVoFUNfeQJU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sintony",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2e3254ed-0ca3-4874-b3b1-9c48ca938f30",1225563354),$APP.$cljs$cst$2675$family$$,"Sintony",$APP.$cljs$cst$725$name$$,"Sintony",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sintony/v17/XoHm2YDqR7-98cVUITQnu98ojjs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sintony/v17/XoHj2YDqR7-98cVUGYgIn9cDkjLp6C8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sirin-stencil",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4c76f381-8797-4389-a439-04a700671f94",942293260),$APP.$cljs$cst$2675$family$$,"Sirin Stencil",$APP.$cljs$cst$725$name$$,"Sirin Stencil",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sirinstencil/v27/mem4YaWwznmLx-lzGfN7MdRydchGBq6al6o.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sirivennela",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("85f0461f-d57d-4396-b174-1497c578741f",-400053555),
$APP.$cljs$cst$2675$family$$,"Sirivennela",$APP.$cljs$cst$725$name$$,"Sirivennela",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sirivennela/v2/kmK5Zq0oHhbAYX-X6lgptg7YiOFDtqtf.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-six-caps",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("025f7bf1-4d38-417b-8f52-fa1b51b833e4",-1858751145),$APP.$cljs$cst$2675$family$$,"Six Caps",$APP.$cljs$cst$725$name$$,"Six Caps",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sixcaps/v23/6ae_4KGrU7VR7bNmabcS9XXaPCop.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sixtyfour",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bba1122c-79d8-440f-87bb-1ce70d7e7076",1140743767),$APP.$cljs$cst$2675$family$$,"Sixtyfour",$APP.$cljs$cst$725$name$$,"Sixtyfour",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sixtyfour/v3/OD5vuMCT1numDm3nakXtp2h4jg463t9haG_3mBkVsV20uFT3BAE5f73YnyS5ZuOV.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sixtyfour-convergence",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("edece25b-1087-4137-808b-0113b8563ae5",281702269),$APP.$cljs$cst$2675$family$$,"Sixtyfour Convergence",$APP.$cljs$cst$725$name$$,"Sixtyfour Convergence",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sixtyfourconvergence/v5/m8IQjepPf7mIglv5K__zM9srGA7wurbybZMfZsqG2Q6EWlJro5FJSJ4acT9PoOPwGgieaK7zkSpdXP-GrR9Yw9Tg7E4HGLbUKPlOh102hotkk3grz3g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-skranji",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4c33266e-c38b-4c50-8cb2-e649620d81d7",860634482),$APP.$cljs$cst$2675$family$$,"Skranji",$APP.$cljs$cst$725$name$$,"Skranji",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/skranji/v14/OZpDg_dtriVFNerMYzuuklTm3Ek.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/skranji/v14/OZpGg_dtriVFNerMW4eBtlzNwED-b4g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-slabo-13px",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("270249bf-ed74-4730-a153-09ee94dd9ad6",825009022),$APP.$cljs$cst$2675$family$$,"Slabo 13px",$APP.$cljs$cst$725$name$$,"Slabo 13px",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/slabo13px/v17/11hEGp_azEvXZUdSBzzRcKer2wkYnvI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-slabo-27px",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("04103dcf-4a4e-4622-b957-4aafea84350d",1546376141),$APP.$cljs$cst$2675$family$$,
"Slabo 27px",$APP.$cljs$cst$725$name$$,"Slabo 27px",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/slabo27px/v16/mFT0WbgBwKPR_Z4hGN2qsxgJ1EJ7i90.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-slackey",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("006ca820-5def-40d4-885b-29a7dcfc58f1",1872543252),$APP.$cljs$cst$2675$family$$,"Slackey",$APP.$cljs$cst$725$name$$,"Slackey",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/slackey/v29/N0bV2SdQO-5yM0-dKlRaJdbWgdY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-slackside-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8eaf4f31-41bf-480d-886c-454a26de00c4",1565909463),$APP.$cljs$cst$2675$family$$,"Slackside One",$APP.$cljs$cst$725$name$$,"Slackside One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/slacksideone/v14/EJRQQgMrXdcGsiBuvnRxodTwVy7VocNB6Iw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-smokum",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8c77f363-9e8f-46ce-8a2c-a601dcfefe93",1651359150),
$APP.$cljs$cst$2675$family$$,"Smokum",$APP.$cljs$cst$725$name$$,"Smokum",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/smokum/v30/TK3iWkUbAhopmrdGHjUHte5fKg.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-smooch",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6340835e-0f81-4c5a-8737-a811ef2c698e",-719613633),$APP.$cljs$cst$2675$family$$,"Smooch",$APP.$cljs$cst$725$name$$,"Smooch",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/smooch/v9/o-0LIps4xW8U1xUBjqp_6hVdYg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-smooch-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5ec01b43-7529-4179-8b64-93ff1911d0a8",938183110),$APP.$cljs$cst$2675$family$$,"Smooch Sans",$APP.$cljs$cst$725$name$$,"Smooch Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/smoochsans/v15/c4mz1n5uGsXss2LJh1QH6b129FZvxPj6I4oiwUFodqIeNlzayg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/smoochsans/v15/c4mz1n5uGsXss2LJh1QH6b129FZvxPj6I4oiQUBodqIeNlzayg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/smoochsans/v15/c4mz1n5uGsXss2LJh1QH6b129FZvxPj6I4oin0BodqIeNlzayg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/smoochsans/v15/c4mz1n5uGsXss2LJh1QH6b129FZvxPj6I4oiwUBodqIeNlzayg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/smoochsans/v15/c4mz1n5uGsXss2LJh1QH6b129FZvxPj6I4oi80BodqIeNlzayg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/smoochsans/v15/c4mz1n5uGsXss2LJh1QH6b129FZvxPj6I4oiH0dodqIeNlzayg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/smoochsans/v15/c4mz1n5uGsXss2LJh1QH6b129FZvxPj6I4oiJkdodqIeNlzayg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/smoochsans/v15/c4mz1n5uGsXss2LJh1QH6b129FZvxPj6I4oiQUdodqIeNlzayg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/smoochsans/v15/c4mz1n5uGsXss2LJh1QH6b129FZvxPj6I4oiaEdodqIeNlzayg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-smythe",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c3695d84-37ad-4d4a-8e02-c4d88a2ef59e",1803846807),$APP.$cljs$cst$2675$family$$,"Smythe",$APP.$cljs$cst$725$name$$,
"Smythe",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/smythe/v24/MwQ3bhT01--coT1BOLh_uGInjA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-sniglet",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d6bd1bef-be2d-4080-8efd-3349be72e1f2",-341000189),$APP.$cljs$cst$2675$family$$,"Sniglet",$APP.$cljs$cst$725$name$$,"Sniglet",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sniglet/v18/cIf9MaFLtkE3UjaJxCmrYGkHgIs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sniglet/v18/cIf4MaFLtkE3UjaJ_ImHRGEsnIJkWL4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-snippet",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a7963c13-d0f0-4470-b8a2-b0404e39c41c",
-1993016415),$APP.$cljs$cst$2675$family$$,"Snippet",$APP.$cljs$cst$725$name$$,"Snippet",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/snippet/v21/bWt47f7XfQH9Gupu2v_Afcp9QWc.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-snowburst-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("da4b7c2e-b086-4704-87cf-892ebea3d40e",-1270104082),$APP.$cljs$cst$2675$family$$,"Snowburst One",$APP.$cljs$cst$725$name$$,"Snowburst One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/snowburstone/v21/MQpS-WezKdujBsXY3B7I-UT7eZ-UPyacPbo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sofadi-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b645c00e-9860-4343-a4be-26144092230c",280950191),$APP.$cljs$cst$2675$family$$,"Sofadi One",$APP.$cljs$cst$725$name$$,"Sofadi One",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofadione/v22/JIA2UVBxdnVBuElZaMFGcDOIETkmYDU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-sofia",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("971215d8-b7a6-4661-94b6-a45e6949788d",607539273),$APP.$cljs$cst$2675$family$$,"Sofia",$APP.$cljs$cst$725$name$$,"Sofia",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sofia/v15/8QIHdirahM3j_vu-sowsrqjk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sofia-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9552879d-87da-416d-9064-43b94045031b",52753881),$APP.$cljs$cst$2675$family$$,"Sofia Sans",$APP.$cljs$cst$725$name$$,"Sofia Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6E-LCVXSLy9uPBwlAThu1SY8Cx8rlT69B6sa3trvKCXl8k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6E-LCVXSLy9uPBwlAThu1SY8Cx8rlT69D6sK3trvKCXl8k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6E-LCVXSLy9uPBwlAThu1SY8Cx8rlT69AksK3trvKCXl8k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6E-LCVXSLy9uPBwlAThu1SY8Cx8rlT69B6sK3trvKCXl8k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6E-LCVXSLy9uPBwlAThu1SY8Cx8rlT69BIsK3trvKCXl8k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6E-LCVXSLy9uPBwlAThu1SY8Cx8rlT69Ckt63trvKCXl8k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6E-LCVXSLy9uPBwlAThu1SY8Cx8rlT69Cdt63trvKCXl8k.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6E-LCVXSLy9uPBwlAThu1SY8Cx8rlT69D6t63trvKCXl8k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6E-LCVXSLy9uPBwlAThu1SY8Cx8rlT69DTt63trvKCXl8k.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6G-LCVXSLy9uPBwlATrORgnBjYmSP97MWy80WvpPagW08kdLY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6G-LCVXSLy9uPBwlATrORgnBjYmSP97MWy88WupPagW08kdLY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sofiasans/v20/Yq6G-LCVXSLy9uPBwlATrORgnBjYmSP97MWy8xuupPagW08kdLY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6G-LCVXSLy9uPBwlATrORgnBjYmSP97MWy80WupPagW08kdLY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6G-LCVXSLy9uPBwlATrORgnBjYmSP97MWy83eupPagW08kdLY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6G-LCVXSLy9uPBwlATrORgnBjYmSP97MWy85uppPagW08kdLY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6G-LCVXSLy9uPBwlATrORgnBjYmSP97MWy86KppPagW08kdLY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6G-LCVXSLy9uPBwlATrORgnBjYmSP97MWy88WppPagW08kdLY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasans/v20/Yq6G-LCVXSLy9uPBwlATrORgnBjYmSP97MWy8-yppPagW08kdLY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-sofia-sans-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("db63916a-2495-4b1c-80f4-ee086efb3c15",-1850484230),$APP.$cljs$cst$2675$family$$,"Sofia Sans Condensed",$APP.$cljs$cst$725$name$$,"Sofia Sans Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r05xGKVS5aVKd567NYXawnFKJaTtoAuLnK0EjiAN5s9CZwUqh-Csl8QO3OfwQQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r05xGKVS5aVKd567NYXawnFKJaTtoAuLnK0EjiAN5s9CZwUqB-Gsl8QO3OfwQQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r05xGKVS5aVKd567NYXawnFKJaTtoAuLnK0EjiAN5s9CZwUq2eGsl8QO3OfwQQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r05xGKVS5aVKd567NYXawnFKJaTtoAuLnK0EjiAN5s9CZwUqh-Gsl8QO3OfwQQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r05xGKVS5aVKd567NYXawnFKJaTtoAuLnK0EjiAN5s9CZwUqteGsl8QO3OfwQQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r05xGKVS5aVKd567NYXawnFKJaTtoAuLnK0EjiAN5s9CZwUqWeasl8QO3OfwQQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r05xGKVS5aVKd567NYXawnFKJaTtoAuLnK0EjiAN5s9CZwUqYOasl8QO3OfwQQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r05xGKVS5aVKd567NYXawnFKJaTtoAuLnK0EjiAN5s9CZwUqB-asl8QO3OfwQQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r05xGKVS5aVKd567NYXawnFKJaTtoAuLnK0EjiAN5s9CZwUqLuasl8QO3OfwQQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r053GKVS5aVKd567NYXawnFKJaTtoAuLnIcNvN_Vj6TYyQI_T6JE1c4K_uLgQZ_3.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r053GKVS5aVKd567NYXawnFKJaTtoAuLnIcNvN_Vj6TYyQI_T6LE1M4K_uLgQZ_3.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r053GKVS5aVKd567NYXawnFKJaTtoAuLnIcNvN_Vj6TYyQI_T6Ia1M4K_uLgQZ_3.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r053GKVS5aVKd567NYXawnFKJaTtoAuLnIcNvN_Vj6TYyQI_T6JE1M4K_uLgQZ_3.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r053GKVS5aVKd567NYXawnFKJaTtoAuLnIcNvN_Vj6TYyQI_T6J21M4K_uLgQZ_3.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r053GKVS5aVKd567NYXawnFKJaTtoAuLnIcNvN_Vj6TYyQI_T6Ka084K_uLgQZ_3.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r053GKVS5aVKd567NYXawnFKJaTtoAuLnIcNvN_Vj6TYyQI_T6Kj084K_uLgQZ_3.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r053GKVS5aVKd567NYXawnFKJaTtoAuLnIcNvN_Vj6TYyQI_T6LE084K_uLgQZ_3.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,
"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanscondensed/v6/r053GKVS5aVKd567NYXawnFKJaTtoAuLnIcNvN_Vj6TYyQI_T6Lt084K_uLgQZ_3.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sofia-sans-extra-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b1ce5db6-4ef4-4736-813e-9f3b8930b991",1109340226),$APP.$cljs$cst$2675$family$$,"Sofia Sans Extra Condensed",$APP.$cljs$cst$725$name$$,"Sofia Sans Extra Condensed",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxdHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0d6iDr-MD5Si9NGLmmmEfzmM356GxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxdHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0d6iDr-MD5Si9NGLGmiEfzmM356GxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxdHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0d6iDr-MD5Si9NGLxGiEfzmM356GxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxdHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0d6iDr-MD5Si9NGLmmiEfzmM356GxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxdHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0d6iDr-MD5Si9NGLqGiEfzmM356GxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxdHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0d6iDr-MD5Si9NGLRG-EfzmM356GxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxdHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0d6iDr-MD5Si9NGLfW-EfzmM356GxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxdHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0d6iDr-MD5Si9NGLGm-EfzmM356GxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxdHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0d6iDr-MD5Si9NGLM2-EfzmM356GxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxfHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0fSrPEBUZv84WtaeUitsPTOI_ZuWxFXe.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxfHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0fSrPEBUZv84WtaeUivsPDOI_ZuWxFXe.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxfHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0fSrPEBUZv84WtaeUisyPDOI_ZuWxFXe.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxfHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0fSrPEBUZv84WtaeUitsPDOI_ZuWxFXe.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxfHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0fSrPEBUZv84WtaeUitePDOI_ZuWxFXe.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxfHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0fSrPEBUZv84WtaeUiuyOzOI_ZuWxFXe.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxfHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0fSrPEBUZv84WtaeUiuLOzOI_ZuWxFXe.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxfHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0fSrPEBUZv84WtaeUivsOzOI_ZuWxFXe.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,
"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasansextracondensed/v6/raxfHjafvdAIOju4GcIfJH0i7zi50X3zRtuLNiMS0fSrPEBUZv84WtaeUivFOzOI_ZuWxFXe.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sofia-sans-semi-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("07e03ab7-1ea6-4be1-acc3-b7a2630cc8ea",1300828499),$APP.$cljs$cst$2675$family$$,"Sofia Sans Semi Condensed",$APP.$cljs$cst$725$name$$,
"Sofia Sans Semi Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kOlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURm28cA7YLHsIVvoobEO9TGahllIhN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kOlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURm28cA7YLHsIVvoqbEe9TGahllIhN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kOlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURm28cA7YLHsIVvopFEe9TGahllIhN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kOlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURm28cA7YLHsIVvoobEe9TGahllIhN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kOlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURm28cA7YLHsIVvoopEe9TGahllIhN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kOlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURm28cA7YLHsIVvorFFu9TGahllIhN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kOlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURm28cA7YLHsIVvor8Fu9TGahllIhN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kOlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURm28cA7YLHsIVvoqbFu9TGahllIhN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kOlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURm28cA7YLHsIVvoqyFu9TGahllIhN.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kMlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURsWYu_G5idVi7uZ_TUgcRE6xHkZhNeas.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kMlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURsWYu_G5idVi7uZ_TUocQE6xHkZhNeas.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kMlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURsWYu_G5idVi7uZ_TUlkQE6xHkZhNeas.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kMlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURsWYu_G5idVi7uZ_TUgcQE6xHkZhNeas.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kMlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURsWYu_G5idVi7uZ_TUjUQE6xHkZhNeas.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kMlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURsWYu_G5idVi7uZ_TUtkXE6xHkZhNeas.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kMlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURsWYu_G5idVi7uZ_TUuAXE6xHkZhNeas.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kMlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURsWYu_G5idVi7uZ_TUocXE6xHkZhNeas.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,
"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sofiasanssemicondensed/v8/46kMlaPnUDrQoNsWDCGXXxYlujh5Wv0nwP4RwxURsWYu_G5idVi7uZ_TUq4XE6xHkZhNeas.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-solitreo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1d880623-b827-4534-8375-1a37d3105839",-1470912038),$APP.$cljs$cst$2675$family$$,"Solitreo",$APP.$cljs$cst$725$name$$,"Solitreo",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/solitreo/v2/r05YGLlS5a9KYsyNO8upyDYtStiJ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-solway",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("9e4b874c-5401-4984-987d-a45b60f9302c",1887555115),$APP.$cljs$cst$2675$family$$,"Solway",$APP.$cljs$cst$725$name$$,"Solway",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/solway/v19/AMOTz46Cs2uTAOCuLlgZms0QW3mqyg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/solway/v19/AMOQz46Cs2uTAOCWgnA9kuYMUg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/solway/v19/AMOTz46Cs2uTAOCudlkZms0QW3mqyg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/solway/v19/AMOTz46Cs2uTAOCuPl8Zms0QW3mqyg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,
"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/solway/v19/AMOTz46Cs2uTAOCuIlwZms0QW3mqyg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sometype-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("896ab430-a8a6-488e-96d3-edb7c8c72075",-369192680),$APP.$cljs$cst$2675$family$$,"Sometype Mono",$APP.$cljs$cst$725$name$$,"Sometype Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sometypemono/v4/70lGu745KGk_R3uxyq0WrROhAJiJsJ_eTWllpTAMGE9agQBbs7uG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sometypemono/v4/70lGu745KGk_R3uxyq0WrROhAJiJsJ_eTWllpTA-GE9agQBbs7uG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sometypemono/v4/70lGu745KGk_R3uxyq0WrROhAJiJsJ_eTWllpTDSH09agQBbs7uG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sometypemono/v4/70lGu745KGk_R3uxyq0WrROhAJiJsJ_eTWllpTDrH09agQBbs7uG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sometypemono/v4/70lEu745KGk_R3uxyq0WrROhKpG7T0e3JvPLoiXEW6cZiwR5tquGrxk.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sometypemono/v4/70lEu745KGk_R3uxyq0WrROhKpG7T0e3JvPLoiXEW5UZiwR5tquGrxk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sometypemono/v4/70lEu745KGk_R3uxyq0WrROhKpG7T0e3JvPLoiXEW3keiwR5tquGrxk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sometypemono/v4/70lEu745KGk_R3uxyq0WrROhKpG7T0e3JvPLoiXEW0AeiwR5tquGrxk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-song-myung",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f902550d-073f-4e42-9fc5-e6937926ada6",375933520),$APP.$cljs$cst$2675$family$$,"Song Myung",$APP.$cljs$cst$725$name$$,"Song Myung",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/songmyung/v22/1cX2aUDWAJH5-EIC7DIhr1GqhcitzeM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bc9a908b-060d-40ed-96a4-fb1085f1e73c",1979624962),$APP.$cljs$cst$2675$family$$,"Sono",$APP.$cljs$cst$725$name$$,"Sono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sono/v12/aFT97PNiY3U2Cqf_aYEN64CYaK18YWJEsV6u-QLiOsxVNkWdEnR4qYeB4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sono/v12/aFT97PNiY3U2Cqf_aYEN64CYaK18YWJEsV6u-QLiOsxV6EWdEnR4qYeB4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sono/v12/aFT97PNiY3U2Cqf_aYEN64CYaK18YWJEsV6u-QLiOsxVtkWdEnR4qYeB4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sono/v12/aFT97PNiY3U2Cqf_aYEN64CYaK18YWJEsV6u-QLiOsxVhEWdEnR4qYeB4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sono/v12/aFT97PNiY3U2Cqf_aYEN64CYaK18YWJEsV6u-QLiOsxVaEKdEnR4qYeB4Q.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sono/v12/aFT97PNiY3U2Cqf_aYEN64CYaK18YWJEsV6u-QLiOsxVUUKdEnR4qYeB4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sono/v12/aFT97PNiY3U2Cqf_aYEN64CYaK18YWJEsV6u-QLiOsxVNkKdEnR4qYeB4Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sonsie-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b9e01dbf-b897-4974-9756-20dfff46273e",316404226),$APP.$cljs$cst$2675$family$$,"Sonsie One",$APP.$cljs$cst$725$name$$,"Sonsie One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sonsieone/v22/PbymFmP_EAnPqbKaoc18YVu80lbp8JM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sora",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("29ff1ee4-54b3-4c39-9dd5-e5e3b7336d0e",1582490910),$APP.$cljs$cst$2675$family$$,
"Sora",$APP.$cljs$cst$725$name$$,"Sora",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sora/v17/xMQOuFFYT72X5wkB_18qmnndmSdSn3-KIwNhBti0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sora/v17/xMQOuFFYT72X5wkB_18qmnndmSfSnn-KIwNhBti0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sora/v17/xMQOuFFYT72X5wkB_18qmnndmScMnn-KIwNhBti0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sora/v17/xMQOuFFYT72X5wkB_18qmnndmSdSnn-KIwNhBti0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sora/v17/xMQOuFFYT72X5wkB_18qmnndmSdgnn-KIwNhBti0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sora/v17/xMQOuFFYT72X5wkB_18qmnndmSeMmX-KIwNhBti0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",
$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sora/v17/xMQOuFFYT72X5wkB_18qmnndmSe1mX-KIwNhBti0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sora/v17/xMQOuFFYT72X5wkB_18qmnndmSfSmX-KIwNhBti0.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sorts-mill-goudy",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ecb4b3b1-6b80-4ee2-b355-1c6a69d53792",2017006162),$APP.$cljs$cst$2675$family$$,"Sorts Mill Goudy",$APP.$cljs$cst$725$name$$,"Sorts Mill Goudy",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sortsmillgoudy/v16/Qw3GZR9MED_6PSuS_50nEaVrfzgEXH0OjpM75PE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sortsmillgoudy/v16/Qw3AZR9MED_6PSuS_50nEaVrfzgEbH8EirE-9PGLfQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sour-gummy",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b06f64cb-1e4c-4936-8dd0-8488bd645348",2141252637),$APP.$cljs$cst$2675$family$$,"Sour Gummy",$APP.$cljs$cst$725$name$$,"Sour Gummy",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtGGs2gPYuNDii97MjjBrLbYfdJvDU5AZfP5opPVCC4oC5ANR1N88JU91CMD2tcoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtGGs2gPYuNDii97MjjBrLbYfdJvDU5AZfP5opPVCC4oC5ANR1Nc8NU91CMD2tcoQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtGGs2gPYuNDii97MjjBrLbYfdJvDU5AZfP5opPVCC4oC5ANR1NrcNU91CMD2tcoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtGGs2gPYuNDii97MjjBrLbYfdJvDU5AZfP5opPVCC4oC5ANR1N88NU91CMD2tcoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtGGs2gPYuNDii97MjjBrLbYfdJvDU5AZfP5opPVCC4oC5ANR1NwcNU91CMD2tcoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtGGs2gPYuNDii97MjjBrLbYfdJvDU5AZfP5opPVCC4oC5ANR1NLcRU91CMD2tcoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtGGs2gPYuNDii97MjjBrLbYfdJvDU5AZfP5opPVCC4oC5ANR1NFMRU91CMD2tcoQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtGGs2gPYuNDii97MjjBrLbYfdJvDU5AZfP5opPVCC4oC5ANR1Nc8RU91CMD2tcoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtGGs2gPYuNDii97MjjBrLbYfdJvDU5AZfP5opPVCC4oC5ANR1NWsRU91CMD2tcoQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtIGs2gPYuNDii97MjjLLvpghcw76OXBoIHpHgGZt9gyUXamxpYO4C8tVqILW5MobGa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtIGs2gPYuNDii97MjjLLvpghcw76OXBoIHpHgGZt9gyUXamxpYO4A8tFqILW5MobGa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sourgummy/v3/8AtIGs2gPYuNDii97MjjLLvpghcw76OXBoIHpHgGZt9gyUXamxpYO4DitFqILW5MobGa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtIGs2gPYuNDii97MjjLLvpghcw76OXBoIHpHgGZt9gyUXamxpYO4C8tFqILW5MobGa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtIGs2gPYuNDii97MjjLLvpghcw76OXBoIHpHgGZt9gyUXamxpYO4COtFqILW5MobGa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sourgummy/v3/8AtIGs2gPYuNDii97MjjLLvpghcw76OXBoIHpHgGZt9gyUXamxpYO4Bis1qILW5MobGa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtIGs2gPYuNDii97MjjLLvpghcw76OXBoIHpHgGZt9gyUXamxpYO4Bbs1qILW5MobGa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourgummy/v3/8AtIGs2gPYuNDii97MjjLLvpghcw76OXBoIHpHgGZt9gyUXamxpYO4A8s1qILW5MobGa.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sourgummy/v3/8AtIGs2gPYuNDii97MjjLLvpghcw76OXBoIHpHgGZt9gyUXamxpYO4AVs1qILW5MobGa.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-source-code-pro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1ebc39e6-1b68-4423-a78f-2ccb34f1427e",-133564941),$APP.$cljs$cst$2675$family$$,"Source Code Pro",$APP.$cljs$cst$725$name$$,"Source Code Pro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_diYsKILxRpg3hIP6sJ7fM7PqPMcMnZFqUwX28DEyQhM5hTXUcdJg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_diYsKILxRpg3hIP6sJ7fM7PqPMcMnZFqUwX28DJKQhM5hTXUcdJg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_diYsKILxRpg3hIP6sJ7fM7PqPMcMnZFqUwX28DMyQhM5hTXUcdJg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_diYsKILxRpg3hIP6sJ7fM7PqPMcMnZFqUwX28DP6QhM5hTXUcdJg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_diYsKILxRpg3hIP6sJ7fM7PqPMcMnZFqUwX28DBKXhM5hTXUcdJg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_diYsKILxRpg3hIP6sJ7fM7PqPMcMnZFqUwX28DCuXhM5hTXUcdJg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_diYsKILxRpg3hIP6sJ7fM7PqPMcMnZFqUwX28DEyXhM5hTXUcdJg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_diYsKILxRpg3hIP6sJ7fM7PqPMcMnZFqUwX28DGWXhM5hTXUcdJg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTT7I1rSVcZZJiGpw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTTMo1rSVcZZJiGpw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTTbI1rSVcZZJiGpw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTTXo1rSVcZZJiGpw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTTsoprSVcZZJiGpw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTTi4prSVcZZJiGpw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTT7IprSVcZZJiGpw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sourcecodepro/v31/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTTxYprSVcZZJiGpw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-source-sans-3",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("da085450-7c62-47d0-8f09-9c7d6a42bacc",2067340572),$APP.$cljs$cst$2675$family$$,"Source Sans 3",$APP.$cljs$cst$725$name$$,"Source Sans 3",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpBtKy2OAdR1K-IwhWudF-R9QMylBJAV3Bo8Kw461EN_io6npfB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpBtKy2OAdR1K-IwhWudF-R9QMylBJAV3Bo8Kzm61EN_io6npfB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpBtKy2OAdR1K-IwhWudF-R9QMylBJAV3Bo8Ky461EN_io6npfB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpBtKy2OAdR1K-IwhWudF-R9QMylBJAV3Bo8KyK61EN_io6npfB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpBtKy2OAdR1K-IwhWudF-R9QMylBJAV3Bo8Kxm7FEN_io6npfB.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpBtKy2OAdR1K-IwhWudF-R9QMylBJAV3Bo8Kxf7FEN_io6npfB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpBtKy2OAdR1K-IwhWudF-R9QMylBJAV3Bo8Kw47FEN_io6npfB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpBtKy2OAdR1K-IwhWudF-R9QMylBJAV3Bo8KwR7FEN_io6npfB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpDtKy2OAdR1K-IwhWudF-R3woAa8opPOrG97lwqDlO9C4Ym4fB3Ts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sourcesans3/v19/nwpDtKy2OAdR1K-IwhWudF-R3woAa8opPOrG97lwqOdO9C4Ym4fB3Ts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpDtKy2OAdR1K-IwhWudF-R3woAa8opPOrG97lwqLlO9C4Ym4fB3Ts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpDtKy2OAdR1K-IwhWudF-R3woAa8opPOrG97lwqItO9C4Ym4fB3Ts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpDtKy2OAdR1K-IwhWudF-R3woAa8opPOrG97lwqGdJ9C4Ym4fB3Ts.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpDtKy2OAdR1K-IwhWudF-R3woAa8opPOrG97lwqF5J9C4Ym4fB3Ts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpDtKy2OAdR1K-IwhWudF-R3woAa8opPOrG97lwqDlJ9C4Ym4fB3Ts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourcesans3/v19/nwpDtKy2OAdR1K-IwhWudF-R3woAa8opPOrG97lwqBBJ9C4Ym4fB3Ts.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-source-serif-4",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("499faebc-5a75-4a8a-9fe8-e264f657d02f",-808186963),$APP.$cljs$cst$2675$family$$,"Source Serif 4",$APP.$cljs$cst$725$name$$,"Source Serif 4",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEFy2_tTDB4M7-auWDN0ahZJW3IX2ih5nk3AucvUHf6OAVIJmeUDygwjipdqrhxXD-wGvjU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEFy2_tTDB4M7-auWDN0ahZJW3IX2ih5nk3AucvUHf6OAVIJmeUDygwjiklqrhxXD-wGvjU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEFy2_tTDB4M7-auWDN0ahZJW3IX2ih5nk3AucvUHf6OAVIJmeUDygwjihdqrhxXD-wGvjU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEFy2_tTDB4M7-auWDN0ahZJW3IX2ih5nk3AucvUHf6OAVIJmeUDygwjiiVqrhxXD-wGvjU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEFy2_tTDB4M7-auWDN0ahZJW3IX2ih5nk3AucvUHf6OAVIJmeUDygwjisltrhxXD-wGvjU.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEFy2_tTDB4M7-auWDN0ahZJW3IX2ih5nk3AucvUHf6OAVIJmeUDygwjivBtrhxXD-wGvjU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEFy2_tTDB4M7-auWDN0ahZJW3IX2ih5nk3AucvUHf6OAVIJmeUDygwjipdtrhxXD-wGvjU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEFy2_tTDB4M7-auWDN0ahZJW3IX2ih5nk3AucvUHf6OAVIJmeUDygwjir5trhxXD-wGvjU.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEF02_tTDB4M7-auWDN0ahZJW1ge6NmXpVAHV83Bfb_US2D2QYxoUKIkn98pxl9dC84DrjXEXw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEF02_tTDB4M7-auWDN0ahZJW1ge6NmXpVAHV83Bfb_US2D2QYxoUKIkn98pGF9dC84DrjXEXw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEF02_tTDB4M7-auWDN0ahZJW1ge6NmXpVAHV83Bfb_US2D2QYxoUKIkn98pRl9dC84DrjXEXw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEF02_tTDB4M7-auWDN0ahZJW1ge6NmXpVAHV83Bfb_US2D2QYxoUKIkn98pdF9dC84DrjXEXw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,
"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEF02_tTDB4M7-auWDN0ahZJW1ge6NmXpVAHV83Bfb_US2D2QYxoUKIkn98pmFhdC84DrjXEXw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEF02_tTDB4M7-auWDN0ahZJW1ge6NmXpVAHV83Bfb_US2D2QYxoUKIkn98poVhdC84DrjXEXw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEF02_tTDB4M7-auWDN0ahZJW1ge6NmXpVAHV83Bfb_US2D2QYxoUKIkn98pxlhdC84DrjXEXw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,
"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sourceserif4/v14/vEF02_tTDB4M7-auWDN0ahZJW1ge6NmXpVAHV83Bfb_US2D2QYxoUKIkn98p71hdC84DrjXEXw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-space-grotesk",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2135c49a-3e95-48fa-a11f-29d40577b733",-1021182042),$APP.$cljs$cst$2675$family$$,"Space Grotesk",$APP.$cljs$cst$725$name$$,"Space Grotesk",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spacegrotesk/v22/V8mQoQDjQSkFtoMM3T6r8E7mF71Q-gOoraIAEj62UUsjNsFjTDJK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spacegrotesk/v22/V8mQoQDjQSkFtoMM3T6r8E7mF71Q-gOoraIAEj7oUUsjNsFjTDJK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spacegrotesk/v22/V8mQoQDjQSkFtoMM3T6r8E7mF71Q-gOoraIAEj7aUUsjNsFjTDJK.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spacegrotesk/v22/V8mQoQDjQSkFtoMM3T6r8E7mF71Q-gOoraIAEj42VksjNsFjTDJK.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spacegrotesk/v22/V8mQoQDjQSkFtoMM3T6r8E7mF71Q-gOoraIAEj4PVksjNsFjTDJK.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-space-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4cd53bfe-5987-4079-9cac-a9a7338838f3",-1508819028),$APP.$cljs$cst$2675$family$$,"Space Mono",$APP.$cljs$cst$725$name$$,"Space Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spacemono/v17/i7dPIFZifjKcF5UAWdDRUEZ2RFq7AwU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/spacemono/v17/i7dNIFZifjKcF5UAWdDRYER8QHi-EwWMbg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spacemono/v17/i7dMIFZifjKcF5UAWdDRaPpZYFKQHwyVd3U.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",
$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spacemono/v17/i7dSIFZifjKcF5UAWdDRYERE_FeaGy6QZ3WfYg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-special-elite",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e08c38fe-95a9-4230-bde0-d754a4887467",-1814921040),$APP.$cljs$cst$2675$family$$,"Special Elite",$APP.$cljs$cst$725$name$$,"Special Elite",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/specialelite/v20/XLYgIZbkc4JPUL5CVArUVL0nhncESXFtUsM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-special-gothic",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("24de1efb-0ba4-4ad9-bfa1-0744372fe291",-1056852738),$APP.$cljs$cst$2675$family$$,"Special Gothic",$APP.$cljs$cst$725$name$$,"Special Gothic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/specialgothic/v3/1q2lY5WcG0Fg_v0fHc8BvIZ2537qdm1JEt9N3w2mJykOEnLhliLsitHN4bF8-SgLPIOkEp8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/specialgothic/v3/1q2lY5WcG0Fg_v0fHc8BvIZ2537qdm1JEt9N3w2mJykOEnLhliLsitHN4YN8-SgLPIOkEp8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/specialgothic/v3/1q2lY5WcG0Fg_v0fHc8BvIZ2537qdm1JEt9N3w2mJykOEnLhliLsitHN4W97-SgLPIOkEp8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/specialgothic/v3/1q2lY5WcG0Fg_v0fHc8BvIZ2537qdm1JEt9N3w2mJykOEnLhliLsitHN4VZ7-SgLPIOkEp8.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-special-gothic-condensed-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f655b1cc-8384-40d1-b085-b18a7640e070",1735171208),$APP.$cljs$cst$2675$family$$,"Special Gothic Condensed One",$APP.$cljs$cst$725$name$$,"Special Gothic Condensed One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/specialgothiccondensedone/v2/R70Njzwei_mJM7OsFDzX7EL9NBO6IPvd-Avolzh49w7PUZt_5YtxbX8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-special-gothic-expanded-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0f82782e-2041-4b19-849f-348913bc3178",-831140504),
$APP.$cljs$cst$2675$family$$,"Special Gothic Expanded One",$APP.$cljs$cst$725$name$$,"Special Gothic Expanded One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/specialgothicexpandedone/v2/IurO6Zxk74-YaYk1r3HOet4g75ENmBxUmOK61tA0Iu5gn5t-KhUVvQ.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-spectral",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4956add1-ddc1-4473-a2fe-89dbb6c654b2",-331544678),$APP.$cljs$cst$2675$family$$,"Spectral",$APP.$cljs$cst$725$name$$,"Spectral",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectral/v15/rnCs-xNNww_2s0amA9v2s13GY_etWWIJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectral/v15/rnCu-xNNww_2s0amA9M8qrXHafOPXHIJErY.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectral/v15/rnCs-xNNww_2s0amA9uSsF3GY_etWWIJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/spectral/v15/rnCu-xNNww_2s0amA9M8qtHEafOPXHIJErY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectral/v15/rnCr-xNNww_2s0amA-M-mHnOSOuk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectral/v15/rnCt-xNNww_2s0amA9M8kn3sTfukQHs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectral/v15/rnCs-xNNww_2s0amA9vKsV3GY_etWWIJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectral/v15/rnCu-xNNww_2s0amA9M8qonFafOPXHIJErY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectral/v15/rnCs-xNNww_2s0amA9vmtl3GY_etWWIJ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectral/v15/rnCu-xNNww_2s0amA9M8qqXCafOPXHIJErY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/spectral/v15/rnCs-xNNww_2s0amA9uCt13GY_etWWIJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectral/v15/rnCu-xNNww_2s0amA9M8qsHDafOPXHIJErY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectral/v15/rnCs-xNNww_2s0amA9uetF3GY_etWWIJ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectral/v15/rnCu-xNNww_2s0amA9M8qt3AafOPXHIJErY.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-spectral-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e379f7c9-28ee-4959-a82f-a356da933859",1775545379),$APP.$cljs$cst$2675$family$$,"Spectral SC",$APP.$cljs$cst$725$name$$,"Spectral SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectralsc/v15/Ktk0ALCRZonmalTgyPmRfs1qwkTXPYeVXJZB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectralsc/v15/Ktk2ALCRZonmalTgyPmRfsWg26zWN4O3WYZB_sU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectralsc/v15/Ktk0ALCRZonmalTgyPmRfs0OwUTXPYeVXJZB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectralsc/v15/Ktk2ALCRZonmalTgyPmRfsWg28jVN4O3WYZB_sU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectralsc/v15/KtkpALCRZonmalTgyPmRfvWi6WDfFpuc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",
$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectralsc/v15/KtkrALCRZonmalTgyPmRfsWg42T9E4ucRY8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectralsc/v15/Ktk0ALCRZonmalTgyPmRfs1WwETXPYeVXJZB.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectralsc/v15/Ktk2ALCRZonmalTgyPmRfsWg25DUN4O3WYZB_sU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectralsc/v15/Ktk0ALCRZonmalTgyPmRfs16x0TXPYeVXJZB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectralsc/v15/Ktk2ALCRZonmalTgyPmRfsWg27zTN4O3WYZB_sU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectralsc/v15/Ktk0ALCRZonmalTgyPmRfs0exkTXPYeVXJZB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectralsc/v15/Ktk2ALCRZonmalTgyPmRfsWg29jSN4O3WYZB_sU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectralsc/v15/Ktk0ALCRZonmalTgyPmRfs0CxUTXPYeVXJZB.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spectralsc/v15/Ktk2ALCRZonmalTgyPmRfsWg28TRN4O3WYZB_sU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-spicy-rice",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("35f7a8e0-9e83-4124-a165-b204602bf63d",-792781033),$APP.$cljs$cst$2675$family$$,"Spicy Rice",$APP.$cljs$cst$725$name$$,"Spicy Rice",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spicyrice/v28/uK_24rSEd-Uqwk4jY1RyGv-2WkowRcc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-spinnaker",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e30ea66e-dc7a-4c68-b0ac-008b1a90fc6d",-2131040352),$APP.$cljs$cst$2675$family$$,
"Spinnaker",$APP.$cljs$cst$725$name$$,"Spinnaker",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spinnaker/v21/w8gYH2oyX-I0_rvR6Hmn3HwLqOqSBg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-spirax",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c3064a3a-0e9a-40da-9c6e-c919c90f8c00",-1285273468),$APP.$cljs$cst$2675$family$$,"Spirax",$APP.$cljs$cst$725$name$$,"Spirax",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/spirax/v22/buE3poKgYNLy0F3cXktt-Csn-Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-splash",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7592513d-ccfd-498b-b7c9-e433a603a64b",-714562325),$APP.$cljs$cst$2675$family$$,"Splash",$APP.$cljs$cst$725$name$$,"Splash",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splash/v8/KtksAL2RZoDkbU6hpPPGNdS6wg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-spline-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cdd25c8c-4631-4106-a893-67987f572521",-1930567305),$APP.$cljs$cst$2675$family$$,
"Spline Sans",$APP.$cljs$cst$725$name$$,"Spline Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splinesans/v16/_6_sED73Uf-2WfU2LzycEZousNzn1a1lKWRpZlnYEtvlUfE2kw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splinesans/v16/_6_sED73Uf-2WfU2LzycEZousNzn1a1lKWRpOFnYEtvlUfE2kw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splinesans/v16/_6_sED73Uf-2WfU2LzycEZousNzn1a1lKWRpClnYEtvlUfE2kw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splinesans/v16/_6_sED73Uf-2WfU2LzycEZousNzn1a1lKWRp5l7YEtvlUfE2kw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splinesans/v16/_6_sED73Uf-2WfU2LzycEZousNzn1a1lKWRp317YEtvlUfE2kw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-spline-sans-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d97bff14-6d30-46fc-b90e-89458acee42c",1712463136),$APP.$cljs$cst$2675$family$$,"Spline Sans Mono",$APP.$cljs$cst$725$name$$,"Spline Sans Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splinesansmono/v13/R70MjzAei_CDNLfgZxrW6wrZOF2WdZ6xabUGSVtNuGA8MrtVy4d4dGb1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splinesansmono/v13/R70MjzAei_CDNLfgZxrW6wrZOF2WdZ6xabUGSVtNuGBiMrtVy4d4dGb1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splinesansmono/v13/R70MjzAei_CDNLfgZxrW6wrZOF2WdZ6xabUGSVtNuGBQMrtVy4d4dGb1.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splinesansmono/v13/R70MjzAei_CDNLfgZxrW6wrZOF2WdZ6xabUGSVtNuGC8NbtVy4d4dGb1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splinesansmono/v13/R70MjzAei_CDNLfgZxrW6wrZOF2WdZ6xabUGSVtNuGCFNbtVy4d4dGb1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splinesansmono/v13/R70yjzAei_CDNLfgZxrW6wrZOF2WX5eDlm1vIsHjv3WqcQ0WwYNacXb12MM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splinesansmono/v13/R70yjzAei_CDNLfgZxrW6wrZOF2WX5eDlm1vIsHjv3WqcVMWwYNacXb12MM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/splinesansmono/v13/R70yjzAei_CDNLfgZxrW6wrZOF2WX5eDlm1vIsHjv3WqcWEWwYNacXb12MM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splinesansmono/v13/R70yjzAei_CDNLfgZxrW6wrZOF2WX5eDlm1vIsHjv3WqcY0RwYNacXb12MM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/splinesansmono/v13/R70yjzAei_CDNLfgZxrW6wrZOF2WX5eDlm1vIsHjv3WqcbQRwYNacXb12MM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-squada-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bb6bafe0-331c-4bb5-8c91-c28ef18d392b",-1416538805),$APP.$cljs$cst$2675$family$$,
"Squada One",$APP.$cljs$cst$725$name$$,"Squada One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/squadaone/v20/BCasqZ8XsOrx4mcOk6MtWaA8WDBkHgs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-square-peg",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f7c3cbc7-a446-40f8-bd5b-e7824589d0e3",-1742335865),$APP.$cljs$cst$2675$family$$,"Square Peg",$APP.$cljs$cst$725$name$$,"Square Peg",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/squarepeg/v7/y83eW48Nzw6ZlUHc-phrBDHrHHfrFPE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sree-krushnadevaraya",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e5b90e8c-c107-4fc7-bf3c-fd218253b788",-642366600),$APP.$cljs$cst$2675$family$$,"Sree Krushnadevaraya",$APP.$cljs$cst$725$name$$,"Sree Krushnadevaraya",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sreekrushnadevaraya/v23/R70FjzQeifmPepmyQQjQ9kvwMkWYPfTA_EWb2FhQuXir.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sriracha",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f8634d71-9f55-4fde-8d7f-a65db2466eb2",
1180014573),$APP.$cljs$cst$2675$family$$,"Sriracha",$APP.$cljs$cst$725$name$$,"Sriracha",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sriracha/v16/0nkrC9D4IuYBgWcI9ObYRQDioeb0.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-srisakdi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b8a371ea-282d-44df-a23f-ea892efcc056",-376817986),$APP.$cljs$cst$2675$family$$,"Srisakdi",$APP.$cljs$cst$725$name$$,"Srisakdi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/srisakdi/v18/yMJRMIlvdpDbkB0A-jq8fSx5i814.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/srisakdi/v18/yMJWMIlvdpDbkB0A-gIAUghxoNFxW0Hz.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-staatliches",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3f10c637-cdde-46f2-bcc0-ffa1cae36f72",1566062809),$APP.$cljs$cst$2675$family$$,"Staatliches",$APP.$cljs$cst$725$name$$,"Staatliches",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/staatliches/v15/HI_OiY8KO6hCsQSoAPmtMbectJG9O9PS.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-stack-sans-headline",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("38d0290d-e372-46d4-84c4-6e49dffb40cc",645686685),$APP.$cljs$cst$2675$family$$,"Stack Sans Headline",$APP.$cljs$cst$725$name$$,"Stack Sans Headline",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksansheadline/v1/1PtFg9jZXvmMnkLnuURbaukKZJTyrDV326uH6mSinjBIwc7tIgFHqgUA3ZCX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksansheadline/v1/1PtFg9jZXvmMnkLnuURbaukKZJTyrDV326uH6mSinjBIwc4zIgFHqgUA3ZCX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksansheadline/v1/1PtFg9jZXvmMnkLnuURbaukKZJTyrDV326uH6mSinjBIwc5tIgFHqgUA3ZCX.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksansheadline/v1/1PtFg9jZXvmMnkLnuURbaukKZJTyrDV326uH6mSinjBIwc5fIgFHqgUA3ZCX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksansheadline/v1/1PtFg9jZXvmMnkLnuURbaukKZJTyrDV326uH6mSinjBIwc6zJQFHqgUA3ZCX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksansheadline/v1/1PtFg9jZXvmMnkLnuURbaukKZJTyrDV326uH6mSinjBIwc6KJQFHqgUA3ZCX.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-stack-sans-notch",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e5ef8273-afd0-460f-a319-c05afdeabca9",-811587722),$APP.$cljs$cst$2675$family$$,"Stack Sans Notch",$APP.$cljs$cst$725$name$$,"Stack Sans Notch",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,
"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksansnotch/v5/TwMY-JcVXlQd3ooGEx9EbUzgioTr5BY5lEpidqlSR8diuR2ZGGf6Bw3r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksansnotch/v5/TwMY-JcVXlQd3ooGEx9EbUzgioTr5BY5lEpidqlSR8e8uR2ZGGf6Bw3r.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksansnotch/v5/TwMY-JcVXlQd3ooGEx9EbUzgioTr5BY5lEpidqlSR8fiuR2ZGGf6Bw3r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksansnotch/v5/TwMY-JcVXlQd3ooGEx9EbUzgioTr5BY5lEpidqlSR8fQuR2ZGGf6Bw3r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksansnotch/v5/TwMY-JcVXlQd3ooGEx9EbUzgioTr5BY5lEpidqlSR8c8vh2ZGGf6Bw3r.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksansnotch/v5/TwMY-JcVXlQd3ooGEx9EbUzgioTr5BY5lEpidqlSR8cFvh2ZGGf6Bw3r.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-stack-sans-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("15d939aa-70c2-40be-8124-f62664fd3e21",-59128753),$APP.$cljs$cst$2675$family$$,
"Stack Sans Text",$APP.$cljs$cst$725$name$$,"Stack Sans Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksanstext/v1/kJEkBuAJ-Q0hiGPmzHEu345X1JJNBpRJ3RPan47MNo-KJO1yGgKF1a0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksanstext/v1/kJEkBuAJ-Q0hiGPmzHEu345X1JJNBpRJ3RPan47MNlGKJO1yGgKF1a0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksanstext/v1/kJEkBuAJ-Q0hiGPmzHEu345X1JJNBpRJ3RPan47MNg-KJO1yGgKF1a0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksanstext/v1/kJEkBuAJ-Q0hiGPmzHEu345X1JJNBpRJ3RPan47MNj2KJO1yGgKF1a0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksanstext/v1/kJEkBuAJ-Q0hiGPmzHEu345X1JJNBpRJ3RPan47MNtGNJO1yGgKF1a0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stacksanstext/v1/kJEkBuAJ-Q0hiGPmzHEu345X1JJNBpRJ3RPan47MNuiNJO1yGgKF1a0.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-stalemate",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1c726b23-f6c9-43c4-98dd-aebf62cfaf4b",904395782),$APP.$cljs$cst$2675$family$$,"Stalemate",$APP.$cljs$cst$725$name$$,"Stalemate",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stalemate/v24/taiIGmZ_EJq97-UfkZRpuqSs8ZQpaQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-stalinist-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8f85d481-2956-4637-913a-63bdf1298fd8",-1890417343),$APP.$cljs$cst$2675$family$$,"Stalinist One",$APP.$cljs$cst$725$name$$,"Stalinist One",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stalinistone/v58/MQpS-WezM9W4Dd7D3B7I-UT7eZ-UPyacPbo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-stardos-stencil",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("314a3e84-b4d4-4ef2-bc8e-4f4f6b2d2404",1689586843),$APP.$cljs$cst$2675$family$$,"Stardos Stencil",$APP.$cljs$cst$725$name$$,"Stardos Stencil",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/stardosstencil/v15/X7n94bcuGPC8hrvEOHXOgaKCc2TR71R3tiSx0g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stardosstencil/v15/X7n44bcuGPC8hrvEOHXOgaKCc2TpU3tTvg-t29HSHw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-stick",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1163e96b-b4f2-4a43-b647-6556407a6e09",111591928),$APP.$cljs$cst$2675$family$$,"Stick",$APP.$cljs$cst$725$name$$,"Stick",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/stick/v20/Qw3TZQpMCyTtJSvfvPVDMPoF.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-stick-no-bills",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9861bf80-81c2-4b40-a732-3e1fb96ddc69",199400433),$APP.$cljs$cst$2675$family$$,"Stick No Bills",$APP.$cljs$cst$725$name$$,"Stick No Bills",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sticknobills/v17/bWts7ffXZwHuAa9Uld-oEK4QKlxj9f9t_7uEmjcVP8Q7KriwKhcTKA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sticknobills/v17/bWts7ffXZwHuAa9Uld-oEK4QKlxj9f9t_7uEmjcV4cQ7KriwKhcTKA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sticknobills/v17/bWts7ffXZwHuAa9Uld-oEK4QKlxj9f9t_7uEmjcVv8Q7KriwKhcTKA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sticknobills/v17/bWts7ffXZwHuAa9Uld-oEK4QKlxj9f9t_7uEmjcVjcQ7KriwKhcTKA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sticknobills/v17/bWts7ffXZwHuAa9Uld-oEK4QKlxj9f9t_7uEmjcVYcM7KriwKhcTKA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sticknobills/v17/bWts7ffXZwHuAa9Uld-oEK4QKlxj9f9t_7uEmjcVWMM7KriwKhcTKA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sticknobills/v17/bWts7ffXZwHuAa9Uld-oEK4QKlxj9f9t_7uEmjcVP8M7KriwKhcTKA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-stint-ultra-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b0e5658b-24ed-45f7-bd71-d5ece7ca98e8",-507442279),$APP.$cljs$cst$2675$family$$,"Stint Ultra Condensed",$APP.$cljs$cst$725$name$$,"Stint Ultra Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stintultracondensed/v25/-W_gXIrsVjjeyEnPC45qD2NoFPtBE0xCh2A-qhUO2cNvdg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-stint-ultra-expanded",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("70c88f01-7194-48e8-afd1-987b3d302f4a",870135873),$APP.$cljs$cst$2675$family$$,"Stint Ultra Expanded",
$APP.$cljs$cst$725$name$$,"Stint Ultra Expanded",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stintultraexpanded/v24/CSRg4yNNh-GbW3o3JkwoDcdvMKMf0oBAd0qoATQkWwam.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-stoke",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2c5e10e6-c033-4a43-93de-f40ab377e2cf",-1300071518),$APP.$cljs$cst$2675$family$$,"Stoke",$APP.$cljs$cst$725$name$$,"Stoke",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stoke/v26/z7NXdRb7aTMfKNvFVgxC_pjcTeWU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stoke/v26/z7NadRb7aTMfKONpfihK1YTV.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-story-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e8b9ae5b-abc7-44c8-a7ec-e1be7fb94778",522450588),$APP.$cljs$cst$2675$family$$,"Story Script",$APP.$cljs$cst$725$name$$,"Story Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/storyscript/v3/mem5YaSw02SQ0OlzDuR8Isk-VeJoCqeDjg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-strait",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dd6f375b-e0ba-42a4-803a-4941a2ffa9d4",305927985),$APP.$cljs$cst$2675$family$$,"Strait",$APP.$cljs$cst$725$name$$,"Strait",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/strait/v19/DtViJxy6WaEr1LZzeDhtkl0U7w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-style-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f80506ee-8ce0-48d1-b509-9c7980c3bb82",-2049842319),$APP.$cljs$cst$2675$family$$,
"Style Script",$APP.$cljs$cst$725$name$$,"Style Script",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stylescript/v13/vm8xdRX3SV7Z0aPa88xzW5npeFT76NZnMw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-stylish",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f5d8741a-1bcd-43b8-9773-b67cbca88507",-165737092),$APP.$cljs$cst$2675$family$$,"Stylish",$APP.$cljs$cst$725$name$$,"Stylish",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/stylish/v25/m8JSjfhPYriQkk7-fo35dLxEdmo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sue-ellen-francisco",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("84ea6db1-1903-496b-b344-88adbc67888b",1652663813),$APP.$cljs$cst$2675$family$$,"Sue Ellen Francisco",$APP.$cljs$cst$725$name$$,"Sue Ellen Francisco",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sueellenfrancisco/v22/wXK3E20CsoJ9j1DDkjHcQ5ZL8xRaxru9ropF2lqk9H4.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-suez-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f42b53e7-b3c4-4b69-9d4f-eac59c4516f3",
2042343512),$APP.$cljs$cst$2675$family$$,"Suez One",$APP.$cljs$cst$725$name$$,"Suez One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suezone/v15/taiJGmd_EZ6rqscQgNFJkIqg-I0w.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sulphur-point",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("66355c40-9c08-4301-b07a-abe10f258748",1659375224),$APP.$cljs$cst$2675$family$$,"Sulphur Point",$APP.$cljs$cst$725$name$$,"Sulphur Point",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",
$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sulphurpoint/v16/RLpkK5vv8KaycDcazWFPBj2afVU6n6kFUHPIFaU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sulphurpoint/v16/RLp5K5vv8KaycDcazWFPBj2aRfkSu6EuTHo.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sulphurpoint/v16/RLpkK5vv8KaycDcazWFPBj2afUU9n6kFUHPIFaU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sumana",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("297f9225-0e14-47de-91cf-de0f1a409a07",-1849497687),
$APP.$cljs$cst$2675$family$$,"Sumana",$APP.$cljs$cst$725$name$$,"Sumana",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sumana/v12/4UaDrE5TqRBjGj-G8Bji76zR4w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sumana/v12/4UaArE5TqRBjGj--TDfG54fN6ppsKg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sunflower",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("39b0549b-5f92-4c90-a21c-700bc467123c",2084494248),$APP.$cljs$cst$2675$family$$,"Sunflower",$APP.$cljs$cst$725$name$$,
"Sunflower",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sunflower/v18/RWmPoKeF8fUjqIj7Vc-06MfiqYsGBGBzCw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sunflower/v18/RWmPoKeF8fUjqIj7Vc-0sMbiqYsGBGBzCw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sunflower/v18/RWmPoKeF8fUjqIj7Vc-0-MDiqYsGBGBzCw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sunshiney",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("de75d095-6039-4791-811d-782ebef885f4",-539936482),$APP.$cljs$cst$2675$family$$,"Sunshiney",$APP.$cljs$cst$725$name$$,"Sunshiney",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sunshiney/v24/LDIwapGTLBwsS-wT4vcgE8moUePWkg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-supermercado-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("366c6449-8a4d-46ba-b76f-31d9762798a5",-1541851204),$APP.$cljs$cst$2675$family$$,"Supermercado One",$APP.$cljs$cst$725$name$$,"Supermercado One",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/supermercadoone/v29/OpNXnpQWg8jc_xps_Gi14kVVEXOn60b3MClBRTs.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-sura",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2e63525a-6e09-414e-836f-784caf131c4a",1634616965),$APP.$cljs$cst$2675$family$$,"Sura",$APP.$cljs$cst$725$name$$,"Sura",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/sura/v21/SZc23FL5PbyzFf5UWzXtjUM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/sura/v21/SZc53FL5PbyzLUJ7fz3GkUrS8DI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-suranna",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b71341e1-4c22-4bf3-bb3d-1841af954196",
-2103427541),$APP.$cljs$cst$2675$family$$,"Suranna",$APP.$cljs$cst$725$name$$,"Suranna",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suranna/v15/gokuH6ztGkFjWe58tBRZT2KmgP0.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-suravaram",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9a300c67-2565-43e9-bae2-3f625864498a",630806838),$APP.$cljs$cst$2675$family$$,"Suravaram",$APP.$cljs$cst$725$name$$,"Suravaram",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suravaram/v23/_gP61R_usiY7SCym4xIAi261Qv9roQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-suwannaphum",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a8d5e8ce-4818-46bc-806d-c2fcccf56cfa",623332818),$APP.$cljs$cst$2675$family$$,"Suwannaphum",$APP.$cljs$cst$725$name$$,"Suwannaphum",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suwannaphum/v33/jAnAgHV7GtDvc8jbe8hXXL3B9cSWXx2VZmk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,
"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suwannaphum/v33/jAnfgHV7GtDvc8jbe8hXXL0J1-S8cRGcf3Ai.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suwannaphum/v33/jAnCgHV7GtDvc8jbe8hXXIWl_8C0Wg2V.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suwannaphum/v33/jAnfgHV7GtDvc8jbe8hXXL0Z0OS8cRGcf3Ai.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/suwannaphum/v33/jAnfgHV7GtDvc8jbe8hXXL0h0uS8cRGcf3Ai.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-swanky-and-moo-moo",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("70a1a8f6-5fa2-4ebf-8207-79717c7b86e3",-223325584),$APP.$cljs$cst$2675$family$$,"Swanky and Moo Moo",$APP.$cljs$cst$725$name$$,"Swanky and Moo Moo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/swankyandmoomoo/v24/flUlRrKz24IuWVI_WJYTYcqbEsMUZ3kUtbPkR64SYQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-syncopate",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8d68d507-5577-4ac3-af5b-e36913e5c867",-1315441148),$APP.$cljs$cst$2675$family$$,"Syncopate",$APP.$cljs$cst$725$name$$,
"Syncopate",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/syncopate/v24/pe0sMIuPIYBCpEV5eFdyAv2-C99ycg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/syncopate/v24/pe0pMIuPIYBCpEV5eFdKvtKaA_Rue1UwVg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-syne",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("be5427e2-2b1e-47a6-8f6f-0e0552710df3",-1613214150),$APP.$cljs$cst$2675$family$$,"Syne",$APP.$cljs$cst$725$name$$,"Syne",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/syne/v24/8vIS7w4qzmVxsWxjBZRjr0FKM_04uT6kR47NCV5Z.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/syne/v24/8vIS7w4qzmVxsWxjBZRjr0FKM_0KuT6kR47NCV5Z.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/syne/v24/8vIS7w4qzmVxsWxjBZRjr0FKM_3mvj6kR47NCV5Z.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/syne/v24/8vIS7w4qzmVxsWxjBZRjr0FKM_3fvj6kR47NCV5Z.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/syne/v24/8vIS7w4qzmVxsWxjBZRjr0FKM_24vj6kR47NCV5Z.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-syne-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8e6a0ea3-f88f-426b-ac02-d0880afec7f7",-1911651369),$APP.$cljs$cst$2675$family$$,"Syne Mono",$APP.$cljs$cst$725$name$$,"Syne Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/synemono/v16/K2FzfZNHj_FHBmRbFvHzIqCkDyvqZA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-syne-tactile",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d9660a24-d78f-4929-b145-52df1d2d7060",-1293481074),$APP.$cljs$cst$2675$family$$,"Syne Tactile",$APP.$cljs$cst$725$name$$,"Syne Tactile",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/synetactile/v16/11hGGpna2UTQKjMCVzjAPMKh3ysdjvKU8Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tasa-explorer",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("baeaae1a-0281-456b-88c7-36d1ce3f75f5",-1954730867),$APP.$cljs$cst$2675$family$$,"TASA Explorer",$APP.$cljs$cst$725$name$$,"TASA Explorer",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/tasaexplorer/v2/K2FkfZdAt8xjBmxMCPK8UO_SPSH6kbsQNeItOI6o7xnGirZPlnP-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tasaexplorer/v2/K2FkfZdAt8xjBmxMCPK8UO_SPSH6kbsQNeItOI6a7xnGirZPlnP-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tasaexplorer/v2/K2FkfZdAt8xjBmxMCPK8UO_SPSH6kbsQNeItOI526BnGirZPlnP-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tasaexplorer/v2/K2FkfZdAt8xjBmxMCPK8UO_SPSH6kbsQNeItOI5P6BnGirZPlnP-.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tasaexplorer/v2/K2FkfZdAt8xjBmxMCPK8UO_SPSH6kbsQNeItOI4o6BnGirZPlnP-.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tasa-orbiter",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("85ed4e39-5756-4c42-8403-6d04e59748c4",
-410604090),$APP.$cljs$cst$2675$family$$,"TASA Orbiter",$APP.$cljs$cst$725$name$$,"TASA Orbiter",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tasaorbiter/v2/3XF4Erw3860rsdSUVZx78hPcTvQoDGHxaFGfVH4C8py095IuGcc.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tasaorbiter/v2/3XF4Erw3860rsdSUVZx78hPcTvQoDGHxaFGfVEwC8py095IuGcc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tasaorbiter/v2/3XF4Erw3860rsdSUVZx78hPcTvQoDGHxaFGfVKAF8py095IuGcc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tasaorbiter/v2/3XF4Erw3860rsdSUVZx78hPcTvQoDGHxaFGfVJkF8py095IuGcc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tasaorbiter/v2/3XF4Erw3860rsdSUVZx78hPcTvQoDGHxaFGfVP4F8py095IuGcc.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tac-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ac40085a-2556-4929-93fb-e7ee136a75d2",-1745745368),$APP.$cljs$cst$2675$family$$,"Tac One",$APP.$cljs$cst$725$name$$,
"Tac One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tacone/v5/ahcZv8Cj3zw7qDr8fO4hU-FwnU0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-tagesschrift",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("71b0dd60-94b2-44f4-ab4b-9e61c897ef74",-2063628229),$APP.$cljs$cst$2675$family$$,"Tagesschrift",$APP.$cljs$cst$725$name$$,"Tagesschrift",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tagesschrift/v2/pe0pMI6IOYlEuEZ7ZEA7ZKOaA_Rue1UwVg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tai-heritage-pro",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c089f00a-45d3-43bd-bd0e-1ebe98da5815",-29726340),$APP.$cljs$cst$2675$family$$,"Tai Heritage Pro",$APP.$cljs$cst$725$name$$,"Tai Heritage Pro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taiheritagepro/v9/sZlfdQid-zgaNiNIYcUzJMU3IYyNoHxSENxuLuE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taiheritagepro/v9/sZlYdQid-zgaNiNIYcUzJMU3IYyNmMB9NNRFMuhjCXY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tajawal",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4a39a59b-38b9-4d3b-bc66-be366c760217",830573187),$APP.$cljs$cst$2675$family$$,"Tajawal",$APP.$cljs$cst$725$name$$,"Tajawal",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tajawal/v12/Iurf6YBj_oCad4k1l_6gLrZjiLlJ-G0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tajawal/v12/Iurf6YBj_oCad4k1l5qjLrZjiLlJ-G0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tajawal/v12/Iura6YBj_oCad4k1rzaLCr5IlLA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tajawal/v12/Iurf6YBj_oCad4k1l8KiLrZjiLlJ-G0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tajawal/v12/Iurf6YBj_oCad4k1l4qkLrZjiLlJ-G0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tajawal/v12/Iurf6YBj_oCad4k1l5anLrZjiLlJ-G0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tajawal/v12/Iurf6YBj_oCad4k1l7KmLrZjiLlJ-G0.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tangerine",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("80b7fdf0-83a8-4523-baff-e0f1f21bc2c3",1675538608),$APP.$cljs$cst$2675$family$$,"Tangerine",$APP.$cljs$cst$725$name$$,"Tangerine",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tangerine/v18/IurY6Y5j_oScZZow4VOBDpxNhLBQ4Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tangerine/v18/Iurd6Y5j_oScZZow4VO5srNpjJtM6G0t9w.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tapestry",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9344519a-95e0-45b3-9678-e3a535201993",2142308328),$APP.$cljs$cst$2675$family$$,"Tapestry",$APP.$cljs$cst$725$name$$,"Tapestry",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tapestry/v6/SlGTmQecrosEYXhaGBIkqnB6aSQU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-taprom",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ac1b6710-537d-43ca-b0d4-f3e08f37633c",1862650662),$APP.$cljs$cst$2675$family$$,"Taprom",$APP.$cljs$cst$725$name$$,"Taprom",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taprom/v29/UcCn3F82JHycULbFQyk3-0kvHg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tauri",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a5648008-cc7b-482d-bf46-ca5cc1dd2021",
2144959756),$APP.$cljs$cst$2675$family$$,"Tauri",$APP.$cljs$cst$725$name$$,"Tauri",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tauri/v20/TwMA-IISS0AM3IpVWHU_TBqO.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-taviraj",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f88cdc36-07d4-45ba-825d-1e52c2edefd8",1625494707),$APP.$cljs$cst$2675$family$$,"Taviraj",$APP.$cljs$cst$725$name$$,"Taviraj",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",
$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahcbv8Cj3ylylTXzRIorV8N1jU2gog.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahcdv8Cj3ylylTXzTOwTM8lxr0iwolLl.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahccv8Cj3ylylTXzRCYKd-lbgUS5u0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahcev8Cj3ylylTXzTOwTn-hRhWa8q0v8ag.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahccv8Cj3ylylTXzREIJd-lbgUS5u0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/taviraj/v15/ahcev8Cj3ylylTXzTOwT--tRhWa8q0v8ag.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahcZv8Cj3ylylTXzfO4hU-FwnU0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahcbv8Cj3ylylTXzTOwrV8N1jU2gog.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahccv8Cj3ylylTXzRBoId-lbgUS5u0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahcev8Cj3ylylTXzTOwTo-pRhWa8q0v8ag.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahccv8Cj3ylylTXzRDYPd-lbgUS5u0s.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahcev8Cj3ylylTXzTOwTj-1RhWa8q0v8ag.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/taviraj/v15/ahccv8Cj3ylylTXzRFIOd-lbgUS5u0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahcev8Cj3ylylTXzTOwT6-xRhWa8q0v8ag.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",
$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahccv8Cj3ylylTXzRE4Nd-lbgUS5u0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahcev8Cj3ylylTXzTOwT9-9RhWa8q0v8ag.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahccv8Cj3ylylTXzRGoMd-lbgUS5u0s.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/taviraj/v15/ahcev8Cj3ylylTXzTOwT0-5RhWa8q0v8ag.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-teachers",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("58d5536e-bc25-405a-b2d8-9b08da250e0c",-861445407),$APP.$cljs$cst$2675$family$$,"Teachers",$APP.$cljs$cst$725$name$$,"Teachers",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/teachers/v6/H4c5BXKVncXVmUGsgTwx4E9oHx2xfjBr3powY55O4AS32A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/teachers/v6/H4c5BXKVncXVmUGsgTwx4E9oHx2xfjBr7JowY55O4AS32A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/teachers/v6/H4c5BXKVncXVmUGsgTwx4E9oHx2xfjBrAJ0wY55O4AS32A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/teachers/v6/H4c5BXKVncXVmUGsgTwx4E9oHx2xfjBrOZ0wY55O4AS32A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/teachers/v6/H4c5BXKVncXVmUGsgTwx4E9oHx2xfjBrXp0wY55O4AS32A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,
"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/teachers/v6/H4c3BXKVncXVmUGsgRY40rCwdnYr0Dd-FtnYIJRKwgGn2JLo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/teachers/v6/H4c3BXKVncXVmUGsgRY40rCwdnYr0Dd-FtnqIJRKwgGn2JLo.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/teachers/v6/H4c3BXKVncXVmUGsgRY40rCwdnYr0Dd-FtkGJ5RKwgGn2JLo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/teachers/v6/H4c3BXKVncXVmUGsgRY40rCwdnYr0Dd-Ftk_J5RKwgGn2JLo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/teachers/v6/H4c3BXKVncXVmUGsgRY40rCwdnYr0Dd-FtlYJ5RKwgGn2JLo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-teko",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("76819afb-5f35-4b44-ae41-a099bde0f383",-1052099345),$APP.$cljs$cst$2675$family$$,"Teko",$APP.$cljs$cst$725$name$$,"Teko",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/teko/v23/LYjYdG7kmE0gV69VVPPdFl06VN9JG7Sy3TKEvkCF.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/teko/v23/LYjYdG7kmE0gV69VVPPdFl06VN8XG7Sy3TKEvkCF.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/teko/v23/LYjYdG7kmE0gV69VVPPdFl06VN8lG7Sy3TKEvkCF.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/teko/v23/LYjYdG7kmE0gV69VVPPdFl06VN_JHLSy3TKEvkCF.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/teko/v23/LYjYdG7kmE0gV69VVPPdFl06VN_wHLSy3TKEvkCF.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tektur",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ef804183-0a3d-4fa8-b05f-eb07a04febc4",-974847232),
$APP.$cljs$cst$2675$family$$,"Tektur",$APP.$cljs$cst$725$name$$,"Tektur",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tektur/v6/XoHN2YHtS7q969kXCjzlV0aSkS_o8OacmTe0TYlYFot8TrwuVYtOY8P7TWd0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tektur/v6/XoHN2YHtS7q969kXCjzlV0aSkS_o8OacmTe0TYlYFot8TrwcVYtOY8P7TWd0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tektur/v6/XoHN2YHtS7q969kXCjzlV0aSkS_o8OacmTe0TYlYFot8TrzwUotOY8P7TWd0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tektur/v6/XoHN2YHtS7q969kXCjzlV0aSkS_o8OacmTe0TYlYFot8TrzJUotOY8P7TWd0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tektur/v6/XoHN2YHtS7q969kXCjzlV0aSkS_o8OacmTe0TYlYFot8TryuUotOY8P7TWd0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tektur/v6/XoHN2YHtS7q969kXCjzlV0aSkS_o8OacmTe0TYlYFot8TryHUotOY8P7TWd0.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-telex",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("37068af5-7382-43e1-b6fe-c1d6b122b887",-18046743),$APP.$cljs$cst$2675$family$$,"Telex",$APP.$cljs$cst$725$name$$,"Telex",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/telex/v18/ieVw2Y1fKWmIO9fTB1piKFIf.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tenali-ramakrishna",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8ef5da98-b77b-448f-80e1-b2235854b6f9",203319054),$APP.$cljs$cst$2675$family$$,"Tenali Ramakrishna",$APP.$cljs$cst$725$name$$,"Tenali Ramakrishna",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tenaliramakrishna/v14/raxgHj6Yt9gAN3LLKs0BZVMo8jmwn1-8KJXqUFFvtA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tenor-sans",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("aa90ee30-af5b-4e30-b493-62eb5e498fbb",-484653874),$APP.$cljs$cst$2675$family$$,"Tenor Sans",$APP.$cljs$cst$725$name$$,"Tenor Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/tenorsans/v21/bx6ANxqUneKx06UkIXISr3JyC22IyqI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-text-me-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5494a80d-6321-441a-b6db-b95ad365c73b",2089834080),$APP.$cljs$cst$2675$family$$,"Text Me One",$APP.$cljs$cst$725$name$$,"Text Me One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/textmeone/v26/i7dOIFdlayuLUvgoFvHQFWZcalayGhyV.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-texturina",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8707f088-128a-4f42-a2ec-f6d613943e65",-1421404360),$APP.$cljs$cst$2675$family$$,"Texturina",$APP.$cljs$cst$725$name$$,
"Texturina",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mM1nxpEtL3pXiAulRTkY-HGmNEX1b9NspjMwhAgliHhVrXy2eYG_Ug25riW1OD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mM1nxpEtL3pXiAulRTkY-HGmNEX1b9NspjMwhAgliHhVrXy2cYGvUg25riW1OD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mM1nxpEtL3pXiAulRTkY-HGmNEX1b9NspjMwhAgliHhVrXy2fGGvUg25riW1OD.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mM1nxpEtL3pXiAulRTkY-HGmNEX1b9NspjMwhAgliHhVrXy2eYGvUg25riW1OD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mM1nxpEtL3pXiAulRTkY-HGmNEX1b9NspjMwhAgliHhVrXy2eqGvUg25riW1OD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mM1nxpEtL3pXiAulRTkY-HGmNEX1b9NspjMwhAgliHhVrXy2dGHfUg25riW1OD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mM1nxpEtL3pXiAulRTkY-HGmNEX1b9NspjMwhAgliHhVrXy2d_HfUg25riW1OD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mM1nxpEtL3pXiAulRTkY-HGmNEX1b9NspjMwhAgliHhVrXy2cYHfUg25riW1OD.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mM1nxpEtL3pXiAulRTkY-HGmNEX1b9NspjMwhAgliHhVrXy2cxHfUg25riW1OD.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mO1nxpEtL3pXiAulR5mL129FhZmLj7I4oiSUJyfYDu7sB5zHJQWR1i0Z7AXkODN94.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mO1nxpEtL3pXiAulR5mL129FhZmLj7I4oiSUJyfYDu7sB5zHJQWZ1j0Z7AXkODN94.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mO1nxpEtL3pXiAulR5mL129FhZmLj7I4oiSUJyfYDu7sB5zHJQWUNj0Z7AXkODN94.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mO1nxpEtL3pXiAulR5mL129FhZmLj7I4oiSUJyfYDu7sB5zHJQWR1j0Z7AXkODN94.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mO1nxpEtL3pXiAulR5mL129FhZmLj7I4oiSUJyfYDu7sB5zHJQWS9j0Z7AXkODN94.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mO1nxpEtL3pXiAulR5mL129FhZmLj7I4oiSUJyfYDu7sB5zHJQWcNk0Z7AXkODN94.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",
$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mO1nxpEtL3pXiAulR5mL129FhZmLj7I4oiSUJyfYDu7sB5zHJQWfpk0Z7AXkODN94.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mO1nxpEtL3pXiAulR5mL129FhZmLj7I4oiSUJyfYDu7sB5zHJQWZ1k0Z7AXkODN94.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/texturina/v32/c4mO1nxpEtL3pXiAulR5mL129FhZmLj7I4oiSUJyfYDu7sB5zHJQWbRk0Z7AXkODN94.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-thasadith",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("412dae0b-7d80-4d05-a953-dcbe710f6635",
1644453238),$APP.$cljs$cst$2675$family$$,"Thasadith",$APP.$cljs$cst$725$name$$,"Thasadith",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/thasadith/v13/mtG44_1TIqPYrd_f5R1YsEkU0CWuFw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/thasadith/v13/mtG-4_1TIqPYrd_f5R1oskMQ8iC-F1ZE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/thasadith/v13/mtG94_1TIqPYrd_f5R1gDGYw2A6yHk9d8w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/thasadith/v13/mtGj4_1TIqPYrd_f5R1osnus3QS2PEpN8zxA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-the-girl-next-door",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4e56ec91-67d7-4f51-9228-e0f2e8f36876",1375462448),$APP.$cljs$cst$2675$family$$,"The Girl Next Door",$APP.$cljs$cst$725$name$$,"The Girl Next Door",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/thegirlnextdoor/v25/pe0zMJCIMIsBjFxqYBIcZ6_OI5oFHCYIV7t7w6bE2A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-the-nautigal",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("57ac56cf-00cc-45cd-b5c8-db60dc8c8d14",722623225),$APP.$cljs$cst$2675$family$$,"The Nautigal",$APP.$cljs$cst$725$name$$,"The Nautigal",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/thenautigal/v8/VdGZAZ8ZH51Lvng9fQV2bfKr5wVk09Se5Q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/thenautigal/v8/VdGGAZ8ZH51Lvng9fQV2bfKTWypA2_-C7LoS7g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tienne",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("512a6290-e76f-4236-819d-1b99c8627d87",-1085898901),$APP.$cljs$cst$2675$family$$,"Tienne",$APP.$cljs$cst$725$name$$,"Tienne",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tienne/v21/AYCKpX7pe9YCRP0LkEPHSFNyxw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tienne/v21/AYCJpX7pe9YCRP0zLGzjQHhuzvef5Q.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tienne/v21/AYCJpX7pe9YCRP0zFG7jQHhuzvef5Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tiktok-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("93548575-cd44-4e17-8dd7-d57a60b60705",1269989693),$APP.$cljs$cst$2675$family$$,
"TikTok Sans",$APP.$cljs$cst$725$name$$,"TikTok Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tiktoksans/v7/70kbu7g-Lm8OXGnh_Ow1sUfFMmlnhbRF425wxXH-UGeud7XItbaHtxhggMrrmAvSNAHtMV6x5PpBL2J5Rgbj-Bo7VuH1pFroETJ6Rg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tiktoksans/v7/70kbu7g-Lm8OXGnh_Ow1sUfFMmlnhbRF425wxXH-UGeud7XItbaHtxhggMrrmAvSNAHtMV6x5PpBL2J5Rgbj-Bo7COH1pFroETJ6Rg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tiktoksans/v7/70kbu7g-Lm8OXGnh_Ow1sUfFMmlnhbRF425wxXH-UGeud7XItbaHtxhggMrrmAvSNAHtMV6x5PpBL2J5Rgbj-Bo7OuH1pFroETJ6Rg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tiktoksans/v7/70kbu7g-Lm8OXGnh_Ow1sUfFMmlnhbRF425wxXH-UGeud7XItbaHtxhggMrrmAvSNAHtMV6x5PpBL2J5Rgbj-Bo71ub1pFroETJ6Rg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tiktoksans/v7/70kbu7g-Lm8OXGnh_Ow1sUfFMmlnhbRF425wxXH-UGeud7XItbaHtxhggMrrmAvSNAHtMV6x5PpBL2J5Rgbj-Bo77-b1pFroETJ6Rg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,
"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tiktoksans/v7/70kbu7g-Lm8OXGnh_Ow1sUfFMmlnhbRF425wxXH-UGeud7XItbaHtxhggMrrmAvSNAHtMV6x5PpBL2J5Rgbj-Bo7iOb1pFroETJ6Rg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tiktoksans/v7/70kbu7g-Lm8OXGnh_Ow1sUfFMmlnhbRF425wxXH-UGeud7XItbaHtxhggMrrmAvSNAHtMV6x5PpBL2J5Rgbj-Bo7oeb1pFroETJ6Rg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tillana",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("59348bf6-daf6-4474-836e-5be463c9ac77",523897667),$APP.$cljs$cst$2675$family$$,"Tillana",$APP.$cljs$cst$725$name$$,"Tillana",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tillana/v15/VuJxdNvf35P4qJ1OeKbXOIFneRo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tillana/v15/VuJ0dNvf35P4qJ1OQFL-HIlMZRNcp0o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tillana/v15/VuJ0dNvf35P4qJ1OQH75HIlMZRNcp0o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tillana/v15/VuJ0dNvf35P4qJ1OQBr4HIlMZRNcp0o.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tillana/v15/VuJ0dNvf35P4qJ1OQAb7HIlMZRNcp0o.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tilt-neon",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e72d7a74-ae60-4771-8097-6797466b6af4",1269862575),$APP.$cljs$cst$2675$family$$,
"Tilt Neon",$APP.$cljs$cst$725$name$$,"Tilt Neon",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tiltneon/v12/E21L_d7gguXdwD9LEFY2WCeElCNtd-eBqpHp1TzrkJSmwpj5ndxquXK9WualJ9DS.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tilt-prism",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c18e9f5c-5d2a-40a9-8f79-80e0c92730ae",-1678952847),$APP.$cljs$cst$2675$family$$,"Tilt Prism",$APP.$cljs$cst$725$name$$,"Tilt Prism",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tiltprism/v16/5h11iZgyPHoZ3YikNzWGfWey2dCAZXT-bH9V4VGn-FJ7tLI25oc_rIbwoTSrn86NKw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tilt-warp",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("fd1b621b-be47-451f-af18-b1ca888c0961",-1150225104),$APP.$cljs$cst$2675$family$$,"Tilt Warp",$APP.$cljs$cst$725$name$$,"Tilt Warp",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tiltwarp/v18/AlZc_zVDs5XpmO7yn3w7flUoytXJp3z29uEwmEMLEJljLXvT8UJSZTBxAVfMGOPb.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-timmana",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("339da122-479e-421a-9c85-00445e15445b",-1699615960),$APP.$cljs$cst$2675$family$$,"Timmana",$APP.$cljs$cst$725$name$$,"Timmana",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/timmana/v14/6xKvdShfL9yK-rvpCmvbKHwJUOM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tinos",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d3ac37d0-5456-4718-8209-92d7d2f09851",-2027424293),$APP.$cljs$cst$2675$family$$,"Tinos",$APP.$cljs$cst$725$name$$,"Tinos",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tinos/v25/buE4poGnedXvwgX8dGVh8TI-.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/tinos/v25/buE2poGnedXvwjX-fmFD9CI-4NU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tinos/v25/buE1poGnedXvwj1AW0Fp2i43-cxL.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tinos/v25/buEzpoGnedXvwjX-Rt1s0CoV_NxLeiw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tiny5",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2236be90-e337-4554-8d37-d9dc6f56c355",13210038),$APP.$cljs$cst$2675$family$$,"Tiny5",$APP.$cljs$cst$725$name$$,"Tiny5",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tiny5/v3/KFOpCnmCvdGT7hw-z0hHAi88.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tiro-bangla",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0f658da8-d95d-4176-a186-f0dfb5d91db4",1513712286),$APP.$cljs$cst$2675$family$$,
"Tiro Bangla",$APP.$cljs$cst$725$name$$,"Tiro Bangla",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirobangla/v6/IFSgHe1Tm95E3O8b5i2V8MG9-UPeuz4i.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirobangla/v6/IFSiHe1Tm95E3O8b5i2V8PG_80f8vi4imBM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tiro-devanagari-hindi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7dbcef8f-abde-422e-ba00-7a950924a6fa",891231337),$APP.$cljs$cst$2675$family$$,
"Tiro Devanagari Hindi",$APP.$cljs$cst$725$name$$,"Tiro Devanagari Hindi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirodevanagarihindi/v5/55xyezN7P8T4e0_CfIJrwdodg9HoYw0i-M9fSOkOfG0Y3A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirodevanagarihindi/v5/55x8ezN7P8T4e0_CfIJrwdodg9HoYw0i-M9vSuMKXmgI3F_o.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tiro-devanagari-marathi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3e068388-f401-4a8f-94c4-de4cec1dc45b",
-75533970),$APP.$cljs$cst$2675$family$$,"Tiro Devanagari Marathi",$APP.$cljs$cst$725$name$$,"Tiro Devanagari Marathi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirodevanagarimarathi/v5/fC1xPZBSZHrRhS3rd4M0MAPNJUHl4znXCxAkotDrDJYM2lAZ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirodevanagarimarathi/v5/fC1zPZBSZHrRhS3rd4M0MAPNJUHl4znXCxAkouDpBpIu30AZbUY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tiro-devanagari-sanskrit",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1fef8be8-d8d4-40f8-bdba-48b647b7a84f",
1123690602),$APP.$cljs$cst$2675$family$$,"Tiro Devanagari Sanskrit",$APP.$cljs$cst$725$name$$,"Tiro Devanagari Sanskrit",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirodevanagarisanskrit/v5/MCoAzBbr09vVUgVBM8FWu_yZdZkhkg-I0nUlb59pEoEqgtOh0w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirodevanagarisanskrit/v5/MCoGzBbr09vVUgVBM8FWu_yZdZkhkg-I0nUlb59ZEIsuoNax06MM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tiro-gurmukhi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a3ab166c-047b-4121-a53a-ac7d427fa8cf",
522320284),$APP.$cljs$cst$2675$family$$,"Tiro Gurmukhi",$APP.$cljs$cst$725$name$$,"Tiro Gurmukhi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirogurmukhi/v6/x3dmckXSYq-Uqjc048JUF7Jvly7HAQsyA2Y.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirogurmukhi/v6/x3d4ckXSYq-Uqjc048JUF7JvpyzNBSk3E2YljQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tiro-kannada",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("331bf8d7-b6a2-4915-9e96-e8e75bb9acb9",
1930866339),$APP.$cljs$cst$2675$family$$,"Tiro Kannada",$APP.$cljs$cst$725$name$$,"Tiro Kannada",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirokannada/v6/CSR44ztKmvqaDxEDJFY7CIYKSPl6tOU9Eg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirokannada/v6/CSRm4ztKmvqaDxEDJFY7CIY6SvN-luAtEnKp.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tiro-tamil",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("abb0f3df-b5ba-4a4a-a14f-efd9a532ba9b",
-1891289402),$APP.$cljs$cst$2675$family$$,"Tiro Tamil",$APP.$cljs$cst$725$name$$,"Tiro Tamil",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirotamil/v11/m8JXjfVIf7OT22n3M-S_ULRvamODxdI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirotamil/v11/m8JVjfVIf7OT22n3M-S_YLZlbkGG1dKEDw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tiro-telugu",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a425a48e-2c59-4823-b6b9-d8925ced4e7b",
1242945621),$APP.$cljs$cst$2675$family$$,"Tiro Telugu",$APP.$cljs$cst$725$name$$,"Tiro Telugu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirotelugu/v7/aFTQ7PxlZWk2EPiSymjXdKSNQqn0X0BO.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirotelugu/v7/aFTS7PxlZWk2EPiSymjXdJSPSK3WWlBOoas.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tirra",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3f0e8afa-0a99-4208-b15e-536d87d041f8",798393292),
$APP.$cljs$cst$2675$family$$,"Tirra",$APP.$cljs$cst$725$name$$,"Tirra",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirra/v2/WBLrrEnNakREGrPF3AHdWn3J.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirra/v2/WBLmrEnNakREGosx9SXVcWHALdio.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirra/v2/WBLmrEnNakREGosd8iXVcWHALdio.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirra/v2/WBLmrEnNakREGot58yXVcWHALdio.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/tirra/v2/WBLmrEnNakREGotl8CXVcWHALdio.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tirra/v2/WBLmrEnNakREGotB8SXVcWHALdio.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-titan-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d71b2648-d02e-49f8-ad72-c89b18d2d5c8",
-1753096607),$APP.$cljs$cst$2675$family$$,"Titan One",$APP.$cljs$cst$725$name$$,"Titan One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/titanone/v17/mFTzWbsGxbbS_J5cQcjykzIn2Etikg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-titillium-web",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("565afe46-7102-4e8a-9a59-575fb72a7435",-2102221793),$APP.$cljs$cst$2675$family$$,"Titillium Web",$APP.$cljs$cst$725$name$$,"Titillium Web",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",
$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/titilliumweb/v19/NaPDcZTIAOhVxoMyOr9n_E7ffAzHKIx5YrSYqWM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/titilliumweb/v19/NaPFcZTIAOhVxoMyOr9n_E7fdMbewI1zZpaduWMmxA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/titilliumweb/v19/NaPDcZTIAOhVxoMyOr9n_E7ffGjEKIx5YrSYqWM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/titilliumweb/v19/NaPFcZTIAOhVxoMyOr9n_E7fdMbepI5zZpaduWMmxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/titilliumweb/v19/NaPecZTIAOhVxoMyOr9n_E7fRMTsDIRSfr0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/titilliumweb/v19/NaPAcZTIAOhVxoMyOr9n_E7fdMbmCKZXbr2BsA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/titilliumweb/v19/NaPDcZTIAOhVxoMyOr9n_E7ffBzCKIx5YrSYqWM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/titilliumweb/v19/NaPFcZTIAOhVxoMyOr9n_E7fdMbe0IhzZpaduWMmxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/titilliumweb/v19/NaPDcZTIAOhVxoMyOr9n_E7ffHjDKIx5YrSYqWM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/titilliumweb/v19/NaPFcZTIAOhVxoMyOr9n_E7fdMbetIlzZpaduWMmxA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,
[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/titilliumweb/v19/NaPDcZTIAOhVxoMyOr9n_E7ffEDBKIx5YrSYqWM.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tomorrow",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e5d807f9-1991-4945-801e-87512fd7e98a",1467285777),$APP.$cljs$cst$2675$family$$,"Tomorrow",$APP.$cljs$cst$725$name$$,
"Tomorrow",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLgrETNbFtZCeGqgR2xe2XiKMiokE4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLirETNbFtZCeGqgRXXQwHoLOqtgE5h0A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLhrETNbFtZCeGqgR0dWkXIBsShiVd4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLjrETNbFtZCeGqgRXXQ63JDMCDjEd4yVY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/tomorrow/v19/WBLhrETNbFtZCeGqgR15WUXIBsShiVd4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLjrETNbFtZCeGqgRXXQ8nKDMCDjEd4yVY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLmrETNbFtZCeGqgSXVcWHALdio.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLgrETNbFtZCeGqgRXXe2XiKMiokE4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLhrETNbFtZCeGqgR0hWEXIBsShiVd4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLjrETNbFtZCeGqgRXXQ5HLDMCDjEd4yVY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLhrETNbFtZCeGqgR0NX0XIBsShiVd4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/tomorrow/v19/WBLjrETNbFtZCeGqgRXXQ73MDMCDjEd4yVY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLhrETNbFtZCeGqgR1pXkXIBsShiVd4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",
$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLjrETNbFtZCeGqgRXXQ9nNDMCDjEd4yVY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLhrETNbFtZCeGqgR11XUXIBsShiVd4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLjrETNbFtZCeGqgRXXQ8XODMCDjEd4yVY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLhrETNbFtZCeGqgR1RXEXIBsShiVd4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tomorrow/v19/WBLjrETNbFtZCeGqgRXXQ-HPDMCDjEd4yVY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tourney",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c105e0a3-971a-4ad2-a65a-a2514815e45f",
-62671115),$APP.$cljs$cst$2675$family$$,"Tourney",$APP.$cljs$cst$725$name$$,"Tourney",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZa_ztDtYzv1tzq1wcJnbVt7xseomk-tNs7qrzTWbyt8n7GOQByZTp1I1LcGA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZa_ztDtYzv1tzq1wcJnbVt7xseomk-tNs7qrzTWbyt8n7GuQFyZTp1I1LcGA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZa_ztDtYzv1tzq1wcJnbVt7xseomk-tNs7qrzTWbyt8n7GZwFyZTp1I1LcGA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZa_ztDtYzv1tzq1wcJnbVt7xseomk-tNs7qrzTWbyt8n7GOQFyZTp1I1LcGA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZa_ztDtYzv1tzq1wcJnbVt7xseomk-tNs7qrzTWbyt8n7GCwFyZTp1I1LcGA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZa_ztDtYzv1tzq1wcJnbVt7xseomk-tNs7qrzTWbyt8n7G5wZyZTp1I1LcGA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZa_ztDtYzv1tzq1wcJnbVt7xseomk-tNs7qrzTWbyt8n7G3gZyZTp1I1LcGA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZa_ztDtYzv1tzq1wcJnbVt7xseomk-tNs7qrzTWbyt8n7GuQZyZTp1I1LcGA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZa_ztDtYzv1tzq1wcJnbVt7xseomk-tNs7qrzTWbyt8n7GkAZyZTp1I1LcGA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZc_ztDtYzv1tzq_Q47flUUvI2wpXz29ilymEMLMNc3XHnT8UKaJzBxAVfMGOPb.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/tourney/v16/AlZc_ztDtYzv1tzq_Q47flUUvI2wpXz29ilymEMLMNc3XHnT8UIaJjBxAVfMGOPb.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZc_ztDtYzv1tzq_Q47flUUvI2wpXz29ilymEMLMNc3XHnT8ULEJjBxAVfMGOPb.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZc_ztDtYzv1tzq_Q47flUUvI2wpXz29ilymEMLMNc3XHnT8UKaJjBxAVfMGOPb.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/tourney/v16/AlZc_ztDtYzv1tzq_Q47flUUvI2wpXz29ilymEMLMNc3XHnT8UKoJjBxAVfMGOPb.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZc_ztDtYzv1tzq_Q47flUUvI2wpXz29ilymEMLMNc3XHnT8UJEITBxAVfMGOPb.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZc_ztDtYzv1tzq_Q47flUUvI2wpXz29ilymEMLMNc3XHnT8UJ9ITBxAVfMGOPb.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/tourney/v16/AlZc_ztDtYzv1tzq_Q47flUUvI2wpXz29ilymEMLMNc3XHnT8UIaITBxAVfMGOPb.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tourney/v16/AlZc_ztDtYzv1tzq_Q47flUUvI2wpXz29ilymEMLMNc3XHnT8UIzITBxAVfMGOPb.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-trade-winds",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7e3b37ec-5a3e-40ca-8591-c3836f6dbf93",1054157693),$APP.$cljs$cst$2675$family$$,"Trade Winds",$APP.$cljs$cst$725$name$$,"Trade Winds",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tradewinds/v18/AYCPpXPpYNIIT7h8-QenM3Jq7PKP5Z_G.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-train-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("52878de0-f649-4923-925b-a5f0b9505c1d",2064076645),$APP.$cljs$cst$2675$family$$,"Train One",$APP.$cljs$cst$725$name$$,"Train One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trainone/v16/gyB-hwkiNtc6KnxUVjWHOqbZRY7JVQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-triodion",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2e182848-1df0-4d62-af26-60a6f50e8be1",1871784494),$APP.$cljs$cst$2675$family$$,
"Triodion",$APP.$cljs$cst$725$name$$,"Triodion",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/triodion/v3/IFSnHe5TgMVEmMQV5mr5u-W10l_X.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-trirong",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("49cfe384-7a63-400e-97f2-09e04b1a4f93",-1775508639),$APP.$cljs$cst$2675$family$$,"Trirong",$APP.$cljs$cst$725$name$$,"Trirong",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3EqXNgp8wxdOdOl-go3YRl6ujngw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3CqXNgp8wxdOdOn44QuY5hyO33g8IY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",
$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3DqXNgp8wxdOdOl0QJ_a5L5uH-mts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3BqXNgp8wxdOdOn44QFa9B4sP7itsB5g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3DqXNgp8wxdOdOlyAK_a5L5uH-mts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/trirong/v17/7r3BqXNgp8wxdOdOn44QcaxB4sP7itsB5g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3GqXNgp8wxdOdOr4wi2aZg-ug.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3EqXNgp8wxdOdOn44o3YRl6ujngw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3DqXNgp8wxdOdOl3gL_a5L5uH-mts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3BqXNgp8wxdOdOn44QKa1B4sP7itsB5g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3DqXNgp8wxdOdOl1QM_a5L5uH-mts.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3BqXNgp8wxdOdOn44QBapB4sP7itsB5g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/trirong/v17/7r3DqXNgp8wxdOdOlzAN_a5L5uH-mts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3BqXNgp8wxdOdOn44QYatB4sP7itsB5g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",
$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3DqXNgp8wxdOdOlywO_a5L5uH-mts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3BqXNgp8wxdOdOn44QfahB4sP7itsB5g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3DqXNgp8wxdOdOlwgP_a5L5uH-mts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trirong/v17/7r3BqXNgp8wxdOdOn44QWalB4sP7itsB5g.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-trispace",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("aaa77085-89a5-4236-96bf-a58c75404a08",2137653428),$APP.$cljs$cst$2675$family$$,"Trispace",$APP.$cljs$cst$725$name$$,"Trispace",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trispace/v27/Yq65-LKSQC3o56LxxgRrtA6yBqsrXL5GI5KI-IUZVGsxWFIlbH9qoQl0zHugpt0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trispace/v27/Yq65-LKSQC3o56LxxgRrtA6yBqsrXL5GI5KI-IUZVGsxWFIlbP9roQl0zHugpt0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trispace/v27/Yq65-LKSQC3o56LxxgRrtA6yBqsrXL5GI5KI-IUZVGsxWFIlbCFroQl0zHugpt0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trispace/v27/Yq65-LKSQC3o56LxxgRrtA6yBqsrXL5GI5KI-IUZVGsxWFIlbH9roQl0zHugpt0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trispace/v27/Yq65-LKSQC3o56LxxgRrtA6yBqsrXL5GI5KI-IUZVGsxWFIlbE1roQl0zHugpt0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trispace/v27/Yq65-LKSQC3o56LxxgRrtA6yBqsrXL5GI5KI-IUZVGsxWFIlbKFsoQl0zHugpt0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trispace/v27/Yq65-LKSQC3o56LxxgRrtA6yBqsrXL5GI5KI-IUZVGsxWFIlbJhsoQl0zHugpt0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trispace/v27/Yq65-LKSQC3o56LxxgRrtA6yBqsrXL5GI5KI-IUZVGsxWFIlbP9soQl0zHugpt0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-trocchi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2ccee650-7dfb-47b5-98dc-d4bef966be60",
-1233115252),$APP.$cljs$cst$2675$family$$,"Trocchi",$APP.$cljs$cst$725$name$$,"Trocchi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trocchi/v19/qWcqB6WkuIDxDZLcDrtUvMeTYD0.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-trochut",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d3eddfff-69dc-4146-84bf-2e186ffeba23",-1016733290),$APP.$cljs$cst$2675$family$$,"Trochut",$APP.$cljs$cst$725$name$$,"Trochut",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trochut/v24/CHyjV-fDDlP9bDIw5nSIfVIPLns.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trochut/v24/CHyhV-fDDlP9bDIw1naCeXAKPns8jw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trochut/v24/CHymV-fDDlP9bDIw3sinWVokMnIllmA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-truculenta",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("61c1a575-cf29-4a80-92e8-57bef57edbe3",651481130),$APP.$cljs$cst$2675$family$$,"Truculenta",$APP.$cljs$cst$725$name$$,
"Truculenta",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/truculenta/v27/LhWfMVvBKusVIfNYGi1-WvRVyDdZeeiySNppcu32Mb2f06y6Oa21F6XHi0VYDX_PzOupMlAjswcFHnJMMhg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/truculenta/v27/LhWfMVvBKusVIfNYGi1-WvRVyDdZeeiySNppcu32Mb2f06y6Oa21F6XHi0VYDX_PzOupMtAiswcFHnJMMhg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/truculenta/v27/LhWfMVvBKusVIfNYGi1-WvRVyDdZeeiySNppcu32Mb2f06y6Oa21F6XHi0VYDX_PzOupMg4iswcFHnJMMhg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/truculenta/v27/LhWfMVvBKusVIfNYGi1-WvRVyDdZeeiySNppcu32Mb2f06y6Oa21F6XHi0VYDX_PzOupMlAiswcFHnJMMhg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/truculenta/v27/LhWfMVvBKusVIfNYGi1-WvRVyDdZeeiySNppcu32Mb2f06y6Oa21F6XHi0VYDX_PzOupMmIiswcFHnJMMhg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/truculenta/v27/LhWfMVvBKusVIfNYGi1-WvRVyDdZeeiySNppcu32Mb2f06y6Oa21F6XHi0VYDX_PzOupMo4lswcFHnJMMhg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/truculenta/v27/LhWfMVvBKusVIfNYGi1-WvRVyDdZeeiySNppcu32Mb2f06y6Oa21F6XHi0VYDX_PzOupMrclswcFHnJMMhg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/truculenta/v27/LhWfMVvBKusVIfNYGi1-WvRVyDdZeeiySNppcu32Mb2f06y6Oa21F6XHi0VYDX_PzOupMtAlswcFHnJMMhg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/truculenta/v27/LhWfMVvBKusVIfNYGi1-WvRVyDdZeeiySNppcu32Mb2f06y6Oa21F6XHi0VYDX_PzOupMvklswcFHnJMMhg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-trykker",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8fabf737-cdf7-47ac-a8aa-e7597a92c2e9",-1973906709),$APP.$cljs$cst$2675$family$$,"Trykker",$APP.$cljs$cst$725$name$$,"Trykker",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/trykker/v22/KtktALyWZJXudUPzhNnoOd2j22U.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tsukimi-rounded",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("df7774b8-9e7e-47a3-be27-514180cefa1b",-2046938519),$APP.$cljs$cst$2675$family$$,
"Tsukimi Rounded",$APP.$cljs$cst$725$name$$,"Tsukimi Rounded",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tsukimirounded/v14/sJoZ3LJNksWZO0LvnZwkF3HtoB7VkVsqN7MT3T9X8g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tsukimirounded/v14/sJoc3LJNksWZO0LvnZwkF3HtoB7tPXMOP5gP1A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tsukimirounded/v14/sJoZ3LJNksWZO0LvnZwkF3HtoB7VyVoqN7MT3T9X8g.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tsukimirounded/v14/sJoZ3LJNksWZO0LvnZwkF3HtoB7V5V0qN7MT3T9X8g.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/tsukimirounded/v14/sJoZ3LJNksWZO0LvnZwkF3HtoB7VgVwqN7MT3T9X8g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tuffy",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("08a62437-418f-4947-bee7-ee369ee98361",256868521),$APP.$cljs$cst$2675$family$$,"Tuffy",$APP.$cljs$cst$725$name$$,"Tuffy",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tuffy/v1/1q2IY56bHkJl7rxzF4xmyfYe.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tuffy/v1/1q2GY56bHkJl7oxxHYhEzOYenEU.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tuffy/v1/1q2FY56bHkJl7oTPOKhu4uoXhVzg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/tuffy/v1/1q2DY56bHkJl7oxxJTRr6O41gEzgZoQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-tulpen-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("1773d896-39c3-4ecc-917a-c8ba47a58201",2056384847),$APP.$cljs$cst$2675$family$$,"Tulpen One",$APP.$cljs$cst$725$name$$,"Tulpen One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/tulpenone/v26/dFa6ZfeC474skLgesc0CWj0w_HyIRlE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-turret-road",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ea7b16f1-e4f1-45fb-9d39-cd3f38cc324f",1897327187),$APP.$cljs$cst$2675$family$$,"Turret Road",$APP.$cljs$cst$725$name$$,
"Turret Road",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/turretroad/v11/pxidypMgpcBFjE84Zv-fE0ONEdeLYk1Mq3ap.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/turretroad/v11/pxidypMgpcBFjE84Zv-fE0PpEteLYk1Mq3ap.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/turretroad/v11/pxiAypMgpcBFjE84Zv-fE3tFOvODSVFF.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/turretroad/v11/pxidypMgpcBFjE84Zv-fE0OxE9eLYk1Mq3ap.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/turretroad/v11/pxidypMgpcBFjE84Zv-fE0P5FdeLYk1Mq3ap.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/turretroad/v11/pxidypMgpcBFjE84Zv-fE0PlFteLYk1Mq3ap.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-twinkle-star",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("94127bb0-fae0-4dbb-ad55-13ff16a24fff",273007704),$APP.$cljs$cst$2675$family$$,"Twinkle Star",$APP.$cljs$cst$725$name$$,"Twinkle Star",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/twinklestar/v8/pe0pMI6IL4dPoFl9LGEmY6WaA_Rue1UwVg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ubuntu",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("34c0ce0c-567c-4a75-b0c6-568099e82765",2137376887),$APP.$cljs$cst$2675$family$$,"Ubuntu",$APP.$cljs$cst$725$name$$,"Ubuntu",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntu/v21/4iCv6KVjbNBYlgoC1CzTt2aMH4V_gg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntu/v21/4iCp6KVjbNBYlgoKejZftWyIPYBvgpUI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntu/v21/4iCs6KVjbNBYlgo6eAT3v02QFg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ubuntu/v21/4iCu6KVjbNBYlgoKeg7znUiAFpxm.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntu/v21/4iCv6KVjbNBYlgoCjC3Tt2aMH4V_gg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntu/v21/4iCp6KVjbNBYlgoKejYHtGyIPYBvgpUI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntu/v21/4iCv6KVjbNBYlgoCxCvTt2aMH4V_gg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntu/v21/4iCp6KVjbNBYlgoKejZPsmyIPYBvgpUI.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ubuntu-condensed",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("74ca255a-2716-4772-97c2-73937fd2d213",626300107),$APP.$cljs$cst$2675$family$$,"Ubuntu Condensed",$APP.$cljs$cst$725$name$$,
"Ubuntu Condensed",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntucondensed/v17/u-4k0rCzjgs5J7oXnJcM_0kACGMtf-fVqvHoJXw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-ubuntu-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a8a90b87-aa8f-4747-839d-bd33130d0d86",1600164768),$APP.$cljs$cst$2675$family$$,"Ubuntu Mono",$APP.$cljs$cst$725$name$$,"Ubuntu Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntumono/v19/KFOjCneDtsqEr0keqCMhbBc9AMX6lJBP.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntumono/v19/KFOhCneDtsqEr0keqCMhbCc_CsHYkYBPY3o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntumono/v19/KFO-CneDtsqEr0keqCMhbC-BL-Hyv4xGemO1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntumono/v19/KFO8CneDtsqEr0keqCMhbCc_Mn33tYhkf3O1GVg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ubuntu-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("850a5fb6-c972-49e3-a88a-906a03a205c1",17000403),$APP.$cljs$cst$2675$family$$,"Ubuntu Sans",$APP.$cljs$cst$725$name$$,"Ubuntu Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3omWd6mSRtB7_9UaLWwJnCq5ALePfPu1tPcW235R53LqrCPWbujzt7CfqLVLT9mgk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3omWd6mSRtB7_9UaLWwJnCq5ALePfPu1tPcW235R53LqrCPWbuj7t6CfqLVLT9mgk.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3omWd6mSRtB7_9UaLWwJnCq5ALePfPu1tPcW235R53LqrCPWbuj2V6CfqLVLT9mgk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3omWd6mSRtB7_9UaLWwJnCq5ALePfPu1tPcW235R53LqrCPWbujzt6CfqLVLT9mgk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3omWd6mSRtB7_9UaLWwJnCq5ALePfPu1tPcW235R53LqrCPWbujwl6CfqLVLT9mgk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3omWd6mSRtB7_9UaLWwJnCq5ALePfPu1tPcW235R53LqrCPWbuj-V9CfqLVLT9mgk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3omWd6mSRtB7_9UaLWwJnCq5ALePfPu1tPcW235R53LqrCPWbuj9x9CfqLVLT9mgk.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3omWd6mSRtB7_9UaLWwJnCq5ALePfPu1tPcW235R53LqrCPWbuj7t9CfqLVLT9mgk.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3mmWd6mSRtB7_9UaLWwLPLmXPrAaRZFVxauS9FrCyI9sOpp8jpmvM54biBUJb4iglIHg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3mmWd6mSRtB7_9UaLWwLPLmXPrAaRZFVxauS9FrCyI9sOpp8jpmvM5YbmBUJb4iglIHg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3mmWd6mSRtB7_9UaLWwLPLmXPrAaRZFVxauS9FrCyI9sOpp8jpmvM5v7mBUJb4iglIHg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3mmWd6mSRtB7_9UaLWwLPLmXPrAaRZFVxauS9FrCyI9sOpp8jpmvM54bmBUJb4iglIHg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3mmWd6mSRtB7_9UaLWwLPLmXPrAaRZFVxauS9FrCyI9sOpp8jpmvM507mBUJb4iglIHg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3mmWd6mSRtB7_9UaLWwLPLmXPrAaRZFVxauS9FrCyI9sOpp8jpmvM5P76BUJb4iglIHg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3mmWd6mSRtB7_9UaLWwLPLmXPrAaRZFVxauS9FrCyI9sOpp8jpmvM5Br6BUJb4iglIHg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusans/v4/co3mmWd6mSRtB7_9UaLWwLPLmXPrAaRZFVxauS9FrCyI9sOpp8jpmvM5Yb6BUJb4iglIHg.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ubuntu-sans-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("324bb127-5cb9-4b67-a5a0-ef7df877d6a2",1308456825),$APP.$cljs$cst$2675$family$$,"Ubuntu Sans Mono",$APP.$cljs$cst$725$name$$,"Ubuntu Sans Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusansmono/v3/jVyc7mzgBHrR5yE7ZyRg0QRJMKI4zAbgjc1t-pKe27Ev_kYRiqcZu3n0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusansmono/v3/jVyc7mzgBHrR5yE7ZyRg0QRJMKI4zAbgjc1t-pKe27Ed_kYRiqcZu3n0.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusansmono/v3/jVyc7mzgBHrR5yE7ZyRg0QRJMKI4zAbgjc1t-pKe27Hx-UYRiqcZu3n0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusansmono/v3/jVyc7mzgBHrR5yE7ZyRg0QRJMKI4zAbgjc1t-pKe27HI-UYRiqcZu3n0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusansmono/v3/jVyi7mzgBHrR5yE7ZyRg0QRJMKI45g_SchUEkQgw3KTnva5SgKM7vmn0BLE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusansmono/v3/jVyi7mzgBHrR5yE7ZyRg0QRJMKI45g_SchUEkQgw3KTnvZxSgKM7vmn0BLE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ubuntusansmono/v3/jVyi7mzgBHrR5yE7ZyRg0QRJMKI45g_SchUEkQgw3KTnvXBVgKM7vmn0BLE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ubuntusansmono/v3/jVyi7mzgBHrR5yE7ZyRg0QRJMKI45g_SchUEkQgw3KTnvUlVgKM7vmn0BLE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-uchen",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("58d8fddb-da86-4a7e-9093-be138e474fc3",1929967210),$APP.$cljs$cst$2675$family$$,"Uchen",$APP.$cljs$cst$725$name$$,"Uchen",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/uchen/v11/nKKZ-GokGZ1baIaSEQGodLxA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ultra",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9dd9aa7e-72c6-413a-b478-3e39f19fd8e9",-1453781972),$APP.$cljs$cst$2675$family$$,"Ultra",$APP.$cljs$cst$725$name$$,"Ultra",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ultra/v25/zOLy4prXmrtY-tT6yLOD6NxF.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-unbounded",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("31876dc5-47a4-485c-abd4-60deaa35c98d",380890403),$APP.$cljs$cst$2675$family$$,
"Unbounded",$APP.$cljs$cst$725$name$$,"Unbounded",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unbounded/v12/Yq6F-LOTXCb04q32xlpat-6uR42XTqtG65jx043HgP6LR0Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unbounded/v12/Yq6F-LOTXCb04q32xlpat-6uR42XTqtG60bx043HgP6LR0Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unbounded/v12/Yq6F-LOTXCb04q32xlpat-6uR42XTqtG6xjx043HgP6LR0Y.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unbounded/v12/Yq6F-LOTXCb04q32xlpat-6uR42XTqtG6yrx043HgP6LR0Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/unbounded/v12/Yq6F-LOTXCb04q32xlpat-6uR42XTqtG68b2043HgP6LR0Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unbounded/v12/Yq6F-LOTXCb04q32xlpat-6uR42XTqtG6__2043HgP6LR0Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unbounded/v12/Yq6F-LOTXCb04q32xlpat-6uR42XTqtG65j2043HgP6LR0Y.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unbounded/v12/Yq6F-LOTXCb04q32xlpat-6uR42XTqtG67H2043HgP6LR0Y.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-uncial-antiqua",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("598e7dff-b7f0-44a3-8257-b4e23de2db9f",-1383918195),$APP.$cljs$cst$2675$family$$,"Uncial Antiqua",$APP.$cljs$cst$725$name$$,"Uncial Antiqua",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/uncialantiqua/v22/N0bM2S5WOex4OUbESzoESK-i-PfRS5VBBSSF.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-underdog",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2b12cd2d-3114-46c2-8fb5-c729be283e2d",1003232032),$APP.$cljs$cst$2675$family$$,"Underdog",$APP.$cljs$cst$725$name$$,"Underdog",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/underdog/v24/CHygV-jCElj7diMroVSiU14GN2Il.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-unica-one",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("d6f32bad-5357-49e7-9b28-4906ef7ae8b0",-893292585),$APP.$cljs$cst$2675$family$$,"Unica One",$APP.$cljs$cst$725$name$$,"Unica One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unicaone/v20/DPEuYwWHyAYGVTSmalshdtffuEY7FA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-unifrakturcook",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4e541841-b4f2-466f-b0e1-c527e29d34ce",-1307283422),$APP.$cljs$cst$2675$family$$,"UnifrakturCook",$APP.$cljs$cst$725$name$$,"UnifrakturCook",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",
$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unifrakturcook/v25/IurA6Yli8YOdcoky-0PTTdkm56n05Uw13ILXs-h6.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-unifrakturmaguntia",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8e3ac7c6-6881-4dd5-9fd4-b97b5e04d321",-393904681),$APP.$cljs$cst$2675$family$$,"UnifrakturMaguntia",$APP.$cljs$cst$725$name$$,
"UnifrakturMaguntia",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unifrakturmaguntia/v22/WWXPlieVYwiGNomYU-ciRLRvEmK7oaVun2xNNgNa1A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-unkempt",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("67a47651-17fd-4c71-8659-69fcbd2b4bce",1631546703),$APP.$cljs$cst$2675$family$$,"Unkempt",$APP.$cljs$cst$725$name$$,"Unkempt",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unkempt/v22/2EbnL-Z2DFZue0DSSYYf8z2Yt_c.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unkempt/v22/2EbiL-Z2DFZue0DScTow1zWzq_5uT84.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-unlock",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cd32caff-fece-47bb-823b-db160c3a41ed",-804056224),$APP.$cljs$cst$2675$family$$,"Unlock",$APP.$cljs$cst$725$name$$,"Unlock",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/unlock/v28/7Au-p_8ykD-cDl7GKAjSwkUVOQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-unna",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e3185f84-dbaa-46c6-91f7-f154d0b53f3e",2098890985),$APP.$cljs$cst$2675$family$$,"Unna",$APP.$cljs$cst$725$name$$,"Unna",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unna/v25/AYCEpXzofN0NCpgBlGHCWFM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unna/v25/AYCKpXzofN0NOpoLkEPHSFNyxw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/unna/v25/AYCLpXzofN0NMiQusGnpRFpr3vc.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/unna/v25/AYCJpXzofN0NOpozLGzjQHhuzvef5Q.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-uoqmunthenkhung",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("efd47ffc-0893-4ba7-a65e-05c8c72966e5",1203462590),$APP.$cljs$cst$2675$family$$,"UoqMunThenKhung",$APP.$cljs$cst$725$name$$,"UoqMunThenKhung",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/uoqmunthenkhung/v1/Y4GTYa1nVTQLt-D5LoLChg5aJjIjwLL9Th8YYA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-updock",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ce394679-f69b-40d9-97a7-4851099e7e3a",-283201230),
$APP.$cljs$cst$2675$family$$,"Updock",$APP.$cljs$cst$725$name$$,"Updock",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/updock/v7/nuF4D_3dVZ70UI9SjLK3602XBw.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-urbanist",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("35fac6e0-a4ab-48aa-9b92-b8ee607f7d39",-201257615),$APP.$cljs$cst$2675$family$$,"Urbanist",$APP.$cljs$cst$725$name$$,"Urbanist",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,
"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xjDF02iFML4hGCyOCpRdycFsGxSrqDyx8fFpOrS8SlKw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xjDF02iFML4hGCyOCpRdycFsGxSrqDSx4fFpOrS8SlKw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xjDF02iFML4hGCyOCpRdycFsGxSrqDlR4fFpOrS8SlKw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xjDF02iFML4hGCyOCpRdycFsGxSrqDyx4fFpOrS8SlKw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xjDF02iFML4hGCyOCpRdycFsGxSrqD-R4fFpOrS8SlKw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/urbanist/v18/L0xjDF02iFML4hGCyOCpRdycFsGxSrqDFRkfFpOrS8SlKw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xjDF02iFML4hGCyOCpRdycFsGxSrqDLBkfFpOrS8SlKw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xjDF02iFML4hGCyOCpRdycFsGxSrqDSxkfFpOrS8SlKw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xjDF02iFML4hGCyOCpRdycFsGxSrqDYhkfFpOrS8SlKw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xtDF02iFML4hGCyMqgdyNEf6or5L2WA133VJmvacG1K4S1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xtDF02iFML4hGCyMqgdyNEf6or5L2WA113VZmvacG1K4S1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xtDF02iFML4hGCyMqgdyNEf6or5L2WA12pVZmvacG1K4S1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xtDF02iFML4hGCyMqgdyNEf6or5L2WA133VZmvacG1K4S1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xtDF02iFML4hGCyMqgdyNEf6or5L2WA13FVZmvacG1K4S1.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xtDF02iFML4hGCyMqgdyNEf6or5L2WA10pUpmvacG1K4S1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xtDF02iFML4hGCyMqgdyNEf6or5L2WA10QUpmvacG1K4S1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xtDF02iFML4hGCyMqgdyNEf6or5L2WA113UpmvacG1K4S1.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/urbanist/v18/L0xtDF02iFML4hGCyMqgdyNEf6or5L2WA11eUpmvacG1K4S1.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-vt323",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("db52e5a4-75cd-4b14-8e29-d68e5eaad25d",-116861081),$APP.$cljs$cst$2675$family$$,
"VT323",$APP.$cljs$cst$725$name$$,"VT323",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vt323/v18/pxiKyp0ihIEF2hsYHpT2dkNE.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-vampiro-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("575d052e-b121-4034-ba98-95243e5e1d6f",-1458270270),$APP.$cljs$cst$2675$family$$,"Vampiro One",$APP.$cljs$cst$725$name$$,"Vampiro One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vampiroone/v19/gokqH6DoDl5yXvJytFsdLkqnsvhIor3K.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-varela",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("4815c1f6-93b2-4d1a-80c9-bb3e9b312915",-1234741607),$APP.$cljs$cst$2675$family$$,"Varela",$APP.$cljs$cst$725$name$$,"Varela",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/varela/v17/DPEtYwqExx0AWHXJBBQFfvzDsQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-varela-round",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0fe174b9-907c-4b48-b984-4944376f1a3e",-790468680),$APP.$cljs$cst$2675$family$$,
"Varela Round",$APP.$cljs$cst$725$name$$,"Varela Round",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/varelaround/v21/w8gdH283Tvk__Lua32TysjIvoMGOD9gxZw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-varta",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("ddef93c6-49dd-4dc3-a5bb-4e9a0abceea8",-970606896),$APP.$cljs$cst$2675$family$$,"Varta",$APP.$cljs$cst$725$name$$,"Varta",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/varta/v25/Qw3AZQpJHj_6LzHUngWbrFkDH1x96j4EirE-9PGLfQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/varta/v25/Qw3AZQpJHj_6LzHUngWbrFkDH1x9tD4EirE-9PGLfQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/varta/v25/Qw3AZQpJHj_6LzHUngWbrFkDH1x9hj4EirE-9PGLfQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/varta/v25/Qw3AZQpJHj_6LzHUngWbrFkDH1x9ajkEirE-9PGLfQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/varta/v25/Qw3AZQpJHj_6LzHUngWbrFkDH1x9UzkEirE-9PGLfQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-vast-shadow",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bb08a7d0-0883-4875-84a4-20362fdf2e4e",1838513160),
$APP.$cljs$cst$2675$family$$,"Vast Shadow",$APP.$cljs$cst$725$name$$,"Vast Shadow",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vastshadow/v21/pe0qMImKOZ1V62ZwbVY9dfe6Kdpickwp.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-vazirmatn",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b795727f-43a1-457f-b6dc-5bc6565e5876",1328910753),$APP.$cljs$cst$2675$family$$,"Vazirmatn",$APP.$cljs$cst$725$name$$,"Vazirmatn",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vazirmatn/v16/Dxx78j6PP2D_kU2muijPEe1n2vVbfJRklWgyOReZ72DF_QY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vazirmatn/v16/Dxx78j6PP2D_kU2muijPEe1n2vVbfJRklegzOReZ72DF_QY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vazirmatn/v16/Dxx78j6PP2D_kU2muijPEe1n2vVbfJRklTYzOReZ72DF_QY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vazirmatn/v16/Dxx78j6PP2D_kU2muijPEe1n2vVbfJRklWgzOReZ72DF_QY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vazirmatn/v16/Dxx78j6PP2D_kU2muijPEe1n2vVbfJRklVozOReZ72DF_QY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vazirmatn/v16/Dxx78j6PP2D_kU2muijPEe1n2vVbfJRklbY0OReZ72DF_QY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vazirmatn/v16/Dxx78j6PP2D_kU2muijPEe1n2vVbfJRklY80OReZ72DF_QY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vazirmatn/v16/Dxx78j6PP2D_kU2muijPEe1n2vVbfJRkleg0OReZ72DF_QY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/vazirmatn/v16/Dxx78j6PP2D_kU2muijPEe1n2vVbfJRklcE0OReZ72DF_QY.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-vend-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6ecdf696-cd4f-4e95-961c-412210e940db",-1933015487),$APP.$cljs$cst$2675$family$$,"Vend Sans",$APP.$cljs$cst$725$name$$,"Vend Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vendsans/v1/E212_d7ijufNwCJPEUs2WCek2ncUdeeBqgeqzzfJQAJuEJw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/vendsans/v1/E212_d7ijufNwCJPEUs2WCek2ncUdeeBqlmqzzfJQAJuEJw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vendsans/v1/E212_d7ijufNwCJPEUs2WCek2ncUdeeBqmuqzzfJQAJuEJw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vendsans/v1/E212_d7ijufNwCJPEUs2WCek2ncUdeeBqoetzzfJQAJuEJw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vendsans/v1/E212_d7ijufNwCJPEUs2WCek2ncUdeeBqr6tzzfJQAJuEJw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vendsans/v1/E210_d7ijufNwCJPEUscURVbAh5_70mGv5HpeXTDRCBrAJz0nA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vendsans/v1/E210_d7ijufNwCJPEUscURVbAh5_70mGv5HpJ3TDRCBrAJz0nA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vendsans/v1/E210_d7ijufNwCJPEUscURVbAh5_70mGv5HpFXTDRCBrAJz0nA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vendsans/v1/E210_d7ijufNwCJPEUscURVbAh5_70mGv5Hp-XPDRCBrAJz0nA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vendsans/v1/E210_d7ijufNwCJPEUscURVbAh5_70mGv5HpwHPDRCBrAJz0nA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-vesper-libre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("971dc1b0-f7a8-4213-a765-c551b087ff2a",-159518836),$APP.$cljs$cst$2675$family$$,"Vesper Libre",$APP.$cljs$cst$725$name$$,"Vesper Libre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vesperlibre/v21/bx6CNxyWnf-uxPdXDHUD_Rd4D0-N2qIWVQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vesperlibre/v21/bx6dNxyWnf-uxPdXDHUD_RdA-2ap0okKXKvPlw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vesperlibre/v21/bx6dNxyWnf-uxPdXDHUD_RdAs2Cp0okKXKvPlw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/vesperlibre/v21/bx6dNxyWnf-uxPdXDHUD_RdAi2Kp0okKXKvPlw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-viaoda-libre",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7ee86736-f9a7-44c8-bcdf-3da01593358b",830369383),$APP.$cljs$cst$2675$family$$,"Viaoda Libre",$APP.$cljs$cst$725$name$$,"Viaoda Libre",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/viaodalibre/v20/vEFW2_lWCgoR6OKuRz9kcRVJb2IY2tOHXg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-vibes",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cbcd1833-19af-42e3-b028-a656b2eed857",-1982257047),
$APP.$cljs$cst$2675$family$$,"Vibes",$APP.$cljs$cst$725$name$$,"Vibes",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vibes/v16/QdVYSTsmIB6tmbd3HpbsuBlh.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-vibur",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("05e110d0-2319-4555-aa28-718937e712a2",1188481298),$APP.$cljs$cst$2675$family$$,"Vibur",$APP.$cljs$cst$725$name$$,"Vibur",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vibur/v24/DPEiYwmEzw0QRjTpLjoJd-Xa.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-victor-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c69710cb-fc2b-4c91-aca0-4ff7f3ed4a57",532493789),$APP.$cljs$cst$2675$family$$,"Victor Mono",$APP.$cljs$cst$725$name$$,"Victor Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/victormono/v5/Yq6H-LGQWyfv-LGy7lEO09xRn-T81AVB_tCyO8_NhNyOV0Y9bQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/victormono/v5/Yq6H-LGQWyfv-LGy7lEO09xRn-T81AVB_tCyu87NhNyOV0Y9bQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/victormono/v5/Yq6H-LGQWyfv-LGy7lEO09xRn-T81AVB_tCyZc7NhNyOV0Y9bQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/victormono/v5/Yq6H-LGQWyfv-LGy7lEO09xRn-T81AVB_tCyO87NhNyOV0Y9bQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/victormono/v5/Yq6H-LGQWyfv-LGy7lEO09xRn-T81AVB_tCyCc7NhNyOV0Y9bQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/victormono/v5/Yq6H-LGQWyfv-LGy7lEO09xRn-T81AVB_tCy5cnNhNyOV0Y9bQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/victormono/v5/Yq6H-LGQWyfv-LGy7lEO09xRn-T81AVB_tCy3MnNhNyOV0Y9bQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/victormono/v5/Yq6B-LGQWyfv-LGy7lEO0_ZYrRskvW7bUNen840lxtaKdUMtba8p.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/victormono/v5/Yq6B-LGQWyfv-LGy7lEO0_ZYrRskvW7bUNen842lx9aKdUMtba8p.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/victormono/v5/Yq6B-LGQWyfv-LGy7lEO0_ZYrRskvW7bUNen8417x9aKdUMtba8p.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/victormono/v5/Yq6B-LGQWyfv-LGy7lEO0_ZYrRskvW7bUNen840lx9aKdUMtba8p.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/victormono/v5/Yq6B-LGQWyfv-LGy7lEO0_ZYrRskvW7bUNen840Xx9aKdUMtba8p.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/victormono/v5/Yq6B-LGQWyfv-LGy7lEO0_ZYrRskvW7bUNen8437wNaKdUMtba8p.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/victormono/v5/Yq6B-LGQWyfv-LGy7lEO0_ZYrRskvW7bUNen843CwNaKdUMtba8p.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-vidaloka",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("868bc503-66c1-48df-9c93-11c14d5063c4",
2038049055),$APP.$cljs$cst$2675$family$$,"Vidaloka",$APP.$cljs$cst$725$name$$,"Vidaloka",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vidaloka/v19/7cHrv4c3ipenMKlEass8yn4hnCci.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-viga",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("83f49a18-ac06-402e-ab24-8dbd274a5dc2",-989562272),$APP.$cljs$cst$2675$family$$,"Viga",$APP.$cljs$cst$725$name$$,"Viga",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/viga/v15/xMQbuFFdSaiX_QIjD4e2OX8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-vina-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("41da5092-aae9-448a-8656-8b83de2d3cdd",1850868600),$APP.$cljs$cst$2675$family$$,"Vina Sans",$APP.$cljs$cst$725$name$$,"Vina Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vinasans/v8/m8JQjfZKf6-d2273MP7zcJ5BZmqa3A.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-voces",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e3fd2483-26e1-47b3-a994-27fe569538d8",
-1143263206),$APP.$cljs$cst$2675$family$$,"Voces",$APP.$cljs$cst$725$name$$,"Voces",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/voces/v24/-F6_fjJyLyU8d4PBBG7YpzlJ.ttf"],null)],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-volkhov",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("dddc1163-1568-4c4d-9580-5405dbadc5ee",-1897220100),$APP.$cljs$cst$2675$family$$,"Volkhov",$APP.$cljs$cst$725$name$$,"Volkhov",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",
$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/volkhov/v18/SlGQmQieoJcKemNeQTIOhHxzcD0.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/volkhov/v18/SlGSmQieoJcKemNecTAEgF52YD0NYw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/volkhov/v18/SlGVmQieoJcKemNeeY4hoHRYbDQUego.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/volkhov/v18/SlGXmQieoJcKemNecTA8PHFSaBYRagrQrA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-vollkorn",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("5256ac68-93d8-494f-a023-3a99bf119445",-1554255085),$APP.$cljs$cst$2675$family$$,"Vollkorn",$APP.$cljs$cst$725$name$$,"Vollkorn",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkorn/v30/0ybgGDoxxrvAnPhYGzMlQLzuMasz6Df2MHGuGWOdEbD63w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkorn/v30/0ybgGDoxxrvAnPhYGzMlQLzuMasz6Df2AnGuGWOdEbD63w.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkorn/v30/0ybgGDoxxrvAnPhYGzMlQLzuMasz6Df27nauGWOdEbD63w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/vollkorn/v30/0ybgGDoxxrvAnPhYGzMlQLzuMasz6Df213auGWOdEbD63w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkorn/v30/0ybgGDoxxrvAnPhYGzMlQLzuMasz6Df2sHauGWOdEbD63w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,
"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkorn/v30/0ybgGDoxxrvAnPhYGzMlQLzuMasz6Df2mXauGWOdEbD63w.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkorn/v30/0ybuGDoxxrvAnPhYGxksckM2WMCpRjDj-DJGWmmZM7Xq34g9.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkorn/v30/0ybuGDoxxrvAnPhYGxksckM2WMCpRjDj-DJ0WmmZM7Xq34g9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkorn/v30/0ybuGDoxxrvAnPhYGxksckM2WMCpRjDj-DKYXWmZM7Xq34g9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkorn/v30/0ybuGDoxxrvAnPhYGxksckM2WMCpRjDj-DKhXWmZM7Xq34g9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkorn/v30/0ybuGDoxxrvAnPhYGxksckM2WMCpRjDj-DLGXWmZM7Xq34g9.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkorn/v30/0ybuGDoxxrvAnPhYGxksckM2WMCpRjDj-DLvXWmZM7Xq34g9.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-vollkorn-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7ce166b4-1b58-4576-bf62-2a5b74ea78dd",-1576693493),$APP.$cljs$cst$2675$family$$,"Vollkorn SC",$APP.$cljs$cst$725$name$$,"Vollkorn SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkornsc/v12/j8_v6-zQ3rXpceZj9cqnVhF5NH-iSq_E.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkornsc/v12/j8_y6-zQ3rXpceZj9cqnVimhGluqYbPN5Yjn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkornsc/v12/j8_y6-zQ3rXpceZj9cqnVinFG1uqYbPN5Yjn.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vollkornsc/v12/j8_y6-zQ3rXpceZj9cqnVin9GVuqYbPN5Yjn.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-voltaire",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("08ce19d0-2a83-41c2-8366-dd2598eb8fe5",-700439450),$APP.$cljs$cst$2675$family$$,"Voltaire",$APP.$cljs$cst$725$name$$,"Voltaire",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/voltaire/v23/1Pttg8PcRfSblAvGvQooYKVnBOif.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-vujahday-script",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7783800e-d293-4eb7-be1d-45ac001c614f",-794611154),$APP.$cljs$cst$2675$family$$,"Vujahday Script",$APP.$cljs$cst$725$name$$,"Vujahday Script",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/vujahdayscript/v10/RWmQoKGA8fEkrIPtSZ3_J7er2dUiDEtvAlaMKw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-wdxl-lubrifont-jp-n",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("71ca8eff-30a7-48d9-82a3-9601e695f2fc",93006100),$APP.$cljs$cst$2675$family$$,"WDXL Lubrifont JP N",$APP.$cljs$cst$725$name$$,"WDXL Lubrifont JP N",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wdxllubrifontjpn/v1/8At1GtSkFqazDiO949fzWta9_T-SVxJiIZctoLhFRNU.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-wdxl-lubrifont-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d5e9bb17-fd28-41b0-9819-23eeb709be2e",-1004991510),$APP.$cljs$cst$2675$family$$,"WDXL Lubrifont SC",$APP.$cljs$cst$725$name$$,"WDXL Lubrifont SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wdxllubrifontsc/v1/gNMeW2VmY6acu0XtugFrduDciOOyfny5mD9ASHz5.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-wdxl-lubrifont-tc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d33047ef-2b21-4539-a5c1-58d3e79ed363",
-353378793),$APP.$cljs$cst$2675$family$$,"WDXL Lubrifont TC",$APP.$cljs$cst$725$name$$,"WDXL Lubrifont TC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wdxllubrifonttc/v4/nKKN-H4mPq1yJurnWXfJE8svQHonWc_-EqxyqaA8.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-waiting-for-the-sunrise",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("aa7b3409-2d8e-480e-8063-6cd38aa3dcc2",1047130089),$APP.$cljs$cst$2675$family$$,"Waiting for the Sunrise",$APP.$cljs$cst$725$name$$,"Waiting for the Sunrise",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/waitingforthesunrise/v23/WBL1rFvOYl9CEv2i1mO6KUW8RKWJ2zoXoz5JsYZQ9h_ZYk5J.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-wallpoet",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("334c6f07-c9d3-432e-b19e-88ab4030b655",-1579099367),$APP.$cljs$cst$2675$family$$,"Wallpoet",$APP.$cljs$cst$725$name$$,
"Wallpoet",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wallpoet/v21/f0X10em2_8RnXVVdUNbu7cXP8L8G.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-walter-turncoat",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("346ffce1-70ba-4277-b46c-a07aff40ce77",-1318138450),$APP.$cljs$cst$2675$family$$,"Walter Turncoat",$APP.$cljs$cst$725$name$$,"Walter Turncoat",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/walterturncoat/v24/snfys0Gs98ln43n0d-14ULoToe67YB2dQ5ZPqQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-warnes",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("43ce367c-61e1-48fb-95d1-083810fa4de1",1350357275),$APP.$cljs$cst$2675$family$$,"Warnes",$APP.$cljs$cst$725$name$$,"Warnes",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/warnes/v29/pONn1hc0GsW6sW5OpiC2o6Lkqg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-water-brush",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("57b58f42-82df-4674-bfd1-5b060f815b7a",-272892270),$APP.$cljs$cst$2675$family$$,
"Water Brush",$APP.$cljs$cst$725$name$$,"Water Brush",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/waterbrush/v6/AYCPpXPqc8cJWLhp4hywKHJq7PKP5Z_G.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-waterfall",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("db4babd8-24d0-41ae-8b09-8e31ff0ca406",-890276176),$APP.$cljs$cst$2675$family$$,"Waterfall",$APP.$cljs$cst$725$name$$,"Waterfall",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/waterfall/v8/MCoRzAfo293fACdFKcwY2rH8D_EZwA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-wavefont",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("075de332-d6b4-4e47-9026-8457d382470e",1482569992),$APP.$cljs$cst$2675$family$$,"Wavefont",$APP.$cljs$cst$725$name$$,"Wavefont",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wavefont/v19/L0xFDF00m0cP6hefyOCpRezQNuizSrqDyx8FHbFu21B3L4m0SEzuQYwq-f_JJ8I1WI3V0rDHXKtOXOg4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wavefont/v19/L0xFDF00m0cP6hefyOCpRezQNuizSrqDyx8FHbFu21B3L4m0SEzuQYwq-f_JJ8I1WI1V07DHXKtOXOg4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wavefont/v19/L0xFDF00m0cP6hefyOCpRezQNuizSrqDyx8FHbFu21B3L4m0SEzuQYwq-f_JJ8I1WI2L07DHXKtOXOg4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wavefont/v19/L0xFDF00m0cP6hefyOCpRezQNuizSrqDyx8FHbFu21B3L4m0SEzuQYwq-f_JJ8I1WI3V07DHXKtOXOg4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wavefont/v19/L0xFDF00m0cP6hefyOCpRezQNuizSrqDyx8FHbFu21B3L4m0SEzuQYwq-f_JJ8I1WI3n07DHXKtOXOg4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wavefont/v19/L0xFDF00m0cP6hefyOCpRezQNuizSrqDyx8FHbFu21B3L4m0SEzuQYwq-f_JJ8I1WI0L1LDHXKtOXOg4.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wavefont/v19/L0xFDF00m0cP6hefyOCpRezQNuizSrqDyx8FHbFu21B3L4m0SEzuQYwq-f_JJ8I1WI0y1LDHXKtOXOg4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wavefont/v19/L0xFDF00m0cP6hefyOCpRezQNuizSrqDyx8FHbFu21B3L4m0SEzuQYwq-f_JJ8I1WI1V1LDHXKtOXOg4.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wavefont/v19/L0xFDF00m0cP6hefyOCpRezQNuizSrqDyx8FHbFu21B3L4m0SEzuQYwq-f_JJ8I1WI181LDHXKtOXOg4.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-wellfleet",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f3ef8d18-590a-405f-93c0-f3fd13ceda97",-1059666497),$APP.$cljs$cst$2675$family$$,"Wellfleet",$APP.$cljs$cst$725$name$$,"Wellfleet",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wellfleet/v25/nuF7D_LfQJb3VYgX6eyT42aLDhO2HA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-wendy-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b148da1d-b2a6-40d0-9013-3486be301519",-1478478311),$APP.$cljs$cst$2675$family$$,"Wendy One",$APP.$cljs$cst$725$name$$,"Wendy One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wendyone/v20/2sDcZGJOipXfgfXV5wgDb2-4C7wFZQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-whisper",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7d06bcb2-13f5-4ebd-9936-3fab44c6ce24",
533242814),$APP.$cljs$cst$2675$family$$,"Whisper",$APP.$cljs$cst$725$name$$,"Whisper",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/whisper/v7/q5uHsoqtKftx74K9milCBxxdmYU.ttf"],null)],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-windsong",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0ba89da8-c7fc-4126-b47a-6b964ee3d71d",739008170),$APP.$cljs$cst$2675$family$$,"WindSong",$APP.$cljs$cst$725$name$$,"WindSong",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/windsong/v13/KR1WBsyu-P-GFEW57r95HdG6vjH3.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/windsong/v13/KR1RBsyu-P-GFEW57oeNNPWylS3-jVXm.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-winky-rough",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("651d0f12-2cd4-4c14-8e65-f38e0b1f95f3",-1993315213),$APP.$cljs$cst$2675$family$$,"Winky Rough",$APP.$cljs$cst$725$name$$,"Winky Rough",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkyrough/v4/t5tzIRwIMoSXA0WSPBjQxJzjxc0_NyCBbx8bOSVuN7JB-KCmzg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkyrough/v4/t5tzIRwIMoSXA0WSPBjQxJzjxc0_NyCBbx8bZyVuN7JB-KCmzg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkyrough/v4/t5tzIRwIMoSXA0WSPBjQxJzjxc0_NyCBbx8bVSVuN7JB-KCmzg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkyrough/v4/t5tzIRwIMoSXA0WSPBjQxJzjxc0_NyCBbx8buSJuN7JB-KCmzg.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkyrough/v4/t5tzIRwIMoSXA0WSPBjQxJzjxc0_NyCBbx8bgCJuN7JB-KCmzg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkyrough/v4/t5tzIRwIMoSXA0WSPBjQxJzjxc0_NyCBbx8b5yJuN7JB-KCmzg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkyrough/v4/t5tzIRwIMoSXA0WSPBjQxJzjxc0_NyCBbx8bziJuN7JB-KCmzg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkyrough/v4/t5t1IRwIMoSXA0WSPBjQxLbq9zLnXksbwRgOr2bYdLhF2qW2zneX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkyrough/v4/t5t1IRwIMoSXA0WSPBjQxLbq9zLnXksbwRgOr2aGdLhF2qW2zneX.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkyrough/v4/t5t1IRwIMoSXA0WSPBjQxLbq9zLnXksbwRgOr2a0dLhF2qW2zneX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkyrough/v4/t5t1IRwIMoSXA0WSPBjQxLbq9zLnXksbwRgOr2ZYc7hF2qW2zneX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkyrough/v4/t5t1IRwIMoSXA0WSPBjQxLbq9zLnXksbwRgOr2Zhc7hF2qW2zneX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkyrough/v4/t5t1IRwIMoSXA0WSPBjQxLbq9zLnXksbwRgOr2YGc7hF2qW2zneX.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/winkyrough/v4/t5t1IRwIMoSXA0WSPBjQxLbq9zLnXksbwRgOr2Yvc7hF2qW2zneX.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-winky-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a77bba74-ee60-4665-83d6-5505b544f5fa",1165128106),$APP.$cljs$cst$2675$family$$,"Winky Sans",$APP.$cljs$cst$725$name$$,"Winky Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkysans/v3/ll8sK2SDUiG1Hpf2p06bHaEAYt6HPhJ2AGXUiD6F2TpBa98q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/winkysans/v3/ll8sK2SDUiG1Hpf2p06bHaEAYt6HPhJ2AGWKiD6F2TpBa98q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkysans/v3/ll8sK2SDUiG1Hpf2p06bHaEAYt6HPhJ2AGW4iD6F2TpBa98q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,
"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkysans/v3/ll8sK2SDUiG1Hpf2p06bHaEAYt6HPhJ2AGVUjz6F2TpBa98q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkysans/v3/ll8sK2SDUiG1Hpf2p06bHaEAYt6HPhJ2AGVtjz6F2TpBa98q.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkysans/v3/ll8sK2SDUiG1Hpf2p06bHaEAYt6HPhJ2AGUKjz6F2TpBa98q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/winkysans/v3/ll8sK2SDUiG1Hpf2p06bHaEAYt6HPhJ2AGUjjz6F2TpBa98q.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkysans/v3/ll8uK2SDUiG1Hpf2p06bN6gynQbuVYjYB3BCy4jG0z5jbs8qbts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkysans/v3/ll8uK2SDUiG1Hpf2p06bN6gynQbuVYjYB3BCy9bG0z5jbs8qbts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkysans/v3/ll8uK2SDUiG1Hpf2p06bN6gynQbuVYjYB3BCy-TG0z5jbs8qbts.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkysans/v3/ll8uK2SDUiG1Hpf2p06bN6gynQbuVYjYB3BCywjB0z5jbs8qbts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkysans/v3/ll8uK2SDUiG1Hpf2p06bN6gynQbuVYjYB3BCyzHB0z5jbs8qbts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkysans/v3/ll8uK2SDUiG1Hpf2p06bN6gynQbuVYjYB3BCy1bB0z5jbs8qbts.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/winkysans/v3/ll8uK2SDUiG1Hpf2p06bN6gynQbuVYjYB3BCy3_B0z5jbs8qbts.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-wire-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("a61c6dd8-41f6-4084-a161-023b0dd7479d",-951793174),$APP.$cljs$cst$2675$family$$,
"Wire One",$APP.$cljs$cst$725$name$$,"Wire One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wireone/v30/qFdH35Wah5htUhV75WGiWdrCwwcJ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-wittgenstein",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cf7f7037-275d-41fe-82c6-d7c06290c2c0",-265820811),$APP.$cljs$cst$2675$family$$,"Wittgenstein",$APP.$cljs$cst$725$name$$,"Wittgenstein",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wittgenstein/v4/WBL3rEDOakJCHParhXGwMgvyJ8hdWNLC1kI61G4T_Bv7Z15J4ow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wittgenstein/v4/WBL3rEDOakJCHParhXGwMgvyJ8hdWNLC1kI61FwT_Bv7Z15J4ow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wittgenstein/v4/WBL3rEDOakJCHParhXGwMgvyJ8hdWNLC1kI61LAU_Bv7Z15J4ow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wittgenstein/v4/WBL3rEDOakJCHParhXGwMgvyJ8hdWNLC1kI61IkU_Bv7Z15J4ow.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wittgenstein/v4/WBL3rEDOakJCHParhXGwMgvyJ8hdWNLC1kI61O4U_Bv7Z15J4ow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wittgenstein/v4/WBL3rEDOakJCHParhXGwMgvyJ8hdWNLC1kI61McU_Bv7Z15J4ow.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wittgenstein/v4/WBLxrEDOakJCHParhXGwMgvYLvqigLupTOw9waZQFFjxY3xM8ozHYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wittgenstein/v4/WBLxrEDOakJCHParhXGwMgvYLvqigLupTOw9waZQJljxY3xM8ozHYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/wittgenstein/v4/WBLxrEDOakJCHParhXGwMgvYLvqigLupTOw9waZQyl_xY3xM8ozHYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wittgenstein/v4/WBLxrEDOakJCHParhXGwMgvYLvqigLupTOw9waZQ81_xY3xM8ozHYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wittgenstein/v4/WBLxrEDOakJCHParhXGwMgvYLvqigLupTOw9waZQlF_xY3xM8ozHYA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wittgenstein/v4/WBLxrEDOakJCHParhXGwMgvYLvqigLupTOw9waZQvV_xY3xM8ozHYA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-wix-madefor-display",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cd92e0fb-58ce-4056-9210-edb515efcb5e",-1755997852),$APP.$cljs$cst$2675$family$$,"Wix Madefor Display",$APP.$cljs$cst$725$name$$,"Wix Madefor Display",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wixmadefordisplay/v12/SZcS3EX9IbbyeJ8aOluD52KXgUA_7Ed1I13G853Cp9duUYFhYltkv_3HQKgh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wixmadefordisplay/v12/SZcS3EX9IbbyeJ8aOluD52KXgUA_7Ed1I13G853Cp9duUYFTYltkv_3HQKgh.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wixmadefordisplay/v12/SZcS3EX9IbbyeJ8aOluD52KXgUA_7Ed1I13G853Cp9duUYG_ZVtkv_3HQKgh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wixmadefordisplay/v12/SZcS3EX9IbbyeJ8aOluD52KXgUA_7Ed1I13G853Cp9duUYGGZVtkv_3HQKgh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wixmadefordisplay/v12/SZcS3EX9IbbyeJ8aOluD52KXgUA_7Ed1I13G853Cp9duUYHhZVtkv_3HQKgh.ttf"],null)],null)],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-wix-madefor-text",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c33cff70-7736-4fa1-8b1e-65c5a323fb65",-1466073687),$APP.$cljs$cst$2675$family$$,"Wix Madefor Text",$APP.$cljs$cst$725$name$$,"Wix Madefor Text",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wixmadefortext/v17/-W_oXI_oSymQ8Qj-Apx3HGN_Hu1RTCk5FtSDETgf0cK_NOeFgpRt9rN5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wixmadefortext/v17/-W_WXI_oSymQ8Qj-Apx3HGN_Hu1RZiAL6QzqeqKx1td3dw_GiJBP86N53IY.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wixmadefortext/v17/-W_oXI_oSymQ8Qj-Apx3HGN_Hu1RTCk5FtSDETgf0cKNNOeFgpRt9rN5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wixmadefortext/v17/-W_WXI_oSymQ8Qj-Apx3HGN_Hu1RZiAL6QzqeqKx1td3dz3GiJBP86N53IY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wixmadefortext/v17/-W_oXI_oSymQ8Qj-Apx3HGN_Hu1RTCk5FtSDETgf0cJhM-eFgpRt9rN5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wixmadefortext/v17/-W_WXI_oSymQ8Qj-Apx3HGN_Hu1RZiAL6QzqeqKx1td3d9HBiJBP86N53IY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/wixmadefortext/v17/-W_oXI_oSymQ8Qj-Apx3HGN_Hu1RTCk5FtSDETgf0cJYM-eFgpRt9rN5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wixmadefortext/v17/-W_WXI_oSymQ8Qj-Apx3HGN_Hu1RZiAL6QzqeqKx1td3d-jBiJBP86N53IY.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wixmadefortext/v17/-W_oXI_oSymQ8Qj-Apx3HGN_Hu1RTCk5FtSDETgf0cI_M-eFgpRt9rN5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/wixmadefortext/v17/-W_WXI_oSymQ8Qj-Apx3HGN_Hu1RZiAL6QzqeqKx1td3d4_BiJBP86N53IY.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-work-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c744d87d-b3c8-4c18-97d3-072708ae4ca5",-1419649893),$APP.$cljs$cst$2675$family$$,"Work Sans",$APP.$cljs$cst$725$name$$,"Work Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,
"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY_z_wNahGAdqQ43RhVcIgYT2Xz5u32K0nWNigDp6_cOyA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY_z_wNahGAdqQ43RhVcIgYT2Xz5u32K8nXNigDp6_cOyA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY_z_wNahGAdqQ43RhVcIgYT2Xz5u32KxfXNigDp6_cOyA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY_z_wNahGAdqQ43RhVcIgYT2Xz5u32K0nXNigDp6_cOyA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY_z_wNahGAdqQ43RhVcIgYT2Xz5u32K3vXNigDp6_cOyA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY_z_wNahGAdqQ43RhVcIgYT2Xz5u32K5fQNigDp6_cOyA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY_z_wNahGAdqQ43RhVcIgYT2Xz5u32K67QNigDp6_cOyA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY_z_wNahGAdqQ43RhVcIgYT2Xz5u32K8nQNigDp6_cOyA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/worksans/v24/QGY_z_wNahGAdqQ43RhVcIgYT2Xz5u32K-DQNigDp6_cOyA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY9z_wNahGAdqQ43Rh_ebrnlwyYfEPxPoGU3moJo43ZKyDSQQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY9z_wNahGAdqQ43Rh_ebrnlwyYfEPxPoGUXmsJo43ZKyDSQQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY9z_wNahGAdqQ43Rh_ebrnlwyYfEPxPoGUgGsJo43ZKyDSQQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY9z_wNahGAdqQ43Rh_ebrnlwyYfEPxPoGU3msJo43ZKyDSQQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY9z_wNahGAdqQ43Rh_ebrnlwyYfEPxPoGU7GsJo43ZKyDSQQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY9z_wNahGAdqQ43Rh_ebrnlwyYfEPxPoGUAGwJo43ZKyDSQQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY9z_wNahGAdqQ43Rh_ebrnlwyYfEPxPoGUOWwJo43ZKyDSQQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/worksans/v24/QGY9z_wNahGAdqQ43Rh_ebrnlwyYfEPxPoGUXmwJo43ZKyDSQQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/worksans/v24/QGY9z_wNahGAdqQ43Rh_ebrnlwyYfEPxPoGUd2wJo43ZKyDSQQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-workbench",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("13fa194e-9946-46ea-89a7-2d7354fd341e",-98832360),$APP.$cljs$cst$2675$family$$,"Workbench",$APP.$cljs$cst$725$name$$,"Workbench",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/workbench/v3/FeV8S05Gp6Et7FcfbPFK1rynGd_MxtkvNFmoUDFhgF2VKTGQk6vapdOL0GKqgZyb.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-xanh-mono",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0b9762af-0ba8-4704-8d9e-c62319d527ae",831089299),$APP.$cljs$cst$2675$family$$,"Xanh Mono",$APP.$cljs$cst$725$name$$,"Xanh Mono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/xanhmono/v19/R70YjykVmvKCep-vWhSYmACQXzLhTg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/xanhmono/v19/R70ejykVmvKCep-vWhSomgqUfTfxTo24.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yaldevi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f413dbf6-51fc-4a52-98ae-234739d92429",-2031663298),$APP.$cljs$cst$2675$family$$,"Yaldevi",$APP.$cljs$cst$725$name$$,"Yaldevi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yaldevi/v17/cY9afj6VW0NMrDWtDNzCOwlPMq9SLpfxJzvobxLCBJkS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yaldevi/v17/cY9afj6VW0NMrDWtDNzCOwlPMq9SLpcvJzvobxLCBJkS.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yaldevi/v17/cY9afj6VW0NMrDWtDNzCOwlPMq9SLpdxJzvobxLCBJkS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/yaldevi/v17/cY9afj6VW0NMrDWtDNzCOwlPMq9SLpdDJzvobxLCBJkS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yaldevi/v17/cY9afj6VW0NMrDWtDNzCOwlPMq9SLpevIDvobxLCBJkS.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,
"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yaldevi/v17/cY9afj6VW0NMrDWtDNzCOwlPMq9SLpeWIDvobxLCBJkS.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yanone-kaffeesatz",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0f500b44-7bde-4482-84ee-16d601370a4d",-1354587473),$APP.$cljs$cst$2675$family$$,"Yanone Kaffeesatz",$APP.$cljs$cst$725$name$$,"Yanone Kaffeesatz",
$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yanonekaffeesatz/v32/3y9I6aknfjLm_3lMKjiMgmUUYBs04aUXNxt9gW2LIftodtWpcGuLCnXkVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yanonekaffeesatz/v32/3y9I6aknfjLm_3lMKjiMgmUUYBs04aUXNxt9gW2LIftoqNWpcGuLCnXkVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yanonekaffeesatz/v32/3y9I6aknfjLm_3lMKjiMgmUUYBs04aUXNxt9gW2LIfto9tWpcGuLCnXkVA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yanonekaffeesatz/v32/3y9I6aknfjLm_3lMKjiMgmUUYBs04aUXNxt9gW2LIftoxNWpcGuLCnXkVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yanonekaffeesatz/v32/3y9I6aknfjLm_3lMKjiMgmUUYBs04aUXNxt9gW2LIftoKNKpcGuLCnXkVA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yanonekaffeesatz/v32/3y9I6aknfjLm_3lMKjiMgmUUYBs04aUXNxt9gW2LIftoEdKpcGuLCnXkVA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-yantramanav",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("415b313b-aff7-491e-ae2c-1a538878a326",-1600065233),$APP.$cljs$cst$2675$family$$,"Yantramanav",$APP.$cljs$cst$725$name$$,"Yantramanav",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yantramanav/v15/flU-Rqu5zY00QEpyWJYWN5-QXeNzDB41rZg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yantramanav/v15/flUhRqu5zY00QEpyWJYWN59Yf8NZIhI8tIHh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yantramanav/v15/flU8Rqu5zY00QEpyWJYWN6f0V-dRCQ41.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yantramanav/v15/flUhRqu5zY00QEpyWJYWN58AfsNZIhI8tIHh.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yantramanav/v15/flUhRqu5zY00QEpyWJYWN59IeMNZIhI8tIHh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/yantramanav/v15/flUhRqu5zY00QEpyWJYWN59wesNZIhI8tIHh.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yarndings-12",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("efcaf183-f57c-41af-9868-40c17b4caf95",-1960600035),$APP.$cljs$cst$2675$family$$,"Yarndings 12",$APP.$cljs$cst$725$name$$,"Yarndings 12",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yarndings12/v4/55xreyp2N8T5P2LJbZAlkY9c8ZLMI2VUnQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yarndings-12-charted",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0a75c65d-86b6-478d-a0b7-b21c30d94135",
-1819229611),$APP.$cljs$cst$2675$family$$,"Yarndings 12 Charted",$APP.$cljs$cst$725$name$$,"Yarndings 12 Charted",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yarndings12charted/v4/eLGDP_DlKhO-DUfeqM4I_vDdJgmIh7hAvvbJ0t-dHaJH.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yarndings-20",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("67467b71-d7b2-4572-8171-5e8324d28b48",1847655329),$APP.$cljs$cst$2675$family$$,"Yarndings 20",$APP.$cljs$cst$725$name$$,"Yarndings 20",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yarndings20/v4/TuGWUVlkUohEQu8l7K8b-vNFB380PMTK1w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yarndings-20-charted",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("39ccc4df-cc92-46fe-8373-054e9223596f",-554234551),$APP.$cljs$cst$2675$family$$,"Yarndings 20 Charted",$APP.$cljs$cst$725$name$$,
"Yarndings 20 Charted",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yarndings20charted/v4/QldRNSdbpg0G8vh0W2qxe0l-hcUPtY2VaLQm4UTqz5V9.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-yatra-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8a4ca3c5-7274-4198-b504-1d56a33ff767",-1150132993),$APP.$cljs$cst$2675$family$$,"Yatra One",$APP.$cljs$cst$725$name$$,"Yatra One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yatraone/v16/C8ch4copsHzj8p7NaF0xw1OBbRDvXw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yellowtail",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("13aed974-7d96-48a1-8fed-565d1b1ca2c2",299090754),$APP.$cljs$cst$2675$family$$,"Yellowtail",$APP.$cljs$cst$725$name$$,"Yellowtail",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yellowtail/v25/OZpGg_pnoDtINPfRIlLotlzNwED-b4g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yeon-sung",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f2d75e92-66d8-485b-abed-4007c5f2069d",327906354),$APP.$cljs$cst$2675$family$$,
"Yeon Sung",$APP.$cljs$cst$725$name$$,"Yeon Sung",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yeonsung/v22/QldMNTpbohAGtsJvUn6xSVNazqx2xg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-yeseva-one",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c614b5e3-f1ce-4edb-85e9-0694cd98fb11",-1345072294),$APP.$cljs$cst$2675$family$$,"Yeseva One",$APP.$cljs$cst$725$name$$,"Yeseva One",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yesevaone/v24/OpNJno4ck8vc-xYpwWWxpipfWhXD00c.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yesteryear",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3d4f5d90-9da3-4218-840c-9089a5de0661",-540580132),$APP.$cljs$cst$2675$family$$,"Yesteryear",$APP.$cljs$cst$725$name$$,"Yesteryear",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yesteryear/v21/dg4g_p78rroaKl8kRKo1r7wHTwonmyw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yomogi",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8a341adb-94b7-45c8-bdcb-ef7b4b917ed5",-1903105859),$APP.$cljs$cst$2675$family$$,
"Yomogi",$APP.$cljs$cst$725$name$$,"Yomogi",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yomogi/v13/VuJwdNrS2ZL7rpoPWIz5NIh-YA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-young-serif",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("72af7f50-69f2-4a3b-b651-bc9594ecdb61",-1780655063),$APP.$cljs$cst$2675$family$$,"Young Serif",$APP.$cljs$cst$725$name$$,"Young Serif",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/youngserif/v2/3qTpojO2nS2VtkB3KtkQZ2t61EcYaQ7F.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yrsa",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0e1a417b-1f4d-4d0e-b3a4-307c4eb81d92",-1740865712),$APP.$cljs$cst$2675$family$$,"Yrsa",$APP.$cljs$cst$725$name$$,"Yrsa",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yrsa/v25/wlprgwnQFlxs_wD3CFSMYmFaaCjASNNV9rRPfrKu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/yrsa/v25/wlprgwnQFlxs_wD3CFSMYmFaaCieSNNV9rRPfrKu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yrsa/v25/wlprgwnQFlxs_wD3CFSMYmFaaCisSNNV9rRPfrKu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",
$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yrsa/v25/wlprgwnQFlxs_wD3CFSMYmFaaChAT9NV9rRPfrKu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yrsa/v25/wlprgwnQFlxs_wD3CFSMYmFaaCh5T9NV9rRPfrKu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yrsa/v25/wlptgwnQFlxs1QnF94zlCfv0bz1WC2UW_LBte6KuGEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yrsa/v25/wlptgwnQFlxs1QnF94zlCfv0bz1WCzsW_LBte6KuGEo.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yrsa/v25/wlptgwnQFlxs1QnF94zlCfv0bz1WCwkW_LBte6KuGEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yrsa/v25/wlptgwnQFlxs1QnF94zlCfv0bz1WC-UR_LBte6KuGEo.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yrsa/v25/wlptgwnQFlxs1QnF94zlCfv0bz1WC9wR_LBte6KuGEo.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-ysabeau",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("96eab310-6d96-4e43-b5cc-673ca126f1a3",-1764954168),$APP.$cljs$cst$2675$family$$,"Ysabeau",$APP.$cljs$cst$725$name$$,"Ysabeau",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKiZqEiBAXLcnuMvjZNI_5FGeJet7OWCTYwI8Gcw6Oi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKiZqEiBAXLcnuMvjZNI_5FGeJet7MWCDYwI8Gcw6Oi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKiZqEiBAXLcnuMvjZNI_5FGeJet7PICDYwI8Gcw6Oi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKiZqEiBAXLcnuMvjZNI_5FGeJet7OWCDYwI8Gcw6Oi.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKiZqEiBAXLcnuMvjZNI_5FGeJet7OkCDYwI8Gcw6Oi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ysabeau/v5/kmKiZqEiBAXLcnuMvjZNI_5FGeJet7NIDzYwI8Gcw6Oi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKiZqEiBAXLcnuMvjZNI_5FGeJet7NxDzYwI8Gcw6Oi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,
"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKiZqEiBAXLcnuMvjZNI_5FGeJet7MWDzYwI8Gcw6Oi.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKiZqEiBAXLcnuMvjZNI_5FGeJet7M_DzYwI8Gcw6Oi.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKsZqEiBAXLcnuMlD9_3CYscnjwsKZeS95yKcW-xrOiIUw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKsZqEiBAXLcnuMlD9_3CYscnjwsKZeS15zKcW-xrOiIUw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKsZqEiBAXLcnuMlD9_3CYscnjwsKZeS4BzKcW-xrOiIUw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKsZqEiBAXLcnuMlD9_3CYscnjwsKZeS95zKcW-xrOiIUw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKsZqEiBAXLcnuMlD9_3CYscnjwsKZeS-xzKcW-xrOiIUw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKsZqEiBAXLcnuMlD9_3CYscnjwsKZeSwB0KcW-xrOiIUw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKsZqEiBAXLcnuMlD9_3CYscnjwsKZeSzl0KcW-xrOiIUw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKsZqEiBAXLcnuMlD9_3CYscnjwsKZeS150KcW-xrOiIUw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeau/v5/kmKsZqEiBAXLcnuMlD9_3CYscnjwsKZeS3d0KcW-xrOiIUw.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ysabeau-infant",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("c0ac7836-1612-4eee-b2eb-8787e04245ff",-1540989701),$APP.$cljs$cst$2675$family$$,
"Ysabeau Infant",$APP.$cljs$cst$725$name$$,"Ysabeau Infant",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-ClzpqOkkV94kBTQVdX1EWI9B0V-HEmd9JmTQYFo4HK5ChLwKH6A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-ClzpqOkkV94kBTQVdX1EWI9B0V-HEmd9JmTQYlo8HK5ChLwKH6A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-ClzpqOkkV94kBTQVdX1EWI9B0V-HEmd9JmTQYSI8HK5ChLwKH6A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-ClzpqOkkV94kBTQVdX1EWI9B0V-HEmd9JmTQYFo8HK5ChLwKH6A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-ClzpqOkkV94kBTQVdX1EWI9B0V-HEmd9JmTQYJI8HK5ChLwKH6A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-ClzpqOkkV94kBTQVdX1EWI9B0V-HEmd9JmTQYyIgHK5ChLwKH6A.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-ClzpqOkkV94kBTQVdX1EWI9B0V-HEmd9JmTQY8YgHK5ChLwKH6A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-ClzpqOkkV94kBTQVdX1EWI9B0V-HEmd9JmTQYlogHK5ChLwKH6A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-ClzpqOkkV94kBTQVdX1EWI9B0V-HEmd9JmTQYv4gHK5ChLwKH6A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-AlzpqOkkV94kBTQVdX1EWI_p9ZR4c8LTTNzMN3szvaZqlDQeX6Dc5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-AlzpqOkkV94kBTQVdX1EWI_p9ZR4c8LTTNzMN3sxvaJqlDQeX6Dc5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-AlzpqOkkV94kBTQVdX1EWI_p9ZR4c8LTTNzMN3syxaJqlDQeX6Dc5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-AlzpqOkkV94kBTQVdX1EWI_p9ZR4c8LTTNzMN3szvaJqlDQeX6Dc5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-AlzpqOkkV94kBTQVdX1EWI_p9ZR4c8LTTNzMN3szdaJqlDQeX6Dc5.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-AlzpqOkkV94kBTQVdX1EWI_p9ZR4c8LTTNzMN3swxb5qlDQeX6Dc5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",
$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-AlzpqOkkV94kBTQVdX1EWI_p9ZR4c8LTTNzMN3swIb5qlDQeX6Dc5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-AlzpqOkkV94kBTQVdX1EWI_p9ZR4c8LTTNzMN3sxvb5qlDQeX6Dc5.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauinfant/v4/hv-AlzpqOkkV94kBTQVdX1EWI_p9ZR4c8LTTNzMN3sxGb5qlDQeX6Dc5.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ysabeau-office",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("3dd6a6c4-281c-43f8-8d03-37075dc32bfa",
1734712936),$APP.$cljs$cst$2675$family$$,"Ysabeau Office",$APP.$cljs$cst$725$name$$,"Ysabeau Office",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDImapaZKhM9RuQIp8FmdYrPPNjFm07hbpKNlPPbh6IfYSfpQj7IGQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDImapaZKhM9RuQIp8FmdYrPPNjFm07hbpKNlPPbB6MfYSfpQj7IGQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDImapaZKhM9RuQIp8FmdYrPPNjFm07hbpKNlPPb2aMfYSfpQj7IGQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDImapaZKhM9RuQIp8FmdYrPPNjFm07hbpKNlPPbh6MfYSfpQj7IGQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDImapaZKhM9RuQIp8FmdYrPPNjFm07hbpKNlPPbtaMfYSfpQj7IGQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDImapaZKhM9RuQIp8FmdYrPPNjFm07hbpKNlPPbWaQfYSfpQj7IGQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDImapaZKhM9RuQIp8FmdYrPPNjFm07hbpKNlPPbYKQfYSfpQj7IGQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDImapaZKhM9RuQIp8FmdYrPPNjFm07hbpKNlPPbB6QfYSfpQj7IGQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDImapaZKhM9RuQIp8FmdYrPPNjFm07hbpKNlPPbLqQfYSfpQj7IGQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"100italic",$APP.$cljs$cst$725$name$$,"100 Italic",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDIkapaZKhM9RuQIp8FmdYrPPPLMqbE5B_kXOvTOT-D3Iy3tYDvYGbGh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDIkapaZKhM9RuQIp8FmdYrPPPLMqbE5B_kXOvTOT-B3Ii3tYDvYGbGh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDIkapaZKhM9RuQIp8FmdYrPPPLMqbE5B_kXOvTOT-CpIi3tYDvYGbGh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDIkapaZKhM9RuQIp8FmdYrPPPLMqbE5B_kXOvTOT-D3Ii3tYDvYGbGh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDIkapaZKhM9RuQIp8FmdYrPPPLMqbE5B_kXOvTOT-DFIi3tYDvYGbGh.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDIkapaZKhM9RuQIp8FmdYrPPPLMqbE5B_kXOvTOT-ApJS3tYDvYGbGh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",
$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDIkapaZKhM9RuQIp8FmdYrPPPLMqbE5B_kXOvTOT-AQJS3tYDvYGbGh.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDIkapaZKhM9RuQIp8FmdYrPPPLMqbE5B_kXOvTOT-B3JS3tYDvYGbGh.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeauoffice/v4/LDIkapaZKhM9RuQIp8FmdYrPPPLMqbE5B_kXOvTOT-BeJS3tYDvYGbGh.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-ysabeau-sc",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e183ce0e-7ca0-4720-82ba-70eda0a99304",
1236270407),$APP.$cljs$cst$2675$family$$,"Ysabeau SC",$APP.$cljs$cst$725$name$$,"Ysabeau SC",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"100",$APP.$cljs$cst$725$name$$,"100",$APP.$cljs$cst$1996$weight$$,"100",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeausc/v4/Noai6Uro3JCIKAbW46nMorJZyP7kKRflbw98U1qEZ4EOmsT5.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeausc/v4/Noai6Uro3JCIKAbW46nMorJZyP7kKRflbw_8UlqEZ4EOmsT5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ysabeausc/v4/Noai6Uro3JCIKAbW46nMorJZyP7kKRflbw8iUlqEZ4EOmsT5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeausc/v4/Noai6Uro3JCIKAbW46nMorJZyP7kKRflbw98UlqEZ4EOmsT5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,
"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeausc/v4/Noai6Uro3JCIKAbW46nMorJZyP7kKRflbw9OUlqEZ4EOmsT5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeausc/v4/Noai6Uro3JCIKAbW46nMorJZyP7kKRflbw-iVVqEZ4EOmsT5.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeausc/v4/Noai6Uro3JCIKAbW46nMorJZyP7kKRflbw-bVVqEZ4EOmsT5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/ysabeausc/v4/Noai6Uro3JCIKAbW46nMorJZyP7kKRflbw_8VVqEZ4EOmsT5.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/ysabeausc/v4/Noai6Uro3JCIKAbW46nMorJZyP7kKRflbw_VVVqEZ4EOmsT5.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"gfont-yuji-boku",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("cf2cfaed-058d-4831-a37f-1b2f0bee66fd",1141628055),$APP.$cljs$cst$2675$family$$,"Yuji Boku",$APP.$cljs$cst$725$name$$,"Yuji Boku",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yujiboku/v8/P5sAzZybeNzXsA9xj1Fkjb2r2dgvJA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yuji-hentaigana-akari",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("04d1e703-8648-4416-a041-51ae5ae11179",-1247238144),$APP.$cljs$cst$2675$family$$,"Yuji Hentaigana Akari",$APP.$cljs$cst$725$name$$,"Yuji Hentaigana Akari",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yujihentaiganaakari/v14/cY9bfiyVT0VB6QuhWKOrpr6z58lnb_zYFnLIRTzODYALaA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yuji-hentaigana-akebono",$cljs$cst$424$uuid$$,
new $cljs$core$UUID$$("d125d43e-822a-4b21-a7c8-0b3d4e01143b",-1323200153),$APP.$cljs$cst$2675$family$$,"Yuji Hentaigana Akebono",$APP.$cljs$cst$725$name$$,"Yuji Hentaigana Akebono",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/yujihentaiganaakebono/v15/EJRGQhkhRNwM-RtitGUwh930GU_f5KAlkuL0wQy9NKXRzrrF.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yuji-mai",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e1586826-2f64-49bf-889f-3b4a643bfe19",1405781874),$APP.$cljs$cst$2675$family$$,"Yuji Mai",$APP.$cljs$cst$725$name$$,"Yuji Mai",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yujimai/v8/ZgNQjPxdJ7DEHrS0gC38hmHmNpCO.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-yuji-syuku",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("575d34d6-6e0a-4baa-8e1e-a8162b2502c5",359372024),$APP.$cljs$cst$2675$family$$,
"Yuji Syuku",$APP.$cljs$cst$725$name$$,"Yuji Syuku",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yujisyuku/v8/BngNUXdTV3vO6Lw5ApOPqPfgwqiA-Rk.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-yusei-magic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("9b07f93e-9aa5-42bd-b8fe-c273c980a532",-1955684731),$APP.$cljs$cst$2675$family$$,"Yusei Magic",$APP.$cljs$cst$725$name$$,"Yusei Magic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/yuseimagic/v16/yYLt0hbAyuCmoo5wlhPkpjHR-tdfcIT_.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zcool-kuaile",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("37abd129-9e27-4f42-9dad-57af5a3717a3",1623136862),$APP.$cljs$cst$2675$family$$,"ZCOOL KuaiLe",$APP.$cljs$cst$725$name$$,"ZCOOL KuaiLe",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zcoolkuaile/v20/tssqApdaRQokwFjFJjvM6h2WpozzoXhC2g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zcool-qingke-huangyou",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("46cea2d5-4a5e-41b8-aee6-8d2e10d5d204",
1686724930),$APP.$cljs$cst$2675$family$$,"ZCOOL QingKe HuangYou",$APP.$cljs$cst$725$name$$,"ZCOOL QingKe HuangYou",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zcoolqingkehuangyou/v16/2Eb5L_R5IXJEWhD3AOhSvFC554MOOahI4mRIi_28c8bHWA.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zcool-xiaowei",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("6b102874-4b4d-4b86-b4de-5ff63d83f85c",1560245243),$APP.$cljs$cst$2675$family$$,"ZCOOL XiaoWei",$APP.$cljs$cst$725$name$$,"ZCOOL XiaoWei",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zcoolxiaowei/v15/i7dMIFFrTRywPpUVX9_RJyM1YFKQHwyVd3U.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zain",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("7ec32aad-6acd-4de8-bff7-c87c303314e6",-450878308),$APP.$cljs$cst$2675$family$$,"Zain",$APP.$cljs$cst$725$name$$,"Zain",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zain/v4/sykz-y9lm7soOBrstSq9-trEvlQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,
"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zain/v4/sykz-y9lm7soOH7vtSq9-trEvlQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zain/v4/sykx-y9lm7soMND1OSi3_vjBrlSILg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zain/v4/syk8-y9lm7soANLHkSKW5tM.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zain/v4/syky-y9lm7soMNDNlQCT9tPdpw.ttf"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zain/v4/sykz-y9lm7soOG7otSq9-trEvlQ.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zain/v4/sykz-y9lm7soOHLrtSq9-trEvlQ.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zain/v4/sykz-y9lm7soOFbqtSq9-trEvlQ.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zalando-sans",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("d566c885-be98-44cf-87af-44b5342f4e5d",-740920639),$APP.$cljs$cst$2675$family$$,
"Zalando Sans",$APP.$cljs$cst$725$name$$,"Zalando Sans",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ67-Asy1Em_lq_aK3hpr-RrktWHD54lnesO2lsVvrnhgw8zPbXoT-7PzkTYUMEgzhp.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ67-Asy1Em_lq_aK3hpr-RrktWHD54lnesO2lsVvrnhgw8zPbXoT9lPzkTYUMEgzhp.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ67-Asy1Em_lq_aK3hpr-RrktWHD54lnesO2lsVvrnhgw8zPbXoT87PzkTYUMEgzhp.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ67-Asy1Em_lq_aK3hpr-RrktWHD54lnesO2lsVvrnhgw8zPbXoT8JPzkTYUMEgzhp.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ67-Asy1Em_lq_aK3hpr-RrktWHD54lnesO2lsVvrnhgw8zPbXoT_lODkTYUMEgzhp.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ67-Asy1Em_lq_aK3hpr-RrktWHD54lnesO2lsVvrnhgw8zPbXoT_cODkTYUMEgzhp.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ67-Asy1Em_lq_aK3hpr-RrktWHD54lnesO2lsVvrnhgw8zPbXoT-7ODkTYUMEgzhp.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ67-Asy1Em_lq_aK3hpr-RrktWHD54lnesO2lsVvrnhgw8zPbXoT-SODkTYUMEgzhp.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ47-Asy1Em_lq_aK3hpr-7p3m1_EcrANmrLqEupLPVedRVp2x5pirzfFFQa0cmhihp69o.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ47-Asy1Em_lq_aK3hpr-7p3m1_EcrANmrLqEupLPVedRVp2x5pirzfI9Qa0cmhihp69o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ47-Asy1Em_lq_aK3hpr-7p3m1_EcrANmrLqEupLPVedRVp2x5pirzfNFQa0cmhihp69o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ47-Asy1Em_lq_aK3hpr-7p3m1_EcrANmrLqEupLPVedRVp2x5pirzfONQa0cmhihp69o.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ47-Asy1Em_lq_aK3hpr-7p3m1_EcrANmrLqEupLPVedRVp2x5pirzfA9Xa0cmhihp69o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ47-Asy1Em_lq_aK3hpr-7p3m1_EcrANmrLqEupLPVedRVp2x5pirzfDZXa0cmhihp69o.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ47-Asy1Em_lq_aK3hpr-7p3m1_EcrANmrLqEupLPVedRVp2x5pirzfFFXa0cmhihp69o.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosans/v2/FwZ47-Asy1Em_lq_aK3hpr-7p3m1_EcrANmrLqEupLPVedRVp2x5pirzfHhXa0cmhihp69o.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zalando-sans-expanded",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e02c802e-9b61-4d88-a39f-572c3e4853f2",
-1381332318),$APP.$cljs$cst$2675$family$$,"Zalando Sans Expanded",$APP.$cljs$cst$725$name$$,"Zalando Sans Expanded",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU6jJci8Cy470GaeFwsix1hi3aTmrgRwU-ZoGTKmeLvpK-4OPGIl41hcxm2zLI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU6jJci8Cy470GaeFwsix1hi3aTmrgRwU-ZoGTKmeLvpK-4OC-Il41hcxm2zLI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU6jJci8Cy470GaeFwsix1hi3aTmrgRwU-ZoGTKmeLvpK-4OHGIl41hcxm2zLI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU6jJci8Cy470GaeFwsix1hi3aTmrgRwU-ZoGTKmeLvpK-4OEOIl41hcxm2zLI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU6jJci8Cy470GaeFwsix1hi3aTmrgRwU-ZoGTKmeLvpK-4OK-Pl41hcxm2zLI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU6jJci8Cy470GaeFwsix1hi3aTmrgRwU-ZoGTKmeLvpK-4OJaPl41hcxm2zLI.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU6jJci8Cy470GaeFwsix1hi3aTmrgRwU-ZoGTKmeLvpK-4OPGPl41hcxm2zLI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU6jJci8Cy470GaeFwsix1hi3aTmrgRwU-ZoGTKmeLvpK-4ONiPl41hcxm2zLI.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU4jJci8Cy470GaeFwsix1hi3aTmrgRwU-zqVY1QYuEPgG_LbnL_85rdzuz3LKaMA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU4jJci8Cy470GaeFwsix1hi3aTmrgRwU-zqVY1QYuEPgG_LbnLIc5rdzuz3LKaMA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU4jJci8Cy470GaeFwsix1hi3aTmrgRwU-zqVY1QYuEPgG_LbnLf85rdzuz3LKaMA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU4jJci8Cy470GaeFwsix1hi3aTmrgRwU-zqVY1QYuEPgG_LbnLTc5rdzuz3LKaMA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU4jJci8Cy470GaeFwsix1hi3aTmrgRwU-zqVY1QYuEPgG_LbnLoclrdzuz3LKaMA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,
"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU4jJci8Cy470GaeFwsix1hi3aTmrgRwU-zqVY1QYuEPgG_LbnLmMlrdzuz3LKaMA.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU4jJci8Cy470GaeFwsix1hi3aTmrgRwU-zqVY1QYuEPgG_LbnL_8lrdzuz3LKaMA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosansexpanded/v2/JTU4jJci8Cy470GaeFwsix1hi3aTmrgRwU-zqVY1QYuEPgG_LbnL1slrdzuz3LKaMA.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zalando-sans-semiexpanded",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8d2d71c8-1b46-4007-ad44-a52243774f68",
1277273355),$APP.$cljs$cst$2675$family$$,"Zalando Sans SemiExpanded",$APP.$cljs$cst$725$name$$,"Zalando Sans SemiExpanded",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLhKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrEzR2jhk_n3T6ACkBbEnP9Fs7bOSO7.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLhKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrEzR2jhk_n3T6ACkCFEnP9Fs7bOSO7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLhKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrEzR2jhk_n3T6ACkDbEnP9Fs7bOSO7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLhKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrEzR2jhk_n3T6ACkDpEnP9Fs7bOSO7.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLhKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrEzR2jhk_n3T6ACkAFFXP9Fs7bOSO7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLhKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrEzR2jhk_n3T6ACkA8FXP9Fs7bOSO7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800",$APP.$cljs$cst$725$name$$,"800",$APP.$cljs$cst$1996$weight$$,"800",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLhKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrEzR2jhk_n3T6ACkBbFXP9Fs7bOSO7.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLhKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrEzR2jhk_n3T6ACkByFXP9Fs7bOSO7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,
"200",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLjKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrE5xSReZeOtqQuDVUTURu-HMr5PDO71Qs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLjKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrE5xSReZeOtqQuDVUTUcW-HMr5PDO71Qs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLjKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrE5xSReZeOtqQuDVUTUZu-HMr5PDO71Qs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,
"500",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLjKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrE5xSReZeOtqQuDVUTUam-HMr5PDO71Qs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLjKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrE5xSReZeOtqQuDVUTUUW5HMr5PDO71Qs.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLjKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrE5xSReZeOtqQuDVUTUXy5HMr5PDO71Qs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"800italic",$APP.$cljs$cst$725$name$$,"800 Italic",$APP.$cljs$cst$1996$weight$$,
"800",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLjKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrE5xSReZeOtqQuDVUTURu5HMr5PDO71Qs.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900italic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zalandosanssemiexpanded/v2/6qLjKYcHuh3msE9OaXROVVclRRa-ClZSEipa2hrE5xSReZeOtqQuDVUTUTK5HMr5PDO71Qs.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zen-antique",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("f7926dae-d0e4-42f1-aa98-5ab9bc280c64",475988650),$APP.$cljs$cst$2675$family$$,"Zen Antique",$APP.$cljs$cst$725$name$$,"Zen Antique",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,
"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenantique/v14/AYCPpXPnd91Ma_Zf-Ri2JXJq7PKP5Z_G.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zen-antique-soft",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("0be5bd34-17a4-471c-8f5b-36084666346f",515954135),$APP.$cljs$cst$2675$family$$,"Zen Antique Soft",$APP.$cljs$cst$725$name$$,"Zen Antique Soft",$APP.$cljs$cst$2676$variants$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenantiquesoft/v14/DtV4JwqzSL1q_KwnEWMc_3xfgW6ihwBmkui5HNg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zen-dots",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("bb740ad5-3637-4aa7-9e5a-fe099869e6a2",-1705772229),$APP.$cljs$cst$2675$family$$,"Zen Dots",$APP.$cljs$cst$725$name$$,"Zen Dots",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/zendots/v14/XRXX3ICfm00IGoesQeaETM_FcCIG.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zen-kaku-gothic-antique",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b1ea54ec-1435-4799-a693-d1640c1bdc25",-421277074),$APP.$cljs$cst$2675$family$$,"Zen Kaku Gothic Antique",$APP.$cljs$cst$725$name$$,"Zen Kaku Gothic Antique",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenkakugothicantique/v18/6qLVKYkHvh-nlUpKPAdoVFBtfxDzIn1eCzpB22cM9TarWJtyZyGU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenkakugothicantique/v18/6qLQKYkHvh-nlUpKPAdoVFBtfxDzIn1eCzpB21-g3RKjc4d7.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenkakugothicantique/v18/6qLVKYkHvh-nlUpKPAdoVFBtfxDzIn1eCzpB22dU9DarWJtyZyGU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenkakugothicantique/v18/6qLVKYkHvh-nlUpKPAdoVFBtfxDzIn1eCzpB22cc8jarWJtyZyGU.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenkakugothicantique/v18/6qLVKYkHvh-nlUpKPAdoVFBtfxDzIn1eCzpB22ck8DarWJtyZyGU.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zen-kaku-gothic-new",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("070cefcb-e2bd-41a0-84d4-55cf61ec168b",519309765),$APP.$cljs$cst$2675$family$$,"Zen Kaku Gothic New",$APP.$cljs$cst$725$name$$,"Zen Kaku Gothic New",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenkakugothicnew/v18/gNMVW2drQpDw0GjzrVNFf_valaDBcznOqpdKaWTSTGlMyd8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenkakugothicnew/v18/gNMYW2drQpDw0GjzrVNFf_valaDBcznOkjtiTWz5UGA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenkakugothicnew/v18/gNMVW2drQpDw0GjzrVNFf_valaDBcznOqs9LaWTSTGlMyd8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenkakugothicnew/v18/gNMVW2drQpDw0GjzrVNFf_valaDBcznOqodNaWTSTGlMyd8.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenkakugothicnew/v18/gNMVW2drQpDw0GjzrVNFf_valaDBcznOqr9PaWTSTGlMyd8.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-zen-kurenaido",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("2283172c-e39b-48f4-bf3f-a551f9a441d8",1350190388),$APP.$cljs$cst$2675$family$$,"Zen Kurenaido",$APP.$cljs$cst$725$name$$,"Zen Kurenaido",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenkurenaido/v19/3XFsEr0515BK2u6UUptu_gWJZfz22PRLd0U.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zen-loop",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("8ed01916-a59b-48a4-a3f8-fc12f0a71bc8",-1301973806),$APP.$cljs$cst$2675$family$$,"Zen Loop",$APP.$cljs$cst$725$name$$,"Zen Loop",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenloop/v11/h0GrssK16UsnJwHsEK9zqwzX5vOG.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",
$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenloop/v11/h0GtssK16UsnJwHsEJ9xoQj14-OGJ0w.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zen-maru-gothic",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("61b6e890-d5c2-42cd-b32c-2b7893905e14",1984239514),$APP.$cljs$cst$2675$family$$,"Zen Maru Gothic",$APP.$cljs$cst$725$name$$,"Zen Maru Gothic",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenmarugothic/v19/o-0XIpIxzW5b-RxT-6A8jWAtCp-cQWpCPJqa_ajlvw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,
"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenmarugothic/v19/o-0SIpIxzW5b-RxT-6A8jWAtCp-k7UJmNLGG9A.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenmarugothic/v19/o-0XIpIxzW5b-RxT-6A8jWAtCp-cGWtCPJqa_ajlvw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenmarugothic/v19/o-0XIpIxzW5b-RxT-6A8jWAtCp-cUW1CPJqa_ajlvw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenmarugothic/v19/o-0XIpIxzW5b-RxT-6A8jWAtCp-caW9CPJqa_ajlvw.ttf"],
null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zen-old-mincho",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("da599cfa-d9a8-4cf9-8f06-3e33af666aa3",1102345211),$APP.$cljs$cst$2675$family$$,"Zen Old Mincho",$APP.$cljs$cst$725$name$$,"Zen Old Mincho",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",
$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenoldmincho/v13/tss0ApVaYytLwxTqcxfMyBveyYb3g31S2s8p.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenoldmincho/v13/tss3ApVaYytLwxTqcxfMyBveyb4Dqlla8dMgPgBu.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenoldmincho/v13/tss3ApVaYytLwxTqcxfMyBveyb4vrVla8dMgPgBu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/zenoldmincho/v13/tss3ApVaYytLwxTqcxfMyBveyb5LrFla8dMgPgBu.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"900",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zenoldmincho/v13/tss3ApVaYytLwxTqcxfMyBveyb5zrlla8dMgPgBu.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zen-tokyo-zoo",
$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("aee8f372-8a31-4294-8917-31f2daadc9d4",495689880),$APP.$cljs$cst$2675$family$$,"Zen Tokyo Zoo",$APP.$cljs$cst$725$name$$,"Zen Tokyo Zoo",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,
"https://fonts.gstatic.com/s/zentokyozoo/v8/NGSyv5ffC0J_BK6aFNtr6sRv8a1uRWe9amg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zeyada",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("e9bb4981-470a-44a6-bee0-7545f48f4d66",-629400980),$APP.$cljs$cst$2675$family$$,"Zeyada",$APP.$cljs$cst$725$name$$,"Zeyada",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zeyada/v22/11hAGpPTxVPUbgZDNGatWKaZ3g.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zhi-mang-xing",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("68387366-37b5-441f-97ae-450ab27f8614",-461410551),$APP.$cljs$cst$2675$family$$,"Zhi Mang Xing",$APP.$cljs$cst$725$name$$,
"Zhi Mang Xing",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zhimangxing/v19/f0Xw0ey79sErYFtWQ9a2rq-g0actfektIJ0.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$266$id$$,"gfont-zilla-slab",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("150e5f5f-ab85-4354-8471-ca88dab1f585",531851191),$APP.$cljs$cst$2675$family$$,"Zilla Slab",$APP.$cljs$cst$725$name$$,"Zilla Slab",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,
"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zillaslab/v12/dFa5ZfeM_74wlPZtksIFYpEY2HSjWlhzbaw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zillaslab/v12/dFanZfeM_74wlPZtksIFaj8CVHapXnp2fazkfg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,
"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zillaslab/v12/dFa6ZfeM_74wlPZtksIFWj0w_HyIRlE.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zillaslab/v12/dFa4ZfeM_74wlPZtksIFaj86-F6NVlFqdA.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500",$APP.$cljs$cst$725$name$$,"500",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zillaslab/v12/dFa5ZfeM_74wlPZtksIFYskZ2HSjWlhzbaw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"500italic",$APP.$cljs$cst$725$name$$,"500 Italic",$APP.$cljs$cst$1996$weight$$,"500",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zillaslab/v12/dFanZfeM_74wlPZtksIFaj8CDHepXnp2fazkfg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600",$APP.$cljs$cst$725$name$$,"600",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zillaslab/v12/dFa5ZfeM_74wlPZtksIFYuUe2HSjWlhzbaw.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"600italic",
$APP.$cljs$cst$725$name$$,"600 Italic",$APP.$cljs$cst$1996$weight$$,"600",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zillaslab/v12/dFanZfeM_74wlPZtksIFaj8CIHCpXnp2fazkfg.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zillaslab/v12/dFa5ZfeM_74wlPZtksIFYoEf2HSjWlhzbaw.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700italic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zillaslab/v12/dFanZfeM_74wlPZtksIFaj8CRHGpXnp2fazkfg.ttf"],null)],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"gfont-zilla-slab-highlight",$cljs$cst$424$uuid$$,new $cljs$core$UUID$$("b6ffb057-86a6-4dd7-bdf5-834d75819639",
1858319356),$APP.$cljs$cst$2675$family$$,"Zilla Slab Highlight",$APP.$cljs$cst$725$name$$,"Zilla Slab Highlight",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zillaslabhighlight/v21/gNMbW2BrTpK8-inLtBJgMMfbm6uNVDvRxhtIY2DwSXlM.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"700",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"https://fonts.gstatic.com/s/zillaslabhighlight/v21/gNMUW2BrTpK8-inLtBJgMMfbm6uNVDvRxiP0TET4YmVF0Mb6.ttf"],null)],null)],null)],!0);
$app$main$fonts$local_fonts$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"sourcesanspro",$APP.$cljs$cst$725$name$$,"Source Sans Pro",$APP.$cljs$cst$2675$family$$,"sourcesanspro",$APP.$cljs$cst$2676$variants$$,new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$266$id$$,
"200",$APP.$cljs$cst$725$name$$,"200",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"normal",$APP.$cljs$cst$1371$suffix$$,"extralight",$cljs$cst$2677$ttf_url$$,"sourcesanspro-extralight.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$266$id$$,"200italic",$APP.$cljs$cst$725$name$$,"200 Italic",$APP.$cljs$cst$1996$weight$$,"200",$APP.$cljs$cst$1904$style$$,"italic",$APP.$cljs$cst$1371$suffix$$,"extralightitalic",$cljs$cst$2677$ttf_url$$,"sourcesanspro-extralightitalic.ttf"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$266$id$$,"300",$APP.$cljs$cst$725$name$$,"300",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"normal",$APP.$cljs$cst$1371$suffix$$,"light",$cljs$cst$2677$ttf_url$$,"sourcesanspro-light.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$266$id$$,"300italic",$APP.$cljs$cst$725$name$$,"300 Italic",$APP.$cljs$cst$1996$weight$$,"300",$APP.$cljs$cst$1904$style$$,"italic",$APP.$cljs$cst$1371$suffix$$,
"lightitalic",$cljs$cst$2677$ttf_url$$,"sourcesanspro-lightitalic.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"regular",$APP.$cljs$cst$725$name$$,"400",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"sourcesanspro-regular.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"italic",$APP.$cljs$cst$725$name$$,"400 Italic",$APP.$cljs$cst$1996$weight$$,"400",$APP.$cljs$cst$1904$style$$,
"italic",$cljs$cst$2677$ttf_url$$,"sourcesanspro-italic.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"bold",$APP.$cljs$cst$725$name$$,"700",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"sourcesanspro-bold.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"bolditalic",$APP.$cljs$cst$725$name$$,"700 Italic",$APP.$cljs$cst$1996$weight$$,"700",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"sourcesanspro-bolditalic.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"black",$APP.$cljs$cst$725$name$$,"900",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"normal",$cljs$cst$2677$ttf_url$$,"sourcesanspro-black.ttf"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,"blackitalic",$APP.$cljs$cst$725$name$$,"900 Italic",$APP.$cljs$cst$1996$weight$$,"900",$APP.$cljs$cst$1904$style$$,"italic",
$cljs$cst$2677$ttf_url$$,"sourcesanspro-blackitalic.ttf"],null)],null)],null)],null);$APP.$app$main$fonts$fontsdb$$=$okulary$core$atom$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$APP.$app$main$fonts$fonts$$=$okulary$core$atom$$($APP.$cljs$core$PersistentVector$EMPTY$$);
$cljs$core$_add_watch$$($APP.$app$main$fonts$fontsdb$$,"main",function($_$jscomp$1590$$,$___$1$jscomp$958$$,$___$2$jscomp$182$$,$db$jscomp$6$$){return $APP.$cljs$core$reset_BANG_$$($APP.$app$main$fonts$fonts$$,$APP.$cljs$core$vec$$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__53013_SHARP_$$,$p2__53012_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p2__53012_SHARP_$$,$APP.$cljs$cst$1795$index$$,$p1__53013_SHARP_$$)},$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,
$APP.$cljs$core$vals$$($db$jscomp$6$$)))))});$app$main$fonts$register_BANG_$$($cljs$cst$2678$builtin$$,$app$main$fonts$local_fonts$$);$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1195$google_fonts_provider$$)&&$app$main$fonts$register_BANG_$$($cljs$cst$2679$google$$,$app$main$fonts$google_fonts$$);
var $app$main$fonts$loaded$$=$okulary$core$atom$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$app$main$fonts$loading$$=$okulary$core$atom$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$app$main$fonts$loaded_hints$$=$okulary$core$atom$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$app$main$fonts$load_font$$,$method_table__5622__auto__$jscomp$inline_12116$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$inline_12117$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$inline_12118$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$inline_12119$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$inline_12120$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());
$app$main$fonts$load_font$$=new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.main.fonts","load-font"),$APP.$cljs$cst$2584$backend$$,$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$inline_12120$$,$method_table__5622__auto__$jscomp$inline_12116$$,$prefer_table__5623__auto__$jscomp$inline_12117$$,$method_cache__5624__auto__$jscomp$inline_12118$$,$cached_hierarchy__5625__auto__$jscomp$inline_12119$$);
$app$main$fonts$load_font$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function($map__53045__$1_p__53044$$){$map__53045__$1_p__53044$$=$APP.$cljs$core$__destructure_map$$($map__53045__$1_p__53044$$);var $backend$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53045__$1_p__53044$$,$APP.$cljs$cst$2584$backend$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.fonts",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"no implementation found for"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2584$backend$$,$backend$jscomp$8$$],null)],null)}),null,"app.main.fonts",$APP.$cljs$cst$1162$warn$$,!1);return null});
$app$main$fonts$load_font$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2678$builtin$$,function($map__53047__$1_on_loaded_p__53046$$){$map__53047__$1_on_loaded_p__53046$$=$APP.$cljs$core$__destructure_map$$($map__53047__$1_on_loaded_p__53046$$);var $id$jscomp$291$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53047__$1_on_loaded_p__53046$$,$APP.$cljs$cst$266$id$$);$map__53047__$1_on_loaded_p__53046$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53047__$1_on_loaded_p__53046$$,
$cljs$cst$2680$app_DOT_main_DOT_fonts_SLASH_on_loaded$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.fonts",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"load-font"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1757$font_id$$,$id$jscomp$291$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2584$backend$$,"builtin"],null)],null)}),null,"app.main.fonts",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$fn_QMARK_$$($map__53047__$1_on_loaded_p__53046$$)?$map__53047__$1_on_loaded_p__53046$$.$cljs$core$IFn$_invoke$arity$1$?$map__53047__$1_on_loaded_p__53046$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$291$$):
$map__53047__$1_on_loaded_p__53046$$($id$jscomp$291$$):null});
$app$main$fonts$load_font$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2679$google$$,function($map__53051__$1_p__53050_url$jscomp$80$$){$map__53051__$1_p__53050_url$jscomp$80$$=$APP.$cljs$core$__destructure_map$$($map__53051__$1_p__53050_url$jscomp$80$$);var $id$jscomp$292$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53051__$1_p__53050_url$jscomp$80$$,$APP.$cljs$cst$266$id$$),$on_loaded$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53051__$1_p__53050_url$jscomp$80$$,$cljs$cst$2680$app_DOT_main_DOT_fonts_SLASH_on_loaded$$);
typeof window!=="undefined"&&($APP.$app$common$logging$enabled_QMARK_$$("app.main.fonts",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"load-font"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1757$font_id$$,$id$jscomp$292$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2584$backend$$,"google"],null)],null)}),null,"app.main.fonts",$APP.$cljs$cst$1160$debug$$,!1),$map__53051__$1_p__53050_url$jscomp$80$$=$app$main$fonts$generate_gfonts_url$$($map__53051__$1_p__53050_url$jscomp$80$$),$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$fonts$add_font_css_BANG_$$,
$id$jscomp$292$$),$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $on_loaded$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_loaded$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$292$$):$on_loaded$jscomp$1$$($id$jscomp$292$$)},$APP.$beicon$v2$core$map$$($app$main$fonts$process_gfont_css$$,$app$main$fonts$fetch_gfont_css$$($map__53051__$1_p__53050_url$jscomp$80$$)))));return null});
$app$main$fonts$load_font$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$2682$custom$$,function($on_loaded$jscomp$2_p__53060$$){var $css$jscomp$2_map__53061__$1$$=$APP.$cljs$core$__destructure_map$$($on_loaded$jscomp$2_p__53060$$),$id$jscomp$293$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($css$jscomp$2_map__53061__$1$$,$APP.$cljs$cst$266$id$$);$on_loaded$jscomp$2_p__53060$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($css$jscomp$2_map__53061__$1$$,$cljs$cst$2680$app_DOT_main_DOT_fonts_SLASH_on_loaded$$);
return typeof window!=="undefined"?($APP.$app$common$logging$enabled_QMARK_$$("app.main.fonts",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"load-font"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1757$font_id$$,$id$jscomp$293$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2584$backend$$,"custom"],null)],null)}),null,"app.main.fonts",$APP.$cljs$cst$1160$debug$$,!1),$css$jscomp$2_map__53061__$1$$=$app$main$fonts$generate_custom_font_css$$($css$jscomp$2_map__53061__$1$$),$app$main$fonts$add_font_css_BANG_$$($id$jscomp$293$$,$css$jscomp$2_map__53061__$1$$),$APP.$cljs$core$fn_QMARK_$$($on_loaded$jscomp$2_p__53060$$)?
$on_loaded$jscomp$2_p__53060$$.$cljs$core$IFn$_invoke$arity$0$?$on_loaded$jscomp$2_p__53060$$.$cljs$core$IFn$_invoke$arity$0$():$on_loaded$jscomp$2_p__53060$$():null):null});
$APP.$app$main$fonts$ensure_loaded_BANG_$$=function $app$main$fonts$ensure_loaded_BANG_$$($var_args$jscomp$1097$$){switch(arguments.length){case 1:return $app$main$fonts$ensure_loaded_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$fonts$ensure_loaded_BANG_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$main$fonts$ensure_loaded_BANG_$$.$cljs$core$IFn$_invoke$arity$1$=function($font_id$jscomp$1$$){return $APP.$app$main$fonts$ensure_loaded_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($font_id$jscomp$1$$,null)};
$APP.$app$main$fonts$ensure_loaded_BANG_$$.$cljs$core$IFn$_invoke$arity$2$=function($font_id$jscomp$2$$,$variant_id$jscomp$2$$){function $on_load$$($resolve$jscomp$22$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$main$fonts$loaded$$,$APP.$cljs$core$conj$$,$font_id$jscomp$2$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$main$fonts$loading$$,$APP.$cljs$core$dissoc$$,$font_id$jscomp$2$$);return $resolve$jscomp$22$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$22$$.$cljs$core$IFn$_invoke$arity$1$($font_id$jscomp$2$$):
$resolve$jscomp$22$$($font_id$jscomp$2$$)}$APP.$app$common$logging$enabled_QMARK_$$("app.main.fonts",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2683$action$$,"try-ensure-loaded!"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1757$font_id$$,$font_id$jscomp$2$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2000$variant_id$$,$variant_id$jscomp$2$$],null)],null)}),null,"app.main.fonts",$APP.$cljs$cst$1160$debug$$,!1);if(typeof window==="undefined")return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($app$main$fonts$loaded_hints$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1757$font_id$$,$font_id$jscomp$2$$,$APP.$cljs$cst$1759$font_variant_id$$,$variant_id$jscomp$2$$],null)),$APP.$promesa$impl$promise$resolved$$($font_id$jscomp$2$$);var $font$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$),$font_id$jscomp$2$$);if($font$jscomp$12$$==null||$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($app$main$fonts$loaded$$),$font_id$jscomp$2$$))return $APP.$promesa$impl$promise$resolved$$($font_id$jscomp$2$$);
if($APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($app$main$fonts$loading$$),$font_id$jscomp$2$$))return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($app$main$fonts$loading$$),$font_id$jscomp$2$$);var $load_p$$=$APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($promesa$core$create$cljs$0core$0IFn$0_invoke$0arity$01$$(function($resolve$jscomp$23$$){return $app$main$fonts$load_font$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($font$jscomp$12$$,
$cljs$cst$2680$app_DOT_main_DOT_fonts_SLASH_on_loaded$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_load$$,$resolve$jscomp$23$$)))}),$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($promesa$core$delay$$,120));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$main$fonts$loading$$,$APP.$cljs$core$assoc$$,$font_id$jscomp$2$$,$load_p$$);return $load_p$$};$APP.$app$main$fonts$ensure_loaded_BANG_$$.$cljs$lang$maxFixedArity$=2;
var $app$main$fonts$font_styles$$=new Map;var $app$main$ui$context$render_id$$,$app$main$ui$context$current_svg_root_id$$,$app$main$ui$context$active_frames$$,$app$main$ui$context$is_component_QMARK_$$;$app$main$ui$context$render_id$$=(0,$APP.$rumext$v2$create_context$$)(null);$APP.$app$main$ui$context$current_route$$=(0,$APP.$rumext$v2$create_context$$)(null);$APP.$app$main$ui$context$current_profile$$=(0,$APP.$rumext$v2$create_context$$)(null);$APP.$app$main$ui$context$current_team_id$$=(0,$APP.$rumext$v2$create_context$$)(null);
$APP.$app$main$ui$context$current_project_id$$=(0,$APP.$rumext$v2$create_context$$)(null);$APP.$app$main$ui$context$current_page_id$$=(0,$APP.$rumext$v2$create_context$$)(null);$APP.$app$main$ui$context$current_file_id$$=(0,$APP.$rumext$v2$create_context$$)(null);$APP.$app$main$ui$context$current_vbox$$=(0,$APP.$rumext$v2$create_context$$)(null);$app$main$ui$context$current_svg_root_id$$=(0,$APP.$rumext$v2$create_context$$)(null);$app$main$ui$context$active_frames$$=(0,$APP.$rumext$v2$create_context$$)(null);
$APP.$app$main$ui$context$render_thumbnails$$=(0,$APP.$rumext$v2$create_context$$)(null);(0,$APP.$rumext$v2$create_context$$)(null);$APP.$app$main$ui$context$design_tokens$$=(0,$APP.$rumext$v2$create_context$$)(null);(0,$APP.$rumext$v2$create_context$$)(null);(0,$APP.$rumext$v2$create_context$$)(null);$APP.$app$main$ui$context$current_zoom$$=(0,$APP.$rumext$v2$create_context$$)(null);$APP.$app$main$ui$context$workspace_read_only_QMARK_$$=(0,$APP.$rumext$v2$create_context$$)(null);
$APP.$app$main$ui$context$is_render_QMARK_$$=(0,$APP.$rumext$v2$create_context$$)(!1);$app$main$ui$context$is_component_QMARK_$$=(0,$APP.$rumext$v2$create_context$$)(!1);$APP.$app$main$ui$context$sidebar$$=(0,$APP.$rumext$v2$create_context$$)(null);$APP.$app$main$ui$context$permissions$$=(0,$APP.$rumext$v2$create_context$$)(null);$APP.$app$main$ui$context$can_edit_QMARK_$$=(0,$APP.$rumext$v2$create_context$$)(null);$APP.$app$main$ui$context$active_tokens_by_type$$=(0,$APP.$rumext$v2$create_context$$)(null);$APP.$app$main$ui$formats$format_pixels$$=function $app$main$ui$formats$format_pixels$$($var_args$jscomp$1101$$){switch(arguments.length){case 1:return $app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$=function($value$jscomp$462$$){return $APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$462$$,null)};
$APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$2$=function($value$jscomp$463_value__$1$jscomp$10$$,$map__51867__$1_p__51866_precision$jscomp$13$$){$map__51867__$1_p__51866_precision$jscomp$13$$=$APP.$cljs$core$__destructure_map$$($map__51867__$1_p__51866_precision$jscomp$13$$);$map__51867__$1_p__51866_precision$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51867__$1_p__51866_precision$jscomp$13$$,$APP.$cljs$cst$267$precision$$,2);$value$jscomp$463_value__$1$jscomp$10$$=
typeof $value$jscomp$463_value__$1$jscomp$10$$==="string"?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$463_value__$1$jscomp$10$$):$value$jscomp$463_value__$1$jscomp$10$$;return $APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($value$jscomp$463_value__$1$jscomp$10$$))?""+($APP.$app$common$math$precision$$($value$jscomp$463_value__$1$jscomp$10$$,$map__51867__$1_p__51866_precision$jscomp$13$$)??"")+"px":null};
$APP.$app$main$ui$formats$format_pixels$$.$cljs$lang$maxFixedArity$=2;var $app$main$ui$shapes$text$fo_text$render_node$$=function $app$main$ui$shapes$text$fo_text$render_node$$($props_53169$$){var $children$jscomp$196_map__53171__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_53169$$,"node")),$type$jscomp$381$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$196_map__53171__$1$$,$APP.$cljs$cst$139$type$$),$component$jscomp$46_text$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$196_map__53171__$1$$,
$APP.$cljs$cst$1588$text$$);$children$jscomp$196_map__53171__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$196_map__53171__$1$$,$APP.$cljs$cst$342$children$$);if(typeof $component$jscomp$46_text$jscomp$24$$==="string")return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$text$fo_text$render_text$$,$props_53169$$);$component$jscomp$46_text$jscomp$24$$=function(){switch($type$jscomp$381$$){case "root":return $app$main$ui$shapes$text$fo_text$render_root$$;case "paragraph-set":return $app$main$ui$shapes$text$fo_text$render_paragraph_set$$;
case "paragraph":return $app$main$ui$shapes$text$fo_text$render_paragraph$$;default:return null}}();return $APP.$cljs$core$truth_$$($component$jscomp$46_text$jscomp$24$$)?(0,$APP.$rumext$v2$create_element$$)($component$jscomp$46_text$jscomp$24$$,$props_53169$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$$,$JSCompiler_temp_const$jscomp$929_p__53173$$){var $JSCompiler_inline_result$jscomp$931_index$jscomp$220_props__$1$jscomp$inline_5743$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$929_p__53173$$,
0,null),$node$jscomp$268$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$929_p__53173$$,1,null);$JSCompiler_temp_const$jscomp$929_p__53173$$=$out_arr__44124__auto__$$.push;$JSCompiler_inline_result$jscomp$931_index$jscomp$220_props__$1$jscomp$inline_5743$$=$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$clone$$($props_53169$$),"node",$node$jscomp$268$$),"index",$JSCompiler_inline_result$jscomp$931_index$jscomp$220_props__$1$jscomp$inline_5743$$),
"key",$JSCompiler_inline_result$jscomp$931_index$jscomp$220_props__$1$jscomp$inline_5743$$);$JSCompiler_inline_result$jscomp$931_index$jscomp$220_props__$1$jscomp$inline_5743$$=(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$text$fo_text$render_node$$,$JSCompiler_inline_result$jscomp$931_index$jscomp$220_props__$1$jscomp$inline_5743$$);$JSCompiler_temp_const$jscomp$929_p__53173$$.call($out_arr__44124__auto__$$,$JSCompiler_inline_result$jscomp$931_index$jscomp$220_props__$1$jscomp$inline_5743$$);
return $out_arr__44124__auto__$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($children$jscomp$196_map__53171__$1$$))):null},$app$main$ui$shapes$text$fo_text$text_shape$$=(0,$APP.$rumext$v2$forward_ref$$)(function($props_53193_shape$jscomp$308$$,$ref$jscomp$23$$){var $grow_type$jscomp$2$$=$props_53193_shape$jscomp$308$$["grow-type"];$props_53193_shape$jscomp$308$$=$props_53193_shape$jscomp$308$$.shape;var $transform$jscomp$62$$=$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($props_53193_shape$jscomp$308$$),
$id$jscomp$297$$=$props_53193_shape$jscomp$308$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_53193_shape$jscomp$308$$,$APP.$cljs$cst$266$id$$),$x$jscomp$1146$$=$props_53193_shape$jscomp$308$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_53193_shape$jscomp$308$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$385$$=$props_53193_shape$jscomp$308$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_53193_shape$jscomp$308$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$79$$=
$props_53193_shape$jscomp$308$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_53193_shape$jscomp$308$$,$APP.$cljs$cst$290$width$$),$height$jscomp$72$$=$props_53193_shape$jscomp$308$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_53193_shape$jscomp$308$$,$APP.$cljs$cst$1522$height$$),$content$jscomp$117$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_53193_shape$jscomp$308$$,$APP.$cljs$cst$1637$content$$),$color_mapping_inverse$jscomp$1_vec__53194$$=
$app$main$ui$shapes$text$fo_text$retrieve_colors$$($props_53193_shape$jscomp$308$$),$colors$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($color_mapping_inverse$jscomp$1_vec__53194$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($color_mapping_inverse$jscomp$1_vec__53194$$,1,null);$color_mapping_inverse$jscomp$1_vec__53194$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($color_mapping_inverse$jscomp$1_vec__53194$$,2,null);return(0,$APP.$rumext$v2$jsxs$$)("foreignObject",
{width:$APP.$cljs$core$truth_$$(function(){var $fexpr__53197$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2036$auto_width$$,null],null),null);return $fexpr__53197$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__53197$$.$cljs$core$IFn$_invoke$arity$1$($grow_type$jscomp$2$$):$fexpr__53197$$($grow_type$jscomp$2$$)}())?1E5:$width$jscomp$79$$,height:$APP.$cljs$core$truth_$$(function(){var $fexpr__53198$$=new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2035$auto_height$$,null,$APP.$cljs$cst$2036$auto_width$$,null],null),null);return $fexpr__53198$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__53198$$.$cljs$core$IFn$_invoke$arity$1$($grow_type$jscomp$2$$):$fexpr__53198$$($grow_type$jscomp$2$$)}())?1E5:$height$jscomp$72$$,children:[(0,$APP.$rumext$v2$jsx$$)("style",{children:".text-node { background-clip: text;\n                           -webkit-background-clip: text; }"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$text$fo_text$render_node$$,
{index:0,shape:$props_53193_shape$jscomp$308$$,node:$content$jscomp$117$$})],x:$x$jscomp$1146$$,id:$id$jscomp$297$$,"data-mapping":JSON.stringify($APP.$cljs$core$clj__GT_js$$($color_mapping_inverse$jscomp$1_vec__53194$$)),transform:$transform$jscomp$62$$,"data-colors":$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$colors$jscomp$3$$),y:$y$jscomp$385$$,ref:$ref$jscomp$23$$})});var $app$common$svg$xml_id_regex$$=/#([:A-Z_a-z\xC0-\xD6\xD8-\xF6\xF8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\u10000-\uEFFFF][\.\-:0-9\xB7A-Z_a-z\xC0-\xD6\xD8-\xF6\xF8-\u02FF\u0300-\u036F\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u203F-\u2040\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\u10000-\uEFFFF]*)/,$app$common$svg$matrices_regex$$=/(matrix|translate|scale|rotate|skewX|skewY)\(([^\)]*)\)/,$app$common$svg$number_regex$$=
/[+-]?\d*(\.\d+)?([eE][+-]?\d+)?/,$app$common$svg$tags_to_remove$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2689$mask$$,null,$cljs$cst$2690$clipPath$$,null,$APP.$cljs$cst$939$title$$,null,$APP.$cljs$cst$2691$filter$$,null,$cljs$cst$2692$linearGradient$$,null,$cljs$cst$2693$radialGradient$$,null,$cljs$cst$1633$metadata$$,null],null),null),$app$common$svg$svg_tags$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
79,[$APP.$cljs$cst$296$path$$,null,$cljs$cst$2694$altGlyph$$,null,$APP.$cljs$cst$2689$mask$$,null,$cljs$cst$2695$feBlend$$,null,$APP.$cljs$cst$2696$textPath$$,null,$cljs$cst$2697$feDistantLight$$,null,$APP.$cljs$cst$2698$desc$$,null,$cljs$cst$2699$feConvolveMatrix$$,null,$cljs$cst$2700$feDisplacementMap$$,null,$cljs$cst$2701$feTurbulence$$,null,$cljs$cst$2702$font_face_uri$$,null,$cljs$cst$2703$use$$,null,$cljs$cst$2704$fePointLight$$,null,$APP.$cljs$cst$219$symbol$$,null,$cljs$cst$2705$feFuncB$$,
null,$cljs$cst$2706$marker$$,null,$cljs$cst$2707$feComponentTransfer$$,null,$cljs$cst$2708$color_profile$$,null,$APP.$cljs$cst$1417$circle$$,null,$cljs$cst$2709$animateColor$$,null,$cljs$cst$2690$clipPath$$,null,$cljs$cst$2710$altGlyphDef$$,null,$APP.$cljs$cst$1997$cursor$$,null,$cljs$cst$2711$animate$$,null,$cljs$cst$2712$font_face$$,null,$cljs$cst$2713$feMergeNode$$,null,$cljs$cst$2714$mpath$$,null,$cljs$cst$2715$feSpotLight$$,null,$APP.$cljs$cst$2716$font$$,null,$APP.$cljs$cst$939$title$$,null,
$cljs$cst$2717$glyphRef$$,null,$APP.$cljs$cst$1904$style$$,null,$cljs$cst$2718$feFlood$$,null,$cljs$cst$2719$feMorphology$$,null,$APP.$cljs$cst$1744$g$$,null,$cljs$cst$2720$feGaussianBlur$$,null,$cljs$cst$2721$stop$$,null,$cljs$cst$2722$feDiffuseLighting$$,null,$APP.$cljs$cst$2691$filter$$,null,$cljs$cst$2723$missing_glyph$$,null,$APP.$cljs$cst$209$line$$,null,$cljs$cst$2724$feComposite$$,null,$cljs$cst$2725$tspan$$,null,$cljs$cst$2726$vkern$$,null,$cljs$cst$2727$defs$$,null,$cljs$cst$2728$glyph$$,
null,$APP.$cljs$cst$1538$svg$$,null,$cljs$cst$2729$feTile$$,null,$APP.$cljs$cst$2730$ellipse$$,null,$cljs$cst$2731$feImage$$,null,$cljs$cst$2732$animateTransform$$,null,$cljs$cst$2733$feColorMatrix$$,null,$cljs$cst$2692$linearGradient$$,null,$cljs$cst$2734$font_face_src$$,null,$APP.$cljs$cst$1612$image$$,null,$cljs$cst$2693$radialGradient$$,null,$cljs$cst$2735$feMerge$$,null,$cljs$cst$2736$feOffset$$,null,$APP.$cljs$cst$203$set$$,null,$cljs$cst$2737$feSpecularLighting$$,null,$cljs$cst$2738$font_face_format$$,
null,$cljs$cst$2739$feFuncA$$,null,$cljs$cst$2740$animateMotion$$,null,$cljs$cst$2741$hkern$$,null,$cljs$cst$2742$tref$$,null,$APP.$cljs$cst$2743$polyline$$,null,$APP.$cljs$cst$1611$rect$$,null,$cljs$cst$2744$feFuncR$$,null,$cljs$cst$2745$altGlyphItem$$,null,$cljs$cst$1633$metadata$$,null,$cljs$cst$2746$font_face_name$$,null,$cljs$cst$2747$feFuncG$$,null,$cljs$cst$2748$switch$$,null,$APP.$cljs$cst$1519$a$$,null,$cljs$cst$2749$view$$,null,$APP.$cljs$cst$2750$polygon$$,null,$cljs$cst$1844$pattern$$,
null,$cljs$cst$2751$foreignObject$$,null,$APP.$cljs$cst$1588$text$$,null],null),null),$app$common$svg$svg_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,196,[$APP.$cljs$cst$1511$y$$,null,$cljs$cst$2752$divisor$$,null,$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$1762$font_style$$,null,$cljs$cst$2753$gradientUnits$$,null,$cljs$cst$2754$xml_COLON_lang$$,null,$cljs$cst$2755$baseProfile$$,null,$cljs$cst$2756$stitchTiles$$,null,$cljs$cst$2757$strikethrough_thickness$$,
null,$cljs$cst$2758$accumulate$$,null,$cljs$cst$2759$startOffset$$,null,$cljs$cst$2760$x_height$$,null,$cljs$cst$2761$exponent$$,null,$cljs$cst$2762$bbox$$,null,$cljs$cst$2763$xlink_COLON_arcrole$$,null,$cljs$cst$2764$stdDeviation$$,null,$APP.$cljs$cst$338$min$$,null,$cljs$cst$2765$font_stretch$$,null,$APP.$cljs$cst$954$format$$,null,$cljs$cst$2766$hanging$$,null,$APP.$cljs$cst$1881$rx$$,null,$APP.$cljs$cst$1743$r$$,null,$cljs$cst$2767$accent_height$$,null,$cljs$cst$2768$pointsAtZ$$,null,$cljs$cst$2769$textLength$$,
null,$cljs$cst$2770$requiredExtensions$$,null,$cljs$cst$2771$elevation$$,null,$cljs$cst$2772$xlink_COLON_show$$,null,$cljs$cst$2773$restart$$,null,$cljs$cst$2774$intercept$$,null,$cljs$cst$2775$kernelMatrix$$,null,$APP.$cljs$cst$1289$transform$$,null,$cljs$cst$2776$patternUnits$$,null,$cljs$cst$2777$dx$$,null,$cljs$cst$2778$maskContentUnits$$,null,$cljs$cst$2779$tableValues$$,null,$cljs$cst$2780$zoomAndPan$$,null,$cljs$cst$2781$refY$$,null,$cljs$cst$2782$patternContentUnits$$,null,$cljs$cst$2783$amplitude$$,
null,$APP.$cljs$cst$1760$font_size$$,null,$cljs$cst$2784$repeatDur$$,null,$cljs$cst$2785$preserveAlpha$$,null,$APP.$cljs$cst$195$offset$$,null,$cljs$cst$2786$kernelUnitLength$$,null,$cljs$cst$2787$stemv$$,null,$APP.$cljs$cst$1902$scale$$,null,$cljs$cst$2788$font_variant$$,null,$APP.$cljs$cst$1761$font_weight$$,null,$cljs$cst$2789$filterUnits$$,null,$cljs$cst$2790$pathLength$$,null,$cljs$cst$2791$edgeMode$$,null,$APP.$cljs$cst$1578$method$$,null,$cljs$cst$2792$repeatCount$$,null,$cljs$cst$2793$pointsAtY$$,
null,$cljs$cst$2794$u1$$,null,$cljs$cst$2795$targetY$$,null,$cljs$cst$2796$spreadMethod$$,null,$cljs$cst$2797$ideographic$$,null,$APP.$cljs$cst$725$name$$,null,$cljs$cst$2798$preserveAspectRatio$$,null,$cljs$cst$2799$horiz_origin_x$$,null,$APP.$cljs$cst$1403$fill$$,null,$cljs$cst$2800$xml_COLON_space$$,null,$cljs$cst$2801$markerWidth$$,null,$cljs$cst$2802$clipPathUnits$$,null,$cljs$cst$2803$vert_origin_y$$,null,$cljs$cst$2804$contentScriptType$$,null,$cljs$cst$2805$strikethrough_position$$,null,$cljs$cst$2806$markerHeight$$,
null,$cljs$cst$2807$horiz_origin_y$$,null,$APP.$cljs$cst$1524$y1$$,null,$APP.$cljs$cst$320$mode$$,null,$APP.$cljs$cst$290$width$$,null,$cljs$cst$2808$dy$$,null,$cljs$cst$2809$g2$$,null,$cljs$cst$2810$orientation$$,null,$cljs$cst$2811$panose_1$$,null,$APP.$cljs$cst$139$type$$,null,$cljs$cst$2812$targetX$$,null,$cljs$cst$2813$vert_origin_x$$,null,$cljs$cst$2814$yChannelSelector$$,null,$APP.$cljs$cst$1604$points$$,null,$cljs$cst$2815$orient$$,null,$cljs$cst$2816$underline_thickness$$,null,$cljs$cst$2817$horiz_adv_x$$,
null,$cljs$cst$2818$maskUnits$$,null,$APP.$cljs$cst$198$string$$,null,$cljs$cst$1565$ascent$$,null,$cljs$cst$2819$calcMode$$,null,$APP.$cljs$cst$2820$radius$$,null,$cljs$cst$2821$diffuseConstant$$,null,$cljs$cst$2822$xlink_COLON_type$$,null,$cljs$cst$2823$contentStyleType$$,null,$cljs$cst$768$seed$$,null,$cljs$cst$2824$specularExponent$$,null,$cljs$cst$733$k$$,null,$APP.$cljs$cst$939$title$$,null,$cljs$cst$2825$arabic_form$$,null,$cljs$cst$2826$widths$$,null,$cljs$cst$2717$glyphRef$$,null,$APP.$cljs$cst$1904$style$$,
null,$cljs$cst$2827$unicode_range$$,null,$APP.$cljs$cst$2828$lang$$,null,$cljs$cst$2829$in2$$,null,$cljs$cst$2830$begin$$,null,$cljs$cst$2831$markerUnits$$,null,$cljs$cst$2832$g1$$,null,$cljs$cst$2833$z$$,null,$cljs$cst$2834$azimuth$$,null,$cljs$cst$2835$alphabetic$$,null,$cljs$cst$2836$xmlns_COLON_xlink$$,null,$cljs$cst$2837$units_per_em$$,null,$cljs$cst$2838$overline_position$$,null,$cljs$cst$2839$glyph_name$$,null,$cljs$cst$1566$descent$$,null,$cljs$cst$2840$cap_height$$,null,$cljs$cst$2841$viewTarget$$,
null,$cljs$cst$2842$numOctaves$$,null,$APP.$cljs$cst$828$result$$,null,$APP.$cljs$cst$1863$from$$,null,$cljs$cst$2843$u2$$,null,$APP.$cljs$cst$339$max$$,null,$APP.$cljs$cst$1897$cx$$,null,$APP.$cljs$cst$266$id$$,null,$APP.$cljs$cst$301$values$$,null,$APP.$cljs$cst$1291$class$$,null,$cljs$cst$2844$dur$$,null,$cljs$cst$2845$k3$$,null,$cljs$cst$2846$surfaceScale$$,null,$APP.$cljs$cst$1898$cy$$,null,$cljs$cst$2847$underline_position$$,null,$cljs$cst$2848$k4$$,null,$cljs$cst$2849$xlink_COLON_actuate$$,
null,$cljs$cst$2850$externalResourcesRequired$$,null,$cljs$cst$2851$v_mathematical$$,null,$cljs$cst$2852$slope$$,null,$cljs$cst$2853$xlink_COLON_href$$,null,$cljs$cst$2854$baseFrequency$$,null,$cljs$cst$2855$primitiveUnits$$,null,$cljs$cst$2856$keyTimes$$,null,$cljs$cst$2857$additive$$,null,$cljs$cst$2858$operator$$,null,$cljs$cst$2859$filterRes$$,null,$cljs$cst$2860$lengthAdjust$$,null,$cljs$cst$2861$keyPoints$$,null,$cljs$cst$2862$xChannelSelector$$,null,$APP.$cljs$cst$2863$rotate$$,null,$cljs$cst$2864$systemLanguage$$,
null,$cljs$cst$2865$mathematical$$,null,$cljs$cst$365$order$$,null,$cljs$cst$1447$d$$,null,$cljs$cst$2866$specularConstant$$,null,$cljs$cst$2867$by$$,null,$APP.$cljs$cst$1786$origin$$,null,$cljs$cst$2868$limitingConeAngle$$,null,$cljs$cst$2869$fy$$,null,$APP.$cljs$cst$1510$x$$,null,$cljs$cst$2870$vert_adv_y$$,null,$APP.$cljs$cst$1523$x1$$,null,$cljs$cst$2871$pointsAtX$$,null,$APP.$cljs$cst$2872$target$$,null,$cljs$cst$2873$patternTransform$$,null,$cljs$cst$2874$rendering_intent$$,null,$cljs$cst$2875$v_hanging$$,
null,$cljs$cst$2876$requiredFeatures$$,null,$APP.$cljs$cst$1293$end$$,null,$cljs$cst$2877$xlink_COLON_title$$,null,$cljs$cst$2878$unicode$$,null,$cljs$cst$2879$bias$$,null,$APP.$cljs$cst$2289$version$$,null,$APP.$cljs$cst$1526$y2$$,null,$cljs$cst$2880$viewBox$$,null,$cljs$cst$2881$v_ideographic$$,null,$cljs$cst$2882$fx$$,null,$APP.$cljs$cst$2883$local$$,null,$cljs$cst$2884$k1$$,null,$cljs$cst$2885$k2$$,null,$cljs$cst$2886$refX$$,null,$APP.$cljs$cst$1639$media$$,null,$APP.$cljs$cst$1525$x2$$,null,
$APP.$cljs$cst$1882$ry$$,null,$cljs$cst$2887$attributeType$$,null,$cljs$cst$2888$attributeName$$,null,$cljs$cst$2889$gradientTransform$$,null,$cljs$cst$2890$v_alphabetic$$,null,$APP.$cljs$cst$1758$font_family$$,null,$APP.$cljs$cst$1522$height$$,null,$APP.$cljs$cst$1983$spacing$$,null,$cljs$cst$2891$keySplines$$,null,$APP.$cljs$cst$297$in$$,null,$cljs$cst$2892$overline_thickness$$,null,$APP.$cljs$cst$1864$to$$,null,$cljs$cst$2893$xml_COLON_base$$,null,$cljs$cst$2894$xlink_COLON_role$$,null,$cljs$cst$2895$stemh$$,
null],null),null),$app$common$svg$svg_presentation_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,60,[$cljs$cst$2896$text_anchor$$,null,$cljs$cst$2897$text_rendering$$,null,$APP.$cljs$cst$1762$font_style$$,null,$APP.$cljs$cst$2689$mask$$,null,$cljs$cst$2898$image_rendering$$,null,$cljs$cst$2899$stroke_dasharray$$,null,$cljs$cst$2900$mask_type$$,null,$cljs$cst$2901$color_rendering$$,null,$cljs$cst$2902$fill_rule$$,null,$cljs$cst$2765$font_stretch$$,
null,$APP.$cljs$cst$2903$stroke$$,null,$cljs$cst$2904$stop_color$$,null,$cljs$cst$2905$clip$$,null,$cljs$cst$2906$glyph_orientation_horizontal$$,null,$APP.$cljs$cst$1298$color$$,null,$APP.$cljs$cst$1760$font_size$$,null,$cljs$cst$2907$kerning$$,null,$cljs$cst$2788$font_variant$$,null,$cljs$cst$2908$writing_mode$$,null,$APP.$cljs$cst$1761$font_weight$$,null,$APP.$cljs$cst$2909$overflow$$,null,$cljs$cst$2910$clip_rule$$,null,$APP.$cljs$cst$1740$stroke_opacity$$,null,$APP.$cljs$cst$1403$fill$$,null,
$cljs$cst$2708$color_profile$$,null,$cljs$cst$2911$stroke_linejoin$$,null,$cljs$cst$2912$shape_rendering$$,null,$APP.$cljs$cst$1997$cursor$$,null,$cljs$cst$2913$stroke_dashoffset$$,null,$cljs$cst$2914$word_spacing$$,null,$cljs$cst$2915$stop_opacity$$,null,$cljs$cst$2916$clip_path$$,null,$cljs$cst$2917$stroke_linecap$$,null,$cljs$cst$2918$flood_opacity$$,null,$cljs$cst$2919$lighting_color$$,null,$cljs$cst$2920$alignment_baseline$$,null,$cljs$cst$2921$dominant_baseline$$,null,$cljs$cst$2922$marker_start$$,
null,$APP.$cljs$cst$2691$filter$$,null,$APP.$cljs$cst$1655$stroke_width$$,null,$APP.$cljs$cst$1734$opacity$$,null,$cljs$cst$2923$baseline_shift$$,null,$cljs$cst$2924$color_interpolation_filters$$,null,$APP.$cljs$cst$1768$text_decoration$$,null,$APP.$cljs$cst$1932$display$$,null,$cljs$cst$2925$stroke_miterlimit$$,null,$APP.$cljs$cst$1766$letter_spacing$$,null,$cljs$cst$2926$flood_color$$,null,$cljs$cst$2927$unicode_bidi$$,null,$cljs$cst$2928$marker_mid$$,null,$cljs$cst$2929$pointer_events$$,null,$cljs$cst$2930$font_size_adjust$$,
null,$cljs$cst$2931$glyph_orientation_vertical$$,null,$cljs$cst$2932$color_interpolation$$,null,$cljs$cst$2933$visibility$$,null,$cljs$cst$2934$enable_background$$,null,$APP.$cljs$cst$1963$direction$$,null,$APP.$cljs$cst$1747$fill_opacity$$,null,$APP.$cljs$cst$1758$font_family$$,null,$cljs$cst$2935$marker_end$$,null],null),null),$app$common$svg$inheritable_props$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,46,[$cljs$cst$2896$text_anchor$$,null,$cljs$cst$2897$text_rendering$$,
null,$APP.$cljs$cst$1762$font_style$$,null,$cljs$cst$2898$image_rendering$$,null,$cljs$cst$2899$stroke_dasharray$$,null,$cljs$cst$2901$color_rendering$$,null,$cljs$cst$2902$fill_rule$$,null,$cljs$cst$2765$font_stretch$$,null,$APP.$cljs$cst$2903$stroke$$,null,$cljs$cst$2906$glyph_orientation_horizontal$$,null,$APP.$cljs$cst$1289$transform$$,null,$APP.$cljs$cst$1298$color$$,null,$APP.$cljs$cst$1760$font_size$$,null,$cljs$cst$2788$font_variant$$,null,$cljs$cst$2908$writing_mode$$,null,$APP.$cljs$cst$1761$font_weight$$,
null,$cljs$cst$2706$marker$$,null,$cljs$cst$2910$clip_rule$$,null,$APP.$cljs$cst$1740$stroke_opacity$$,null,$APP.$cljs$cst$1403$fill$$,null,$cljs$cst$2708$color_profile$$,null,$cljs$cst$2911$stroke_linejoin$$,null,$cljs$cst$2912$shape_rendering$$,null,$APP.$cljs$cst$1997$cursor$$,null,$cljs$cst$2913$stroke_dashoffset$$,null,$cljs$cst$2914$word_spacing$$,null,$APP.$cljs$cst$2716$font$$,null,$APP.$cljs$cst$1904$style$$,null,$cljs$cst$2917$stroke_linecap$$,null,$cljs$cst$2921$dominant_baseline$$,null,
$cljs$cst$2922$marker_start$$,null,$APP.$cljs$cst$1655$stroke_width$$,null,$cljs$cst$2924$color_interpolation_filters$$,null,$cljs$cst$2925$stroke_miterlimit$$,null,$APP.$cljs$cst$1766$letter_spacing$$,null,$cljs$cst$2928$marker_mid$$,null,$cljs$cst$2929$pointer_events$$,null,$cljs$cst$2930$font_size_adjust$$,null,$cljs$cst$2931$glyph_orientation_vertical$$,null,$cljs$cst$2932$color_interpolation$$,null,$cljs$cst$2933$visibility$$,null,$APP.$cljs$cst$1963$direction$$,null,$APP.$cljs$cst$1747$fill_opacity$$,
null,$APP.$cljs$cst$1758$font_family$$,null,$cljs$cst$2935$marker_end$$,null,$cljs$cst$2936$paint_order$$,null],null),null),$app$common$svg$gradient_tags$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$2692$linearGradient$$,null,$cljs$cst$2693$radialGradient$$,null],null),null),$app$common$svg$filter_tags$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,17,[$cljs$cst$2695$feBlend$$,null,$cljs$cst$2699$feConvolveMatrix$$,
null,$cljs$cst$2700$feDisplacementMap$$,null,$cljs$cst$2701$feTurbulence$$,null,$cljs$cst$2707$feComponentTransfer$$,null,$cljs$cst$2718$feFlood$$,null,$cljs$cst$2719$feMorphology$$,null,$cljs$cst$2720$feGaussianBlur$$,null,$cljs$cst$2722$feDiffuseLighting$$,null,$APP.$cljs$cst$2691$filter$$,null,$cljs$cst$2724$feComposite$$,null,$cljs$cst$2729$feTile$$,null,$cljs$cst$2731$feImage$$,null,$cljs$cst$2733$feColorMatrix$$,null,$cljs$cst$2735$feMerge$$,null,$cljs$cst$2736$feOffset$$,null,$cljs$cst$2737$feSpecularLighting$$,
null],null),null),$app$common$svg$parent_tags$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1744$g$$,null,$cljs$cst$2725$tspan$$,null,$APP.$cljs$cst$1538$svg$$,null,$APP.$cljs$cst$1588$text$$,null],null),null),$app$common$svg$svg_group_safe_tags$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,39,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$2689$mask$$,null,$APP.$cljs$cst$2698$desc$$,null,
$cljs$cst$2703$use$$,null,$APP.$cljs$cst$219$symbol$$,null,$cljs$cst$2706$marker$$,null,$cljs$cst$2708$color_profile$$,null,$APP.$cljs$cst$1417$circle$$,null,$cljs$cst$2709$animateColor$$,null,$cljs$cst$2690$clipPath$$,null,$cljs$cst$2710$altGlyphDef$$,null,$APP.$cljs$cst$1997$cursor$$,null,$cljs$cst$2711$animate$$,null,$cljs$cst$2712$font_face$$,null,$APP.$cljs$cst$2716$font$$,null,$APP.$cljs$cst$939$title$$,null,$APP.$cljs$cst$1904$style$$,null,$APP.$cljs$cst$1744$g$$,null,$APP.$cljs$cst$2691$filter$$,
null,$APP.$cljs$cst$209$line$$,null,$cljs$cst$2727$defs$$,null,$APP.$cljs$cst$1538$svg$$,null,$APP.$cljs$cst$2730$ellipse$$,null,$cljs$cst$2732$animateTransform$$,null,$cljs$cst$2692$linearGradient$$,null,$APP.$cljs$cst$1612$image$$,null,$cljs$cst$2693$radialGradient$$,null,$APP.$cljs$cst$203$set$$,null,$cljs$cst$2740$animateMotion$$,null,$APP.$cljs$cst$2743$polyline$$,null,$APP.$cljs$cst$1611$rect$$,null,$cljs$cst$1633$metadata$$,null,$cljs$cst$2748$switch$$,null,$APP.$cljs$cst$1519$a$$,null,$cljs$cst$2749$view$$,
null,$APP.$cljs$cst$2750$polygon$$,null,$cljs$cst$1844$pattern$$,null,$cljs$cst$2751$foreignObject$$,null,$APP.$cljs$cst$1588$text$$,null],null),null),$app$common$svg$svg_props$$,$xf$jscomp$inline_5749$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$common$svg$prop_key$$);
$app$common$svg$svg_props$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$xf$jscomp$inline_5749$$,$app$common$svg$svg_attrs$$),$xf$jscomp$inline_5749$$,$app$common$svg$svg_presentation_attrs$$);
var $app$common$svg$svg_tag_defaults$$=function(){var $filter_default$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$2939$units$$,$cljs$cst$2789$filterUnits$$,$APP.$cljs$cst$205$default$$,"objectBoundingBox","objectBoundingBox",$APP.$cljs$core$PersistentArrayMap$EMPTY$$,"userSpaceOnUse",new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1510$x$$,"-10%",$APP.$cljs$cst$1511$y$$,"-10%",$APP.$cljs$cst$290$width$$,"120%",$APP.$cljs$cst$1522$height$$,"120%"],null)],null),$filter_values$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__52105_SHARP_$$,$p2__52106_SHARP_$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__52105_SHARP_$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$p2__52106_SHARP_$$],[$filter_default$$])]))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$app$common$svg$filter_tags$$);return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$cljs$cst$2692$linearGradient$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$2939$units$$,$cljs$cst$2753$gradientUnits$$,$APP.$cljs$cst$205$default$$,"objectBoundingBox","objectBoundingBox",$APP.$cljs$core$PersistentArrayMap$EMPTY$$,"userSpaceOnUse",new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1523$x1$$,"0%",$APP.$cljs$cst$1524$y1$$,"0%",$APP.$cljs$cst$1525$x2$$,"100%",$APP.$cljs$cst$1526$y2$$,"0%"],null)],null),$cljs$cst$2693$radialGradient$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$cljs$cst$2939$units$$,$cljs$cst$2753$gradientUnits$$,$APP.$cljs$cst$205$default$$,"objectBoundingBox","objectBoundingBox",$APP.$cljs$core$PersistentArrayMap$EMPTY$$,"userSpaceOnUse",new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1897$cx$$,"50%",$APP.$cljs$cst$1898$cy$$,"50%",$APP.$cljs$cst$1743$r$$,"50%"],null)],null),$APP.$cljs$cst$2689$mask$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$2939$units$$,$cljs$cst$2818$maskUnits$$,$APP.$cljs$cst$205$default$$,"userSpaceOnUse",
"objectBoundingBox",$APP.$cljs$core$PersistentArrayMap$EMPTY$$,"userSpaceOnUse",new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1510$x$$,"-10%",$APP.$cljs$cst$1511$y$$,"-10%",$APP.$cljs$cst$290$width$$,"120%",$APP.$cljs$cst$1522$height$$,"120%"],null)],null)],null),$filter_values$$]))}(),$app$common$svg$extract_ids$$=function $app$common$svg$extract_ids$$($val$jscomp$167$$){return typeof $val$jscomp$167$$==="string"?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,
$APP.$cljs$core$re_seq$$($app$common$svg$xml_id_regex$$,$val$jscomp$167$$)):$APP.$cljs$core$sequential_QMARK_$$($val$jscomp$167$$)?$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$svg$extract_ids$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$val$jscomp$167$$])):$APP.$cljs$core$PersistentVector$EMPTY$$},$app$common$svg$extract_defs$$=function $app$common$svg$extract_defs$$($node_defs_p__52165_rec_result$$){var $map__52166__$1_node__$1$jscomp$67$$=$APP.$cljs$core$__destructure_map$$($node_defs_p__52165_rec_result$$),
$attrs$jscomp$28_current_node_defs$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52166__$1_node__$1$jscomp$67$$,$APP.$cljs$cst$2645$attrs$$);return $APP.$cljs$core$map_QMARK_$$($map__52166__$1_node__$1$jscomp$67$$)?($node_defs_p__52165_rec_result$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$common$svg$extract_defs$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($map__52166__$1_node__$1$jscomp$67$$)),$map__52166__$1_node__$1$jscomp$67$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__52166__$1_node__$1$jscomp$67$$,
$APP.$cljs$cst$1637$content$$,$APP.$cljs$core$filterv$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$not$$,function($map__52169__$1_p__52168_tag$jscomp$54$$){$map__52169__$1_p__52168_tag$jscomp$54$$=$APP.$cljs$core$__destructure_map$$($map__52169__$1_p__52168_tag$jscomp$54$$);$map__52169__$1_p__52168_tag$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52169__$1_p__52168_tag$jscomp$54$$,$APP.$cljs$cst$78$tag$$);return $map__52169__$1_p__52168_tag$jscomp$54$$!=
null&&($APP.$cljs$core$contains_QMARK_$$($app$common$svg$tags_to_remove$$,$map__52169__$1_p__52168_tag$jscomp$54$$)||!$APP.$cljs$core$contains_QMARK_$$($app$common$svg$svg_tags$$,$map__52169__$1_p__52168_tag$jscomp$54$$))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$node_defs_p__52165_rec_result$$))),$attrs$jscomp$28_current_node_defs$$=$APP.$cljs$core$contains_QMARK_$$($attrs$jscomp$28_current_node_defs$$,$APP.$cljs$cst$266$id$$)?$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$28_current_node_defs$$)],
[$map__52166__$1_node__$1$jscomp$67$$]):$cljs$core$PersistentHashMap$EMPTY$$,$node_defs_p__52165_rec_result$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$merge$$,$attrs$jscomp$28_current_node_defs$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$node_defs_p__52165_rec_result$$)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$node_defs_p__52165_rec_result$$,$map__52166__$1_node__$1$jscomp$67$$],
null)):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$map__52166__$1_node__$1$jscomp$67$$],null)},$app$common$svg$find_attr_references$$=function $app$common$svg$find_attr_references$$($attrs$jscomp$29$$){return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($attr_value_p__52173$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value_p__52173$$,0,null);$attr_value_p__52173$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value_p__52173$$,1,null);return typeof $attr_value_p__52173$$==="string"?$app$common$svg$extract_ids$$($attr_value_p__52173$$):$app$common$svg$find_attr_references$$.$cljs$core$IFn$_invoke$arity$1$?$app$common$svg$find_attr_references$$.$cljs$core$IFn$_invoke$arity$1$($attr_value_p__52173$$):$app$common$svg$find_attr_references$$($attr_value_p__52173$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs$jscomp$29$$]))},
$app$common$svg$find_node_references$$=function $app$common$svg$find_node_references$$($children$jscomp$197_node$jscomp$271$$){var $current$jscomp$32$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$app$common$svg$find_attr_references$$($APP.$cljs$cst$2645$attrs$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$197_node$jscomp$271$$)));$children$jscomp$197_node$jscomp$271$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$flatten$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$common$svg$find_node_references$$,$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$197_node$jscomp$271$$))));return $APP.$cljs$core$vec$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$32$$,$children$jscomp$197_node$jscomp$271$$))},$app$common$svg$xf_parse_numbers$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$),
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$not_empty$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$parse_double$$)),$app$common$svg$map_nodes$$=function $app$common$svg$map_nodes$$($mapfn$$,$node$jscomp$277$$){function $update_content$$($content$jscomp$119$$){return $APP.$cljs$core$vector_QMARK_$$($content$jscomp$119$$)?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$svg$map_nodes$$,
$mapfn$$),$content$jscomp$119$$):$content$jscomp$119$$}return $APP.$cljs$core$map_QMARK_$$($node$jscomp$277$$)?$APP.$app$common$data$update_when$$($mapfn$$.$cljs$core$IFn$_invoke$arity$1$?$mapfn$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$277$$):$mapfn$$($node$jscomp$277$$),$APP.$cljs$cst$1637$content$$,$update_content$$):$node$jscomp$277$$},$app$common$svg$reduce_nodes$$=function $app$common$svg$reduce_nodes$$($JSCompiler_temp$jscomp$944_redfn$$,$G__52449$jscomp$inline_5767_content$jscomp$inline_5762_content__$1$jscomp$inline_5764_value$jscomp$468$$,
$current$jscomp$inline_5763_node$jscomp$278$$){if($APP.$cljs$core$map_QMARK_$$($current$jscomp$inline_5763_node$jscomp$278$$))a:{var $G__52448$jscomp$inline_5766_value__$1$jscomp$inline_5761$$=$JSCompiler_temp$jscomp$944_redfn$$.$cljs$core$IFn$_invoke$arity$2$?$JSCompiler_temp$jscomp$944_redfn$$.$cljs$core$IFn$_invoke$arity$2$($G__52449$jscomp$inline_5767_content$jscomp$inline_5762_content__$1$jscomp$inline_5764_value$jscomp$468$$,$current$jscomp$inline_5763_node$jscomp$278$$):$JSCompiler_temp$jscomp$944_redfn$$($G__52449$jscomp$inline_5767_content$jscomp$inline_5762_content__$1$jscomp$inline_5764_value$jscomp$468$$,
$current$jscomp$inline_5763_node$jscomp$278$$);$G__52449$jscomp$inline_5767_content$jscomp$inline_5762_content__$1$jscomp$inline_5764_value$jscomp$468$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$inline_5763_node$jscomp$278$$);$current$jscomp$inline_5763_node$jscomp$278$$=$APP.$cljs$core$first$$($G__52449$jscomp$inline_5767_content$jscomp$inline_5762_content__$1$jscomp$inline_5764_value$jscomp$468$$);$G__52449$jscomp$inline_5767_content$jscomp$inline_5762_content__$1$jscomp$inline_5764_value$jscomp$468$$=
$APP.$cljs$core$rest$$($G__52449$jscomp$inline_5767_content$jscomp$inline_5762_content__$1$jscomp$inline_5764_value$jscomp$468$$);for(var $G__52450$jscomp$inline_5768_value__$2$jscomp$inline_5765$$=$G__52448$jscomp$inline_5766_value__$1$jscomp$inline_5761$$;;){if($current$jscomp$inline_5763_node$jscomp$278$$==null){$JSCompiler_temp$jscomp$944_redfn$$=$G__52450$jscomp$inline_5768_value__$2$jscomp$inline_5765$$;break a}$G__52448$jscomp$inline_5766_value__$1$jscomp$inline_5761$$=$APP.$cljs$core$first$$($G__52449$jscomp$inline_5767_content$jscomp$inline_5762_content__$1$jscomp$inline_5764_value$jscomp$468$$);
$G__52449$jscomp$inline_5767_content$jscomp$inline_5762_content__$1$jscomp$inline_5764_value$jscomp$468$$=$APP.$cljs$core$rest$$($G__52449$jscomp$inline_5767_content$jscomp$inline_5762_content__$1$jscomp$inline_5764_value$jscomp$468$$);$G__52450$jscomp$inline_5768_value__$2$jscomp$inline_5765$$=$app$common$svg$reduce_nodes$$.$cljs$core$IFn$_invoke$arity$3$?$app$common$svg$reduce_nodes$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$944_redfn$$,$G__52450$jscomp$inline_5768_value__$2$jscomp$inline_5765$$,
$current$jscomp$inline_5763_node$jscomp$278$$):$app$common$svg$reduce_nodes$$($JSCompiler_temp$jscomp$944_redfn$$,$G__52450$jscomp$inline_5768_value__$2$jscomp$inline_5765$$,$current$jscomp$inline_5763_node$jscomp$278$$);$current$jscomp$inline_5763_node$jscomp$278$$=$G__52448$jscomp$inline_5766_value__$1$jscomp$inline_5761$$}$JSCompiler_temp$jscomp$944_redfn$$=void 0}else $JSCompiler_temp$jscomp$944_redfn$$=$G__52449$jscomp$inline_5767_content$jscomp$inline_5762_content__$1$jscomp$inline_5764_value$jscomp$468$$;
return $JSCompiler_temp$jscomp$944_redfn$$};var $app$main$broadcast$event_52343$$,$app$main$broadcast$default_channel$$;$APP.$JSCompiler_prototypeAlias$$=$app$main$broadcast$BroadcastMessage$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$33$$,$k__5324__auto__$jscomp$33$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$33$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$33$$,$k52246$$,$else__5326__auto__$jscomp$33$$){switch($k52246$$ instanceof $APP.$cljs$core$Keyword$$?$k52246$$.$fqn$:null){case "id":return this.id;case "type":return this.type;case "data":return this.data;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k52246$$,$else__5326__auto__$jscomp$33$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$33$$,$f__5344__auto__$jscomp$33$$,$init__5345__auto__$jscomp$33$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$33$$,$p__52263_v__5348__auto__$jscomp$33$$){var $k__5347__auto__$jscomp$33$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52263_v__5348__auto__$jscomp$33$$,0,null);$p__52263_v__5348__auto__$jscomp$33$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__52263_v__5348__auto__$jscomp$33$$,
1,null);return $f__5344__auto__$jscomp$33$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$33$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$33$$,$k__5347__auto__$jscomp$33$$,$p__52263_v__5348__auto__$jscomp$33$$):$f__5344__auto__$jscomp$33$$($ret__5346__auto__$jscomp$33$$,$k__5347__auto__$jscomp$33$$,$p__52263_v__5348__auto__$jscomp$33$$)},$init__5345__auto__$jscomp$33$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$33$$,$writer__5339__auto__$jscomp$33$$,$opts__5340__auto__$jscomp$33$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$33$$,function($keyval__5342__auto__$jscomp$33$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$33$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$33$$,$keyval__5342__auto__$jscomp$33$$)},"#app.main.broadcast.BroadcastMessage{",
", ","}",$opts__5340__auto__$jscomp$33$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,this.id],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,this.type],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,this.data],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,3,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$142$data$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $app$main$broadcast$BroadcastMessage$$(this.id,this.type,this.data,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 3+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$63_h__5134__auto____$1$jscomp$63$$=this.$__hash$;return $h__5134__auto__$jscomp$63_h__5134__auto____$1$jscomp$63$$!=null?$h__5134__auto__$jscomp$63_h__5134__auto____$1$jscomp$63$$:this.$__hash$=$h__5134__auto__$jscomp$63_h__5134__auto____$1$jscomp$63$$=-110346835^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this52247$$,$other52248$$){return $other52248$$!=null&&this.constructor===$other52248$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.id,$other52248$$.id)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.type,$other52248$$.type)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.data,$other52248$$.data)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,
$other52248$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$33$$,$k__5334__auto__$jscomp$33$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,null,$APP.$cljs$cst$266$id$$,null,$APP.$cljs$cst$142$data$$,null],null),null),$k__5334__auto__$jscomp$33$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),
this.$__meta$),$k__5334__auto__$jscomp$33$$):new $app$main$broadcast$BroadcastMessage$$(this.id,this.type,this.data,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$33$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$33$$,$k52246$jscomp$1$$){switch($k52246$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k52246$jscomp$1$$.$fqn$:null){case "id":case "type":case "data":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k52246$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$33$$,$k__5332__auto__$jscomp$33$$,$G__52245$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$k__5332__auto__$jscomp$33$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$266$id$$,$k__5332__auto__$jscomp$33$$))?new $app$main$broadcast$BroadcastMessage$$($G__52245$jscomp$1$$,
this.type,this.data,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$,$k__5332__auto__$jscomp$33$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$139$type$$,$k__5332__auto__$jscomp$33$$))?new $app$main$broadcast$BroadcastMessage$$(this.id,$G__52245$jscomp$1$$,this.data,this.$__meta$,this.$__extmap$,null):
$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$33$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$33$$))?new $app$main$broadcast$BroadcastMessage$$(this.id,this.type,$G__52245$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $app$main$broadcast$BroadcastMessage$$(this.id,this.type,
this.data,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$33$$,$G__52245$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$266$id$$,this.id,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$139$type$$,this.type,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$142$data$$,this.data,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDeref$_deref$arity$1$=function(){return this.data};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$33$$,$G__52245$jscomp$2$$){return new $app$main$broadcast$BroadcastMessage$$(this.id,this.type,this.data,$G__52245$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$33$$,$entry__5329__auto__$jscomp$33$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$33$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$33$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$33$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$33$$)};
var $JSCompiler_temp$jscomp$963$$;if(typeof BroadcastChannel!=="undefined")try{$JSCompiler_temp$jscomp$963$$=new BroadcastChannel("penpot")}catch($e52318$jscomp$inline_5794$$){$JSCompiler_temp$jscomp$963$$=null}else $JSCompiler_temp$jscomp$963$$=null;$app$main$broadcast$default_channel$$=$JSCompiler_temp$jscomp$963$$;
$APP.$app$main$broadcast$stream$$=typeof BroadcastChannel!=="undefined"?$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$map$$($app$main$broadcast$map__GT_BroadcastMessage$$,$APP.$beicon$v2$core$map$$($APP.$app$common$transit$decode_str$$,$APP.$beicon$v2$core$create$$(function($subs$jscomp$15$$){var $chan$$=new BroadcastChannel("penpot");$chan$$.onmessage=function($p1__52320_SHARP_$$){return $subs$jscomp$15$$.next($p1__52320_SHARP_$$.data)};return function(){return $chan$$.close()}})))):$APP.$beicon$v2$core$subject$$();var $shadow$js$shim$module$0$0penpot$0mousetrap$0default$$=shadow$bridge("@penpot/mousetrap").default;var $app$main$data$shortcuts$push_shortcuts_52443$$,$app$main$data$shortcuts$pop_shortcuts_52467$$;$APP.$app$common$logging$loggers$$.set("app.main.data.shortcuts",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));
var $app$main$data$shortcuts$check_shortcuts$$=$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,$APP.$cljs$cst$221$keyword$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$418$any$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$core$fn_QMARK_$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2946$tooltip$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null)],null)],null)),$app$main$data$shortcuts$conj_STAR_$$=$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$linked$map$empty_linked_map$$);var $app$main$ui$hooks$render_id$$,$app$main$ui$hooks$intersection_subject$$,$app$main$ui$hooks$intersection_observer$$;$app$main$ui$hooks$render_id$$=0;$APP.$app$main$ui$hooks$sortable_ctx$$=(0,$APP.$rumext$v2$create_context$$)(null);$app$main$ui$hooks$intersection_subject$$=$APP.$beicon$v2$core$subject$$();
$app$main$ui$hooks$intersection_observer$$=new $APP.$cljs$core$Delay$$(function(){return new IntersectionObserver(function($entries$jscomp$11$$){return $APP.$cljs$core$run_BANG_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($beicon$v2$core$push_BANG_$$,$app$main$ui$hooks$intersection_subject$$),$APP.$cljs$core$seq$$($entries$jscomp$11$$))},{rootMargin:"0px",threshold:[0,1]})});$APP.$app$main$ui$shapes$embed$context$$=(0,$APP.$rumext$v2$create_context$$)(!1);var $app$main$ui$shapes$export$0$internal_counter$$,$app$main$ui$shapes$export$0$render_xml$$;$app$main$ui$shapes$export$0$internal_counter$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(0);$APP.$app$main$ui$shapes$export$0$include_metadata_ctx$$=(0,$APP.$rumext$v2$create_context$$)(!1);
$app$main$ui$shapes$export$0$render_xml$$=function $app$main$ui$shapes$export$render_xml$$($map__52778_map__52778__$1_map__52779_props_52777_tag$jscomp$60$$){$map__52778_map__52778__$1_map__52779_props_52777_tag$jscomp$60$$=$APP.$rumext$v2$util$wrap_props$$($map__52778_map__52778__$1_map__52779_props_52777_tag$jscomp$60$$);$map__52778_map__52778__$1_map__52779_props_52777_tag$jscomp$60$$=$APP.$cljs$core$__destructure_map$$($map__52778_map__52778__$1_map__52779_props_52777_tag$jscomp$60$$);$map__52778_map__52778__$1_map__52779_props_52777_tag$jscomp$60$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52778_map__52778__$1_map__52779_props_52777_tag$jscomp$60$$,$cljs$cst$2963$xml$$);var $map__52779__$1_props$jscomp$104$$=$APP.$cljs$core$__destructure_map$$($map__52778_map__52778__$1_map__52779_props_52777_tag$jscomp$60$$);$map__52778_map__52778__$1_map__52779_props_52777_tag$jscomp$60$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52779__$1_props$jscomp$104$$,$APP.$cljs$cst$78$tag$$);var $attrs$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52779__$1_props$jscomp$104$$,
$APP.$cljs$cst$2645$attrs$$),$content$jscomp$121$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52779__$1_props$jscomp$104$$,$APP.$cljs$cst$1637$content$$);return $APP.$cljs$core$map_QMARK_$$($map__52779__$1_props$jscomp$104$$)?($map__52779__$1_props$jscomp$104$$=$APP.$app$common$json$__GT_js$$.$cljs$core$IFn$_invoke$arity$variadic$($app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$01$$($attrs$jscomp$43$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$291$key_fn$$,
$APP.$cljs$core$name$$])),(0,$APP.$rumext$v2$create_element$$)($APP.$app$common$data$name$$($map__52778_map__52778__$1_map__52779_props_52777_tag$jscomp$60$$),$map__52779__$1_props$jscomp$104$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$1$$,$child$jscomp$72$$){$out_arr__44124__auto__$jscomp$1$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$export$render_xml$$,{xml:$child$jscomp$72$$},$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$shapes$export$0$internal_counter$$,
$APP.$cljs$core$inc$$)));return $out_arr__44124__auto__$jscomp$1$$},[],$content$jscomp$121$$))):typeof $map__52779__$1_props$jscomp$104$$==="string"?$map__52779__$1_props$jscomp$104$$:null};var $app$main$ui$shapes$text$svg_text$text_shape$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($group_props_props_53027_shape$jscomp$335_x$jscomp$1154$$){var $render_id$jscomp$22$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$render_id$$);$group_props_props_53027_shape$jscomp$335_x$jscomp$1154$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($group_props_props_53027_shape$jscomp$335_x$jscomp$1154$$,"shape");var $shape__$1$jscomp$28$$=$APP.$cljs$core$truth_$$($cljs$cst$2966$is_mask_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($group_props_props_53027_shape$jscomp$335_x$jscomp$1154$$))?
$app$main$ui$shapes$text$svg_text$set_white_fill$$($group_props_props_53027_shape$jscomp$335_x$jscomp$1154$$):$group_props_props_53027_shape$jscomp$335_x$jscomp$1154$$,$map__53030__$1_position_data$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($shape__$1$jscomp$28$$);$group_props_props_53027_shape$jscomp$335_x$jscomp$1154$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53030__$1_position_data$jscomp$4$$,$APP.$cljs$cst$1510$x$$);var $y$jscomp$392$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53030__$1_position_data$jscomp$4$$,
$APP.$cljs$cst$1511$y$$),$width$jscomp$87$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53030__$1_position_data$jscomp$4$$,$APP.$cljs$cst$290$width$$),$height$jscomp$78$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53030__$1_position_data$jscomp$4$$,$APP.$cljs$cst$1522$height$$);$map__53030__$1_position_data$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53030__$1_position_data$jscomp$4$$,$APP.$cljs$cst$1891$position_data$$);var $transform$jscomp$69$$=
$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$28$$);$group_props_props_53027_shape$jscomp$335_x$jscomp$1154$$=$app$main$ui$shapes$attrs$add_border_props_BANG_$$($app$main$ui$shapes$attrs$add_fill_props_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$({transform:$transform$jscomp$69$$,className:"text-container",x:$group_props_props_53027_shape$jscomp$335_x$jscomp$1154$$,y:$y$jscomp$392$$,width:$width$jscomp$87$$,height:$height$jscomp$78$$},$shape__$1$jscomp$28$$,
$render_id$jscomp$22$$),$shape__$1$jscomp$28$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$1748$fill_color_gradient$$,$map__53030__$1_position_data$jscomp$4$$))?(0,$APP.$rumext$v2$jsx$$)("defs",{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$18$$,$JSCompiler_temp_const$jscomp$982_p__53033$$){var $JSCompiler_temp$jscomp$984_id$jscomp$inline_5851_index$jscomp$240$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$982_p__53033$$,0,null),$data$jscomp$253$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$982_p__53033$$,1,null);$JSCompiler_temp_const$jscomp$982_p__53033$$=$out_arr__44124__auto__$jscomp$18$$.push;$APP.$cljs$cst$1748$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$253$$)!=null?($JSCompiler_temp$jscomp$984_id$jscomp$inline_5851_index$jscomp$240$$="fill-color-gradient-"+
([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($render_id$jscomp$22$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$28$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$984_id$jscomp$inline_5851_index$jscomp$240$$)].join("")??""),$JSCompiler_temp$jscomp$984_id$jscomp$inline_5851_index$jscomp$240$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$gradients$gradient$$,{id:$JSCompiler_temp$jscomp$984_id$jscomp$inline_5851_index$jscomp$240$$,
attr:$APP.$cljs$cst$1748$fill_color_gradient$$,shape:$data$jscomp$253$$},$JSCompiler_temp$jscomp$984_id$jscomp$inline_5851_index$jscomp$240$$)):$JSCompiler_temp$jscomp$984_id$jscomp$inline_5851_index$jscomp$240$$=null;$JSCompiler_temp_const$jscomp$982_p__53033$$.call($out_arr__44124__auto__$jscomp$18$$,$JSCompiler_temp$jscomp$984_id$jscomp$inline_5851_index$jscomp$240$$);return $out_arr__44124__auto__$jscomp$18$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($map__53030__$1_position_data$jscomp$4$$))}):
null,(0,$APP.$rumext$v2$create_element$$)("g",$group_props_props_53027_shape$jscomp$335_x$jscomp$1154$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$19$$,$JSCompiler_temp_const$jscomp$10811_p__53038$$){var $JSCompiler_inline_result$jscomp$10813_index$jscomp$241$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$10811_p__53038$$,0,null),$data$jscomp$254$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$10811_p__53038$$,
1,null);$JSCompiler_temp_const$jscomp$10811_p__53038$$=$out_arr__44124__auto__$jscomp$19$$.push;var $G__53042$jscomp$inline_12162_rtl_QMARK_$jscomp$inline_12159_shape__$2$jscomp$inline_12163$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("rtl",$APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$)),$browser_props$jscomp$inline_12160_props__$1$jscomp$inline_12161$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1346$safari$$)?{dominantBaseline:"hanging",
dy:"0.2em",y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$)-$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$)}:null;$G__53042$jscomp$inline_12162_rtl_QMARK_$jscomp$inline_12159_shape__$2$jscomp$inline_12163$$={key:"text-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$28$$)??"")+"-"+($JSCompiler_inline_result$jscomp$10813_index$jscomp$241$$??""),x:$G__53042$jscomp$inline_12162_rtl_QMARK_$jscomp$inline_12159_shape__$2$jscomp$inline_12163$$?
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$):$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$),y:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$),dominantBaseline:"ideographic",textLength:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$),lengthAdjust:"spacingAndGlyphs",style:$APP.$app$util$object$set_BANG_$$({textTransform:$APP.$cljs$cst$1769$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$),
fontFamily:$APP.$cljs$cst$1758$font_family$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$),letterSpacing:$APP.$cljs$cst$1766$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$),fontStyle:$APP.$cljs$cst$1762$font_style$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$),fontWeight:$APP.$cljs$cst$1761$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$),whiteSpace:"pre",fontSize:$APP.$cljs$cst$1760$font_size$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$),
textDecoration:$APP.$cljs$cst$1768$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$),direction:$APP.$cljs$cst$1963$direction$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$)},"fill",["url(#fill-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10813_index$jscomp$241$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($render_id$jscomp$22$$),")"].join(""))};$browser_props$jscomp$inline_12160_props__$1$jscomp$inline_12161$$=$APP.$cljs$core$truth_$$($browser_props$jscomp$inline_12160_props__$1$jscomp$inline_12161$$)?
$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__53042$jscomp$inline_12162_rtl_QMARK_$jscomp$inline_12159_shape__$2$jscomp$inline_12163$$,$browser_props$jscomp$inline_12160_props__$1$jscomp$inline_12161$$):$G__53042$jscomp$inline_12162_rtl_QMARK_$jscomp$inline_12159_shape__$2$jscomp$inline_12163$$;$G__53042$jscomp$inline_12162_rtl_QMARK_$jscomp$inline_12159_shape__$2$jscomp$inline_12163$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$28$$,
$APP.$cljs$cst$1634$fills$$,$APP.$cljs$cst$1634$fills$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$)),$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1653$blur$$]));var $render_id__$1$jscomp$inline_12164$$=""+($render_id$jscomp$22$$??"")+"-"+($JSCompiler_inline_result$jscomp$10813_index$jscomp$241$$??"");$JSCompiler_inline_result$jscomp$10813_index$jscomp$241$$=(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$provider$$($app$main$ui$context$render_id$$),
{value:$render_id__$1$jscomp$inline_12164$$,children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$fills$fills$$,{shape:$G__53042$jscomp$inline_12162_rtl_QMARK_$jscomp$inline_12159_shape__$2$jscomp$inline_12163$$,"render-id":$render_id__$1$jscomp$inline_12164$$})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$custom_stroke$shape_custom_strokes$$,{shape:$G__53042$jscomp$inline_12162_rtl_QMARK_$jscomp$inline_12159_shape__$2$jscomp$inline_12163$$,position:$JSCompiler_inline_result$jscomp$10813_index$jscomp$241$$,
"render-id":$render_id__$1$jscomp$inline_12164$$,children:(0,$APP.$rumext$v2$create_element$$)("text",$browser_props$jscomp$inline_12160_props__$1$jscomp$inline_12161$$,$APP.$cljs$cst$1588$text$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$254$$))})]},$JSCompiler_inline_result$jscomp$10813_index$jscomp$241$$);$JSCompiler_temp_const$jscomp$10811_p__53038$$.call($out_arr__44124__auto__$jscomp$19$$,$JSCompiler_inline_result$jscomp$10813_index$jscomp$241$$);return $out_arr__44124__auto__$jscomp$19$$},
[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($map__53030__$1_position_data$jscomp$4$$)))]})});$APP.$app$render_wasm$helpers$error_code$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[1,$cljs$cst$2967$non_blocking$$,2,$cljs$cst$2968$panic$$],null);$module$app$render_wasm$api$shared$$={$CursorDirection$:{backward:0,forward:1,"line-before":2,"line-after":3,"line-start":4,"line-end":5},$GrowType$:{fixed:0,"auto-width":1,"auto-height":2},$RawAlignContent$:{start:0,end:1,center:2,"space-between":3,"space-around":4,"space-evenly":5,stretch:6},$RawAlignItems$:{start:0,end:1,center:2,stretch:3},$RawAlignSelf$:{none:0,auto:1,start:2,end:3,center:4,stretch:5},$RawBlendMode$:{normal:3,screen:14,overlay:15,darken:16,lighten:17,"color-dodge":18,"color-burn":19,
"hard-light":20,"soft-light":21,difference:22,exclusion:23,multiply:24,hue:25,saturation:26,color:27,luminosity:28},$RawBlurType$:{"layer-blur":0,"background-blur":1},$RawBoolType$:{union:0,difference:1,intersection:2,exclude:3},$RawConstraintH$:{left:0,right:1,leftright:2,center:3,scale:4},$RawConstraintV$:{top:0,bottom:1,topbottom:2,center:3,scale:4},$RawFillData$:{solid:0,linear:1,radial:2,image:3},$RawFillRule$:{nonzero:0,evenodd:1},$RawFlexDirection$:{row:0,"row-reverse":1,column:2,"column-reverse":3},
$RawFontStyle$:{normal:0,italic:1},$RawGridDirection$:{row:0,column:1},$RawGridTrackType$:{percent:0,flex:1,auto:2,fixed:3},$RawGrowType$:{fixed:0,"auto-width":1,"auto-height":2},$RawJustifyContent$:{start:0,end:1,center:2,"space-between":3,"space-around":4,"space-evenly":5,stretch:6},$RawJustifyItems$:{start:0,end:1,center:2,stretch:3},$RawJustifySelf$:{none:0,auto:1,start:2,end:3,center:4,stretch:5},$RawSegmentData$:{"move-to":1,"line-to":2,"curve-to":3,close:4},$RawShadowStyle$:{"drop-shadow":0,
"inner-shadow":1},$RawShapeType$:{frame:0,group:1,bool:2,rect:3,path:4,text:5,circle:6,"svg-raw":7},$RawSizing$:{fill:0,fix:1,auto:2},$RawStrokeCap$:{none:0,"line-arrow":1,"triangle-arrow":2,"square-marker":3,"circle-marker":4,"diamond-marker":5,round:6,square:7},$RawStrokeLineCap$:{butt:0,round:1,square:2},$RawStrokeLineJoin$:{miter:0,round:1,bevel:2},$RawStrokeStyle$:{solid:0,dotted:1,dashed:2,mixed:3},$RawTextAlign$:{left:0,center:1,right:2,justify:3},$RawTextDecoration$:{none:0,underline:1,"line-through":2,
overline:3},$RawTextDirection$:{ltr:0,rtl:1},$RawTextTransform$:{none:0,uppercase:1,lowercase:2,capitalize:3},$RawTransformEntryKind$:{parent:0,child:1},$RawVerticalAlign$:{top:0,center:1,bottom:2},$RawWrapType$:{wrap:0,nowrap:1},$TextEditorEvent$:{none:0,"content-changed":1,"selection-changed":2,"styles-changed":3,"needs-layout":4}};var $app$render_wasm$wasm$internal_frame_id$$,$app$render_wasm$wasm$canvas$$,$app$render_wasm$wasm$gl_context_handle$$,$app$render_wasm$wasm$gl_context$$,$app$render_wasm$wasm$context_lost_QMARK_$$,$app$render_wasm$wasm$disable_request_render_QMARK_$$,$app$render_wasm$wasm$serializers$$;$app$render_wasm$wasm$internal_frame_id$$=null;$APP.$app$render_wasm$wasm$internal_module$$={};$app$render_wasm$wasm$canvas$$=null;$APP.$app$render_wasm$wasm$canvas_snapshot_url$$=null;
$app$render_wasm$wasm$gl_context_handle$$=null;$app$render_wasm$wasm$gl_context$$=null;$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$=!1;$app$render_wasm$wasm$context_lost_QMARK_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$app$render_wasm$wasm$disable_request_render_QMARK_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);
$app$render_wasm$wasm$serializers$$={"font-style":$module$app$render_wasm$api$shared$$.$RawFontStyle$,"fill-rule":$module$app$render_wasm$api$shared$$.$RawFillRule$,"align-items":$module$app$render_wasm$api$shared$$.$RawAlignItems$,"constraint-h":$module$app$render_wasm$api$shared$$.$RawConstraintH$,sizing:$module$app$render_wasm$api$shared$$.$RawSizing$,"shape-type":$module$app$render_wasm$api$shared$$.$RawShapeType$,"align-content":$module$app$render_wasm$api$shared$$.$RawAlignContent$,"text-transform":$module$app$render_wasm$api$shared$$.$RawTextTransform$,
"transform-entry-kind":$module$app$render_wasm$api$shared$$.$RawTransformEntryKind$,"text-align":$module$app$render_wasm$api$shared$$.$RawTextAlign$,"vertical-align":$module$app$render_wasm$api$shared$$.$RawVerticalAlign$,"bool-type":$module$app$render_wasm$api$shared$$.$RawBoolType$,"grid-track-type":$module$app$render_wasm$api$shared$$.$RawGridTrackType$,"grow-type":$module$app$render_wasm$api$shared$$.$RawGrowType$,"stroke-style":$module$app$render_wasm$api$shared$$.$RawStrokeStyle$,"blend-mode":$module$app$render_wasm$api$shared$$.$RawBlendMode$,
"text-direction":$module$app$render_wasm$api$shared$$.$RawTextDirection$,"stroke-linejoin":$module$app$render_wasm$api$shared$$.$RawStrokeLineJoin$,"justify-self":$module$app$render_wasm$api$shared$$.$RawJustifySelf$,"shadow-style":$module$app$render_wasm$api$shared$$.$RawShadowStyle$,"stroke-linecap":$module$app$render_wasm$api$shared$$.$RawStrokeLineCap$,"wrap-type":$module$app$render_wasm$api$shared$$.$RawWrapType$,"blur-type":$module$app$render_wasm$api$shared$$.$RawBlurType$,"stroke-cap":$module$app$render_wasm$api$shared$$.$RawStrokeCap$,
"grid-direction":$module$app$render_wasm$api$shared$$.$RawGridDirection$,"fill-data":$module$app$render_wasm$api$shared$$.$RawFillData$,"justify-content":$module$app$render_wasm$api$shared$$.$RawJustifyContent$,"segment-data":$module$app$render_wasm$api$shared$$.$RawSegmentData$,"text-decoration":$module$app$render_wasm$api$shared$$.$RawTextDecoration$,"align-self":$module$app$render_wasm$api$shared$$.$RawAlignSelf$,"constraint-v":$module$app$render_wasm$api$shared$$.$RawConstraintV$,"flex-direction":$module$app$render_wasm$api$shared$$.$RawFlexDirection$,
"justify-items":$module$app$render_wasm$api$shared$$.$RawJustifyItems$};var $app$render_wasm$api$fonts$fonts$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2969$fonts$$,$APP.$app$main$store$state$$),$app$render_wasm$api$fonts$fetching$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$app$render_wasm$api$fonts$noto_fonts$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$2982$oriya$$,$cljs$cst$2983$coptic$$,$cljs$cst$2984$japanese$$,$cljs$cst$2985$runic$$,$cljs$cst$2986$tamil$$,
$cljs$cst$2987$ol_chiki$$,$cljs$cst$2988$music$$,$cljs$cst$2989$osmanya$$,$cljs$cst$2990$shavian$$,$cljs$cst$2991$bengali$$,$cljs$cst$2992$cyrillic$$,$cljs$cst$2993$latin_ext$$,$cljs$cst$2994$chinese$$,$cljs$cst$2995$gurmukhi$$,$cljs$cst$2996$ethiopic$$,$cljs$cst$2997$sinhala$$,$cljs$cst$2998$sora_sompeng$$,$cljs$cst$2999$khmer$$,$cljs$cst$3000$telugu$$,$cljs$cst$3001$vai$$,$cljs$cst$3002$javanese$$,$cljs$cst$3003$malayalam$$,$cljs$cst$3004$vietnamese$$,$cljs$cst$3005$devanagari$$,$cljs$cst$3006$thai$$,
$cljs$cst$3007$gujarati$$,$cljs$cst$3008$cherokee$$,$cljs$cst$3009$symbols_2$$,$cljs$cst$3010$tibetan$$,$cljs$cst$3011$bamum$$,$cljs$cst$3012$hebrew$$,$cljs$cst$3013$lao$$,$cljs$cst$3014$georgian$$,$cljs$cst$3015$tifinagh$$,$cljs$cst$3016$korean$$,$cljs$cst$3017$myanmar$$,$cljs$cst$3018$modi$$,$cljs$cst$3019$mongolian$$,$cljs$cst$3020$syriac$$,$cljs$cst$3021$greek$$,$cljs$cst$3022$old_italic$$,$cljs$cst$3023$arabic$$,$cljs$cst$3024$brahmi$$,$cljs$cst$3025$kannada$$,$cljs$cst$3026$symbols$$,$cljs$cst$3027$armenian$$,
$cljs$cst$3028$meroitic$$],[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-oriya",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-coptic",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-jp",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-runic",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-tamil",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-ol-chiki",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-music",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-osmanya",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-shavian",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-bengali",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-sc",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-gurmukhi",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-ethiopic",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-sinhala",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-sora-sompeng",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-khmer",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-telugu",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-vai",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-javanese",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-malayalam",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-thai",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-gujarati",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-cherokee",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-symbols-2",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-serif-tibetan",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-bamum",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-hebrew",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-lao",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-georgian",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-tifinagh",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-kr",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-myanmar",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-modi",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-mongolian",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-syriac",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-old-italic",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-arabic",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-brahmi",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-kannada",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-symbols",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-armenian",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,
!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1757$font_id$$,"gfont-noto-sans-meroitic",$APP.$cljs$cst$1759$font_variant_id$$,"regular",$APP.$cljs$cst$1904$style$$,0,$APP.$cljs$cst$1996$weight$$,400,$cljs$cst$2979$is_fallback$$,!0],null)]);var $app$render_wasm$api$texts$emoji_pattern$$=/(?:\uD83C[\uDDE6-\uDDFF]\uD83C[\uDDE6-\uDDFF])|(?:\uD83C[\uDC00-\uDFFF]|\uD83D[\uDC00-\uDEFF])|(?:\uD83E[\uDD00-\uDDFF])|(?:\uD83D[\uDE80-\uDEFF]|\uD83E[\uDC00-\uDCFF])|(?:\uD83E[\uDE70-\uDFFF])|[\u2600-\u26FF\u2700-\u27BF\u2300-\u23FF\u2B00-\u2BFF]/,$app$render_wasm$api$texts$unicode_ranges$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$2982$oriya$$,$cljs$cst$2983$coptic$$,$cljs$cst$2984$japanese$$,$cljs$cst$2985$runic$$,$cljs$cst$2986$tamil$$,
$cljs$cst$2987$ol_chiki$$,$cljs$cst$2988$music$$,$cljs$cst$2989$osmanya$$,$cljs$cst$2990$shavian$$,$cljs$cst$2991$bengali$$,$cljs$cst$2992$cyrillic$$,$cljs$cst$2993$latin_ext$$,$cljs$cst$2994$chinese$$,$cljs$cst$2995$gurmukhi$$,$cljs$cst$2996$ethiopic$$,$cljs$cst$2997$sinhala$$,$cljs$cst$2998$sora_sompeng$$,$cljs$cst$2999$khmer$$,$cljs$cst$3000$telugu$$,$cljs$cst$3001$vai$$,$cljs$cst$3002$javanese$$,$cljs$cst$3003$malayalam$$,$cljs$cst$3004$vietnamese$$,$cljs$cst$3005$devanagari$$,$cljs$cst$3006$thai$$,
$cljs$cst$3007$gujarati$$,$cljs$cst$3008$cherokee$$,$cljs$cst$3009$symbols_2$$,$cljs$cst$3010$tibetan$$,$cljs$cst$3011$bamum$$,$cljs$cst$3012$hebrew$$,$cljs$cst$3013$lao$$,$cljs$cst$3014$georgian$$,$cljs$cst$3015$tifinagh$$,$cljs$cst$3016$korean$$,$cljs$cst$3017$myanmar$$,$cljs$cst$3018$modi$$,$cljs$cst$3019$mongolian$$,$cljs$cst$3020$syriac$$,$cljs$cst$3021$greek$$,$cljs$cst$3022$old_italic$$,$cljs$cst$3023$arabic$$,$cljs$cst$3024$brahmi$$,$cljs$cst$3025$kannada$$,$cljs$cst$3026$symbols$$,$cljs$cst$3027$armenian$$,
$cljs$cst$3028$meroitic$$],[/[\u0B00-\u0B7F]/,/[\u2C80-\u2CFF]/,/[\u3040-\u30FF\u31F0-\u31FF\uFF66-\uFF9F]/,/[\u16A0-\u16FF]/,/[\u0B80-\u0BFF]/,/[\u1C50-\u1C7F]/,/[\u2669-\u267B]|\uD834[\uDD00-\uDD1F]/,/\uD801[\uDC80-\uDCAF]/,/\uD801[\uDC50-\uDC7F]/,/[\u0980-\u09FF]/,/[\u0400-\u04FF\u0500-\u052F\u2DE0-\u2DFF\uA640-\uA69F]/,/[\u0100-\u017F\u0180-\u024F]/,/[\u4E00-\u9FFF\u3400-\u4DBF]/,/[\u0A00-\u0A7F]/,/[\u1200-\u137F]/,/[\u0D80-\u0DFF]/,/\uD804[\uDCD0-\uDCFF]/,/[\u1780-\u17FF\u19E0-\u19FF]/,/[\u0C00-\u0C7F]/,
/[\uA500-\uA63F]/,/[\uA980-\uA9DF]/,/[\u0D00-\u0D7F]/,/[\u1EA0-\u1EF9]/,/[\u0900-\u097F\uA8E0-\uA8FF]/,/[\u0E00-\u0E7F]/,/[\u0A80-\u0AFF]/,/[\u13A0-\u13FF]/,/[\u2190-\u21FF\u2200-\u22FF\u2300-\u23FF\u25A0-\u25FF\u2600-\u26FF\u2700-\u27BF\u2B00-\u2BFF]|\uD83C[\uDC00-\uDCFF]|\uD83E[\uDC00-\uDCFF\uDF00-\uDFFF]/,/[\u0F00-\u0FFF]/,/[\uA6A0-\uA6FF]/,/[\u0590-\u05FF\uFB1D-\uFB4F]/,/[\u0E80-\u0EFF]/,/[\u10A0-\u10FF]/,/[\u2D30-\u2D7F]/,/[\uAC00-\uD7AF]/,/[\u1000-\u109F\uAA60-\uAA7F]/,/\uD805[\uDE00-\uDE5F]/,
/[\u1800-\u18AF]/,/[\u0700-\u074F]/,/[\u0370-\u03FF\u1F00-\u1FFF]/,/\uD800[\uDF00-\uDF2F]/,/[\u0600-\u06FF\u0750-\u077F\u0870-\u089F\u08A0-\u08FF]/,/\uD804[\uDC00-\uDC7F]/,/[\u0C80-\u0CFF]/,/[\u2190-\u21FF\u2200-\u22FF\u2300-\u23FF\u25A0-\u25FF\u2600-\u26FF\u2700-\u27BF\u2B00-\u2BFF]/,/[\u0530-\u058F\uFB13-\uFB17]/,/\uD802[\uDD80-\uDD9F]/]);var $app$render_wasm$gesture$interactive_transform_active_QMARK_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);var $app$render_wasm$svg_fills$url_fill_pattern$$=/url\(\s*['"]?#([^)'"]+)['"]?\s*\)/;var $app$render_wasm$svg_filters$drop_shadow_tags$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$2720$feGaussianBlur$$,null,$cljs$cst$2733$feColorMatrix$$,null,$cljs$cst$2736$feOffset$$,null],null),null);$APP.$app$render_wasm$text_editor$shape_text_contents$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$APP.$app$util$debug$state$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$);
$APP.$app$util$debug$options$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,31,[$cljs$cst$3052$disable_thumbnail_cache$$,null,$APP.$cljs$cst$3053$grid_layout$$,null,$APP.$cljs$cst$3054$disable_frame_thumbnails$$,null,$APP.$cljs$cst$3055$layout_lines$$,null,$APP.$cljs$cst$1608$group$$,null,$cljs$cst$3056$simple_selection$$,null,$APP.$cljs$cst$3057$grid_cells$$,null,$cljs$cst$3058$bounding_boxes$$,null,$APP.$cljs$cst$3059$layout_content_bounds$$,null,$APP.$cljs$cst$2318$events$$,
null,$APP.$cljs$cst$3060$layout_drop_zones$$,null,$APP.$cljs$cst$2229$thumbnails$$,null,$APP.$cljs$cst$3061$parent_bounds$$,null,$APP.$cljs$cst$1299$handlers$$,null,$cljs$cst$3062$events_times$$,null,$cljs$cst$3063$wasm_viewbox$$,null,$APP.$cljs$cst$3064$history_overlay$$,null,$cljs$cst$3065$gl_context$$,null,$cljs$cst$3066$wasm_gl_context_init_error$$,null,$APP.$cljs$cst$3067$force_frame_thumbnails$$,null,$cljs$cst$3068$selection_center$$,null,$APP.$cljs$cst$3069$text_outline$$,null,$cljs$cst$2593$show_ids$$,
null,$cljs$cst$3070$bool_shapes$$,null,$APP.$cljs$cst$3071$pixel_grid$$,null,$APP.$cljs$cst$3072$show_export_metadata$$,null,$APP.$cljs$cst$3073$display_touched$$,null,$APP.$cljs$cst$3074$shape_titles$$,null,$APP.$cljs$cst$3075$shape_panel$$,null,$cljs$cst$2594$show_touched$$,null,$APP.$cljs$cst$3076$html_text$$,null],null),null);
$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)&&($app$util$debug$handle_change$$(),$cljs$core$_add_watch$$($APP.$app$util$debug$state$$,$cljs$cst$3077$watcher$$,$app$util$debug$handle_change$$));var $app$util$text$content$styles$mixed_values$$;
$APP.$app$util$text$content$styles$mapping$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1634$fills$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$util$text$content$styles$encode$$,$app$util$text$content$styles$decode$$],null),$APP.$cljs$cst$1756$typography_ref_id$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$util$text$content$styles$encode$$,$app$util$text$content$styles$decode$$],
null),$APP.$cljs$cst$1642$typography_ref_file$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$util$text$content$styles$encode$$,$app$util$text$content$styles$decode$$],null),$APP.$cljs$cst$1757$font_id$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$identity$$,$APP.$cljs$core$identity$$],null),$APP.$cljs$cst$1759$font_variant_id$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$core$identity$$,$APP.$cljs$core$identity$$],null),$APP.$cljs$cst$1767$vertical_align$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$identity$$,$APP.$cljs$core$identity$$],null)],null);
$app$util$text$content$styles$mixed_values$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1616$multiple$$,null,"mixed",null,$APP.$cljs$cst$2038$mixed$$,null,"multiple",null],null),null);var $app$render_wasm$api$use_dpr_QMARK_$$,$app$render_wasm$api$snapshot_tiles_handler_STAR_$$,$app$render_wasm$api$schedule_canvas_snapshot_capture_BANG_$$,$app$render_wasm$api$view_interaction_active_QMARK_$$,$app$render_wasm$api$shape_wrapper_factory$$,$ch_54498$$,$app$render_wasm$api$pending_render$$,$app$render_wasm$api$deferred_render_QMARK_$$,$app$render_wasm$api$render_finish$$,$app$render_wasm$api$default_context_options$$;
$app$render_wasm$api$use_dpr_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$1234$render_wasm_dpr$$);$APP.$app$render_wasm$api$page_transition_QMARK_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$APP.$app$render_wasm$api$context_loss_overlay_QMARK_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$APP.$app$render_wasm$api$transition_image_url_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);
$APP.$app$render_wasm$api$transition_epoch_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(0);$APP.$app$render_wasm$api$transition_tiles_handler_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$app$render_wasm$api$snapshot_tiles_handler_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);
$app$render_wasm$api$schedule_canvas_snapshot_capture_BANG_$$=$APP.$app$util$functions$debounce$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$render_wasm$api$initialized_QMARK_$$()&&$app$render_wasm$wasm$canvas$$!=null?$promesa$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$render_wasm$api$webgl$capture_canvas_snapshot_url$$(),function(){return null}):null},250);$app$render_wasm$api$view_interaction_active_QMARK_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);
$APP.$app$render_wasm$api$dpr$$=$app$render_wasm$api$use_dpr_QMARK_$$?typeof window!=="undefined"?window.devicePixelRatio:1:1;$APP.$app$render_wasm$api$noop_fn$$=$APP.$cljs$core$constantly$$(null);$app$render_wasm$api$shape_wrapper_factory$$=null;$ch_54498$$=new MessageChannel;$app$render_wasm$api$pending_render$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$APP.$app$render_wasm$api$shapes_loading_QMARK_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);
$app$render_wasm$api$deferred_render_QMARK_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);
$app$render_wasm$api$render_finish$$=$APP.$app$util$functions$debounce$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){if($APP.$app$render_wasm$api$initialized_QMARK_$$()){$APP.$app$render_wasm$api$view_interaction_end_BANG_$$();var $cause54093_fn_54092$$=$APP.$app$render_wasm$wasm$internal_module$$._render;try{return $cause54093_fn_54092$$(0)}catch($e54094$$){$cause54093_fn_54092$$=$e54094$$;var $code__52999__auto__$jscomp$73_code_num__52998__auto__$jscomp$73_read_code_fn__52997__auto__$jscomp$73$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__52999__auto__$jscomp$73_code_num__52998__auto__$jscomp$73_read_code_fn__52997__auto__$jscomp$73$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$73_code_num__52998__auto__$jscomp$73_read_code_fn__52997__auto__$jscomp$73$$)?$code__52999__auto__$jscomp$73_code_num__52998__auto__$jscomp$73_read_code_fn__52997__auto__$jscomp$73$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$73_code_num__52998__auto__$jscomp$73_read_code_fn__52997__auto__$jscomp$73$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$73_code_num__52998__auto__$jscomp$73_read_code_fn__52997__auto__$jscomp$73$$():null;$code__52999__auto__$jscomp$73_code_num__52998__auto__$jscomp$73_read_code_fn__52997__auto__$jscomp$73$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$73_code_num__52998__auto__$jscomp$73_read_code_fn__52997__auto__$jscomp$73$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$73$$=["WASM Error (",
$APP.$app$common$data$name$$($code__52999__auto__$jscomp$73_code_num__52998__auto__$jscomp$73_read_code_fn__52997__auto__$jscomp$73$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$73$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_render",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$73$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$73_code_num__52998__auto__$jscomp$73_read_code_fn__52997__auto__$jscomp$73$$],
null),$cause54093_fn_54092$$);}}else return null},100);$app$render_wasm$api$default_context_options$$={antialias:!1,depth:!0,stencil:!0,alpha:!0,preserveDrawingBuffer:!0};
$APP.$app$render_wasm$api$module$$=new $APP.$cljs$core$Delay$$(function(){if(typeof dynamicImport!=="undefined"){var $uri$jscomp$79$$=$app$config$resolve_href$$("js/render-wasm.js");return $APP.$promesa$core$merr$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$48$$){console.error($cause$jscomp$48$$);return $APP.$promesa$impl$promise$resolved$$(!1)},$APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($default$$jscomp$85$$){$APP.$app$render_wasm$wasm$internal_module$$=
$default$$jscomp$85$$;return!0},$promesa$core$mcat$cljs$0core$0IFn$0_invoke$0arity$02$$($app$render_wasm$api$init_wasm_module$$,$shadow$esm$dynamic_import$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($uri$jscomp$79$$)))))}return $APP.$promesa$impl$promise$resolved$$(!1)});$APP.$JSCompiler_prototypeAlias$$=$app$render_wasm$shape$ShapeProxy$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$app$common$types$shape$IShape$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($_$jscomp$1627$$,$writer$jscomp$169$$){return $APP.$cljs$core$_write$$($writer$jscomp$169$$,["#penpot/shape ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.$delegate$))].join(""))};
$APP.$JSCompiler_prototypeAlias$$.toString=function(){var $coll$jscomp$1088$$=this;return["{",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",function(){return function $app$render_wasm$shape$iter__54483$$($s__54484$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__54484__$2_temp__5825__auto__$jscomp$176$$=$APP.$cljs$core$seq$$($s__54484$$);if($s__54484__$2_temp__5825__auto__$jscomp$176$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__54484__$2_temp__5825__auto__$jscomp$176$$)){var $JSCompiler_inline_result$jscomp$1043_c__5501__auto__$jscomp$31_v$jscomp$572_vec__54494$$=
$APP.$cljs$core$_chunked_first$$($s__54484__$2_temp__5825__auto__$jscomp$176$$),$size__5502__auto__$jscomp$31$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1043_c__5501__auto__$jscomp$31_v$jscomp$572_vec__54494$$),$b__54486_k$jscomp$628$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$31$$);a:{for(var $i__54485$jscomp$inline_6128$$=0;;)if($i__54485$jscomp$inline_6128$$<$size__5502__auto__$jscomp$31$$){var $b$jscomp$inline_12298_vec__54489$jscomp$inline_6129$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1043_c__5501__auto__$jscomp$31_v$jscomp$572_vec__54494$$,
$i__54485$jscomp$inline_6128$$),$k$jscomp$inline_6130_x$jscomp$inline_12299$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_12298_vec__54489$jscomp$inline_6129$$,0,null),$v$jscomp$inline_6131$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_12298_vec__54489$jscomp$inline_6129$$,1,null);$b$jscomp$inline_12298_vec__54489$jscomp$inline_6129$$=$b__54486_k$jscomp$628$$;$k$jscomp$inline_6130_x$jscomp$inline_12299$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$inline_6130_x$jscomp$inline_12299$$),
" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$inline_6131$$)].join("");$b$jscomp$inline_12298_vec__54489$jscomp$inline_6129$$.add($k$jscomp$inline_6130_x$jscomp$inline_12299$$);$i__54485$jscomp$inline_6128$$+=1}else{$JSCompiler_inline_result$jscomp$1043_c__5501__auto__$jscomp$31_v$jscomp$572_vec__54494$$=!0;break a}$JSCompiler_inline_result$jscomp$1043_c__5501__auto__$jscomp$31_v$jscomp$572_vec__54494$$=void 0}return $JSCompiler_inline_result$jscomp$1043_c__5501__auto__$jscomp$31_v$jscomp$572_vec__54494$$?
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__54486_k$jscomp$628$$),$app$render_wasm$shape$iter__54483$$($APP.$cljs$core$_chunked_rest$$($s__54484__$2_temp__5825__auto__$jscomp$176$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__54486_k$jscomp$628$$),null)}$JSCompiler_inline_result$jscomp$1043_c__5501__auto__$jscomp$31_v$jscomp$572_vec__54494$$=$APP.$cljs$core$first$$($s__54484__$2_temp__5825__auto__$jscomp$176$$);$b__54486_k$jscomp$628$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1043_c__5501__auto__$jscomp$31_v$jscomp$572_vec__54494$$,
0,null);$JSCompiler_inline_result$jscomp$1043_c__5501__auto__$jscomp$31_v$jscomp$572_vec__54494$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1043_c__5501__auto__$jscomp$31_v$jscomp$572_vec__54494$$,1,null);return $APP.$cljs$core$cons$$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($b__54486_k$jscomp$628$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1043_c__5501__auto__$jscomp$31_v$jscomp$572_vec__54494$$)].join(""),
$app$render_wasm$shape$iter__54483$$($APP.$cljs$core$rest$$($s__54484__$2_temp__5825__auto__$jscomp$176$$)))}return null}},null,null)}($coll$jscomp$1088$$)}())),"}"].join("")};$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$192$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$192$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$_find$arity$2$=function($_$jscomp$1628$$,$k$jscomp$630$$){switch($k$jscomp$630$$ instanceof $APP.$cljs$core$Keyword$$?$k$jscomp$630$$.$fqn$:null){case "id":return new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$266$id$$,this.id,null);case "type":return new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$139$type$$,this.type,null);default:return $cljs$core$_find$$(this.$delegate$,$k$jscomp$630$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_$jscomp$1629$$,$meta$jscomp$87$$){return new $app$render_wasm$shape$ShapeProxy$$(this.id,this.type,$APP.$cljs$core$with_meta$$(this.$delegate$,$meta$jscomp$87$$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($coll$jscomp$1089$$,$k$jscomp$631$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$631$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($_$jscomp$1630$$,$k$jscomp$632$$,$not_found$jscomp$82$$){switch($k$jscomp$632$$ instanceof $APP.$cljs$core$Keyword$$?$k$jscomp$632$$.$fqn$:null){case "id":return this.id;case "type":return this.type;default:return $APP.$cljs$core$_lookup$$(this.$delegate$,$k$jscomp$632$$,$not_found$jscomp$82$$)}};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return $APP.$cljs$core$meta$$(this.$delegate$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $APP.$cljs$core$hash$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($coll$jscomp$1091$$,$other$jscomp$193$$){return $APP.$cljs$core$equiv_map$$(this,$other$jscomp$193$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return new $app$render_wasm$shape$ShapeProxy$$(null,null,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($coll$jscomp$1092$$,$k$jscomp$633$$,$v$jscomp$574$$){return $app$render_wasm$shape$impl_assoc$$.$cljs$core$IFn$_invoke$arity$3$?$app$render_wasm$shape$impl_assoc$$.$cljs$core$IFn$_invoke$arity$3$(this,$k$jscomp$633$$,$v$jscomp$574$$):$app$render_wasm$shape$impl_assoc$$(this,$k$jscomp$633$$,$v$jscomp$574$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($_$jscomp$1633$$,$k$jscomp$634$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$634$$,$APP.$cljs$cst$266$id$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$634$$,$APP.$cljs$cst$139$type$$)||$APP.$cljs$core$contains_QMARK_$$(this.$delegate$,$k$jscomp$634$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 1+$APP.$cljs$core$count$$(this.$delegate$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($coll$jscomp$1093$$,$k$jscomp$635$$){return $app$render_wasm$shape$impl_dissoc$$.$cljs$core$IFn$_invoke$arity$2$?$app$render_wasm$shape$impl_dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this,$k$jscomp$635$$):$app$render_wasm$shape$impl_dissoc$$(this,$k$jscomp$635$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$cons$$(new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$266$id$$,this.id,null),$APP.$cljs$core$cons$$(new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$139$type$$,this.type,null),$cljs$core$_seq$$(this.$delegate$)))};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14276__auto__$jscomp$30$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$3443$$,$args54467$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args54467$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$636$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$636$$,null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$637$$,$not_found$jscomp$83$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$637$$,$not_found$jscomp$83$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($coll$jscomp$1096$$,$entry$jscomp$45$$){return $app$render_wasm$shape$impl_conj$$.$cljs$core$IFn$_invoke$arity$2$?$app$render_wasm$shape$impl_conj$$.$cljs$core$IFn$_invoke$arity$2$(this,$entry$jscomp$45$$):$app$render_wasm$shape$impl_conj$$(this,$entry$jscomp$45$$)};
var $app$render_wasm$shape$conj_STAR_$$=$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$()),$app$render_wasm$shape$xf_COLON_without_id_and_type$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($k$jscomp$641_kvpair$$){$k$jscomp$641_kvpair$$=$APP.$cljs$core$_key$$($k$jscomp$641_kvpair$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$641_kvpair$$,$APP.$cljs$cst$266$id$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($k$jscomp$641_kvpair$$,$APP.$cljs$cst$139$type$$)});
$APP.$app$common$transit$add_handlers_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,"shape",$APP.$cljs$cst$1291$class$$,$app$render_wasm$shape$ShapeProxy$$,$APP.$cljs$cst$1314$wfn$$,function($p1__54667_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$p1__54667_SHARP_$$)}],null)]));var $app$main$features$initialize_54846$$,$app$main$features$recompute_features_54849$$;$APP.$app$common$logging$loggers$$.set("app.main.features",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$144$trace$$));$APP.$app$main$features$global_enabled_features$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($app$common$features$default_features$$,$app$common$features$xf_flag_to_feature$$,$APP.$app$config$flags$$);
$APP.$app$main$features$features_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$227$features$$),$APP.$app$main$store$state$$);$APP.$app$main$worker$instance$$=null;$APP.$app$main$worker$ask_BANG_$$=function $app$main$worker$ask_BANG_$$($var_args$jscomp$1144$$){switch(arguments.length){case 1:return $app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$1$=function($message$jscomp$73$$){return $APP.$cljs$core$truth_$$($APP.$app$main$worker$instance$$)?$APP.$app$util$worker$ask_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$main$worker$instance$$,$message$jscomp$73$$,null):$APP.$beicon$v2$core$empty$$()};
$APP.$app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$2$=function($message$jscomp$74$$,$transfer$jscomp$9$$){return $APP.$cljs$core$truth_$$($APP.$app$main$worker$instance$$)?$APP.$app$util$worker$ask_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$main$worker$instance$$,$message$jscomp$74$$,$transfer$jscomp$9$$):$APP.$beicon$v2$core$empty$$()};$APP.$app$main$worker$ask_BANG_$$.$cljs$lang$maxFixedArity$=2;var $app$main$data$changes$update_indexes_54901$$,$app$main$data$changes$sync_wasm_structural_changes_54972$$,$app$main$data$changes$apply_changes_localy_55044$$,$app$main$data$changes$commit_55124$$,$app$main$data$changes$commit_changes_55177$$,$app$main$data$changes$page_change_QMARK_$$,$app$main$data$changes$xf_COLON_map_page_id$$,$app$main$data$changes$wasm_structural_change_types$$;$APP.$app$common$logging$loggers$$.set("app.main.data.changes",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));
$app$main$data$changes$page_change_QMARK_$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2622$del_page$$,null,$APP.$cljs$cst$2623$mov_page$$,null,$cljs$cst$2621$mod_page$$,null,$APP.$cljs$cst$2620$add_page$$,null],null),null);$APP.$app$main$data$changes$commit_QMARK_$$=$APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$2147$app_DOT_main_DOT_data_DOT_changes_SLASH_commit$$);
$app$main$data$changes$xf_COLON_map_page_id$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2043$page_id$$);$app$main$data$changes$wasm_structural_change_types$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$2616$mov_objects$$,null,$APP.$cljs$cst$2610$add_obj$$,null],null),null);$APP.$app$common$logging$loggers$$.set("app.main.data.persistence",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));$APP.$app$main$data$persistence$revn_data$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
$APP.$app$main$data$persistence$queue_conj$$=$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentQueue$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$));$APP.$app$main$data$persistence$xf_mapcat_undo$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3137$undo_changes$$);$APP.$app$main$data$persistence$xf_mapcat_redo$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3133$redo_changes$$);var $app$common$files$changes_builder$schema_COLON_changes$$=$app$common$schema$register_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"changes"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3133$redo_changes$$,
$APP.$cljs$core$vector_QMARK_$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$seq_QMARK_$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1786$origin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$974$app_DOT_common_DOT_schema_SLASH_any$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3140$save_undo_QMARK_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$core$boolean_QMARK_$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3141$stack_undo_QMARK_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$core$boolean_QMARK_$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3138$undo_group$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$974$app_DOT_common_DOT_schema_SLASH_any$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$934$app_DOT_common_DOT_schema_SLASH_type$$,$cljs$cst$3165$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_changes$$],null)));$app$common$schema$check_fn$$($app$common$files$changes_builder$schema_COLON_changes$$);var $app$common$types$profile$schema_COLON_profile$$=new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Profile"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1569$created_at$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1360$fullname$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3183$email$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2828$lang$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3184$theme$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1359$photo_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3185$photo_url$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$198$string$$],null)],null);$cljs$spec$alpha$def_impl$$($cljs$cst$3186$app_DOT_main_DOT_data_DOT_media_SLASH_blob$$,$cljs$cst$3187$app_DOT_main_DOT_data_DOT_media_SLASH_blob_QMARK_$$,function($o$jscomp$265$$){return $o$jscomp$265$$ instanceof Blob});
$cljs$spec$alpha$def_impl$$($cljs$cst$3188$app_DOT_main_DOT_data_DOT_media_SLASH_blobs$$,$APP.$cljs$core$list$$($cljs$cst$3189$cljs_DOT_spec_DOT_alpha_SLASH_coll_of$$,$cljs$cst$3186$app_DOT_main_DOT_data_DOT_media_SLASH_blob$$),$cljs$spec$alpha$every_impl$cljs$0core$0IFn$0_invoke$0arity$04$$($cljs$cst$3186$app_DOT_main_DOT_data_DOT_media_SLASH_blob$$,$cljs$cst$3186$app_DOT_main_DOT_data_DOT_media_SLASH_blob$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1082$cljs_DOT_spec_DOT_alpha_SLASH_conform_all$$,
!0,$cljs$cst$1073$cljs_DOT_spec_DOT_alpha_SLASH_kind_form$$,null,$cljs$cst$1077$cljs_DOT_spec_DOT_alpha_SLASH_describe$$,$APP.$cljs$core$list$$($cljs$cst$3189$cljs_DOT_spec_DOT_alpha_SLASH_coll_of$$,$cljs$cst$3186$app_DOT_main_DOT_data_DOT_media_SLASH_blob$$),$cljs$cst$1075$cljs_DOT_spec_DOT_alpha_SLASH_cpred$$,function($G__54072$$){return $APP.$cljs$core$coll_QMARK_$$($G__54072$$)}],null),null));
$cljs$spec$alpha$def_impl$$($cljs$cst$3190$app_DOT_main_DOT_data_DOT_media_SLASH_file$$,$cljs$cst$3191$app_DOT_main_DOT_data_DOT_media_SLASH_file_QMARK_$$,$APP.$app$main$data$media$file_QMARK_$$);
$cljs$spec$alpha$def_impl$$($cljs$cst$3192$app_DOT_main_DOT_data_DOT_media_SLASH_files$$,$APP.$cljs$core$list$$($cljs$cst$3189$cljs_DOT_spec_DOT_alpha_SLASH_coll_of$$,$cljs$cst$3190$app_DOT_main_DOT_data_DOT_media_SLASH_file$$),$cljs$spec$alpha$every_impl$cljs$0core$0IFn$0_invoke$0arity$04$$($cljs$cst$3190$app_DOT_main_DOT_data_DOT_media_SLASH_file$$,$cljs$cst$3190$app_DOT_main_DOT_data_DOT_media_SLASH_file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$1082$cljs_DOT_spec_DOT_alpha_SLASH_conform_all$$,
!0,$cljs$cst$1073$cljs_DOT_spec_DOT_alpha_SLASH_kind_form$$,null,$cljs$cst$1077$cljs_DOT_spec_DOT_alpha_SLASH_describe$$,$APP.$cljs$core$list$$($cljs$cst$3189$cljs_DOT_spec_DOT_alpha_SLASH_coll_of$$,$cljs$cst$3190$app_DOT_main_DOT_data_DOT_media_SLASH_file$$),$cljs$cst$1075$cljs_DOT_spec_DOT_alpha_SLASH_cpred$$,function($G__54076$$){return $APP.$cljs$core$coll_QMARK_$$($G__54076$$)}],null),null));$APP.$app$plugins$register$registry$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $app$main$data$profile$set_profile_54905$$,$app$main$data$profile$fetch_profile_54957$$,$app$main$data$profile$refresh_profile_54975$$,$app$main$data$profile$persist_profile_55022$$,$app$main$data$profile$toggle_theme_55047$$,$app$main$data$profile$cancel_email_change_55133$$,$app$main$data$profile$update_profile_props_55278$$,$app$main$data$profile$delete_photo_55310$$,$app$main$data$profile$request_profile_recovery_55333$$,$app$main$data$profile$access_tokens_fetched_55348$$,$app$main$data$profile$fetch_access_tokens_55353$$,
$app$main$data$profile$check_request_profile_recovery$$;$APP.$app$main$data$profile$check_profile$$=$app$common$schema$check_fn$$($app$common$types$profile$schema_COLON_profile$$);$APP.$app$main$data$profile$profile_fetched_QMARK_$$=$APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3199$app_DOT_main_DOT_data_DOT_profile_SLASH_profile_fetched$$);
typeof $app$main$data$profile$cancel_email_change_55133$$==="undefined"&&($app$main$data$profile$cancel_email_change_55133$$=function($meta55134$jscomp$inline_6178$$){this.$meta55134$=$meta55134$jscomp$inline_6178$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$profile$cancel_email_change_55133$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3212$app_DOT_main_DOT_data_DOT_profile_SLASH_cancel_email_change$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55135$jscomp$inline_6179$$,$meta55134__$1$jscomp$inline_6180$$){return new $app$main$data$profile$cancel_email_change_55133$$($meta55134__$1$jscomp$inline_6180$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55134$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$($APP.$app$main$data$profile$refresh_profile$$()),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3213$cancel_email_change$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$))});new $app$main$data$profile$cancel_email_change_55133$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
$APP.$app$main$data$profile$check_update_password$$=$app$common$schema$check_fn$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$462$closed$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3214$password_1$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3215$password_2$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3216$password_old$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null)],
null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,"expected valid parameters for update password"]));
$APP.$app$main$data$profile$check_update_notifications_params$$=$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"NotificationsForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3219$dashboard_comments$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2124$all$$,null,$APP.$cljs$cst$2125$partial$$,null,$APP.$cljs$cst$226$none$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3220$email_comments$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2124$all$$,null,$APP.$cljs$cst$2125$partial$$,null,$APP.$cljs$cst$226$none$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3221$email_invites$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2124$all$$,null,$APP.$cljs$cst$226$none$$,null],null),null)],null)],null)],null));
typeof $app$main$data$profile$delete_photo_55310$$==="undefined"&&($app$main$data$profile$delete_photo_55310$$=function($meta55311$jscomp$inline_6182$$){this.$meta55311$=$meta55311$jscomp$inline_6182$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$profile$delete_photo_55310$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3233$app_DOT_main_DOT_data_DOT_profile_SLASH_delete_photo$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55312$jscomp$inline_6183$$,$meta55311__$1$jscomp$inline_6184$$){return new $app$main$data$profile$delete_photo_55310$$($meta55311__$1$jscomp$inline_6184$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55311$},$APP.$JSCompiler_prototypeAlias$$.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$app$main$data$event$Event$_data$arity$1$=function(){return $APP.$cljs$core$PersistentArrayMap$EMPTY$$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_6185$$,$state$jscomp$inline_6186$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$inline_6186$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1914$profile$$,$APP.$cljs$cst$1359$photo_id$$],null),null)},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$inline_6187$$){console.error("delete-photo failed",$cause$jscomp$inline_6187$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$profile$refresh_profile$$())},
$APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$($APP.$app$main$data$profile$refresh_profile$$()),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3234$delete_profile_photo$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)))});$APP.$app$main$data$profile$delete_photo$$=new $app$main$data$profile$delete_photo_55310$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$APP.$app$main$data$profile$profile_deleted_event_QMARK_$$=$APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3239$app_DOT_main_DOT_data_DOT_profile_SLASH_profile_deleted$$);
$app$main$data$profile$check_request_profile_recovery$$=$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"request-profile-recovery",$cljs$cst$462$closed$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3183$email$$,$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$],
null)],null));
$APP.$app$main$data$profile$check_recover_profile$$=$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"recover-profile",$cljs$cst$462$closed$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$751$password$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$cst$198$string$$],null)],null));var $allowedTypes$$module$app$util$clipboard$$="image/webp image/png image/jpeg image/svg+xml application/transit+json text/html text/plain".split(" "),$exclusiveTypes$$module$app$util$clipboard$$=["application/transit+json","text/html","text/plain"],$svgTextPattern$$module$app$util$clipboard$$=/^(\s*<\?xml[^?]*\?>\s*)?(\s*\x3c!--[\s\S]*?--\x3e\s*)*<svg[\s>]/i;
$module$app$util$clipboard$$={$fromClipboardData$:function($clipboardData$$,$options$jscomp$496$$){return $fromDataTransfer$$module$app$util$clipboard$$($clipboardData$$,$options$jscomp$496$$)},$fromClipboardEvent$:function($e$jscomp$316$$,$options$jscomp$497$$){return $fromDataTransfer$$module$app$util$clipboard$$($e$jscomp$316$$.clipboardData,$options$jscomp$497$$)}};$module$app$util$clipboard$$.$fromDataTransfer$=$fromDataTransfer$$module$app$util$clipboard$$;
$module$app$util$clipboard$$.$fromNavigator$=async function($options$jscomp$494$$){$options$jscomp$494$$=$options$jscomp$494$$||{};const $items$jscomp$29$$=await navigator.clipboard.read();return(await Promise.all(Array.from($items$jscomp$29$$).map(async $blob$jscomp$19_item$jscomp$59_text$jscomp$41$$=>{var $itemAllowedTypes_type$jscomp$429$$=Array.from($blob$jscomp$19_item$jscomp$59_text$jscomp$41$$.types).filter($filterAllowedTypes$$module$app$util$clipboard$$($options$jscomp$494$$)).sort($sortTypes$$module$app$util$clipboard$$);
if($itemAllowedTypes_type$jscomp$429$$.length===1&&$itemAllowedTypes_type$jscomp$429$$.at(0)==="text/plain")return $blob$jscomp$19_item$jscomp$59_text$jscomp$41$$=await $blob$jscomp$19_item$jscomp$59_text$jscomp$41$$.getType("text/plain"),$blob$jscomp$19_item$jscomp$59_text$jscomp$41$$.size<16777216?($blob$jscomp$19_item$jscomp$59_text$jscomp$41$$=await $blob$jscomp$19_item$jscomp$59_text$jscomp$41$$.text(),$parseText$$module$app$util$clipboard$$($blob$jscomp$19_item$jscomp$59_text$jscomp$41$$,$options$jscomp$494$$)):
$blob$jscomp$19_item$jscomp$59_text$jscomp$41$$;$itemAllowedTypes_type$jscomp$429$$=$itemAllowedTypes_type$jscomp$429$$.at(0);return $itemAllowedTypes_type$jscomp$429$$==null?null:$blob$jscomp$19_item$jscomp$59_text$jscomp$41$$.getType($itemAllowedTypes_type$jscomp$429$$)}))).filter($item$jscomp$60$$=>!!$item$jscomp$60$$)};var $app$util$clipboard$image_types$$;$app$util$clipboard$image_types$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["image/webp","image/png","image/jpeg","image/svg+xml"],null);$APP.$app$util$clipboard$default_options$$={decodeTransit:$APP.$app$common$transit$decode_str$$,allowHTMLPaste:!1};var $app$main$data$team$teams_fetched_55394$$,$app$main$data$team$fetch_teams_55400$$,$app$main$data$team$members_fetched_55407$$,$app$main$data$team$fetch_members_55416$$,$app$main$data$team$invitations_fetched_55424$$,$app$main$data$team$fetch_invitations_55429$$,$app$main$data$team$update_member_role_55450$$,$app$main$data$team$delete_member_55455$$,$app$main$data$team$webhooks_fetched_55475$$,$app$main$data$team$fetch_webhooks_55480$$,$app$main$data$team$team_created_55529$$,$app$main$data$team$create_team_55543$$,
$app$main$data$team$update_team_55575$$,$app$main$data$team$team_leaved_55580$$,$app$main$data$team$leave_current_team_55595$$,$app$main$data$team$create_invitations_55602$$,$app$main$data$team$copy_invitation_link_55608$$,$app$main$data$team$update_invitation_role_55614$$,$app$main$data$team$team_deleted_55624$$,$app$main$data$team$delete_team_55629$$,$app$main$data$team$delete_webhook_55635$$,$app$main$data$team$update_webhook_55647$$,$app$main$data$team$create_webhook_55657$$,$app$main$data$team$shared_files_fetched_55671$$,
$app$main$data$team$fetch_shared_files_55676$$;$APP.$app$common$logging$loggers$$.set("app.main.data.team",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));
var $app$main$data$team$check_create_invitations_params$$=$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3290$emails$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3268$invitations$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3183$email$$,$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2490$role$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,$app$common$types$team$valid_roles$$],null)],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1927$team_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3299$resend_QMARK_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,function($attrs$jscomp$62$$){return $APP.$cljs$core$contains_QMARK_$$($attrs$jscomp$62$$,$APP.$cljs$cst$3290$emails$$)||$APP.$cljs$core$contains_QMARK_$$($attrs$jscomp$62$$,$APP.$cljs$cst$3268$invitations$$)}],
null)],null));$APP.$goog$inherits$$($goog$net$WebSocket$$,$APP.$goog$events$EventTarget$$);var $goog$net$WebSocket$BinaryType$BLOB$$="blob";$APP.$JSCompiler_prototypeAlias$$=$goog$net$WebSocket$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$webSocket_$=null;$APP.$JSCompiler_prototypeAlias$$.$url_$=null;$APP.$JSCompiler_prototypeAlias$$.$protocol_$=void 0;$APP.$JSCompiler_prototypeAlias$$.$closeExpected_$=!1;$APP.$JSCompiler_prototypeAlias$$.$reconnectAttempt_$=0;
$APP.$JSCompiler_prototypeAlias$$.$reconnectTimer_$=null;$APP.$JSCompiler_prototypeAlias$$.$logger_$=$goog$log$getLogger$$("goog.net.WebSocket");
$APP.$JSCompiler_prototypeAlias$$.open=function($url$jscomp$85$$,$opt_protocol$jscomp$1$$){this.$reconnectTimer_$!=null&&$APP.$goog$global$$.clearTimeout(this.$reconnectTimer_$);this.$reconnectTimer_$=null;this.$url_$=$url$jscomp$85$$;(this.$protocol_$=$opt_protocol$jscomp$1$$)?($goog$log$info$$(this.$logger_$,"Opening the WebSocket on "+this.$url_$+" with protocol "+this.$protocol_$),this.$webSocket_$=new WebSocket(this.$url_$,this.$protocol_$)):($goog$log$info$$(this.$logger_$,"Opening the WebSocket on "+
this.$url_$),this.$webSocket_$=new WebSocket(this.$url_$));this.$webSocket_$.binaryType=this.$binaryType_$;this.$webSocket_$.onopen=$goog$bind$$(this.$onOpen_$,this);this.$webSocket_$.onclose=$goog$bind$$(this.$onClose_$,this);this.$webSocket_$.onmessage=$goog$bind$$(this.$onMessage_$,this);this.$webSocket_$.onerror=$goog$bind$$(this.$onError_$,this)};
$APP.$JSCompiler_prototypeAlias$$.close=function(){this.$reconnectTimer_$!=null&&$APP.$goog$global$$.clearTimeout(this.$reconnectTimer_$);this.$reconnectTimer_$=null;this.$webSocket_$&&($goog$log$info$$(this.$logger_$,"Closing the WebSocket."),this.$closeExpected_$=!0,this.$webSocket_$.close(),this.$webSocket_$=null)};$APP.$JSCompiler_prototypeAlias$$.send=function($message$jscomp$81$$){this.$webSocket_$.send($message$jscomp$81$$)};
$APP.$JSCompiler_prototypeAlias$$.isOpen=function(){return!!this.$webSocket_$&&this.$webSocket_$.readyState==1};$APP.$JSCompiler_prototypeAlias$$.$onOpen_$=function(){$goog$log$info$$(this.$logger_$,"WebSocket opened on "+this.$url_$);this.dispatchEvent("opened$6");this.$reconnectAttempt_$=0;this.$nextReconnect_$=this.$getNextReconnect_$(this.$reconnectAttempt_$)};
$APP.$JSCompiler_prototypeAlias$$.$onClose_$=function($event$jscomp$86$$){$goog$log$info$$(this.$logger_$,"The WebSocket on "+this.$url_$+" closed.");this.dispatchEvent(new $goog$net$WebSocket$ClosedEvent$$($event$jscomp$86$$.code,$event$jscomp$86$$.reason,$event$jscomp$86$$.wasClean));this.$webSocket_$=null;this.$closeExpected_$?($goog$log$info$$(this.$logger_$,"The WebSocket closed normally."),this.$url_$=null,this.$protocol_$=void 0):($goog$log$error$$(this.$logger_$,"The WebSocket disconnected unexpectedly: "+
$event$jscomp$86$$.data),this.$autoReconnect_$&&($goog$log$info$$(this.$logger_$,"Seconds until next reconnect attempt: "+Math.floor(this.$nextReconnect_$/1E3)),this.$reconnectTimer_$=$goog$Timer$callOnce$$($goog$bind$$(this.open,this,this.$url_$,this.$protocol_$),this.$nextReconnect_$,this),this.$reconnectAttempt_$++,this.$nextReconnect_$=this.$getNextReconnect_$(this.$reconnectAttempt_$)));this.$closeExpected_$=!1};$APP.$JSCompiler_prototypeAlias$$.$onMessage_$=function($event$jscomp$87$$){this.dispatchEvent(new $goog$net$WebSocket$MessageEvent$$($event$jscomp$87$$.data))};
$APP.$JSCompiler_prototypeAlias$$.$onError_$=function($data$jscomp$277_event$jscomp$88$$){$data$jscomp$277_event$jscomp$88$$=$data$jscomp$277_event$jscomp$88$$.data;$goog$log$error$$(this.$logger_$,"An error occurred: "+$data$jscomp$277_event$jscomp$88$$);this.dispatchEvent(new $goog$net$WebSocket$ErrorEvent$$($data$jscomp$277_event$jscomp$88$$))};$APP.$JSCompiler_prototypeAlias$$.$disposeInternal$=function(){$goog$net$WebSocket$$.$superClass_$.$disposeInternal$.call(this);this.close()};
$APP.$goog$inherits$$($goog$net$WebSocket$ClosedEvent$$,$APP.$goog$events$Event$$);$APP.$goog$inherits$$($goog$net$WebSocket$MessageEvent$$,$APP.$goog$events$Event$$);$APP.$goog$inherits$$($goog$net$WebSocket$ErrorEvent$$,$APP.$goog$events$Event$$);$APP.$JSCompiler_prototypeAlias$$=$app$util$websocket$t_app$0util$0websocket54423$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_54425$$,$meta54424__$1$$){return new $app$util$websocket$t_app$0util$0websocket54423$$(this.uri,this.sb,this.ws,this.data,this.$lk1$,this.$lk2$,this.$lk3$,$meta54424__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta54424$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDeref$_deref$arity$1$=function(){return $APP.$cljs$core$_deref$$(this.data)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReset$_reset_BANG_$arity$2$=function($_$jscomp$1749$$,$newval$jscomp$9$$){return $cljs$core$_reset_BANG_$$(this.data,$newval$jscomp$9$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$2$=function($_$jscomp$1750$$,$f$jscomp$819$$){return $cljs$core$_swap_BANG_$$(this.data,$f$jscomp$819$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$3$=function($_$jscomp$1751$$,$f$jscomp$820$$,$x$jscomp$1166$$){return $cljs$core$_swap_BANG_$$(this.data,$f$jscomp$820$$,$x$jscomp$1166$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$4$=function($_$jscomp$1752$$,$f$jscomp$821$$,$x$jscomp$1167$$,$y$jscomp$404$$){return $cljs$core$_swap_BANG_$$(this.data,$f$jscomp$821$$,$x$jscomp$1167$$,$y$jscomp$404$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$5$=function($_$jscomp$1753$$,$f$jscomp$822$$,$x$jscomp$1168$$,$y$jscomp$405$$,$more$jscomp$50$$){return $cljs$core$_swap_BANG_$$(this.data,$f$jscomp$822$$,$x$jscomp$1168$$,$y$jscomp$405$$,$more$jscomp$50$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWatchable$_notify_watches$arity$3$=function($_$jscomp$1754$$,$oldval$jscomp$8$$,$newval$jscomp$10$$){return $cljs$core$_notify_watches$$(this.data,$oldval$jscomp$8$$,$newval$jscomp$10$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWatchable$_add_watch$arity$3$=function($_$jscomp$1755$$,$key$jscomp$368$$,$f$jscomp$823$$){return $cljs$core$_add_watch$$(this.data,$key$jscomp$368$$,$f$jscomp$823$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWatchable$_remove_watch$arity$2$=function($_$jscomp$1756$$,$key$jscomp$369$$){return $cljs$core$_remove_watch$$(this.data,$key$jscomp$369$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $goog$getUid$$(this.ws)};
$APP.$JSCompiler_prototypeAlias$$.$app$util$websocket$IWebSocket$_stream$arity$1$=function(){return $APP.$beicon$v2$core$map$$(function($map__54436__$1_p__54435$$){$map__54436__$1_p__54435$$=$APP.$cljs$core$__destructure_map$$($map__54436__$1_p__54435$$);var $type$jscomp$432$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54436__$1_p__54435$$,$APP.$cljs$cst$139$type$$),$payload$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54436__$1_p__54435$$,$APP.$cljs$cst$3113$payload$$);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$141$message$$,$type$jscomp$432$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__54436__$1_p__54435$$,$APP.$cljs$cst$3113$payload$$,$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($payload$jscomp$7$$)):$map__54436__$1_p__54435$$},this.sb)};
$APP.$JSCompiler_prototypeAlias$$.$app$util$websocket$IWebSocket$_send$arity$2$=function($_$jscomp$1759$$,$msg$jscomp$24$$){return $APP.$cljs$core$truth_$$(this.ws.isOpen())?this.ws.send($msg$jscomp$24$$):null};$APP.$JSCompiler_prototypeAlias$$.$app$util$websocket$IWebSocket$_close$arity$1$=function(){this.sb.complete();$APP.$goog$events$unlistenByKey$$(this.$lk1$);$APP.$goog$events$unlistenByKey$$(this.$lk2$);$APP.$goog$events$unlistenByKey$$(this.$lk3$);this.ws.close();return this.ws.dispose()};var $app$main$data$websocket$send_message_54455$$,$app$main$data$websocket$initialize_54461$$,$app$main$data$websocket$finalize_54464$$;$APP.$app$common$logging$loggers$$.set("app.main.data.websocket",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$849$error$$));var $app$main$data$websocket$ws_conn$$=$APP.$cljs$core$volatile_BANG_$$(null);var $app$main$data$auth$logged_in_55750$$,$app$main$data$auth$login_55780$$,$app$main$data$auth$login_with_ldap_55808$$,$app$main$data$auth$login_with_sso_55820$$,$app$main$data$auth$login_from_register_55851$$,$app$main$data$auth$logged_out_55870$$,$app$main$data$auth$logout_55886$$;var $app$main$errors$handling_error_QMARK_$$;$APP.$app$main$errors$last_report$$=null;$app$main$errors$handling_error_QMARK_$$=$APP.$cljs$core$volatile_BANG_$$(!1);$APP.$cljs$core$reset_BANG_$$($app$main$store$on_error$$,$APP.$app$main$errors$on_error$$);
$potok$v2$core$handle_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$1584$network$$,function($error$jscomp$58$$){var $temp__5825__auto___56235$$=$APP.$cljs$cst$3364$app_DOT_main_DOT_errors_SLASH_instance$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$58$$);$APP.$cljs$core$truth_$$($temp__5825__auto___56235$$)&&$app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($temp__5825__auto___56235$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,
"Network Error"]));return $app$main$errors$flash$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$145$cause$$,$APP.$cljs$cst$3364$app_DOT_main_DOT_errors_SLASH_instance$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$58$$),$APP.$cljs$cst$139$type$$,$cljs$cst$3366$handled$$]))});
$potok$v2$core$handle_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$1752$internal$$,function($error$jscomp$59_temp__5825__auto__$jscomp$183$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$assign_exception$$($error$jscomp$59_temp__5825__auto__$jscomp$183$$));$error$jscomp$59_temp__5825__auto__$jscomp$183$$=$APP.$cljs$cst$3364$app_DOT_main_DOT_errors_SLASH_instance$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$59_temp__5825__auto__$jscomp$183$$);
return $APP.$cljs$core$truth_$$($error$jscomp$59_temp__5825__auto__$jscomp$183$$)?$app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($error$jscomp$59_temp__5825__auto__$jscomp$183$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,"Internal Error"])):null});
$potok$v2$core$handle_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function($error$jscomp$60_temp__5825__auto__$jscomp$184$$){if(typeof $APP.$cljs$cst$275$hint$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$60_temp__5825__auto__$jscomp$184$$)==="string"&&$APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$cst$275$hint$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$60_temp__5825__auto__$jscomp$184$$),"Assert failed:"))return $potok$v2$core$handle_error$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($error$jscomp$60_temp__5825__auto__$jscomp$184$$,
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$272$assertion$$));$error$jscomp$60_temp__5825__auto__$jscomp$184$$=$APP.$cljs$cst$3364$app_DOT_main_DOT_errors_SLASH_instance$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$60_temp__5825__auto__$jscomp$184$$);return $APP.$cljs$core$truth_$$($error$jscomp$60_temp__5825__auto__$jscomp$184$$)?($app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($error$jscomp$60_temp__5825__auto__$jscomp$184$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,
"Unexpected Error"])),$app$main$errors$flash$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$145$cause$$,$error$jscomp$60_temp__5825__auto__$jscomp$184$$,$APP.$cljs$cst$139$type$$,$cljs$cst$3367$unhandled$$]))):null});
$potok$v2$core$handle_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2972$wasm_error$$,function($error$jscomp$61$$){var $temp__5825__auto__$jscomp$185$$=$APP.$cljs$cst$3364$app_DOT_main_DOT_errors_SLASH_instance$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$61$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$185$$)){$APP.$app$common$exceptions$print_throwable$$($temp__5825__auto__$jscomp$185$$);var $code$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error$jscomp$61$$,
$APP.$cljs$cst$273$code$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$27$$,$cljs$cst$2968$panic$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$assign_exception$$($error$jscomp$61$$)):$app$main$errors$flash$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$cljs$cst$3366$handled$$,$cljs$cst$145$cause$$,$temp__5825__auto__$jscomp$185$$]))}return null});
$potok$v2$core$handle_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$3157$authentication$$,function($error$jscomp$62$$){var $message$jscomp$89$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.auth.unable-to-login"),$uri$jscomp$89$$=$APP.$app$util$globals$location$$.href,$show_error_QMARK_$$=function(){var $or__5025__auto__$jscomp$625_or__5025__auto____$1$jscomp$76_or__5025__auto____$2$jscomp$21$$=$APP.$cuerdas$core$includes_QMARK_$$($uri$jscomp$89$$,"workspace");
if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$625_or__5025__auto____$1$jscomp$76_or__5025__auto____$2$jscomp$21$$))return $or__5025__auto__$jscomp$625_or__5025__auto____$1$jscomp$76_or__5025__auto____$2$jscomp$21$$;$or__5025__auto__$jscomp$625_or__5025__auto____$1$jscomp$76_or__5025__auto____$2$jscomp$21$$=$APP.$cuerdas$core$includes_QMARK_$$($uri$jscomp$89$$,"dashboard");if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$625_or__5025__auto____$1$jscomp$76_or__5025__auto____$2$jscomp$21$$))return $or__5025__auto__$jscomp$625_or__5025__auto____$1$jscomp$76_or__5025__auto____$2$jscomp$21$$;
$or__5025__auto__$jscomp$625_or__5025__auto____$1$jscomp$76_or__5025__auto____$2$jscomp$21$$=$APP.$cuerdas$core$includes_QMARK_$$($uri$jscomp$89$$,"view");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$625_or__5025__auto____$1$jscomp$76_or__5025__auto____$2$jscomp$21$$)?$or__5025__auto__$jscomp$625_or__5025__auto____$1$jscomp$76_or__5025__auto____$2$jscomp$21$$:$APP.$cuerdas$core$includes_QMARK_$$($uri$jscomp$89$$,"settings")}();if($APP.$cljs$core$truth_$$($show_error_QMARK_$$))return $app$main$store$async_emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$router$assign_exception$$($error$jscomp$62$$)]));
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$auth$logout$$());return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(500,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$warn$cljs$0core$0IFn$0_invoke$0arity$02$$($message$jscomp$89$$))})});
$potok$v2$core$handle_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2252$validation$$,function($map__56106__$1_message$jscomp$90_p__56102$$){$map__56106__$1_message$jscomp$90_p__56102$$=$APP.$cljs$core$__destructure_map$$($map__56106__$1_message$jscomp$90_p__56102$$);var $code$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56106__$1_message$jscomp$90_p__56102$$,$APP.$cljs$cst$273$code$$),$temp__5825__auto___56240$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56106__$1_message$jscomp$90_p__56102$$,
$APP.$cljs$cst$3364$app_DOT_main_DOT_errors_SLASH_instance$$);$APP.$cljs$core$truth_$$($temp__5825__auto___56240$$)&&$app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($temp__5825__auto___56240$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,"Validation Error"]));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$28$$,$cljs$cst$3368$invalid_paste_data$$)?($map__56106__$1_message$jscomp$90_p__56102$$=
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.paste-data-validation"),$app$main$store$async_emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$map__56106__$1_message$jscomp$90_p__56102$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,
$APP.$cljs$cst$2353$timeout$$,3E3],null))]))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$28$$,$cljs$cst$3369$vern_conflict$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($potok$v2$core$resolve$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3370$app_DOT_main_DOT_data_DOT_workspace_SLASH_reload_current_file$$,null)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$28$$,$cljs$cst$3371$snapshot_is_locked$$)?($map__56106__$1_message$jscomp$90_p__56102$$=
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.version-locked"),$app$main$store$async_emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$map__56106__$1_message$jscomp$90_p__56102$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2353$timeout$$,
3E3],null))]))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$28$$,$cljs$cst$3372$only_creator_can_lock$$)?($map__56106__$1_message$jscomp$90_p__56102$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.only-creator-can-lock"),$app$main$store$async_emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,
$map__56106__$1_message$jscomp$90_p__56102$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2353$timeout$$,3E3],null))]))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$28$$,$cljs$cst$3373$only_creator_can_unlock$$)?($map__56106__$1_message$jscomp$90_p__56102$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.only-creator-can-unlock"),$app$main$store$async_emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1637$content$$,$map__56106__$1_message$jscomp$90_p__56102$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2353$timeout$$,3E3],null))]))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$28$$,$cljs$cst$3374$snapshot_already_locked$$)?($map__56106__$1_message$jscomp$90_p__56102$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.version-already-locked"),$app$main$store$async_emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1637$content$$,$map__56106__$1_message$jscomp$90_p__56102$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2353$timeout$$,3E3],null))]))):$app$main$store$async_emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$router$assign_exception$$($map__56106__$1_message$jscomp$90_p__56102$$)]))});
$potok$v2$core$handle_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$272$assertion$$,function($error$jscomp$64_temp__5825__auto__$jscomp$186$$){$error$jscomp$64_temp__5825__auto__$jscomp$186$$=$APP.$cljs$cst$3364$app_DOT_main_DOT_errors_SLASH_instance$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$64_temp__5825__auto__$jscomp$186$$);return $APP.$cljs$core$truth_$$($error$jscomp$64_temp__5825__auto__$jscomp$186$$)?($app$main$errors$flash$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$145$cause$$,
$error$jscomp$64_temp__5825__auto__$jscomp$186$$,$APP.$cljs$cst$139$type$$,$cljs$cst$3366$handled$$])),$app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($error$jscomp$64_temp__5825__auto__$jscomp$186$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,"Assertion Error"]))):null});
$potok$v2$core$handle_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$3375$worker_error$$,function($G__56110_error$jscomp$65$$){$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.internal-worker-error"),
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2353$timeout$$,3E3],null)))});$G__56110_error$jscomp$65$$=$APP.$cljs$cst$3364$app_DOT_main_DOT_errors_SLASH_instance$$.$cljs$core$IFn$_invoke$arity$1$($G__56110_error$jscomp$65$$);return $G__56110_error$jscomp$65$$==null?null:$app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__56110_error$jscomp$65$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,
"Web Worker Error"]))});
$potok$v2$core$handle_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$3376$svg_parser$$,function(){return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.svg-parser.invalid-svg"),$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2353$timeout$$,3E3],null)))})});
$potok$v2$core$handle_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$3377$comment_error$$,function(){return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1637$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.comment-error"),$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$2349$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2353$timeout$$,3E3],null)))})});$cljs$core$derive$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2665$not_found$$,$cljs$cst$3378$app_DOT_main_DOT_errors_SLASH_exceptional_state$$);$cljs$core$derive$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2248$bad_gateway$$,$cljs$cst$3378$app_DOT_main_DOT_errors_SLASH_exceptional_state$$);
$cljs$core$derive$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2247$service_unavailable$$,$cljs$cst$3378$app_DOT_main_DOT_errors_SLASH_exceptional_state$$);
$potok$v2$core$handle_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$3378$app_DOT_main_DOT_errors_SLASH_exceptional_state$$,function($error$jscomp$66$$){var $temp__5825__auto___56246$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error$jscomp$66$$,$APP.$cljs$cst$3364$app_DOT_main_DOT_errors_SLASH_instance$$);$APP.$cljs$core$truth_$$($temp__5825__auto___56246$$)&&$app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($temp__5825__auto___56246$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,"Exceptional State"]));return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$assign_exception$$($error$jscomp$66$$))})});
$potok$v2$core$handle_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2561$restriction$$,function($map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$){$map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$=$APP.$cljs$core$__destructure_map$$($map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$);var $code$jscomp$29_on_accept$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$,
$APP.$cljs$cst$273$code$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2566$migration_in_progress$$,$code$jscomp$29_on_accept$$))return $map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.migration-in-progress",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2563$feature$$.$cljs$core$IFn$_invoke$arity$1$($map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$)])),
$code$jscomp$29_on_accept$$=$APP.$cljs$core$constantly$$(null),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3379$alert$$,$APP.$cljs$cst$141$message$$,$map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$,$APP.$cljs$cst$2479$on_accept$$,$code$jscomp$29_on_accept$$],null)));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2567$team_feature_mismatch$$,
$code$jscomp$29_on_accept$$))return $map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.team-feature-mismatch",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2563$feature$$.$cljs$core$IFn$_invoke$arity$1$($map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$)])),$code$jscomp$29_on_accept$$=$APP.$cljs$core$constantly$$(null),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3379$alert$$,$APP.$cljs$cst$141$message$$,$map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$,$APP.$cljs$cst$2479$on_accept$$,$code$jscomp$29_on_accept$$],null)));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2564$file_feature_mismatch$$,$code$jscomp$29_on_accept$$))return $map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.file-feature-mismatch",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2563$feature$$.$cljs$core$IFn$_invoke$arity$1$($map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$)])),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3379$alert$$,$APP.$cljs$cst$141$message$$,$map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$,
$APP.$cljs$cst$2479$on_accept$$,$app$main$errors$redirect_to_dashboard$$],null)));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3380$feature_mismatch$$,$code$jscomp$29_on_accept$$))return $map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.feature-mismatch",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2563$feature$$.$cljs$core$IFn$_invoke$arity$1$($map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$)])),
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3379$alert$$,$APP.$cljs$cst$141$message$$,$map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$,$APP.$cljs$cst$2479$on_accept$$,$app$main$errors$redirect_to_dashboard$$],null)));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2562$feature_not_supported$$,
$code$jscomp$29_on_accept$$))return $map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.feature-not-supported",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2563$feature$$.$cljs$core$IFn$_invoke$arity$1$($map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$)])),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3379$alert$$,$APP.$cljs$cst$141$message$$,$map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$,$APP.$cljs$cst$2479$on_accept$$,$app$main$errors$redirect_to_dashboard$$],null)));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3381$file_version_not_supported$$,$code$jscomp$29_on_accept$$))return $map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.version-not-supported"),
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3379$alert$$,$APP.$cljs$cst$141$message$$,$map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$,$APP.$cljs$cst$2479$on_accept$$,$app$main$errors$redirect_to_dashboard$$],null)));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3382$max_quote_reached$$,
$code$jscomp$29_on_accept$$))return $map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.max-quota-reached",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2872$target$$.$cljs$core$IFn$_invoke$arity$1$($map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$)])),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3379$alert$$,$APP.$cljs$cst$141$message$$,$map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$],null)));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2570$paste_feature_not_enabled$$,$code$jscomp$29_on_accept$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2568$missing_features_in_paste_content$$,$code$jscomp$29_on_accept$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2569$paste_feature_not_supported$$,
$code$jscomp$29_on_accept$$))return $map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.feature-not-supported",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2563$feature$$.$cljs$core$IFn$_invoke$arity$1$($map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$)])),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3379$alert$$,$APP.$cljs$cst$141$message$$,$map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$],null)));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2565$file_in_components_v1$$,$code$jscomp$29_on_accept$$))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$3379$alert$$,$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.deprecated"),$APP.$cljs$cst$3383$link_message$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3384$before$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.deprecated.contact.before"),$APP.$cljs$cst$1588$text$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.deprecated.contact.text"),$APP.$cljs$cst$3385$after$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.deprecated.contact.after"),
$APP.$cljs$cst$3386$on_click$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2509$settings_feedback$$))}],null)],null)));$map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$=$APP.$cljs$cst$3364$app_DOT_main_DOT_errors_SLASH_instance$$.$cljs$core$IFn$_invoke$arity$1$($map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$);return $APP.$cljs$core$truth_$$($map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$)?
($app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,"Restriction Error"])),$app$main$errors$flash$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$145$cause$$,$map__56140__$1_message$jscomp$91_p__56138_temp__5825__auto__$jscomp$187$$,$APP.$cljs$cst$139$type$$,
$cljs$cst$3367$unhandled$$]))):null});
$potok$v2$core$handle_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$3387$server_error$$,function($error$jscomp$68$$){var $temp__5825__auto___56252$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error$jscomp$68$$,$APP.$cljs$cst$3364$app_DOT_main_DOT_errors_SLASH_instance$$);$APP.$cljs$core$truth_$$($temp__5825__auto___56252$$)&&$app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($temp__5825__auto___56252$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,
"Server Error"]));return $app$main$store$async_emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$router$assign_exception$$($error$jscomp$68$$)]))});
(function(){function $on_unhandled_rejection$$($event$jscomp$90_type$jscomp$436$$){$event$jscomp$90_type$jscomp$436$$.preventDefault();var $temp__5825__auto__$jscomp$189$$=$event$jscomp$90_type$jscomp$436$$.reason;if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$189$$)){if($APP.$cljs$core$truth_$$($APP.$app$main$errors$stale_asset_error_QMARK_$$($temp__5825__auto__$jscomp$189$$)))return $APP.$app$config$throttled_reload$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$984$reason$$,$APP.$cljs$core$ex_message$$($temp__5825__auto__$jscomp$189$$)]));
if($APP.$cljs$core$truth_$$($app$main$errors$from_plugin_QMARK_$$($temp__5825__auto__$jscomp$189$$)))return $app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($temp__5825__auto__$jscomp$189$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,"Plugin Error"]));if($APP.$cljs$core$truth_$$($app$main$errors$is_ignorable_exception_QMARK_$$($temp__5825__auto__$jscomp$189$$)))return null;$event$jscomp$90_type$jscomp$436$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$ex_data$$($temp__5825__auto__$jscomp$189$$),
$APP.$cljs$cst$139$type$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2972$wasm_error$$,$event$jscomp$90_type$jscomp$436$$))return $APP.$app$main$errors$on_error$$($temp__5825__auto__$jscomp$189$$);$app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($temp__5825__auto__$jscomp$189$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,"Uncaught Rejection"]));return $APP.$app$util$timers$asap$$(function(){return $app$main$errors$flash$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$145$cause$$,
$temp__5825__auto__$jscomp$189$$,$APP.$cljs$cst$139$type$$,$cljs$cst$3367$unhandled$$]))})}return null}function $on_unhandled_error$$($event$jscomp$89_type$jscomp$435$$){$event$jscomp$89_type$jscomp$435$$.preventDefault();var $temp__5825__auto__$jscomp$188$$=$event$jscomp$89_type$jscomp$435$$.error;if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$188$$)){if($APP.$cljs$core$truth_$$($APP.$app$main$errors$stale_asset_error_QMARK_$$($temp__5825__auto__$jscomp$188$$)))return $APP.$app$config$throttled_reload$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$984$reason$$,
$APP.$cljs$core$ex_message$$($temp__5825__auto__$jscomp$188$$)]));if($APP.$cljs$core$truth_$$($app$main$errors$from_plugin_QMARK_$$($temp__5825__auto__$jscomp$188$$)))return $app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($temp__5825__auto__$jscomp$188$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,"Plugin Error"]));if($APP.$cljs$core$truth_$$($app$main$errors$is_ignorable_exception_QMARK_$$($temp__5825__auto__$jscomp$188$$)))return null;
$event$jscomp$89_type$jscomp$435$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$ex_data$$($temp__5825__auto__$jscomp$188$$),$APP.$cljs$cst$139$type$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2972$wasm_error$$,$event$jscomp$89_type$jscomp$435$$))return $APP.$app$main$errors$on_error$$($temp__5825__auto__$jscomp$188$$);$app$common$exceptions$print_throwable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($temp__5825__auto__$jscomp$188$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$971$prefix$$,
"Uncaught Exception"]));return $APP.$app$util$timers$asap$$(function(){return $app$main$errors$flash$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$145$cause$$,$temp__5825__auto__$jscomp$188$$,$APP.$cljs$cst$139$type$$,$cljs$cst$3367$unhandled$$]))})}return null}$APP.$app$util$globals$window$$.addEventListener("error",$on_unhandled_error$$);$APP.$app$util$globals$window$$.addEventListener("unhandledrejection",$on_unhandled_rejection$$);
return function(){$APP.$app$util$globals$window$$.removeEventListener("error",$on_unhandled_error$$);return $APP.$app$util$globals$window$$.removeEventListener("unhandledrejection",$on_unhandled_rejection$$)}})();var $app$plugins$flags$reset_55464$$;var $app$main$data$plugins$save_plugin_permissions_peek_66063$$,$app$main$data$plugins$save_current_plugin_66070$$,$app$main$data$plugins$remove_current_plugin_66120$$,$app$main$data$plugins$close_current_plugin_66232$$,$app$main$data$plugins$check_open_plugin_66285$$;var $app$main$data$comments$created_thread_on_workspace_55705$$,$app$main$data$comments$create_thread_on_workspace_55739$$,$app$main$data$comments$update_comment_thread_status_55895$$,$app$main$data$comments$update_comment_thread_55920$$,$app$main$data$comments$create_comment_55943$$,$app$main$data$comments$update_comment_55957$$,$app$main$data$comments$delete_comment_thread_on_workspace_55971$$,$app$main$data$comments$delete_comment_thread_on_viewer_55976$$,$app$main$data$comments$delete_comment_55982$$,
$app$main$data$comments$refresh_comment_thread_55988$$,$app$main$data$comments$comment_threads_fetched_55996$$,$app$main$data$comments$retrieve_comment_threads_56001$$,$app$main$data$comments$retrieve_comments_56006$$,$app$main$data$comments$retrieve_unread_comment_threads_56024$$,$app$main$data$comments$mark_all_threads_as_read_56027$$,$app$main$data$comments$open_comment_thread_56043$$,$app$main$data$comments$close_comment_thread_56051$$,$app$main$data$comments$update_filters_56062$$,$app$main$data$comments$update_options_56074$$,
$app$main$data$comments$create_draft_56086$$,$app$main$data$comments$update_draft_thread_56092$$,$app$main$data$comments$toggle_comment_options_56099$$,$app$main$data$comments$hide_comment_options_56107$$,$app$main$data$comments$update_comment_thread_frame_56160$$,$app$main$data$comments$detach_comment_thread_56173$$,$app$main$data$comments$fetch_profiles_56183$$,$app$main$data$comments$schema_COLON_comment$$=new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Comment"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3430$thread_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3324$owner_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3422$owner_fullname$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3423$owner_email$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1569$created_at$$,
$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1737$modified_at$$,$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$198$string$$],null)],null);
$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,19,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"CommentThread"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2043$page_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2181$project_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3324$owner_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3422$owner_fullname$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$3423$owner_email$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3424$page_name$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3425$file_name$$,$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3426$seqn$$,$cljs$cst$344$int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3427$participants$$,$cljs$cst$955$app_DOT_common_DOT_schema_SLASH_set_of_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1569$created_at$$,$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1737$modified_at$$,$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,$cljs$cst$1518$app_DOT_common_DOT_geom_DOT_point_SLASH_point$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3428$count_unread_comments$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$344$int$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$3429$count_comments$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$344$int$$],null)],null));$app$common$schema$check_fn$$($app$main$data$comments$schema_COLON_comment$$);
var $app$main$data$comments$r_mentions$$=/@\[([^\]]*)\]\(([^\)]*)\)/,$app$main$data$comments$update_comment_thread_frame$$=function $app$main$data$comments$update_comment_thread_frame$$($var_args$jscomp$1181$$){switch(arguments.length){case 1:return $app$main$data$comments$update_comment_thread_frame$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$data$comments$update_comment_thread_frame$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$data$comments$update_comment_thread_frame$$.$cljs$core$IFn$_invoke$arity$1$=function($thread$jscomp$20$$){return $app$main$data$comments$update_comment_thread_frame$$.$cljs$core$IFn$_invoke$arity$2$($thread$jscomp$20$$,$APP.$app$common$uuid$zero$$)};
$app$main$data$comments$update_comment_thread_frame$$.$cljs$core$IFn$_invoke$arity$2$=function($thread$jscomp$21$$,$frame_id$jscomp$37$$){typeof $app$main$data$comments$update_comment_thread_frame_56160$$==="undefined"&&($app$main$data$comments$update_comment_thread_frame_56160$$=function($thread$jscomp$22$$,$frame_id$jscomp$38$$,$meta56161$$){this.thread=$thread$jscomp$22$$;this.$frame_id$=$frame_id$jscomp$38$$;this.$meta56161$=$meta56161$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$comments$update_comment_thread_frame_56160$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_comment_thread_frame_56160$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3480$app_DOT_main_DOT_data_DOT_comments_SLASH_update_comment_thread_frame$$},$app$main$data$comments$update_comment_thread_frame_56160$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56162$$,$meta56161__$1$$){return new $app$main$data$comments$update_comment_thread_frame_56160$$(this.thread,
this.$frame_id$,$meta56161__$1$$)},$app$main$data$comments$update_comment_thread_frame_56160$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56161$},$app$main$data$comments$update_comment_thread_frame_56160$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_comment_thread_frame_56160$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1836_thread_id$jscomp$8$$,$state$jscomp$283$$){$_$jscomp$1836_thread_id$jscomp$8$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.thread);return $APP.$cljs$core$assoc_in$$($state$jscomp$283$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2175$comment_threads$$,$_$jscomp$1836_thread_id$jscomp$8$$,$APP.$cljs$cst$1607$frame_id$$],null),this.$frame_id$)},$app$main$data$comments$update_comment_thread_frame_56160$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$update_comment_thread_frame_56160$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $thread_id$jscomp$9$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.thread);return $APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3377$comment_error$$,$APP.$cljs$cst$273$code$$,$cljs$cst$3481$update_comment_thread_frame$$],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3481$update_comment_thread_frame$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$thread_id$jscomp$9$$,$APP.$cljs$cst$1607$frame_id$$,this.$frame_id$],null))))});return new $app$main$data$comments$update_comment_thread_frame_56160$$($thread$jscomp$21$$,$frame_id$jscomp$37$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$comments$update_comment_thread_frame$$.$cljs$lang$maxFixedArity$=2;$APP.$shadow$js$shim$module$0opentype$$=shadow$bridge("opentype.js");var $app$main$data$fonts$fonts_loaded_55734$$,$app$main$data$fonts$fetch_fonts_55742$$;var $app$main$data$project$project_fetched_55747$$,$app$main$data$project$fetch_project_55771$$,$app$main$data$project$initialize_project_55788$$;$APP.$app$common$logging$loggers$$.set("app.main.data.project",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));var $app$common$logic$shapes$text_typography_style_attrs$$=$APP.$cljs$core$set$$($app$common$types$text$text_typography_attrs$$);$APP.$app$common$logging$loggers$$.set("app.common.logic.libraries",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));
var $app$common$logic$libraries$updatable_attrs$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66045_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1696$layout_grid_cells$$,$p1__66045_SHARP_$$)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$swap_keep_attrs$$,$APP.$cljs$core$keys$$($app$common$types$component$sync_attrs$$))),$app$common$logic$libraries$generate_detach_recursive$$=function $app$common$logic$libraries$generate_detach_recursive$$($G__66204__$1_G__66204__$2_changes$jscomp$105$$,
$container$jscomp$40$$,$libraries$jscomp$39$$,$shape_id$jscomp$66$$,$children_ids$jscomp$6_first$jscomp$13$$,$component_root_QMARK_$$){var $G__66215_shape$jscomp$410$$=$APP.$app$common$types$container$get_shape$$($container$jscomp$40$$,$shape_id$jscomp$66$$);$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($shape_id$jscomp$66$$,$container$jscomp$40$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"  Processing"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2543$shape_id$$,$shape_id$jscomp$66$$],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);if($APP.$app$common$types$component$instance_head_QMARK_$$($G__66215_shape$jscomp$410$$)&&
$APP.$cljs$core$not$$($children_ids$jscomp$6_first$jscomp$13$$))return $G__66204__$1_G__66204__$2_changes$jscomp$105$$=$APP.$cljs$core$truth_$$($component_root_QMARK_$$)?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66204__$1_G__66204__$2_changes$jscomp$105$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$66$$],null),function($p1__66189_SHARP_$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",
$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"  -\x3e promote to root"],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__66189_SHARP_$$,
$APP.$cljs$cst$2044$component_root$$,!0)}):$G__66204__$1_G__66204__$2_changes$jscomp$105$$,$G__66204__$1_G__66204__$2_changes$jscomp$105$$=$APP.$app$common$types$component$get_swap_slot$$($G__66215_shape$jscomp$410$$)!=null?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66204__$1_G__66204__$2_changes$jscomp$105$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$66$$],null),function($p1__66190_SHARP_$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",
$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"  -\x3e remove swap-slot"],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);return $app$common$types$component$remove_swap_slot$$($p1__66190_SHARP_$$)}):
$G__66204__$1_G__66204__$2_changes$jscomp$105$$,$APP.$app$common$types$component$get_swap_slot$$($G__66215_shape$jscomp$410$$)==null?($G__66215_shape$jscomp$410$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__66215_shape$jscomp$410$$),$app$common$logic$libraries$generate_advance_nesting_level$$.$cljs$core$IFn$_invoke$arity$5$?$app$common$logic$libraries$generate_advance_nesting_level$$.$cljs$core$IFn$_invoke$arity$5$($G__66204__$1_G__66204__$2_changes$jscomp$105$$,null,$container$jscomp$40$$,
$libraries$jscomp$39$$,$G__66215_shape$jscomp$410$$):$app$common$logic$libraries$generate_advance_nesting_level$$($G__66204__$1_G__66204__$2_changes$jscomp$105$$,null,$container$jscomp$40$$,$libraries$jscomp$39$$,$G__66215_shape$jscomp$410$$)):$G__66204__$1_G__66204__$2_changes$jscomp$105$$;$children_ids$jscomp$6_first$jscomp$13$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($G__66215_shape$jscomp$410$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&
$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"  -\x3e detach"],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__66191_SHARP_$$,$p2__66192_SHARP_$$){return $app$common$logic$libraries$generate_detach_recursive$$.$cljs$core$IFn$_invoke$arity$6$?
$app$common$logic$libraries$generate_detach_recursive$$.$cljs$core$IFn$_invoke$arity$6$($p1__66191_SHARP_$$,$container$jscomp$40$$,$libraries$jscomp$39$$,$p2__66192_SHARP_$$,!1,$component_root_QMARK_$$):$app$common$logic$libraries$generate_detach_recursive$$($p1__66191_SHARP_$$,$container$jscomp$40$$,$libraries$jscomp$39$$,$p2__66192_SHARP_$$,!1,$component_root_QMARK_$$)},$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($G__66204__$1_G__66204__$2_changes$jscomp$105$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__66215_shape$jscomp$410$$)],null),$app$common$types$component$detach_shape$$),$children_ids$jscomp$6_first$jscomp$13$$)},$app$common$logic$libraries$uses_assets_QMARK_$$=function(){var $method_table__5622__auto__$jscomp$19$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$19$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$19$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$19$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.common.logic.libraries","uses-assets?"),function($asset_type$jscomp$6$$){return $asset_type$jscomp$6$$},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$19$$,$method_table__5622__auto__$jscomp$19$$,
$prefer_table__5623__auto__$jscomp$19$$,$method_cache__5624__auto__$jscomp$19$$,$cached_hierarchy__5625__auto__$jscomp$19$$)}();
$app$common$logic$libraries$uses_assets_QMARK_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$1638$components$$,function($_$jscomp$1866$$,$component_id$jscomp$42$$,$shape$jscomp$413$$,$library_id$jscomp$24$$){return $component_id$jscomp$42$$==null?$app$common$types$component$uses_library_components_QMARK_$$($shape$jscomp$413$$,$library_id$jscomp$24$$):$app$common$types$component$instance_of_QMARK_$$($shape$jscomp$413$$,$library_id$jscomp$24$$,$component_id$jscomp$42$$)});
$app$common$logic$libraries$uses_assets_QMARK_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2212$colors$$,function($_$jscomp$1867$$,$color_id$jscomp$5$$,$shape$jscomp$414$$,$library_id$jscomp$25$$){return $color_id$jscomp$5$$==null?$app$common$types$shape$uses_library_colors_QMARK_$$($shape$jscomp$414$$,$library_id$jscomp$25$$):$app$common$types$shape$uses_library_color_QMARK_$$($shape$jscomp$414$$,$library_id$jscomp$25$$,$color_id$jscomp$5$$)});
$app$common$logic$libraries$uses_assets_QMARK_$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2215$typographies$$,function($_$jscomp$1868$$,$typography_id$jscomp$5$$,$shape$jscomp$415$$,$library_id$jscomp$26$$){return $typography_id$jscomp$5$$==null?$app$common$types$typography$uses_library_typographies_QMARK_$$($shape$jscomp$415$$,$library_id$jscomp$26$$):$app$common$types$typography$uses_library_typography_QMARK_$$($shape$jscomp$415$$,$library_id$jscomp$26$$,$typography_id$jscomp$5$$)});
var $app$common$logic$libraries$generate_sync_shape$$=function(){var $method_table__5622__auto__$jscomp$20$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$20$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$20$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$20$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.common.logic.libraries",
"generate-sync-shape"),function($asset_type$jscomp$7$$){return $asset_type$jscomp$7$$},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$20$$,$method_table__5622__auto__$jscomp$20$$,$prefer_table__5623__auto__$jscomp$20$$,$method_cache__5624__auto__$jscomp$20$$,$cached_hierarchy__5625__auto__$jscomp$20$$)}();
$app$common$logic$libraries$generate_sync_shape$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$1638$components$$,function($_$jscomp$1869_shape_id$jscomp$69$$,$changes$jscomp$113$$,$_library_id$jscomp$1$$,$container$jscomp$45$$,$shape$jscomp$416$$,$libraries$jscomp$44$$,$current_file_id$jscomp$4_file$jscomp$50$$){$_$jscomp$1869_shape_id$jscomp$69$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$416$$);$current_file_id$jscomp$4_file$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$44$$,
$current_file_id$jscomp$4_file$jscomp$50$$);return $APP.$app$common$logic$libraries$generate_sync_shape_direct$$.$cljs$core$IFn$_invoke$arity$6$?$APP.$app$common$logic$libraries$generate_sync_shape_direct$$.$cljs$core$IFn$_invoke$arity$6$($changes$jscomp$113$$,$current_file_id$jscomp$4_file$jscomp$50$$,$libraries$jscomp$44$$,$container$jscomp$45$$,$_$jscomp$1869_shape_id$jscomp$69$$,!1):$APP.$app$common$logic$libraries$generate_sync_shape_direct$$($changes$jscomp$113$$,$current_file_id$jscomp$4_file$jscomp$50$$,
$libraries$jscomp$44$$,$container$jscomp$45$$,$_$jscomp$1869_shape_id$jscomp$69$$,!1)});
$app$common$logic$libraries$generate_sync_shape$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2212$colors$$,function($_$jscomp$1870$$,$changes$jscomp$114$$,$library_id$jscomp$27$$,$___$1$jscomp$1182$$,$shape$jscomp$417$$,$libraries$jscomp$45$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$417$$),null)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$)&&
$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Sync colors of shape"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$417$$)],
null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$,!1);var $library_colors$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$45$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$library_id$jscomp$27$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2212$colors$$],null));return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$114$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$417$$)],null),function($p1__66349_SHARP_$$){return $app$common$types$library$sync_colors$$($p1__66349_SHARP_$$,$library_id$jscomp$27$$,$library_colors$jscomp$1$$)})});
$app$common$logic$libraries$generate_sync_shape$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$2215$typographies$$,function($_$jscomp$1871$$,$changes$jscomp$115$$,$library_id$jscomp$28$$,$container$jscomp$46$$,$shape$jscomp$418$$,$libraries$jscomp$46$$){function $update_node$$($node$jscomp$298$$){var $temp__5823__auto__$jscomp$166$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($typographies$$,$APP.$cljs$cst$1756$typography_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$298$$));
return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$166$$)?$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$node$jscomp$298$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($temp__5823__auto__$jscomp$166$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$]))])):$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($node$jscomp$298$$,
$APP.$cljs$cst$1756$typography_ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1642$typography_ref_file$$]))}$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$418$$),null)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Sync typographies of shape"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1811$shape$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$418$$)],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$,!1);var $typographies$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$46$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$library_id$jscomp$28$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2215$typographies$$],null));return $app$common$logic$libraries$generate_sync_text_shape$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$logic$libraries$generate_sync_text_shape$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$115$$,$shape$jscomp$418$$,$container$jscomp$46$$,
$update_node$$):$app$common$logic$libraries$generate_sync_text_shape$$($changes$jscomp$115$$,$shape$jscomp$418$$,$container$jscomp$46$$,$update_node$$)});
var $app$common$logic$libraries$generate_sync_shape_direct_recursive$$=function $app$common$logic$libraries$generate_sync_shape_direct_recursive$$($changes$jscomp$118$$,$container$jscomp$50$$,$shape_inst$jscomp$5$$,$component$jscomp$66$$,$library$jscomp$19$$,$file$jscomp$53$$,$libraries$jscomp$49$$,$shape_main$jscomp$5$$,$root_inst$jscomp$1$$,$root_main$jscomp$1$$,$reset_QMARK_$jscomp$1$$,$initial_root_QMARK_$jscomp$1$$){function $moved$$($changes__$2$jscomp$12$$,$child_inst$jscomp$3$$,$child_main$jscomp$3$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$3$$),
$container$jscomp$50$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Move"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3536$child_inst$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$3$$))," ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$3$$))].join("")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3538$child_main$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($child_main$jscomp$3$$)),
" ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_main$jscomp$3$$))].join("")],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);var $G__66474$$=$APP.$app$common$data$index_of$$($children_inst$$,$child_inst$jscomp$3$$),$G__66475$$=$APP.$app$common$data$index_of$$($children_main$$,$child_main$jscomp$3$$);return $APP.$app$common$logic$libraries$move_shape$$.$cljs$core$IFn$_invoke$arity$6$?$APP.$app$common$logic$libraries$move_shape$$.$cljs$core$IFn$_invoke$arity$6$($changes__$2$jscomp$12$$,
$child_inst$jscomp$3$$,$G__66474$$,$G__66475$$,$container$jscomp$50$$,$omit_touched_QMARK_$jscomp$1$$):$APP.$app$common$logic$libraries$move_shape$$($changes__$2$jscomp$12$$,$child_inst$jscomp$3$$,$G__66474$$,$G__66475$$,$container$jscomp$50$$,$omit_touched_QMARK_$jscomp$1$$)}function $swapped$$($changes__$2$jscomp$11$$,$child_inst$jscomp$2$$,$child_main$jscomp$2$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$2$$),
$container$jscomp$50$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Match slot"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3536$child_inst$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$2$$))," ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$2$$))].join("")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3538$child_main$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($child_main$jscomp$2$$)),
" ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_main$jscomp$2$$))].join("")],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);return $changes__$2$jscomp$11$$}function $both$$($changes__$2$jscomp$10$$,$child_inst$jscomp$1$$,$child_main$jscomp$1$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$1$$),$container$jscomp$50$$)&&
$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Both"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3536$child_inst$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$1$$))," ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$1$$))].join("")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3538$child_main$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($child_main$jscomp$1$$)),
" ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_main$jscomp$1$$))].join("")],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);return $app$common$logic$libraries$generate_sync_shape_direct_recursive$$.$cljs$core$IFn$_invoke$arity$12$?$app$common$logic$libraries$generate_sync_shape_direct_recursive$$.$cljs$core$IFn$_invoke$arity$12$($changes__$2$jscomp$10$$,$container$jscomp$50$$,$child_inst$jscomp$1$$,
$component$jscomp$66$$,$library$jscomp$19$$,$file$jscomp$53$$,$libraries$jscomp$49$$,$child_main$jscomp$1$$,$root_inst$jscomp$1$$,$root_main$jscomp$1$$,$reset_QMARK_$jscomp$1$$,$initial_root_QMARK_$jscomp$1$$):$app$common$logic$libraries$generate_sync_shape_direct_recursive$$($changes__$2$jscomp$10$$,$container$jscomp$50$$,$child_inst$jscomp$1$$,$component$jscomp$66$$,$library$jscomp$19$$,$file$jscomp$53$$,$libraries$jscomp$49$$,$child_main$jscomp$1$$,$root_inst$jscomp$1$$,$root_main$jscomp$1$$,$reset_QMARK_$jscomp$1$$,
$initial_root_QMARK_$jscomp$1$$)}function $only_main$$($changes__$2$jscomp$9$$,$child_main$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_main$$),$component_container$jscomp$1$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Only main"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3538$child_main$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($child_main$$))," ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_main$$))].join("")],
null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);if($omit_touched_QMARK_$jscomp$1$$&&$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$5$$),$cljs$cst$3537$shapes_group$$))return $changes__$2$jscomp$9$$;var $G__66448$$=$APP.$app$common$data$index_of$$($children_main$$,$child_main$$);return $app$common$logic$libraries$add_shape_to_instance$$.$cljs$core$IFn$_invoke$arity$9$?$app$common$logic$libraries$add_shape_to_instance$$.$cljs$core$IFn$_invoke$arity$9$($changes__$2$jscomp$9$$,
$child_main$$,$G__66448$$,$component_container$jscomp$1$$,$container$jscomp$50$$,$root_inst$jscomp$1$$,$root_main$jscomp$1$$,$omit_touched_QMARK_$jscomp$1$$,$set_remote_synced_QMARK_$$):$app$common$logic$libraries$add_shape_to_instance$$($changes__$2$jscomp$9$$,$child_main$$,$G__66448$$,$component_container$jscomp$1$$,$container$jscomp$50$$,$root_inst$jscomp$1$$,$root_main$jscomp$1$$,$omit_touched_QMARK_$jscomp$1$$,$set_remote_synced_QMARK_$$)}function $only_inst$$($changes__$2$jscomp$8$$,$child_inst$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$$),
$container$jscomp$50$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Only inst"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3536$child_inst$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$$))," ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$$))].join("")],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);return $omit_touched_QMARK_$jscomp$1$$&&$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$1626$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$5$$),
$cljs$cst$3537$shapes_group$$)?$changes__$2$jscomp$8$$:$APP.$app$common$logic$libraries$remove_shape$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$common$logic$libraries$remove_shape$$.$cljs$core$IFn$_invoke$arity$4$($changes__$2$jscomp$8$$,$child_inst$$,$container$jscomp$50$$,$omit_touched_QMARK_$jscomp$1$$):$APP.$app$common$logic$libraries$remove_shape$$($changes__$2$jscomp$8$$,$child_inst$$,$container$jscomp$50$$,$omit_touched_QMARK_$jscomp$1$$)}$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$5$$),
$container$jscomp$50$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1546$msg$$,"Sync shape direct recursive"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3533$shape_inst$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$5$$))," ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$5$$))].join("")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1625$component$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$66$$)],
null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$,!1);if($shape_main$jscomp$5$$==null)return $changes$jscomp$118$$;var $omit_touched_QMARK_$jscomp$1$$=$APP.$cljs$core$not$$($reset_QMARK_$jscomp$1$$),$clear_remote_synced_QMARK_$$=$APP.$cljs$core$truth_$$($initial_root_QMARK_$jscomp$1$$)?$reset_QMARK_$jscomp$1$$:$initial_root_QMARK_$jscomp$1$$,$set_remote_synced_QMARK_$$=function(){var $and__5023__auto__$jscomp$378$$=$APP.$cljs$core$not$$($initial_root_QMARK_$jscomp$1$$);
return $and__5023__auto__$jscomp$378$$?$reset_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$378$$}(),$changes__$1$jscomp$26$$=function(){var $G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$=$APP.$app$common$logic$libraries$update_attrs$$.$cljs$core$IFn$_invoke$arity$7$?$APP.$app$common$logic$libraries$update_attrs$$.$cljs$core$IFn$_invoke$arity$7$($changes$jscomp$118$$,$shape_inst$jscomp$5$$,$shape_main$jscomp$5$$,$root_inst$jscomp$1$$,$root_main$jscomp$1$$,$container$jscomp$50$$,
$omit_touched_QMARK_$jscomp$1$$):$APP.$app$common$logic$libraries$update_attrs$$($changes$jscomp$118$$,$shape_inst$jscomp$5$$,$shape_main$jscomp$5$$,$root_inst$jscomp$1$$,$root_main$jscomp$1$$,$container$jscomp$50$$,$omit_touched_QMARK_$jscomp$1$$);$G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape_main$jscomp$5$$)?$app$common$logic$libraries$update_flex_child_copy_attrs$$.$cljs$core$IFn$_invoke$arity$7$?
$app$common$logic$libraries$update_flex_child_copy_attrs$$.$cljs$core$IFn$_invoke$arity$7$($G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$,$shape_main$jscomp$5$$,$shape_inst$jscomp$5$$,$library$jscomp$19$$,$component$jscomp$66$$,$container$jscomp$50$$,$omit_touched_QMARK_$jscomp$1$$):$app$common$logic$libraries$update_flex_child_copy_attrs$$($G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$,$shape_main$jscomp$5$$,$shape_inst$jscomp$5$$,
$library$jscomp$19$$,$component$jscomp$66$$,$container$jscomp$50$$,$omit_touched_QMARK_$jscomp$1$$):$G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$;if($APP.$cljs$core$truth_$$($reset_QMARK_$jscomp$1$$)){var $G__66412$jscomp$inline_6306$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3535$reset_touched_QMARK_$$,!0],null);$G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$=$APP.$app$common$logic$libraries$change_touched$$.$cljs$core$IFn$_invoke$arity$5$?
$APP.$app$common$logic$libraries$change_touched$$.$cljs$core$IFn$_invoke$arity$5$($G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$,$shape_inst$jscomp$5$$,$shape_main$jscomp$5$$,$container$jscomp$50$$,$G__66412$jscomp$inline_6306$$):$APP.$app$common$logic$libraries$change_touched$$($G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$,$shape_inst$jscomp$5$$,$shape_main$jscomp$5$$,$container$jscomp$50$$,$G__66412$jscomp$inline_6306$$)}$G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$=
$APP.$cljs$core$truth_$$($clear_remote_synced_QMARK_$$)?$APP.$app$common$logic$libraries$change_remote_synced$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$common$logic$libraries$change_remote_synced$$.$cljs$core$IFn$_invoke$arity$4$($G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$,$shape_inst$jscomp$5$$,$container$jscomp$50$$,null):$APP.$app$common$logic$libraries$change_remote_synced$$($G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$,
$shape_inst$jscomp$5$$,$container$jscomp$50$$,null):$G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$;return $APP.$cljs$core$truth_$$($set_remote_synced_QMARK_$$)?$APP.$app$common$logic$libraries$change_remote_synced$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$common$logic$libraries$change_remote_synced$$.$cljs$core$IFn$_invoke$arity$4$($G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$,$shape_inst$jscomp$5$$,$container$jscomp$50$$,
!0):$APP.$app$common$logic$libraries$change_remote_synced$$($G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$,$shape_inst$jscomp$5$$,$container$jscomp$50$$,!0):$G__66406__$1_G__66406__$2_G__66406__$3_G__66406__$4_JSCompiler_temp$jscomp$1097$$}(),$component_container$jscomp$1$$=$app$common$logic$libraries$find_main_container$$($container$jscomp$50$$,$shape_inst$jscomp$5$$,$shape_main$jscomp$5$$,$library$jscomp$19$$,$file$jscomp$53$$,$libraries$jscomp$49$$,$component$jscomp$66$$),
$children_inst$$=$APP.$cljs$core$vec$$($app$common$types$container$get_direct_children$$($container$jscomp$50$$,$shape_inst$jscomp$5$$)),$children_main$$=$APP.$cljs$core$vec$$($app$common$types$container$get_direct_children$$($component_container$jscomp$1$$,$shape_main$jscomp$5$$)),$changes__$2$jscomp$7$$=$APP.$app$common$logic$libraries$compare_children$$.$cljs$core$IFn$_invoke$arity$15$?$APP.$app$common$logic$libraries$compare_children$$.$cljs$core$IFn$_invoke$arity$15$($changes__$1$jscomp$26$$,
$shape_inst$jscomp$5$$,$children_inst$$,$children_main$$,$container$jscomp$50$$,$component_container$jscomp$1$$,$file$jscomp$53$$,$libraries$jscomp$49$$,$only_inst$$,$only_main$$,$both$$,$swapped$$,$moved$$,!1,$reset_QMARK_$jscomp$1$$):$APP.$app$common$logic$libraries$compare_children$$($changes__$1$jscomp$26$$,$shape_inst$jscomp$5$$,$children_inst$$,$children_main$$,$container$jscomp$50$$,$component_container$jscomp$1$$,$file$jscomp$53$$,$libraries$jscomp$49$$,$only_inst$$,$only_main$$,$both$$,$swapped$$,
$moved$$,!1,$reset_QMARK_$jscomp$1$$);return function(){if($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$5$$)){var $G__66483$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$5$$);return $app$common$logic$libraries$update_grid_copy_attrs$$.$cljs$core$IFn$_invoke$arity$6$?$app$common$logic$libraries$update_grid_copy_attrs$$.$cljs$core$IFn$_invoke$arity$6$($changes__$2$jscomp$7$$,$G__66483$$,$shape_main$jscomp$5$$,
$library$jscomp$19$$,$component$jscomp$66$$,$omit_touched_QMARK_$jscomp$1$$):$app$common$logic$libraries$update_grid_copy_attrs$$($changes__$2$jscomp$7$$,$G__66483$$,$shape_main$jscomp$5$$,$library$jscomp$19$$,$component$jscomp$66$$,$omit_touched_QMARK_$jscomp$1$$)}return $changes__$2$jscomp$7$$}()};var $app$main$data$workspace$collapse$expand_all_parents_56078$$,$app$main$data$workspace$collapse$toggle_collapse_56089$$,$app$main$data$workspace$collapse$expand_collapse_56095$$,$app$main$data$workspace$collapse$collapse_all_56103$$,$app$main$data$workspace$collapse$expand_subtree_56111$$;var $app$main$data$workspace$path$common$finish_path_66050$$;var $app$main$data$workspace$edition$start_edition_mode_66094$$,$app$main$data$workspace$edition$clear_edition_mode_66133$$;var $app$main$data$workspace$undo$materialize_undo_66059$$,$app$main$data$workspace$undo$append_undo_66100$$,$app$main$data$workspace$undo$start_undo_transaction_66130$$,$app$main$data$workspace$undo$commit_undo_transaction_66180$$,$app$main$data$workspace$undo$reset_undo_66194$$,$app$main$data$workspace$undo$check_open_transactions_66216$$,$app$main$data$workspace$undo$restore_selection_66241$$,$app$main$data$workspace$undo$undo_to_index_66254$$,$app$main$data$workspace$undo$undo_66274$$,$app$main$data$workspace$undo$redo_66308$$,
$app$main$data$workspace$undo$assure_valid_current_page_66340$$,$app$main$data$workspace$undo$empty_tx$$;$APP.$app$common$logging$loggers$$.set("app.main.data.workspace.undo",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));
$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"undo-entry"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3137$undo_changes$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$app$common$files$changes$schema_COLON_change$$],
null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3133$redo_changes$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$app$common$files$changes$schema_COLON_change$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3138$undo_group$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3142$tags$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$221$keyword$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3144$selected_before$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3561$selected_after$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,
[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],null)],null));
$app$main$data$workspace$undo$empty_tx$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$3133$redo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null);
typeof $app$main$data$workspace$undo$reset_undo_66194$$==="undefined"&&($app$main$data$workspace$undo$reset_undo_66194$$=function($meta66195$jscomp$inline_6372$$){this.$meta66195$=$meta66195$jscomp$inline_6372$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$undo$reset_undo_66194$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3570$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_reset_undo$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66196$jscomp$inline_6373$$,$meta66195__$1$jscomp$inline_6374$$){return new $app$main$data$workspace$undo$reset_undo_66194$$($meta66195__$1$jscomp$inline_6374$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66195$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_6375$$,$state$jscomp$inline_6376$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$inline_6376$$,$APP.$cljs$cst$3563$workspace_undo$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)});$APP.$app$main$data$workspace$undo$reinitialize_undo$$=new $app$main$data$workspace$undo$reset_undo_66194$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
typeof $app$main$data$workspace$undo$undo_66274$$==="undefined"&&($app$main$data$workspace$undo$undo_66274$$=function($meta66275$jscomp$inline_6380$$){this.$meta66275$=$meta66275$jscomp$inline_6380$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$undo$undo_66274$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3574$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_undo$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66276$jscomp$inline_6381$$,$meta66275__$1$jscomp$inline_6382$$){return new $app$main$data$workspace$undo$undo_66274$$($meta66275__$1$jscomp$inline_6382$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66275$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function($first_item$jscomp$inline_6396_index$jscomp$inline_6390_it$jscomp$inline_6383$$,$item$jscomp$inline_6391_state$jscomp$inline_6384$$){var $objects$jscomp$inline_6385$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$inline_6391_state$jscomp$inline_6384$$),$edition$jscomp$inline_6386$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$inline_6391_state$jscomp$inline_6384$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2199$edition$$],null)),$drawing$jscomp$inline_6387$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$inline_6391_state$jscomp$inline_6384$$,$APP.$cljs$cst$2189$workspace_drawing$$);if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$inline_6397$$=$edition$jscomp$inline_6386$$==null&&$APP.$cljs$cst$2198$object$$.$cljs$core$IFn$_invoke$arity$1$($drawing$jscomp$inline_6387$$)==
null;return $or__5025__auto__$jscomp$inline_6397$$?$or__5025__auto__$jscomp$inline_6397$$:$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_6385$$,$edition$jscomp$inline_6386$$)}())){var $undo$jscomp$inline_6388$$=$APP.$cljs$cst$3563$workspace_undo$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$inline_6391_state$jscomp$inline_6384$$),$items$jscomp$inline_6389$$=$APP.$cljs$cst$1838$items$$.$cljs$core$IFn$_invoke$arity$1$($undo$jscomp$inline_6388$$);
$first_item$jscomp$inline_6396_index$jscomp$inline_6390_it$jscomp$inline_6383$$=function(){var $or__5025__auto__$jscomp$inline_6398$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($undo$jscomp$inline_6388$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_6398$$)?$or__5025__auto__$jscomp$inline_6398$$:$APP.$cljs$core$count$$($items$jscomp$inline_6389$$)-1}();if($APP.$cljs$core$empty_QMARK_$$($items$jscomp$inline_6389$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($first_item$jscomp$inline_6396_index$jscomp$inline_6390_it$jscomp$inline_6383$$,
-1))return null;$item$jscomp$inline_6391_state$jscomp$inline_6384$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$inline_6389$$,$first_item$jscomp$inline_6396_index$jscomp$inline_6390_it$jscomp$inline_6383$$);var $changes$jscomp$inline_6392$$=$APP.$cljs$cst$3137$undo_changes$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$inline_6391_state$jscomp$inline_6384$$),$undo_group$jscomp$inline_6393$$=$APP.$cljs$cst$3138$undo_group$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$inline_6391_state$jscomp$inline_6384$$),
$find_first_group_idx$jscomp$inline_6394_undo_group_index$jscomp$inline_6395$$=function($index__$1$jscomp$inline_6399$$){for(;;)if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$inline_6389$$,$index__$1$jscomp$inline_6399$$),$APP.$cljs$cst$3138$undo_group$$),$undo_group$jscomp$inline_6393$$))--$index__$1$jscomp$inline_6399$$;else return $index__$1$jscomp$inline_6399$$+
1};$find_first_group_idx$jscomp$inline_6394_undo_group_index$jscomp$inline_6395$$=$APP.$cljs$core$truth_$$($undo_group$jscomp$inline_6393$$)?$find_first_group_idx$jscomp$inline_6394_undo_group_index$jscomp$inline_6395$$($first_item$jscomp$inline_6396_index$jscomp$inline_6390_it$jscomp$inline_6383$$):null;return $APP.$cljs$core$truth_$$($undo_group$jscomp$inline_6393$$)?($first_item$jscomp$inline_6396_index$jscomp$inline_6390_it$jscomp$inline_6383$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$inline_6389$$,
$find_first_group_idx$jscomp$inline_6394_undo_group_index$jscomp$inline_6395$$),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$undo_to_index$$($find_first_group_idx$jscomp$inline_6394_undo_group_index$jscomp$inline_6395$$-1),$app$main$data$workspace$undo$restore_selection$$($cljs$cst$3144$selected_before$$.$cljs$core$IFn$_invoke$arity$1$($first_item$jscomp$inline_6396_index$jscomp$inline_6390_it$jscomp$inline_6383$$)))):(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$undo$materialize_undo$$($changes$jscomp$inline_6392$$,
$first_item$jscomp$inline_6396_index$jscomp$inline_6390_it$jscomp$inline_6383$$-1),$APP.$app$main$data$changes$commit_changes$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3133$redo_changes$$,$changes$jscomp$inline_6392$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!1,$APP.$cljs$cst$1786$origin$$,this],null)),$app$main$data$workspace$undo$restore_selection$$($cljs$cst$3144$selected_before$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$inline_6391_state$jscomp$inline_6384$$)),
$app$main$data$workspace$undo$assure_valid_current_page$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$workspace$undo$assure_valid_current_page$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$workspace$undo$assure_valid_current_page$$())}return null});$APP.$app$main$data$workspace$undo$undo$$=new $app$main$data$workspace$undo$undo_66274$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
typeof $app$main$data$workspace$undo$redo_66308$$==="undefined"&&($app$main$data$workspace$undo$redo_66308$$=function($meta66309$jscomp$inline_6401$$){this.$meta66309$=$meta66309$jscomp$inline_6401$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$undo$redo_66308$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3575$app_DOT_main_DOT_data_DOT_workspace_DOT_undo_SLASH_redo$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66310$jscomp$inline_6402$$,$meta66309__$1$jscomp$inline_6403$$){return new $app$main$data$workspace$undo$redo_66308$$($meta66309__$1$jscomp$inline_6403$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66309$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function($index$jscomp$inline_6411_it$jscomp$inline_6404_last_item$jscomp$inline_6417$$,$item$jscomp$inline_6412_state$jscomp$inline_6405$$){var $objects$jscomp$inline_6406$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$inline_6412_state$jscomp$inline_6405$$),$edition$jscomp$inline_6407$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$inline_6412_state$jscomp$inline_6405$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2199$edition$$],null)),$drawing$jscomp$inline_6408$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$inline_6412_state$jscomp$inline_6405$$,$APP.$cljs$cst$2189$workspace_drawing$$);if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$inline_6418$$=$edition$jscomp$inline_6407$$==null&&$APP.$cljs$cst$2198$object$$.$cljs$core$IFn$_invoke$arity$1$($drawing$jscomp$inline_6408$$)==
null;return $or__5025__auto__$jscomp$inline_6418$$?$or__5025__auto__$jscomp$inline_6418$$:$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_6406$$,$edition$jscomp$inline_6407$$)}())){var $undo$jscomp$inline_6409$$=$APP.$cljs$cst$3563$workspace_undo$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$inline_6412_state$jscomp$inline_6405$$),$items$jscomp$inline_6410$$=$APP.$cljs$cst$1838$items$$.$cljs$core$IFn$_invoke$arity$1$($undo$jscomp$inline_6409$$);
$index$jscomp$inline_6411_it$jscomp$inline_6404_last_item$jscomp$inline_6417$$=function(){var $or__5025__auto__$jscomp$inline_6419$$=$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($undo$jscomp$inline_6409$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_6419$$)?$or__5025__auto__$jscomp$inline_6419$$:$APP.$cljs$core$count$$($items$jscomp$inline_6410$$)-1}();if($APP.$cljs$core$empty_QMARK_$$($items$jscomp$inline_6410$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$inline_6411_it$jscomp$inline_6404_last_item$jscomp$inline_6417$$,
$APP.$cljs$core$count$$($items$jscomp$inline_6410$$)-1))return null;$item$jscomp$inline_6412_state$jscomp$inline_6405$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$inline_6410$$,$index$jscomp$inline_6411_it$jscomp$inline_6404_last_item$jscomp$inline_6417$$+1);var $changes$jscomp$inline_6413$$=$APP.$cljs$cst$3133$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$inline_6412_state$jscomp$inline_6405$$),$undo_group$jscomp$inline_6414$$=$APP.$cljs$cst$3138$undo_group$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$inline_6412_state$jscomp$inline_6405$$),
$find_last_group_idx$jscomp$inline_6415_redo_group_index$jscomp$inline_6416$$=function $app$main$data$workspace$undo$flgidx$jscomp$inline_6421$$($index__$1$jscomp$inline_6420$$){var $item__$1$jscomp$inline_6422$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$inline_6410$$,$index__$1$jscomp$inline_6420$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3138$undo_group$$.$cljs$core$IFn$_invoke$arity$1$($item__$1$jscomp$inline_6422$$),$undo_group$jscomp$inline_6414$$)?
$app$main$data$workspace$undo$flgidx$jscomp$inline_6421$$($index__$1$jscomp$inline_6420$$+1):$index__$1$jscomp$inline_6420$$-1};$find_last_group_idx$jscomp$inline_6415_redo_group_index$jscomp$inline_6416$$=$APP.$cljs$core$truth_$$($undo_group$jscomp$inline_6414$$)?$find_last_group_idx$jscomp$inline_6415_redo_group_index$jscomp$inline_6416$$($index$jscomp$inline_6411_it$jscomp$inline_6404_last_item$jscomp$inline_6417$$+1):null;return $APP.$cljs$core$truth_$$($undo_group$jscomp$inline_6414$$)?($index$jscomp$inline_6411_it$jscomp$inline_6404_last_item$jscomp$inline_6417$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$inline_6410$$,$find_last_group_idx$jscomp$inline_6415_redo_group_index$jscomp$inline_6416$$),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$undo_to_index$$($find_last_group_idx$jscomp$inline_6415_redo_group_index$jscomp$inline_6416$$),$app$main$data$workspace$undo$restore_selection$$($cljs$cst$3561$selected_after$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$inline_6411_it$jscomp$inline_6404_last_item$jscomp$inline_6417$$)))):
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$undo$materialize_undo$$($changes$jscomp$inline_6413$$,$index$jscomp$inline_6411_it$jscomp$inline_6404_last_item$jscomp$inline_6417$$+1),$APP.$app$main$data$changes$commit_changes$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3133$redo_changes$$,$changes$jscomp$inline_6413$$,$APP.$cljs$cst$3137$undo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1786$origin$$,this,$APP.$cljs$cst$3140$save_undo_QMARK_$$,!1],
null)),$app$main$data$workspace$undo$restore_selection$$($cljs$cst$3561$selected_after$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$inline_6412_state$jscomp$inline_6405$$)))}return null});$APP.$app$main$data$workspace$undo$redo$$=new $app$main$data$workspace$undo$redo_66308$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $app$main$data$workspace$zoom$increase_zoom_66110$$,$app$main$data$workspace$zoom$decrease_zoom_66145$$,$app$main$data$workspace$zoom$set_zoom_66175$$,$app$main$data$workspace$zoom$reset_zoom_66201$$,$app$main$data$workspace$zoom$zoom_to_fit_all_66226$$,$app$main$data$workspace$zoom$zoom_to_selected_shape_66251$$;
typeof $app$main$data$workspace$zoom$reset_zoom_66201$$==="undefined"&&($app$main$data$workspace$zoom$reset_zoom_66201$$=function($meta66202$jscomp$inline_6428$$){this.$meta66202$=$meta66202$jscomp$inline_6428$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$zoom$reset_zoom_66201$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$3582$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_reset_zoom$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66203$jscomp$inline_6429$$,$meta66202__$1$jscomp$inline_6430$$){return new $app$main$data$workspace$zoom$reset_zoom_66201$$($meta66202__$1$jscomp$inline_6430$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66202$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_6431$$,$state$jscomp$inline_6432$$){return $APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$inline_6432$$)?$state$jscomp$inline_6432$$:$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$inline_6432$$,$APP.$cljs$cst$1920$workspace_local$$,function($p1__66200_SHARP_$jscomp$inline_6433$$){return $app$main$data$workspace$zoom$impl_update_zoom$$($p1__66200_SHARP_$jscomp$inline_6433$$,
null,1)})},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$inline_6434$$,$state$jscomp$inline_6435$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$inline_6435$$)});$APP.$app$main$data$workspace$zoom$reset_zoom$$=new $app$main$data$workspace$zoom$reset_zoom_66201$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
typeof $app$main$data$workspace$zoom$zoom_to_fit_all_66226$$==="undefined"&&($app$main$data$workspace$zoom$zoom_to_fit_all_66226$$=function($meta66227$jscomp$inline_6437$$){this.$meta66227$=$meta66227$jscomp$inline_6437$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$zoom$zoom_to_fit_all_66226$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3583$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_zoom_to_fit_all$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66228$jscomp$inline_6438$$,$meta66227__$1$jscomp$inline_6439$$){return new $app$main$data$workspace$zoom$zoom_to_fit_all_66226$$($meta66227__$1$jscomp$inline_6439$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66227$},
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_6440_objects$jscomp$inline_6443_page_id$jscomp$inline_6442_shapes$jscomp$inline_6444$$,$state$jscomp$inline_6441$$){if($APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$inline_6441$$))return $state$jscomp$inline_6441$$;$_$jscomp$inline_6440_objects$jscomp$inline_6443_page_id$jscomp$inline_6442_shapes$jscomp$inline_6444$$=
$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$inline_6441$$);$_$jscomp$inline_6440_objects$jscomp$inline_6443_page_id$jscomp$inline_6442_shapes$jscomp$inline_6444$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$inline_6441$$,$_$jscomp$inline_6440_objects$jscomp$inline_6443_page_id$jscomp$inline_6442_shapes$jscomp$inline_6444$$);$_$jscomp$inline_6440_objects$jscomp$inline_6443_page_id$jscomp$inline_6442_shapes$jscomp$inline_6444$$=
$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$inline_6440_objects$jscomp$inline_6443_page_id$jscomp$inline_6442_shapes$jscomp$inline_6444$$,$APP.$app$common$uuid$zero$$,null);var $srect$jscomp$inline_6445$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($_$jscomp$inline_6440_objects$jscomp$inline_6443_page_id$jscomp$inline_6442_shapes$jscomp$inline_6444$$);return $APP.$cljs$core$empty_QMARK_$$($_$jscomp$inline_6440_objects$jscomp$inline_6443_page_id$jscomp$inline_6442_shapes$jscomp$inline_6444$$)?
$state$jscomp$inline_6441$$:$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$inline_6441$$,$APP.$cljs$cst$1920$workspace_local$$,function($map__66245__$1$jscomp$inline_6447_p__66244$jscomp$inline_6446$$){$map__66245__$1$jscomp$inline_6447_p__66244$jscomp$inline_6446$$=$APP.$cljs$core$__destructure_map$$($map__66245__$1$jscomp$inline_6447_p__66244$jscomp$inline_6446$$);var $vport$jscomp$inline_6448_zoom$jscomp$inline_6450$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66245__$1$jscomp$inline_6447_p__66244$jscomp$inline_6446$$,
$APP.$cljs$cst$2203$vport$$),$srect__$1$jscomp$inline_6449$$=$APP.$app$common$geom$align$adjust_to_viewport$cljs$0core$0IFn$0_invoke$0arity$03$$($vport$jscomp$inline_6448_zoom$jscomp$inline_6450$$,$srect$jscomp$inline_6445$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$256$padding$$,160,$APP.$cljs$cst$3421$min_zoom$$,.01],null));$vport$jscomp$inline_6448_zoom$jscomp$inline_6450$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$inline_6448_zoom$jscomp$inline_6450$$)/
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($srect__$1$jscomp$inline_6449$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__66245__$1$jscomp$inline_6447_p__66244$jscomp$inline_6446$$,$APP.$cljs$cst$2196$zoom$$,$vport$jscomp$inline_6448_zoom$jscomp$inline_6450$$),$APP.$cljs$cst$3577$zoom_inverse$$,1/$vport$jscomp$inline_6448_zoom$jscomp$inline_6450$$),
$APP.$cljs$cst$1925$vbox$$,$APP.$cljs$core$merge$$,$srect__$1$jscomp$inline_6449$$)})},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$inline_6451$$,$state$jscomp$inline_6452$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$inline_6452$$)});
$APP.$app$main$data$workspace$zoom$zoom_to_fit_all$$=new $app$main$data$workspace$zoom$zoom_to_fit_all_66226$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
typeof $app$main$data$workspace$zoom$zoom_to_selected_shape_66251$$==="undefined"&&($app$main$data$workspace$zoom$zoom_to_selected_shape_66251$$=function($meta66252$jscomp$inline_6454$$){this.$meta66252$=$meta66252$jscomp$inline_6454$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$zoom$zoom_to_selected_shape_66251$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3584$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_zoom_to_selected_shape$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66253$jscomp$inline_6455$$,$meta66252__$1$jscomp$inline_6456$$){return new $app$main$data$workspace$zoom$zoom_to_selected_shape_66251$$($meta66252__$1$jscomp$inline_6456$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66252$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_6457_selected$jscomp$inline_6459$$,$state$jscomp$inline_6458$$){if($APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$inline_6458$$))return $state$jscomp$inline_6458$$;$_$jscomp$inline_6457_selected$jscomp$inline_6459$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$inline_6458$$);
if($APP.$cljs$core$empty_QMARK_$$($_$jscomp$inline_6457_selected$jscomp$inline_6459$$))return $state$jscomp$inline_6458$$;var $page_id$jscomp$inline_6460$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$inline_6458$$),$objects$jscomp$inline_6461$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$inline_6458$$,$page_id$jscomp$inline_6460$$),$srect$jscomp$inline_6462$$=$APP.$app$common$geom$shapes$shapes__GT_rect$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66250_SHARP_$jscomp$inline_6463$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_6461$$,
$p1__66250_SHARP_$jscomp$inline_6463$$)},$_$jscomp$inline_6457_selected$jscomp$inline_6459$$));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$inline_6458$$,$APP.$cljs$cst$1920$workspace_local$$,function($map__66262__$1$jscomp$inline_6465_p__66261$jscomp$inline_6464$$){$map__66262__$1$jscomp$inline_6465_p__66261$jscomp$inline_6464$$=$APP.$cljs$core$__destructure_map$$($map__66262__$1$jscomp$inline_6465_p__66261$jscomp$inline_6464$$);var $vport$jscomp$inline_6466_zoom$jscomp$inline_6468$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66262__$1$jscomp$inline_6465_p__66261$jscomp$inline_6464$$,$APP.$cljs$cst$2203$vport$$),$srect__$1$jscomp$inline_6467$$=$APP.$app$common$geom$align$adjust_to_viewport$cljs$0core$0IFn$0_invoke$0arity$03$$($vport$jscomp$inline_6466_zoom$jscomp$inline_6468$$,$srect$jscomp$inline_6462$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$256$padding$$,40,$APP.$cljs$cst$3421$min_zoom$$,.01],null));$vport$jscomp$inline_6466_zoom$jscomp$inline_6468$$=
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$inline_6466_zoom$jscomp$inline_6468$$)/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($srect__$1$jscomp$inline_6467$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__66262__$1$jscomp$inline_6465_p__66261$jscomp$inline_6464$$,$APP.$cljs$cst$2196$zoom$$,$vport$jscomp$inline_6466_zoom$jscomp$inline_6468$$),
$APP.$cljs$cst$3577$zoom_inverse$$,1/$vport$jscomp$inline_6466_zoom$jscomp$inline_6468$$),$APP.$cljs$cst$1925$vbox$$,$APP.$cljs$core$merge$$,$srect__$1$jscomp$inline_6467$$)})},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$inline_6469$$,$state$jscomp$inline_6470$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$inline_6470$$)});
$APP.$app$main$data$workspace$zoom$zoom_to_selected_shape$$=new $app$main$data$workspace$zoom$zoom_to_selected_shape_66251$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $app$main$data$workspace$selection$select_shape_67181$$,$app$main$data$workspace$selection$select_prev_shape_67230$$,$app$main$data$workspace$selection$select_next_shape_67251$$,$app$main$data$workspace$selection$deselect_shape_67293$$,$app$main$data$workspace$selection$shift_select_shapes_67316$$,$app$main$data$workspace$selection$select_shapes_67319$$,$app$main$data$workspace$selection$select_all_67337$$,$app$main$data$workspace$selection$deselect_all_67343$$,$app$main$data$workspace$selection$clear_memorize_duplicated_67361$$,
$app$main$data$workspace$selection$memorize_duplicated_67364$$,$app$main$data$workspace$selection$duplicate_shapes_67381$$,$app$main$data$workspace$selection$duplicate_selected_67391$$,$app$main$data$workspace$selection$update_focus_shapes_67403$$,$app$main$data$workspace$selection$toggle_focus_mode_67407$$;$APP.$app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$=function $app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$($var_args$jscomp$1206$$){switch(arguments.length){case 8:return $app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$.$cljs$core$IFn$_invoke$arity$8$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7]);case 9:return $app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$.$cljs$core$IFn$_invoke$arity$9$(arguments[0],
arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8]);case 10:return $app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$.$cljs$core$IFn$_invoke$arity$10$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$.$cljs$core$IFn$_invoke$arity$8$=function($changes$jscomp$164$$,$id$jscomp$495$$,$parent_id$jscomp$47$$,$objects$jscomp$325$$,$selected$jscomp$25$$,$index$jscomp$269$$,$frame_name$$,$without_fill_QMARK_$$){return $APP.$app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$.$cljs$core$IFn$_invoke$arity$9$($changes$jscomp$164$$,$id$jscomp$495$$,$parent_id$jscomp$47$$,$objects$jscomp$325$$,$selected$jscomp$25$$,
$index$jscomp$269$$,$frame_name$$,$without_fill_QMARK_$$,null)};
$APP.$app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$.$cljs$core$IFn$_invoke$arity$9$=function($changes$jscomp$165$$,$id$jscomp$496$$,$parent_id$jscomp$48$$,$objects$jscomp$326$$,$selected$jscomp$26$$,$index$jscomp$270$$,$frame_name$jscomp$1$$,$without_fill_QMARK_$jscomp$1$$,$target_cell_id$$){return $APP.$app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$.$cljs$core$IFn$_invoke$arity$10$($changes$jscomp$165$$,$id$jscomp$496$$,$parent_id$jscomp$48$$,
$objects$jscomp$326$$,$selected$jscomp$26$$,$index$jscomp$270$$,$frame_name$jscomp$1$$,$without_fill_QMARK_$jscomp$1$$,$target_cell_id$$,null)};
$APP.$app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$.$cljs$core$IFn$_invoke$arity$10$=function($changes$jscomp$166_changes__$1$jscomp$59_vec__66142$$,$id$jscomp$497$$,$parent_id$jscomp$49_shape$jscomp$439_shape__$1$jscomp$32$$,$objects$jscomp$327$$,$selected$jscomp$27$$,$index$jscomp$271_new_index$jscomp$2$$,$frame_name$jscomp$2$$,$without_fill_QMARK_$jscomp$2$$,$target_cell_id$jscomp$1$$,$delta$jscomp$34$$){var $selected_id$jscomp$1_selected_obj_temp__5825__auto__$jscomp$197$$=
$APP.$cljs$core$not_empty$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$327$$),$selected$jscomp$27$$));if($APP.$cljs$core$truth_$$($selected_id$jscomp$1_selected_obj_temp__5825__auto__$jscomp$197$$)){var $changes__$3$jscomp$8_selected_SINGLEQUOTE_$$=$app$common$files$helpers$order_by_indexed_shapes$$($objects$jscomp$327$$,$selected$jscomp$27$$);$index$jscomp$271_new_index$jscomp$2$$=$APP.$cljs$core$truth_$$($index$jscomp$271_new_index$jscomp$2$$)?
$index$jscomp$271_new_index$jscomp$2$$:$app$common$files$helpers$get_position_on_parent$$($objects$jscomp$327$$,$APP.$cljs$core$first$$($changes__$3$jscomp$8_selected_SINGLEQUOTE_$$))+1;var $srect$jscomp$6$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($selected_id$jscomp$1_selected_obj_temp__5825__auto__$jscomp$197$$);$selected_id$jscomp$1_selected_obj_temp__5825__auto__$jscomp$197$$=$APP.$cljs$core$first$$($selected$jscomp$27$$);$selected_id$jscomp$1_selected_obj_temp__5825__auto__$jscomp$197$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$327$$,$selected_id$jscomp$1_selected_obj_temp__5825__auto__$jscomp$197$$);var $frame_id$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selected_id$jscomp$1_selected_obj_temp__5825__auto__$jscomp$197$$,$APP.$cljs$cst$1607$frame_id$$),$parent_id__$1$jscomp$7$$=$APP.$cljs$core$truth_$$($parent_id$jscomp$49_shape$jscomp$439_shape__$1$jscomp$32$$)?$parent_id$jscomp$49_shape$jscomp$439_shape__$1$jscomp$32$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selected_id$jscomp$1_selected_obj_temp__5825__auto__$jscomp$197$$,
$APP.$cljs$cst$1619$parent_id$$),$base_parent$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$327$$,$parent_id__$1$jscomp$7$$),$layout_attrs$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($selected$jscomp$27$$))&&$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($base_parent$$)?$APP.$cljs$core$select_keys$$($selected_id$jscomp$1_selected_obj_temp__5825__auto__$jscomp$197$$,$app$common$types$shape$layout$layout_child_attrs$$):
null,$target_cell_id__$1$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$418$$=$target_cell_id$jscomp$1$$==null;return $and__5023__auto__$jscomp$418$$?$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$327$$,$parent_id__$1$jscomp$7$$):$and__5023__auto__$jscomp$418$$}())?function(){var $ncols$$=$APP.$cljs$core$count$$($APP.$cljs$cst$1695$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($base_parent$$));return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$min_key$$,
function($p__66157_row$jscomp$24$$){var $column$jscomp$30_map__66158__$1$$=$APP.$cljs$core$__destructure_map$$($p__66157_row$jscomp$24$$);$p__66157_row$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column$jscomp$30_map__66158__$1$$,$APP.$cljs$cst$1656$row$$);$column$jscomp$30_map__66158__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column$jscomp$30_map__66158__$1$$,$APP.$cljs$cst$216$column$$);return $ncols$$*$p__66157_row$jscomp$24$$+$column$jscomp$30_map__66158__$1$$},
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66083_SHARP_$$){return $APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($base_parent$$,$p1__66083_SHARP_$$)},$selected$jscomp$27$$)))}():$target_cell_id$jscomp$1$$,$attrs$jscomp$75$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1606$frame$$,$APP.$cljs$cst$1510$x$$,function(){var $G__66163$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($srect$jscomp$6$$);return $APP.$cljs$core$truth_$$($delta$jscomp$34$$)?
$G__66163$$+$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$34$$):$G__66163$$}(),$APP.$cljs$cst$1511$y$$,function(){var $G__66165$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($srect$jscomp$6$$);return $APP.$cljs$core$truth_$$($delta$jscomp$34$$)?$G__66165$$+$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$34$$):$G__66165$$}(),$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($srect$jscomp$6$$),$APP.$cljs$cst$1522$height$$,
$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($srect$jscomp$6$$)],null);$parent_id$jscomp$49_shape$jscomp$439_shape__$1$jscomp$32$$=$APP.$app$common$types$shape$setup_shape$$(function(){var $G__66169__$1_G__66169__$2_G__66169__$3_G__66169__$4$$=$id$jscomp$497$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$75$$,$APP.$cljs$cst$266$id$$,$id$jscomp$497$$):$attrs$jscomp$75$$;$G__66169__$1_G__66169__$2_G__66169__$3_G__66169__$4$$=$frame_name$jscomp$2$$!=null?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66169__$1_G__66169__$2_G__66169__$3_G__66169__$4$$,$APP.$cljs$cst$725$name$$,$frame_name$jscomp$2$$):$G__66169__$1_G__66169__$2_G__66169__$3_G__66169__$4$$;$G__66169__$1_G__66169__$2_G__66169__$3_G__66169__$4$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__66169__$1_G__66169__$2_G__66169__$3_G__66169__$4$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$47$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$parent_id$$,
$parent_id__$1$jscomp$7$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$selected$jscomp$27$$)]));$G__66169__$1_G__66169__$2_G__66169__$3_G__66169__$4$$=$layout_attrs$$!=null?$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($G__66169__$1_G__66169__$2_G__66169__$3_G__66169__$4$$,$layout_attrs$$):$G__66169__$1_G__66169__$2_G__66169__$3_G__66169__$4$$;var $or__5025__auto__$jscomp$inline_6480$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$47$$,
$APP.$app$common$uuid$zero$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_6480$$?$or__5025__auto__$jscomp$inline_6480$$:$without_fill_QMARK_$jscomp$2$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__66169__$1_G__66169__$2_G__66169__$3_G__66169__$4$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1875$hide_in_viewer$$,!0,$APP.$cljs$cst$1876$show_content$$,!0])):
$G__66169__$1_G__66169__$2_G__66169__$3_G__66169__$4$$}());$parent_id$jscomp$49_shape$jscomp$439_shape__$1$jscomp$32$$=$APP.$cljs$core$with_meta$$($parent_id$jscomp$49_shape$jscomp$439_shape__$1$jscomp$32$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1795$index$$,$index$jscomp$271_new_index$jscomp$2$$],null));$changes$jscomp$166_changes__$1$jscomp$59_vec__66142$$=$APP.$app$common$files$shapes_helpers$prepare_add_shape$$($changes$jscomp$166_changes__$1$jscomp$59_vec__66142$$,$parent_id$jscomp$49_shape$jscomp$439_shape__$1$jscomp$32$$,
$objects$jscomp$327$$);var $shape__$2$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$166_changes__$1$jscomp$59_vec__66142$$,0,null);$changes$jscomp$166_changes__$1$jscomp$59_vec__66142$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$166_changes__$1$jscomp$59_vec__66142$$,1,null);var $changes__$2$jscomp$28$$=$app$common$files$shapes_helpers$prepare_move_shapes_into_frame$$($changes$jscomp$166_changes__$1$jscomp$59_vec__66142$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$2$jscomp$8$$),
$changes__$3$jscomp$8_selected_SINGLEQUOTE_$$,$objects$jscomp$327$$,!1);$changes__$3$jscomp$8_selected_SINGLEQUOTE_$$=function(){return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$327$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$2$jscomp$8$$)))?$APP.$app$common$files$changes_builder$reorder_grid_children$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($changes__$2$jscomp$28$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$2$jscomp$8$$)],null),function($G__66197$jscomp$inline_6482_JSCompiler_inline_result$jscomp$1117_parent$jscomp$224$$,$objects__$1$jscomp$9$$){var $JSCompiler_temp_const$jscomp$1116$$=$APP.$app$common$types$shape$layout$assign_cells$$;$G__66197$jscomp$inline_6482_JSCompiler_inline_result$jscomp$1117_parent$jscomp$224$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__66197$jscomp$inline_6482_JSCompiler_inline_result$jscomp$1117_parent$jscomp$224$$,
$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$1696$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($base_parent$$)),$APP.$cljs$cst$1694$layout_grid_rows$$,$APP.$cljs$cst$1694$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($base_parent$$)),$APP.$cljs$cst$1695$layout_grid_columns$$,$APP.$cljs$cst$1695$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($base_parent$$));$G__66197$jscomp$inline_6482_JSCompiler_inline_result$jscomp$1117_parent$jscomp$224$$=$target_cell_id__$1$$!=null?
$APP.$cljs$core$assoc_in$$($G__66197$jscomp$inline_6482_JSCompiler_inline_result$jscomp$1117_parent$jscomp$224$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1696$layout_grid_cells$$,$target_cell_id__$1$$,$APP.$cljs$cst$1614$shapes$$],null),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$2$jscomp$8$$)],null)):$G__66197$jscomp$inline_6482_JSCompiler_inline_result$jscomp$1117_parent$jscomp$224$$;
return $JSCompiler_temp_const$jscomp$1116$$($G__66197$jscomp$inline_6482_JSCompiler_inline_result$jscomp$1117_parent$jscomp$224$$,$objects__$1$jscomp$9$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3175$with_objects_QMARK_$$,!0],null)),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$2$jscomp$8$$)],null)):$changes__$2$jscomp$28$$}();return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape__$2$jscomp$8$$,$changes__$3$jscomp$8_selected_SINGLEQUOTE_$$],null)}return null};$APP.$app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$.$cljs$lang$maxFixedArity$=10;var $app$main$data$workspace$shapes$update_shapes_buffer_start_67426$$,$app$main$data$workspace$shapes$update_shapes_buffer_stop_67431$$,$app$main$data$workspace$shapes$update_shapes_buffer_commit_67437$$,$app$main$data$workspace$shapes$update_shapes_buffer_67454$$,$app$main$data$workspace$shapes$update_shapes_67469$$,$app$main$data$workspace$shapes$add_shape_67499$$,$app$main$data$workspace$shapes$move_shapes_into_frame_67536$$,$app$main$data$workspace$shapes$delete_shapes_67546$$,$app$main$data$workspace$shapes$create_and_add_shape_67564$$,
$app$main$data$workspace$shapes$create_artboard_from_shapes_67580$$,$app$main$data$workspace$shapes$create_artboard_from_selection_67598$$,$app$main$data$workspace$shapes$update_shape_flags_67606$$,$app$main$data$workspace$shapes$toggle_visibility_selected_67614$$,$app$main$data$workspace$shapes$toggle_lock_selected_67618$$,$app$main$data$workspace$shapes$toggle_file_thumbnail_selected_67624$$,$app$main$data$workspace$shapes$relocate_shapes_67644$$,$app$main$data$workspace$shapes$update_layout_attr_QMARK_$$=
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1620$hidden$$,null],null),null);var $app$main$data$workspace$bool$create_bool_union_67704$$;
$APP.$app$main$data$workspace$bool$create_bool$$=function $app$main$data$workspace$bool$create_bool$$($var_args$jscomp$1215$$){for(var $args__5755__auto__$jscomp$222$$=[],$len__5749__auto___67756$$=arguments.length,$i__5750__auto___67757$$=0;;)if($i__5750__auto___67757$$<$len__5749__auto___67756$$)$args__5755__auto__$jscomp$222$$.push(arguments[$i__5750__auto___67757$$]),$i__5750__auto___67757$$+=1;else break;return $app$main$data$workspace$bool$create_bool$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<
$args__5755__auto__$jscomp$222$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$222$$.slice(1),0,null):null)};
$APP.$app$main$data$workspace$bool$create_bool$$.$cljs$core$IFn$_invoke$arity$variadic$=function($type$jscomp$454$$,$p__67702$$){var $map__67703__$1$$=$APP.$cljs$core$__destructure_map$$($p__67702$$),$ids$jscomp$84$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67703__$1$$,$APP.$cljs$cst$1723$ids$$),$force_shape_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67703__$1$$,$APP.$cljs$cst$3656$force_shape_id$$);typeof $app$main$data$workspace$bool$create_bool_union_67704$$===
"undefined"&&($app$main$data$workspace$bool$create_bool_union_67704$$=function($type$jscomp$455$$,$p__67702$jscomp$1$$,$map__67703$jscomp$1$$,$ids$jscomp$85$$,$force_shape_id$jscomp$1$$,$meta67705$$){this.type=$type$jscomp$455$$;this.$p__67702$=$p__67702$jscomp$1$$;this.$map__67703$=$map__67703$jscomp$1$$;this.ids=$ids$jscomp$85$$;this.$force_shape_id$=$force_shape_id$jscomp$1$$;this.$meta67705$=$meta67705$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$bool$create_bool_union_67704$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$bool$create_bool_union_67704$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3657$app_DOT_main_DOT_data_DOT_workspace_DOT_bool_SLASH_create_bool_union$$},$app$main$data$workspace$bool$create_bool_union_67704$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67706$$,$meta67705__$1$$){return new $app$main$data$workspace$bool$create_bool_union_67704$$(this.type,
this.$p__67702$,this.$map__67703$,this.ids,this.$force_shape_id$,$meta67705__$1$$)},$app$main$data$workspace$bool$create_bool_union_67704$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67705$},$app$main$data$workspace$bool$create_bool_union_67704$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$bool$create_bool_union_67704$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$176_it$jscomp$159_page_id$jscomp$127$$,
$state$jscomp$401$$){var $self__$jscomp$4376$$=this;$changes$jscomp$176_it$jscomp$159_page_id$jscomp$127$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$401$$);var $objects$jscomp$342$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$401$$,$changes$jscomp$176_it$jscomp$159_page_id$jscomp$127$$),$name$jscomp$298_shape$jscomp$446$$=$APP.$cuerdas$core$capital$$($APP.$app$common$data$name$$($self__$jscomp$4376$$.type)),
$ids__$1$jscomp$10_shapes$jscomp$55$$=$app$main$data$helpers$process_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$342$$,function(){var $or__5025__auto__$jscomp$700$$=$self__$jscomp$4376$$.ids;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$700$$)?$or__5025__auto__$jscomp$700$$:$app$main$data$helpers$get_selected_ids$$($state$jscomp$401$$)}()),$shape_id$jscomp$74_vec__67724_xform$jscomp$34$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$getf$$($objects$jscomp$342$$)),
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$frame_shape_QMARK_$$),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$component$is_variant_QMARK_$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__67687_SHARP_$$){return $APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$342$$,$p1__67687_SHARP_$$)})]));$ids__$1$jscomp$10_shapes$jscomp$55$$=
$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$shape_id$jscomp$74_vec__67724_xform$jscomp$34$$,$app$common$files$helpers$order_by_indexed_shapes$$($objects$jscomp$342$$,$ids__$1$jscomp$10_shapes$jscomp$55$$)));if($APP.$cljs$core$truth_$$($ids__$1$jscomp$10_shapes$jscomp$55$$)){$shape_id$jscomp$74_vec__67724_xform$jscomp$34$$=$app$main$data$workspace$bool$create_bool_shape$$($self__$jscomp$4376$$.$force_shape_id$,$self__$jscomp$4376$$.type,
$name$jscomp$298_shape$jscomp$446$$,$APP.$cljs$core$reverse$$($ids__$1$jscomp$10_shapes$jscomp$55$$),$objects$jscomp$342$$);$name$jscomp$298_shape$jscomp$446$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shape_id$jscomp$74_vec__67724_xform$jscomp$34$$,0,null);var $index$jscomp$281$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shape_id$jscomp$74_vec__67724_xform$jscomp$34$$,1,null);$shape_id$jscomp$74_vec__67724_xform$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$298_shape$jscomp$446$$,
$APP.$cljs$cst$266$id$$);$changes$jscomp$176_it$jscomp$159_page_id$jscomp$127$$=$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$changes$jscomp$176_it$jscomp$159_page_id$jscomp$127$$),
$objects$jscomp$342$$),$name$jscomp$298_shape$jscomp$446$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1795$index$$,$index$jscomp$281$$+1],null)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$ids__$1$jscomp$10_shapes$jscomp$55$$),$app$common$types$shape$layout$remove_layout_item_data$$),$shape_id$jscomp$74_vec__67724_xform$jscomp$34$$,$ids__$1$jscomp$10_shapes$jscomp$55$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$176_it$jscomp$159_page_id$jscomp$127$$),
$APP.$app$main$data$workspace$selection$select_shapes$$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$74_vec__67724_xform$jscomp$34$$)))}return null});return new $app$main$data$workspace$bool$create_bool_union_67704$$($type$jscomp$454$$,$p__67702$$,$map__67703__$1$$,$ids$jscomp$84$$,$force_shape_id$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$main$data$workspace$bool$create_bool$$.$cljs$lang$maxFixedArity$=1;
$APP.$app$main$data$workspace$bool$create_bool$$.$cljs$lang$applyTo$=function($seq67692_seq67692__$1$$){var $G__67693$$=$APP.$cljs$core$first$$($seq67692_seq67692__$1$$);$seq67692_seq67692__$1$$=$APP.$cljs$core$next$$($seq67692_seq67692__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__67693$$,$seq67692_seq67692__$1$$)};var $app$common$geom$shapes$grid_layout$layout_data$_child_min_width$$=null,$app$common$geom$shapes$grid_layout$layout_data$_child_min_height$$=null;var $app$common$geom$shapes$grid_layout$calculate_params$$;
$APP.$app$common$geom$shapes$grid_layout$calc_layout_data$$=function(){var $app$common$geom$shapes$grid_layout$calc_layout_data$$=null;$app$common$geom$shapes$grid_layout$calc_layout_data$$=function($param66850$jscomp$1$$,$param66851$jscomp$1$$,$param66852$jscomp$1$$,$param66853$jscomp$1$$,$param66854$jscomp$1$$,$param66855$jscomp$1$$){switch(arguments.length){case 5:return $app$common$geom$shapes$grid_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$05$$($param66850$jscomp$1$$,$param66851$jscomp$1$$,
$param66852$jscomp$1$$,$param66853$jscomp$1$$,$param66854$jscomp$1$$);case 6:return $app$common$geom$shapes$grid_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$06$$($param66850$jscomp$1$$,$param66851$jscomp$1$$,$param66852$jscomp$1$$,$param66853$jscomp$1$$,$param66854$jscomp$1$$,$param66855$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$common$geom$shapes$grid_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$=function($param66845$$,$param66846$$,$param66847$$,
$param66848$$,$param66849$$){return $app$common$geom$shapes$grid_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$05$$($param66845$$,$param66846$$,$param66847$$,$param66848$$,$param66849$$)};$app$common$geom$shapes$grid_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$6$=function($param66850$$,$param66851$$,$param66852$$,$param66853$$,$param66854$$,$param66855$$){return $app$common$geom$shapes$grid_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$06$$($param66850$$,
$param66851$$,$param66852$$,$param66853$$,$param66854$$,$param66855$$)};return $app$common$geom$shapes$grid_layout$calc_layout_data$$}();
$app$common$geom$shapes$grid_layout$calculate_params$$=function(){var $app$common$geom$shapes$grid_layout$calculate_params$$=null;$app$common$geom$shapes$grid_layout$calculate_params$$=function($param66880$jscomp$1$$,$param66881$jscomp$1$$,$param66882$jscomp$1$$){switch(arguments.length){case 2:return $app$common$geom$shapes$grid_layout$params$calculate_params$cljs$0core$0IFn$0_invoke$0arity$03$$($param66881$jscomp$1$$,null);case 3:return $app$common$geom$shapes$grid_layout$params$calculate_params$cljs$0core$0IFn$0_invoke$0arity$03$$($param66881$jscomp$1$$,
$param66882$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$common$geom$shapes$grid_layout$calculate_params$$.$cljs$core$IFn$_invoke$arity$2$=function($param66878$$,$param66879$$){return $app$common$geom$shapes$grid_layout$params$calculate_params$cljs$0core$0IFn$0_invoke$0arity$03$$($param66879$$,null)};$app$common$geom$shapes$grid_layout$calculate_params$$.$cljs$core$IFn$_invoke$arity$3$=function($param66880$$,$param66881$$,$param66882$$){return $app$common$geom$shapes$grid_layout$params$calculate_params$cljs$0core$0IFn$0_invoke$0arity$03$$($param66881$$,
$param66882$$)};return $app$common$geom$shapes$grid_layout$calculate_params$$}();var $shadow$js$shim$module$0$0penpot$0svgo$0default$$=shadow$bridge("@penpot/svgo").default;var $app$common$files$shapes_builder$create_svg_children$$=function $app$common$files$shapes_builder$create_svg_children$$($objects$jscomp$359$$,$selected$jscomp$36$$,$frame_id$jscomp$57$$,$parent_id$jscomp$67_shape__$1$jscomp$36$$,$svg_data$jscomp$7$$,$children$jscomp$213_children__$1$jscomp$24_p__66986$$,$new_children$jscomp$3_p__66987_svg_element_vec__66995$$){var $unames$jscomp$8_unames__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$213_children__$1$jscomp$24_p__66986$$,
0,null);$children$jscomp$213_children__$1$jscomp$24_p__66986$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$213_children__$1$jscomp$24_p__66986$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_children$jscomp$3_p__66987_svg_element_vec__66995$$,0,null);$new_children$jscomp$3_p__66987_svg_element_vec__66995$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_children$jscomp$3_p__66987_svg_element_vec__66995$$,1,null);$new_children$jscomp$3_p__66987_svg_element_vec__66995$$=
$app$common$files$shapes_builder$parse_svg_element$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$files$shapes_builder$parse_svg_element$$.$cljs$core$IFn$_invoke$arity$4$($frame_id$jscomp$57$$,$svg_data$jscomp$7$$,$new_children$jscomp$3_p__66987_svg_element_vec__66995$$,$unames$jscomp$8_unames__$1$$):$app$common$files$shapes_builder$parse_svg_element$$($frame_id$jscomp$57$$,$svg_data$jscomp$7$$,$new_children$jscomp$3_p__66987_svg_element_vec__66995$$,$unames$jscomp$8_unames__$1$$);var $shape$jscomp$450$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_children$jscomp$3_p__66987_svg_element_vec__66995$$,0,null);$new_children$jscomp$3_p__66987_svg_element_vec__66995$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_children$jscomp$3_p__66987_svg_element_vec__66995$$,1,null);if($shape$jscomp$450$$!=null){var $shape_id$jscomp$83$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$450$$);$parent_id$jscomp$67_shape__$1$jscomp$36$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$450$$,
$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$57$$),$APP.$cljs$cst$1619$parent_id$$,$parent_id$jscomp$67_shape__$1$jscomp$36$$);$children$jscomp$213_children__$1$jscomp$24_p__66986$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$213_children__$1$jscomp$24_p__66986$$,$parent_id$jscomp$67_shape__$1$jscomp$36$$);$unames$jscomp$8_unames__$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($unames$jscomp$8_unames__$1$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($parent_id$jscomp$67_shape__$1$jscomp$36$$));
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$files$shapes_builder$create_svg_children$$,$objects$jscomp$359$$,$selected$jscomp$36$$,$frame_id$jscomp$57$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shape_id$jscomp$83$$,$svg_data$jscomp$7$$])),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$unames$jscomp$8_unames__$1$$,$children$jscomp$213_children__$1$jscomp$24_p__66986$$],
null),$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($new_children$jscomp$3_p__66987_svg_element_vec__66995$$))}return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$unames$jscomp$8_unames__$1$$,$children$jscomp$213_children__$1$jscomp$24_p__66986$$],null)},$app$common$files$shapes_builder$parse_svg_element$$=function $app$common$files$shapes_builder$parse_svg_element$$($frame_id$jscomp$63$$,$svg_data$jscomp$13$$,$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$,
$unames$jscomp$9$$){var $map__67097__$1$$=$APP.$cljs$core$__destructure_map$$($all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$),$tag$jscomp$70$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67097__$1$$,$APP.$cljs$cst$78$tag$$),$attrs$jscomp$98$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67097__$1$$,$APP.$cljs$cst$2645$attrs$$),$hidden$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67097__$1$$,
$APP.$cljs$cst$1620$hidden$$),$name$jscomp$307$$=$app$common$files$shapes_builder$resolve_element_name$$($tag$jscomp$70$$,$attrs$jscomp$98$$);$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$=$app$common$svg$find_attr_references$$($attrs$jscomp$98$$);var $defs$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($svg_data$jscomp$13$$,$cljs$cst$2727$defs$$);$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$=
$app$common$files$shapes_builder$filter_valid_def_references$$($all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$,$defs$jscomp$11$$);$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$=$app$common$svg$find_def_references$$($defs$jscomp$11$$,$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$);var $references$jscomp$2$$=$app$common$files$shapes_builder$filter_valid_def_references$$($all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$,
$defs$jscomp$11$$);$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$=function(){var $or__5025__auto__$jscomp$727_or__5025__auto____$1$jscomp$90$$=$APP.$cljs$cst$2462$href$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$98$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$727_or__5025__auto____$1$jscomp$90$$))return $or__5025__auto__$jscomp$727_or__5025__auto____$1$jscomp$90$$;$or__5025__auto__$jscomp$727_or__5025__auto____$1$jscomp$90$$=$cljs$cst$2853$xlink_COLON_href$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$98$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$727_or__5025__auto____$1$jscomp$90$$)?$or__5025__auto__$jscomp$727_or__5025__auto____$1$jscomp$90$$:" "}();$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$=typeof $all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$==="string"&&$APP.$cljs$core$count$$($all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$)>
0?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$,1):$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2703$use$$,$tag$jscomp$70$$)&&$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$!=null&&$APP.$cljs$core$contains_QMARK_$$($defs$jscomp$11$$,
$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$)){$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$11$$,$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$),$APP.$cljs$cst$2645$attrs$$,function($p1__67095_SHARP_$$){return $APP.$app$common$data$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$($p1__67095_SHARP_$$,
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($attrs$jscomp$98$$,$cljs$cst$2853$xlink_COLON_href$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2462$href$$])))});var $disp_matrix_displacement$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$98$$,"0")),$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$98$$,
"0")));$disp_matrix_displacement$$=""+($APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($disp_matrix_displacement$$)??"");$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__67097__$1$$,
$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$1744$g$$),$APP.$cljs$cst$2645$attrs$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$2462$href$$,$cljs$cst$2853$xlink_COLON_href$$,$APP.$cljs$cst$1289$transform$$])),$APP.$cljs$cst$2645$attrs$$,$app$common$svg$add_transform$$,$disp_matrix_displacement$$),$APP.$cljs$cst$1637$content$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$],null));return $app$common$files$shapes_builder$parse_svg_element$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$files$shapes_builder$parse_svg_element$$.$cljs$core$IFn$_invoke$arity$4$($frame_id$jscomp$63$$,$svg_data$jscomp$13$$,$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$,$unames$jscomp$9$$):$app$common$files$shapes_builder$parse_svg_element$$($frame_id$jscomp$63$$,
$svg_data$jscomp$13$$,$all_refs_att_refs_element__$1_href_id$jscomp$1_href_id__$1$jscomp$1_p__67096_use_data_valid_refs$$,$unames$jscomp$9$$)}var $shape$jscomp$455$$=function(){switch($tag$jscomp$70$$ instanceof $APP.$cljs$core$Keyword$$?$tag$jscomp$70$$.$fqn$:null){case "g":case "a":case "svg":var $defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$=
$APP.$cljs$core$__destructure_map$$($svg_data$jscomp$13$$),$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$APP.$cljs$cst$1510$x$$),$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$APP.$cljs$cst$1511$y$$),$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$APP.$cljs$cst$290$width$$),$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$APP.$cljs$cst$1522$height$$),$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$APP.$cljs$cst$1650$offset_x$$),$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$APP.$cljs$cst$1651$offset_y$$);$defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$cljs$cst$2727$defs$$);var $map__66978__$1$jscomp$inline_6625_map__67002__$1$jscomp$inline_6561_transform$jscomp$inline_6563$$=$APP.$cljs$core$__destructure_map$$($map__67097__$1$$),$attrs$jscomp$inline_6562_attrs$jscomp$inline_6626_attrs__$1$jscomp$inline_6564_props$jscomp$inline_6627$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66978__$1$jscomp$inline_6625_map__67002__$1$jscomp$inline_6561_transform$jscomp$inline_6563$$,$APP.$cljs$cst$2645$attrs$$);$map__66978__$1$jscomp$inline_6625_map__67002__$1$jscomp$inline_6561_transform$jscomp$inline_6563$$=$app$common$svg$parse_transform$$($APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$inline_6562_attrs$jscomp$inline_6626_attrs__$1$jscomp$inline_6564_props$jscomp$inline_6627$$));$attrs$jscomp$inline_6562_attrs$jscomp$inline_6626_attrs__$1$jscomp$inline_6564_props$jscomp$inline_6627$$=
$app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$without_keys$$($attrs$jscomp$inline_6562_attrs$jscomp$inline_6626_attrs__$1$jscomp$inline_6564_props$jscomp$inline_6627$$,$app$common$svg$inheritable_props$$));var $vbox$jscomp$inline_6565$$=$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,
$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$,$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$,
$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$);return $APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1890$svg_attrs$$,$cljs$cst$2965$svg_transform$$,
$cljs$cst$1893$svg_viewbox$$,$cljs$cst$2943$svg_defs$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1522$height$$],[$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$+$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$,
$name$jscomp$307$$,$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$,$APP.$cljs$cst$1608$group$$,$attrs$jscomp$inline_6562_attrs$jscomp$inline_6626_attrs__$1$jscomp$inline_6564_props$jscomp$inline_6627$$,$map__66978__$1$jscomp$inline_6625_map__67002__$1$jscomp$inline_6561_transform$jscomp$inline_6563$$,
$vbox$jscomp$inline_6565$$,$defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$frame_id$jscomp$63$$,$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$+
$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$]));
case "rect":return $JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=$APP.$cljs$core$__destructure_map$$($map__67097__$1$$),
$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$,
$APP.$cljs$cst$2645$attrs$$),$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=$APP.$app$common$geom$matrix$transform_in$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($svg_data$jscomp$13$$),
$app$common$svg$parse_transform$$($APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$))),$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$=
$APP.$app$common$geom$point$negate$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($svg_data$jscomp$13$$)),$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$=$app$common$files$shapes_builder$parse_rect_attrs$$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$),
$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$,
$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$_$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$)),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$)),
$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$=$app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,
$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1881$rx$$,$APP.$cljs$cst$1882$ry$$,$APP.$cljs$cst$1289$transform$$]))),$APP.$cljs$core$contains_QMARK_$$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,
$APP.$cljs$cst$1881$rx$$)||$APP.$cljs$core$contains_QMARK_$$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,$APP.$cljs$cst$1882$ry$$)?($offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$=
$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1881$rx$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$),0),$defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$=
$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1882$ry$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$),0),$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$=
$APP.$cljs$core$contains_QMARK_$$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,$APP.$cljs$cst$1881$rx$$)&&$APP.$cljs$core$contains_QMARK_$$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,
$APP.$cljs$cst$1882$ry$$)?$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$<$defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$?$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$:
$defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$:$APP.$cljs$core$contains_QMARK_$$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,
$APP.$cljs$cst$1881$rx$$)?$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$:$APP.$cljs$core$contains_QMARK_$$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,
$APP.$cljs$cst$1882$ry$$)?$defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$:0,$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1646$r1$$,$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,$APP.$cljs$cst$1647$r2$$,$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,
$APP.$cljs$cst$1648$r3$$,$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,$APP.$cljs$cst$1649$r4$$,$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$],
null)):$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$common$files$shapes_builder$calculate_rect_metadata$$($cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$,
$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1611$rect$$),
$APP.$cljs$cst$725$name$$,$name$jscomp$307$$),$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$63$$),$cljs$cst$1893$svg_viewbox$$,$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$),$APP.$cljs$cst$1890$svg_attrs$$,
$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$),$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$])));
case "circle":case "ellipse":return $JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=
$APP.$cljs$core$__destructure_map$$($map__67097__$1$$),$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$,
$APP.$cljs$cst$2645$attrs$$),$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$getf$$($JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$)),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$parse_double$$)),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1897$cx$$,$APP.$cljs$cst$1898$cy$$,$APP.$cljs$cst$1743$r$$,$APP.$cljs$cst$1881$rx$$,$APP.$cljs$cst$1882$ry$$],null)),$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$,0,null),$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$,1,null),$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$,2,null),$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$,3,null),$defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$,4,null),$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$=
$APP.$app$common$geom$matrix$transform_in$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($svg_data$jscomp$13$$),$app$common$svg$parse_transform$$($APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$))),
$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,
$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$),$defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,
$defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$),$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$,0),$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,
0),$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$,
0),$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$,
0),$defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$=$APP.$app$common$geom$point$negate$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($svg_data$jscomp$13$$)),$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$=
$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$-$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$-
$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$),$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$-
$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$),2*$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,
2*$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$),$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=
$app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$,
$APP.$cljs$cst$1897$cx$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1898$cy$$,$APP.$cljs$cst$1743$r$$,$APP.$cljs$cst$1881$rx$$,$APP.$cljs$cst$1882$ry$$,$APP.$cljs$cst$1289$transform$$]))),$APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$common$files$shapes_builder$calculate_rect_metadata$$($cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$,
$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1417$circle$$),$APP.$cljs$cst$725$name$$,$name$jscomp$307$$),$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$63$$),
$cljs$cst$1893$svg_viewbox$$,$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$),$APP.$cljs$cst$1890$svg_attrs$$,$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$),
$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$));case "path":return $app$common$files$shapes_builder$create_path_shape$$($name$jscomp$307$$,$frame_id$jscomp$63$$,$svg_data$jscomp$13$$,$map__67097__$1$$);case "polyline":return $JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=
$APP.$cljs$core$__destructure_map$$($map__67097__$1$$),$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$,
$APP.$cljs$cst$2645$attrs$$),$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$,
$APP.$cljs$cst$1604$points$$),$cljs$cst$1447$d$$,$app$common$svg$points__GT_path$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$))),$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$,
$APP.$cljs$cst$2645$attrs$$,$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$296$path$$])),$app$common$files$shapes_builder$create_path_shape$$($name$jscomp$307$$,
$frame_id$jscomp$63$$,$svg_data$jscomp$13$$,$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$);
case "polygon":return $JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=$APP.$cljs$core$__destructure_map$$($map__67097__$1$$),
$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$,
$APP.$cljs$cst$2645$attrs$$),$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$,
$APP.$cljs$cst$1604$points$$),$cljs$cst$1447$d$$,[$app$common$svg$points__GT_path$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$)),"Z"].join("")),
$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$,
$APP.$cljs$cst$2645$attrs$$,$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$296$path$$])),$app$common$files$shapes_builder$create_path_shape$$($name$jscomp$307$$,
$frame_id$jscomp$63$$,$svg_data$jscomp$13$$,$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$);
case "line":return $JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=$APP.$cljs$core$__destructure_map$$($map__67097__$1$$),
$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$,
$APP.$cljs$cst$2645$attrs$$),$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$=$APP.$cljs$core$__destructure_map$$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$),
$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$,
$APP.$cljs$cst$1523$x1$$),$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$,
$APP.$cljs$cst$1524$y1$$),$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$,
$APP.$cljs$cst$1525$x2$$),$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$,
$APP.$cljs$cst$1526$y2$$),$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$=$APP.$cljs$core$truth_$$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$)?
$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$:0,$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$=
$APP.$cljs$core$truth_$$($offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$)?$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$:0,$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$=
$APP.$cljs$core$truth_$$($cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$)?$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$:
0,$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$=$APP.$cljs$core$truth_$$($cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$)?
$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$:0,$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$,$APP.$cljs$cst$1523$x1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1525$x2$$,
$APP.$cljs$cst$1524$y1$$,$APP.$cljs$cst$1526$y2$$])),$cljs$cst$1447$d$$,["M",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$),",",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$),
" L",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$),",",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$)].join("")),
$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$,
$APP.$cljs$cst$2645$attrs$$,$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$296$path$$])),$app$common$files$shapes_builder$create_path_shape$$($name$jscomp$307$$,
$frame_id$jscomp$63$$,$svg_data$jscomp$13$$,$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$);
case "image":return $JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=$APP.$cljs$core$__destructure_map$$($map__67097__$1$$),
$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$,
$APP.$cljs$cst$2645$attrs$$),$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=$APP.$app$common$geom$matrix$transform_in$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($svg_data$jscomp$13$$),
$app$common$svg$parse_transform$$($APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$))),$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$=
$APP.$cljs$cst$2462$href$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$),$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$=
$APP.$cljs$core$truth_$$($cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$)?$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$:
$cljs$cst$2853$xlink_COLON_href$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$),$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($svg_data$jscomp$13$$,$APP.$cljs$cst$3673$image_data$$),$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$),$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$725$name$$,$name$jscomp$307$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$),
$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$),$APP.$cljs$cst$1726$mtype$$,$APP.$cljs$cst$1726$mtype$$.$cljs$core$IFn$_invoke$arity$1$($cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$),
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$)],null),$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$=
$APP.$app$common$geom$point$negate$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($svg_data$jscomp$13$$)),$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($app$common$files$shapes_builder$parse_rect_attrs$$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$),
$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$_$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$)),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$_$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$)),
$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$=$app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$,
$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$2462$href$$,$cljs$cst$2853$xlink_COLON_href$$]))),$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$!=
null?$APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$common$files$shapes_builder$calculate_rect_metadata$$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,
$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1611$rect$$),
$APP.$cljs$cst$725$name$$,$name$jscomp$307$$),$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$63$$),$APP.$cljs$cst$1634$fills$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1747$fill_opacity$$,1,$APP.$cljs$cst$1632$fill_image$$,$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$],
null)],null)),$cljs$cst$1633$metadata$$,$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$),$cljs$cst$1893$svg_viewbox$$,$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$),
$APP.$cljs$cst$1890$svg_attrs$$,$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$)):null;default:return $defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$=
$APP.$cljs$core$__destructure_map$$($svg_data$jscomp$13$$),$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$APP.$cljs$cst$1510$x$$),$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$APP.$cljs$cst$1511$y$$),$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$APP.$cljs$cst$290$width$$),$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$APP.$cljs$cst$1522$height$$),$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$APP.$cljs$cst$1650$offset_x$$),$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$APP.$cljs$cst$1651$offset_y$$),$defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,$cljs$cst$2727$defs$$),$map__66978__$1$jscomp$inline_6625_map__67002__$1$jscomp$inline_6561_transform$jscomp$inline_6563$$=$APP.$cljs$core$__destructure_map$$($map__67097__$1$$),$attrs$jscomp$inline_6562_attrs$jscomp$inline_6626_attrs__$1$jscomp$inline_6564_props$jscomp$inline_6627$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66978__$1$jscomp$inline_6625_map__67002__$1$jscomp$inline_6561_transform$jscomp$inline_6563$$,$APP.$cljs$cst$2645$attrs$$),$attrs$jscomp$inline_6562_attrs$jscomp$inline_6626_attrs__$1$jscomp$inline_6564_props$jscomp$inline_6627$$=$app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$01$$($attrs$jscomp$inline_6562_attrs$jscomp$inline_6626_attrs__$1$jscomp$inline_6564_props$jscomp$inline_6627$$),$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$=
$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,$offset_y$jscomp$inline_6559_offset_y$jscomp$inline_6623_rx$jscomp$inline_6590_rx__$1$jscomp$inline_6593_rx_val$jscomp$inline_12407_ry__$2$jscomp$inline_6596_y1$jscomp$inline_12416_y1__$1$jscomp$inline_12420$$,
$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$,$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$),
$APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1890$svg_attrs$$,$cljs$cst$1893$svg_viewbox$$,$cljs$cst$2943$svg_defs$$,$APP.$cljs$cst$1607$frame_id$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1522$height$$],[$attrs$jscomp$inline_12413_attrs$jscomp$inline_12430_attrs$jscomp$inline_6605_attrs$jscomp$inline_6610_attrs__$1$jscomp$inline_12423_attrs__$1$jscomp$inline_6606_attrs__$1$jscomp$inline_6611_props$jscomp$inline_12438_transform$jscomp$inline_6592_vbox$jscomp$inline_6575_vec__67026$jscomp$inline_6586_y$jscomp$inline_6555_y$jscomp$inline_6619$$,
$map__66978__$1$jscomp$inline_6625_map__67002__$1$jscomp$inline_6561_transform$jscomp$inline_6563$$,$name$jscomp$307$$,$cy$jscomp$inline_6588_cy__$1$jscomp$inline_6598_image_data$jscomp$inline_12434_image_url$jscomp$inline_12432_or__5025__auto__$jscomp$inline_12433_origin$jscomp$inline_6574_rect$jscomp$inline_6576_rect$jscomp$inline_6600_width$jscomp$inline_6556_width$jscomp$inline_6620_x2$jscomp$inline_12417_x2__$1$jscomp$inline_12421$$,$APP.$cljs$cst$1613$svg_raw$$,$attrs$jscomp$inline_6562_attrs$jscomp$inline_6626_attrs__$1$jscomp$inline_6564_props$jscomp$inline_6627$$,
$attrs$jscomp$inline_6572_offset_x$jscomp$inline_6558_offset_x$jscomp$inline_6622_origin$jscomp$inline_12436_r$jscomp$inline_6589_radius$jscomp$inline_12409_radius_attrs$jscomp$inline_6578_rect$jscomp$inline_12437_rx__$2$jscomp$inline_6595_vbox$jscomp$inline_6628_x1$jscomp$inline_12415_x1__$1$jscomp$inline_12419$$,$defs$jscomp$inline_6560_defs$jscomp$inline_6624_map__66977__$1$jscomp$inline_6617_map__67001__$1$jscomp$inline_6553_origin$jscomp$inline_6599_ry$jscomp$inline_6591_ry__$1$jscomp$inline_6594_ry_val$jscomp$inline_12408$$,
$frame_id$jscomp$63$$,$JSCompiler_inline_result$jscomp$10794_JSCompiler_inline_result$jscomp$942_JSCompiler_inline_result$jscomp$943_attrs$jscomp$inline_6585_map__52230__$1$jscomp$inline_6604_map__52234__$1$jscomp$inline_6609_map__52241__$1$jscomp$inline_12412_map__67019__$1$jscomp$inline_6571_map__67024__$1$jscomp$inline_6584_map__67041__$1$jscomp$inline_12429_props$jscomp$inline_6601_transform$jscomp$inline_12431_transform$jscomp$inline_6573_x$jscomp$inline_6554_x$jscomp$inline_6618$$,$cx$jscomp$inline_6587_cx__$1$jscomp$inline_6597_height$jscomp$inline_6557_height$jscomp$inline_6621_map__52242__$1$jscomp$inline_12414_metadata$jscomp$inline_12435_props$jscomp$inline_6577_y2$jscomp$inline_12418_y2__$1$jscomp$inline_12422$$]))}}();
return $shape$jscomp$455$$!=null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[function(){var $G__67130$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($app$common$files$shapes_builder$setup_other$$($app$common$files$shapes_builder$setup_opacity$$($app$common$files$shapes_builder$setup_stroke$$($app$common$files$shapes_builder$setup_fill$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$455$$,$cljs$cst$2943$svg_defs$$,
$APP.$cljs$core$select_keys$$($defs$jscomp$11$$,$references$jscomp$2$$)))))),$APP.$cljs$cst$1890$svg_attrs$$,function($attrs__$1$jscomp$13$$){return $APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1904$style$$.$cljs$core$IFn$_invoke$arity$1$($attrs__$1$jscomp$13$$))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($attrs__$1$jscomp$13$$,$APP.$cljs$cst$1904$style$$):$attrs__$1$jscomp$13$$});return $hidden$jscomp$9$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__67130$$,$APP.$cljs$cst$1620$hidden$$,
!0):$G__67130$$}(),function(){var $G__67134$$=$APP.$cljs$cst$1637$content$$.$cljs$core$IFn$_invoke$arity$1$($map__67097__$1$$);return $APP.$cljs$core$contains_QMARK_$$($app$common$svg$parent_tags$$,$tag$jscomp$70$$)?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$svg$inherit_attributes$$,$attrs$jscomp$98$$),$G__67134$$):$G__67134$$}()],null):null};var $app$main$data$workspace$svg_upload$add_svg_shapes_67442$$;var $shadow$js$shim$module$0sax$$=shadow$bridge("sax");var $app$main$data$workspace$media$image_uploaded_67695$$,$app$main$data$workspace$media$svg_uploaded_67710$$,$app$main$data$workspace$media$process_media_objects_67745$$;$APP.$app$main$data$workspace$media$accept_image_types$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$app$common$media$image_types$$);var $shadow$js$shim$module$0$0penpot$0text_editor$$=shadow$bridge("@penpot/text-editor");var $app$main$data$workspace$layout$toggle_layout_flag_67149$$,$app$main$data$workspace$layout$remove_layout_flag_67161$$,$app$main$data$workspace$layout$set_options_mode_67178$$,$app$main$data$workspace$layout$layout_flags_persistence_mapping$$;
$APP.$app$main$data$workspace$layout$presets$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3718$assets$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3729$del$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3714$sitemap$$,null,$APP.$cljs$cst$3719$document_history$$,null,$APP.$cljs$cst$3727$layers$$,null],null),null),$APP.$cljs$cst$3730$add$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3718$assets$$,null],null),null)],null),$APP.$cljs$cst$3719$document_history$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3729$del$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3714$sitemap$$,null,$APP.$cljs$cst$3718$assets$$,null,$APP.$cljs$cst$3727$layers$$,null],null),null),$APP.$cljs$cst$3730$add$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3719$document_history$$,
null],null),null)],null),$APP.$cljs$cst$3727$layers$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3729$del$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3718$assets$$,null,$APP.$cljs$cst$3719$document_history$$,null],null),null),$APP.$cljs$cst$3730$add$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3714$sitemap$$,null,$APP.$cljs$cst$3727$layers$$,null],
null),null)],null),$APP.$cljs$cst$2100$tokens$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3729$del$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3714$sitemap$$,null,$APP.$cljs$cst$3718$assets$$,null,$APP.$cljs$cst$3719$document_history$$,null,$APP.$cljs$cst$3727$layers$$,null],null),null),$APP.$cljs$cst$3730$add$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2100$tokens$$,
null],null),null)],null)],null);
$APP.$app$main$data$workspace$layout$default_layout$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,11,[$APP.$cljs$cst$3714$sitemap$$,null,$APP.$cljs$cst$2210$snap_pixel_grid$$,null,$APP.$cljs$cst$3717$show_pixel_grid$$,null,$APP.$cljs$cst$3720$snap_guides$$,null,$APP.$cljs$cst$3722$display_artboard_names$$,null,$APP.$cljs$cst$2211$rulers$$,null,$APP.$cljs$cst$3723$snap_ruler_guides$$,null,$APP.$cljs$cst$3724$dynamic_alignment$$,null,$APP.$cljs$cst$3725$display_guides$$,
null,$APP.$cljs$cst$3727$layers$$,null,$cljs$cst$3728$element_options$$,null],null),null);$APP.$app$main$data$workspace$layout$default_global$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2200$options_mode$$,$APP.$cljs$cst$3732$design$$],null);
$APP.$app$main$data$workspace$layout$toggle_layout_flag$$=function $app$main$data$workspace$layout$toggle_layout_flag$$($var_args$jscomp$1222$$){for(var $args__5755__auto__$jscomp$223$$=[],$len__5749__auto___67248$$=arguments.length,$i__5750__auto___67249$$=0;;)if($i__5750__auto___67249$$<$len__5749__auto___67248$$)$args__5755__auto__$jscomp$223$$.push(arguments[$i__5750__auto___67249$$]),$i__5750__auto___67249$$+=1;else break;return $app$main$data$workspace$layout$toggle_layout_flag$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],
1<$args__5755__auto__$jscomp$223$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$223$$.slice(1),0,null):null)};
$APP.$app$main$data$workspace$layout$toggle_layout_flag$$.$cljs$core$IFn$_invoke$arity$variadic$=function($flag$jscomp$6$$,$p__67147$$){var $map__67148__$1$$=$APP.$cljs$core$__destructure_map$$($p__67147$$),$force_QMARK_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67148__$1$$,$APP.$cljs$cst$3734$force_QMARK_$$);typeof $app$main$data$workspace$layout$toggle_layout_flag_67149$$==="undefined"&&($app$main$data$workspace$layout$toggle_layout_flag_67149$$=function($flag$jscomp$7$$,
$p__67147$jscomp$1$$,$map__67148$jscomp$1$$,$opts$jscomp$298$$,$force_QMARK_$jscomp$4$$,$meta67150$$){this.$flag$=$flag$jscomp$7$$;this.$p__67147$=$p__67147$jscomp$1$$;this.$map__67148$=$map__67148$jscomp$1$$;this.$opts$=$opts$jscomp$298$$;this.$force_QMARK_$=$force_QMARK_$jscomp$4$$;this.$meta67150$=$meta67150$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$layout$toggle_layout_flag_67149$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layout$toggle_layout_flag_67149$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3735$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_toggle_layout_flag$$},$app$main$data$workspace$layout$toggle_layout_flag_67149$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67151$$,$meta67150__$1$$){return new $app$main$data$workspace$layout$toggle_layout_flag_67149$$(this.$flag$,this.$p__67147$,this.$map__67148$,
this.$opts$,this.$force_QMARK_$,$meta67150__$1$$)},$app$main$data$workspace$layout$toggle_layout_flag_67149$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67150$},$app$main$data$workspace$layout$toggle_layout_flag_67149$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layout$toggle_layout_flag_67149$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,
this.$flag$],null)},$app$main$data$workspace$layout$toggle_layout_flag_67149$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layout$toggle_layout_flag_67149$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1987$$,$state$jscomp$410$$){var $self__$jscomp$4437$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$410$$,$APP.$cljs$cst$2209$workspace_layout$$,function($flags$jscomp$31$$){return $APP.$cljs$core$truth_$$($self__$jscomp$4437$$.$force_QMARK_$)?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($flags$jscomp$31$$,$self__$jscomp$4437$$.$flag$):$APP.$cljs$core$contains_QMARK_$$($flags$jscomp$31$$,$self__$jscomp$4437$$.$flag$)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($flags$jscomp$31$$,$self__$jscomp$4437$$.$flag$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($flags$jscomp$31$$,$self__$jscomp$4437$$.$flag$)})},$app$main$data$workspace$layout$toggle_layout_flag_67149$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$layout$toggle_layout_flag_67149$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1988_flags$jscomp$32$$,$state$jscomp$411$$){$_$jscomp$1988_flags$jscomp$32$$=$APP.$cljs$cst$2209$workspace_layout$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$411$$);return $app$main$data$workspace$layout$persist_layout_flags_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$layout$persist_layout_flags_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1988_flags$jscomp$32$$):
$app$main$data$workspace$layout$persist_layout_flags_BANG_$$($_$jscomp$1988_flags$jscomp$32$$)});return new $app$main$data$workspace$layout$toggle_layout_flag_67149$$($flag$jscomp$6$$,$p__67147$$,$map__67148__$1$$,$map__67148__$1$$,$force_QMARK_$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$main$data$workspace$layout$toggle_layout_flag$$.$cljs$lang$maxFixedArity$=1;
$APP.$app$main$data$workspace$layout$toggle_layout_flag$$.$cljs$lang$applyTo$=function($seq67145_seq67145__$1$$){var $G__67146$$=$APP.$cljs$core$first$$($seq67145_seq67145__$1$$);$seq67145_seq67145__$1$$=$APP.$cljs$core$next$$($seq67145_seq67145__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__67146$$,$seq67145_seq67145__$1$$)};
$app$main$data$workspace$layout$layout_flags_persistence_mapping$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3726$hide_palettes$$,$cljs$cst$3738$app_DOT_main_DOT_data_DOT_workspace_SLASH_hide_palettes_QMARK_$$,$APP.$cljs$cst$3715$colorpalette$$,$cljs$cst$3739$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_colorpalette_QMARK_$$,$APP.$cljs$cst$3740$textpalette$$,$cljs$cst$3741$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_textpalette_QMARK_$$,$APP.$cljs$cst$2211$rulers$$,$cljs$cst$3742$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_rulers_QMARK_$$],
null);$APP.$app$main$data$workspace$layout$layout_state_persistence_mapping$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$3744$selected_palette$$,$cljs$cst$3745$app_DOT_main_DOT_data_DOT_workspace_SLASH_selected_palette$$,$cljs$cst$3746$selected_palette_colorpicker$$,$cljs$cst$3747$app_DOT_main_DOT_data_DOT_workspace_SLASH_selected_palette_colorpicker$$],null);var $app$main$data$workspace$common$set_workspace_visited_67261$$,$app$main$data$workspace$common$show_toolbar_67275$$,$app$main$data$workspace$common$set_workspace_read_only_67310$$;$APP.$app$common$logging$loggers$$.set("app.main.data.workspace.common",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));var $app$common$logic$variants$generate_path$$=function $app$common$logic$variants$generate_path$$($G__67174_path$jscomp$235$$,$objects$jscomp$363$$,$base_id$jscomp$3$$,$G__67177_shape$jscomp$459$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($base_id$jscomp$3$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__67177_shape$jscomp$459$$)))return $G__67174_path$jscomp$235$$;$G__67174_path$jscomp$235$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__67174_path$jscomp$235$$),
" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($G__67177_shape$jscomp$459$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__67170_SHARP_$$){switch($p1__67170_SHARP_$$ instanceof $APP.$cljs$core$Keyword$$?$p1__67170_SHARP_$$.$fqn$:null){case "frame":return $APP.$cljs$cst$2588$container$$;case "group":return $APP.$cljs$cst$2588$container$$;case "rect":return $APP.$cljs$cst$1811$shape$$;case "circle":return $APP.$cljs$cst$1811$shape$$;
case "bool":return $APP.$cljs$cst$1811$shape$$;case "path":return $APP.$cljs$cst$1811$shape$$;default:return $p1__67170_SHARP_$$}}($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__67177_shape$jscomp$459$$)))].join("");$G__67177_shape$jscomp$459$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$363$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($G__67177_shape$jscomp$459$$));return $app$common$logic$variants$generate_path$$.$cljs$core$IFn$_invoke$arity$4$?
$app$common$logic$variants$generate_path$$.$cljs$core$IFn$_invoke$arity$4$($G__67174_path$jscomp$235$$,$objects$jscomp$363$$,$base_id$jscomp$3$$,$G__67177_shape$jscomp$459$$):$app$common$logic$variants$generate_path$$($G__67174_path$jscomp$235$$,$objects$jscomp$363$$,$base_id$jscomp$3$$,$G__67177_shape$jscomp$459$$)},$app$common$logic$variants$find_shape_ref_child_of$$=function $app$common$logic$variants$find_shape_ref_child_of$$($container$jscomp$67_ref_shape$jscomp$4$$,$libraries$jscomp$65$$,$ref_shape_container_shape$jscomp$463$$,
$parent_id$jscomp$69$$){$container$jscomp$67_ref_shape$jscomp$4$$=$app$common$types$file$find_ref_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(null,$container$jscomp$67_ref_shape$jscomp$4$$,$libraries$jscomp$65$$,$ref_shape_container_shape$jscomp$463$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$2591$with_context_QMARK_$$,!0]));$ref_shape_container_shape$jscomp$463$$=$APP.$cljs$core$truth_$$($container$jscomp$67_ref_shape$jscomp$4$$)?$APP.$cljs$cst$2588$container$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($container$jscomp$67_ref_shape$jscomp$4$$)):
null;var $ref_shape_parents_set$$=$APP.$cljs$core$truth_$$($container$jscomp$67_ref_shape$jscomp$4$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$app$common$data$xf_COLON_map_id$$,$app$common$files$helpers$get_parents_with_self$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($ref_shape_container_shape$jscomp$463$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$67_ref_shape$jscomp$4$$))):null;return $container$jscomp$67_ref_shape$jscomp$4$$==
null||$APP.$cljs$core$contains_QMARK_$$($ref_shape_parents_set$$,$parent_id$jscomp$69$$)?$container$jscomp$67_ref_shape$jscomp$4$$:$app$common$logic$variants$find_shape_ref_child_of$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$logic$variants$find_shape_ref_child_of$$.$cljs$core$IFn$_invoke$arity$4$($ref_shape_container_shape$jscomp$463$$,$libraries$jscomp$65$$,$container$jscomp$67_ref_shape$jscomp$4$$,$parent_id$jscomp$69$$):$app$common$logic$variants$find_shape_ref_child_of$$($ref_shape_container_shape$jscomp$463$$,
$libraries$jscomp$65$$,$container$jscomp$67_ref_shape$jscomp$4$$,$parent_id$jscomp$69$$)};var $app$main$data$workspace$groups$group_shapes_67504$$,$app$main$data$workspace$groups$group_selected_67515$$,$app$main$data$workspace$groups$ungroup_shapes_67532$$,$app$main$data$workspace$groups$ungroup_selected_67543$$,$app$main$data$workspace$groups$mask_group_67555$$,$app$main$data$workspace$groups$unmask_group_67575$$;$APP.$app$main$rasterizer$ready_QMARK_$$=!1;$APP.$app$main$rasterizer$queue$$=[];$APP.$app$main$rasterizer$instance$$=null;$APP.$app$main$rasterizer$msgbus$$=$APP.$beicon$v2$core$subject$$();$APP.$app$main$rasterizer$origin$$=""+($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$rasterizer_uri$$,"rasterizer.html"]))??"");var $app$main$ui$shapes$svg_defs$svg_node$$=function $app$main$ui$shapes$svg_defs$svg_node$$($props_67819_tag$jscomp$75$$){var $transform$jscomp$90$$=$props_67819_tag$jscomp$75$$.transform,$type$jscomp$477$$=$props_67819_tag$jscomp$75$$.type,$content$jscomp$167_map__67820__$1_node$jscomp$305$$=$props_67819_tag$jscomp$75$$.node,$bounds$jscomp$30$$=$props_67819_tag$jscomp$75$$.bounds,$prefix_id$$=$props_67819_tag$jscomp$75$$["prefix-id"];if(typeof $content$jscomp$167_map__67820__$1_node$jscomp$305$$===
"string")return $content$jscomp$167_map__67820__$1_node$jscomp$305$$;$content$jscomp$167_map__67820__$1_node$jscomp$305$$=$APP.$cljs$core$__destructure_map$$($content$jscomp$167_map__67820__$1_node$jscomp$305$$);$props_67819_tag$jscomp$75$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$167_map__67820__$1_node$jscomp$305$$,$APP.$cljs$cst$78$tag$$);var $attrs$jscomp$101$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$167_map__67820__$1_node$jscomp$305$$,
$APP.$cljs$cst$2645$attrs$$);$content$jscomp$167_map__67820__$1_node$jscomp$305$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$167_map__67820__$1_node$jscomp$305$$,$APP.$cljs$cst$1637$content$$);var $transform_gradient_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($app$common$svg$gradient_tags$$,$props_67819_tag$jscomp$75$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("userSpaceOnUse",$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$101$$,$cljs$cst$2753$gradientUnits$$,
"objectBoundingBox")),$transform_pattern_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$1844$pattern$$,$props_67819_tag$jscomp$75$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("userSpaceOnUse",$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$101$$,$cljs$cst$2782$patternContentUnits$$,"userSpaceOnUse"))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("userSpaceOnUse",$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$101$$,
$cljs$cst$2776$patternUnits$$,"userSpaceOnUse")),$transform_clippath_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$2690$clipPath$$,$props_67819_tag$jscomp$75$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("userSpaceOnUse",$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$101$$,$cljs$cst$2802$clipPathUnits$$,"userSpaceOnUse")),$transform_filter_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($app$common$svg$filter_tags$$,$props_67819_tag$jscomp$75$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("userSpaceOnUse",$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$101$$,$cljs$cst$2789$filterUnits$$,"objectBoundingBox")),$transform_mask_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2689$mask$$,$props_67819_tag$jscomp$75$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("userSpaceOnUse",$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$101$$,$cljs$cst$2818$maskUnits$$,
"objectBoundingBox")),$attrs__$1$jscomp$15_wrapper$jscomp$7$$=function(){var $G__67824_G__67824__$1_G__67824__$2_G__67824__$3$$=function(){var $G__67825$$=$app$common$svg$attrs__GT_props$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$svg$update_attr_ids$$($attrs$jscomp$101$$,$prefix_id$$));return($transform_gradient_QMARK_$$||$transform_pattern_QMARK_$$||$transform_clippath_QMARK_$$||$transform_filter_QMARK_$$||$transform_mask_QMARK_$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,
$type$jscomp$477$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__67825$$,$cljs$cst$2937$className$$,function($p1__67818_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__67818_SHARP_$$)?""+($p1__67818_SHARP_$$??"")+" svg-def":"svg-def"}):$G__67825$$}();$G__67824_G__67824__$1_G__67824__$2_G__67824__$3$$=$transform_gradient_QMARK_$$?$app$main$ui$shapes$svg_defs$add_matrix$$($G__67824_G__67824__$1_G__67824__$2_G__67824__$3$$,$cljs$cst$2889$gradientTransform$$,$transform$jscomp$90$$):$G__67824_G__67824__$1_G__67824__$2_G__67824__$3$$;
$G__67824_G__67824__$1_G__67824__$2_G__67824__$3$$=$transform_pattern_QMARK_$$?$app$main$ui$shapes$svg_defs$add_matrix$$($G__67824_G__67824__$1_G__67824__$2_G__67824__$3$$,$cljs$cst$2873$patternTransform$$,$transform$jscomp$90$$):$G__67824_G__67824__$1_G__67824__$2_G__67824__$3$$;$G__67824_G__67824__$1_G__67824__$2_G__67824__$3$$=$transform_clippath_QMARK_$$?$app$main$ui$shapes$svg_defs$add_matrix$$($G__67824_G__67824__$1_G__67824__$2_G__67824__$3$$,$APP.$cljs$cst$1289$transform$$,$transform$jscomp$90$$):
$G__67824_G__67824__$1_G__67824__$2_G__67824__$3$$;return $transform_filter_QMARK_$$||$transform_mask_QMARK_$$?$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__67824_G__67824__$1_G__67824__$2_G__67824__$3$$,$bounds$jscomp$30$$])):$G__67824_G__67824__$1_G__67824__$2_G__67824__$3$$}(),$attrs__$2$jscomp$3_props$jscomp$175$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_67819_tag$jscomp$75$$,$APP.$cljs$cst$2691$filter$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_67819_tag$jscomp$75$$,$APP.$cljs$cst$2689$mask$$)?$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs__$1$jscomp$15_wrapper$jscomp$7$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$3771$data_old_x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($attrs__$1$jscomp$15_wrapper$jscomp$7$$),$cljs$cst$3772$data_old_y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($attrs__$1$jscomp$15_wrapper$jscomp$7$$),
$cljs$cst$3773$data_old_width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($attrs__$1$jscomp$15_wrapper$jscomp$7$$),$cljs$cst$3774$data_old_height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($attrs__$1$jscomp$15_wrapper$jscomp$7$$)],null)])):$attrs__$1$jscomp$15_wrapper$jscomp$7$$,$vec__67821_wrapper_props$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_67819_tag$jscomp$75$$,$APP.$cljs$cst$2689$mask$$)?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["g",{className:"svg-mask-wrapper",transform:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($transform$jscomp$90$$)}],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$rumext$v2$Fragment$$,{}],null);$attrs__$1$jscomp$15_wrapper$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__67821_wrapper_props$$,0,null);$vec__67821_wrapper_props$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__67821_wrapper_props$$,
1,null);$attrs__$2$jscomp$3_props$jscomp$175$$=$APP.$app$common$json$__GT_js$$.$cljs$core$IFn$_invoke$arity$variadic$($attrs__$2$jscomp$3_props$jscomp$175$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$291$key_fn$$,$APP.$cljs$core$name$$]));return(0,$APP.$rumext$v2$create_element$$)($APP.$cljs$core$name$$($props_67819_tag$jscomp$75$$),$attrs__$2$jscomp$3_props$jscomp$175$$,(0,$APP.$rumext$v2$create_element$$)($attrs__$1$jscomp$15_wrapper$jscomp$7$$,$vec__67821_wrapper_props$$,
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$25$$,$node__$1$jscomp$68_p__67827$$){var $index$jscomp$284$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($node__$1$jscomp$68_p__67827$$,0,null);$node__$1$jscomp$68_p__67827$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($node__$1$jscomp$68_p__67827$$,1,null);$out_arr__44124__auto__$jscomp$25$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$svg_defs$svg_node$$,{type:$type$jscomp$477$$,
node:$node__$1$jscomp$68_p__67827$$,"prefix-id":$prefix_id$$,transform:$transform$jscomp$90$$,bounds:$bounds$jscomp$30$$},"node-"+($index$jscomp$284$$??"")));return $out_arr__44124__auto__$jscomp$25$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$167_map__67820__$1_node$jscomp$305$$))))};$APP.$app$main$ui$shapes$shape$shape_container$$=(0,$APP.$rumext$v2$forward_ref$$)(function($props_67842_wrapper_props__$1$$,$ref$jscomp$30$$){var $shape$jscomp$490$$=$props_67842_wrapper_props__$1$$.shape,$children$jscomp$221_children__$1$jscomp$26$$=$props_67842_wrapper_props__$1$$.children,$pointer_events$$=$props_67842_wrapper_props__$1$$["pointer-events"],$shape_id$jscomp$86$$=$shape$jscomp$490$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$490$$,$APP.$cljs$cst$266$id$$),
$preview_blend_mode_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$86$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$okulary$core$key$$($shape_id$jscomp$86$$),$APP.$app$main$refs$workspace_preview_blend$$,$APP.$cljs$core$_EQ_$$)}),$blend_mode$jscomp$3$$=function(){var $or__5025__auto__$jscomp$741$$=$APP.$rumext$v2$deref$$($preview_blend_mode_ref$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$741$$)?
$or__5025__auto__$jscomp$741$$:$APP.$cljs$cst$1867$blend_mode$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$490$$)}(),$type$jscomp$478$$=$shape$jscomp$490$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$490$$,$APP.$cljs$cst$139$type$$),$render_id$jscomp$37$$=$app$main$ui$hooks$use_render_id$$(),$styles$jscomp$12$$=function(){var $G__67843_G__67844$jscomp$inline_12462_G__67845$jscomp$inline_12463$$=$APP.$app$util$object$set_BANG_$$({},"pointerEvents",$pointer_events$$);
$G__67843_G__67844$jscomp$inline_12462_G__67845$jscomp$inline_12463$$=$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$490$$)?$G__67843_G__67844$jscomp$inline_12462_G__67845$jscomp$inline_12463$$:$APP.$app$util$object$set_BANG_$$($G__67843_G__67844$jscomp$inline_12462_G__67845$jscomp$inline_12463$$,"opacity",$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$490$$));$G__67843_G__67844$jscomp$inline_12462_G__67845$jscomp$inline_12463$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$490$$))?$APP.$app$util$object$set_BANG_$$($G__67843_G__67844$jscomp$inline_12462_G__67845$jscomp$inline_12463$$,"display","none"):$G__67843_G__67844$jscomp$inline_12462_G__67845$jscomp$inline_12463$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($blend_mode$jscomp$3$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($blend_mode$jscomp$3$$,$APP.$cljs$cst$2023$normal$$):$blend_mode$jscomp$3$$)?
$APP.$app$util$object$set_BANG_$$($G__67843_G__67844$jscomp$inline_12462_G__67845$jscomp$inline_12463$$,"mixBlendMode",$APP.$app$common$data$name$$($blend_mode$jscomp$3$$)):$G__67843_G__67844$jscomp$inline_12462_G__67845$jscomp$inline_12463$$}(),$include_metadata_QMARK_$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$shapes$export$0$include_metadata_ctx$$),$shape_without_blur$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$490$$,$APP.$cljs$cst$1653$blur$$),$shape_without_shadows$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$490$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$filter_id$jscomp$8$$="filter-"+($render_id$jscomp$37$$??""),$filter_str$$=$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$490$$)||$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$490$$)?$app$main$ui$shapes$filters$filter_str$$($filter_id$jscomp$8$$,$shape$jscomp$490$$):
null,$wrapper_props$jscomp$3$$=$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$clone$$($props_67842_wrapper_props__$1$$),"shape"),"children"),"ref",$ref$jscomp$30$$),"id","shape-"+($shape_id$jscomp$86$$??"")),"style",$styles$jscomp$12$$);$props_67842_wrapper_props__$1$$=function(){var $G__67846__$1_G__67846__$2$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$490$$)&&
$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1891$position_data$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$490$$))?$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($wrapper_props$jscomp$3$$,"x",$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$490$$)),"y",$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$490$$)),"width",$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$490$$)),
"height",$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$490$$)):$wrapper_props$jscomp$3$$;$G__67846__$1_G__67846__$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,$type$jscomp$478$$)?$app$main$ui$shapes$attrs$add_border_props_BANG_$$($app$main$ui$shapes$attrs$add_fill_props_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67846__$1_G__67846__$2$$,$shape$jscomp$490$$,$render_id$jscomp$37$$),$shape$jscomp$490$$):$G__67846__$1_G__67846__$2$$;
return $filter_str$$!=null?$APP.$app$util$object$set_BANG_$$($G__67846__$1_G__67846__$2$$,"filter",$filter_str$$):$G__67846__$1_G__67846__$2$$}();$children$jscomp$221_children__$1$jscomp$26$$=$APP.$cljs$core$contains_QMARK_$$($shape$jscomp$490$$,$APP.$cljs$cst$1890$svg_attrs$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1608$group$$,$type$jscomp$478$$)?$app$main$ui$shapes$shape$propagate_wrapper_styles$$($children$jscomp$221_children__$1$jscomp$26$$,$props_67842_wrapper_props__$1$$):
$children$jscomp$221_children__$1$jscomp$26$$;return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($app$main$ui$context$render_id$$),{value:$render_id$jscomp$37$$,children:(0,$APP.$rumext$v2$create_element$$)("g",$props_67842_wrapper_props__$1$$,$APP.$cljs$core$truth_$$($include_metadata_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$export$0$export_data$$,{shape:$shape$jscomp$490$$}):null,(0,$APP.$rumext$v2$jsxs$$)("defs",{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$svg_defs$svg_defs$$,
{shape:$shape$jscomp$490$$,"render-id":$render_id$jscomp$37$$}),$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$490$$)?null:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$filters$filters$$,{shape:$shape$jscomp$490$$,"filter-id":$filter_id$jscomp$8$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$filters$filters$$,{shape:$shape_without_blur$$,"filter-id":"filter-shadow-"+($render_id$jscomp$37$$??
"")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$filters$filters$$,{shape:$shape_without_shadows$$,"filter-id":"filter-blur-"+($render_id$jscomp$37$$??"")})]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$frame$frame_clip_def$$,{shape:$shape$jscomp$490$$,"render-id":$render_id$jscomp$37$$}),$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$490$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$fills$fills$$,{shape:$shape$jscomp$490$$,"render-id":$render_id$jscomp$37$$})]}),
$children$jscomp$221_children__$1$jscomp$26$$)})});var $app$main$ui$shapes$svg_raw$svg_ids_ctx$$;
$APP.$app$main$ui$shapes$svg_raw$graphic_element$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,13,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$2696$textPath$$,null,$cljs$cst$2703$use$$,null,$APP.$cljs$cst$219$symbol$$,null,$APP.$cljs$cst$1417$circle$$,null,$APP.$cljs$cst$209$line$$,null,$APP.$cljs$cst$1538$svg$$,null,$APP.$cljs$cst$2730$ellipse$$,null,$APP.$cljs$cst$1612$image$$,null,$APP.$cljs$cst$2743$polyline$$,null,$APP.$cljs$cst$1611$rect$$,null,
$APP.$cljs$cst$2750$polygon$$,null,$APP.$cljs$cst$1588$text$$,null],null),null);$app$main$ui$shapes$svg_raw$svg_ids_ctx$$=(0,$APP.$rumext$v2$create_context$$)(null);(function($p1__67853_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__67853_SHARP_$$,function($new_props_67855$$,$old_props_67856$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_67855$$.fonts,$old_props_67856$$.fonts)})})(function($fonts_css_props_67854$$){$fonts_css_props_67854$$=$app$main$ui$shapes$text$fontfaces$use_fonts_css$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fonts_css_props_67854$$,"fonts"));return(0,$APP.$rumext$v2$jsx$$)("style",
{children:$fonts_css_props_67854$$})});
var $app$main$ui$shapes$text$fontfaces$fontfaces_style_render$$=function($p1__67857_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__67857_SHARP_$$,function($new_props_67859$$,$old_props_67860$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_67859$$.fonts,$old_props_67860$$.fonts)})}(function($fonts_css$jscomp$1_props_67858$$){$fonts_css$jscomp$1_props_67858$$=$app$main$ui$shapes$text$fontfaces$use_fonts_css$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fonts_css$jscomp$1_props_67858$$,"fonts"));
return(0,$APP.$rumext$v2$jsx$$)("style",{children:$fonts_css$jscomp$1_props_67858$$})}),$app$main$ui$shapes$text$fontfaces$fontfaces_style$$=function($p1__67862_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__67862_SHARP_$$,function($new_props_67864$$,$old_props_67865$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_67864$$.fonts,$old_props_67865$$.fonts)})}(function($fonts$jscomp$17_props_67863$$){$fonts$jscomp$17_props_67863$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fonts$jscomp$17_props_67863$$,
"fonts");return $APP.$app$common$data$not_empty_QMARK_$$($fonts$jscomp$17_props_67863$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$text$fontfaces$fontfaces_style_render$$,{fonts:$fonts$jscomp$17_props_67863$$}):null});var $p1__67907_SHARP_$jscomp$inline_6671$$,$p1__67919_SHARP_$jscomp$inline_6673$$,$app$main$render$objects_svg$$;$app$render_wasm$api$shape_wrapper_factory$$=$APP.$app$main$render$shape_wrapper_factory$$;
$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($data$jscomp$330_map__67896_props_67895$$){$data$jscomp$330_map__67896_props_67895$$=$APP.$rumext$v2$util$wrap_props$$($data$jscomp$330_map__67896_props_67895$$);var $aspect_ratio$jscomp$3_dim_map__67896__$1_vbox$jscomp$10$$=$APP.$cljs$core$__destructure_map$$($data$jscomp$330_map__67896_props_67895$$);$data$jscomp$330_map__67896_props_67895$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($aspect_ratio$jscomp$3_dim_map__67896__$1_vbox$jscomp$10$$,
$APP.$cljs$cst$142$data$$);var $use_thumbnails$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($aspect_ratio$jscomp$3_dim_map__67896__$1_vbox$jscomp$10$$,$cljs$cst$3775$use_thumbnails$$),$embed$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($aspect_ratio$jscomp$3_dim_map__67896__$1_vbox$jscomp$10$$,$APP.$cljs$cst$3776$embed$$,!1),$include_metadata$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($aspect_ratio$jscomp$3_dim_map__67896__$1_vbox$jscomp$10$$,$cljs$cst$3777$include_metadata$$,
!1);$aspect_ratio$jscomp$3_dim_map__67896__$1_vbox$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($aspect_ratio$jscomp$3_dim_map__67896__$1_vbox$jscomp$10$$,$cljs$cst$3778$aspect_ratio$$);var $objects$jscomp$388$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$330_map__67896_props_67895$$),$shapes$jscomp$66$$=$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$388$$,$APP.$app$common$uuid$zero$$,null);
$aspect_ratio$jscomp$3_dim_map__67896__$1_vbox$jscomp$10$$=$app$main$render$calculate_dimensions$$($objects$jscomp$388$$,$aspect_ratio$jscomp$3_dim_map__67896__$1_vbox$jscomp$10$$);$aspect_ratio$jscomp$3_dim_map__67896__$1_vbox$jscomp$10$$=$APP.$app$main$render$format_viewbox$$($aspect_ratio$jscomp$3_dim_map__67896__$1_vbox$jscomp$10$$);var $bgcolor$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$330_map__67896_props_67895$$,$APP.$cljs$cst$2058$background$$,"#E8E9EA"),$shape_wrapper$jscomp$10$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$388$$)],function(){return $APP.$app$main$render$shape_wrapper_factory$$($objects$jscomp$388$$)});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$render_thumbnails$$),{value:$use_thumbnails$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$shapes$embed$context$$),{value:$embed$jscomp$4$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$shapes$export$0$include_metadata_ctx$$),
{value:$include_metadata$$,children:(0,$APP.$rumext$v2$jsxs$$)("svg",{viewBox:$aspect_ratio$jscomp$3_dim_map__67896__$1_vbox$jscomp$10$$,version:"1.1",xmlns:"http://www.w3.org/2000/svg",xmlnsXlink:"http://www.w3.org/1999/xlink","xmlns:penpot":$APP.$cljs$core$truth_$$($include_metadata$$)?"https://penpot.app/xmlns":null,style:{width:"100%",height:"100%",background:$bgcolor$$},fill:"none",children:[$APP.$cljs$core$truth_$$($include_metadata$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$shapes$export$0$export_page$$,
{page:$data$jscomp$330_map__67896_props_67895$$}):null,function(){var $fonts$jscomp$18_shapes__$1$jscomp$9$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__67894_SHARP_$$){return $APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$388$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__67894_SHARP_$$))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,
$shapes$jscomp$66$$)]));$fonts$jscomp$18_shapes__$1$jscomp$9$$=$APP.$app$main$ui$shapes$text$fontfaces$shapes__GT_fonts$$($fonts$jscomp$18_shapes__$1$jscomp$9$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$text$fontfaces$fontfaces_style$$,{fonts:$fonts$jscomp$18_shapes__$1$jscomp$9$$})}(),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$29$$,$item$jscomp$81$$){$out_arr__44124__auto__$jscomp$29$$.push((0,$APP.$rumext$v2$jsx$$)($shape_wrapper$jscomp$10$$,
{shape:$item$jscomp$81$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$81$$)));return $out_arr__44124__auto__$jscomp$29$$},[],$shapes$jscomp$66$$)]})})})})});
$APP.$app$main$render$frame_svg$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__67901_props_67900_use_thumbnails$jscomp$1$$){$map__67901_props_67900_use_thumbnails$jscomp$1$$=$APP.$rumext$v2$util$wrap_props$$($map__67901_props_67900_use_thumbnails$jscomp$1$$);var $background_color_bgcolor$jscomp$1_map__67901__$1$$=$APP.$cljs$core$__destructure_map$$($map__67901_props_67900_use_thumbnails$jscomp$1$$),$objects$jscomp$390$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($background_color_bgcolor$jscomp$1_map__67901__$1$$,
$APP.$cljs$cst$1631$objects$$),$frame$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($background_color_bgcolor$jscomp$1_map__67901__$1$$,$APP.$cljs$cst$1606$frame$$),$height$jscomp$109_zoom$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($background_color_bgcolor$jscomp$1_map__67901__$1$$,$APP.$cljs$cst$2196$zoom$$,1);$map__67901_props_67900_use_thumbnails$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($background_color_bgcolor$jscomp$1_map__67901__$1$$,
$cljs$cst$3775$use_thumbnails$$);var $aspect_ratio$jscomp$4_bounds$jscomp$32_vbox$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($background_color_bgcolor$jscomp$1_map__67901__$1$$,$cljs$cst$3778$aspect_ratio$$);$background_color_bgcolor$jscomp$1_map__67901__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($background_color_bgcolor$jscomp$1_map__67901__$1$$,$APP.$cljs$cst$3779$background_color$$);var $frame_id$jscomp$68$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$21$$);
$background_color_bgcolor$jscomp$1_map__67901__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($background_color_bgcolor$jscomp$1_map__67901__$1$$,"#E8E9EA");var $include_metadata$jscomp$1$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$shapes$export$0$include_metadata_ctx$$);$aspect_ratio$jscomp$4_bounds$jscomp$32_vbox$jscomp$12$$=$app$common$geom$rect$fix_aspect_ratio$$($APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$390$$,
$frame$jscomp$21$$),$aspect_ratio$jscomp$4_bounds$jscomp$32_vbox$jscomp$12$$);var $bounds2_frame__$2_shape_wrapper$jscomp$12$$=$APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$390$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($frame$jscomp$21$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1653$blur$$]))),$delta_bounds_frame__$3$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($aspect_ratio$jscomp$4_bounds$jscomp$32_vbox$jscomp$12$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($aspect_ratio$jscomp$4_bounds$jscomp$32_vbox$jscomp$12$$)),$vector$jscomp$24$$=$APP.$app$common$geom$point$negate$$($delta_bounds_frame__$3$$),$children_ids$jscomp$7$$=$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$390$$,$frame_id$jscomp$68$$),$objects__$1$jscomp$11$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$68$$),$APP.$rumext$v2$adapt$$($objects$jscomp$390$$),
$APP.$rumext$v2$adapt$$($vector$jscomp$24$$)],function(){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__67898_SHARP_$$,$p2__67899_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__67898_SHARP_$$,$p2__67899_SHARP_$$,$APP.$app$common$geom$shapes$transform_shape$$,$APP.$app$common$types$modifiers$move_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$($vector$jscomp$24$$))},$objects$jscomp$390$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$68$$],null),$children_ids$jscomp$7$$))}),$frame__$1$jscomp$1_width$jscomp$123$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($vector$jscomp$24$$)],function(){return $APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$21$$,$APP.$app$common$types$modifiers$move_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$($vector$jscomp$24$$))});$bounds2_frame__$2_shape_wrapper$jscomp$12$$=
$aspect_ratio$jscomp$4_bounds$jscomp$32_vbox$jscomp$12$$!=null&&$APP.$cljs$cst$1913$children_bounds$$.$cljs$core$IFn$_invoke$arity$1$($aspect_ratio$jscomp$4_bounds$jscomp$32_vbox$jscomp$12$$)==null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($frame__$1$jscomp$1_width$jscomp$123$$,$APP.$cljs$cst$1913$children_bounds$$,$bounds2_frame__$2_shape_wrapper$jscomp$12$$):$frame__$1$jscomp$1_width$jscomp$123$$;$delta_bounds_frame__$3$$=$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($bounds2_frame__$2_shape_wrapper$jscomp$12$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1913$children_bounds$$,$APP.$cljs$cst$1510$x$$],null),$APP.$cljs$core$_$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($delta_bounds_frame__$3$$)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1913$children_bounds$$,$APP.$cljs$cst$1511$y$$],null),$APP.$cljs$core$_$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($delta_bounds_frame__$3$$));
$bounds2_frame__$2_shape_wrapper$jscomp$12$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects__$1$jscomp$11$$)],function(){return $APP.$app$main$render$shape_wrapper_factory$$($objects__$1$jscomp$11$$)});$frame__$1$jscomp$1_width$jscomp$123$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($aspect_ratio$jscomp$4_bounds$jscomp$32_vbox$jscomp$12$$)*$height$jscomp$109_zoom$jscomp$10$$;$height$jscomp$109_zoom$jscomp$10$$*=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($aspect_ratio$jscomp$4_bounds$jscomp$32_vbox$jscomp$12$$);
$aspect_ratio$jscomp$4_bounds$jscomp$32_vbox$jscomp$12$$=$APP.$app$main$render$format_viewbox$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$2$($aspect_ratio$jscomp$4_bounds$jscomp$32_vbox$jscomp$12$$,0),$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$2$($aspect_ratio$jscomp$4_bounds$jscomp$32_vbox$jscomp$12$$,0)],null));return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$render_thumbnails$$),
{value:$map__67901_props_67900_use_thumbnails$jscomp$1$$,children:(0,$APP.$rumext$v2$jsx$$)("svg",{"xmlns:penpot":$APP.$cljs$core$truth_$$($include_metadata$jscomp$1$$)?"https://penpot.app/xmlns":null,width:$APP.$app$util$strings$format_precision$$($frame__$1$jscomp$1_width$jscomp$123$$,3),xmlns:"http://www.w3.org/2000/svg",height:$APP.$app$util$strings$format_precision$$($height$jscomp$109_zoom$jscomp$10$$,3),children:(0,$APP.$rumext$v2$jsx$$)($bounds2_frame__$2_shape_wrapper$jscomp$12$$,{shape:$delta_bounds_frame__$3$$}),
viewBox:$aspect_ratio$jscomp$4_bounds$jscomp$32_vbox$jscomp$12$$,style:{background:$background_color_bgcolor$jscomp$1_map__67901__$1$$},xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",version:"1.1"})})});
$p1__67907_SHARP_$jscomp$inline_6671$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__67911_props_67910_show_grids_QMARK_$$){$map__67911_props_67910_show_grids_QMARK_$$=$APP.$rumext$v2$util$wrap_props$$($map__67911_props_67910_show_grids_QMARK_$$);var $class$$jscomp$3_map__67911__$1$$=$APP.$cljs$core$__destructure_map$$($map__67911_props_67910_show_grids_QMARK_$$),$objects$jscomp$392$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$3_map__67911__$1$$,
$APP.$cljs$cst$1631$objects$$),$root_shape$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$3_map__67911__$1$$,$cljs$cst$3780$root_shape$$);$map__67911_props_67910_show_grids_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$3_map__67911__$1$$,$cljs$cst$3781$show_grids_QMARK_$$);var $is_hidden$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$3_map__67911__$1$$,$cljs$cst$3782$is_hidden$$),$height$jscomp$110_zoom$jscomp$11$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($class$$jscomp$3_map__67911__$1$$,$APP.$cljs$cst$2196$zoom$$,1);$class$$jscomp$3_map__67911__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$3_map__67911__$1$$,$APP.$cljs$cst$1291$class$$);if($APP.$cljs$core$truth_$$($root_shape$jscomp$4$$)){var $root_shape_id$jscomp$1$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root_shape$jscomp$4$$),$include_metadata$jscomp$2$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$shapes$export$0$include_metadata_ctx$$),
$vector$jscomp$25$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($root_shape$jscomp$4$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($root_shape$jscomp$4$$))],function(){return $APP.$app$common$geom$point$negate$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($root_shape$jscomp$4$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($root_shape$jscomp$4$$)))}),
$objects__$1$jscomp$12$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($vector$jscomp$25$$),$APP.$rumext$v2$adapt$$($objects$jscomp$392$$),$APP.$rumext$v2$adapt$$($root_shape_id$jscomp$1$$)],function(){var $children_ids$jscomp$8$$=$APP.$cljs$core$cons$$($root_shape_id$jscomp$1$$,$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$392$$,$root_shape_id$jscomp$1$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__67908_SHARP_$$,
$p2__67909_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__67908_SHARP_$$,$p2__67909_SHARP_$$,$APP.$app$common$geom$shapes$transform_shape$$,$APP.$app$common$types$modifiers$move_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$($vector$jscomp$25$$))},$objects$jscomp$392$$,$children_ids$jscomp$8$$)}),$root_shape_SINGLEQUOTE_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$12$$,$root_shape_id$jscomp$1$$),$width$jscomp$124$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($root_shape_SINGLEQUOTE_$$)*
$height$jscomp$110_zoom$jscomp$11$$;$height$jscomp$110_zoom$jscomp$11$$*=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($root_shape_SINGLEQUOTE_$$);var $vbox$jscomp$13$$=$APP.$app$main$render$format_viewbox$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$2$($root_shape_SINGLEQUOTE_$$,0),$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$2$($root_shape_SINGLEQUOTE_$$,
0)],null)),$root_shape_wrapper$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects__$1$jscomp$12$$),$APP.$rumext$v2$adapt$$($root_shape_SINGLEQUOTE_$$)],function(){var $G__67912_G__67912__$1$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($root_shape_SINGLEQUOTE_$$);$G__67912_G__67912__$1$$=$G__67912_G__67912__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__67912_G__67912__$1$$.$fqn$:null;switch($G__67912_G__67912__$1$$){case "group":return $APP.$app$main$render$group_wrapper_factory$$($objects__$1$jscomp$12$$);
case "frame":return $APP.$app$main$render$frame_wrapper_factory$$($objects__$1$jscomp$12$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__67912_G__67912__$1$$)].join(""));}});return(0,$APP.$rumext$v2$jsx$$)("svg",{"xmlns:penpot":$APP.$cljs$core$truth_$$($include_metadata$jscomp$2$$)?"https://penpot.app/xmlns":null,width:$APP.$app$util$strings$format_precision$$($width$jscomp$124$$,3),xmlns:"http://www.w3.org/2000/svg",height:$APP.$app$util$strings$format_precision$$($height$jscomp$110_zoom$jscomp$11$$,
3),className:$class$$jscomp$3_map__67911__$1$$,children:$APP.$cljs$core$truth_$$($is_hidden$$)?null:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$shapes$shape$shape_container$$,{shape:$root_shape_SINGLEQUOTE_$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($app$main$ui$context$is_component_QMARK_$$),{value:!0,children:(0,$APP.$rumext$v2$jsx$$)($root_shape_wrapper$$,{shape:$root_shape_SINGLEQUOTE_$$,"view-box":$vbox$jscomp$13$$})})}),
$APP.$cljs$core$truth_$$($map__67911_props_67910_show_grids_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$render$empty_grids$$,{"root-shape-id":$root_shape_id$jscomp$1$$,objects:$objects__$1$jscomp$12$$}):null]}),viewBox:$vbox$jscomp$13$$,xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",version:"1.1"})}return null});$APP.$app$main$render$component_svg$$=$APP.$rumext$v2$deferred$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__67907_SHARP_$jscomp$inline_6671$$,$APP.$app$util$timers$idle_then_raf$$);
$p1__67919_SHARP_$jscomp$inline_6673$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__67923_props_67922_thumbnail_uri$$){$map__67923_props_67922_thumbnail_uri$$=$APP.$rumext$v2$util$wrap_props$$($map__67923_props_67922_thumbnail_uri$$);var $map__67923__$1_objects__$1$jscomp$13$$=$APP.$cljs$core$__destructure_map$$($map__67923_props_67922_thumbnail_uri$$);$map__67923_props_67922_thumbnail_uri$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67923__$1_objects__$1$jscomp$13$$,
$cljs$cst$3783$thumbnail_uri$$);var $on_error$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67923__$1_objects__$1$jscomp$13$$,$APP.$cljs$cst$1295$on_error$$),$show_grids_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67923__$1_objects__$1$jscomp$13$$,$cljs$cst$3781$show_grids_QMARK_$$),$class$$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67923__$1_objects__$1$jscomp$13$$,$APP.$cljs$cst$1291$class$$),$objects$jscomp$393$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67923__$1_objects__$1$jscomp$13$$,$APP.$cljs$cst$1631$objects$$),$root_shape$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67923__$1_objects__$1$jscomp$13$$,$cljs$cst$3780$root_shape$$),$height_zoom_zoom$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67923__$1_objects__$1$jscomp$13$$,$APP.$cljs$cst$2196$zoom$$,1);if($APP.$cljs$core$truth_$$($root_shape$jscomp$5$$)){var $root_shape_id$jscomp$2$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root_shape$jscomp$5$$),$vector$jscomp$26$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($root_shape$jscomp$5$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($root_shape$jscomp$5$$))],function(){return $APP.$app$common$geom$point$negate$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($root_shape$jscomp$5$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($root_shape$jscomp$5$$)))});$map__67923__$1_objects__$1$jscomp$13$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($vector$jscomp$26$$),$APP.$rumext$v2$adapt$$($objects$jscomp$393$$),$APP.$rumext$v2$adapt$$($root_shape_id$jscomp$2$$)],function(){var $children_ids$jscomp$9$$=$APP.$cljs$core$cons$$($root_shape_id$jscomp$2$$,$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$393$$,
$root_shape_id$jscomp$2$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__67920_SHARP_$$,$p2__67921_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__67920_SHARP_$$,$p2__67921_SHARP_$$,$APP.$app$common$geom$shapes$transform_shape$$,$APP.$app$common$types$modifiers$move_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$($vector$jscomp$26$$))},$objects$jscomp$393$$,$children_ids$jscomp$9$$)});var $root_shape_SINGLEQUOTE_$jscomp$1_vbox$jscomp$14$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67923__$1_objects__$1$jscomp$13$$,$root_shape_id$jscomp$2$$),$width$jscomp$125$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$2$($root_shape_SINGLEQUOTE_$jscomp$1_vbox$jscomp$14$$,0),$height$jscomp$111$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$2$($root_shape_SINGLEQUOTE_$jscomp$1_vbox$jscomp$14$$,0),$width_zoom$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($root_shape_SINGLEQUOTE_$jscomp$1_vbox$jscomp$14$$)*
$height_zoom_zoom$jscomp$12$$;$height_zoom_zoom$jscomp$12$$*=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($root_shape_SINGLEQUOTE_$jscomp$1_vbox$jscomp$14$$);$root_shape_SINGLEQUOTE_$jscomp$1_vbox$jscomp$14$$=$APP.$app$main$render$format_viewbox$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,$width$jscomp$125$$,$APP.$cljs$cst$1522$height$$,$height$jscomp$111$$],null));return(0,$APP.$rumext$v2$jsxs$$)("svg",{width:$APP.$app$util$strings$format_precision$$($width_zoom$$,
3),xmlns:"http://www.w3.org/2000/svg",height:$APP.$app$util$strings$format_precision$$($height_zoom_zoom$jscomp$12$$,3),className:$class$$jscomp$4$$,children:[(0,$APP.$rumext$v2$jsx$$)("image",{x:0,y:0,width:$width$jscomp$125$$,height:$height$jscomp$111$$,href:$map__67923_props_67922_thumbnail_uri$$,onError:$on_error$jscomp$33$$,loading:"lazy",decoding:"async"}),$APP.$cljs$core$truth_$$($show_grids_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$render$empty_grids$$,{"root-shape-id":$root_shape_id$jscomp$2$$,
objects:$map__67923__$1_objects__$1$jscomp$13$$}):null],viewBox:$root_shape_SINGLEQUOTE_$jscomp$1_vbox$jscomp$14$$,xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",version:"1.1"})}return null});$APP.$app$main$render$component_svg_thumbnail$$=$APP.$rumext$v2$deferred$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__67919_SHARP_$jscomp$inline_6673$$,$APP.$app$util$timers$idle_then_raf$$);
$APP.$app$main$render$object_svg$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__67926_object_id$jscomp$10_props_67924$$){$map__67926_object_id$jscomp$10_props_67924$$=$APP.$rumext$v2$util$wrap_props$$($map__67926_object_id$jscomp$10_props_67924$$);var $map__67926__$1_object__$1$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($map__67926_object_id$jscomp$10_props_67924$$),$objects$jscomp$394$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67926__$1_object__$1$jscomp$3$$,
$APP.$cljs$cst$1631$objects$$);$map__67926_object_id$jscomp$10_props_67924$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67926__$1_object__$1$jscomp$3$$,$APP.$cljs$cst$2272$object_id$$);var $embed$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__67926__$1_object__$1$jscomp$3$$,$APP.$cljs$cst$3776$embed$$,!1),$skip_children$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67926__$1_object__$1$jscomp$3$$,$APP.$cljs$cst$3784$skip_children$$),$object$jscomp$27$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$394$$,$map__67926_object_id$jscomp$10_props_67924$$);$map__67926__$1_object__$1$jscomp$3$$=function(){var $G__67928__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1874$hide_fill_on_export$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$27$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($object$jscomp$27$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$):$object$jscomp$27$$;return $APP.$cljs$core$truth_$$($skip_children$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__67928__$1$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$):$G__67928__$1$$}();var $map__67927_width$jscomp$126$$=$APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$394$$,$map__67926__$1_object__$1$jscomp$3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1911$ignore_margin_QMARK_$$,!1],null)),$map__67927__$1_vbox$jscomp$15$$=$APP.$cljs$core$__destructure_map$$($map__67927_width$jscomp$126$$);
$map__67927_width$jscomp$126$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67927__$1_vbox$jscomp$15$$,$APP.$cljs$cst$290$width$$);var $height$jscomp$112$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67927__$1_vbox$jscomp$15$$,$APP.$cljs$cst$1522$height$$);$map__67927__$1_vbox$jscomp$15$$=$APP.$app$main$render$format_viewbox$$($map__67927__$1_vbox$jscomp$15$$);var $fonts$jscomp$19$$=$app$main$ui$shapes$text$fontfaces$shape__GT_fonts$$($map__67926__$1_object__$1$jscomp$3$$,
$objects$jscomp$394$$),$shape_wrapper$jscomp$13$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$394$$)],function(){return $APP.$app$main$render$shape_wrapper_factory$$($objects$jscomp$394$$)});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$shapes$export$0$include_metadata_ctx$$),{value:!1,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$shapes$embed$context$$),{value:$embed$jscomp$5$$,
children:(0,$APP.$rumext$v2$jsxs$$)("svg",{width:$APP.$app$util$strings$format_precision$$($map__67927_width$jscomp$126$$,3),xmlns:"http://www.w3.org/2000/svg",height:$APP.$app$util$strings$format_precision$$($height$jscomp$112$$,3),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$text$fontfaces$fontfaces_style$$,{fonts:$fonts$jscomp$19$$}),(0,$APP.$rumext$v2$jsx$$)($shape_wrapper$jscomp$13$$,{shape:$map__67926__$1_object__$1$jscomp$3$$})],id:"screenshot-"+($map__67926_object_id$jscomp$10_props_67924$$??
""),viewBox:$map__67927__$1_vbox$jscomp$15$$,style:{WebkitPrintColorAdjust:$cljs$cst$3785$exact$$},xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",version:"1.1"})})})});
$app$main$render$objects_svg$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($embed$jscomp$6_map__67937_map__67937__$1_props_67936$$){$embed$jscomp$6_map__67937_map__67937__$1_props_67936$$=$APP.$rumext$v2$util$wrap_props$$($embed$jscomp$6_map__67937_map__67937__$1_props_67936$$);$embed$jscomp$6_map__67937_map__67937__$1_props_67936$$=$APP.$cljs$core$__destructure_map$$($embed$jscomp$6_map__67937_map__67937__$1_props_67936$$);var $objects$jscomp$395$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($embed$jscomp$6_map__67937_map__67937__$1_props_67936$$,
$APP.$cljs$cst$1631$objects$$),$object_ids_shapes$jscomp$67$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($embed$jscomp$6_map__67937_map__67937__$1_props_67936$$,$cljs$cst$3786$object_ids$$);$embed$jscomp$6_map__67937_map__67937__$1_props_67936$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($embed$jscomp$6_map__67937_map__67937__$1_props_67936$$,$APP.$cljs$cst$3776$embed$$,!1);$object_ids_shapes$jscomp$67$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($object$jscomp$28$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1874$hide_fill_on_export$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$28$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($object$jscomp$28$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$):$object$jscomp$28$$},$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__67933_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$395$$,$p1__67933_SHARP_$$)},$object_ids_shapes$jscomp$67$$));var $bounds$jscomp$34_vbox$jscomp$16$$=$APP.$app$common$geom$rect$join_rects$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67934_SHARP_$$){return $APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$395$$,
$p1__67934_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1911$ignore_margin_QMARK_$$,!1],null))},$object_ids_shapes$jscomp$67$$)),$height$jscomp$113_map__67938__$1$$=$APP.$cljs$core$__destructure_map$$($bounds$jscomp$34_vbox$jscomp$16$$),$width$jscomp$127$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$113_map__67938__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$113_map__67938__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$113_map__67938__$1$$,
$APP.$cljs$cst$1522$height$$);$bounds$jscomp$34_vbox$jscomp$16$$=$APP.$app$main$render$format_viewbox$$($bounds$jscomp$34_vbox$jscomp$16$$);var $fonts$jscomp$20$$=$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__67935_SHARP_$$){return $app$main$ui$shapes$text$fontfaces$shape__GT_fonts$$($p1__67935_SHARP_$$,$objects$jscomp$395$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$object_ids_shapes$jscomp$67$$]))),
$shape_wrapper$jscomp$14$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$395$$)],function(){return $APP.$app$main$render$shape_wrapper_factory$$($objects$jscomp$395$$)});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$shapes$export$0$include_metadata_ctx$$),{value:!1,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$shapes$embed$context$$),{value:$embed$jscomp$6_map__67937_map__67937__$1_props_67936$$,
children:(0,$APP.$rumext$v2$jsxs$$)("svg",{width:$APP.$app$util$strings$format_precision$$($width$jscomp$127$$,3),xmlns:"http://www.w3.org/2000/svg",height:$APP.$app$util$strings$format_precision$$($height$jscomp$113_map__67938__$1$$,3),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$text$fontfaces$fontfaces_style$$,{fonts:$fonts$jscomp$20$$}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$31$$,$shape$jscomp$500$$){$out_arr__44124__auto__$jscomp$31$$.push((0,$APP.$rumext$v2$jsx$$)($shape_wrapper$jscomp$14$$,
{shape:$shape$jscomp$500$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$500$$)??"")));return $out_arr__44124__auto__$jscomp$31$$},[],$object_ids_shapes$jscomp$67$$)],viewBox:$bounds$jscomp$34_vbox$jscomp$16$$,style:{WebkitPrintColorAdjust:$cljs$cst$3785$exact$$},xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",version:"1.1"})})})});
$APP.$app$main$render$object_wasm$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__67942_props_67941_scale$jscomp$28$$){$map__67942_props_67941_scale$jscomp$28$$=$APP.$rumext$v2$util$wrap_props$$($map__67942_props_67941_scale$jscomp$28$$);var $map__67942__$1_map__67943_object__$1$jscomp$4_width$jscomp$129$$=$APP.$cljs$core$__destructure_map$$($map__67942_props_67941_scale$jscomp$28$$),$objects$jscomp$397$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67942__$1_map__67943_object__$1$jscomp$4_width$jscomp$129$$,
$APP.$cljs$cst$1631$objects$$),$object_id$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67942__$1_map__67943_object__$1$jscomp$4_width$jscomp$129$$,$APP.$cljs$cst$2272$object_id$$),$skip_children$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67942__$1_map__67943_object__$1$jscomp$4_width$jscomp$129$$,$APP.$cljs$cst$3784$skip_children$$);$map__67942_props_67941_scale$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67942__$1_map__67943_object__$1$jscomp$4_width$jscomp$129$$,
$APP.$cljs$cst$1902$scale$$);var $on_render$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67942__$1_map__67943_object__$1$jscomp$4_width$jscomp$129$$,$cljs$cst$3092$on_render$$),$object$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$397$$,$object_id$jscomp$12$$);$map__67942__$1_map__67943_object__$1$jscomp$4_width$jscomp$129$$=function(){var $G__67944__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1874$hide_fill_on_export$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$29$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($object$jscomp$29$$,$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$):$object$jscomp$29$$;return $APP.$cljs$core$truth_$$($skip_children$jscomp$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__67944__$1$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$):$G__67944__$1$$}();$map__67942__$1_map__67943_object__$1$jscomp$4_width$jscomp$129$$=$APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$397$$,
$map__67942__$1_map__67943_object__$1$jscomp$4_width$jscomp$129$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1911$ignore_margin_QMARK_$$,!1],null));var $map__67943__$1$$=$APP.$cljs$core$__destructure_map$$($map__67942__$1_map__67943_object__$1$jscomp$4_width$jscomp$129$$);$map__67942__$1_map__67943_object__$1$jscomp$4_width$jscomp$129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67943__$1$$,$APP.$cljs$cst$290$width$$);var $height$jscomp$115$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67943__$1$$,
$APP.$cljs$cst$1522$height$$),$scale__$1$$=$APP.$cljs$core$truth_$$($map__67942_props_67941_scale$jscomp$28$$)?$map__67942_props_67941_scale$jscomp$28$$:1,$canvas_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $canvas$jscomp$12$$=$APP.$rumext$v2$ref_val$$($canvas_ref$$);return $APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($ready_QMARK_$$){return $APP.$cljs$core$truth_$$($ready_QMARK_$$)?$app$main$render$render_to_canvas$$($objects$jscomp$397$$,
$canvas$jscomp$12$$,$map__67943__$1$$,$scale__$1$$,$object_id$jscomp$12$$,$on_render$jscomp$4$$):null},$APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$module$$))});return(0,$APP.$rumext$v2$jsx$$)("canvas",{ref:$canvas_ref$$,width:$scale__$1$$*$map__67942__$1_map__67943_object__$1$jscomp$4_width$jscomp$129$$,height:$scale__$1$$*$height$jscomp$115$$,style:{background:"transparent"}})});$APP.$app$common$logging$loggers$$.set("app.util.queue",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1161$info$$));var $app$main$data$workspace$thumbnails$clear_thumbnail_68039$$,$app$main$data$workspace$thumbnails$assoc_thumbnail_68049$$,$app$main$data$workspace$thumbnails$update_thumbnail_68066$$,$app$main$data$workspace$thumbnails$watch_state_changes_68127$$;$APP.$app$common$logging$loggers$$.set("app.main.data.workspace.thumbnails",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));var $app$main$data$workspace$thumbnails$queue$$;
$app$main$data$workspace$thumbnails$queue$$={"find-fn":function($params$jscomp$264$$,$item$jscomp$85$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$264$$["file-id"],$item$jscomp$85$$["file-id"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$264$$["page-id"],$item$jscomp$85$$["page-id"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$264$$["shape-id"],$item$jscomp$85$$["shape-id"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$264$$.tag,
$item$jscomp$85$$.tag)},items:[],timeout:null,time:0,threshold:1E3/30,"max-iterations":Infinity};var $app$main$data$workspace$thumbnails_wasm$render_thumbnail_68244$$,$app$main$data$workspace$thumbnails_wasm$persist_thumbnail_68277$$;$APP.$app$common$logging$loggers$$.set("app.main.data.workspace.thumbnails-wasm",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));var $app$common$geom$shapes$flex_layout$bounds$_child_min_width$$=null,$app$common$geom$shapes$flex_layout$bounds$_child_min_height$$=null;var $app$common$geom$shapes$flex_layout$layout_data$conjv$$=$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$app$common$geom$shapes$flex_layout$layout_data$_child_min_width$$=null,$app$common$geom$shapes$flex_layout$layout_data$_child_min_height$$=null;var $app$common$geom$shapes$flex_layout$calculate_params$$;
$APP.$app$common$geom$shapes$flex_layout$child_layout_bound_points$$=function(){var $app$common$geom$shapes$flex_layout$child_layout_bound_points$$=null;$app$common$geom$shapes$flex_layout$child_layout_bound_points$$=function($param68387$jscomp$1$$,$param68388$jscomp$1$$,$param68389$jscomp$1$$,$param68390$jscomp$1$$,$param68391$jscomp$1$$,$param68392$jscomp$1$$,$param68393$jscomp$1$$){switch(arguments.length){case 6:return $app$common$geom$shapes$flex_layout$bounds$child_layout_bound_points$cljs$0core$0IFn$0_invoke$0arity$07$$($param68387$jscomp$1$$,$param68388$jscomp$1$$,
$param68389$jscomp$1$$,$param68390$jscomp$1$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$0$(),$param68391$jscomp$1$$,$param68392$jscomp$1$$);case 7:return $app$common$geom$shapes$flex_layout$bounds$child_layout_bound_points$cljs$0core$0IFn$0_invoke$0arity$07$$($param68387$jscomp$1$$,$param68388$jscomp$1$$,$param68389$jscomp$1$$,$param68390$jscomp$1$$,$param68391$jscomp$1$$,$param68392$jscomp$1$$,$param68393$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$common$geom$shapes$flex_layout$child_layout_bound_points$$.$cljs$core$IFn$_invoke$arity$6$=
function($param68381$$,$param68382$$,$param68383$$,$param68384$$,$param68385$$,$param68386$$){return $app$common$geom$shapes$flex_layout$bounds$child_layout_bound_points$cljs$0core$0IFn$0_invoke$0arity$07$$($param68381$$,$param68382$$,$param68383$$,$param68384$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$0$(),$param68385$$,$param68386$$)};$app$common$geom$shapes$flex_layout$child_layout_bound_points$$.$cljs$core$IFn$_invoke$arity$7$=function($param68387$$,$param68388$$,$param68389$$,
$param68390$$,$param68391$$,$param68392$$,$param68393$$){return $app$common$geom$shapes$flex_layout$bounds$child_layout_bound_points$cljs$0core$0IFn$0_invoke$0arity$07$$($param68387$$,$param68388$$,$param68389$$,$param68390$$,$param68391$$,$param68392$$,$param68393$$)};return $app$common$geom$shapes$flex_layout$child_layout_bound_points$$}();
$APP.$app$common$geom$shapes$flex_layout$calc_layout_data$$=function(){var $app$common$geom$shapes$flex_layout$calc_layout_data$$=null;$app$common$geom$shapes$flex_layout$calc_layout_data$$=function($param68405$jscomp$1$$,$param68406$jscomp$1$$,$param68407$jscomp$1$$,$param68408$jscomp$1$$,$param68409$jscomp$1$$,$param68410$jscomp$1$$){switch(arguments.length){case 5:return $app$common$geom$shapes$flex_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$05$$($param68405$jscomp$1$$,
$param68406$jscomp$1$$,$param68407$jscomp$1$$,$param68408$jscomp$1$$,$param68409$jscomp$1$$);case 6:return $app$common$geom$shapes$flex_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$06$$($param68405$jscomp$1$$,$param68406$jscomp$1$$,$param68407$jscomp$1$$,$param68408$jscomp$1$$,$param68409$jscomp$1$$,$param68410$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$common$geom$shapes$flex_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$=function($param68400$$,
$param68401$$,$param68402$$,$param68403$$,$param68404$$){return $app$common$geom$shapes$flex_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$05$$($param68400$$,$param68401$$,$param68402$$,$param68403$$,$param68404$$)};$app$common$geom$shapes$flex_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$6$=function($param68405$$,$param68406$$,$param68407$$,$param68408$$,$param68409$$,$param68410$$){return $app$common$geom$shapes$flex_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$06$$($param68405$$,
$param68406$$,$param68407$$,$param68408$$,$param68409$$,$param68410$$)};return $app$common$geom$shapes$flex_layout$calc_layout_data$$}();
$app$common$geom$shapes$flex_layout$calculate_params$$=function(){var $app$common$geom$shapes$flex_layout$calculate_params$$=null;$app$common$geom$shapes$flex_layout$calculate_params$$=function($param68418$jscomp$1$$,$param68419$jscomp$1$$,$param68420$jscomp$1$$){switch(arguments.length){case 2:return $app$common$geom$shapes$flex_layout$params$calculate_params$cljs$0core$0IFn$0_invoke$0arity$03$$($param68418$jscomp$1$$,$param68419$jscomp$1$$,null);case 3:return $app$common$geom$shapes$flex_layout$params$calculate_params$cljs$0core$0IFn$0_invoke$0arity$03$$($param68418$jscomp$1$$,
$param68419$jscomp$1$$,$param68420$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$common$geom$shapes$flex_layout$calculate_params$$.$cljs$core$IFn$_invoke$arity$2$=function($param68416$$,$param68417$$){return $app$common$geom$shapes$flex_layout$params$calculate_params$cljs$0core$0IFn$0_invoke$0arity$03$$($param68416$$,$param68417$$,null)};$app$common$geom$shapes$flex_layout$calculate_params$$.$cljs$core$IFn$_invoke$arity$3$=function($param68418$$,$param68419$$,$param68420$$){return $app$common$geom$shapes$flex_layout$params$calculate_params$cljs$0core$0IFn$0_invoke$0arity$03$$($param68418$$,
$param68419$$,$param68420$$)};return $app$common$geom$shapes$flex_layout$calculate_params$$}();var $app$common$geom$shapes$min_size_layout$child_min_width$$=function $app$common$geom$shapes$min_size_layout$child_min_width$$($var_args$jscomp$1237$$){switch(arguments.length){case 4:return $app$common$geom$shapes$min_size_layout$child_min_width$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);case 5:return $app$common$geom$shapes$min_size_layout$child_min_width$$.$cljs$core$IFn$_invoke$arity$5$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4]);
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$common$geom$shapes$min_size_layout$child_min_width$$.$cljs$core$IFn$_invoke$arity$4$=function($child$jscomp$106$$,$child_bounds$jscomp$23$$,$bounds$jscomp$52$$,$objects$jscomp$431$$){return $app$common$geom$shapes$min_size_layout$child_min_width$$.$cljs$core$IFn$_invoke$arity$5$($child$jscomp$106$$,$child_bounds$jscomp$23$$,$bounds$jscomp$52$$,$objects$jscomp$431$$,!1)};
$app$common$geom$shapes$min_size_layout$child_min_width$$.$cljs$core$IFn$_invoke$arity$5$=function($child$jscomp$107_y__5111__auto__$jscomp$117$$,$child_bounds$jscomp$24_x__5110__auto__$jscomp$117$$,$bounds$jscomp$53$$,$layout_data$jscomp$13_objects$jscomp$432$$,$children$jscomp$233_strict_QMARK_$$){return $APP.$cljs$core$not$$($children$jscomp$233_strict_QMARK_$$)&&$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$107_y__5111__auto__$jscomp$117$$)&&
$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$107_y__5111__auto__$jscomp$117$$)?$app$common$types$shape$layout$child_min_width$$($child$jscomp$107_y__5111__auto__$jscomp$117$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($children$jscomp$233_strict_QMARK_$$)?$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$107_y__5111__auto__$jscomp$117$$)&&$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$107_y__5111__auto__$jscomp$117$$):
$children$jscomp$233_strict_QMARK_$$)?($children$jscomp$233_strict_QMARK_$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$,$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($layout_data$jscomp$13_objects$jscomp$432$$,$child$jscomp$107_y__5111__auto__$jscomp$117$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($child$jscomp$107_y__5111__auto__$jscomp$117$$,$APP.$cljs$cst$266$id$$))),
$child_bounds$jscomp$24_x__5110__auto__$jscomp$117$$=$app$common$types$shape$layout$child_min_width$$($child$jscomp$107_y__5111__auto__$jscomp$117$$),$child$jscomp$107_y__5111__auto__$jscomp$117$$=$APP.$app$common$geom$shapes$points$width_points$$($APP.$app$common$geom$shapes$flex_layout$bounds$layout_content_bounds$$($bounds$jscomp$53$$,$child$jscomp$107_y__5111__auto__$jscomp$117$$,$children$jscomp$233_strict_QMARK_$$,$layout_data$jscomp$13_objects$jscomp$432$$)),$child_bounds$jscomp$24_x__5110__auto__$jscomp$117$$>
$child$jscomp$107_y__5111__auto__$jscomp$117$$?$child_bounds$jscomp$24_x__5110__auto__$jscomp$117$$:$child$jscomp$107_y__5111__auto__$jscomp$117$$):$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$107_y__5111__auto__$jscomp$117$$)&&$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$107_y__5111__auto__$jscomp$117$$)?($children$jscomp$233_strict_QMARK_$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68300_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$53$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__68300_SHARP_$$))),$p1__68300_SHARP_$$],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$,$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($layout_data$jscomp$13_objects$jscomp$432$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$107_y__5111__auto__$jscomp$117$$)))),$layout_data$jscomp$13_objects$jscomp$432$$=$app$common$geom$shapes$grid_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$06$$($child$jscomp$107_y__5111__auto__$jscomp$117$$,$APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$53$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$107_y__5111__auto__$jscomp$117$$))),
$children$jscomp$233_strict_QMARK_$$,$bounds$jscomp$53$$,$layout_data$jscomp$13_objects$jscomp$432$$,!0),$child_bounds$jscomp$24_x__5110__auto__$jscomp$117$$=$app$common$types$shape$layout$child_min_width$$($child$jscomp$107_y__5111__auto__$jscomp$117$$),$child$jscomp$107_y__5111__auto__$jscomp$117$$=$APP.$app$common$geom$shapes$points$width_points$$($APP.$app$common$geom$shapes$grid_layout$bounds$layout_content_bounds$$($bounds$jscomp$53$$,$child$jscomp$107_y__5111__auto__$jscomp$117$$,$layout_data$jscomp$13_objects$jscomp$432$$)),
$child_bounds$jscomp$24_x__5110__auto__$jscomp$117$$>$child$jscomp$107_y__5111__auto__$jscomp$117$$?$child_bounds$jscomp$24_x__5110__auto__$jscomp$117$$:$child$jscomp$107_y__5111__auto__$jscomp$117$$):$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$107_y__5111__auto__$jscomp$117$$)?$app$common$types$shape$layout$child_min_width$$($child$jscomp$107_y__5111__auto__$jscomp$117$$):$APP.$app$common$geom$shapes$points$width_points$$($child_bounds$jscomp$24_x__5110__auto__$jscomp$117$$)};
$app$common$geom$shapes$min_size_layout$child_min_width$$.$cljs$lang$maxFixedArity$=5;
var $app$common$geom$shapes$min_size_layout$child_min_height$$=function $app$common$geom$shapes$min_size_layout$child_min_height$$($var_args$jscomp$1238$$){switch(arguments.length){case 4:return $app$common$geom$shapes$min_size_layout$child_min_height$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);case 5:return $app$common$geom$shapes$min_size_layout$child_min_height$$.$cljs$core$IFn$_invoke$arity$5$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4]);
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$common$geom$shapes$min_size_layout$child_min_height$$.$cljs$core$IFn$_invoke$arity$4$=function($child$jscomp$108$$,$child_bounds$jscomp$25$$,$bounds$jscomp$54$$,$objects$jscomp$433$$){return $app$common$geom$shapes$min_size_layout$child_min_height$$.$cljs$core$IFn$_invoke$arity$5$($child$jscomp$108$$,$child_bounds$jscomp$25$$,$bounds$jscomp$54$$,$objects$jscomp$433$$,!1)};
$app$common$geom$shapes$min_size_layout$child_min_height$$.$cljs$core$IFn$_invoke$arity$5$=function($child$jscomp$109_y__5111__auto__$jscomp$118$$,$child_bounds$jscomp$26_x__5110__auto__$jscomp$118$$,$bounds$jscomp$55$$,$auto_bounds_layout_data$jscomp$14_objects$jscomp$434$$,$children$jscomp$234_strict_QMARK_$jscomp$1$$){return $APP.$cljs$core$not$$($children$jscomp$234_strict_QMARK_$jscomp$1$$)&&$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$109_y__5111__auto__$jscomp$118$$)&&
$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$109_y__5111__auto__$jscomp$118$$)?$app$common$types$shape$layout$child_min_height$$($child$jscomp$109_y__5111__auto__$jscomp$118$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($children$jscomp$234_strict_QMARK_$jscomp$1$$)?$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$109_y__5111__auto__$jscomp$118$$)&&$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$109_y__5111__auto__$jscomp$118$$):
$children$jscomp$234_strict_QMARK_$jscomp$1$$)?($children$jscomp$234_strict_QMARK_$jscomp$1$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$,$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($auto_bounds_layout_data$jscomp$14_objects$jscomp$434$$,$child$jscomp$109_y__5111__auto__$jscomp$118$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($child$jscomp$109_y__5111__auto__$jscomp$118$$,
$APP.$cljs$cst$266$id$$))),$child_bounds$jscomp$26_x__5110__auto__$jscomp$118$$=$app$common$types$shape$layout$child_min_height$$($child$jscomp$109_y__5111__auto__$jscomp$118$$),$child$jscomp$109_y__5111__auto__$jscomp$118$$=$APP.$app$common$geom$shapes$points$height_points$$($APP.$app$common$geom$shapes$flex_layout$bounds$layout_content_bounds$$($bounds$jscomp$55$$,$child$jscomp$109_y__5111__auto__$jscomp$118$$,$children$jscomp$234_strict_QMARK_$jscomp$1$$,$auto_bounds_layout_data$jscomp$14_objects$jscomp$434$$)),
$child_bounds$jscomp$26_x__5110__auto__$jscomp$118$$>$child$jscomp$109_y__5111__auto__$jscomp$118$$?$child_bounds$jscomp$26_x__5110__auto__$jscomp$118$$:$child$jscomp$109_y__5111__auto__$jscomp$118$$):$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$109_y__5111__auto__$jscomp$118$$)&&$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$109_y__5111__auto__$jscomp$118$$)?($children$jscomp$234_strict_QMARK_$jscomp$1$$=
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($child__$1$jscomp$2$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$55$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child__$1$jscomp$2$$))),$child__$1$jscomp$2$$],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$,
$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($auto_bounds_layout_data$jscomp$14_objects$jscomp$434$$,$child$jscomp$109_y__5111__auto__$jscomp$118$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($child$jscomp$109_y__5111__auto__$jscomp$118$$,$APP.$cljs$cst$266$id$$)))),$auto_bounds_layout_data$jscomp$14_objects$jscomp$434$$=$app$common$geom$shapes$grid_layout$layout_data$calc_layout_data$cljs$0core$0IFn$0_invoke$0arity$06$$($child$jscomp$109_y__5111__auto__$jscomp$118$$,
$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$109_y__5111__auto__$jscomp$118$$),$children$jscomp$234_strict_QMARK_$jscomp$1$$,$bounds$jscomp$55$$,$auto_bounds_layout_data$jscomp$14_objects$jscomp$434$$,!0),$auto_bounds_layout_data$jscomp$14_objects$jscomp$434$$=$APP.$app$common$geom$shapes$grid_layout$bounds$layout_content_bounds$$($bounds$jscomp$55$$,$child$jscomp$109_y__5111__auto__$jscomp$118$$,$auto_bounds_layout_data$jscomp$14_objects$jscomp$434$$),$child_bounds$jscomp$26_x__5110__auto__$jscomp$118$$=
$app$common$types$shape$layout$child_min_height$$($child$jscomp$109_y__5111__auto__$jscomp$118$$),$child$jscomp$109_y__5111__auto__$jscomp$118$$=$APP.$app$common$geom$shapes$points$height_points$$($auto_bounds_layout_data$jscomp$14_objects$jscomp$434$$),$child_bounds$jscomp$26_x__5110__auto__$jscomp$118$$>$child$jscomp$109_y__5111__auto__$jscomp$118$$?$child_bounds$jscomp$26_x__5110__auto__$jscomp$118$$:$child$jscomp$109_y__5111__auto__$jscomp$118$$):$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$109_y__5111__auto__$jscomp$118$$)?
$app$common$types$shape$layout$child_min_height$$($child$jscomp$109_y__5111__auto__$jscomp$118$$):$APP.$app$common$geom$shapes$points$height_points$$($child_bounds$jscomp$26_x__5110__auto__$jscomp$118$$)};$app$common$geom$shapes$min_size_layout$child_min_height$$.$cljs$lang$maxFixedArity$=5;$app$common$geom$shapes$flex_layout$layout_data$_child_min_width$$=$app$common$geom$shapes$min_size_layout$child_min_width$$;$app$common$geom$shapes$flex_layout$layout_data$_child_min_height$$=$app$common$geom$shapes$min_size_layout$child_min_height$$;
$app$common$geom$shapes$flex_layout$bounds$_child_min_width$$=$app$common$geom$shapes$min_size_layout$child_min_width$$;$app$common$geom$shapes$flex_layout$bounds$_child_min_height$$=$app$common$geom$shapes$min_size_layout$child_min_height$$;$app$common$geom$shapes$grid_layout$layout_data$_child_min_width$$=$app$common$geom$shapes$min_size_layout$child_min_width$$;$app$common$geom$shapes$grid_layout$layout_data$_child_min_height$$=$app$common$geom$shapes$min_size_layout$child_min_height$$;var $app$main$data$workspace$modifiers$clear_local_transform_68613$$,$app$main$data$workspace$modifiers$set_modifiers_68694$$,$app$main$data$workspace$modifiers$set_temporary_selrect_68733$$,$app$main$data$workspace$modifiers$set_temporary_modifiers_68738$$,$app$main$data$workspace$modifiers$set_wasm_modifiers_68759$$,$app$main$data$workspace$modifiers$apply_wasm_modifiesr_68801$$,$app$main$data$workspace$modifiers$set_delta_rotation_modifiers_68881$$,$app$main$data$workspace$modifiers$apply_modifiers_STAR__68885$$,
$app$main$data$workspace$modifiers$apply_modifiers_68899$$,$app$main$data$workspace$modifiers$xf_COLON_without_uuid_zero$$,$app$main$data$workspace$modifiers$wasm_structure_modifiers_active_QMARK_$$,$app$main$data$workspace$modifiers$transform_attrs$$,$app$main$data$workspace$modifiers$xf_COLON_parse_geometry_modifier$$,$app$main$data$workspace$modifiers$xf_COLON_map_key$$;
$app$main$data$workspace$modifiers$xf_COLON_without_uuid_zero$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__68582_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__68582_SHARP_$$,$APP.$app$common$uuid$zero$$)});$app$main$data$workspace$modifiers$wasm_structure_modifiers_active_QMARK_$$=$APP.$cljs$core$volatile_BANG_$$(!1);
$app$main$data$workspace$modifiers$transform_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,35,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1695$layout_grid_columns$$,null,$APP.$cljs$cst$1686$layout_padding$$,null,$APP.$cljs$cst$1289$transform$$,null,$APP.$cljs$cst$1788$rotation$$,null,$APP.$cljs$cst$1770$grow_type$$,null,$APP.$cljs$cst$1637$content$$,null,$APP.$cljs$cst$1698$layout_item_margin_type$$,null,$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1696$layout_grid_cells$$,
null,$APP.$cljs$cst$1685$layout_padding_type$$,null,$APP.$cljs$cst$1604$points$$,null,$APP.$cljs$cst$1647$r2$$,null,$APP.$cljs$cst$1706$layout_item_max_w$$,null,$APP.$cljs$cst$1708$layout_item_h_sizing$$,null,$APP.$cljs$cst$1680$layout_gap$$,null,$APP.$cljs$cst$1787$transform_inverse$$,null,$APP.$cljs$cst$1709$layout_item_v_sizing$$,null,$APP.$cljs$cst$1648$r3$$,null,$APP.$cljs$cst$1653$blur$$,null,$APP.$cljs$cst$1646$r1$$,null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1891$position_data$$,
null,$APP.$cljs$cst$1636$strokes$$,null,$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1654$shadow$$,null,$APP.$cljs$cst$1649$r4$$,null,$APP.$cljs$cst$1694$layout_grid_rows$$,null,$APP.$cljs$cst$1699$layout_item_margin$$,null,$APP.$cljs$cst$1605$selrect$$,null,$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null,$APP.$cljs$cst$1879$flip_x$$,null,$APP.$cljs$cst$1522$height$$,null,$APP.$cljs$cst$1880$flip_y$$,null],null),null);
$app$main$data$workspace$modifiers$xf_COLON_parse_geometry_modifier$$=function(){var $default_transform$$=$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$();return $APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($data$jscomp$337_p__68715$$){var $id$jscomp$539$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$337_p__68715$$,0,null);$data$jscomp$337_p__68715$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$337_p__68715$$,
1,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$539$$,$APP.$app$common$uuid$zero$$))return null;if($app$common$types$modifiers$has_geometry_QMARK_$$($APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$337_p__68715$$))){var $kind$jscomp$27_parent$jscomp$262$$=$APP.$cljs$cst$1777$geometry_parent$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$337_p__68715$$));$kind$jscomp$27_parent$jscomp$262$$=
$APP.$app$common$data$not_empty_QMARK_$$($kind$jscomp$27_parent$jscomp$262$$)?$APP.$cljs$cst$1365$parent$$:$cljs$cst$392$child$$;return $app$common$data$vec2$$($id$jscomp$539$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1289$transform$$,$app$common$types$modifiers$modifiers__GT_transform$$($APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$337_p__68715$$)),$APP.$cljs$cst$947$kind$$,$kind$jscomp$27_parent$jscomp$262$$],null))}return $app$common$data$vec2$$($id$jscomp$539$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1289$transform$$,$default_transform$$,$APP.$cljs$cst$947$kind$$,$APP.$cljs$cst$1365$parent$$],null))})}();$app$main$data$workspace$modifiers$xf_COLON_map_key$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$key$$);
$APP.$app$main$data$workspace$modifiers$xf_rotation_shape$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__68849_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($p1__68849_SHARP_$$,$APP.$cljs$cst$1623$blocked$$,!1)}),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__68850_SHARP_$$){return $APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$attrs$editable_attrs$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__68850_SHARP_$$)))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$));var $$jscomp$scope$236007416$0$Color$RED$$=1,$$jscomp$scope$236007416$0$Color$BLACK$$=2,$$jscomp$scope$236007416$1$Node$$=class{constructor($value$jscomp$554$$,$data$jscomp$342$$){this.value=$value$jscomp$554$$;this.data=[$data$jscomp$342$$];this.right=this.left=null;this.color=$$jscomp$scope$236007416$0$Color$BLACK$$}},$$jscomp$scope$236007416$2$RangeTree$$=class{constructor(){this.root=null}remove($value$jscomp$556$$,$data$jscomp$344_newData$jscomp$2$$){if(!this.root)return this;this.root=$$jscomp$scope$236007416$7$recRemoveData$$(this.root,
$value$jscomp$556$$,$data$jscomp$344_newData$jscomp$2$$);($data$jscomp$344_newData$jscomp$2$$=$$jscomp$scope$236007416$9$recGet$$(this.root,$value$jscomp$556$$))&&$data$jscomp$344_newData$jscomp$2$$.length===0&&($$jscomp$scope$236007416$3$isRed$$(this.root.left)||$$jscomp$scope$236007416$3$isRed$$(this.root.right)||(this.root.color=$$jscomp$scope$236007416$0$Color$RED$$),this.root=$$jscomp$scope$236007416$8$recRemoveNode$$(this.root,$value$jscomp$556$$))&&(this.root.color=$$jscomp$scope$236007416$0$Color$BLACK$$);
return this}update($value$jscomp$557$$,$oldData$jscomp$1$$,$newData$jscomp$3$$){this.root=$$jscomp$scope$236007416$10$recUpdate$$(this.root,$value$jscomp$557$$,$oldData$jscomp$1$$,$newData$jscomp$3$$);return this}get($value$jscomp$558$$){return $$jscomp$scope$236007416$9$recGet$$(this.root,$value$jscomp$558$$)}height(){return $$jscomp$scope$236007416$19$recHeight$$(this.root)}isEmpty(){return!this.root}toString(){const $result$jscomp$295$$=[];$$jscomp$scope$236007416$20$recToString$$(this.root,$result$jscomp$295$$);
return $result$jscomp$295$$.join(", ")}},$app$util$range_tree$range_query$$=($tree$jscomp$12$$,$from_value$$,$to_value$$)=>$tree$jscomp$12$$?$APP.$cljs$core$vec$$($$jscomp$scope$236007416$11$recRangeQuery$$($tree$jscomp$12$$.root,$from_value$$,$to_value$$,[])):$APP.$cljs$core$vec$$();var $app$main$snap$combine_snaps_points$$=function $app$main$snap$combine_snaps_points$$($var_args$jscomp$1251$$){switch(arguments.length){case 0:return $app$main$snap$combine_snaps_points$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $app$main$snap$combine_snaps_points$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$snap$combine_snaps_points$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$app$main$snap$combine_snaps_points$$.$cljs$core$IFn$_invoke$arity$0$=function(){return null};$app$main$snap$combine_snaps_points$$.$cljs$core$IFn$_invoke$arity$1$=function($p1$jscomp$73$$){return $p1$jscomp$73$$};
$app$main$snap$combine_snaps_points$$.$cljs$core$IFn$_invoke$arity$2$=function($p1$jscomp$74$$,$p2$jscomp$55$$){return $p2$jscomp$55$$==null?$p1$jscomp$74$$:$p1$jscomp$74$$==null?$p2$jscomp$55$$:$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($app$common$math$max_abs$$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p1$jscomp$74$$),$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($p2$jscomp$55$$)),$app$common$math$max_abs$$($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p1$jscomp$74$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($p2$jscomp$55$$)))};$app$main$snap$combine_snaps_points$$.$cljs$lang$maxFixedArity$=2;
$APP.$app$main$snap$create_ranges$$=function $app$main$snap$create_ranges$$($var_args$jscomp$1252$$){switch(arguments.length){case 1:return $app$main$snap$create_ranges$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$snap$create_ranges$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$main$snap$create_ranges$$.$cljs$core$IFn$_invoke$arity$1$=function($points$jscomp$71$$){return $APP.$app$main$snap$create_ranges$$.$cljs$core$IFn$_invoke$arity$2$($points$jscomp$71$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$)};
$APP.$app$main$snap$create_ranges$$.$cljs$core$IFn$_invoke$arity$2$=function($points$jscomp$72$$,$selected_points$$){function $make_ranges$$($coord$jscomp$14$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($into_tree$$($coord$jscomp$14$$),new $$jscomp$scope$236007416$2$RangeTree$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$not$$,$selected_points__$1$$),$points$jscomp$72$$))}function $into_tree$$($coord$jscomp$13$$){return function($tree$jscomp$17$$,
$point$jscomp$59$$){var $value$jscomp$inline_6764$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$59$$,$coord$jscomp$13$$);return $JSCompiler_StaticMethods_insert$$($tree$jscomp$17$$,$value$jscomp$inline_6764$$,$point$jscomp$59$$)}}var $selected_points__$1$$=$APP.$cljs$core$truth_$$($selected_points$$)?$selected_points$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$;return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$make_ranges$$($APP.$cljs$cst$1510$x$$),
$APP.$cljs$cst$1511$y$$,$make_ranges$$($APP.$cljs$cst$1511$y$$)],null)};$APP.$app$main$snap$create_ranges$$.$cljs$lang$maxFixedArity$=2;
var $app$main$snap$merge_matches$$=function $app$main$snap$merge_matches$$($var_args$jscomp$1253$$){switch(arguments.length){case 0:return $app$main$snap$merge_matches$$.$cljs$core$IFn$_invoke$arity$0$();case 2:return $app$main$snap$merge_matches$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$main$snap$merge_matches$$.$cljs$core$IFn$_invoke$arity$0$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,null,$APP.$cljs$cst$1511$y$$,null],null)};
$app$main$snap$merge_matches$$.$cljs$core$IFn$_invoke$arity$2$=function($matches$jscomp$9$$,$other$jscomp$196$$){function $merge_coord$$($keys$jscomp$52_matches__$1$$,$other__$1$jscomp$1$$){var $matches__$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$keys$jscomp$52_matches__$1$$),$other__$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$other__$1$jscomp$1$$);$keys$jscomp$52_matches__$1$$=
$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($APP.$cljs$core$keys$$($matches__$2$$)),$APP.$cljs$core$set$$($APP.$cljs$core$keys$$($other__$2$$)));return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($key$jscomp$381$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$key$jscomp$381$$,$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($matches__$2$$,
$key$jscomp$381$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($other__$2$$,$key$jscomp$381$$,$APP.$cljs$core$PersistentVector$EMPTY$$)]))],null)}),$keys$jscomp$52_matches__$1$$)}return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($matches$jscomp$9$$,$APP.$cljs$cst$1510$x$$,$merge_coord$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$196$$)),
$APP.$cljs$cst$1511$y$$,$merge_coord$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$196$$))};$app$main$snap$merge_matches$$.$cljs$lang$maxFixedArity$=2;var $app$main$data$workspace$transforms$finish_transform_68929$$,$app$main$data$workspace$transforms$trigger_bounding_box_cloaking_69061$$,$app$main$data$workspace$transforms$update_dimensions_69078$$,$app$main$data$workspace$transforms$increase_rotation_69141$$,$app$main$data$workspace$transforms$start_move_selected_69156$$,$app$main$data$workspace$transforms$start_move_duplicate_69169$$,$app$main$data$workspace$transforms$set_ghost_displacement_69172$$,$app$main$data$workspace$transforms$start_move_69181$$,
$app$main$data$workspace$transforms$reorder_layout_child_69292$$,$app$main$data$workspace$transforms$nudge_selected_shapes_69340$$,$app$main$data$workspace$transforms$move_selected_69355$$,$app$main$data$workspace$transforms$update_position_69368$$,$app$main$data$workspace$transforms$update_positions_69373$$,$app$main$data$workspace$transforms$position_shapes_69376$$,$app$main$data$workspace$transforms$move_shapes_to_frame_69386$$,$app$main$data$workspace$transforms$flip_horizontal_selected_69392$$,
$app$main$data$workspace$transforms$flip_vertical_selected_69398$$,$app$main$data$workspace$transforms$increase_rotation$$=function $app$main$data$workspace$transforms$increase_rotation$$($var_args$jscomp$1256$$){switch(arguments.length){case 2:return $app$main$data$workspace$transforms$increase_rotation$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$104$$=[],$len__5749__auto___69448$$=arguments.length,$i__5750__auto___69449$$=0;;)if($i__5750__auto___69449$$<
$len__5749__auto___69448$$)$args_arr__5774__auto__$jscomp$104$$.push(arguments[$i__5750__auto___69449$$]),$i__5750__auto___69449$$+=1;else break;return $app$main$data$workspace$transforms$increase_rotation$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],arguments[2],3<$args_arr__5774__auto__$jscomp$104$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$104$$.slice(3),0,null):null)}};
$app$main$data$workspace$transforms$increase_rotation$$.$cljs$core$IFn$_invoke$arity$2$=function($ids$jscomp$120$$,$rotation$jscomp$14$$){return $app$main$data$workspace$transforms$increase_rotation$$($ids$jscomp$120$$,$rotation$jscomp$14$$,null)};
$app$main$data$workspace$transforms$increase_rotation$$.$cljs$core$IFn$_invoke$arity$variadic$=function($ids$jscomp$121$$,$rotation$jscomp$15$$,$p__69137$$,$p__69138$$){var $map__69139__$1$$=$APP.$cljs$core$__destructure_map$$($p__69137$$),$center$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69139__$1$$,$APP.$cljs$cst$1667$center$$),$delta_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69139__$1$$,$APP.$cljs$cst$3844$delta_QMARK_$$),$map__69140__$1$$=
$APP.$cljs$core$__destructure_map$$($p__69138$$),$no_wasm_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69140__$1$$,$cljs$cst$3864$no_wasm_QMARK_$$);typeof $app$main$data$workspace$transforms$increase_rotation_69141$$==="undefined"&&($app$main$data$workspace$transforms$increase_rotation_69141$$=function($options$jscomp$517$$,$map__69139$jscomp$1$$,$delta_QMARK_$jscomp$3$$,$p__69138$jscomp$1$$,$rotation$jscomp$16$$,$params$jscomp$276$$,$ids$jscomp$122$$,$map__69140$jscomp$1$$,
$center$jscomp$52$$,$p__69137$jscomp$1$$,$no_wasm_QMARK_$jscomp$3$$,$meta69142$$){this.options=$options$jscomp$517$$;this.$map__69139$=$map__69139$jscomp$1$$;this.$delta_QMARK_$=$delta_QMARK_$jscomp$3$$;this.$p__69138$=$p__69138$jscomp$1$$;this.rotation=$rotation$jscomp$16$$;this.params=$params$jscomp$276$$;this.ids=$ids$jscomp$122$$;this.$map__69140$=$map__69140$jscomp$1$$;this.$center$=$center$jscomp$52$$;this.$p__69137$=$p__69137$jscomp$1$$;this.$no_wasm_QMARK_$=$no_wasm_QMARK_$jscomp$3$$;this.$meta69142$=
$meta69142$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$increase_rotation_69141$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$increase_rotation_69141$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3868$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_increase_rotation$$},$app$main$data$workspace$transforms$increase_rotation_69141$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69143$$,$meta69142__$1$$){return new $app$main$data$workspace$transforms$increase_rotation_69141$$(this.options,this.$map__69139$,this.$delta_QMARK_$,this.$p__69138$,this.rotation,this.params,this.ids,this.$map__69140$,this.$center$,this.$p__69137$,this.$no_wasm_QMARK_$,$meta69142__$1$$)},$app$main$data$workspace$transforms$increase_rotation_69141$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69142$},$app$main$data$workspace$transforms$increase_rotation_69141$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$increase_rotation_69141$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2056_modif_tree$jscomp$58_page_id$jscomp$170$$,$state$jscomp$462$$){var $self__$jscomp$4616$$=this;if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$462$$,"render-wasm/v1")&&$APP.$cljs$core$not$$($self__$jscomp$4616$$.$no_wasm_QMARK_$)){var $objects$jscomp$483$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$462$$);
$_$jscomp$2056_modif_tree$jscomp$58_page_id$jscomp$170$$=$APP.$app$main$data$workspace$modifiers$build_modif_tree$$($self__$jscomp$4616$$.ids,$objects$jscomp$483$$,function($shape$jscomp$546$$){var $delta$jscomp$43$$=$APP.$cljs$core$truth_$$($self__$jscomp$4616$$.$delta_QMARK_$)?$self__$jscomp$4616$$.rotation:$self__$jscomp$4616$$.rotation-$APP.$cljs$cst$1788$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$546$$);var $center__$1$jscomp$5_or__5025__auto__$jscomp$inline_6767$$=$self__$jscomp$4616$$.$center$;
$center__$1$jscomp$5_or__5025__auto__$jscomp$inline_6767$$=$APP.$cljs$core$truth_$$($center__$1$jscomp$5_or__5025__auto__$jscomp$inline_6767$$)?$center__$1$jscomp$5_or__5025__auto__$jscomp$inline_6767$$:$APP.$app$common$geom$shapes$common$shape__GT_center$$($shape$jscomp$546$$);return $APP.$app$common$types$modifiers$rotation_modifiers$$($shape$jscomp$546$$,$center__$1$jscomp$5_or__5025__auto__$jscomp$inline_6767$$,$delta$jscomp$43$$)});return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($_$jscomp$2056_modif_tree$jscomp$58_page_id$jscomp$170$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2556$ignore_touched$$,$APP.$cljs$cst$2556$ignore_touched$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4616$$.options)])))}$_$jscomp$2056_modif_tree$jscomp$58_page_id$jscomp$170$$=function(){var $or__5025__auto__$jscomp$788$$=$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4616$$.options);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$788$$)?$or__5025__auto__$jscomp$788$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$462$$)}();
$objects$jscomp$483$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$462$$,$_$jscomp$2056_modif_tree$jscomp$58_page_id$jscomp$170$$);var $shapes$jscomp$96$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69126_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$483$$,$p1__69126_SHARP_$$)},$self__$jscomp$4616$$.ids),$options__$1$jscomp$70$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$4616$$.options,
$APP.$cljs$cst$2043$page_id$$,$_$jscomp$2056_modif_tree$jscomp$58_page_id$jscomp$170$$);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$modifiers$set_delta_rotation_modifiers$$($self__$jscomp$4616$$.rotation,$shapes$jscomp$96$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$4616$$.params,$APP.$cljs$cst$2043$page_id$$,$_$jscomp$2056_modif_tree$jscomp$58_page_id$jscomp$170$$))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$($options__$1$jscomp$70$$)))});
return new $app$main$data$workspace$transforms$increase_rotation_69141$$($map__69140__$1$$,$map__69139__$1$$,$delta_QMARK_$jscomp$2$$,$p__69138$$,$rotation$jscomp$15$$,$map__69139__$1$$,$ids$jscomp$121$$,$map__69140__$1$$,$center$jscomp$51$$,$p__69137$$,$no_wasm_QMARK_$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$increase_rotation$$.$cljs$lang$applyTo$=function($G__69130_seq69128$$){var $G__69129$$=$APP.$cljs$core$first$$($G__69130_seq69128$$),$G__69131_seq69128__$1$$=$APP.$cljs$core$next$$($G__69130_seq69128$$);$G__69130_seq69128$$=$APP.$cljs$core$first$$($G__69131_seq69128__$1$$);var $seq69128__$2_seq69128__$3$$=$APP.$cljs$core$next$$($G__69131_seq69128__$1$$);$G__69131_seq69128__$1$$=$APP.$cljs$core$first$$($seq69128__$2_seq69128__$3$$);$seq69128__$2_seq69128__$3$$=$APP.$cljs$core$next$$($seq69128__$2_seq69128__$3$$);
return this.$cljs$core$IFn$_invoke$arity$variadic$($G__69129$$,$G__69130_seq69128$$,$G__69131_seq69128__$1$$,$seq69128__$2_seq69128__$3$$)};$app$main$data$workspace$transforms$increase_rotation$$.$cljs$lang$maxFixedArity$=3;
var $app$main$data$workspace$transforms$nudge_selected_shapes$$=function $app$main$data$workspace$transforms$nudge_selected_shapes$$($direction$jscomp$17$$,$shift_QMARK_$jscomp$6$$){var $same_event$$=Symbol("same-event");typeof $app$main$data$workspace$transforms$nudge_selected_shapes_69340$$==="undefined"&&($app$main$data$workspace$transforms$nudge_selected_shapes_69340$$=function($direction$jscomp$18$$,$shift_QMARK_$jscomp$7$$,$same_event$jscomp$1$$,$meta69341$$){this.direction=$direction$jscomp$18$$;
this.$shift_QMARK_$=$shift_QMARK_$jscomp$7$$;this.$same_event$=$same_event$jscomp$1$$;this.$meta69341$=$meta69341$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$nudge_selected_shapes_69340$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$nudge_selected_shapes_69340$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3874$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_nudge_selected_shapes$$},
$app$main$data$workspace$transforms$nudge_selected_shapes_69340$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69342$$,$meta69341__$1$$){return new $app$main$data$workspace$transforms$nudge_selected_shapes_69340$$(this.direction,this.$shift_QMARK_$,this.$same_event$,$meta69341__$1$$)},$app$main$data$workspace$transforms$nudge_selected_shapes_69340$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69341$},$app$main$data$workspace$transforms$nudge_selected_shapes_69340$$.prototype.$cljs$core$IDeref$_deref$arity$1$=
function(){return this.direction},$app$main$data$workspace$transforms$nudge_selected_shapes_69340$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$nudge_selected_shapes_69340$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2065$$,$state$jscomp$468$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$468$$,$cljs$cst$3828$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_current_move_selected$$)==
null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc_in$$($state$jscomp$468$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1289$transform$$],null),$APP.$cljs$cst$1798$move$$),$cljs$cst$3828$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_current_move_selected$$,this.$same_event$):$state$jscomp$468$$},$app$main$data$workspace$transforms$nudge_selected_shapes_69340$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$nudge_selected_shapes_69340$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2066_move_events$$,$modif_stream_state$jscomp$469$$,$stream$jscomp$53$$){var $self__$jscomp$4644$$=this;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4644$$.$same_event$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modif_stream_state$jscomp$469$$,$cljs$cst$3828$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_current_move_selected$$))){var $selected$jscomp$48$$=
$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($modif_stream_state$jscomp$469$$),$nudge$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($modif_stream_state$jscomp$469$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1914$profile$$,$APP.$cljs$cst$575$props$$,$APP.$cljs$cst$3875$nudge$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3876$big$$,10,$APP.$cljs$cst$3877$small$$,
1],null));$_$jscomp$2066_move_events$$=$APP.$beicon$v2$core$filter$$(function($p1__69332_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4644$$.direction,$APP.$cljs$core$_deref$$($p1__69332_SHARP_$$))},$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3874$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_nudge_selected_shapes$$),$stream$jscomp$53$$));var $stopper$jscomp$15$$=$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$switch_map$$(function(){return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$timer$$)(1E3),
$APP.$beicon$v2$core$delay$$(250,$APP.$beicon$v2$core$filter$$($app$util$keyboard$key_up_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($app$util$keyboard$keyboard_event_QMARK_$$,$stream$jscomp$53$$))))},$_$jscomp$2066_move_events$$)),$scale$jscomp$30$$=$APP.$cljs$core$truth_$$($self__$jscomp$4644$$.$shift_QMARK_$)?$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$(function(){var $or__5025__auto__$jscomp$790$$=$APP.$cljs$cst$3876$big$$.$cljs$core$IFn$_invoke$arity$1$($nudge$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$790$$)?
$or__5025__auto__$jscomp$790$$:10}()):$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$(function(){var $or__5025__auto__$jscomp$791$$=$APP.$cljs$cst$3877$small$$.$cljs$core$IFn$_invoke$arity$1$($nudge$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$791$$)?$or__5025__auto__$jscomp$791$$:1}()),$mov_vec$$=$APP.$app$common$geom$point$multiply$$($app$main$data$workspace$transforms$get_displacement$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$transforms$get_displacement$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4644$$.direction):
$app$main$data$workspace$transforms$get_displacement$$($self__$jscomp$4644$$.direction),$scale$jscomp$30$$);return $APP.$app$main$features$active_feature_QMARK_$$($modif_stream_state$jscomp$469$$,"render-wasm/v1")?($modif_stream_state$jscomp$469$$=$APP.$beicon$v2$core$take_until$$($stopper$jscomp$15$$,$APP.$beicon$v2$core$map$$(function($p1__69334_SHARP_$$){return $APP.$app$main$data$workspace$modifiers$create_modif_tree$$($selected$jscomp$48$$,$APP.$app$common$types$modifiers$move_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$($p1__69334_SHARP_$$))},
$APP.$beicon$v2$core$scan$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__69333_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__69333_SHARP_$$,$mov_vec$$)},$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),$_$jscomp$2066_move_events$$))),$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$(function($p1__69335_SHARP_$$){return $APP.$app$main$data$workspace$modifiers$set_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($p1__69335_SHARP_$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3833$ignore_snap_pixel$$,!0],null)]))},$modif_stream_state$jscomp$469$$),$APP.$beicon$v2$core$map$$(function($p1__69336_SHARP_$$){return $APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($p1__69336_SHARP_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3833$ignore_snap_pixel$$,
!0],null)]))},$APP.$beicon$v2$core$last$$($modif_stream_state$jscomp$469$$)),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$transforms$nudge_selected_shapes$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$data$workspace$transforms$nudge_selected_shapes$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4644$$.direction,$self__$jscomp$4644$$.$shift_QMARK_$):$app$main$data$workspace$transforms$nudge_selected_shapes$$($self__$jscomp$4644$$.direction,$self__$jscomp$4644$$.$shift_QMARK_$))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$transforms$finish_transform$$()))):
$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($stopper$jscomp$15$$,$APP.$beicon$v2$core$map$$(function($p1__69339_SHARP_$$){return $APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($p1__69339_SHARP_$$,!1,!0,null)},$APP.$beicon$v2$core$map$$(function($p1__69338_SHARP_$$){return $APP.$app$main$data$workspace$modifiers$create_modif_tree$$($selected$jscomp$48$$,$APP.$app$common$types$modifiers$move_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$($p1__69338_SHARP_$$))},
$APP.$beicon$v2$core$scan$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__69337_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__69337_SHARP_$$,$mov_vec$$)},$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),$_$jscomp$2066_move_events$$)))),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$transforms$nudge_selected_shapes$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$data$workspace$transforms$nudge_selected_shapes$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4644$$.direction,
$self__$jscomp$4644$$.$shift_QMARK_$):$app$main$data$workspace$transforms$nudge_selected_shapes$$($self__$jscomp$4644$$.direction,$self__$jscomp$4644$$.$shift_QMARK_$))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$APP.$app$main$data$workspace$transforms$finish_transform$$()))}return $APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$transforms$nudge_selected_shapes_69340$$($direction$jscomp$17$$,
$shift_QMARK_$jscomp$6$$,$same_event$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};var $app$main$data$workspace$wasm_text$resize_wasm_text_68926$$,$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_commit_68947$$,$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner_68963$$,$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_68982$$,$app$main$data$workspace$wasm_text$resize_wasm_text_all_68994$$;
$APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$=function $app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$($var_args$jscomp$1267$$){switch(arguments.length){case 1:return $app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$1$=function($id$jscomp$564$$){return $APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$564$$,null)};
$APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$2$=function($id$jscomp$565$$,$p__68980$$){var $map__68981__$1$$=$APP.$cljs$core$__destructure_map$$($p__68980$$),$undo_group$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68981__$1$$,$APP.$cljs$cst$3138$undo_group$$),$undo_id$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68981__$1$$,$APP.$cljs$cst$3646$undo_id$$);typeof $app$main$data$workspace$wasm_text$resize_wasm_text_debounce_68982$$===
"undefined"&&($app$main$data$workspace$wasm_text$resize_wasm_text_debounce_68982$$=function($id$jscomp$566$$,$p__68980$jscomp$1$$,$map__68981$jscomp$1$$,$opts$jscomp$301$$,$undo_group$jscomp$22$$,$undo_id$jscomp$19$$,$meta68983$$){this.id=$id$jscomp$566$$;this.$p__68980$=$p__68980$jscomp$1$$;this.$map__68981$=$map__68981$jscomp$1$$;this.$opts$=$opts$jscomp$301$$;this.$undo_group$=$undo_group$jscomp$22$$;this.$undo_id$=$undo_id$jscomp$19$$;this.$meta68983$=$meta68983$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_68982$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_68982$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3896$app_DOT_main_DOT_data_DOT_workspace_DOT_wasm_text_SLASH_resize_wasm_text_debounce$$},$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_68982$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_68984$$,$meta68983__$1$$){return new $app$main$data$workspace$wasm_text$resize_wasm_text_debounce_68982$$(this.id,this.$p__68980$,this.$map__68981$,this.$opts$,this.$undo_group$,this.$undo_id$,$meta68983__$1$$)},$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_68982$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68983$},$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_68982$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$wasm_text$resize_wasm_text_debounce_68982$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2080_page_id$jscomp$175$$,$content$jscomp$171_fonts$jscomp$22_objects$jscomp$499_pass_opts_state$jscomp$482$$){var $self__$jscomp$4697$$=this;$_$jscomp$2080_page_id$jscomp$175$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$171_fonts$jscomp$22_objects$jscomp$499_pass_opts_state$jscomp$482$$);$content$jscomp$171_fonts$jscomp$22_objects$jscomp$499_pass_opts_state$jscomp$482$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$171_fonts$jscomp$22_objects$jscomp$499_pass_opts_state$jscomp$482$$,$_$jscomp$2080_page_id$jscomp$175$$);$content$jscomp$171_fonts$jscomp$22_objects$jscomp$499_pass_opts_state$jscomp$482$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$171_fonts$jscomp$22_objects$jscomp$499_pass_opts_state$jscomp$482$$,$self__$jscomp$4697$$.id),
$APP.$cljs$cst$1637$content$$);$content$jscomp$171_fonts$jscomp$22_objects$jscomp$499_pass_opts_state$jscomp$482$$=$app$render_wasm$api$fonts$get_content_fonts$$($content$jscomp$171_fonts$jscomp$22_objects$jscomp$499_pass_opts_state$jscomp$482$$);return $APP.$cljs$core$every_QMARK_$$(function($font$jscomp$39_font_data$jscomp$10$$){$font$jscomp$39_font_data$jscomp$10$$=$app$render_wasm$api$fonts$make_font_data$$($font$jscomp$39_font_data$jscomp$10$$);return $app$render_wasm$api$fonts$font_stored_QMARK_$$($font$jscomp$39_font_data$jscomp$10$$,
$cljs$cst$2980$emoji_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$39_font_data$jscomp$10$$))},$content$jscomp$171_fonts$jscomp$22_objects$jscomp$499_pass_opts_state$jscomp$482$$)?($content$jscomp$171_fonts$jscomp$22_objects$jscomp$499_pass_opts_state$jscomp$482$$=$self__$jscomp$4697$$.$undo_group$!=null||$self__$jscomp$4697$$.$undo_id$!=null?function(){var $G__68991_G__68991__$1$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;$G__68991_G__68991__$1$$=$self__$jscomp$4697$$.$undo_group$!=null?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__68991_G__68991__$1$$,$APP.$cljs$cst$3138$undo_group$$,$self__$jscomp$4697$$.$undo_group$):$G__68991_G__68991__$1$$;return $self__$jscomp$4697$$.$undo_id$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__68991_G__68991__$1$$,$APP.$cljs$cst$3646$undo_id$$,$self__$jscomp$4697$$.$undo_id$):$G__68991_G__68991__$1$$}():null,(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$wasm_text$resize_wasm_text_debounce_inner$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$4697$$.id,
$content$jscomp$171_fonts$jscomp$22_objects$jscomp$499_pass_opts_state$jscomp$482$$))):$APP.$beicon$v2$core$delay$$(20,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4697$$.id,$self__$jscomp$4697$$.$opts$)))});return new $app$main$data$workspace$wasm_text$resize_wasm_text_debounce_68982$$($id$jscomp$565$$,$p__68980$$,$map__68981__$1$$,$map__68981__$1$$,$undo_group$jscomp$21$$,$undo_id$jscomp$18$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$lang$maxFixedArity$=2;var $app$main$data$workspace$libraries$add_color_69429$$,$app$main$data$workspace$libraries$clear_color_for_rename_69434$$,$app$main$data$workspace$libraries$update_color_69444$$,$app$main$data$workspace$libraries$rename_color_69455$$,$app$main$data$workspace$libraries$delete_color_69461$$,$app$main$data$workspace$libraries$add_typography_69485$$,$app$main$data$workspace$libraries$update_typography_69493$$,$app$main$data$workspace$libraries$rename_typography_69496$$,$app$main$data$workspace$libraries$delete_typography_69505$$,
$app$main$data$workspace$libraries$add_component2_69513$$,$app$main$data$workspace$libraries$add_component_69525$$,$app$main$data$workspace$libraries$rename_component_69535$$,$app$main$data$workspace$libraries$rename_component_and_main_instance_69554$$,$app$main$data$workspace$libraries$delete_component_69567$$,$app$main$data$workspace$libraries$instantiate_component_69586$$,$app$main$data$workspace$libraries$detach_component_69597$$,$app$main$data$workspace$libraries$detach_selected_components_69627$$,
$app$main$data$workspace$libraries$go_to_local_component_69646$$,$app$main$data$workspace$libraries$library_thumbnails_fetched_69654$$,$app$main$data$workspace$libraries$fetch_library_thumbnails_69657$$,$app$main$data$workspace$libraries$ext_library_changed_69660$$,$app$main$data$workspace$libraries$launch_component_sync_69734$$,$app$main$data$workspace$libraries$update_component_thumbnail_69750$$,$app$main$data$workspace$libraries$component_swap_69768$$,$app$main$data$workspace$libraries$set_updating_library_69801$$,
$app$main$data$workspace$libraries$sync_file_69822$$,$app$main$data$workspace$libraries$ignore_sync_69839$$,$app$main$data$workspace$libraries$notify_sync_file_69861$$,$app$main$data$workspace$libraries$touch_component_69873$$,$app$main$data$workspace$libraries$component_changed_69880$$,$app$main$data$workspace$libraries$watch_component_changes_69896$$,$app$main$data$workspace$libraries$libraries_fetched_69932$$,$app$main$data$workspace$libraries$load_library_file_69936$$,$app$main$data$workspace$libraries$attach_library_69943$$,
$app$main$data$workspace$libraries$attach_library_finished_69953$$;$APP.$app$common$logging$loggers$$.set("app.main.data.workspace.libraries",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));
typeof $app$main$data$workspace$libraries$clear_color_for_rename_69434$$==="undefined"&&($app$main$data$workspace$libraries$clear_color_for_rename_69434$$=function($meta69435$jscomp$inline_6789$$){this.$meta69435$=$meta69435$jscomp$inline_6789$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$libraries$clear_color_for_rename_69434$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3905$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_clear_color_for_rename$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69436$jscomp$inline_6790$$,$meta69435__$1$jscomp$inline_6791$$){return new $app$main$data$workspace$libraries$clear_color_for_rename_69434$$($meta69435__$1$jscomp$inline_6791$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69435$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_6792$$,$state$jscomp$inline_6793$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$inline_6793$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$3904$color_for_rename$$],
null),null)});$APP.$app$main$data$workspace$libraries$clear_color_for_rename$$=new $app$main$data$workspace$libraries$clear_color_for_rename_69434$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $app$main$data$workspace$libraries$detach_selected_components$$;
typeof $app$main$data$workspace$libraries$detach_selected_components_69627$$==="undefined"&&($app$main$data$workspace$libraries$detach_selected_components_69627$$=function($meta69628$jscomp$inline_6811$$){this.$meta69628$=$meta69628$jscomp$inline_6811$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$libraries$detach_selected_components_69627$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3936$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_detach_selected_components$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69629$jscomp$inline_6812$$,$meta69628__$1$jscomp$inline_6813$$){return new $app$main$data$workspace$libraries$detach_selected_components_69627$$($meta69628__$1$jscomp$inline_6813$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69628$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function($can_detach_QMARK_$jscomp$inline_6824_file_id$jscomp$inline_6817_it$jscomp$inline_6814_selected_objects$jscomp$inline_6822$$,$changes$jscomp$inline_6825_selected$jscomp$inline_6821_state$jscomp$inline_6815$$){var $page_id$jscomp$inline_6816$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$inline_6825_selected$jscomp$inline_6821_state$jscomp$inline_6815$$);
$can_detach_QMARK_$jscomp$inline_6824_file_id$jscomp$inline_6817_it$jscomp$inline_6814_selected_objects$jscomp$inline_6822$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$inline_6825_selected$jscomp$inline_6821_state$jscomp$inline_6815$$);var $objects$jscomp$inline_6818$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$inline_6825_selected$jscomp$inline_6821_state$jscomp$inline_6815$$,$page_id$jscomp$inline_6816$$),
$libraries$jscomp$inline_6819$$=$APP.$app$main$data$helpers$lookup_libraries$$($changes$jscomp$inline_6825_selected$jscomp$inline_6821_state$jscomp$inline_6815$$),$fdata$jscomp$inline_6820$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$inline_6825_selected$jscomp$inline_6821_state$jscomp$inline_6815$$,$can_detach_QMARK_$jscomp$inline_6824_file_id$jscomp$inline_6817_it$jscomp$inline_6814_selected_objects$jscomp$inline_6822$$);$changes$jscomp$inline_6825_selected$jscomp$inline_6821_state$jscomp$inline_6815$$=
$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$inline_6818$$,$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($changes$jscomp$inline_6825_selected$jscomp$inline_6821_state$jscomp$inline_6815$$));$can_detach_QMARK_$jscomp$inline_6824_file_id$jscomp$inline_6817_it$jscomp$inline_6814_selected_objects$jscomp$inline_6822$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69624_SHARP_$jscomp$inline_6826$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_6818$$,
$p1__69624_SHARP_$jscomp$inline_6826$$)},$changes$jscomp$inline_6825_selected$jscomp$inline_6821_state$jscomp$inline_6815$$);var $copies$jscomp$inline_6823$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$in_component_copy_QMARK_$$,$can_detach_QMARK_$jscomp$inline_6824_file_id$jscomp$inline_6817_it$jscomp$inline_6814_selected_objects$jscomp$inline_6822$$);$changes$jscomp$inline_6825_selected$jscomp$inline_6821_state$jscomp$inline_6815$$=($can_detach_QMARK_$jscomp$inline_6824_file_id$jscomp$inline_6817_it$jscomp$inline_6814_selected_objects$jscomp$inline_6822$$=
$APP.$cljs$core$seq$$($copies$jscomp$inline_6823$$)&&$APP.$cljs$core$every_QMARK_$$(function($p1__69625_SHARP_$jscomp$inline_6827$$){return $APP.$cljs$core$not$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$inline_6818$$,$p1__69625_SHARP_$jscomp$inline_6827$$))},$can_detach_QMARK_$jscomp$inline_6824_file_id$jscomp$inline_6817_it$jscomp$inline_6814_selected_objects$jscomp$inline_6822$$))?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes$jscomp$inline_6828$$,
$id$jscomp$inline_6829$$){return $app$common$logic$libraries$generate_detach_component$$($changes$jscomp$inline_6828$$,$id$jscomp$inline_6829$$,$fdata$jscomp$inline_6820$$,$page_id$jscomp$inline_6816$$,$libraries$jscomp$inline_6819$$)},$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$inline_6825_selected$jscomp$inline_6821_state$jscomp$inline_6815$$):null;return(0,$APP.$beicon$v2$core$of$$)($can_detach_QMARK_$jscomp$inline_6824_file_id$jscomp$inline_6817_it$jscomp$inline_6814_selected_objects$jscomp$inline_6822$$?
$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$inline_6825_selected$jscomp$inline_6821_state$jscomp$inline_6815$$):null)});$app$main$data$workspace$libraries$detach_selected_components$$=new $app$main$data$workspace$libraries$detach_selected_components_69627$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $app$main$data$workspace$libraries$ignore_sync$$;
typeof $app$main$data$workspace$libraries$ignore_sync_69839$$==="undefined"&&($app$main$data$workspace$libraries$ignore_sync_69839$$=function($meta69840$jscomp$inline_6835$$){this.$meta69840$=$meta69840$jscomp$inline_6835$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$libraries$ignore_sync_69839$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3967$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_ignore_sync$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69841$jscomp$inline_6836$$,$meta69840__$1$jscomp$inline_6837$$){return new $app$main$data$workspace$libraries$ignore_sync_69839$$($meta69840__$1$jscomp$inline_6837$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69840$},
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_6838_file_id$jscomp$inline_6840$$,$state$jscomp$inline_6839$$){$_$jscomp$inline_6838_file_id$jscomp$inline_6840$$=$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$inline_6839$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$inline_6839$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1916$files$$,$_$jscomp$inline_6838_file_id$jscomp$inline_6840$$,$cljs$cst$2585$ignore_sync_until$$],null),$APP.$app$common$time$now$$())},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$inline_6841_file_id$jscomp$inline_6843$$,$state$jscomp$inline_6842$$){$_$jscomp$inline_6841_file_id$jscomp$inline_6843$$=
$APP.$cljs$cst$1917$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$inline_6842$$);return $APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3968$ignore_file_library_sync_status$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1644$file_id$$,$_$jscomp$inline_6841_file_id$jscomp$inline_6843$$,$cljs$cst$3969$date$$,$APP.$app$common$time$now$$()],null)))});$app$main$data$workspace$libraries$ignore_sync$$=new $app$main$data$workspace$libraries$ignore_sync_69839$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$=shadow$bridge("@penpot/draft-js");var $app$main$data$workspace$texts$update_editor_state_70036$$,$app$main$data$workspace$texts$update_root_attrs_70148$$,$app$main$data$workspace$texts$update_paragraph_attrs_70168$$,$app$main$data$workspace$texts$update_text_attrs_70179$$,$app$main$data$workspace$texts$update_text_with_function_70204$$,$app$main$data$workspace$texts$start_edit_if_selected_70218$$,$app$main$data$workspace$texts$update_attrs_70334$$,$app$main$data$workspace$texts$apply_typography_70347$$,$app$main$data$workspace$texts$v2_update_text_editor_styles_70361$$,
$app$main$data$workspace$texts$v2_update_text_shape_content_70380$$,$app$main$data$workspace$texts$create_root_from_html$$,$app$main$data$workspace$texts$start_edit_if_selected$$;$app$main$data$workspace$texts$create_root_from_html$$=$shadow$js$shim$module$0$0penpot$0text_editor$$.createRootFromHTML;$APP.$app$main$data$workspace$texts$create_editor$$=$shadow$js$shim$module$0$0penpot$0text_editor$$.create;$APP.$app$main$data$workspace$texts$set_editor_root_BANG_$$=$shadow$js$shim$module$0$0penpot$0text_editor$$.setRoot;
$APP.$app$main$data$workspace$texts$get_editor_root$$=$shadow$js$shim$module$0$0penpot$0text_editor$$.getRoot;$APP.$app$main$data$workspace$texts$is_empty_QMARK_$$=$shadow$js$shim$module$0$0penpot$0text_editor$$.isEmpty;$APP.$app$main$data$workspace$texts$dispose_BANG_$$=$shadow$js$shim$module$0$0penpot$0text_editor$$.dispose;
typeof $app$main$data$workspace$texts$start_edit_if_selected_70218$$==="undefined"&&($app$main$data$workspace$texts$start_edit_if_selected_70218$$=function($meta70219$jscomp$inline_6901$$){this.$meta70219$=$meta70219$jscomp$inline_6901$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$texts$start_edit_if_selected_70218$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4018$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_start_edit_if_selected$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70220$jscomp$inline_6902$$,$meta70219__$1$jscomp$inline_6903$$){return new $app$main$data$workspace$texts$start_edit_if_selected_70218$$($meta70219__$1$jscomp$inline_6903$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70219$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_6904_selected$jscomp$inline_6907$$,$state$jscomp$inline_6905$$){var $objects$jscomp$inline_6906$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$inline_6905$$);$_$jscomp$inline_6904_selected$jscomp$inline_6907$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70217_SHARP_$jscomp$inline_6908$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_6906$$,
$p1__70217_SHARP_$jscomp$inline_6908$$)},$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$inline_6905$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($_$jscomp$inline_6904_selected$jscomp$inline_6907$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($_$jscomp$inline_6904_selected$jscomp$inline_6907$$)),$APP.$cljs$cst$1588$text$$)?
$APP.$cljs$core$assoc_in$$($state$jscomp$inline_6905$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2199$edition$$],null),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($_$jscomp$inline_6904_selected$jscomp$inline_6907$$))):$state$jscomp$inline_6905$$});$app$main$data$workspace$texts$start_edit_if_selected$$=new $app$main$data$workspace$texts$start_edit_if_selected_70218$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $shadow$js$shim$module$0js_beautify$$=shadow$bridge("js-beautify");var $app$util$code_gen$style_css_formats$css_formatters$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$4049$border_style$$,$APP.$cljs$cst$1984$min_width$$,$cljs$cst$4050$padding_inline_end$$,$cljs$cst$4051$box_shadow$$,$cljs$cst$4052$padding_block_start$$,$APP.$cljs$cst$1986$max_height$$,$cljs$cst$4053$margin_inline_end$$,$cljs$cst$1988$min_height$$,$APP.$cljs$cst$1562$top$$,$cljs$cst$4054$border_end_start_radius$$,$cljs$cst$4055$max_block_size$$,$cljs$cst$4056$padding_block_end$$,$cljs$cst$4057$min_inline_size$$,
$cljs$cst$4058$margin_block_end$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$2058$background$$,$cljs$cst$4059$grid_template_rows$$,$APP.$cljs$cst$281$max_width$$,$cljs$cst$4060$backdrop_filter$$,$APP.$cljs$cst$1682$column_gap$$,$cljs$cst$4061$border_width$$,$APP.$cljs$cst$2691$filter$$,$cljs$cst$4062$margin_block_start$$,$cljs$cst$4063$border_start_end_radius$$,$cljs$cst$4064$min_block_size$$,$APP.$cljs$cst$256$padding$$,$APP.$cljs$cst$4065$gap$$,$cljs$cst$4066$max_inline_size$$,$cljs$cst$4067$border_color$$,
$cljs$cst$4068$border_end_end_radius$$,$cljs$cst$4069$margin_inline_start$$,$cljs$cst$4070$grid_template_columns$$,$APP.$cljs$cst$4071$border$$,$APP.$cljs$cst$1982$border_radius$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1681$row_gap$$,$cljs$cst$4072$border_start_start_radius$$,$APP.$cljs$cst$257$left$$,$cljs$cst$4073$padding_inline_start$$,$APP.$cljs$cst$1929$margin$$],[$cljs$cst$4049$border_style$$,$APP.$cljs$cst$874$size$$,$cljs$cst$4074$size_array$$,$APP.$cljs$cst$4075$shadows$$,$cljs$cst$4074$size_array$$,
$APP.$cljs$cst$874$size$$,$cljs$cst$4074$size_array$$,$APP.$cljs$cst$874$size$$,$APP.$cljs$cst$1676$position$$,$cljs$cst$4076$string_or_size_array$$,$APP.$cljs$cst$874$size$$,$cljs$cst$4074$size_array$$,$APP.$cljs$cst$874$size$$,$cljs$cst$4074$size_array$$,$APP.$cljs$cst$874$size$$,$APP.$cljs$cst$1298$color$$,$cljs$cst$4077$tracks$$,$APP.$cljs$cst$874$size$$,$APP.$cljs$cst$1653$blur$$,$cljs$cst$4074$size_array$$,$cljs$cst$4061$border_width$$,$APP.$cljs$cst$1653$blur$$,$cljs$cst$4074$size_array$$,
$cljs$cst$4076$string_or_size_array$$,$APP.$cljs$cst$874$size$$,$cljs$cst$4074$size_array$$,$cljs$cst$4074$size_array$$,$APP.$cljs$cst$874$size$$,$cljs$cst$4067$border_color$$,$cljs$cst$4076$string_or_size_array$$,$cljs$cst$4074$size_array$$,$cljs$cst$4077$tracks$$,$APP.$cljs$cst$4071$border$$,$cljs$cst$4076$string_or_size_array$$,$APP.$cljs$cst$874$size$$,$cljs$cst$4074$size_array$$,$cljs$cst$4076$string_or_size_array$$,$APP.$cljs$cst$1676$position$$,$cljs$cst$4074$size_array$$,$cljs$cst$4074$size_array$$]);var $app$util$code_gen$style_css$shape_wrapper_css_properties$$,$app$util$code_gen$style_css$shape_css_properties$$;
$app$util$code_gen$style_css$shape_wrapper_css_properties$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,14,[$APP.$cljs$cst$1984$min_width$$,null,$APP.$cljs$cst$1986$max_height$$,null,$cljs$cst$1988$min_height$$,null,$APP.$cljs$cst$1562$top$$,null,$APP.$cljs$cst$1678$justify_self$$,null,$APP.$cljs$cst$281$max_width$$,null,$cljs$cst$4082$flex_shrink$$,null,$cljs$cst$4083$grid_row$$,null,$cljs$cst$4084$z_index$$,null,$APP.$cljs$cst$1676$position$$,null,
$APP.$cljs$cst$1677$align_self$$,null,$cljs$cst$4085$grid_column$$,null,$APP.$cljs$cst$257$left$$,null,$APP.$cljs$cst$1929$margin$$,null],null),null);
$app$util$code_gen$style_css$shape_css_properties$$=$APP.$cljs$core$PersistentVector$fromArray$$([$APP.$cljs$cst$1676$position$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1562$top$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1289$transform$$,$APP.$cljs$cst$2058$background$$,$APP.$cljs$cst$4071$border$$,$cljs$cst$4072$border_start_start_radius$$,$cljs$cst$4063$border_start_end_radius$$,$cljs$cst$4054$border_end_start_radius$$,$cljs$cst$4068$border_end_end_radius$$,$cljs$cst$4051$box_shadow$$,
$APP.$cljs$cst$2691$filter$$,$cljs$cst$4060$backdrop_filter$$,$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$2909$overflow$$,$APP.$cljs$cst$1867$blend_mode$$,$APP.$cljs$cst$1932$display$$,$APP.$cljs$cst$4086$align_items$$,$APP.$cljs$cst$4087$align_content$$,$APP.$cljs$cst$4088$justify_items$$,$APP.$cljs$cst$4089$justify_content$$,$APP.$cljs$cst$4065$gap$$,$APP.$cljs$cst$1682$column_gap$$,$APP.$cljs$cst$1681$row_gap$$,$cljs$cst$4073$padding_inline_start$$,$cljs$cst$4050$padding_inline_end$$,$cljs$cst$4052$padding_block_start$$,
$cljs$cst$4056$padding_block_end$$,$cljs$cst$4084$z_index$$,$APP.$cljs$cst$4090$flex_direction$$,$APP.$cljs$cst$4091$flex_wrap$$,$APP.$cljs$cst$1660$flex$$,$cljs$cst$4092$flex_grow$$,$cljs$cst$4059$grid_template_rows$$,$cljs$cst$4070$grid_template_columns$$,$cljs$cst$4093$grid_template_areas$$,$cljs$cst$4094$grid_auto_flow$$,$cljs$cst$4082$flex_shrink$$,$APP.$cljs$cst$1929$margin$$,$cljs$cst$4062$margin_block_start$$,$cljs$cst$4058$margin_block_end$$,$cljs$cst$4069$margin_inline_start$$,$cljs$cst$4053$margin_inline_end$$,
$APP.$cljs$cst$1986$max_height$$,$cljs$cst$4055$max_block_size$$,$cljs$cst$1988$min_height$$,$cljs$cst$4064$min_block_size$$,$APP.$cljs$cst$281$max_width$$,$cljs$cst$4066$max_inline_size$$,$APP.$cljs$cst$1984$min_width$$,$cljs$cst$4057$min_inline_size$$,$APP.$cljs$cst$1677$align_self$$,$APP.$cljs$cst$1678$justify_self$$,$cljs$cst$4085$grid_column$$,$cljs$cst$4083$grid_row$$,$cljs$cst$4095$grid_area$$],!0);
$APP.$app$util$code_gen$style_css$generate_style$$=function $app$util$code_gen$style_css$generate_style$$($var_args$jscomp$1292$$){switch(arguments.length){case 3:return $app$util$code_gen$style_css$generate_style$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$util$code_gen$style_css$generate_style$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$util$code_gen$style_css$generate_style$$.$cljs$core$IFn$_invoke$arity$3$=function($objects$jscomp$569$$,$root_shapes$$,$all_shapes$$){return $APP.$app$util$code_gen$style_css$generate_style$$.$cljs$core$IFn$_invoke$arity$4$($objects$jscomp$569$$,$root_shapes$$,$all_shapes$$,null)};
$APP.$app$util$code_gen$style_css$generate_style$$.$cljs$core$IFn$_invoke$arity$4$=function($objects$jscomp$570$$,$root_shapes$jscomp$1$$,$all_shapes$jscomp$1$$,$map__69249__$1_p__69248$$){$map__69249__$1_p__69248$$=$APP.$cljs$core$__destructure_map$$($map__69249__$1_p__69248$$);var $with_prelude_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__69249__$1_p__69248$$,$APP.$cljs$cst$4097$with_prelude_QMARK_$$,!0),$options__$1$jscomp$71$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__69249__$1_p__69248$$,
$cljs$cst$4079$root_shapes$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$root_shapes$jscomp$1$$));return($APP.$cljs$core$truth_$$($with_prelude_QMARK_$$)?"\nhtml, body {\n  margin: 0;\n  min-height: 100%;\n  min-width: 100%;\n  padding: 0;\n}\n\nbody {\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  width: 100vw;\n  min-height: 100vh;\n}\n\n* {\n  box-sizing: border-box;\n}\n\n.text-node { background-clip: text !important; -webkit-background-clip: text !important; }\n\n":
"")+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n\n",$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$){if($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$!=null&&$APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$)!=null){var $selector$jscomp$inline_12771$$=$app$util$code_gen$common$shape__GT_selector$$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$),
$wrapper_QMARK_$jscomp$inline_12772$$=$app$util$code_gen$common$has_wrapper_QMARK_$$($objects$jscomp$570$$,$JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$),$svg_QMARK_$jscomp$inline_12773$$=$app$util$code_gen$common$svg_markup_QMARK_$$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$),$css_properties$jscomp$inline_12774_properties$jscomp$inline_12775$$=$wrapper_QMARK_$jscomp$inline_12772$$?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$complement$$($app$util$code_gen$style_css$shape_wrapper_css_properties$$),
$app$util$code_gen$style_css$shape_css_properties$$):$app$util$code_gen$style_css$shape_css_properties$$;$css_properties$jscomp$inline_12774_properties$jscomp$inline_12775$$=$app$util$code_gen$style_css$format_css_properties$$($app$util$code_gen$style_css$shape__GT_css_properties$$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$,$objects$jscomp$570$$,$css_properties$jscomp$inline_12774_properties$jscomp$inline_12775$$,$options__$1$jscomp$71$$),$options__$1$jscomp$71$$);if($wrapper_QMARK_$jscomp$inline_12772$$){var $JSCompiler_temp$jscomp$14066_JSCompiler_temp_const$jscomp$14068_wrapper_properties$jscomp$inline_12776$$=
$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$;var $JSCompiler_inline_result$jscomp$14072_JSCompiler_temp$jscomp$14071_JSCompiler_temp_const$jscomp$14067_wrapper_child_properties$jscomp$inline_12777$$=$app$util$code_gen$style_css$shape__GT_css_properties$$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$,$objects$jscomp$570$$,$app$util$code_gen$style_css$shape_wrapper_css_properties$$,$options__$1$jscomp$71$$);if($APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$570$$,
$JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$)&&!$app$common$geom$matrix$unit_QMARK_$$($APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$))){var $G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$570$$,
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$));var $JSCompiler_temp_const$jscomp$inline_12779_bounds$jscomp$inline_14441_height$jscomp$inline_14443$$=$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$),$APP.$cljs$cst$1604$points$$.$cljs$core$IFn$_invoke$arity$1$($G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$));
$G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$=$APP.$app$common$geom$shapes$points$width_points$$($JSCompiler_temp_const$jscomp$inline_12779_bounds$jscomp$inline_14441_height$jscomp$inline_14443$$);$JSCompiler_temp_const$jscomp$inline_12779_bounds$jscomp$inline_14441_height$jscomp$inline_14443$$=
$APP.$app$common$geom$shapes$points$height_points$$($JSCompiler_temp_const$jscomp$inline_12779_bounds$jscomp$inline_14441_height$jscomp$inline_14443$$);$G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$,$G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1522$height$$,$JSCompiler_temp_const$jscomp$inline_12779_bounds$jscomp$inline_14441_height$jscomp$inline_14443$$],
null)],null);$G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$=!$APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$570$$,$JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$)||$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$))?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,"relative"],null)):$G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$}else $G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$=
null;$JSCompiler_temp$jscomp$14066_JSCompiler_temp_const$jscomp$14068_wrapper_properties$jscomp$inline_12776$$=$app$util$code_gen$style_css$format_css_properties$$($JSCompiler_temp$jscomp$14066_JSCompiler_temp_const$jscomp$14068_wrapper_properties$jscomp$inline_12776$$.call($APP.$app$common$data$concat_vec$$,$JSCompiler_inline_result$jscomp$14072_JSCompiler_temp$jscomp$14071_JSCompiler_temp_const$jscomp$14067_wrapper_child_properties$jscomp$inline_12777$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$])),
$options__$1$jscomp$71$$)}else $JSCompiler_temp$jscomp$14066_JSCompiler_temp_const$jscomp$14068_wrapper_properties$jscomp$inline_12776$$=null;$wrapper_QMARK_$jscomp$inline_12772$$?($JSCompiler_inline_result$jscomp$14072_JSCompiler_temp$jscomp$14071_JSCompiler_temp_const$jscomp$14067_wrapper_child_properties$jscomp$inline_12777$$=$APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$570$$,$JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$)&&!$app$common$geom$matrix$unit_QMARK_$$($APP.$cljs$cst$1289$transform$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$))?
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,"absolute"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$257$left$$,"50%"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1562$top$$,"50%"],
null)],null):null,$JSCompiler_inline_result$jscomp$14072_JSCompiler_temp$jscomp$14071_JSCompiler_temp_const$jscomp$14067_wrapper_child_properties$jscomp$inline_12777$$=$app$util$code_gen$style_css$format_css_properties$$($JSCompiler_inline_result$jscomp$14072_JSCompiler_temp$jscomp$14071_JSCompiler_temp_const$jscomp$14067_wrapper_child_properties$jscomp$inline_12777$$,$options__$1$jscomp$71$$)):$JSCompiler_inline_result$jscomp$14072_JSCompiler_temp$jscomp$14071_JSCompiler_temp_const$jscomp$14067_wrapper_child_properties$jscomp$inline_12777$$=
null;$svg_QMARK_$jscomp$inline_12773$$?($G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$=$APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$570$$,$JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$),$G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$=
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,"absolute"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1562$top$$,0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$257$left$$,0],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1289$transform$$,"translate("+($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$))+
"px,")+($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$)-$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1605$selrect$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$))+"px)")],
null)],null),$G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$=$app$util$code_gen$style_css$format_css_properties$$($G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$,
$options__$1$jscomp$71$$)):$G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$=null;$JSCompiler_temp_const$jscomp$inline_12779_bounds$jscomp$inline_14441_height$jscomp$inline_14443$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$;var $JSCompiler_temp_const$jscomp$inline_12780$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$,
$JSCompiler_temp_const$jscomp$inline_12781$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;var $G__69217$jscomp$inline_12783_JSCompiler_inline_result$jscomp$inline_12782$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$);$G__69217$jscomp$inline_12783_JSCompiler_inline_result$jscomp$inline_12782$$=$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$("/* %s */",$G__69217$jscomp$inline_12783_JSCompiler_inline_result$jscomp$inline_12782$$):
$APP.$cuerdas$core$format$$("/* %s */",$G__69217$jscomp$inline_12783_JSCompiler_inline_result$jscomp$inline_12782$$);$JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$=$JSCompiler_temp_const$jscomp$inline_12779_bounds$jscomp$inline_14441_height$jscomp$inline_14443$$.call($APP.$cuerdas$core$join$$,"\n",$JSCompiler_temp_const$jscomp$inline_12780$$.call($APP.$cljs$core$filter$$,$APP.$cljs$core$some_QMARK_$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$JSCompiler_temp_const$jscomp$inline_12781$$,
[$G__69217$jscomp$inline_12783_JSCompiler_inline_result$jscomp$inline_12782$$,$wrapper_QMARK_$jscomp$inline_12772$$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$3$(".%s-wrapper {\n%s\n}",$selector$jscomp$inline_12771$$,$JSCompiler_temp$jscomp$14066_JSCompiler_temp_const$jscomp$14068_wrapper_properties$jscomp$inline_12776$$):$APP.$cuerdas$core$format$$(".%s-wrapper {\n%s\n}",$selector$jscomp$inline_12771$$,$JSCompiler_temp$jscomp$14066_JSCompiler_temp_const$jscomp$14068_wrapper_properties$jscomp$inline_12776$$):
null,$wrapper_QMARK_$jscomp$inline_12772$$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$3$(".%s-wrapper \x3e * {\n%s\n}",$selector$jscomp$inline_12771$$,$JSCompiler_inline_result$jscomp$14072_JSCompiler_temp$jscomp$14071_JSCompiler_temp_const$jscomp$14067_wrapper_child_properties$jscomp$inline_12777$$):$APP.$cuerdas$core$format$$(".%s-wrapper \x3e * {\n%s\n}",$selector$jscomp$inline_12771$$,$JSCompiler_inline_result$jscomp$14072_JSCompiler_temp$jscomp$14071_JSCompiler_temp_const$jscomp$14067_wrapper_child_properties$jscomp$inline_12777$$):
null,$svg_QMARK_$jscomp$inline_12773$$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$3$(".%s \x3e svg {\n%s\n}",$selector$jscomp$inline_12771$$,$G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$):$APP.$cuerdas$core$format$$(".%s \x3e svg {\n%s\n}",
$selector$jscomp$inline_12771$$,$G__69178$jscomp$inline_14444_JSCompiler_inline_result$jscomp$14070_JSCompiler_inline_result$jscomp$14074_JSCompiler_temp$jscomp$14073_bounds$jscomp$inline_14451_parent$jscomp$inline_14440_svg_child_props$jscomp$inline_12778_width$jscomp$inline_14442$$):null,$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$3$(".%s {\n%s\n}",$selector$jscomp$inline_12771$$,$css_properties$jscomp$inline_12774_properties$jscomp$inline_12775$$):
$APP.$cuerdas$core$format$$(".%s {\n%s\n}",$selector$jscomp$inline_12771$$,$css_properties$jscomp$inline_12774_properties$jscomp$inline_12775$$),$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$)?$app$util$code_gen$style_css$generate_text_css$$($JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$):null],null)))}else $JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$=null;return $JSCompiler_inline_result$jscomp$10888_p1__69239_SHARP_$$},
$all_shapes$jscomp$1$$))??"")};$APP.$app$util$code_gen$style_css$generate_style$$.$cljs$lang$maxFixedArity$=4;var $app$main$data$workspace$clipboard$copy_selected_70494$$,$app$main$data$workspace$clipboard$paste_from_clipboard_70530$$,$app$main$data$workspace$clipboard$copy_selected_props_70638$$,$app$main$data$workspace$clipboard$paste_selected_props_70686$$,$app$main$data$workspace$clipboard$paste_transit_shapes_70775$$,$app$main$data$workspace$clipboard$paste_transit_props_70835$$,$app$main$data$workspace$clipboard$paste_shapes_70992$$,$app$main$data$workspace$clipboard$paste_html_text_71029$$,$app$main$data$workspace$clipboard$paste_text_71036$$,
$app$main$data$workspace$clipboard$paste_svg_text_71045$$,$app$main$data$workspace$clipboard$paste_image_71050$$,$app$main$data$workspace$clipboard$copy_link_to_clipboard_71058$$;$APP.$app$main$data$workspace$clipboard$default_options$$={decodeTransit:$APP.$app$common$transit$decode_str$$,allowHTMLPaste:$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2-html-paste")};
$APP.$app$main$data$workspace$clipboard$paste_data_valid_QMARK_$$=$app$common$schema$lazy_validator$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$531$multi$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"paste-data",$cljs$cst$532$dispatch$$,$APP.$cljs$cst$139$type$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4101$copied_shapes$$,new $APP.$cljs$core$PersistentVector$$(null,
10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"paste-data-shapes"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$cljs$cst$4101$copied_shapes$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$227$features$$,$cljs$cst$952$app_DOT_common_DOT_schema_SLASH_set_of_strings$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2289$version$$,$cljs$cst$344$int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1921$selected$$,$cljs$cst$955$app_DOT_common_DOT_schema_SLASH_set_of_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$objects$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$,$APP.$cljs$cst$202$map$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4099$images$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$202$map$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$position$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1518$app_DOT_common_DOT_geom_DOT_point_SLASH_point$$],
null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4111$copied_props$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"paste-data-props"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,$APP.$cljs$cst$4111$copied_props$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$227$features$$,$cljs$cst$952$app_DOT_common_DOT_schema_SLASH_set_of_strings$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2289$version$$,$cljs$cst$344$int$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$575$props$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$463$map_of$$,$APP.$cljs$cst$221$keyword$$,$APP.$cljs$cst$418$any$$],null)],null)],null)],null)],null));var $app$main$data$workspace$colors$change_fill_70475$$,$app$main$data$workspace$colors$remove_all_fills_70543$$,$app$main$data$workspace$colors$change_stroke_color_70599$$,$app$main$data$workspace$colors$change_shadow_70661$$,$app$main$data$workspace$colors$add_stroke_70682$$,$app$main$data$workspace$colors$picker_for_selected_shape_70781$$,$app$main$data$workspace$colors$change_color_in_selected_70813$$,$app$main$data$workspace$colors$stroke_style_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1866$stroke_style$$,$APP.$cljs$cst$1868$stroke_alignment$$,$APP.$cljs$cst$1655$stroke_width$$,$APP.$cljs$cst$1865$stroke_cap_start$$,$APP.$cljs$cst$1869$stroke_cap_end$$],null);
$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4158$prop$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$499$enum$$,
$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1637$content$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1795$index$$,$cljs$cst$344$int$$],null)],null)],null));
var $app$main$data$workspace$colors$text__GT_color_att$$=function $app$main$data$workspace$colors$text__GT_color_att$$($var_args$jscomp$1304$$){for(var $args__5755__auto__$jscomp$231$$=[],$len__5749__auto___71207$$=arguments.length,$i__5750__auto___71208$$=0;;)if($i__5750__auto___71208$$<$len__5749__auto___71207$$)$args__5755__auto__$jscomp$231$$.push(arguments[$i__5750__auto___71208$$]),$i__5750__auto___71208$$+=1;else break;return $app$main$data$workspace$colors$text__GT_color_att$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],
arguments[1],arguments[2],3<$args__5755__auto__$jscomp$231$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$231$$.slice(3),0,null):null)};
$app$main$data$workspace$colors$text__GT_color_att$$.$cljs$core$IFn$_invoke$arity$variadic$=function($fill$jscomp$19$$,$file_id$jscomp$212$$,$attrs$jscomp$148_colors$jscomp$7_libraries$jscomp$89$$,$map__71062__$1_p__71061_ref_id$jscomp$10$$){$map__71062__$1_p__71061_ref_id$jscomp$10$$=$APP.$cljs$core$__destructure_map$$($map__71062__$1_p__71061_ref_id$jscomp$10$$);var $has_token_applied$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71062__$1_p__71061_ref_id$jscomp$10$$,$APP.$cljs$cst$4185$has_token_applied$$),
$token_name$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71062__$1_p__71061_ref_id$jscomp$10$$,$APP.$cljs$cst$4186$token_name$$),$ref_file$jscomp$9$$=$APP.$cljs$cst$1640$fill_color_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$19$$);$map__71062__$1_p__71061_ref_id$jscomp$10$$=$APP.$cljs$cst$1745$fill_color_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$19$$);$attrs$jscomp$148_colors$jscomp$7_libraries$jscomp$89$$=$app$common$types$library$get_colors$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$148_colors$jscomp$7_libraries$jscomp$89$$,
$ref_file$jscomp$9$$),$APP.$cljs$cst$142$data$$));var $shared_QMARK_$jscomp$2$$=$APP.$cljs$core$contains_QMARK_$$($attrs$jscomp$148_colors$jscomp$7_libraries$jscomp$89$$,$map__71062__$1_p__71061_ref_id$jscomp$10$$),$base_attrs$jscomp$2$$=function(){var $G__71063$$=$APP.$app$common$types$fills$fill__GT_color$$($fill$jscomp$19$$);return $shared_QMARK_$jscomp$2$$||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ref_file$jscomp$9$$,$file_id$jscomp$212$$)?$G__71063$$:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71063$$,
$APP.$cljs$cst$1736$ref_file$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1735$ref_id$$]))}();$attrs$jscomp$148_colors$jscomp$7_libraries$jscomp$89$$=function(){var $G__71064__$1$$=$APP.$cljs$core$truth_$$($has_token_applied$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($base_attrs$jscomp$2$$,$APP.$cljs$cst$4185$has_token_applied$$,!0):$base_attrs$jscomp$2$$;return $APP.$cljs$core$truth_$$($token_name$jscomp$7$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71064__$1$$,
$APP.$cljs$cst$4186$token_name$$,$token_name$jscomp$7$$):$G__71064__$1$$}();return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2645$attrs$$,$attrs$jscomp$148_colors$jscomp$7_libraries$jscomp$89$$,$APP.$cljs$cst$4158$prop$$,$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$2543$shape_id$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$19$$),$APP.$cljs$cst$1795$index$$,$APP.$cljs$cst$1795$index$$.$cljs$core$IFn$_invoke$arity$1$($fill$jscomp$19$$)],null)};
$app$main$data$workspace$colors$text__GT_color_att$$.$cljs$lang$maxFixedArity$=3;
$app$main$data$workspace$colors$text__GT_color_att$$.$cljs$lang$applyTo$=function($G__71056_seq71054$$){var $G__71055$$=$APP.$cljs$core$first$$($G__71056_seq71054$$),$G__71057_seq71054__$1$$=$APP.$cljs$core$next$$($G__71056_seq71054$$);$G__71056_seq71054$$=$APP.$cljs$core$first$$($G__71057_seq71054__$1$$);var $seq71054__$2_seq71054__$3$$=$APP.$cljs$core$next$$($G__71057_seq71054__$1$$);$G__71057_seq71054__$1$$=$APP.$cljs$core$first$$($seq71054__$2_seq71054__$3$$);$seq71054__$2_seq71054__$3$$=$APP.$cljs$core$next$$($seq71054__$2_seq71054__$3$$);
return this.$cljs$core$IFn$_invoke$arity$variadic$($G__71055$$,$G__71056_seq71054$$,$G__71057_seq71054__$1$$,$seq71054__$2_seq71054__$3$$)};var $app$main$data$workspace$drawing$select_for_drawing_70046$$,$app$main$data$workspace$drawing$start_drawing_70061$$,$app$main$data$workspace$drawing$handle_drawing_70070$$,$app$main$data$workspace$drawing$common$clear_drawing_69146$$,$app$main$data$workspace$drawing$common$handle_finish_drawing_69159$$;var $app$main$data$workspace$drawing$box$handle_drawing_69279$$;/*
 BSD License <https://opensource.org/licenses/BSD-2-Clause>
*/
var $app$main$data$workspace$drawing$curve$setup_frame_69329$$,$app$main$data$workspace$drawing$curve$insert_point_69345$$,$app$main$data$workspace$drawing$curve$finish_drawing_69348$$,$app$main$data$workspace$drawing$curve$handle_drawing_69359$$;var $app$main$data$workspace$path$changes$save_path_content_69422$$;var $app$main$data$workspace$path$undo$undo_path_69651$$,$app$main$data$workspace$path$undo$redo_path_69671$$,$app$main$data$workspace$path$undo$merge_head_69682$$,$app$main$data$workspace$path$undo$add_undo_entry_69688$$,$app$main$data$workspace$path$undo$end_path_undo_69697$$,$app$main$data$workspace$path$undo$start_path_undo_69710$$,$app$main$data$workspace$path$undo$path_content_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$683$$){return $APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$683$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$content$$]))},$APP.$app$main$store$state$$);var $app$main$data$workspace$path$drawing$preview_next_point_69774$$,$app$main$data$workspace$path$drawing$add_node_69793$$,$app$main$data$workspace$path$drawing$drag_handler_69808$$,$app$main$data$workspace$path$drawing$finish_drag_69825$$,$app$main$data$workspace$path$drawing$start_edition_69887$$,$app$main$data$workspace$path$drawing$setup_frame_69907$$,$app$main$data$workspace$path$drawing$handle_drawing_end_69923$$,$app$main$data$workspace$path$drawing$handle_new_shape_69939$$,$app$main$data$workspace$path$drawing$start_draw_mode_69956$$,
$app$main$data$workspace$path$drawing$start_draw_mode_STAR__69968$$,$app$main$data$workspace$path$drawing$change_edit_mode_69979$$,$app$main$data$workspace$path$drawing$check_changed_content_69995$$,$app$main$data$workspace$path$drawing$start_draw_mode_STAR_$$=function $app$main$data$workspace$path$drawing$start_draw_mode_STAR_$$(){typeof $app$main$data$workspace$path$drawing$start_draw_mode_STAR__69968$$==="undefined"&&($app$main$data$workspace$path$drawing$start_draw_mode_STAR__69968$$=function($meta69969$$){this.$meta69969$=
$meta69969$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$start_draw_mode_STAR__69968$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$start_draw_mode_STAR__69968$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4230$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_start_draw_mode_STAR_$$},$app$main$data$workspace$path$drawing$start_draw_mode_STAR__69968$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69970$$,$meta69969__$1$$){return new $app$main$data$workspace$path$drawing$start_draw_mode_STAR__69968$$($meta69969__$1$$)},$app$main$data$workspace$path$drawing$start_draw_mode_STAR__69968$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69969$},$app$main$data$workspace$path$drawing$start_draw_mode_STAR__69968$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$start_draw_mode_STAR__69968$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2312_id$jscomp$671$$,$local$jscomp$7_mode$jscomp$28_state$jscomp$703$$,$stream$jscomp$75$$){$local$jscomp$7_mode$jscomp$28_state$jscomp$703$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$7_mode$jscomp$28_state$jscomp$703$$,$APP.$cljs$cst$1920$workspace_local$$);$_$jscomp$2312_id$jscomp$671$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$7_mode$jscomp$28_state$jscomp$703$$,$APP.$cljs$cst$2199$edition$$);$local$jscomp$7_mode$jscomp$28_state$jscomp$703$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$7_mode$jscomp$28_state$jscomp$703$$,$APP.$cljs$cst$1923$edit_path$$),$_$jscomp$2312_id$jscomp$671$$),$APP.$cljs$cst$4223$edit_mode$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4224$draw$$,$local$jscomp$7_mode$jscomp$28_state$jscomp$703$$)?$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$_$jscomp$2312_id$jscomp$671$$],null),$APP.$app$common$types$path$convert_to_path$$)),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$drawing$start_edition$$($_$jscomp$2312_id$jscomp$671$$)),$APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$drawing$check_changed_content$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$workspace$path$drawing$check_changed_content$$.$cljs$core$IFn$_invoke$arity$0$():
$app$main$data$workspace$path$drawing$check_changed_content$$(),$app$main$data$workspace$path$drawing$start_draw_mode_STAR_$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$workspace$path$drawing$start_draw_mode_STAR_$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$workspace$path$drawing$start_draw_mode_STAR_$$())},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4225$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_end_edition$$),
$stream$jscomp$75$$)))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$path$drawing$start_draw_mode_STAR__69968$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};var $app$main$data$workspace$path$selection$update_selection_69783$$;var $app$main$data$workspace$path$edition$apply_content_modifiers_69828$$,$app$main$data$workspace$path$edition$set_modifiers_69856$$,$app$main$data$workspace$path$edition$finish_move_selected_69911$$,$app$main$data$workspace$path$edition$move_selected_69928$$,$app$main$data$workspace$path$edition$start_path_edit_69973$$,$app$main$data$workspace$path$edition$stop_path_edit_69982$$,$app$main$data$workspace$path$edition$move_selected$$=function $app$main$data$workspace$path$edition$move_selected$$($direction$jscomp$23$$,
$shift_QMARK_$jscomp$26$$){var $same_event$jscomp$2$$=Symbol("same-event");typeof $app$main$data$workspace$path$edition$move_selected_69928$$==="undefined"&&($app$main$data$workspace$path$edition$move_selected_69928$$=function($direction$jscomp$24$$,$shift_QMARK_$jscomp$27$$,$same_event$jscomp$3$$,$meta69929$$){this.direction=$direction$jscomp$24$$;this.$shift_QMARK_$=$shift_QMARK_$jscomp$27$$;this.$same_event$=$same_event$jscomp$3$$;this.$meta69929$=$meta69929$$;this.$cljs$lang$protocol_mask$partition0$$=
425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$move_selected_69928$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$move_selected_69928$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4258$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_move_selected$$},$app$main$data$workspace$path$edition$move_selected_69928$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69930$$,$meta69929__$1$$){return new $app$main$data$workspace$path$edition$move_selected_69928$$(this.direction,this.$shift_QMARK_$,this.$same_event$,$meta69929__$1$$)},$app$main$data$workspace$path$edition$move_selected_69928$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69929$},$app$main$data$workspace$path$edition$move_selected_69928$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.direction},$app$main$data$workspace$path$edition$move_selected_69928$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$move_selected_69928$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2336_id$jscomp$693$$,$state$jscomp$726$$){$_$jscomp$2336_id$jscomp$693$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$726$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2199$edition$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$726$$,
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1923$edit_path$$),$_$jscomp$2336_id$jscomp$693$$),$cljs$cst$4257$current_move$$)==null?$APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$726$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2336_id$jscomp$693$$,$APP.$cljs$cst$4251$moving_nodes$$],null),!0),new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$1923$edit_path$$,$_$jscomp$2336_id$jscomp$693$$,$cljs$cst$4257$current_move$$],null),this.$same_event$):$state$jscomp$726$$},$app$main$data$workspace$path$edition$move_selected_69928$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$move_selected_69928$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2337_id$jscomp$694$$,
$move_events$jscomp$1_state$jscomp$727$$,$stopper$jscomp$28_stream$jscomp$78$$){var $self__$jscomp$5541$$=this;$_$jscomp$2337_id$jscomp$694$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($move_events$jscomp$1_state$jscomp$727$$,$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$2199$edition$$);var $current_move$jscomp$1_scale$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($move_events$jscomp$1_state$jscomp$727$$,
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1923$edit_path$$),$_$jscomp$2337_id$jscomp$694$$),$cljs$cst$4257$current_move$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($_$jscomp$2337_id$jscomp$694$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5541$$.$same_event$,$current_move$jscomp$1_scale$jscomp$31$$):$_$jscomp$2337_id$jscomp$694$$)){var $points$jscomp$92$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($move_events$jscomp$1_state$jscomp$727$$,
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1923$edit_path$$),$_$jscomp$2337_id$jscomp$694$$),$APP.$cljs$cst$4241$selected_points$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);$move_events$jscomp$1_state$jscomp$727$$=$APP.$beicon$v2$core$filter$$(function($p1__69922_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5541$$.direction,$APP.$cljs$core$_deref$$($p1__69922_SHARP_$$))},$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4258$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_move_selected$$),
$stopper$jscomp$28_stream$jscomp$78$$));$stopper$jscomp$28_stream$jscomp$78$$=$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$debounce$$(100,$move_events$jscomp$1_state$jscomp$727$$));$current_move$jscomp$1_scale$jscomp$31$$=$APP.$cljs$core$truth_$$($self__$jscomp$5541$$.$shift_QMARK_$)?$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$(10):$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$(1);var $mov_vec$jscomp$1$$=$APP.$app$common$geom$point$multiply$$($app$main$data$workspace$path$edition$get_displacement$$($self__$jscomp$5541$$.direction),
$current_move$jscomp$1_scale$jscomp$31$$);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$_$jscomp$2337_id$jscomp$694$$],null),$APP.$app$common$types$path$convert_to_path$$)),$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$(function($p1__69927_SHARP_$$){return $app$main$data$workspace$path$edition$set_move_modifier$$($points$jscomp$92$$,
$p1__69927_SHARP_$$)},$APP.$beicon$v2$core$scan$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__69926_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__69926_SHARP_$$,$mov_vec$jscomp$1$$)},$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),$APP.$beicon$v2$core$take_until$$($stopper$jscomp$28_stream$jscomp$78$$,$move_events$jscomp$1_state$jscomp$727$$))),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$edition$move_selected$$.$cljs$core$IFn$_invoke$arity$2$?
$app$main$data$workspace$path$edition$move_selected$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5541$$.direction,$self__$jscomp$5541$$.$shift_QMARK_$):$app$main$data$workspace$path$edition$move_selected$$($self__$jscomp$5541$$.direction,$self__$jscomp$5541$$.$shift_QMARK_$))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$edition$apply_content_modifiers$$(),$app$main$data$workspace$path$edition$finish_move_selected$$()))}return $APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$path$edition$move_selected_69928$$($direction$jscomp$23$$,
$shift_QMARK_$jscomp$26$$,$same_event$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};var $app$main$data$workspace$path$tools$process_path_tool_69728$$,$app$main$data$workspace$path$tools$toggle_snap_69758$$;$APP.$app$main$data$workspace$path$make_curve$$=function(){var $app$main$data$workspace$path$make_curve$$=null;$app$main$data$workspace$path$make_curve$$=function($param70030$jscomp$1$$){switch(arguments.length){case 0:return $app$main$data$workspace$path$tools$make_curve$cljs$0core$0IFn$0_invoke$0arity$01$$(null);case 1:return $app$main$data$workspace$path$tools$make_curve$cljs$0core$0IFn$0_invoke$0arity$01$$($param70030$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$main$data$workspace$path$make_curve$$.$cljs$core$IFn$_invoke$arity$0$=
function(){return $app$main$data$workspace$path$tools$make_curve$cljs$0core$0IFn$0_invoke$0arity$01$$(null)};$app$main$data$workspace$path$make_curve$$.$cljs$core$IFn$_invoke$arity$1$=function($param70030$$){return $app$main$data$workspace$path$tools$make_curve$cljs$0core$0IFn$0_invoke$0arity$01$$($param70030$$)};return $app$main$data$workspace$path$make_curve$$}();
$APP.$app$main$data$workspace$path$make_corner$$=function(){var $app$main$data$workspace$path$make_corner$$=null;$app$main$data$workspace$path$make_corner$$=function($param70031$jscomp$1$$){switch(arguments.length){case 0:return $app$main$data$workspace$path$tools$make_corner$cljs$0core$0IFn$0_invoke$0arity$01$$(null);case 1:return $app$main$data$workspace$path$tools$make_corner$cljs$0core$0IFn$0_invoke$0arity$01$$($param70031$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$main$data$workspace$path$make_corner$$.$cljs$core$IFn$_invoke$arity$0$=
function(){return $app$main$data$workspace$path$tools$make_corner$cljs$0core$0IFn$0_invoke$0arity$01$$(null)};$app$main$data$workspace$path$make_corner$$.$cljs$core$IFn$_invoke$arity$1$=function($param70031$$){return $app$main$data$workspace$path$tools$make_corner$cljs$0core$0IFn$0_invoke$0arity$01$$($param70031$$)};return $app$main$data$workspace$path$make_corner$$}();$APP.$app$main$data$workspace$drawing$select_for_drawing$$=function $app$main$data$workspace$drawing$select_for_drawing$$($tool$jscomp$1$$){typeof $app$main$data$workspace$drawing$select_for_drawing_70046$$==="undefined"&&($app$main$data$workspace$drawing$select_for_drawing_70046$$=function($tool$jscomp$2$$,$meta70047$$){this.tool=$tool$jscomp$2$$;this.$meta70047$=$meta70047$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$drawing$select_for_drawing_70046$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$select_for_drawing_70046$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4266$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_select_for_drawing$$},$app$main$data$workspace$drawing$select_for_drawing_70046$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70048$$,$meta70047__$1$$){return new $app$main$data$workspace$drawing$select_for_drawing_70046$$(this.tool,$meta70047__$1$$)},$app$main$data$workspace$drawing$select_for_drawing_70046$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70047$},$app$main$data$workspace$drawing$select_for_drawing_70046$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$select_for_drawing_70046$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2348$$,$state$jscomp$735$$){var $self__$jscomp$5576$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$735$$,
$APP.$cljs$cst$2209$workspace_layout$$,function($workspace_layout$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5576$$.tool,$APP.$cljs$cst$3436$comments$$)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($workspace_layout$$,$APP.$cljs$cst$3719$document_history$$):$workspace_layout$$}),$APP.$cljs$cst$2189$workspace_drawing$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2197$tool$$,$self__$jscomp$5576$$.tool),$APP.$cljs$cst$2209$workspace_layout$$,$APP.$cljs$core$disj$$,
$APP.$cljs$cst$3716$scale_text$$)},$app$main$data$workspace$drawing$select_for_drawing_70046$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$select_for_drawing_70046$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2349$$,$___$1$jscomp$1579$$,$stream$jscomp$81$$){var $self__$jscomp$5577$$=this;return $APP.$beicon$v2$core$merge$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5577$$.tool,$APP.$cljs$cst$296$path$$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$drawing$start_drawing$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$data$workspace$drawing$start_drawing$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$):$APP.$app$main$data$workspace$drawing$start_drawing$$($APP.$cljs$cst$296$path$$)):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5577$$.tool,$APP.$cljs$cst$2052$curve$$)?function(){var $stopper$jscomp$30$$=$APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$common$interrupt_QMARK_$$,
$stream$jscomp$81$$);return $APP.$beicon$v2$core$take_until$$($stopper$jscomp$30$$,$APP.$beicon$v2$core$map$$($app$main$data$workspace$drawing$select_for_drawing$$,$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2329$async$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$($self__$jscomp$5577$$.tool),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4188$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_DOT_common_SLASH_handle_finish_drawing$$),
$stream$jscomp$81$$))))))}():null,$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5577$$.tool,$APP.$cljs$cst$3436$comments$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5577$$.tool,$APP.$cljs$cst$296$path$$)?function(){var $stopper$jscomp$31$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4267$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_clear_drawing$$),$stream$jscomp$81$$);
return $APP.$beicon$v2$core$take_until$$($stopper$jscomp$31$$,$APP.$beicon$v2$core$map$$($APP.$app$main$data$workspace$drawing$common$clear_drawing$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$common$interrupt_QMARK_$$,$stream$jscomp$81$$))))}():null)});return new $app$main$data$workspace$drawing$select_for_drawing_70046$$($tool$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};var $app$main$data$workspace$comments$center_to_comment_thread_70140$$,$app$main$data$workspace$comments$update_comment_thread_position_70162$$,$app$main$data$workspace$comments$move_frame_comment_threads_70173$$,$app$main$data$workspace$comments$set_zoom_to_separate_grouped_bubbles_70188$$,$app$main$data$workspace$comments$navigate_to_comment_from_dashboard_70191$$,$app$main$data$workspace$comments$navigate_to_comment_70194$$,$app$main$data$workspace$comments$navigate_to_comment_id_70200$$;
$potok$v2$core$resolve$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$3841$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_move_frame_comment_threads$$,function($_$jscomp$2361$$,$ids_or_transforms$$){return $APP.$app$common$data$not_empty_QMARK_$$($ids_or_transforms$$)?$app$main$data$workspace$comments$move_frame_comment_threads$$($APP.$cljs$core$map_QMARK_$$($ids_or_transforms$$)?$APP.$cljs$core$keys$$($ids_or_transforms$$):$ids_or_transforms$$,$APP.$cljs$core$map_QMARK_$$($ids_or_transforms$$)?
$ids_or_transforms$$:null):null});
var $app$main$data$workspace$comments$calculate_zoom_scale_to_ungroup_current_bubble$$=function $app$main$data$workspace$comments$calculate_zoom_scale_to_ungroup_current_bubble$$($zoom$jscomp$34$$,$thread$jscomp$28$$,$threads$jscomp$6$$){var $G__70184_threads_rest$$=$APP.$cljs$core$filterv$$(function($p1__70182_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__70182_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$28$$))},$threads$jscomp$6$$);
return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__70183_SHARP_$$){return $app$main$data$workspace$comments$overlap_bubbles_QMARK_$$($zoom$jscomp$34$$,$thread$jscomp$28$$,$p1__70183_SHARP_$$)},$G__70184_threads_rest$$))?($G__70184_threads_rest$$=$zoom$jscomp$34$$*1.75,$app$main$data$workspace$comments$calculate_zoom_scale_to_ungroup_current_bubble$$.$cljs$core$IFn$_invoke$arity$3$?$app$main$data$workspace$comments$calculate_zoom_scale_to_ungroup_current_bubble$$.$cljs$core$IFn$_invoke$arity$3$($G__70184_threads_rest$$,
$thread$jscomp$28$$,$threads$jscomp$6$$):$app$main$data$workspace$comments$calculate_zoom_scale_to_ungroup_current_bubble$$($G__70184_threads_rest$$,$thread$jscomp$28$$,$threads$jscomp$6$$)):$zoom$jscomp$34$$};var $app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_local_library_70221$$,$app$main$data$workspace$fix_deleted_fonts$fix_deleted_fonts_for_page_70225$$;var $app$main$data$workspace$guides$update_guides_70247$$,$app$main$data$workspace$guides$remove_guide_70260$$,$app$main$data$workspace$guides$remove_guides_70268$$,$app$main$data$workspace$guides$move_frame_guides_70291$$;
$potok$v2$core$resolve$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$3839$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_move_frame_guides$$,function($_$jscomp$2378$$,$args$jscomp$248$$){typeof $app$main$data$workspace$guides$move_frame_guides_70291$$==="undefined"&&($app$main$data$workspace$guides$move_frame_guides_70291$$=function($_$jscomp$2379$$,$args$jscomp$249$$,$meta70292$$){this.$_$=$_$jscomp$2379$$;this.args=$args$jscomp$249$$;this.$meta70292$=$meta70292$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$guides$move_frame_guides_70291$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$move_frame_guides_70291$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$3839$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_move_frame_guides$$},$app$main$data$workspace$guides$move_frame_guides_70291$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70293$$,
$meta70292__$1$$){return new $app$main$data$workspace$guides$move_frame_guides_70291$$(this.$_$,this.args,$meta70292__$1$$)},$app$main$data$workspace$guides$move_frame_guides_70291$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70292$},$app$main$data$workspace$guides$move_frame_guides_70291$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$move_frame_guides_70291$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($___$1$jscomp$1601_frame_ids_QMARK_$jscomp$2_ids$jscomp$211$$,$guides$jscomp$7_state$jscomp$756$$){$___$1$jscomp$1601_frame_ids_QMARK_$jscomp$2_ids$jscomp$211$$=$APP.$cljs$cst$1723$ids$$.$cljs$core$IFn$_invoke$arity$1$(this.args);var $object_modifiers$jscomp$4$$=$APP.$cljs$cst$1810$modifiers$$.$cljs$core$IFn$_invoke$arity$1$(this.args),$object_transforms$$=$cljs$cst$3840$transforms$$.$cljs$core$IFn$_invoke$arity$1$(this.args),$objects$jscomp$606$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($guides$jscomp$7_state$jscomp$756$$);
$___$1$jscomp$1601_frame_ids_QMARK_$jscomp$2_ids$jscomp$211$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($id$jscomp$713$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1606$frame$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$606$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$id$jscomp$713$$,$APP.$cljs$cst$139$type$$],null)))}),$___$1$jscomp$1601_frame_ids_QMARK_$jscomp$2_ids$jscomp$211$$);$guides$jscomp$7_state$jscomp$756$$=$APP.$cljs$core$vals$$($APP.$cljs$cst$2057$guides$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($guides$jscomp$7_state$jscomp$756$$)));return $APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($guide$jscomp$7_guide__$1$jscomp$1$$){var $frame_id$jscomp$102_transform$jscomp$104$$=
$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$7_guide__$1$jscomp$1$$),$frame$jscomp$38_moved$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$606$$,$frame_id$jscomp$102_transform$jscomp$104$$),$G__70298__$1$jscomp$inline_7192_frame_SINGLEQUOTE_$jscomp$1_modifier$jscomp$6$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($object_modifiers$jscomp$4$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$frame_id$jscomp$102_transform$jscomp$104$$,$APP.$cljs$cst$1810$modifiers$$],null));$frame_id$jscomp$102_transform$jscomp$104$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($object_transforms$$,$frame_id$jscomp$102_transform$jscomp$104$$);$G__70298__$1$jscomp$inline_7192_frame_SINGLEQUOTE_$jscomp$1_modifier$jscomp$6$$=$G__70298__$1$jscomp$inline_7192_frame_SINGLEQUOTE_$jscomp$1_modifier$jscomp$6$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$38_moved$jscomp$3$$,
$G__70298__$1$jscomp$inline_7192_frame_SINGLEQUOTE_$jscomp$1_modifier$jscomp$6$$):$frame$jscomp$38_moved$jscomp$3$$;$G__70298__$1$jscomp$inline_7192_frame_SINGLEQUOTE_$jscomp$1_modifier$jscomp$6$$=$frame_id$jscomp$102_transform$jscomp$104$$!=null?$APP.$app$common$geom$shapes$transforms$apply_transform$$($G__70298__$1$jscomp$inline_7192_frame_SINGLEQUOTE_$jscomp$1_modifier$jscomp$6$$,$frame_id$jscomp$102_transform$jscomp$104$$):$G__70298__$1$jscomp$inline_7192_frame_SINGLEQUOTE_$jscomp$1_modifier$jscomp$6$$;
$frame$jscomp$38_moved$jscomp$3$$=$APP.$app$common$geom$point$to_vec$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$38_moved$jscomp$3$$),$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$38_moved$jscomp$3$$)),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($G__70298__$1$jscomp$inline_7192_frame_SINGLEQUOTE_$jscomp$1_modifier$jscomp$6$$),
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($G__70298__$1$jscomp$inline_7192_frame_SINGLEQUOTE_$jscomp$1_modifier$jscomp$6$$)));$guide$jscomp$7_guide__$1$jscomp$1$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($guide$jscomp$7_guide__$1$jscomp$1$$,$APP.$cljs$cst$1676$position$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$38_moved$jscomp$3$$,$APP.$cljs$cst$2054$axis$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$7_guide__$1$jscomp$1$$)));
return $APP.$app$main$data$workspace$guides$update_guides$$($guide$jscomp$7_guide__$1$jscomp$1$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($___$1$jscomp$1601_frame_ids_QMARK_$jscomp$2_ids$jscomp$211$$,$APP.$cljs$cst$1607$frame_id$$),$guides$jscomp$7_state$jscomp$756$$)))});return new $app$main$data$workspace$guides$move_frame_guides_70291$$($_$jscomp$2378$$,$args$jscomp$248$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)});var $app$main$data$workspace$highlight$highlight_shape_70314$$,$app$main$data$workspace$highlight$dehighlight_shape_70321$$;var $app$main$data$workspace$interactions$add_flow_70399$$,$app$main$data$workspace$interactions$remove_flow_70422$$,$app$main$data$workspace$interactions$update_flow_70433$$,$app$main$data$workspace$interactions$remove_interaction_70485$$,$app$main$data$workspace$interactions$update_interaction_70499$$;var $app$main$data$workspace$layers$set_opacity_70535$$,$app$main$data$workspace$layers$pressed_opacity_70557$$,$app$main$data$workspace$layers$pressed_opacity$$=function $app$main$data$workspace$layers$pressed_opacity$$($opacity$jscomp$34$$){var $same_event$jscomp$4$$=Symbol("same-event");typeof $app$main$data$workspace$layers$pressed_opacity_70557$$==="undefined"&&($app$main$data$workspace$layers$pressed_opacity_70557$$=function($opacity$jscomp$35$$,$same_event$jscomp$5$$,$meta70558$$){this.opacity=
$opacity$jscomp$35$$;this.$same_event$=$same_event$jscomp$5$$;this.$meta70558$=$meta70558$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$layers$pressed_opacity_70557$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layers$pressed_opacity_70557$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4322$app_DOT_main_DOT_data_DOT_workspace_DOT_layers_SLASH_pressed_opacity$$},
$app$main$data$workspace$layers$pressed_opacity_70557$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70559$$,$meta70558__$1$$){return new $app$main$data$workspace$layers$pressed_opacity_70557$$(this.opacity,this.$same_event$,$meta70558__$1$$)},$app$main$data$workspace$layers$pressed_opacity_70557$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70558$},$app$main$data$workspace$layers$pressed_opacity_70557$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return this.opacity},
$app$main$data$workspace$layers$pressed_opacity_70557$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layers$pressed_opacity_70557$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2409$$,$state$jscomp$783$$){return $cljs$cst$4323$press_opacity_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$783$$)==null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$783$$,$cljs$cst$4323$press_opacity_id$$,this.$same_event$):
$state$jscomp$783$$},$app$main$data$workspace$layers$pressed_opacity_70557$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layers$pressed_opacity_70557$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2410_opacity_events$$,$state$jscomp$784$$,$stream$jscomp$87$$){if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$same_event$,$cljs$cst$4323$press_opacity_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$784$$)))return $APP.$beicon$v2$core$empty$$();
$_$jscomp$2410_opacity_events$$=$APP.$beicon$v2$core$map$$(function($p1__70556_SHARP_$$){return $app$main$data$workspace$layers$set_opacity$$($app$main$data$workspace$layers$calculate_opacity$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$deref$$,$p1__70556_SHARP_$$)))},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$buffer_time$cljs$0core$0IFn$0_invoke$0arity$02$$(600,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4322$app_DOT_main_DOT_data_DOT_workspace_DOT_layers_SLASH_pressed_opacity$$),
$stream$jscomp$87$$))));return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$layers$set_opacity$$($app$main$data$workspace$layers$calculate_opacity$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.opacity],null)))),$APP.$beicon$v2$core$merge$$($_$jscomp$2410_opacity_events$$,(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$layers$pressed_opacity$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$layers$pressed_opacity$$.$cljs$core$IFn$_invoke$arity$1$(this.opacity):
$app$main$data$workspace$layers$pressed_opacity$$(this.opacity))),(0,$APP.$beicon$v2$core$of$$)(function($state__$1$jscomp$47$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state__$1$jscomp$47$$,$cljs$cst$4323$press_opacity_id$$)}))});return new $app$main$data$workspace$layers$pressed_opacity_70557$$($opacity$jscomp$34$$,$same_event$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};var $app$main$data$workspace$mcp$set_mcp_active_70546$$,$app$main$data$workspace$mcp$handle_pong_70567$$,$app$main$data$workspace$mcp$handle_ping_70583$$,$app$main$data$workspace$mcp$notify_other_tabs_disconnect_70602$$,$app$main$data$workspace$mcp$update_mcp_status_70613$$,$app$main$data$workspace$mcp$update_mcp_plugin_connection_70632$$,$app$main$data$workspace$mcp$connect_mcp_70654$$,$app$main$data$workspace$mcp$user_disconnect_mcp_70667$$,$app$main$data$workspace$mcp$manage_mcp_notification_70678$$,
$app$main$data$workspace$mcp$init_70727$$;$APP.$app$common$logging$loggers$$.set("app.main.data.workspace.mcp",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1161$info$$));
var $app$main$data$workspace$mcp$default_manifest$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$273$code$$,"plugin.js",$APP.$cljs$cst$725$name$$,"Penpot MCP Plugin",$APP.$cljs$cst$2289$version$$,2,$APP.$cljs$cst$1720$plugin_id$$,"96dfa740-005d-8020-8007-55ede24a2bae",$APP.$cljs$cst$936$description$$,"This plugin enables interaction with the Penpot MCP server",$cljs$cst$3400$allow_background$$,!0,$APP.$cljs$cst$1722$permissions$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
6,["library:read",null,"library:write",null,"comment:read",null,"content:write",null,"comment:write",null,"content:read",null],null),null)],null),$app$main$data$workspace$mcp$interval_sub$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$app$main$data$workspace$mcp$init$$=function $app$main$data$workspace$mcp$init$$(){typeof $app$main$data$workspace$mcp$init_70727$$==="undefined"&&($app$main$data$workspace$mcp$init_70727$$=function($meta70728$$){this.$meta70728$=$meta70728$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$mcp$init_70727$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$init_70727$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4343$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_init$$},$app$main$data$workspace$mcp$init_70727$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70729$$,$meta70728__$1$$){return new $app$main$data$workspace$mcp$init_70727$$($meta70728__$1$$)},
$app$main$data$workspace$mcp$init_70727$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70728$},$app$main$data$workspace$mcp$init_70727$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$init_70727$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2425$$,$state$jscomp$792$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$792$$,$APP.$cljs$cst$1236$mcp$$,$APP.$cljs$core$assoc$$,
$cljs$cst$4330$connected_tab$$,$APP.$cljs$cst$2332$session_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$792$$),$cljs$cst$4326$active$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([!0]))},$app$main$data$workspace$mcp$init_70727$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$mcp$init_70727$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2426_stoper_s$jscomp$2$$,$enabled_QMARK_$jscomp$2_state$jscomp$793$$,
$stream$jscomp$89$$){$_$jscomp$2426_stoper_s$jscomp$2$$=$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4324$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize_workspace$$),$stream$jscomp$89$$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4343$app_DOT_main_DOT_data_DOT_workspace_DOT_mcp_SLASH_init$$),$stream$jscomp$89$$));var $session_id$jscomp$7$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($enabled_QMARK_$jscomp$2_state$jscomp$793$$,$APP.$cljs$cst$2332$session_id$$);$enabled_QMARK_$jscomp$2_state$jscomp$793$$=$APP.$cljs$cst$4335$mcp_enabled$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1914$profile$$.$cljs$core$IFn$_invoke$arity$1$($enabled_QMARK_$jscomp$2_state$jscomp$793$$)));return $APP.$beicon$v2$core$take_until$$($_$jscomp$2426_stoper_s$jscomp$2$$,$APP.$beicon$v2$core$merge$$($APP.$cljs$core$truth_$$($enabled_QMARK_$jscomp$2_state$jscomp$793$$)?
$APP.$beicon$v2$core$merge$$($app$main$data$workspace$mcp$init_mcp$$($stream$jscomp$89$$),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$broadcast$event$$($cljs$cst$4344$mcp_SLASH_ping$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)),$APP.$beicon$v2$core$map$$($app$main$data$workspace$mcp$handle_ping$$,$APP.$beicon$v2$core$filter$$(function($id$jscomp$722_map__70755__$1_p__70754$$){$id$jscomp$722_map__70755__$1_p__70754$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$722_map__70755__$1_p__70754$$);$id$jscomp$722_map__70755__$1_p__70754$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$722_map__70755__$1_p__70754$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($session_id$jscomp$7$$,$id$jscomp$722_map__70755__$1_p__70754$$)},$APP.$beicon$v2$core$filter$$($app$main$broadcast$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4344$mcp_SLASH_ping$$),$APP.$app$main$broadcast$stream$$))),$APP.$beicon$v2$core$map$$($app$main$data$workspace$mcp$handle_pong$$,$APP.$beicon$v2$core$filter$$(function($id$jscomp$723_map__70757__$1_p__70756$$){$id$jscomp$723_map__70757__$1_p__70756$$=
$APP.$cljs$core$__destructure_map$$($id$jscomp$723_map__70757__$1_p__70756$$);$id$jscomp$723_map__70757__$1_p__70756$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$723_map__70757__$1_p__70756$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($session_id$jscomp$7$$,$id$jscomp$723_map__70757__$1_p__70756$$)},$APP.$beicon$v2$core$filter$$($app$main$broadcast$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4332$mcp_SLASH_pong$$),
$APP.$app$main$broadcast$stream$$))),$APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$workspace$mcp$user_disconnect_mcp$$()},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$(function($id$jscomp$724_map__70771__$1_p__70769$$){$id$jscomp$724_map__70771__$1_p__70769$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$724_map__70771__$1_p__70769$$);$id$jscomp$724_map__70771__$1_p__70769$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$724_map__70771__$1_p__70769$$,
$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($session_id$jscomp$7$$,$id$jscomp$724_map__70771__$1_p__70769$$)},$APP.$beicon$v2$core$filter$$($app$main$broadcast$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$4339$mcp_SLASH_force_disconect$$),$APP.$app$main$broadcast$stream$$))))):$APP.$beicon$v2$core$empty$$(),$APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$mcp$update_mcp_status$$(!0),$app$main$data$workspace$mcp$init$$.$cljs$core$IFn$_invoke$arity$0$?
$app$main$data$workspace$mcp$init$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$workspace$mcp$init$$())},$APP.$beicon$v2$core$filter$$($app$main$broadcast$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4345$mcp_SLASH_enable$$),$APP.$app$main$broadcast$stream$$)),$APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$mcp$update_mcp_status$$(!1),$app$main$data$workspace$mcp$init$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$workspace$mcp$init$$.$cljs$core$IFn$_invoke$arity$0$():
$app$main$data$workspace$mcp$init$$(),$APP.$app$main$data$workspace$mcp$user_disconnect_mcp$$())},$APP.$beicon$v2$core$filter$$($app$main$broadcast$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4346$mcp_SLASH_disable$$),$APP.$app$main$broadcast$stream$$))))});return new $app$main$data$workspace$mcp$init_70727$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};var $app$main$data$workspace$notifications$initialize_70587$$,$app$main$data$workspace$notifications$handle_change_team_role_70620$$,$app$main$data$workspace$notifications$handle_pointer_send_70657$$,$app$main$data$workspace$notifications$handle_presence_70690$$,$app$main$data$workspace$notifications$handle_pointer_update_70709$$,$app$main$data$workspace$notifications$handle_file_change_70736$$,$app$main$data$workspace$notifications$handle_file_deleted_70766$$,$app$main$data$workspace$notifications$handle_file_restored_70786$$,
$app$main$data$workspace$notifications$handle_library_change_70830$$,$app$main$data$workspace$notifications$presence_palette$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,9,["#dee563",null,"#faa6b7",null,"#f49ef7",null,"#fdcf79",null,"#a9bdfa",null,"#75cafc",null,"#cbaaff",null,"#b1e96f",null,"#f9b489",null],null),null);
$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"handle-file-change"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$221$keyword$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2313$profile_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2332$session_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2270$revn$$,$cljs$cst$344$int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2577$vern$$,$cljs$cst$344$int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3131$changes$$,$app$common$files$changes$schema_COLON_changes$$],null)],null));
$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"handle-file-restored"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$221$keyword$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2577$vern$$,$cljs$cst$344$int$$],null)],null));
$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"handle-library-change"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$221$keyword$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2313$profile_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2332$session_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2270$revn$$,$cljs$cst$344$int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1737$modified_at$$,$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3131$changes$$,$app$common$files$changes$schema_COLON_changes$$],null)],null));var $app$main$data$workspace$pages$select_frame_tool_70706$$,$app$main$data$workspace$pages$initialize_page_STAR__70748$$,$app$main$data$workspace$pages$initialize_page_70778$$,$app$main$data$workspace$pages$update_page_root_70809$$,$app$main$data$workspace$pages$create_page_70822$$,$app$main$data$workspace$pages$rename_page_70958$$,$app$main$data$workspace$pages$default_workspace_local$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2196$zoom$$,1],null),$app$main$data$workspace$pages$xf_COLON_collect_file_media$$=
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($metadata$jscomp$8_p__70722$$){var $fill_image$jscomp$1_map__70723__$1$$=$APP.$cljs$core$__destructure_map$$($metadata$jscomp$8_p__70722$$);$metadata$jscomp$8_p__70722$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill_image$jscomp$1_map__70723__$1$$,$cljs$cst$1633$metadata$$);$fill_image$jscomp$1_map__70723__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fill_image$jscomp$1_map__70723__$1$$,$APP.$cljs$cst$1632$fill_image$$);return $metadata$jscomp$8_p__70722$$!=null?$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($metadata$jscomp$8_p__70722$$):$fill_image$jscomp$1_map__70723__$1$$!=null?$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($fill_image$jscomp$1_map__70723__$1$$):null}));
$cljs$spec$alpha$def_impl$$($cljs$cst$4372$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_rename_page$$,$APP.$cljs$core$list$$($cljs$cst$991$cljs_DOT_spec_DOT_alpha_SLASH_keys$$,$cljs$cst$994$req_un$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4373$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_id$$,$cljs$cst$4374$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_name$$],null)),$cljs$spec$alpha$map_spec_impl$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$994$req_un$$,
$cljs$cst$995$opt_un$$,$cljs$cst$990$gfn$$,$cljs$cst$1014$pred_exprs$$,$cljs$cst$1015$keys_pred$$,$cljs$cst$1016$opt_keys$$,$cljs$cst$1017$req_specs$$,$cljs$cst$992$req$$,$cljs$cst$1018$req_keys$$,$cljs$cst$1019$opt_specs$$,$cljs$cst$1020$pred_forms$$,$APP.$cljs$cst$993$opt$$],[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4373$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_id$$,$cljs$cst$4374$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_name$$],
null),null,null,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[function($G__70927$$){return $APP.$cljs$core$map_QMARK_$$($G__70927$$)},function($G__70927$jscomp$1$$){return $APP.$cljs$core$contains_QMARK_$$($G__70927$jscomp$1$$,$APP.$cljs$cst$266$id$$)},function($G__70927$jscomp$2$$){return $APP.$cljs$core$contains_QMARK_$$($G__70927$jscomp$2$$,$APP.$cljs$cst$725$name$$)}],null),function($G__70927$jscomp$3$$){return $APP.$cljs$core$map_QMARK_$$($G__70927$jscomp$3$$)&&
$APP.$cljs$core$contains_QMARK_$$($G__70927$jscomp$3$$,$APP.$cljs$cst$266$id$$)&&$APP.$cljs$core$contains_QMARK_$$($G__70927$jscomp$3$$,$APP.$cljs$cst$725$name$$)},$APP.$cljs$core$PersistentVector$EMPTY$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4373$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_id$$,$cljs$cst$4374$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_name$$],null),null,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$725$name$$],null),$APP.$cljs$core$PersistentVector$EMPTY$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$list$$($cljs$cst$1105$cljs_DOT_core_SLASH_fn$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$979$_PERCENT_$$],null),$APP.$cljs$core$list$$($cljs$cst$989$cljs_DOT_core_SLASH_map_QMARK_$$,
$APP.$cljs$cst$979$_PERCENT_$$)),$APP.$cljs$core$list$$($cljs$cst$1105$cljs_DOT_core_SLASH_fn$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$979$_PERCENT_$$],null),$APP.$cljs$core$list$$($cljs$cst$4375$cljs_DOT_core_SLASH_contains_QMARK_$$,$APP.$cljs$cst$979$_PERCENT_$$,$APP.$cljs$cst$266$id$$)),$APP.$cljs$core$list$$($cljs$cst$1105$cljs_DOT_core_SLASH_fn$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$979$_PERCENT_$$],null),$APP.$cljs$core$list$$($cljs$cst$4375$cljs_DOT_core_SLASH_contains_QMARK_$$,$APP.$cljs$cst$979$_PERCENT_$$,$APP.$cljs$cst$725$name$$))],null),null])));var $app$main$data$workspace$path$shapes_to_path$convert_selected_to_path_70751$$,$app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path_70804$$,$app$main$data$workspace$path$shapes_to_path$dissoc_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$1881$rx$$,$APP.$cljs$cst$1882$ry$$,$APP.$cljs$cst$1646$r1$$,
$APP.$cljs$cst$1647$r2$$,$APP.$cljs$cst$1648$r3$$,$APP.$cljs$cst$1649$r4$$,$cljs$cst$1633$metadata$$],null);var $app$main$data$workspace$grid_layout$editor$clean_selection_70913$$;var $app$main$data$workspace$shape_layout$update_layout_positions_71107$$,$app$main$data$workspace$shape_layout$initialize_shape_layout_71115$$,$app$main$data$workspace$shape_layout$create_layout_from_id_71132$$,$app$main$data$workspace$shape_layout$create_layout_from_selection_71137$$,$app$main$data$workspace$shape_layout$remove_shape_layout_71145$$,$app$main$data$workspace$shape_layout$create_shape_layout_71149$$,$app$main$data$workspace$shape_layout$toggle_shape_layout_71156$$,$app$main$data$workspace$shape_layout$update_layout_71167$$,
$app$main$data$workspace$shape_layout$add_layout_track_71175$$,$app$main$data$workspace$shape_layout$remove_layout_track_71192$$,$app$main$data$workspace$shape_layout$change_layout_track_71227$$,$app$main$data$workspace$shape_layout$update_layout_child_71248$$,$app$main$data$workspace$shape_layout$update_grid_cells_71256$$,$app$main$data$workspace$shape_layout$change_cells_mode_71260$$,$app$main$data$workspace$shape_layout$update_grid_cell_position_71274$$,$app$main$data$workspace$shape_layout$layout_keys$$=
new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1615$layout$$,$APP.$cljs$cst$1679$layout_flex_dir$$,$APP.$cljs$cst$1683$layout_gap_type$$,$APP.$cljs$cst$1680$layout_gap$$,$APP.$cljs$cst$1692$layout_align_items$$,$APP.$cljs$cst$1689$layout_justify_content$$,$APP.$cljs$cst$1691$layout_align_content$$,$APP.$cljs$cst$1684$layout_wrap_type$$,$APP.$cljs$cst$1685$layout_padding_type$$,$APP.$cljs$cst$1686$layout_padding$$,$APP.$cljs$cst$1683$layout_gap_type$$],
null),$app$main$data$workspace$shape_layout$initial_flex_layout$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1683$layout_gap_type$$,$APP.$cljs$cst$1686$layout_padding$$,$APP.$cljs$cst$1684$layout_wrap_type$$,$APP.$cljs$cst$1615$layout$$,$APP.$cljs$cst$1692$layout_align_items$$,$APP.$cljs$cst$1685$layout_padding_type$$,$APP.$cljs$cst$1680$layout_gap$$,$APP.$cljs$cst$1689$layout_justify_content$$,$APP.$cljs$cst$1679$layout_flex_dir$$,$APP.$cljs$cst$1691$layout_align_content$$],[$APP.$cljs$cst$1616$multiple$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1093$p1$$,0,$APP.$cljs$cst$1091$p2$$,0,$APP.$cljs$cst$1687$p3$$,0,$APP.$cljs$cst$1688$p4$$,0],null),$APP.$cljs$cst$1664$nowrap$$,$APP.$cljs$cst$1660$flex$$,$APP.$cljs$cst$1292$start$$,$APP.$cljs$cst$1663$simple$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1681$row_gap$$,0,$APP.$cljs$cst$1682$column_gap$$,0],null),$APP.$cljs$cst$1292$start$$,$APP.$cljs$cst$1656$row$$,$APP.$cljs$cst$1669$stretch$$]),$app$main$data$workspace$shape_layout$initial_grid_layout$$=
$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1695$layout_grid_columns$$,$APP.$cljs$cst$1683$layout_gap_type$$,$APP.$cljs$cst$1686$layout_padding$$,$APP.$cljs$cst$1615$layout$$,$APP.$cljs$cst$1692$layout_align_items$$,$APP.$cljs$cst$1696$layout_grid_cells$$,$APP.$cljs$cst$1685$layout_padding_type$$,$APP.$cljs$cst$1680$layout_gap$$,$APP.$cljs$cst$1689$layout_justify_content$$,$APP.$cljs$cst$1690$layout_justify_items$$,$APP.$cljs$cst$1691$layout_align_content$$,$APP.$cljs$cst$1694$layout_grid_rows$$,
$APP.$cljs$cst$1693$layout_grid_dir$$],[$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1616$multiple$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1093$p1$$,0,$APP.$cljs$cst$1091$p2$$,0,$APP.$cljs$cst$1687$p3$$,0,$APP.$cljs$cst$1688$p4$$,0],null),$APP.$cljs$cst$1659$grid$$,$APP.$cljs$cst$1292$start$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1663$simple$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1681$row_gap$$,0,$APP.$cljs$cst$1682$column_gap$$,
0],null),$APP.$cljs$cst$1669$stretch$$,$APP.$cljs$cst$1292$start$$,$APP.$cljs$cst$1669$stretch$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1656$row$$]);var $app$main$data$workspace$variants$update_properties_names_and_values_71386$$,$app$main$data$workspace$variants$update_property_name_71405$$,$app$main$data$workspace$variants$update_property_value_71412$$,$app$main$data$workspace$variants$update_error_71418$$,$app$main$data$workspace$variants$remove_property_71423$$,$app$main$data$workspace$variants$remove_empty_properties_71426$$,$app$main$data$workspace$variants$add_new_property_71456$$,$app$main$data$workspace$variants$set_variant_id_71478$$,
$app$main$data$workspace$variants$focus_property_71481$$,$app$main$data$workspace$variants$resposition_and_resize_variant_71484$$,$app$main$data$workspace$variants$add_new_variant_71489$$,$app$main$data$workspace$variants$transform_in_variant_71498$$,$app$main$data$workspace$variants$add_component_or_variant_71502$$,$app$main$data$workspace$variants$duplicate_or_add_variant_71508$$,$app$main$data$workspace$variants$rename_variant_71513$$,$app$main$data$workspace$variants$rename_comp_or_variant_and_main_71516$$,
$app$main$data$workspace$variants$combine_as_variants_71528$$,$app$main$data$workspace$variants$variant_switch_71541$$,$app$main$data$workspace$variants$variants_switch_71549$$;
$APP.$app$main$data$workspace$variants$add_new_variant$$=function $app$main$data$workspace$variants$add_new_variant$$($var_args$jscomp$1328$$){switch(arguments.length){case 1:return $app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$=function($shape_id$jscomp$123$$){return $APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$2$($shape_id$jscomp$123$$,!1)};
$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$2$=function($shape_id$jscomp$124$$,$multiselect_QMARK_$$){typeof $app$main$data$workspace$variants$add_new_variant_71489$$==="undefined"&&($app$main$data$workspace$variants$add_new_variant_71489$$=function($shape_id$jscomp$125$$,$multiselect_QMARK_$jscomp$1$$,$meta71490$$){this.$shape_id$=$shape_id$jscomp$125$$;this.$multiselect_QMARK_$=$multiselect_QMARK_$jscomp$1$$;this.$meta71490$=$meta71490$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$add_new_variant_71489$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$add_new_variant_71489$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4435$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_add_new_variant$$},$app$main$data$workspace$variants$add_new_variant_71489$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71491$$,
$meta71490__$1$$){return new $app$main$data$workspace$variants$add_new_variant_71489$$(this.$shape_id$,this.$multiselect_QMARK_$,$meta71490__$1$$)},$app$main$data$workspace$variants$add_new_variant_71489$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71490$},$app$main$data$workspace$variants$add_new_variant_71489$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$add_new_variant_71489$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($component_id$jscomp$78_container_id_it$jscomp$239_variant_container$jscomp$1$$,$shape$jscomp$747_shape__$1$jscomp$64_state$jscomp$847$$){var $JSCompiler_inline_result$jscomp$1048_new_shape$jscomp$inline_7229_page_id$jscomp$258$$=$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$747_shape__$1$jscomp$64_state$jscomp$847$$),$changes$jscomp$inline_7215_data$jscomp$400_value$jscomp$inline_7227_variant_id$jscomp$inline_7220$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$747_shape__$1$jscomp$64_state$jscomp$847$$),
$G__67167$jscomp$inline_7230_data$jscomp$inline_7224_objects$jscomp$650_vec__67164$jscomp$inline_7228$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($changes$jscomp$inline_7215_data$jscomp$400_value$jscomp$inline_7227_variant_id$jscomp$inline_7220$$,$JSCompiler_inline_result$jscomp$1048_new_shape$jscomp$inline_7229_page_id$jscomp$258$$),$APP.$cljs$cst$1631$objects$$);$shape$jscomp$747_shape__$1$jscomp$64_state$jscomp$847$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__67167$jscomp$inline_7230_data$jscomp$inline_7224_objects$jscomp$650_vec__67164$jscomp$inline_7228$$,
this.$shape_id$);$shape$jscomp$747_shape__$1$jscomp$64_state$jscomp$847$$=$APP.$cljs$core$truth_$$($APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$747_shape__$1$jscomp$64_state$jscomp$847$$))?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__67167$jscomp$inline_7230_data$jscomp$inline_7224_objects$jscomp$650_vec__67164$jscomp$inline_7228$$,$APP.$cljs$core$last$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$747_shape__$1$jscomp$64_state$jscomp$847$$))):
$shape$jscomp$747_shape__$1$jscomp$64_state$jscomp$847$$;$component_id$jscomp$78_container_id_it$jscomp$239_variant_container$jscomp$1$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$747_shape__$1$jscomp$64_state$jscomp$847$$);var $component$jscomp$89_component_id$jscomp$inline_7226$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($changes$jscomp$inline_7215_data$jscomp$400_value$jscomp$inline_7227_variant_id$jscomp$inline_7220$$,
$component_id$jscomp$78_container_id_it$jscomp$239_variant_container$jscomp$1$$);$component_id$jscomp$78_container_id_it$jscomp$239_variant_container$jscomp$1$$=$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$747_shape__$1$jscomp$64_state$jscomp$847$$);$component_id$jscomp$78_container_id_it$jscomp$239_variant_container$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__67167$jscomp$inline_7230_data$jscomp$inline_7224_objects$jscomp$650_vec__67164$jscomp$inline_7228$$,
$component_id$jscomp$78_container_id_it$jscomp$239_variant_container$jscomp$1$$);var $has_layout_QMARK_$jscomp$3$$=$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($component_id$jscomp$78_container_id_it$jscomp$239_variant_container$jscomp$1$$),$G__67167__$1$jscomp$inline_7231_changes$jscomp$271_new_component_id$jscomp$7$$=$APP.$app$common$uuid$next$$(),$new_shape_id$jscomp$3$$=$APP.$app$common$uuid$next$$(),$prop_num$jscomp$1_undo_id$jscomp$73$$=$APP.$cljs$core$count$$($APP.$cljs$cst$2001$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$89_component_id$jscomp$inline_7226$$))-
1;$changes$jscomp$inline_7215_data$jscomp$400_value$jscomp$inline_7227_variant_id$jscomp$inline_7220$$=$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$JSCompiler_inline_result$jscomp$1048_new_shape$jscomp$inline_7229_page_id$jscomp$258$$),$changes$jscomp$inline_7215_data$jscomp$400_value$jscomp$inline_7227_variant_id$jscomp$inline_7220$$),
$G__67167$jscomp$inline_7230_data$jscomp$inline_7224_objects$jscomp$650_vec__67164$jscomp$inline_7228$$);$JSCompiler_inline_result$jscomp$1048_new_shape$jscomp$inline_7229_page_id$jscomp$258$$=$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$inline_7215_data$jscomp$400_value$jscomp$inline_7227_variant_id$jscomp$inline_7220$$,$APP.$cljs$cst$3166$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$,$JSCompiler_inline_result$jscomp$1048_new_shape$jscomp$inline_7229_page_id$jscomp$258$$);
$changes$jscomp$inline_7215_data$jscomp$400_value$jscomp$inline_7227_variant_id$jscomp$inline_7220$$=$APP.$cljs$cst$2000$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$89_component_id$jscomp$inline_7226$$);$G__67167$jscomp$inline_7230_data$jscomp$inline_7224_objects$jscomp$650_vec__67164$jscomp$inline_7228$$=$APP.$app$common$files$changes_builder$get_library_data$$($JSCompiler_inline_result$jscomp$1048_new_shape$jscomp$inline_7229_page_id$jscomp$258$$);var $objects$jscomp$inline_7225$$=
$APP.$app$common$files$changes_builder$get_objects$$($JSCompiler_inline_result$jscomp$1048_new_shape$jscomp$inline_7229_page_id$jscomp$258$$);$component$jscomp$89_component_id$jscomp$inline_7226$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$747_shape__$1$jscomp$64_state$jscomp$847$$);$changes$jscomp$inline_7215_data$jscomp$400_value$jscomp$inline_7227_variant_id$jscomp$inline_7220$$=["Value ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$count$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($APP.$app$common$files$variant$extract_properties_values$$($G__67167$jscomp$inline_7230_data$jscomp$inline_7224_objects$jscomp$650_vec__67164$jscomp$inline_7228$$,
$objects$jscomp$inline_7225$$,$changes$jscomp$inline_7215_data$jscomp$400_value$jscomp$inline_7227_variant_id$jscomp$inline_7220$$))))+1)].join("");$G__67167$jscomp$inline_7230_data$jscomp$inline_7224_objects$jscomp$650_vec__67164$jscomp$inline_7228$$=$APP.$app$common$logic$libraries$generate_duplicate_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($JSCompiler_inline_result$jscomp$1048_new_shape$jscomp$inline_7229_page_id$jscomp$258$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$142$data$$,
$G__67167$jscomp$inline_7230_data$jscomp$inline_7224_objects$jscomp$650_vec__67164$jscomp$inline_7228$$],null),$component$jscomp$89_component_id$jscomp$inline_7226$$,$G__67167__$1$jscomp$inline_7231_changes$jscomp$271_new_component_id$jscomp$7$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$3528$new_shape_id$$,$new_shape_id$jscomp$3$$,$APP.$cljs$cst$3179$apply_changes_local_library_QMARK_$$,!0],null)]));$JSCompiler_inline_result$jscomp$1048_new_shape$jscomp$inline_7229_page_id$jscomp$258$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67167$jscomp$inline_7230_data$jscomp$inline_7224_objects$jscomp$650_vec__67164$jscomp$inline_7228$$,0,null);$G__67167$jscomp$inline_7230_data$jscomp$inline_7224_objects$jscomp$650_vec__67164$jscomp$inline_7228$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67167$jscomp$inline_7230_data$jscomp$inline_7224_objects$jscomp$650_vec__67164$jscomp$inline_7228$$,1,null);$G__67167__$1$jscomp$inline_7231_changes$jscomp$271_new_component_id$jscomp$7$$=
$prop_num$jscomp$1_undo_id$jscomp$73$$>=0?$app$common$logic$variant_properties$generate_update_property_value$$($G__67167$jscomp$inline_7230_data$jscomp$inline_7224_objects$jscomp$650_vec__67164$jscomp$inline_7228$$,$G__67167__$1$jscomp$inline_7231_changes$jscomp$271_new_component_id$jscomp$7$$,$prop_num$jscomp$1_undo_id$jscomp$73$$,$changes$jscomp$inline_7215_data$jscomp$400_value$jscomp$inline_7227_variant_id$jscomp$inline_7220$$):$G__67167$jscomp$inline_7230_data$jscomp$inline_7224_objects$jscomp$650_vec__67164$jscomp$inline_7228$$;
$G__67167__$1$jscomp$inline_7231_changes$jscomp$271_new_component_id$jscomp$7$$=$APP.$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$04$$($G__67167__$1$jscomp$inline_7231_changes$jscomp$271_new_component_id$jscomp$7$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$747_shape__$1$jscomp$64_state$jscomp$847$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_inline_result$jscomp$1048_new_shape$jscomp$inline_7229_page_id$jscomp$258$$],
null),0);$prop_num$jscomp$1_undo_id$jscomp$73$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($prop_num$jscomp$1_undo_id$jscomp$73$$),$APP.$app$main$data$changes$commit_changes$$($G__67167__$1$jscomp$inline_7231_changes$jscomp$271_new_component_id$jscomp$7$$),$has_layout_QMARK_$jscomp$3$$?null:$app$main$data$workspace$variants$resposition_and_resize_variant$$($new_shape_id$jscomp$3$$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($prop_num$jscomp$1_undo_id$jscomp$73$$),
$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3624$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1723$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$747_shape__$1$jscomp$64_state$jscomp$847$$)],null)],null)),$APP.$cljs$core$truth_$$(this.$multiselect_QMARK_$)?$app$main$data$workspace$selection$shift_select_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($new_shape_id$jscomp$3$$,
null):$APP.$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$01$$($new_shape_id$jscomp$3$$)),$APP.$beicon$v2$core$delay$$(250,(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$variants$focus_property$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_id$jscomp$78_container_id_it$jscomp$239_variant_container$jscomp$1$$)))))});return new $app$main$data$workspace$variants$add_new_variant_71489$$($shape_id$jscomp$124$$,$multiselect_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$lang$maxFixedArity$=2;var $app$main$data$workspace$viewport$update_viewport_position_center_71187$$,$app$main$data$workspace$viewport$update_viewport_position_71198$$;var $app$main$data$workspace$deselect_all$$,$app$main$data$workspace$shift_select_shapes$$;$APP.$app$common$logging$loggers$$.set("app.main.data.workspace",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1161$info$$));$potok$v2$core$resolve$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$3370$app_DOT_main_DOT_data_DOT_workspace_SLASH_reload_current_file$$,function(){return $app$main$data$workspace$reload_current_file$$()});
$APP.$app$main$data$workspace$toggle_layout_flag$$=function(){function $app$main$data$workspace$toggle_layout_flag$$($param71704$jscomp$1$$,$var_args$jscomp$1331$$){var $G__72319__i_param71705$jscomp$1$$=null;if(arguments.length>1){$G__72319__i_param71705$jscomp$1$$=0;for(var $G__72319__a$$=Array(arguments.length-1);$G__72319__i_param71705$jscomp$1$$<$G__72319__a$$.length;)$G__72319__a$$[$G__72319__i_param71705$jscomp$1$$]=arguments[$G__72319__i_param71705$jscomp$1$$+1],++$G__72319__i_param71705$jscomp$1$$;
$G__72319__i_param71705$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__72319__a$$,0,null)}return $app$main$data$workspace$toggle_layout_flag__delegate$$.call(this,$param71704$jscomp$1$$,$G__72319__i_param71705$jscomp$1$$)}function $app$main$data$workspace$toggle_layout_flag__delegate$$($param71704$$,$param71705$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$data$workspace$layout$toggle_layout_flag$$,$param71704$$,$param71705$$)}$app$main$data$workspace$toggle_layout_flag$$.$cljs$lang$maxFixedArity$=
1;$app$main$data$workspace$toggle_layout_flag$$.$cljs$lang$applyTo$=function($arglist__72320_param71705$jscomp$2$$){var $param71704$jscomp$2$$=$APP.$cljs$core$first$$($arglist__72320_param71705$jscomp$2$$);$arglist__72320_param71705$jscomp$2$$=$APP.$cljs$core$rest$$($arglist__72320_param71705$jscomp$2$$);return $app$main$data$workspace$toggle_layout_flag__delegate$$($param71704$jscomp$2$$,$arglist__72320_param71705$jscomp$2$$)};$app$main$data$workspace$toggle_layout_flag$$.$cljs$core$IFn$_invoke$arity$variadic$=
$app$main$data$workspace$toggle_layout_flag__delegate$$;return $app$main$data$workspace$toggle_layout_flag$$}();
$APP.$app$main$data$workspace$show_shape_context_menu$$=function $app$main$data$workspace$show_shape_context_menu$$($p__71966$$){var $map__71967__$1$$=$APP.$cljs$core$__destructure_map$$($p__71966$$),$shape$jscomp$758$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71967__$1$$,$APP.$cljs$cst$1811$shape$$);typeof $app$main$data$workspace$show_shape_context_menu_71968$$==="undefined"&&($app$main$data$workspace$show_shape_context_menu_71968$$=function($p__71966$jscomp$1$$,$map__71967$jscomp$1$$,
$params$jscomp$297$$,$shape$jscomp$759$$,$meta71969$$){this.$p__71966$=$p__71966$jscomp$1$$;this.$map__71967$=$map__71967$jscomp$1$$;this.params=$params$jscomp$297$$;this.shape=$shape$jscomp$759$$;this.$meta71969$=$meta71969$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$show_shape_context_menu_71968$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_shape_context_menu_71968$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4505$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_shape_context_menu$$},$app$main$data$workspace$show_shape_context_menu_71968$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71970$$,$meta71969__$1$$){return new $app$main$data$workspace$show_shape_context_menu_71968$$(this.$p__71966$,this.$map__71967$,this.params,this.shape,$meta71969__$1$$)},$app$main$data$workspace$show_shape_context_menu_71968$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71969$},
$app$main$data$workspace$show_shape_context_menu_71968$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_shape_context_menu_71968$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2577_selected$jscomp$109$$,$all_selected_no_bool_shapes_QMARK__state$jscomp$916$$){$_$jscomp$2577_selected$jscomp$109$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($all_selected_no_bool_shapes_QMARK__state$jscomp$916$$);
var $objects$jscomp$669$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($all_selected_no_bool_shapes_QMARK__state$jscomp$916$$);$all_selected_no_bool_shapes_QMARK__state$jscomp$916$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__71965_SHARP_$$){return $APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$669$$,$p1__71965_SHARP_$$)}),
$_$jscomp$2577_selected$jscomp$109$$);var $head$jscomp$22_not_group_like_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$669$$,$APP.$cljs$core$first$$($_$jscomp$2577_selected$jscomp$109$$));$head$jscomp$22_not_group_like_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($_$jscomp$2577_selected$jscomp$109$$),1)&&!$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1608$group$$,null,$APP.$cljs$cst$1610$bool$$,null],null),null),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$22_not_group_like_QMARK_$$));$all_selected_no_bool_shapes_QMARK__state$jscomp$916$$=$APP.$cljs$core$some$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1606$frame$$,null,$APP.$cljs$cst$1588$text$$,null],null),null),$APP.$cljs$cst$139$type$$),
$all_selected_no_bool_shapes_QMARK__state$jscomp$916$$);return this.shape==null||$APP.$cljs$core$contains_QMARK_$$($_$jscomp$2577_selected$jscomp$109$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.shape))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$show_context_menu$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$(this.params,$APP.$cljs$cst$947$kind$$,$APP.$cljs$cst$1811$shape$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$4506$disable_booleans_QMARK_$$,
$APP.$cljs$core$truth_$$($all_selected_no_bool_shapes_QMARK__state$jscomp$916$$)?$all_selected_no_bool_shapes_QMARK__state$jscomp$916$$:$head$jscomp$22_not_group_like_QMARK_$$,$cljs$cst$4507$disable_flatten_QMARK_$$,$all_selected_no_bool_shapes_QMARK__state$jscomp$916$$,$APP.$cljs$cst$1921$selected$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2577_selected$jscomp$109$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.shape))])))):$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.shape))),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$show_shape_context_menu$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$show_shape_context_menu$$.$cljs$core$IFn$_invoke$arity$1$(this.params):$app$main$data$workspace$show_shape_context_menu$$(this.params)))});return new $app$main$data$workspace$show_shape_context_menu_71968$$($p__71966$$,$map__71967__$1$$,$map__71967__$1$$,$shape$jscomp$758$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
typeof $app$main$data$workspace$hide_context_menu_72022$$==="undefined"&&($app$main$data$workspace$hide_context_menu_72022$$=function($meta72023$jscomp$inline_7242$$){this.$meta72023$=$meta72023$jscomp$inline_7242$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$hide_context_menu_72022$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4514$app_DOT_main_DOT_data_DOT_workspace_SLASH_hide_context_menu$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72024$jscomp$inline_7243$$,$meta72023__$1$jscomp$inline_7244$$){return new $app$main$data$workspace$hide_context_menu_72022$$($meta72023__$1$jscomp$inline_7244$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72023$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_7245$$,$state$jscomp$inline_7246$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$inline_7246$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$cst$2205$context_menu$$],null),null)});$APP.$app$main$data$workspace$hide_context_menu$$=new $app$main$data$workspace$hide_context_menu_72022$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
typeof $app$main$data$workspace$close_layers_search_72139$$==="undefined"&&($app$main$data$workspace$close_layers_search_72139$$=function($meta72140$jscomp$inline_7252$$){this.$meta72140$=$meta72140$jscomp$inline_7252$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$close_layers_search_72139$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4538$app_DOT_main_DOT_data_DOT_workspace_SLASH_close_layers_search$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72141$jscomp$inline_7253$$,$meta72140__$1$jscomp$inline_7254$$){return new $app$main$data$workspace$close_layers_search_72139$$($meta72140__$1$jscomp$inline_7254$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72140$},
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_7255$$,$state$jscomp$inline_7256$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$inline_7256$$,$APP.$cljs$cst$1920$workspace_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4537$layers_search$$)});$APP.$app$main$data$workspace$close_layers_search$$=new $app$main$data$workspace$close_layers_search_72139$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
$APP.$app$main$data$workspace$update_dimensions$$=function(){var $app$main$data$workspace$update_dimensions$$=null;$app$main$data$workspace$update_dimensions$$=function($param72156$jscomp$1$$,$param72157$jscomp$1$$,$param72158$jscomp$1$$,$param72159$jscomp$1$$){switch(arguments.length){case 3:return $app$main$data$workspace$transforms$update_dimensions$cljs$0core$0IFn$0_invoke$0arity$03$$($param72156$jscomp$1$$,$param72157$jscomp$1$$,$param72158$jscomp$1$$);case 4:return $app$main$data$workspace$transforms$update_dimensions$cljs$0core$0IFn$0_invoke$0arity$04$$($param72156$jscomp$1$$,
$param72157$jscomp$1$$,$param72158$jscomp$1$$,$param72159$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$main$data$workspace$update_dimensions$$.$cljs$core$IFn$_invoke$arity$3$=function($param72153$$,$param72154$$,$param72155$$){return $app$main$data$workspace$transforms$update_dimensions$cljs$0core$0IFn$0_invoke$0arity$03$$($param72153$$,$param72154$$,$param72155$$)};$app$main$data$workspace$update_dimensions$$.$cljs$core$IFn$_invoke$arity$4$=function($param72156$$,$param72157$$,
$param72158$$,$param72159$$){return $app$main$data$workspace$transforms$update_dimensions$cljs$0core$0IFn$0_invoke$0arity$04$$($param72156$$,$param72157$$,$param72158$$,$param72159$$)};return $app$main$data$workspace$update_dimensions$$}();
$APP.$app$main$data$workspace$increase_rotation$$=function(){function $app$main$data$workspace$increase_rotation__2$$($param72163$$,$param72164$$){return $app$main$data$workspace$transforms$increase_rotation$$.$cljs$core$IFn$_invoke$arity$2$($param72163$$,$param72164$$)}var $app$main$data$workspace$increase_rotation$$=null,$app$main$data$workspace$increase_rotation__4$$=function(){function $G__72463$$($param72165$jscomp$1$$,$param72166$jscomp$1$$,$param72167$jscomp$1$$,$var_args$jscomp$1341$$){var $G__72464__i_param72168$jscomp$1$$=
null;if(arguments.length>3){$G__72464__i_param72168$jscomp$1$$=0;for(var $G__72464__a$$=Array(arguments.length-3);$G__72464__i_param72168$jscomp$1$$<$G__72464__a$$.length;)$G__72464__a$$[$G__72464__i_param72168$jscomp$1$$]=arguments[$G__72464__i_param72168$jscomp$1$$+3],++$G__72464__i_param72168$jscomp$1$$;$G__72464__i_param72168$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__72464__a$$,0,null)}return $G__72463__delegate$$.call(this,$param72165$jscomp$1$$,$param72166$jscomp$1$$,$param72167$jscomp$1$$,
$G__72464__i_param72168$jscomp$1$$)}function $G__72463__delegate$$($param72165$$,$param72166$$,$param72167$$,$param72168$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($app$main$data$workspace$transforms$increase_rotation$$,$param72165$$,$param72166$$,$param72167$$,$param72168$$)}$G__72463$$.$cljs$lang$maxFixedArity$=3;$G__72463$$.$cljs$lang$applyTo$=function($arglist__72465_param72168$jscomp$2$$){var $param72165$jscomp$2$$=$APP.$cljs$core$first$$($arglist__72465_param72168$jscomp$2$$);
$arglist__72465_param72168$jscomp$2$$=$APP.$cljs$core$next$$($arglist__72465_param72168$jscomp$2$$);var $param72166$jscomp$2$$=$APP.$cljs$core$first$$($arglist__72465_param72168$jscomp$2$$);$arglist__72465_param72168$jscomp$2$$=$APP.$cljs$core$next$$($arglist__72465_param72168$jscomp$2$$);var $param72167$jscomp$2$$=$APP.$cljs$core$first$$($arglist__72465_param72168$jscomp$2$$);$arglist__72465_param72168$jscomp$2$$=$APP.$cljs$core$rest$$($arglist__72465_param72168$jscomp$2$$);return $G__72463__delegate$$($param72165$jscomp$2$$,
$param72166$jscomp$2$$,$param72167$jscomp$2$$,$arglist__72465_param72168$jscomp$2$$)};$G__72463$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__72463__delegate$$;return $G__72463$$}();$app$main$data$workspace$increase_rotation$$=function($param72165$jscomp$3$$,$param72166$jscomp$3$$,$param72167$jscomp$3$$,$var_args$jscomp$1342$$){switch(arguments.length){case 2:return $app$main$data$workspace$increase_rotation__2$$.call(this,$param72165$jscomp$3$$,$param72166$jscomp$3$$);default:var $G__72466_G__72467__i$$=
null;if(arguments.length>3){$G__72466_G__72467__i$$=0;for(var $G__72467__a$$=Array(arguments.length-3);$G__72466_G__72467__i$$<$G__72467__a$$.length;)$G__72467__a$$[$G__72466_G__72467__i$$]=arguments[$G__72466_G__72467__i$$+3],++$G__72466_G__72467__i$$;$G__72466_G__72467__i$$=new $APP.$cljs$core$IndexedSeq$$($G__72467__a$$,0,null)}return $app$main$data$workspace$increase_rotation__4$$.$cljs$core$IFn$_invoke$arity$variadic$($param72165$jscomp$3$$,$param72166$jscomp$3$$,$param72167$jscomp$3$$,$G__72466_G__72467__i$$)}throw Error("Invalid arity: "+
arguments.length);};$app$main$data$workspace$increase_rotation$$.$cljs$lang$maxFixedArity$=3;$app$main$data$workspace$increase_rotation$$.$cljs$lang$applyTo$=$app$main$data$workspace$increase_rotation__4$$.$cljs$lang$applyTo$;$app$main$data$workspace$increase_rotation$$.$cljs$core$IFn$_invoke$arity$2$=$app$main$data$workspace$increase_rotation__2$$;$app$main$data$workspace$increase_rotation$$.$cljs$core$IFn$_invoke$arity$variadic$=$app$main$data$workspace$increase_rotation__4$$.$cljs$core$IFn$_invoke$arity$variadic$;
return $app$main$data$workspace$increase_rotation$$}();
$APP.$app$main$data$workspace$start_move_selected$$=function(){var $app$main$data$workspace$start_move_selected$$=null;$app$main$data$workspace$start_move_selected$$=function($param72169$jscomp$1$$,$param72170$jscomp$1$$){switch(arguments.length){case 0:return $app$main$data$workspace$transforms$start_move_selected$cljs$0core$0IFn$0_invoke$0arity$02$$(null,!1);case 2:return $app$main$data$workspace$transforms$start_move_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($param72169$jscomp$1$$,$param72170$jscomp$1$$)}throw Error("Invalid arity: "+
arguments.length);};$app$main$data$workspace$start_move_selected$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $app$main$data$workspace$transforms$start_move_selected$cljs$0core$0IFn$0_invoke$0arity$02$$(null,!1)};$app$main$data$workspace$start_move_selected$$.$cljs$core$IFn$_invoke$arity$2$=function($param72169$$,$param72170$$){return $app$main$data$workspace$transforms$start_move_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($param72169$$,$param72170$$)};return $app$main$data$workspace$start_move_selected$$}();
$APP.$app$main$data$workspace$update_position$$=function(){var $app$main$data$workspace$update_position$$=null;$app$main$data$workspace$update_position$$=function($param72176$jscomp$1$$,$param72177$jscomp$1$$,$param72178$jscomp$1$$){switch(arguments.length){case 2:return $app$main$data$workspace$transforms$update_position$cljs$0core$0IFn$0_invoke$0arity$03$$($param72176$jscomp$1$$,$param72177$jscomp$1$$,null);case 3:return $app$main$data$workspace$transforms$update_position$cljs$0core$0IFn$0_invoke$0arity$03$$($param72176$jscomp$1$$,
$param72177$jscomp$1$$,$param72178$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$main$data$workspace$update_position$$.$cljs$core$IFn$_invoke$arity$2$=function($param72174$$,$param72175$$){return $app$main$data$workspace$transforms$update_position$cljs$0core$0IFn$0_invoke$0arity$03$$($param72174$$,$param72175$$,null)};$app$main$data$workspace$update_position$$.$cljs$core$IFn$_invoke$arity$3$=function($param72176$$,$param72177$$,$param72178$$){return $app$main$data$workspace$transforms$update_position$cljs$0core$0IFn$0_invoke$0arity$03$$($param72176$$,
$param72177$$,$param72178$$)};return $app$main$data$workspace$update_position$$}();
$APP.$app$main$data$workspace$update_positions$$=function(){var $app$main$data$workspace$update_positions$$=null;$app$main$data$workspace$update_positions$$=function($param72181$jscomp$1$$,$param72182$jscomp$1$$,$param72183$jscomp$1$$){switch(arguments.length){case 2:return $app$main$data$workspace$transforms$update_positions$cljs$0core$0IFn$0_invoke$0arity$03$$($param72181$jscomp$1$$,$param72182$jscomp$1$$,null);case 3:return $app$main$data$workspace$transforms$update_positions$cljs$0core$0IFn$0_invoke$0arity$03$$($param72181$jscomp$1$$,$param72182$jscomp$1$$,
$param72183$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$main$data$workspace$update_positions$$.$cljs$core$IFn$_invoke$arity$2$=function($param72179$$,$param72180$$){return $app$main$data$workspace$transforms$update_positions$cljs$0core$0IFn$0_invoke$0arity$03$$($param72179$$,$param72180$$,null)};$app$main$data$workspace$update_positions$$.$cljs$core$IFn$_invoke$arity$3$=function($param72181$$,$param72182$$,$param72183$$){return $app$main$data$workspace$transforms$update_positions$cljs$0core$0IFn$0_invoke$0arity$03$$($param72181$$,
$param72182$$,$param72183$$)};return $app$main$data$workspace$update_positions$$}();
$APP.$app$main$data$workspace$flip_horizontal_selected$$=function(){var $app$main$data$workspace$flip_horizontal_selected$$=null;$app$main$data$workspace$flip_horizontal_selected$$=function($param72184$jscomp$1$$){switch(arguments.length){case 0:return $app$main$data$workspace$transforms$flip_horizontal_selected$cljs$0core$0IFn$0_invoke$0arity$01$$(null);case 1:return $app$main$data$workspace$transforms$flip_horizontal_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($param72184$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);
};$app$main$data$workspace$flip_horizontal_selected$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $app$main$data$workspace$transforms$flip_horizontal_selected$cljs$0core$0IFn$0_invoke$0arity$01$$(null)};$app$main$data$workspace$flip_horizontal_selected$$.$cljs$core$IFn$_invoke$arity$1$=function($param72184$$){return $app$main$data$workspace$transforms$flip_horizontal_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($param72184$$)};return $app$main$data$workspace$flip_horizontal_selected$$}();
$APP.$app$main$data$workspace$flip_vertical_selected$$=function(){var $app$main$data$workspace$flip_vertical_selected$$=null;$app$main$data$workspace$flip_vertical_selected$$=function($param72185$jscomp$1$$){switch(arguments.length){case 0:return $app$main$data$workspace$transforms$flip_vertical_selected$cljs$0core$0IFn$0_invoke$0arity$01$$(null);case 1:return $app$main$data$workspace$transforms$flip_vertical_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($param72185$jscomp$1$$)}throw Error("Invalid arity: "+
arguments.length);};$app$main$data$workspace$flip_vertical_selected$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $app$main$data$workspace$transforms$flip_vertical_selected$cljs$0core$0IFn$0_invoke$0arity$01$$(null)};$app$main$data$workspace$flip_vertical_selected$$.$cljs$core$IFn$_invoke$arity$1$=function($param72185$$){return $app$main$data$workspace$transforms$flip_vertical_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($param72185$$)};return $app$main$data$workspace$flip_vertical_selected$$}();
$APP.$app$main$data$workspace$add_shape$$=function(){var $app$main$data$workspace$add_shape$$=null;$app$main$data$workspace$add_shape$$=function($param72188$jscomp$1$$,$param72189$jscomp$1$$){switch(arguments.length){case 1:return $app$main$data$workspace$shapes$add_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($param72188$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);case 2:return $app$main$data$workspace$shapes$add_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($param72188$jscomp$1$$,$param72189$jscomp$1$$)}throw Error("Invalid arity: "+
arguments.length);};$app$main$data$workspace$add_shape$$.$cljs$core$IFn$_invoke$arity$1$=function($param72187$$){return $app$main$data$workspace$shapes$add_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($param72187$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$add_shape$$.$cljs$core$IFn$_invoke$arity$2$=function($param72188$$,$param72189$$){return $app$main$data$workspace$shapes$add_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($param72188$$,$param72189$$)};return $app$main$data$workspace$add_shape$$}();
$APP.$app$main$data$workspace$paste_from_clipboard$$=function(){var $app$main$data$workspace$paste_from_clipboard$$=null;$app$main$data$workspace$paste_from_clipboard$$=function($param72192$jscomp$1$$){switch(arguments.length){case 0:return $app$main$data$workspace$clipboard$paste_from_clipboard$cljs$0core$0IFn$0_invoke$0arity$01$$(null);case 1:return $app$main$data$workspace$clipboard$paste_from_clipboard$cljs$0core$0IFn$0_invoke$0arity$01$$($param72192$jscomp$1$$)}throw Error("Invalid arity: "+
arguments.length);};$app$main$data$workspace$paste_from_clipboard$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $app$main$data$workspace$clipboard$paste_from_clipboard$cljs$0core$0IFn$0_invoke$0arity$01$$(null)};$app$main$data$workspace$paste_from_clipboard$$.$cljs$core$IFn$_invoke$arity$1$=function($param72192$$){return $app$main$data$workspace$clipboard$paste_from_clipboard$cljs$0core$0IFn$0_invoke$0arity$01$$($param72192$$)};return $app$main$data$workspace$paste_from_clipboard$$}();
$app$main$data$workspace$deselect_all$$=function(){var $app$main$data$workspace$deselect_all$$=null;$app$main$data$workspace$deselect_all$$=function($param72201$jscomp$1$$){switch(arguments.length){case 0:return $APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$00$$();case 1:return $APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$01$$($param72201$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$main$data$workspace$deselect_all$$.$cljs$core$IFn$_invoke$arity$0$=
function(){return $APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$00$$()};$app$main$data$workspace$deselect_all$$.$cljs$core$IFn$_invoke$arity$1$=function($param72201$$){return $APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$01$$($param72201$$)};return $app$main$data$workspace$deselect_all$$}();
$APP.$app$main$data$workspace$select_shape$$=function(){var $app$main$data$workspace$select_shape$$=null;$app$main$data$workspace$select_shape$$=function($param72212$jscomp$1$$,$param72213$jscomp$1$$){switch(arguments.length){case 1:return $APP.$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$01$$($param72212$jscomp$1$$);case 2:return $app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($param72212$jscomp$1$$,$param72213$jscomp$1$$)}throw Error("Invalid arity: "+
arguments.length);};$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$1$=function($param72211$$){return $APP.$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$01$$($param72211$$)};$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$2$=function($param72212$$,$param72213$$){return $app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($param72212$$,$param72213$$)};return $app$main$data$workspace$select_shape$$}();
$app$main$data$workspace$shift_select_shapes$$=function(){var $app$main$data$workspace$shift_select_shapes$$=null;$app$main$data$workspace$shift_select_shapes$$=function($param72215$jscomp$1$$,$param72216$jscomp$1$$){switch(arguments.length){case 1:return $app$main$data$workspace$selection$shift_select_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($param72215$jscomp$1$$,null);case 2:return $app$main$data$workspace$selection$shift_select_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($param72215$jscomp$1$$,
$param72216$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$main$data$workspace$shift_select_shapes$$.$cljs$core$IFn$_invoke$arity$1$=function($param72214$$){return $app$main$data$workspace$selection$shift_select_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($param72214$$,null)};$app$main$data$workspace$shift_select_shapes$$.$cljs$core$IFn$_invoke$arity$2$=function($param72215$$,$param72216$$){return $app$main$data$workspace$selection$shift_select_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($param72215$$,
$param72216$$)};return $app$main$data$workspace$shift_select_shapes$$}();
$APP.$app$main$data$workspace$mask_group$$=function(){var $app$main$data$workspace$mask_group$$=null;$app$main$data$workspace$mask_group$$=function($param72225$jscomp$1$$){switch(arguments.length){case 0:return $APP.$app$main$data$workspace$groups$mask_group$cljs$0core$0IFn$0_invoke$0arity$01$$(null);case 1:return $APP.$app$main$data$workspace$groups$mask_group$cljs$0core$0IFn$0_invoke$0arity$01$$($param72225$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$main$data$workspace$mask_group$$.$cljs$core$IFn$_invoke$arity$0$=
function(){return $APP.$app$main$data$workspace$groups$mask_group$cljs$0core$0IFn$0_invoke$0arity$01$$(null)};$app$main$data$workspace$mask_group$$.$cljs$core$IFn$_invoke$arity$1$=function($param72225$$){return $APP.$app$main$data$workspace$groups$mask_group$cljs$0core$0IFn$0_invoke$0arity$01$$($param72225$$)};return $app$main$data$workspace$mask_group$$}();
$APP.$app$main$data$workspace$unmask_group$$=function(){var $app$main$data$workspace$unmask_group$$=null;$app$main$data$workspace$unmask_group$$=function($param72227$jscomp$1$$){switch(arguments.length){case 0:return $APP.$app$main$data$workspace$groups$unmask_group$cljs$0core$0IFn$0_invoke$0arity$01$$(null);case 1:return $APP.$app$main$data$workspace$groups$unmask_group$cljs$0core$0IFn$0_invoke$0arity$01$$($param72227$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);};$app$main$data$workspace$unmask_group$$.$cljs$core$IFn$_invoke$arity$0$=
function(){return $APP.$app$main$data$workspace$groups$unmask_group$cljs$0core$0IFn$0_invoke$0arity$01$$(null)};$app$main$data$workspace$unmask_group$$.$cljs$core$IFn$_invoke$arity$1$=function($param72227$$){return $APP.$app$main$data$workspace$groups$unmask_group$cljs$0core$0IFn$0_invoke$0arity$01$$($param72227$$)};return $app$main$data$workspace$unmask_group$$}();
$APP.$app$main$data$workspace$create_bool$$=function(){function $app$main$data$workspace$create_bool$$($param72229$jscomp$1$$,$var_args$jscomp$1343$$){var $G__72491__i_param72230$jscomp$1$$=null;if(arguments.length>1){$G__72491__i_param72230$jscomp$1$$=0;for(var $G__72491__a$$=Array(arguments.length-1);$G__72491__i_param72230$jscomp$1$$<$G__72491__a$$.length;)$G__72491__a$$[$G__72491__i_param72230$jscomp$1$$]=arguments[$G__72491__i_param72230$jscomp$1$$+1],++$G__72491__i_param72230$jscomp$1$$;$G__72491__i_param72230$jscomp$1$$=
new $APP.$cljs$core$IndexedSeq$$($G__72491__a$$,0,null)}return $app$main$data$workspace$create_bool__delegate$$.call(this,$param72229$jscomp$1$$,$G__72491__i_param72230$jscomp$1$$)}function $app$main$data$workspace$create_bool__delegate$$($param72229$$,$param72230$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$data$workspace$bool$create_bool$$,$param72229$$,$param72230$$)}$app$main$data$workspace$create_bool$$.$cljs$lang$maxFixedArity$=1;$app$main$data$workspace$create_bool$$.$cljs$lang$applyTo$=
function($arglist__72492_param72230$jscomp$2$$){var $param72229$jscomp$2$$=$APP.$cljs$core$first$$($arglist__72492_param72230$jscomp$2$$);$arglist__72492_param72230$jscomp$2$$=$APP.$cljs$core$rest$$($arglist__72492_param72230$jscomp$2$$);return $app$main$data$workspace$create_bool__delegate$$($param72229$jscomp$2$$,$arglist__72492_param72230$jscomp$2$$)};$app$main$data$workspace$create_bool$$.$cljs$core$IFn$_invoke$arity$variadic$=$app$main$data$workspace$create_bool__delegate$$;return $app$main$data$workspace$create_bool$$}();
$APP.$app$main$data$workspace$convert_selected_to_path$$=function(){var $app$main$data$workspace$convert_selected_to_path$$=null;$app$main$data$workspace$convert_selected_to_path$$=function($param72236$jscomp$1$$){switch(arguments.length){case 0:return $APP.$app$main$data$workspace$path$shapes_to_path$convert_selected_to_path$cljs$0core$0IFn$0_invoke$0arity$01$$(null);case 1:return $APP.$app$main$data$workspace$path$shapes_to_path$convert_selected_to_path$cljs$0core$0IFn$0_invoke$0arity$01$$($param72236$jscomp$1$$)}throw Error("Invalid arity: "+
arguments.length);};$app$main$data$workspace$convert_selected_to_path$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$app$main$data$workspace$path$shapes_to_path$convert_selected_to_path$cljs$0core$0IFn$0_invoke$0arity$01$$(null)};$app$main$data$workspace$convert_selected_to_path$$.$cljs$core$IFn$_invoke$arity$1$=function($param72236$$){return $APP.$app$main$data$workspace$path$shapes_to_path$convert_selected_to_path$cljs$0core$0IFn$0_invoke$0arity$01$$($param72236$$)};return $app$main$data$workspace$convert_selected_to_path$$}();
$APP.$app$main$data$workspace$convert_selected_strokes_to_path$$=function(){var $app$main$data$workspace$convert_selected_strokes_to_path$$=null;$app$main$data$workspace$convert_selected_strokes_to_path$$=function($param72241$jscomp$1$$){switch(arguments.length){case 0:return $app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path$cljs$0core$0IFn$0_invoke$0arity$01$$(null);case 1:return $app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path$cljs$0core$0IFn$0_invoke$0arity$01$$($param72241$jscomp$1$$)}throw Error("Invalid arity: "+
arguments.length);};$app$main$data$workspace$convert_selected_strokes_to_path$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path$cljs$0core$0IFn$0_invoke$0arity$01$$(null)};$app$main$data$workspace$convert_selected_strokes_to_path$$.$cljs$core$IFn$_invoke$arity$1$=function($param72241$$){return $app$main$data$workspace$path$shapes_to_path$convert_selected_strokes_to_path$cljs$0core$0IFn$0_invoke$0arity$01$$($param72241$$)};
return $app$main$data$workspace$convert_selected_strokes_to_path$$}();
$APP.$app$main$data$workspace$decrease_zoom$$=function(){var $app$main$data$workspace$decrease_zoom$$=null;$app$main$data$workspace$decrease_zoom$$=function($param72250$jscomp$1$$){switch(arguments.length){case 0:return $app$main$data$workspace$zoom$decrease_zoom$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3578$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_auto$$);case 1:return $app$main$data$workspace$zoom$decrease_zoom$cljs$0core$0IFn$0_invoke$0arity$01$$($param72250$jscomp$1$$)}throw Error("Invalid arity: "+arguments.length);
};$app$main$data$workspace$decrease_zoom$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $app$main$data$workspace$zoom$decrease_zoom$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3578$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_auto$$)};$app$main$data$workspace$decrease_zoom$$.$cljs$core$IFn$_invoke$arity$1$=function($param72250$$){return $app$main$data$workspace$zoom$decrease_zoom$cljs$0core$0IFn$0_invoke$0arity$01$$($param72250$$)};return $app$main$data$workspace$decrease_zoom$$}();
$APP.$app$main$data$workspace$increase_zoom$$=function(){var $app$main$data$workspace$increase_zoom$$=null;$app$main$data$workspace$increase_zoom$$=function($param72253$jscomp$1$$){switch(arguments.length){case 0:return $app$main$data$workspace$zoom$increase_zoom$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3578$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_auto$$);case 1:return $app$main$data$workspace$zoom$increase_zoom$cljs$0core$0IFn$0_invoke$0arity$01$$($param72253$jscomp$1$$)}throw Error("Invalid arity: "+
arguments.length);};$app$main$data$workspace$increase_zoom$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $app$main$data$workspace$zoom$increase_zoom$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$3578$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_auto$$)};$app$main$data$workspace$increase_zoom$$.$cljs$core$IFn$_invoke$arity$1$=function($param72253$$){return $app$main$data$workspace$zoom$increase_zoom$cljs$0core$0IFn$0_invoke$0arity$01$$($param72253$$)};return $app$main$data$workspace$increase_zoom$$}();
$APP.$app$main$data$workspace$set_zoom$$=function(){var $app$main$data$workspace$set_zoom$$=null;$app$main$data$workspace$set_zoom$$=function($param72255$jscomp$1$$,$param72256$jscomp$1$$){switch(arguments.length){case 1:return $APP.$app$main$data$workspace$zoom$set_zoom$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$param72255$jscomp$1$$);case 2:return $APP.$app$main$data$workspace$zoom$set_zoom$cljs$0core$0IFn$0_invoke$0arity$02$$($param72255$jscomp$1$$,$param72256$jscomp$1$$)}throw Error("Invalid arity: "+
arguments.length);};$app$main$data$workspace$set_zoom$$.$cljs$core$IFn$_invoke$arity$1$=function($param72254$$){return $APP.$app$main$data$workspace$zoom$set_zoom$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$param72254$$)};$app$main$data$workspace$set_zoom$$.$cljs$core$IFn$_invoke$arity$2$=function($param72255$$,$param72256$$){return $APP.$app$main$data$workspace$zoom$set_zoom$cljs$0core$0IFn$0_invoke$0arity$02$$($param72255$$,$param72256$$)};return $app$main$data$workspace$set_zoom$$}();$APP.$app$common$logging$loggers$$.set("app.main.ui.hooks.resize",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));$APP.$app$main$ui$hooks$resize$last_resize_type$$=null;var $app$main$ui$modal$modal_wrapper_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($components$jscomp$7_props_71390_temp__5825__auto__$jscomp$227$$){function $handle_keydown$$($JSCompiler_inline_result$jscomp$10901_event$jscomp$115$$){var $and__5023__auto__$jscomp$inline_12883$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($JSCompiler_inline_result$jscomp$10901_event$jscomp$115$$);$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_12883$$)?
$APP.$cljs$core$not$$($allow_click_outside$jscomp$2$$):$and__5023__auto__$jscomp$inline_12883$$)?($APP.$app$util$dom$stop_propagation$$($JSCompiler_inline_result$jscomp$10901_event$jscomp$115$$),$JSCompiler_inline_result$jscomp$10901_event$jscomp$115$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())):$JSCompiler_inline_result$jscomp$10901_event$jscomp$115$$=null;return $JSCompiler_inline_result$jscomp$10901_event$jscomp$115$$}function $handle_click_outside$$($JSCompiler_inline_result$jscomp$10902_event$jscomp$114$$){var $type$jscomp$inline_12875$$=
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$407$$),$wrapper$jscomp$inline_12877$$=$APP.$rumext$v2$ref_val$$($wrapper_ref$jscomp$1$$),$current$jscomp$inline_12878$$=$APP.$app$util$dom$get_target$$($JSCompiler_inline_result$jscomp$10902_event$jscomp$114$$);$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($wrapper$jscomp$inline_12877$$)?$APP.$cljs$core$not$$($allow_click_outside$jscomp$2$$)&&$APP.$cljs$core$not$$($wrapper$jscomp$inline_12877$$.contains($current$jscomp$inline_12878$$))&&
!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$inline_12875$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($current$jscomp$inline_12878$$,"allow-click-modal")))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$10902_event$jscomp$114$$.button,0):$wrapper$jscomp$inline_12877$$)?($APP.$app$util$dom$stop_propagation$$($JSCompiler_inline_result$jscomp$10902_event$jscomp$114$$),$APP.$app$util$dom$prevent_default$$($JSCompiler_inline_result$jscomp$10902_event$jscomp$114$$),
$JSCompiler_inline_result$jscomp$10902_event$jscomp$114$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())):$JSCompiler_inline_result$jscomp$10902_event$jscomp$114$$=null;return $JSCompiler_inline_result$jscomp$10902_event$jscomp$114$$}var $data$jscomp$407$$=$components$jscomp$7_props_71390_temp__5825__auto__$jscomp$227$$.data,$wrapper_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null);$components$jscomp$7_props_71390_temp__5825__auto__$jscomp$227$$=
$APP.$rumext$v2$deref$$($APP.$app$main$data$modal$components$$);var $allow_click_outside$jscomp$2$$=$APP.$cljs$cst$2339$allow_click_outside$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$407$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($allow_click_outside$jscomp$2$$)],function(){var $keys$jscomp$53$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$goog$events$listen$$(window,"popstate",$app$main$ui$modal$on_pop_state$$),
$APP.$goog$events$listen$$(document,"keydown",$handle_keydown$$),$APP.$goog$events$listen$$($APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$document$$,"#app"),"pointerdown",$handle_click_outside$$),$APP.$goog$events$listen$$(document,"contextmenu",$handle_click_outside$$)],null);return function(){return $APP.$cljs$core$run_BANG_$$($APP.$goog$events$unlistenByKey$$,$keys$jscomp$53$$)}});$components$jscomp$7_props_71390_temp__5825__auto__$jscomp$227$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($components$jscomp$7_props_71390_temp__5825__auto__$jscomp$227$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$407$$));return $APP.$cljs$core$truth_$$($components$jscomp$7_props_71390_temp__5825__auto__$jscomp$227$$)?(0,$APP.$rumext$v2$jsx$$)("div",{ref:$wrapper_ref$jscomp$1$$,className:"main_ui_modal__modal-wrapper",children:$rumext$v2$element$cljs$0core$0IFn$0_invoke$0arity$02$$($components$jscomp$7_props_71390_temp__5825__auto__$jscomp$227$$,$APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$407$$))}):null}),$app$main$ui$modal$ref_COLON_modal$$=
$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2338$app_DOT_main_DOT_data_DOT_modal_SLASH_modal$$,$APP.$app$main$store$state$$);$APP.$app$main$ui$components$file_uploader$file_uploader$$=(0,$APP.$rumext$v2$forward_ref$$)(function($accept$jscomp$6_map__71443_props_71433$$,$input_ref$$){function $opt_pick_one$$($p1__71432_SHARP_$$){return $APP.$cljs$core$truth_$$($multi$jscomp$4$$)?$p1__71432_SHARP_$$:$APP.$cljs$core$first$$($p1__71432_SHARP_$$)}$accept$jscomp$6_map__71443_props_71433$$=$APP.$rumext$v2$util$wrap_props$$($accept$jscomp$6_map__71443_props_71433$$);var $data_testid_map__71443__$1$$=$APP.$cljs$core$__destructure_map$$($accept$jscomp$6_map__71443_props_71433$$);
$accept$jscomp$6_map__71443_props_71433$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data_testid_map__71443__$1$$,$APP.$cljs$cst$924$accept$$);var $multi$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data_testid_map__71443__$1$$,$cljs$cst$531$multi$$),$label_text$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data_testid_map__71443__$1$$,$cljs$cst$4551$label_text$$),$label_class$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data_testid_map__71443__$1$$,
$cljs$cst$4552$label_class$$),$input_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data_testid_map__71443__$1$$,$cljs$cst$4553$input_id$$),$on_selected$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data_testid_map__71443__$1$$,$cljs$cst$4554$on_selected$$);$data_testid_map__71443__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data_testid_map__71443__$1$$,$cljs$cst$4555$data_testid$$);var $on_files_selected$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($opt_pick_one$$)],
function($event$jscomp$116_target$jscomp$135$$){$event$jscomp$116_target$jscomp$135$$=$APP.$app$util$dom$get_target$$($event$jscomp$116_target$jscomp$135$$);var $JSCompiler_temp_const$jscomp$1290$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $G__71455__$1$jscomp$inline_7267_G__71455__$2$jscomp$inline_7268_JSCompiler_inline_result$jscomp$1292$$=$event$jscomp$116_target$jscomp$135$$==null?null:$APP.$app$util$dom$get_files$$($event$jscomp$116_target$jscomp$135$$);$G__71455__$1$jscomp$inline_7267_G__71455__$2$jscomp$inline_7268_JSCompiler_inline_result$jscomp$1292$$=
$G__71455__$1$jscomp$inline_7267_G__71455__$2$jscomp$inline_7268_JSCompiler_inline_result$jscomp$1292$$==null?null:$opt_pick_one$$($G__71455__$1$jscomp$inline_7267_G__71455__$2$jscomp$inline_7268_JSCompiler_inline_result$jscomp$1292$$);$G__71455__$1$jscomp$inline_7267_G__71455__$2$jscomp$inline_7268_JSCompiler_inline_result$jscomp$1292$$=$G__71455__$1$jscomp$inline_7267_G__71455__$2$jscomp$inline_7268_JSCompiler_inline_result$jscomp$1292$$==null?null:$on_selected$$.$cljs$core$IFn$_invoke$arity$1$?
$on_selected$$.$cljs$core$IFn$_invoke$arity$1$($G__71455__$1$jscomp$inline_7267_G__71455__$2$jscomp$inline_7268_JSCompiler_inline_result$jscomp$1292$$):$on_selected$$($G__71455__$1$jscomp$inline_7267_G__71455__$2$jscomp$inline_7268_JSCompiler_inline_result$jscomp$1292$$);$JSCompiler_temp_const$jscomp$1290$$.call($APP.$app$main$store$emit_BANG_$$,$G__71455__$1$jscomp$inline_7267_G__71455__$2$jscomp$inline_7268_JSCompiler_inline_result$jscomp$1292$$);return $event$jscomp$116_target$jscomp$135$$!=null?
$event$jscomp$116_target$jscomp$135$$.value="":null});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($label_text$$)?(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:$input_id$$,className:$label_class$$,children:$label_text$$}):null,(0,$APP.$rumext$v2$jsx$$)("input",{onChange:$on_files_selected$$,"aria-label":"uploader",id:$input_id$$,"data-testid":$data_testid_map__71443__$1$$,style:{display:"none",width:0},accept:$accept$jscomp$6_map__71443_props_71433$$,
type:"file",ref:$input_ref$$,multiple:$multi$jscomp$4$$})]})});$APP.$cljs$core$set$$($APP.$cljs$core$list$$("view-as-icons","character-e","align-content-row-evenly","character-l","padding-bottom","character-t","align-self-column-bottom","clock","align-self-column-center","text-middle","status-update","character-x","corner-top","play","margin-right","stroke-dashed","boards-thumbnail","align-content-row-start","help","character-o","stroke-circle","align-self-column-stretch","column-reverse","flex-horizontal","align-items-column-start","character-c","easing-ease-in-out",
"constraint-vertical","character-k","character-z","add","margin-top-bottom","gap-vertical","padding-extended","stroke-rectangle","text-letterspacing","download","msg-success","align-content-column-around","msg-neutral","align-top","to-curve","justify-content-row-end","user","boolean-difference","align-content-row-end","justify-content-column-evenly","grid-rows","align-content-column-end","text-palette","arrow-up-right","picker","align-bottom","stroke-solid","corner-bottom-right","expand","align-self-row-stretch",
"corner-bottom-left","stroke-inside","margin-bottom","switch","character-i","grid-column","distribute-horizontally","lock","stroke-rounded","character-g","menu","rectangle","img","padding-top-bottom","text-font-family","text","stroke-squared","boolean-exclude","justify-content-row-between","margin","justify-content-column-center","align-content-row-around","board","row","gap-horizontal","masked","corner-radius","character-u","easing-ease-in","text-rtl","text-paragraph","easing-ease","path","padding-left-right",
"text-lineheight","text-fixed","text-bottom","tick","arrow-left","text-align-right","puzzle","stroke-arrow","arrow","align-items-row-start","stroke-diamond","mask","constraint-horizontal","boolean-flatten","text-uppercase","text-underlined","arrow-right","rgba","gutter-vertical","remove","size-vertical","text-mixed","easing-ease-out","text-auto-width","align-content-column-between","view-as-list","feedback","wrap","stroke-triangle","align-content-row-between","group","rotation","delete-text","align-vertical-center",
"detach","msg-error","tree","stroke-dotted","grid-gutter","corner-top-right","vertical-align-items-center","corner-bottom","align-left","character-s","character-m","to-corner","arrow-up","text-typography","corner-top-left","justify-content-column-around","variant","number","align-items-column-end","stroke-center","exit","desc-sort","align-content-column-start","vertical-align-items-start","arrow-down","join-nodes","justify-content-row-around","align-content-column-center","character-a","character-v",
"character-r","text-auto-height","fit-content","stroke-outside","corner-center","character-h","grid","stroke-size","folder","justify-content-column-end","character-n","justify-content-column-start","margin-left","status-alert","gutter-horizontal","comments","vertical-align-items-end","align-content-column-stretch","external-link","align-self-column-top","margin-top","align-self-row-right","distribute-vertical-spacing","flip-horizontal","character-p","text-font-weight","move","pentool","open-link",
"settings","clip-content","drop","snap-nodes","swatches","component-copy","boolean-union","size-horizontal","boolean-intersection","interaction","detached","text-stroked","merge-nodes","align-items-column-center","text-align-left","delete","flex","character-w","drop-shadow","history","status-tick","grid-square","locate","icon","bug","character-f","justify-content-column-between","shown","msg-warning","component","search","reorder","align-content-row-stretch","flex-grid","percentage","eye-off","pin",
"easing-linear","asc-sort","close","absolute","character-y","character-q","close-small","column","align-items-row-end","row-reverse","hide","padding-right","character-d","broken-link","align-horizontal-center","stroke-mixed","align-content-column-evenly","flip-vertical","text-font-size","character-b","library","text-lowercase","align-self-row-center","crown","grid-row","document","justify-content-row-start","text-justify","margin-left-right","thumbnail","align-self-row-left","grid-columns","character-j",
"filter","padding-left","text-top","justify-content-row-center","padding-top","align-content-row-center","effects","elipse","text-ltr","clipboard","character-ntilde","import-export","justify-content-row-evenly","hsva","graphics","grid-margin","at","status-wrong","inner-shadow","separate-nodes","fill-content","fixed-width","curve","svg","info","hug-content","code","reload","text-align-center","flex-vertical","tokens","align-right","rgba-complementary","unlock","layers","align-items-row-center"));var $app$main$ui$components$radio_buttons$context$$=(0,$APP.$rumext$v2$create_context$$)(null);var $app$main$ui$icons$icon_verify$$,$app$main$ui$icons$logo_error_screen$$,$app$main$ui$icons$logo_subscription$$,$app$main$ui$icons$logo_subscription_light$$,$app$main$ui$icons$nitrate_welcome$$,$app$main$ui$icons$brand_openid$$,$app$main$ui$icons$brand_github$$,$app$main$ui$icons$brand_gitlab$$,$app$main$ui$icons$brand_google$$,$app$main$ui$icons$absolute$$,$app$main$ui$icons$align_content_column_around$$,$app$main$ui$icons$align_content_column_between$$,$app$main$ui$icons$align_content_column_center$$,
$app$main$ui$icons$align_content_column_end$$,$app$main$ui$icons$align_content_column_evenly$$,$app$main$ui$icons$align_content_column_start$$,$app$main$ui$icons$align_content_column_stretch$$,$app$main$ui$icons$align_content_row_around$$,$app$main$ui$icons$align_content_row_between$$,$app$main$ui$icons$align_content_row_center$$,$app$main$ui$icons$align_content_row_end$$,$app$main$ui$icons$align_content_row_evenly$$,$app$main$ui$icons$align_content_row_start$$,$app$main$ui$icons$align_content_row_stretch$$,
$app$main$ui$icons$align_items_column_center$$,$app$main$ui$icons$align_items_column_end$$,$app$main$ui$icons$align_items_column_start$$,$app$main$ui$icons$align_items_row_center$$,$app$main$ui$icons$align_items_row_end$$,$app$main$ui$icons$align_items_row_start$$,$app$main$ui$icons$align_self_column_bottom$$,$app$main$ui$icons$align_self_column_center$$,$app$main$ui$icons$align_self_column_stretch$$,$app$main$ui$icons$align_self_column_top$$,$app$main$ui$icons$align_self_row_center$$,$app$main$ui$icons$align_self_row_left$$,
$app$main$ui$icons$align_self_row_right$$,$app$main$ui$icons$align_self_row_stretch$$,$app$main$ui$icons$asc_sort$$,$app$main$ui$icons$boards_thumbnail$$,$app$main$ui$icons$boolean_difference$$,$app$main$ui$icons$boolean_exclude$$,$app$main$ui$icons$boolean_flatten$$,$app$main$ui$icons$boolean_intersection$$,$app$main$ui$icons$boolean_union$$,$app$main$ui$icons$character_e$$,$app$main$ui$icons$character_u$$,$app$main$ui$icons$clip_content$$,$app$main$ui$icons$clock$$,$app$main$ui$icons$close_small$$,
$app$main$ui$icons$code$$,$app$main$ui$icons$column_reverse$$,$app$main$ui$icons$column$$,$app$main$ui$icons$component_copy$$,$app$main$ui$icons$constraint_horizontal$$,$app$main$ui$icons$constraint_vertical$$,$app$main$ui$icons$corner_bottom_left$$,$app$main$ui$icons$corner_bottom_right$$,$app$main$ui$icons$corner_bottom$$,$app$main$ui$icons$corner_center$$,$app$main$ui$icons$corner_radius$$,$app$main$ui$icons$corner_top$$,$app$main$ui$icons$corner_top_left$$,$app$main$ui$icons$corner_top_right$$,
$app$main$ui$icons$crown$$,$app$main$ui$icons$delete_text$$,$app$main$ui$icons$delete$0$$,$app$main$ui$icons$desc_sort$$,$app$main$ui$icons$detach$$,$app$main$ui$icons$detached$$,$app$main$ui$icons$download$$,$app$main$ui$icons$drop_shadow$$,$app$main$ui$icons$easing_ease_in_out$$,$app$main$ui$icons$easing_ease_in$$,$app$main$ui$icons$easing_ease_out$$,$app$main$ui$icons$easing_ease$$,$app$main$ui$icons$easing_linear$$,$app$main$ui$icons$effects$$,$app$main$ui$icons$exit$$,$app$main$ui$icons$expand$$,
$app$main$ui$icons$external_link$$,$app$main$ui$icons$feedback$$,$app$main$ui$icons$fill_content$$,$app$main$ui$icons$fixed_width$$,$app$main$ui$icons$flex_grid$$,$app$main$ui$icons$flex$$,$app$main$ui$icons$flip_horizontal$$,$app$main$ui$icons$flip_vertical$$,$app$main$ui$icons$folder$$,$app$main$ui$icons$graphics$$,$app$main$ui$icons$grid_column$$,$app$main$ui$icons$grid_columns$$,$app$main$ui$icons$grid_gutter$$,$app$main$ui$icons$grid$$,$app$main$ui$icons$grid_row$$,$app$main$ui$icons$grid_rows$$,
$app$main$ui$icons$grid_square$$,$app$main$ui$icons$gutter_horizontal$$,$app$main$ui$icons$gutter_vertical$$,$app$main$ui$icons$help$$,$app$main$ui$icons$hide$$,$app$main$ui$icons$hsva$$,$app$main$ui$icons$hug_content$$,$app$main$ui$icons$icon$$,$app$main$ui$icons$inner_shadow$$,$app$main$ui$icons$interaction$$,$app$main$ui$icons$join_nodes$$,$app$main$ui$icons$justify_content_column_around$$,$app$main$ui$icons$justify_content_column_between$$,$app$main$ui$icons$justify_content_column_center$$,$app$main$ui$icons$justify_content_column_end$$,
$app$main$ui$icons$justify_content_column_evenly$$,$app$main$ui$icons$justify_content_column_start$$,$app$main$ui$icons$justify_content_row_around$$,$app$main$ui$icons$justify_content_row_between$$,$app$main$ui$icons$justify_content_row_center$$,$app$main$ui$icons$justify_content_row_end$$,$app$main$ui$icons$justify_content_row_evenly$$,$app$main$ui$icons$justify_content_row_start$$,$app$main$ui$icons$layers$$,$app$main$ui$icons$locate$$,$app$main$ui$icons$lock$$,$app$main$ui$icons$mask$$,$app$main$ui$icons$masked$$,
$app$main$ui$icons$merge_nodes$$,$app$main$ui$icons$msg_error$$,$app$main$ui$icons$msg_success$$,$app$main$ui$icons$msg_warning$$,$app$main$ui$icons$number$$,$app$main$ui$icons$oauth_1$$,$app$main$ui$icons$oauth_2$$,$app$main$ui$icons$oauth_3$$,$app$main$ui$icons$pentool$$,$app$main$ui$icons$pin$$,$app$main$ui$icons$rgba$$,$app$main$ui$icons$rgba_complementary$$,$app$main$ui$icons$row$$,$app$main$ui$icons$row_reverse$$,$app$main$ui$icons$separate_nodes$$,$app$main$ui$icons$settings$$,$app$main$ui$icons$shown$$,
$app$main$ui$icons$size_horizontal$$,$app$main$ui$icons$size_vertical$$,$app$main$ui$icons$snap_nodes$$,$app$main$ui$icons$status_update$$,$app$main$ui$icons$stroke_arrow$$,$app$main$ui$icons$stroke_circle$$,$app$main$ui$icons$stroke_diamond$$,$app$main$ui$icons$stroke_rectangle$$,$app$main$ui$icons$stroke_rounded$$,$app$main$ui$icons$stroke_size$$,$app$main$ui$icons$stroke_squared$$,$app$main$ui$icons$stroke_triangle$$,$app$main$ui$icons$switch$0$$,$app$main$ui$icons$text_align_center$$,$app$main$ui$icons$text_align_left$$,
$app$main$ui$icons$text_align_right$$,$app$main$ui$icons$text_auto_height$$,$app$main$ui$icons$text_auto_width$$,$app$main$ui$icons$text_bottom$$,$app$main$ui$icons$text_fixed$$,$app$main$ui$icons$text_font_family$$,$app$main$ui$icons$text_font_size$$,$app$main$ui$icons$text_font_weight$$,$app$main$ui$icons$text_justify$$,$app$main$ui$icons$text_lowercase$$,$app$main$ui$icons$text_ltr$$,$app$main$ui$icons$text_middle$$,$app$main$ui$icons$text_mixed$$,$app$main$ui$icons$text_paragraph$$,$app$main$ui$icons$text_rtl$$,
$app$main$ui$icons$text_stroked$$,$app$main$ui$icons$text_top$$,$app$main$ui$icons$text_typography$$,$app$main$ui$icons$text_underlined$$,$app$main$ui$icons$text_uppercase$$,$app$main$ui$icons$thumbnail$$,$app$main$ui$icons$tokens$$,$app$main$ui$icons$to_corner$$,$app$main$ui$icons$to_curve$$,$app$main$ui$icons$unlock$$,$app$main$ui$icons$variant$$,$app$main$ui$icons$vertical_align_items_center$$,$app$main$ui$icons$vertical_align_items_end$$,$app$main$ui$icons$vertical_align_items_start$$,$app$main$ui$icons$view_as_icons$$,
$app$main$ui$icons$view_as_list$$;$app$main$ui$icons$icon_verify$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-icon-verify",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-icon-verify"})});$APP.$app$main$ui$icons$loader$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-loader",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-loader"})});
$APP.$app$main$ui$icons$logo$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-penpot-logo",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-penpot-logo"})});$APP.$app$main$ui$icons$logo_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-penpot-logo-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-penpot-logo-icon"})});
$app$main$ui$icons$logo_error_screen$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-logo-error-screen",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-logo-error-screen"})});$app$main$ui$icons$logo_subscription$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-logo-subscription",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-logo-subscription"})});
$app$main$ui$icons$logo_subscription_light$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-logo-subscription-light",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-logo-subscription-light"})});$app$main$ui$icons$nitrate_welcome$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-nitrate-welcome",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-nitrate-welcome"})});
$app$main$ui$icons$brand_openid$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-brand-openid",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-brand-openid"})});$app$main$ui$icons$brand_github$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-brand-github",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-brand-github"})});
$app$main$ui$icons$brand_gitlab$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-brand-gitlab",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-brand-gitlab"})});$app$main$ui$icons$brand_google$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-brand-google",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-brand-google"})});
$app$main$ui$icons$absolute$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-absolute",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-absolute"})});$APP.$app$main$ui$icons$add$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-add",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-add"})});
$APP.$app$main$ui$icons$align_bottom$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-bottom",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-bottom"})});$app$main$ui$icons$align_content_column_around$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-content-column-around",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-content-column-around"})});
$app$main$ui$icons$align_content_column_between$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-content-column-between",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-content-column-between"})});$app$main$ui$icons$align_content_column_center$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-content-column-center",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-content-column-center"})});
$app$main$ui$icons$align_content_column_end$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-content-column-end",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-content-column-end"})});$app$main$ui$icons$align_content_column_evenly$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-content-column-evenly",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-content-column-evenly"})});
$app$main$ui$icons$align_content_column_start$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-content-column-start",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-content-column-start"})});$app$main$ui$icons$align_content_column_stretch$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-content-column-stretch",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-content-column-stretch"})});
$app$main$ui$icons$align_content_row_around$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-content-row-around",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-content-row-around"})});$app$main$ui$icons$align_content_row_between$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-content-row-between",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-content-row-between"})});
$app$main$ui$icons$align_content_row_center$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-content-row-center",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-content-row-center"})});$app$main$ui$icons$align_content_row_end$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-content-row-end",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-content-row-end"})});
$app$main$ui$icons$align_content_row_evenly$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-content-row-evenly",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-content-row-evenly"})});$app$main$ui$icons$align_content_row_start$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-content-row-start",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-content-row-start"})});
$app$main$ui$icons$align_content_row_stretch$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-content-row-stretch",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-content-row-stretch"})});$APP.$app$main$ui$icons$align_horizontal_center$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-horizontal-center",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-horizontal-center"})});
$app$main$ui$icons$align_items_column_center$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-items-column-center",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-items-column-center"})});$app$main$ui$icons$align_items_column_end$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-items-column-end",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-items-column-end"})});
$app$main$ui$icons$align_items_column_start$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-items-column-start",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-items-column-start"})});$app$main$ui$icons$align_items_row_center$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-items-row-center",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-items-row-center"})});
$app$main$ui$icons$align_items_row_end$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-items-row-end",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-items-row-end"})});$app$main$ui$icons$align_items_row_start$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-items-row-start",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-items-row-start"})});
$APP.$app$main$ui$icons$align_left$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-left",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-left"})});$APP.$app$main$ui$icons$align_right$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-right",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-right"})});
$app$main$ui$icons$align_self_column_bottom$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-self-column-bottom",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-self-column-bottom"})});$app$main$ui$icons$align_self_column_center$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-self-column-center",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-self-column-center"})});
$app$main$ui$icons$align_self_column_stretch$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-self-column-stretch",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-self-column-stretch"})});$app$main$ui$icons$align_self_column_top$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-self-column-top",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-self-column-top"})});
$app$main$ui$icons$align_self_row_center$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-self-row-center",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-self-row-center"})});$app$main$ui$icons$align_self_row_left$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-self-row-left",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-self-row-left"})});
$app$main$ui$icons$align_self_row_right$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-self-row-right",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-self-row-right"})});$app$main$ui$icons$align_self_row_stretch$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-self-row-stretch",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-self-row-stretch"})});
$APP.$app$main$ui$icons$align_top$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-top",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-top"})});$APP.$app$main$ui$icons$align_vertical_center$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-align-vertical-center",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-align-vertical-center"})});
$APP.$app$main$ui$icons$arrow$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-arrow",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-arrow"})});$app$main$ui$icons$asc_sort$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-asc-sort",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-asc-sort"})});
$APP.$app$main$ui$icons$board$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-board",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-board"})});$app$main$ui$icons$boards_thumbnail$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-boards-thumbnail",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-boards-thumbnail"})});
$app$main$ui$icons$boolean_difference$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-boolean-difference",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-boolean-difference"})});$app$main$ui$icons$boolean_exclude$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-boolean-exclude",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-boolean-exclude"})});
$app$main$ui$icons$boolean_flatten$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-boolean-flatten",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-boolean-flatten"})});$app$main$ui$icons$boolean_intersection$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-boolean-intersection",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-boolean-intersection"})});
$app$main$ui$icons$boolean_union$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-boolean-union",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-boolean-union"})});$APP.$app$main$ui$icons$bug$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-bug",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-bug"})});
$app$main$ui$icons$character_e$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-character-e",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-character-e"})});$app$main$ui$icons$character_u$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-character-u",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-character-u"})});
$app$main$ui$icons$clip_content$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-clip-content",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-clip-content"})});$APP.$app$main$ui$icons$clipboard$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-clipboard",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-clipboard"})});
$app$main$ui$icons$clock$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-clock",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-clock"})});$app$main$ui$icons$close_small$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-close-small",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-close-small"})});
$APP.$app$main$ui$icons$close$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-close",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-close"})});$app$main$ui$icons$code$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-code",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-code"})});
$app$main$ui$icons$column_reverse$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-column-reverse",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-column-reverse"})});$app$main$ui$icons$column$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-column",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-column"})});
$APP.$app$main$ui$icons$comments$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-comments",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-comments"})});$app$main$ui$icons$component_copy$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-component-copy",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-component-copy"})});
$APP.$app$main$ui$icons$component$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-component",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-component"})});$app$main$ui$icons$constraint_horizontal$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-constraint-horizontal",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-constraint-horizontal"})});
$app$main$ui$icons$constraint_vertical$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-constraint-vertical",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-constraint-vertical"})});$app$main$ui$icons$corner_bottom_left$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-corner-bottom-left",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-corner-bottom-left"})});
$app$main$ui$icons$corner_bottom_right$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-corner-bottom-right",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-corner-bottom-right"})});$app$main$ui$icons$corner_bottom$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-corner-bottom",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-corner-bottom"})});
$app$main$ui$icons$corner_center$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-corner-center",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-corner-center"})});$app$main$ui$icons$corner_radius$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-corner-radius",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-corner-radius"})});
$app$main$ui$icons$corner_top$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-corner-top",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-corner-top"})});$app$main$ui$icons$corner_top_left$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-corner-top-left",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-corner-top-left"})});
$app$main$ui$icons$corner_top_right$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-corner-top-right",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-corner-top-right"})});$app$main$ui$icons$crown$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-crown",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-crown"})});
$APP.$app$main$ui$icons$curve$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-curve",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-curve"})});$app$main$ui$icons$delete_text$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-delete-text",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-delete-text"})});
$app$main$ui$icons$delete$0$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-delete",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-delete"})});$app$main$ui$icons$desc_sort$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-desc-sort",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-desc-sort"})});
$app$main$ui$icons$detach$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-detach",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-detach"})});$app$main$ui$icons$detached$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-detached",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-detached"})});
$APP.$app$main$ui$icons$distribute_horizontally$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-distribute-horizontally",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-distribute-horizontally"})});$APP.$app$main$ui$icons$distribute_vertical_spacing$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-distribute-vertical-spacing",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-distribute-vertical-spacing"})});
$APP.$app$main$ui$icons$document$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-document",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-document"})});$app$main$ui$icons$download$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-download",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-download"})});
$APP.$app$main$ui$icons$drop_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-drop",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-drop"})});$app$main$ui$icons$drop_shadow$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-drop-shadow",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-drop-shadow"})});
$app$main$ui$icons$easing_ease_in_out$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-easing-ease-in-out",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-easing-ease-in-out"})});$app$main$ui$icons$easing_ease_in$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-easing-ease-in",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-easing-ease-in"})});
$app$main$ui$icons$easing_ease_out$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-easing-ease-out",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-easing-ease-out"})});$app$main$ui$icons$easing_ease$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-easing-ease",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-easing-ease"})});
$app$main$ui$icons$easing_linear$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-easing-linear",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-easing-linear"})});$app$main$ui$icons$effects$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-effects",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-effects"})});
$APP.$app$main$ui$icons$elipse$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-elipse",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-elipse"})});$app$main$ui$icons$exit$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-exit",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-exit"})});$app$main$ui$icons$expand$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-expand",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-expand"})});
$app$main$ui$icons$external_link$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-external-link",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-external-link"})});$app$main$ui$icons$feedback$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-feedback",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-feedback"})});
$app$main$ui$icons$fill_content$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-fill-content",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-fill-content"})});$APP.$app$main$ui$icons$filter_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-filter",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-filter"})});
$app$main$ui$icons$fixed_width$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-fixed-width",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-fixed-width"})});$app$main$ui$icons$flex_grid$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-flex-grid",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-flex-grid"})});
$APP.$app$main$ui$icons$flex_horizontal$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-flex-horizontal",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-flex-horizontal"})});$APP.$app$main$ui$icons$flex_vertical$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-flex-vertical",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-flex-vertical"})});
$app$main$ui$icons$flex$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-flex",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-flex"})});$app$main$ui$icons$flip_horizontal$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-flip-horizontal",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-flip-horizontal"})});
$app$main$ui$icons$flip_vertical$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-flip-vertical",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-flip-vertical"})});$app$main$ui$icons$folder$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-folder",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-folder"})});
$APP.$app$main$ui$icons$gap_horizontal$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-gap-horizontal",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-gap-horizontal"})});$APP.$app$main$ui$icons$gap_vertical$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-gap-vertical",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-gap-vertical"})});
$app$main$ui$icons$graphics$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-graphics",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-graphics"})});$app$main$ui$icons$grid_column$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-grid-column",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-grid-column"})});
$app$main$ui$icons$grid_columns$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-grid-columns",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-grid-columns"})});$app$main$ui$icons$grid_gutter$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-grid-gutter",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-grid-gutter"})});
$APP.$app$main$ui$icons$grid_margin$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-grid-margin",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-grid-margin"})});$app$main$ui$icons$grid$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-grid",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-grid"})});
$app$main$ui$icons$grid_row$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-grid-row",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-grid-row"})});$app$main$ui$icons$grid_rows$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-grid-rows",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-grid-rows"})});
$app$main$ui$icons$grid_square$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-grid-square",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-grid-square"})});$APP.$app$main$ui$icons$group$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-group",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-group"})});
$app$main$ui$icons$gutter_horizontal$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-gutter-horizontal",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-gutter-horizontal"})});$app$main$ui$icons$gutter_vertical$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-gutter-vertical",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-gutter-vertical"})});
$app$main$ui$icons$help$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-help",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-help"})});$app$main$ui$icons$hide$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-hide",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-hide"})});$APP.$app$main$ui$icons$history$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-history",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-history"})});
$app$main$ui$icons$hsva$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-hsva",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-hsva"})});$app$main$ui$icons$hug_content$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-hug-content",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-hug-content"})});$app$main$ui$icons$icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-icon"})});
$APP.$app$main$ui$icons$img$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-img",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-img"})});$app$main$ui$icons$inner_shadow$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-inner-shadow",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-inner-shadow"})});
$app$main$ui$icons$interaction$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-interaction",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-interaction"})});$app$main$ui$icons$join_nodes$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-join-nodes",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-join-nodes"})});
$app$main$ui$icons$justify_content_column_around$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-justify-content-column-around",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-justify-content-column-around"})});$app$main$ui$icons$justify_content_column_between$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-justify-content-column-between",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-justify-content-column-between"})});
$app$main$ui$icons$justify_content_column_center$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-justify-content-column-center",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-justify-content-column-center"})});$app$main$ui$icons$justify_content_column_end$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-justify-content-column-end",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-justify-content-column-end"})});
$app$main$ui$icons$justify_content_column_evenly$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-justify-content-column-evenly",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-justify-content-column-evenly"})});$app$main$ui$icons$justify_content_column_start$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-justify-content-column-start",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-justify-content-column-start"})});
$app$main$ui$icons$justify_content_row_around$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-justify-content-row-around",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-justify-content-row-around"})});$app$main$ui$icons$justify_content_row_between$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-justify-content-row-between",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-justify-content-row-between"})});
$app$main$ui$icons$justify_content_row_center$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-justify-content-row-center",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-justify-content-row-center"})});$app$main$ui$icons$justify_content_row_end$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-justify-content-row-end",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-justify-content-row-end"})});
$app$main$ui$icons$justify_content_row_evenly$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-justify-content-row-evenly",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-justify-content-row-evenly"})});$app$main$ui$icons$justify_content_row_start$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-justify-content-row-start",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-justify-content-row-start"})});
$app$main$ui$icons$layers$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-layers",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-layers"})});$APP.$app$main$ui$icons$library$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-library",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-library"})});$app$main$ui$icons$locate$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-locate",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-locate"})});
$app$main$ui$icons$lock$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-lock",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-lock"})});$APP.$app$main$ui$icons$margin$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-margin",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-margin"})});
$APP.$app$main$ui$icons$margin_bottom$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-margin-bottom",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-margin-bottom"})});$APP.$app$main$ui$icons$margin_left$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-margin-left",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-margin-left"})});
$APP.$app$main$ui$icons$margin_left_right$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-margin-left-right",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-margin-left-right"})});$APP.$app$main$ui$icons$margin_right$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-margin-right",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-margin-right"})});
$APP.$app$main$ui$icons$margin_top$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-margin-top",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-margin-top"})});$APP.$app$main$ui$icons$margin_top_bottom$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-margin-top-bottom",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-margin-top-bottom"})});
$app$main$ui$icons$mask$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-mask",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-mask"})});$app$main$ui$icons$masked$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-masked",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-masked"})});$APP.$app$main$ui$icons$menu$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-menu",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-menu"})});
$app$main$ui$icons$merge_nodes$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-merge-nodes",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-merge-nodes"})});$APP.$app$main$ui$icons$move$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-move",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-move"})});
$app$main$ui$icons$msg_error$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-msg-error",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-msg-error"})});$APP.$app$main$ui$icons$msg_neutral$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-msg-neutral",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-msg-neutral"})});
$app$main$ui$icons$msg_success$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-msg-success",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-msg-success"})});$app$main$ui$icons$msg_warning$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-msg-warning",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-msg-warning"})});
$app$main$ui$icons$number$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-number",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-number"})});$APP.$app$main$ui$icons$open_link$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-open-link",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-open-link"})});
$app$main$ui$icons$oauth_1$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-oauth-1",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-oauth-1"})});$app$main$ui$icons$oauth_2$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-oauth-2",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-oauth-2"})});$app$main$ui$icons$oauth_3$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-oauth-3",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-oauth-3"})});
$APP.$app$main$ui$icons$padding_bottom$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-padding-bottom",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-padding-bottom"})});$APP.$app$main$ui$icons$padding_extended$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-padding-extended",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-padding-extended"})});
$APP.$app$main$ui$icons$padding_left$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-padding-left",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-padding-left"})});$APP.$app$main$ui$icons$padding_left_right$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-padding-left-right",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-padding-left-right"})});
$APP.$app$main$ui$icons$padding_right$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-padding-right",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-padding-right"})});$APP.$app$main$ui$icons$padding_top$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-padding-top",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-padding-top"})});
$APP.$app$main$ui$icons$padding_top_bottom$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-padding-top-bottom",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-padding-top-bottom"})});$APP.$app$main$ui$icons$path$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-path",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-path"})});
$app$main$ui$icons$pentool$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-pentool",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-pentool"})});$APP.$app$main$ui$icons$picker$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-picker",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-picker"})});$app$main$ui$icons$pin$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-pin",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-pin"})});
$APP.$app$main$ui$icons$play$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-play",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-play"})});$APP.$app$main$ui$icons$puzzle$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-puzzle",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-puzzle"})});
$APP.$app$main$ui$icons$rectangle$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-rectangle",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-rectangle"})});$APP.$app$main$ui$icons$reload$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-reload",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-reload"})});
$APP.$app$main$ui$icons$remove_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-remove",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-remove"})});$app$main$ui$icons$rgba$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-rgba",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-rgba"})});
$app$main$ui$icons$rgba_complementary$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-rgba-complementary",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-rgba-complementary"})});$APP.$app$main$ui$icons$rotation$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-rotation",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-rotation"})});
$app$main$ui$icons$row$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-row",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-row"})});$app$main$ui$icons$row_reverse$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-row-reverse",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-row-reverse"})});
$APP.$app$main$ui$icons$search$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-search",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-search"})});$app$main$ui$icons$separate_nodes$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-separate-nodes",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-separate-nodes"})});
$app$main$ui$icons$settings$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-settings",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-settings"})});$APP.$app$main$ui$icons$share$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-share",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-share"})});$app$main$ui$icons$shown$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-shown",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-shown"})});
$app$main$ui$icons$size_horizontal$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-size-horizontal",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-size-horizontal"})});$app$main$ui$icons$size_vertical$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-size-vertical",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-size-vertical"})});
$app$main$ui$icons$snap_nodes$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-snap-nodes",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-snap-nodes"})});$APP.$app$main$ui$icons$status_alert$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-status-alert",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-status-alert"})});
$APP.$app$main$ui$icons$status_tick$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-status-tick",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-status-tick"})});$app$main$ui$icons$status_update$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-status-update",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-status-update"})});
$APP.$app$main$ui$icons$status_wrong$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-status-wrong",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-status-wrong"})});$app$main$ui$icons$stroke_arrow$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-stroke-arrow",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-stroke-arrow"})});
$app$main$ui$icons$stroke_circle$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-stroke-circle",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-stroke-circle"})});$app$main$ui$icons$stroke_diamond$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-stroke-diamond",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-stroke-diamond"})});
$app$main$ui$icons$stroke_rectangle$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-stroke-rectangle",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-stroke-rectangle"})});$app$main$ui$icons$stroke_rounded$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-stroke-rounded",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-stroke-rounded"})});
$app$main$ui$icons$stroke_size$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-stroke-size",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-stroke-size"})});$app$main$ui$icons$stroke_squared$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-stroke-squared",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-stroke-squared"})});
$app$main$ui$icons$stroke_triangle$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-stroke-triangle",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-stroke-triangle"})});$APP.$app$main$ui$icons$svg$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-svg",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-svg"})});
$APP.$app$main$ui$icons$swatches$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-swatches",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-swatches"})});$app$main$ui$icons$switch$0$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-switch",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-switch"})});
$APP.$app$main$ui$icons$text$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text"})});$app$main$ui$icons$text_align_center$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-align-center",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-align-center"})});
$app$main$ui$icons$text_align_left$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-align-left",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-align-left"})});$app$main$ui$icons$text_align_right$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-align-right",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-align-right"})});
$app$main$ui$icons$text_auto_height$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-auto-height",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-auto-height"})});$app$main$ui$icons$text_auto_width$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-auto-width",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-auto-width"})});
$app$main$ui$icons$text_bottom$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-bottom",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-bottom"})});$app$main$ui$icons$text_fixed$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-fixed",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-fixed"})});
$app$main$ui$icons$text_font_family$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-font-family",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-font-family"})});$app$main$ui$icons$text_font_size$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-font-size",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-font-size"})});
$app$main$ui$icons$text_font_weight$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-font-weight",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-font-weight"})});$app$main$ui$icons$text_justify$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-justify",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-justify"})});
$APP.$app$main$ui$icons$text_letterspacing$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-letterspacing",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-letterspacing"})});$APP.$app$main$ui$icons$text_lineheight$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-lineheight",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-lineheight"})});
$app$main$ui$icons$text_lowercase$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-lowercase",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-lowercase"})});$app$main$ui$icons$text_ltr$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-ltr",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-ltr"})});
$app$main$ui$icons$text_middle$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-middle",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-middle"})});$app$main$ui$icons$text_mixed$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-mixed",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-mixed"})});
$APP.$app$main$ui$icons$text_palette$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-palette",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-palette"})});$app$main$ui$icons$text_paragraph$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-paragraph",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-paragraph"})});
$app$main$ui$icons$text_rtl$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-rtl",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-rtl"})});$app$main$ui$icons$text_stroked$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-stroked",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-stroked"})});
$app$main$ui$icons$text_top$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-top",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-top"})});$app$main$ui$icons$text_typography$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-typography",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-typography"})});
$app$main$ui$icons$text_underlined$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-underlined",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-underlined"})});$app$main$ui$icons$text_uppercase$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-text-uppercase",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-text-uppercase"})});
$app$main$ui$icons$thumbnail$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-thumbnail",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-thumbnail"})});$APP.$app$main$ui$icons$tick$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-tick",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-tick"})});$app$main$ui$icons$tokens$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-tokens",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-tokens"})});
$app$main$ui$icons$to_corner$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-to-corner",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-to-corner"})});$app$main$ui$icons$to_curve$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-to-curve",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-to-curve"})});
$APP.$app$main$ui$icons$tree$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-tree",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-tree"})});$app$main$ui$icons$unlock$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-unlock",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-unlock"})});$APP.$app$main$ui$icons$user$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-user",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-user"})});
$APP.$app$main$ui$icons$v2_icon_1$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-v2-icon-1",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-v2-icon-1"})});$APP.$app$main$ui$icons$v2_icon_2$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-v2-icon-2",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-v2-icon-2"})});
$APP.$app$main$ui$icons$v2_icon_3$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-v2-icon-3",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-v2-icon-3"})});$APP.$app$main$ui$icons$v2_icon_4$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-v2-icon-4",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-v2-icon-4"})});
$app$main$ui$icons$variant$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-variant",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-variant"})});$app$main$ui$icons$vertical_align_items_center$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-vertical-align-items-center",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-vertical-align-items-center"})});
$app$main$ui$icons$vertical_align_items_end$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-vertical-align-items-end",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-vertical-align-items-end"})});$app$main$ui$icons$vertical_align_items_start$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-vertical-align-items-start",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-vertical-align-items-start"})});
$app$main$ui$icons$view_as_icons$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-view-as-icons",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-view-as-icons"})});$app$main$ui$icons$view_as_list$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-view-as-list",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-view-as-list"})});
$APP.$app$main$ui$icons$wrap$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"icon-wrap",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-wrap"})});
$APP.$app$main$ui$icons$default$0$$={GridMargin:$APP.$app$main$ui$icons$grid_margin$$,MarginTopBottom:$APP.$app$main$ui$icons$margin_top_bottom$$,StatusUpdate:$app$main$ui$icons$status_update$$,JustifyContentRowBetween:$app$main$ui$icons$justify_content_row_between$$,Switch:$app$main$ui$icons$switch$0$$,Variant:$app$main$ui$icons$variant$$,JustifyContentRowEvenly:$app$main$ui$icons$justify_content_row_evenly$$,LogoSubscriptionLight:$app$main$ui$icons$logo_subscription_light$$,MsgError:$app$main$ui$icons$msg_error$$,
ToCorner:$app$main$ui$icons$to_corner$$,NitrateWelcome:$app$main$ui$icons$nitrate_welcome$$,GutterHorizontal:$app$main$ui$icons$gutter_horizontal$$,AlignTop:$APP.$app$main$ui$icons$align_top$$,TextUnderlined:$app$main$ui$icons$text_underlined$$,ToCurve:$app$main$ui$icons$to_curve$$,JustifyContentRowStart:$app$main$ui$icons$justify_content_row_start$$,AlignRight:$APP.$app$main$ui$icons$align_right$$,TextTypography:$app$main$ui$icons$text_typography$$,FillContent:$app$main$ui$icons$fill_content$$,Masked:$app$main$ui$icons$masked$$,
AlignItemsColumnStart:$app$main$ui$icons$align_items_column_start$$,EasingEase:$app$main$ui$icons$easing_ease$$,Loader:$APP.$app$main$ui$icons$loader$$,Locate:$app$main$ui$icons$locate$$,PaddingBottom:$APP.$app$main$ui$icons$padding_bottom$$,SizeVertical:$app$main$ui$icons$size_vertical$$,JustifyContentColumnStart:$app$main$ui$icons$justify_content_column_start$$,SnapNodes:$app$main$ui$icons$snap_nodes$$,Picker:$APP.$app$main$ui$icons$picker$$,TextPalette:$APP.$app$main$ui$icons$text_palette$$,Share:$APP.$app$main$ui$icons$share$$,
BooleanIntersection:$app$main$ui$icons$boolean_intersection$$,MarginLeft:$APP.$app$main$ui$icons$margin_left$$,Pentool:$app$main$ui$icons$pentool$$,MarginRight:$APP.$app$main$ui$icons$margin_right$$,MergeNodes:$app$main$ui$icons$merge_nodes$$,AlignSelfRowCenter:$app$main$ui$icons$align_self_row_center$$,Layers:$app$main$ui$icons$layers$$,InnerShadow:$app$main$ui$icons$inner_shadow$$,GridGutter:$app$main$ui$icons$grid_gutter$$,ViewAsList:$app$main$ui$icons$view_as_list$$,Comments:$APP.$app$main$ui$icons$comments$$,
EasingEaseOut:$app$main$ui$icons$easing_ease_out$$,AlignItemsColumnCenter:$app$main$ui$icons$align_items_column_center$$,AlignSelfRowStretch:$app$main$ui$icons$align_self_row_stretch$$,JustifyContentRowEnd:$app$main$ui$icons$justify_content_row_end$$,TextStroked:$app$main$ui$icons$text_stroked$$,VerticalAlignItemsCenter:$app$main$ui$icons$vertical_align_items_center$$,MarginTop:$APP.$app$main$ui$icons$margin_top$$,Path:$APP.$app$main$ui$icons$path$$,JustifyContentColumnAround:$app$main$ui$icons$justify_content_column_around$$,
AlignContentColumnAround:$app$main$ui$icons$align_content_column_around$$,DistributeVerticalSpacing:$APP.$app$main$ui$icons$distribute_vertical_spacing$$,Folder:$app$main$ui$icons$folder$$,Tokens:$app$main$ui$icons$tokens$$,Curve:$APP.$app$main$ui$icons$curve$$,V2Icon2:$APP.$app$main$ui$icons$v2_icon_2$$,PaddingLeftRight:$APP.$app$main$ui$icons$padding_left_right$$,Number:$app$main$ui$icons$number$$,TextFixed:$app$main$ui$icons$text_fixed$$,ClipContent:$app$main$ui$icons$clip_content$$,AlignBottom:$APP.$app$main$ui$icons$align_bottom$$,
TextAutoHeight:$app$main$ui$icons$text_auto_height$$,Board:$APP.$app$main$ui$icons$board$$,TextMiddle:$app$main$ui$icons$text_middle$$,AlignSelfRowRight:$app$main$ui$icons$align_self_row_right$$,RgbaComplementary:$app$main$ui$icons$rgba_complementary$$,PaddingTopBottom:$APP.$app$main$ui$icons$padding_top_bottom$$,Svg:$APP.$app$main$ui$icons$svg$$,EasingLinear:$app$main$ui$icons$easing_linear$$,AlignContentRowAround:$app$main$ui$icons$align_content_row_around$$,EasingEaseIn:$app$main$ui$icons$easing_ease_in$$,
JustifyContentColumnBetween:$app$main$ui$icons$justify_content_column_between$$,BooleanDifference:$app$main$ui$icons$boolean_difference$$,AlignContentColumnBetween:$app$main$ui$icons$align_content_column_between$$,Oauth3:$app$main$ui$icons$oauth_3$$,AlignContentRowEnd:$app$main$ui$icons$align_content_row_end$$,User:$APP.$app$main$ui$icons$user$$,Close:$APP.$app$main$ui$icons$close$$,GapHorizontal:$APP.$app$main$ui$icons$gap_horizontal$$,AlignLeft:$APP.$app$main$ui$icons$align_left$$,StrokeCircle:$app$main$ui$icons$stroke_circle$$,
TextJustify:$app$main$ui$icons$text_justify$$,Grid:$app$main$ui$icons$grid$$,StrokeSize:$app$main$ui$icons$stroke_size$$,Hsva:$app$main$ui$icons$hsva$$,SizeHorizontal:$app$main$ui$icons$size_horizontal$$,TextFontWeight:$app$main$ui$icons$text_font_weight$$,BooleanExclude:$app$main$ui$icons$boolean_exclude$$,AlignItemsRowEnd:$app$main$ui$icons$align_items_row_end$$,AlignContentRowStretch:$app$main$ui$icons$align_content_row_stretch$$,FlipVertical:$app$main$ui$icons$flip_vertical$$,CornerTop:$app$main$ui$icons$corner_top$$,
Img:$APP.$app$main$ui$icons$img$$,RowReverse:$app$main$ui$icons$row_reverse$$,CloseSmall:$app$main$ui$icons$close_small$$,IconVerify:$app$main$ui$icons$icon_verify$$,Swatches:$APP.$app$main$ui$icons$swatches$$,AlignItemsRowCenter:$app$main$ui$icons$align_items_row_center$$,DeleteText:$app$main$ui$icons$delete_text$$,Delete:$app$main$ui$icons$delete$0$$,Row:$app$main$ui$icons$row$$,MsgWarning:$app$main$ui$icons$msg_warning$$,ConstraintHorizontal:$app$main$ui$icons$constraint_horizontal$$,PaddingTop:$APP.$app$main$ui$icons$padding_top$$,
History:$APP.$app$main$ui$icons$history$$,JustifyContentColumnEvenly:$app$main$ui$icons$justify_content_column_evenly$$,TextAutoWidth:$app$main$ui$icons$text_auto_width$$,JustifyContentRowAround:$app$main$ui$icons$justify_content_row_around$$,AlignContentRowStart:$app$main$ui$icons$align_content_row_start$$,LogoErrorScreen:$app$main$ui$icons$logo_error_screen$$,Arrow:$APP.$app$main$ui$icons$arrow$$,StatusWrong:$APP.$app$main$ui$icons$status_wrong$$,GridRow:$app$main$ui$icons$grid_row$$,ViewAsIcons:$app$main$ui$icons$view_as_icons$$,
Menu:$APP.$app$main$ui$icons$menu$$,TextLineheight:$APP.$app$main$ui$icons$text_lineheight$$,Expand:$app$main$ui$icons$expand$$,ColumnReverse:$app$main$ui$icons$column_reverse$$,Rotation:$APP.$app$main$ui$icons$rotation$$,Icon:$app$main$ui$icons$icon$$,FlexHorizontal:$APP.$app$main$ui$icons$flex_horizontal$$,AlignContentColumnEnd:$app$main$ui$icons$align_content_column_end$$,Graphics:$app$main$ui$icons$graphics$$,RemoveIcon:$APP.$app$main$ui$icons$remove_icon$$,TextMixed:$app$main$ui$icons$text_mixed$$,
Add:$APP.$app$main$ui$icons$add$$,ConstraintVertical:$app$main$ui$icons$constraint_vertical$$,Library:$APP.$app$main$ui$icons$library$$,DropIcon:$APP.$app$main$ui$icons$drop_icon$$,StrokeDiamond:$app$main$ui$icons$stroke_diamond$$,AlignItemsRowStart:$app$main$ui$icons$align_items_row_start$$,JustifyContentColumnCenter:$app$main$ui$icons$justify_content_column_center$$,V2Icon4:$APP.$app$main$ui$icons$v2_icon_4$$,TextTop:$app$main$ui$icons$text_top$$,TextAlignRight:$app$main$ui$icons$text_align_right$$,
Elipse:$APP.$app$main$ui$icons$elipse$$,TextBottom:$app$main$ui$icons$text_bottom$$,Clock:$app$main$ui$icons$clock$$,Bug:$APP.$app$main$ui$icons$bug$$,CornerRadius:$app$main$ui$icons$corner_radius$$,AlignContentColumnStart:$app$main$ui$icons$align_content_column_start$$,StrokeTriangle:$app$main$ui$icons$stroke_triangle$$,AlignSelfColumnCenter:$app$main$ui$icons$align_self_column_center$$,DistributeHorizontally:$APP.$app$main$ui$icons$distribute_horizontally$$,BoardsThumbnail:$app$main$ui$icons$boards_thumbnail$$,
GapVertical:$APP.$app$main$ui$icons$gap_vertical$$,Flex:$app$main$ui$icons$flex$$,CornerBottom:$app$main$ui$icons$corner_bottom$$,Settings:$app$main$ui$icons$settings$$,Thumbnail:$app$main$ui$icons$thumbnail$$,AlignSelfColumnTop:$app$main$ui$icons$align_self_column_top$$,Effects:$app$main$ui$icons$effects$$,CornerBottomRight:$app$main$ui$icons$corner_bottom_right$$,SeparateNodes:$app$main$ui$icons$separate_nodes$$,Download:$app$main$ui$icons$download$$,BrandOpenid:$app$main$ui$icons$brand_openid$$,
FlipHorizontal:$app$main$ui$icons$flip_horizontal$$,MsgNeutral:$APP.$app$main$ui$icons$msg_neutral$$,Rgba:$app$main$ui$icons$rgba$$,AscSort:$app$main$ui$icons$asc_sort$$,TextLetterspacing:$APP.$app$main$ui$icons$text_letterspacing$$,CornerBottomLeft:$app$main$ui$icons$corner_bottom_left$$,FlexVertical:$APP.$app$main$ui$icons$flex_vertical$$,FlexGrid:$app$main$ui$icons$flex_grid$$,Detach:$app$main$ui$icons$detach$$,AlignVerticalCenter:$APP.$app$main$ui$icons$align_vertical_center$$,VerticalAlignItemsStart:$app$main$ui$icons$vertical_align_items_start$$,
MarginBottom:$APP.$app$main$ui$icons$margin_bottom$$,DescSort:$app$main$ui$icons$desc_sort$$,Reload:$APP.$app$main$ui$icons$reload$$,StatusTick:$APP.$app$main$ui$icons$status_tick$$,Column:$app$main$ui$icons$column$$,Margin:$APP.$app$main$ui$icons$margin$$,PaddingRight:$APP.$app$main$ui$icons$padding_right$$,AlignContentColumnCenter:$app$main$ui$icons$align_content_column_center$$,CornerTopLeft:$app$main$ui$icons$corner_top_left$$,Shown:$app$main$ui$icons$shown$$,AlignContentRowCenter:$app$main$ui$icons$align_content_row_center$$,
Oauth1:$app$main$ui$icons$oauth_1$$,V2Icon3:$APP.$app$main$ui$icons$v2_icon_3$$,CharacterE:$app$main$ui$icons$character_e$$,Pin:$app$main$ui$icons$pin$$,ComponentCopy:$app$main$ui$icons$component_copy$$,V2Icon1:$APP.$app$main$ui$icons$v2_icon_1$$,TextAlignCenter:$app$main$ui$icons$text_align_center$$,HugContent:$app$main$ui$icons$hug_content$$,StrokeRounded:$app$main$ui$icons$stroke_rounded$$,CharacterU:$app$main$ui$icons$character_u$$,BrandGithub:$app$main$ui$icons$brand_github$$,TextUppercase:$app$main$ui$icons$text_uppercase$$,
BooleanUnion:$app$main$ui$icons$boolean_union$$,Puzzle:$APP.$app$main$ui$icons$puzzle$$,FixedWidth:$app$main$ui$icons$fixed_width$$,Wrap:$APP.$app$main$ui$icons$wrap$$,FilterIcon:$APP.$app$main$ui$icons$filter_icon$$,BrandGitlab:$app$main$ui$icons$brand_gitlab$$,AlignContentRowBetween:$app$main$ui$icons$align_content_row_between$$,StrokeArrow:$app$main$ui$icons$stroke_arrow$$,StatusAlert:$APP.$app$main$ui$icons$status_alert$$,Crown:$app$main$ui$icons$crown$$,Component:$APP.$app$main$ui$icons$component$$,
JoinNodes:$app$main$ui$icons$join_nodes$$,OpenLink:$APP.$app$main$ui$icons$open_link$$,Text:$APP.$app$main$ui$icons$text$$,DropShadow:$app$main$ui$icons$drop_shadow$$,Help:$app$main$ui$icons$help$$,Oauth2:$app$main$ui$icons$oauth_2$$,AlignSelfColumnStretch:$app$main$ui$icons$align_self_column_stretch$$,Hide:$app$main$ui$icons$hide$$,TextRtl:$app$main$ui$icons$text_rtl$$,AlignContentRowEvenly:$app$main$ui$icons$align_content_row_evenly$$,Tree:$APP.$app$main$ui$icons$tree$$,GridSquare:$app$main$ui$icons$grid_square$$,
TextFontSize:$app$main$ui$icons$text_font_size$$,CornerTopRight:$app$main$ui$icons$corner_top_right$$,Mask:$app$main$ui$icons$mask$$,TextLtr:$app$main$ui$icons$text_ltr$$,AlignHorizontalCenter:$APP.$app$main$ui$icons$align_horizontal_center$$,AlignItemsColumnEnd:$app$main$ui$icons$align_items_column_end$$,AlignContentColumnEvenly:$app$main$ui$icons$align_content_column_evenly$$,MarginLeftRight:$APP.$app$main$ui$icons$margin_left_right$$,Interaction:$app$main$ui$icons$interaction$$,Lock:$app$main$ui$icons$lock$$,
LogoSubscription:$app$main$ui$icons$logo_subscription$$,Tick:$APP.$app$main$ui$icons$tick$$,Document:$APP.$app$main$ui$icons$document$$,Code:$app$main$ui$icons$code$$,Feedback:$app$main$ui$icons$feedback$$,Group:$APP.$app$main$ui$icons$group$$,CornerCenter:$app$main$ui$icons$corner_center$$,StrokeSquared:$app$main$ui$icons$stroke_squared$$,GridColumns:$app$main$ui$icons$grid_columns$$,PaddingLeft:$APP.$app$main$ui$icons$padding_left$$,AlignContentColumnStretch:$app$main$ui$icons$align_content_column_stretch$$,
Rectangle:$APP.$app$main$ui$icons$rectangle$$,VerticalAlignItemsEnd:$app$main$ui$icons$vertical_align_items_end$$,AlignSelfColumnBottom:$app$main$ui$icons$align_self_column_bottom$$,StrokeRectangle:$app$main$ui$icons$stroke_rectangle$$,AlignSelfRowLeft:$app$main$ui$icons$align_self_row_left$$,TextFontFamily:$app$main$ui$icons$text_font_family$$,Exit:$app$main$ui$icons$exit$$,Play:$APP.$app$main$ui$icons$play$$,EasingEaseInOut:$app$main$ui$icons$easing_ease_in_out$$,MsgSuccess:$app$main$ui$icons$msg_success$$,
GutterVertical:$app$main$ui$icons$gutter_vertical$$,ExternalLink:$app$main$ui$icons$external_link$$,Move:$APP.$app$main$ui$icons$move$$,Absolute:$app$main$ui$icons$absolute$$,GridColumn:$app$main$ui$icons$grid_column$$,JustifyContentColumnEnd:$app$main$ui$icons$justify_content_column_end$$,Search:$APP.$app$main$ui$icons$search$$,Unlock:$app$main$ui$icons$unlock$$,Logo:$APP.$app$main$ui$icons$logo$$,TextParagraph:$app$main$ui$icons$text_paragraph$$,Clipboard:$APP.$app$main$ui$icons$clipboard$$,LogoIcon:$APP.$app$main$ui$icons$logo_icon$$,
JustifyContentRowCenter:$app$main$ui$icons$justify_content_row_center$$,TextLowercase:$app$main$ui$icons$text_lowercase$$,Detached:$app$main$ui$icons$detached$$,BooleanFlatten:$app$main$ui$icons$boolean_flatten$$,BrandGoogle:$app$main$ui$icons$brand_google$$,TextAlignLeft:$app$main$ui$icons$text_align_left$$,GridRows:$app$main$ui$icons$grid_rows$$,PaddingExtended:$APP.$app$main$ui$icons$padding_extended$$};var $app$main$ui$ds$layout$tab_switcher$tab_nav_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($nav_class_props_71642$$){var $selected$jscomp$113$$=void 0,$action_button$$=void 0,$tabs$$=void 0,$ref$jscomp$32$$=void 0,$on_click$jscomp$2$$=void 0,$button_position$$=void 0,$props$jscomp$215_props__$1$jscomp$35$$=void 0;({ref:$ref$jscomp$32$$,tabs:$tabs$$,selected:$selected$jscomp$113$$,onClick:$on_click$jscomp$2$$,buttonPosition:$button_position$$,actionButton:$action_button$$,...$props$jscomp$215_props__$1$jscomp$35$$}=
$nav_class_props_71642$$);$nav_class_props_71642$$="main_ui_ds_layout_tab_switcher__tab-nav "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("start",$button_position$$)?"main_ui_ds_layout_tab_switcher__tab-nav-start":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("end",$button_position$$)?"main_ui_ds_layout_tab_switcher__tab-nav-end":"");$props$jscomp$215_props__$1$jscomp$35$$={...$props$jscomp$215_props__$1$jscomp$35$$,className:"main_ui_ds_layout_tab_switcher__tab-list",
role:"tablist","aria-orientation":"horizontal"};return(0,$APP.$rumext$v2$jsxs$$)("nav",{className:$nav_class_props_71642$$,children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($button_position$$,"start")?$action_button$$:null,(0,$APP.$rumext$v2$create_element$$)("ul",$props$jscomp$215_props__$1$jscomp$35$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$34$$,$element$jscomp$73_id$jscomp$inline_7279$$){var $JSCompiler_temp_const$jscomp$1296$$=
$out_arr__44124__auto__$jscomp$34$$.push;var $JSCompiler_inline_result$jscomp$1298_icon$jscomp$inline_7276$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$73_id$jscomp$inline_7279$$,$APP.$cljs$cst$1721$icon$$);var $label$jscomp$inline_7277$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$73_id$jscomp$inline_7279$$,$APP.$cljs$cst$2287$label$$),$aria_label$jscomp$inline_7278$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$73_id$jscomp$inline_7279$$,
$APP.$cljs$cst$4564$aria_label$$);$element$jscomp$73_id$jscomp$inline_7279$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$73_id$jscomp$inline_7279$$,$APP.$cljs$cst$266$id$$);$JSCompiler_inline_result$jscomp$1298_icon$jscomp$inline_7276$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$layout$tab_switcher$tab_STAR_$$,{icon:$JSCompiler_inline_result$jscomp$1298_icon$jscomp$inline_7276$$,label:$label$jscomp$inline_7277$$,"aria-label":$aria_label$jscomp$inline_7278$$,selected:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$73_id$jscomp$inline_7279$$,
$selected$jscomp$113$$),onClick:$on_click$jscomp$2$$,ref:$ref$jscomp$32$$,id:$element$jscomp$73_id$jscomp$inline_7279$$},$element$jscomp$73_id$jscomp$inline_7279$$);$JSCompiler_temp_const$jscomp$1296$$.call($out_arr__44124__auto__$jscomp$34$$,$JSCompiler_inline_result$jscomp$1298_icon$jscomp$inline_7276$$);return $out_arr__44124__auto__$jscomp$34$$},[],$tabs$$)),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($button_position$$,"end")?$action_button$$:null]})});$APP.$app$main$constants$size_presets$$=$APP.$cljs$core$PersistentVector$fromArray$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,"APPLE"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPhone 16",$APP.$cljs$cst$290$width$$,393,$APP.$cljs$cst$1522$height$$,852],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPhone 16 Pro",$APP.$cljs$cst$290$width$$,402,$APP.$cljs$cst$1522$height$$,874],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,"iPhone 16 Pro Max",$APP.$cljs$cst$290$width$$,440,$APP.$cljs$cst$1522$height$$,956],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPhone 16 Plus",$APP.$cljs$cst$290$width$$,430,$APP.$cljs$cst$1522$height$$,932],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"14/15 Pro Max",$APP.$cljs$cst$290$width$$,430,$APP.$cljs$cst$1522$height$$,932],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,
"iPhone 15/15 Pro",$APP.$cljs$cst$290$width$$,393,$APP.$cljs$cst$1522$height$$,852],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPhone 13/14 ",$APP.$cljs$cst$290$width$$,390,$APP.$cljs$cst$1522$height$$,844],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPhone 14 Plus",$APP.$cljs$cst$290$width$$,428,$APP.$cljs$cst$1522$height$$,926],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPhone 13 Mini",
$APP.$cljs$cst$290$width$$,375,$APP.$cljs$cst$1522$height$$,812],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPhone SE",$APP.$cljs$cst$290$width$$,320,$APP.$cljs$cst$1522$height$$,568],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPhone 12/12 Pro",$APP.$cljs$cst$290$width$$,390,$APP.$cljs$cst$1522$height$$,844],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPhone 12 Mini",$APP.$cljs$cst$290$width$$,
360,$APP.$cljs$cst$1522$height$$,780],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPhone 12 Pro Max",$APP.$cljs$cst$290$width$$,428,$APP.$cljs$cst$1522$height$$,926],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPhone X/XS/11 Pro",$APP.$cljs$cst$290$width$$,375,$APP.$cljs$cst$1522$height$$,812],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPhone XS Max/XR/11",$APP.$cljs$cst$290$width$$,
414,$APP.$cljs$cst$1522$height$$,896],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPad",$APP.$cljs$cst$290$width$$,768,$APP.$cljs$cst$1522$height$$,1024],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPad Mini 8.3in",$APP.$cljs$cst$290$width$$,744,$APP.$cljs$cst$1522$height$$,1133],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPad Pro 10.5in",$APP.$cljs$cst$290$width$$,834,$APP.$cljs$cst$1522$height$$,
1112],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPad Pro 11in",$APP.$cljs$cst$290$width$$,834,$APP.$cljs$cst$1522$height$$,1194],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"iPad Pro 12.9in",$APP.$cljs$cst$290$width$$,1027,$APP.$cljs$cst$1522$height$$,1366],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Watch Series 10",$APP.$cljs$cst$290$width$$,416,$APP.$cljs$cst$1522$height$$,496],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Watch 45mm",$APP.$cljs$cst$290$width$$,396,$APP.$cljs$cst$1522$height$$,484],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Watch 44mm",$APP.$cljs$cst$290$width$$,368,$APP.$cljs$cst$1522$height$$,448],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Watch 42mm",$APP.$cljs$cst$290$width$$,312,$APP.$cljs$cst$1522$height$$,390],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,"Watch 41mm",$APP.$cljs$cst$290$width$$,352,$APP.$cljs$cst$1522$height$$,430],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Watch 40mm",$APP.$cljs$cst$290$width$$,324,$APP.$cljs$cst$1522$height$$,394],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Watch 38mm",$APP.$cljs$cst$290$width$$,272,$APP.$cljs$cst$1522$height$$,340],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,
"MacBook Air",$APP.$cljs$cst$290$width$$,1280,$APP.$cljs$cst$1522$height$$,832],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"MacBook Pro 14in",$APP.$cljs$cst$290$width$$,1512,$APP.$cljs$cst$1522$height$$,982],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"MacBook Pro 16in",$APP.$cljs$cst$290$width$$,1728,$APP.$cljs$cst$1522$height$$,1117],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,"ANDROID"],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Expanded",$APP.$cljs$cst$290$width$$,1280,$APP.$cljs$cst$1522$height$$,800],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Compact",$APP.$cljs$cst$290$width$$,412,$APP.$cljs$cst$1522$height$$,917],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Large",$APP.$cljs$cst$290$width$$,360,$APP.$cljs$cst$1522$height$$,800],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,"Medium",$APP.$cljs$cst$290$width$$,700,$APP.$cljs$cst$1522$height$$,840],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Small",$APP.$cljs$cst$290$width$$,360,$APP.$cljs$cst$1522$height$$,640],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Mobile",$APP.$cljs$cst$290$width$$,360,$APP.$cljs$cst$1522$height$$,640],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Tablet",
$APP.$cljs$cst$290$width$$,768,$APP.$cljs$cst$1522$height$$,1024],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Google Pixel 7 Pro",$APP.$cljs$cst$290$width$$,412,$APP.$cljs$cst$1522$height$$,892],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Google Pixel 6a/6",$APP.$cljs$cst$290$width$$,412,$APP.$cljs$cst$1522$height$$,915],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Google Pixel 4a/5",$APP.$cljs$cst$290$width$$,
393,$APP.$cljs$cst$1522$height$$,851],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Samsung Galaxy S22",$APP.$cljs$cst$290$width$$,360,$APP.$cljs$cst$1522$height$$,780],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Samsung Galaxy S20+",$APP.$cljs$cst$290$width$$,384,$APP.$cljs$cst$1522$height$$,854],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Samsung Galaxy A71/A51",$APP.$cljs$cst$290$width$$,
412,$APP.$cljs$cst$1522$height$$,914],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,"MICROSOFT"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Surface Pro 3",$APP.$cljs$cst$290$width$$,1440,$APP.$cljs$cst$1522$height$$,960],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Surface Pro 4/5/6/7",$APP.$cljs$cst$290$width$$,1368,$APP.$cljs$cst$1522$height$$,912],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,"Surface Pro 8",$APP.$cljs$cst$290$width$$,140,$APP.$cljs$cst$1522$height$$,960],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,"ReMarkable"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Remarkable 2",$APP.$cljs$cst$290$width$$,1404,$APP.$cljs$cst$1522$height$$,1872],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Remarkable Pro",$APP.$cljs$cst$290$width$$,1620,$APP.$cljs$cst$1522$height$$,
2160],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,"WEB"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Web 1280",$APP.$cljs$cst$290$width$$,1280,$APP.$cljs$cst$1522$height$$,800],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Web 1366",$APP.$cljs$cst$290$width$$,1366,$APP.$cljs$cst$1522$height$$,768],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Web 1024",
$APP.$cljs$cst$290$width$$,1024,$APP.$cljs$cst$1522$height$$,768],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Web 1920",$APP.$cljs$cst$290$width$$,1920,$APP.$cljs$cst$1522$height$$,1080],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,"MIXED"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Desktop/Wireframe",$APP.$cljs$cst$290$width$$,1440,$APP.$cljs$cst$1522$height$$,1024],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,"TV",$APP.$cljs$cst$290$width$$,1280,$APP.$cljs$cst$1522$height$$,720],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Slide 16:9",$APP.$cljs$cst$290$width$$,1920,$APP.$cljs$cst$1522$height$$,1080],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Slide 4:3",$APP.$cljs$cst$290$width$$,1027,$APP.$cljs$cst$1522$height$$,768],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,
"PRINT (96dpi)"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"A0",$APP.$cljs$cst$290$width$$,3179,$APP.$cljs$cst$1522$height$$,4494],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"A1",$APP.$cljs$cst$290$width$$,2245,$APP.$cljs$cst$1522$height$$,3179],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"A2",$APP.$cljs$cst$290$width$$,1587,$APP.$cljs$cst$1522$height$$,2245],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,"A3",$APP.$cljs$cst$290$width$$,1123,$APP.$cljs$cst$1522$height$$,1587],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"A4",$APP.$cljs$cst$290$width$$,794,$APP.$cljs$cst$1522$height$$,1123],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"A5",$APP.$cljs$cst$290$width$$,559,$APP.$cljs$cst$1522$height$$,794],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"A6",$APP.$cljs$cst$290$width$$,
397,$APP.$cljs$cst$1522$height$$,559],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Letter",$APP.$cljs$cst$290$width$$,816,$APP.$cljs$cst$1522$height$$,1054],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"DIN Lang",$APP.$cljs$cst$290$width$$,835,$APP.$cljs$cst$1522$height$$,413],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,"SOCIAL MEDIA"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,
[$APP.$cljs$cst$725$name$$,"Instagram profile",$APP.$cljs$cst$290$width$$,320,$APP.$cljs$cst$1522$height$$,320],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Instagram post",$APP.$cljs$cst$290$width$$,1080,$APP.$cljs$cst$1522$height$$,1350],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Instagram story",$APP.$cljs$cst$290$width$$,1080,$APP.$cljs$cst$1522$height$$,1920],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,
"Facebook profile",$APP.$cljs$cst$290$width$$,720,$APP.$cljs$cst$1522$height$$,720],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Facebook cover",$APP.$cljs$cst$290$width$$,820,$APP.$cljs$cst$1522$height$$,312],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Facebook post",$APP.$cljs$cst$290$width$$,1200,$APP.$cljs$cst$1522$height$$,630],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"LinkedIn profile",
$APP.$cljs$cst$290$width$$,400,$APP.$cljs$cst$1522$height$$,400],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"LinkedIn cover",$APP.$cljs$cst$290$width$$,1584,$APP.$cljs$cst$1522$height$$,396],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"LinkedIn post",$APP.$cljs$cst$290$width$$,520,$APP.$cljs$cst$1522$height$$,320],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Bluesky profile",$APP.$cljs$cst$290$width$$,
400,$APP.$cljs$cst$1522$height$$,400],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Bluesky cover",$APP.$cljs$cst$290$width$$,3E3,$APP.$cljs$cst$1522$height$$,1E3],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"Bluesky post",$APP.$cljs$cst$290$width$$,1080,$APP.$cljs$cst$1522$height$$,1350],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"X profile",$APP.$cljs$cst$290$width$$,400,$APP.$cljs$cst$1522$height$$,
400],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"X header",$APP.$cljs$cst$290$width$$,1500,$APP.$cljs$cst$1522$height$$,500],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"X post",$APP.$cljs$cst$290$width$$,1024,$APP.$cljs$cst$1522$height$$,512],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"YouTube profile",$APP.$cljs$cst$290$width$$,800,$APP.$cljs$cst$1522$height$$,800],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,"YouTube banner",$APP.$cljs$cst$290$width$$,2560,$APP.$cljs$cst$1522$height$$,1440],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"YouTube cover",$APP.$cljs$cst$290$width$$,2048,$APP.$cljs$cst$1522$height$$,1152],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"YouTube thumb",$APP.$cljs$cst$290$width$$,1280,$APP.$cljs$cst$1522$height$$,720],null)],!0);var $app$common$files$tokens$schema_COLON_token_value_numeric$$,$app$common$files$tokens$schema_COLON_token_value_composite_ref$$,$app$common$files$tokens$schema_COLON_token_value_opacity$$,$app$common$files$tokens$schema_COLON_token_value_font_family$$,$app$common$files$tokens$schema_COLON_token_value_font_weight$$,$app$common$files$tokens$schema_COLON_token_value_typography$$,$app$common$files$tokens$schema_COLON_token_value_shadow$$,$app$common$files$tokens$parseable_token_value_regexp$$;
$APP.$app$common$files$tokens$schema_COLON_token_value_generic$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,$app$common$files$tokens$token_value_empty_fn$$],null)],null);
$app$common$files$tokens$schema_COLON_token_value_numeric$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,$app$common$files$tokens$token_value_empty_fn$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71657_SHARP_$$){return $APP.$app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.invalid-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__71657_SHARP_$$)]))}],null),function($value$jscomp$623$$){return $cuerdas$core$numeric_QMARK_$$($value$jscomp$623$$)?
$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$623$$)!=null:!0}],null)],null);$app$common$files$tokens$schema_COLON_token_value_composite_ref$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,$app$common$files$tokens$token_value_empty_fn$$],null)],null);
$app$common$files$tokens$schema_COLON_token_value_opacity$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,$app$common$files$tokens$token_value_empty_fn$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return(0,$APP.$app$common$i18n$tr$$)("errors.tokens.opacity-range")}],null),function($n$jscomp$291_opacity$jscomp$36$$){return $cuerdas$core$numeric_QMARK_$$($n$jscomp$291_opacity$jscomp$36$$)?($n$jscomp$291_opacity$jscomp$36$$=$app$common$data$parse_percent$cljs$0core$0IFn$0_invoke$0arity$02$$($n$jscomp$291_opacity$jscomp$36$$),
$n$jscomp$291_opacity$jscomp$36$$!=null&&0<=$n$jscomp$291_opacity$jscomp$36$$&&$n$jscomp$291_opacity$jscomp$36$$<=1):!0}],null)],null);
$app$common$files$tokens$schema_COLON_token_value_font_family$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),$app$common$types$token$schema_COLON_token_ref$$],null);
$app$common$files$tokens$schema_COLON_token_value_font_weight$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return(0,$APP.$app$common$i18n$tr$$)("errors.tokens.invalid-font-weight-token-value")}],null),$app$common$types$token$valid_font_weight_variant$$],
null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null);
$app$common$files$tokens$schema_COLON_token_value_typography$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1758$font_family$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),$app$common$files$tokens$schema_COLON_token_value_font_family$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1760$font_size$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$files$tokens$schema_COLON_token_value_numeric$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1761$font_weight$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$app$common$files$tokens$schema_COLON_token_value_font_weight$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1765$line_height$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,$app$common$files$tokens$token_value_empty_fn$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71658_SHARP_$$){return $APP.$app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.value-with-percent",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__71658_SHARP_$$)]))}],null),function($value$jscomp$624$$){return $cuerdas$core$numeric_QMARK_$$($cuerdas$core$rtrim$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$624$$))?$app$common$data$parse_percent$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$624$$)!=null:!0}],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1766$letter_spacing$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$files$tokens$schema_COLON_token_value_generic$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4573$paragraph_spacing$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$files$tokens$schema_COLON_token_value_generic$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1768$text_decoration$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$files$tokens$schema_COLON_token_value_generic$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1979$text_case$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$files$tokens$schema_COLON_token_value_generic$$],
null)],null),$app$common$files$tokens$schema_COLON_token_value_composite_ref$$],null);
$app$common$files$tokens$schema_COLON_token_value_shadow$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1650$offset_x$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1651$offset_y$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1653$blur$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return(0,$APP.$app$common$i18n$tr$$)("workspace.tokens.shadow-token-blur-value-error")}],null),function($blur$jscomp$10_n$jscomp$292$$){$blur$jscomp$10_n$jscomp$292$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($blur$jscomp$10_n$jscomp$292$$);return $blur$jscomp$10_n$jscomp$292$$==null||!($blur$jscomp$10_n$jscomp$292$$<
0)}],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1652$spread$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,
function(){return(0,$APP.$app$common$i18n$tr$$)("workspace.tokens.shadow-token-spread-value-error")}],null),function($n$jscomp$293_spread$jscomp$6$$){$n$jscomp$293_spread$jscomp$6$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$293_spread$jscomp$6$$);return $n$jscomp$293_spread$jscomp$6$$==null||!($n$jscomp$293_spread$jscomp$6$$<0)}],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1298$color$$,
$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2133$inset$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null)],null)],null),$app$common$files$tokens$schema_COLON_token_value_composite_ref$$],null);
$APP.$app$common$files$tokens$schema_COLON_token_description$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$339$max$$,2048,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.field-max-length",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([2048]))}],null)],null);
$APP.$app$common$files$tokens$schema_COLON_token_set_description$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$339$max$$,2048,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.field-max-length",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([2048]))}],null)],null);
$APP.$app$common$files$tokens$schema_COLON_token_theme_description$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$339$max$$,2048,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.field-max-length",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([2048]))}],null)],null);
$app$common$files$tokens$parseable_token_value_regexp$$=/^\s*(-?[0-9]+\.?[0-9]*)(px|%)?\s*$/;$APP.$app$common$types$stroke$default_stroke$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1868$stroke_alignment$$,$APP.$cljs$cst$2041$inner$$,$APP.$cljs$cst$1866$stroke_style$$,$APP.$cljs$cst$2037$solid$$,$APP.$cljs$cst$1739$stroke_color$$,"#000000",$APP.$cljs$cst$1740$stroke_opacity$$,1,$APP.$cljs$cst$1655$stroke_width$$,1],null);var $shadow$js$shim$module$0$0tokens_studio$0sd_transforms$$=shadow$bridge("@tokens-studio/sd-transforms");var $shadow$js$shim$module$0style_dictionary$0default$$=shadow$bridge("style-dictionary").default;$APP.$shadow$js$shim$module$0tinycolor2$0default$$=shadow$bridge("tinycolor2").default;$APP.$shadow$js$shim$module$0$0penpot$0tokenscript$$=shadow$bridge("@penpot/tokenscript");var $app$main$data$workspace$tokens$errors$error_codes$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$4575$error_DOT_import_SLASH_json_parse_error$$,$cljs$cst$4576$error_DOT_style_dictionary_SLASH_invalid_token_value_font_weight$$,$cljs$cst$4577$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow$$,$cljs$cst$4578$error_DOT_style_dictionary_SLASH_invalid_token_value_font_family$$,$APP.$cljs$cst$4579$error_DOT_token_SLASH_empty_input$$,$cljs$cst$4580$error_DOT_style_dictionary_SLASH_value_with_percent$$,
$APP.$cljs$cst$4581$error_DOT_style_dictionary_SLASH_invalid_token_value$$,$cljs$cst$4582$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_spread$$,$cljs$cst$4583$error_DOT_token_SLASH_invalid_color$$,$cljs$cst$4584$error_DOT_style_dictionary_SLASH_value_with_units$$,$cljs$cst$4585$error_DOT_token_SLASH_number_too_large$$,$APP.$cljs$cst$4586$error_DOT_import_SLASH_invalid_token_name$$,$APP.$cljs$cst$4587$error_DOT_import_SLASH_style_dictionary_unknown_error$$,$cljs$cst$4588$error_DOT_style_dictionary_SLASH_composite_line_height_needs_font_size$$,
$APP.$cljs$cst$4589$error_DOT_import_SLASH_no_token_files_found$$,$APP.$cljs$cst$2134$error_DOT_import_SLASH_invalid_json_data$$,$cljs$cst$4590$error_DOT_style_dictionary_SLASH_invalid_token_value_opacity$$,$APP.$cljs$cst$4591$error_DOT_token_SLASH_direct_self_reference$$,$cljs$cst$4592$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_type$$,$APP.$cljs$cst$4593$error_DOT_token_SLASH_name_collision$$,$cljs$cst$4594$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_blur$$,$APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,
$cljs$cst$4596$error_DOT_style_dictionary_SLASH_invalid_token_value_stroke_width$$,$cljs$cst$4597$error_DOT_style_dictionary_SLASH_invalid_token_value_text_case$$,$cljs$cst$4598$error_DOT_style_dictionary_SLASH_invalid_token_value_text_decoration$$,$cljs$cst$4599$error_DOT_style_dictionary_SLASH_invalid_token_value_typography$$,$cljs$cst$4600$error_DOT_import_SLASH_style_dictionary_reference_errors$$,$APP.$cljs$cst$4601$error_SLASH_unknown$$],[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,
$APP.$cljs$cst$4575$error_DOT_import_SLASH_json_parse_error$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.error-parse")}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4576$error_DOT_style_dictionary_SLASH_invalid_token_value_font_weight$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71769_SHARP_$$){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.invalid-font-weight-token-value",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71769_SHARP_$$]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4577$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71774_SHARP_$$){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.invalid-token-value-shadow",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71774_SHARP_$$]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4578$error_DOT_style_dictionary_SLASH_invalid_token_value_font_family$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71770_SHARP_$$){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.invalid-font-family-token-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71770_SHARP_$$]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,
[$APP.$cljs$cst$945$error_SLASH_code$$,$APP.$cljs$cst$4579$error_DOT_token_SLASH_empty_input$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.empty-input")}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4580$error_DOT_style_dictionary_SLASH_value_with_percent$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.value-with-percent"))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$APP.$cljs$cst$4581$error_DOT_style_dictionary_SLASH_invalid_token_value$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71764_SHARP_$$){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.invalid-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71764_SHARP_$$])))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4582$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_spread$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.shadow-spread-range")}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4583$error_DOT_token_SLASH_invalid_color$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71760_SHARP_$$){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.invalid-color",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71760_SHARP_$$])))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4584$error_DOT_style_dictionary_SLASH_value_with_units$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.value-with-units"))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4585$error_DOT_token_SLASH_number_too_large$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71761_SHARP_$$){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.number-too-large",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71761_SHARP_$$])))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$945$error_SLASH_code$$,
$APP.$cljs$cst$4586$error_DOT_import_SLASH_invalid_token_name$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.invalid-json-token-name")},$APP.$cljs$cst$4602$error_SLASH_detail$$,function($p1__71757_SHARP_$$){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.invalid-json-token-name-detail",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71757_SHARP_$$]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4600$error_DOT_import_SLASH_style_dictionary_reference_errors$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.import-error")}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4588$error_DOT_style_dictionary_SLASH_composite_line_height_needs_font_size$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71772_SHARP_$$){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.composite-line-height-needs-font-size",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71772_SHARP_$$]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$APP.$cljs$cst$4589$error_DOT_import_SLASH_no_token_files_found$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.no-token-files-found")}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$APP.$cljs$cst$2134$error_DOT_import_SLASH_invalid_json_data$$,
$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.invalid-json")}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4590$error_DOT_style_dictionary_SLASH_invalid_token_value_opacity$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71765_SHARP_$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.invalid-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71765_SHARP_$$]))),"."].join(""),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.opacity-range")],null))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$APP.$cljs$cst$4591$error_DOT_token_SLASH_direct_self_reference$$,
$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.self-reference")}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4592$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_type$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71773_SHARP_$$){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.invalid-shadow-type-token-value",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71773_SHARP_$$]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$APP.$cljs$cst$4593$error_DOT_token_SLASH_name_collision$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71762_SHARP_$$){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.name-collision",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71762_SHARP_$$])))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4594$error_DOT_style_dictionary_SLASH_invalid_token_value_shadow_blur$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.shadow-blur-range")}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$APP.$cljs$cst$4595$error_DOT_style_dictionary_SLASH_missing_reference$$,$APP.$cljs$cst$884$error_SLASH_fn$$,
function($p1__71763_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.missing-references")),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$p1__71763_SHARP_$$))].join("")}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4596$error_DOT_style_dictionary_SLASH_invalid_token_value_stroke_width$$,
$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71766_SHARP_$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.invalid-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71766_SHARP_$$]))),"."].join(""),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.stroke-width-range")],
null))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4597$error_DOT_style_dictionary_SLASH_invalid_token_value_text_case$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71767_SHARP_$$){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.invalid-text-case-token-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71767_SHARP_$$]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4598$error_DOT_style_dictionary_SLASH_invalid_token_value_text_decoration$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71768_SHARP_$$){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.invalid-text-decoration-token-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71768_SHARP_$$]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4599$error_DOT_style_dictionary_SLASH_invalid_token_value_typography$$,
$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71771_SHARP_$$){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.invalid-token-value-typography",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__71771_SHARP_$$]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$945$error_SLASH_code$$,$cljs$cst$4600$error_DOT_import_SLASH_style_dictionary_reference_errors$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__71758_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.import-error")),
"\n\n",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($p1__71758_SHARP_$$))].join("")},$APP.$cljs$cst$4602$error_SLASH_detail$$,function($p1__71759_SHARP_$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n\n",$APP.$cljs$core$rest$$($p1__71759_SHARP_$$))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,$APP.$cljs$cst$4601$error_SLASH_unknown$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.unknown-error")}],
null)]);$APP.$app$common$logging$loggers$$.set("app.main.data.tokenscript",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1160$debug$$));var $app$main$data$tokenscript$config$$=$APP.$shadow$js$shim$module$0$0penpot$0tokenscript$$.makeConfig();var $app$main$data$workspace$tokens$warnings$warning_codes$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$4606$warning_DOT_style_dictionary_SLASH_invalid_referenced_token_value_opacity$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$4607$warning_SLASH_code$$,$cljs$cst$4606$warning_DOT_style_dictionary_SLASH_invalid_referenced_token_value_opacity$$,$cljs$cst$4608$warning_SLASH_fn$$,function($value$jscomp$630$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$630$$]))),"."].join(""),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.opacity-range")],null))}],null),$cljs$cst$4609$warning_DOT_style_dictionary_SLASH_invalid_referenced_token_value_stroke_width$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$4607$warning_SLASH_code$$,$cljs$cst$4609$warning_DOT_style_dictionary_SLASH_invalid_referenced_token_value_stroke_width$$,$cljs$cst$4608$warning_SLASH_fn$$,function($value$jscomp$631$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$value$jscomp$631$$]))),"."].join(""),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.stroke-width-range")],null))}],null),$cljs$cst$4610$warning_SLASH_unknown$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$4607$warning_SLASH_code$$,$cljs$cst$4610$warning_SLASH_unknown$$,$cljs$cst$4611$warning_SLASH_message$$,"Unknown warning"],null)],null);$APP.$app$common$logging$loggers$$.set("app.main.data.style-dictionary",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1160$debug$$));$shadow$js$shim$module$0$0tokens_studio$0sd_transforms$$.register($shadow$js$shim$module$0style_dictionary$0default$$);$shadow$js$shim$module$0style_dictionary$0default$$.registerTransformGroup({name:"penpot",transforms:$shadow$js$shim$module$0$0tokens_studio$0sd_transforms$$.getTransforms().concat(["ts/color/css/hexrgba","ts/color/modifiers","color/css"])});
$shadow$js$shim$module$0style_dictionary$0default$$.registerFormat({name:"custom/json",format:function($res$jscomp$inline_7303$$){return $res$jscomp$inline_7303$$.dictionary.tokens}});
$APP.$app$main$data$style_dictionary$default_config$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$4613$platforms$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$923$json$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$4614$transformGroup$$,"penpot",$APP.$cljs$cst$1916$files$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$954$format$$,"custom/json",
$APP.$cljs$cst$1967$destination$$,"penpot"],null)],null)],null)],null),$cljs$cst$4615$preprocessors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["tokens-studio"],null),$APP.$cljs$cst$3029$log$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4616$verbosity$$,"silent",$cljs$cst$4617$warnings$$,"silent",$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$4618$brokenReferences$$,"console"],null)],null)],
null);$APP.$app$main$data$style_dictionary$StyleDictionary$$.prototype.$app$main$data$style_dictionary$IStyleDictionary$add_tokens$arity$2$=function($_$jscomp$2614$$,$tokens$jscomp$28$$){return new $APP.$app$main$data$style_dictionary$StyleDictionary$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.config,$APP.$cljs$cst$2100$tokens$$,$tokens$jscomp$28$$))};
$APP.$app$main$data$style_dictionary$StyleDictionary$$.prototype.$app$main$data$style_dictionary$IStyleDictionary$build_dictionary$arity$1$=function(){var $build_PLUS__config_SINGLEQUOTE_$$=$APP.$cljs$core$clj__GT_js$$(this.config);$build_PLUS__config_SINGLEQUOTE_$$=$APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$((new $shadow$js$shim$module$0style_dictionary$0default$$($build_PLUS__config_SINGLEQUOTE_$$)).buildAllPlatforms("json"),
function($p1__71971_SHARP_$$){return $p1__71971_SHARP_$$.getPlatformTokens("json")}),function($p1__71972_SHARP_$$){return $p1__71972_SHARP_$$.allTokens});return $APP.$beicon$v2$core$from$$($build_PLUS__config_SINGLEQUOTE_$$)};var $app$main$data$workspace$tokens$application$update_shape_rotation_72285$$,$app$main$data$workspace$tokens$application$update_fill_72299$$,$app$main$data$workspace$tokens$application$update_fill_stroke_72315$$,$app$main$data$workspace$tokens$application$update_layout_item_margin_72323$$,$app$main$data$workspace$tokens$application$update_layout_padding_72331$$,$app$main$data$workspace$tokens$application$update_shape_position_72341$$,$app$main$data$workspace$tokens$application$update_layout_gap_72344$$,
$app$main$data$workspace$tokens$application$update_layout_sizing_limits_72350$$,$app$main$data$workspace$tokens$application$generate_text_shape_update_72356$$,$app$main$data$workspace$tokens$application$generate_font_family_text_shape_update_72369$$,$app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update_72414$$,$app$main$data$workspace$tokens$application$update_shape_dimensions_72447$$,$app$main$data$workspace$tokens$application$apply_dimensions_token_72494$$,$app$main$data$workspace$tokens$application$apply_spacing_token_72514$$,
$app$main$data$workspace$tokens$application$apply_sizing_token_72526$$,$app$main$data$workspace$tokens$application$apply_token_72546$$,$app$main$data$workspace$tokens$application$apply_spacing_token_separated_72574$$,$app$main$data$workspace$tokens$application$unapply_token_72589$$,$app$main$data$workspace$tokens$application$on_toggle_token_72598$$,$app$main$data$workspace$tokens$application$attributes__GT_shape_update$$,$a$jscomp$inline_7350$$,$xs$jscomp$inline_7351$$;
$APP.$app$main$data$workspace$tokens$application$update_shape_radius$$=function $app$main$data$workspace$tokens$application$update_shape_radius$$($var_args$jscomp$1348$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_shape_radius$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_shape_radius$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$app$main$data$workspace$tokens$application$update_shape_radius$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$650$$,$shape_ids$jscomp$16$$,$attributes$jscomp$20$$){return $APP.$app$main$data$workspace$tokens$application$update_shape_radius$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$650$$,$shape_ids$jscomp$16$$,$attributes$jscomp$20$$,null)};
$APP.$app$main$data$workspace$tokens$application$update_shape_radius$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$651$$,$shape_ids$jscomp$17$$,$attributes$jscomp$21$$,$page_id$jscomp$281$$){if(typeof $value$jscomp$651$$==="number"){var $value__$1$jscomp$25$$=0>$value$jscomp$651$$?0:$value$jscomp$651$$;return $APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($shape_ids$jscomp$17$$,function($shape$jscomp$763$$){return $app$common$types$shape$radius$set_radius_for_corners$$($shape$jscomp$763$$,
$attributes$jscomp$21$$,$value__$1$jscomp$25$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3636$reg_objects_QMARK_$$,!0,$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$281$$,$APP.$cljs$cst$2645$attrs$$,$app$common$types$token$border_radius_keys$$],null))}return null};$APP.$app$main$data$workspace$tokens$application$update_shape_radius$$.$cljs$lang$maxFixedArity$=4;
$APP.$app$main$data$workspace$tokens$application$update_shape_radius_for_corners$$=function $app$main$data$workspace$tokens$application$update_shape_radius_for_corners$$($var_args$jscomp$1349$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_shape_radius_for_corners$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_shape_radius_for_corners$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],
arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$main$data$workspace$tokens$application$update_shape_radius_for_corners$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$652$$,$shape_ids$jscomp$18$$,$attributes$jscomp$22$$){return $APP.$app$main$data$workspace$tokens$application$update_shape_radius_for_corners$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$652$$,$shape_ids$jscomp$18$$,$attributes$jscomp$22$$,null)};
$APP.$app$main$data$workspace$tokens$application$update_shape_radius_for_corners$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$653$$,$shape_ids$jscomp$19$$,$attributes$jscomp$23$$,$page_id$jscomp$282$$){if(typeof $value$jscomp$653$$==="number"){var $value__$1$jscomp$26$$=0>$value$jscomp$653$$?0:$value$jscomp$653$$;return $APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($shape_ids$jscomp$19$$,function($shape$jscomp$764$$){return $app$common$types$shape$radius$set_radius_for_corners$$($shape$jscomp$764$$,
$attributes$jscomp$23$$,$value__$1$jscomp$26$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3636$reg_objects_QMARK_$$,!0,$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$282$$,$APP.$cljs$cst$2645$attrs$$,$app$common$types$token$border_radius_keys$$],null))}return null};$APP.$app$main$data$workspace$tokens$application$update_shape_radius_for_corners$$.$cljs$lang$maxFixedArity$=4;
var $app$main$data$workspace$tokens$application$update_opacity$$=function $app$main$data$workspace$tokens$application$update_opacity$$($var_args$jscomp$1350$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_opacity$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_opacity$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$data$workspace$tokens$application$update_opacity$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$654$$,$shape_ids$jscomp$20$$,$attributes$jscomp$24$$){return $app$main$data$workspace$tokens$application$update_opacity$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$654$$,$shape_ids$jscomp$20$$,$attributes$jscomp$24$$,null)};
$app$main$data$workspace$tokens$application$update_opacity$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$655$$,$shape_ids$jscomp$21$$,$_attributes$$,$page_id$jscomp$283$$){return 0<=$value$jscomp$655$$&&$value$jscomp$655$$<=1?$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($shape_ids$jscomp$21$$,function($p1__72280_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__72280_SHARP_$$,$APP.$cljs$cst$1734$opacity$$,$value$jscomp$655$$)},
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$283$$],null)):null};$app$main$data$workspace$tokens$application$update_opacity$$.$cljs$lang$maxFixedArity$=4;
$APP.$app$main$data$workspace$tokens$application$update_rotation$$=function $app$main$data$workspace$tokens$application$update_rotation$$($var_args$jscomp$1351$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_rotation$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_rotation$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$app$main$data$workspace$tokens$application$update_rotation$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$656$$,$shape_ids$jscomp$22$$,$attributes$jscomp$25$$){return $APP.$app$main$data$workspace$tokens$application$update_rotation$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$656$$,$shape_ids$jscomp$22$$,$attributes$jscomp$25$$,null)};
$APP.$app$main$data$workspace$tokens$application$update_rotation$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$657$$,$shape_ids$jscomp$23$$,$_attributes$jscomp$1$$,$page_id$jscomp$284$$){typeof $app$main$data$workspace$tokens$application$update_shape_rotation_72285$$==="undefined"&&($app$main$data$workspace$tokens$application$update_shape_rotation_72285$$=function($value$jscomp$658$$,$shape_ids$jscomp$24$$,$_attributes$jscomp$2$$,$page_id$jscomp$285$$,$meta72286$$){this.value=$value$jscomp$658$$;
this.$shape_ids$=$shape_ids$jscomp$24$$;this.$_attributes$=$_attributes$jscomp$2$$;this.$page_id$=$page_id$jscomp$285$$;this.$meta72286$=$meta72286$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$update_shape_rotation_72285$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_shape_rotation_72285$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4628$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_shape_rotation$$},$app$main$data$workspace$tokens$application$update_shape_rotation_72285$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72287$$,$meta72286__$1$$){return new $app$main$data$workspace$tokens$application$update_shape_rotation_72285$$(this.value,this.$shape_ids$,this.$_attributes$,this.$page_id$,$meta72286__$1$$)},$app$main$data$workspace$tokens$application$update_shape_rotation_72285$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72286$},$app$main$data$workspace$tokens$application$update_shape_rotation_72285$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_shape_rotation_72285$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return typeof this.value==="number"?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$(this.$shape_ids$),$APP.$app$main$data$workspace$increase_rotation$$.$cljs$core$IFn$_invoke$arity$variadic$(this.$shape_ids$,
this.value,null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2043$page_id$$,this.$page_id$,$APP.$cljs$cst$2556$ignore_touched$$,!0,$cljs$cst$3864$no_wasm_QMARK_$$,!0],null)]))):null});return new $app$main$data$workspace$tokens$application$update_shape_rotation_72285$$($value$jscomp$657$$,$shape_ids$jscomp$23$$,$_attributes$jscomp$1$$,$page_id$jscomp$284$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$application$update_rotation$$.$cljs$lang$maxFixedArity$=4;
$APP.$app$main$data$workspace$tokens$application$update_stroke_width$$=function $app$main$data$workspace$tokens$application$update_stroke_width$$($var_args$jscomp$1352$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_stroke_width$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_stroke_width$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$app$main$data$workspace$tokens$application$update_stroke_width$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$659$$,$shape_ids$jscomp$25$$,$attributes$jscomp$26$$){return $APP.$app$main$data$workspace$tokens$application$update_stroke_width$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$659$$,$shape_ids$jscomp$25$$,$attributes$jscomp$26$$,null)};
$APP.$app$main$data$workspace$tokens$application$update_stroke_width$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$660$$,$shape_ids$jscomp$26$$,$_attributes$jscomp$3$$,$page_id$jscomp$286$$){return typeof $value$jscomp$660$$==="number"?$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($shape_ids$jscomp$26$$,function($shape$jscomp$765$$){if($APP.$cljs$core$seq$$($APP.$cljs$cst$1636$strokes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$765$$)))return $APP.$cljs$core$assoc_in$$($shape$jscomp$765$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$,0,$APP.$cljs$cst$1655$stroke_width$$],null),$value$jscomp$660$$);var $stroke$jscomp$28$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$types$stroke$default_stroke$$,$APP.$cljs$cst$1655$stroke_width$$,$value$jscomp$660$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$765$$,$APP.$cljs$cst$1636$strokes$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$stroke$jscomp$28$$],null))},new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3636$reg_objects_QMARK_$$,!0,$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$286$$,$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$strokes$$],null)],null)):null};
$APP.$app$main$data$workspace$tokens$application$update_stroke_width$$.$cljs$lang$maxFixedArity$=4;
$APP.$app$main$data$workspace$tokens$application$update_fill$$=function $app$main$data$workspace$tokens$application$update_fill$$($var_args$jscomp$1353$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_fill$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_fill$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$app$main$data$workspace$tokens$application$update_fill$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$662$$,$shape_ids$jscomp$28$$,$attributes$jscomp$27$$){return $APP.$app$main$data$workspace$tokens$application$update_fill$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$662$$,$shape_ids$jscomp$28$$,$attributes$jscomp$27$$,null)};
$APP.$app$main$data$workspace$tokens$application$update_fill$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$663$$,$shape_ids$jscomp$29$$,$_attributes$jscomp$4$$,$page_id$jscomp$288$$){typeof $app$main$data$workspace$tokens$application$update_fill_72299$$==="undefined"&&($app$main$data$workspace$tokens$application$update_fill_72299$$=function($value$jscomp$664$$,$shape_ids$jscomp$30$$,$_attributes$jscomp$5$$,$page_id$jscomp$289$$,$meta72300$$){this.value=$value$jscomp$664$$;this.$shape_ids$=
$shape_ids$jscomp$30$$;this.$_attributes$=$_attributes$jscomp$5$$;this.$page_id$=$page_id$jscomp$289$$;this.$meta72300$=$meta72300$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$update_fill_72299$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_fill_72299$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4629$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_fill$$},
$app$main$data$workspace$tokens$application$update_fill_72299$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72301$$,$meta72300__$1$$){return new $app$main$data$workspace$tokens$application$update_fill_72299$$(this.value,this.$shape_ids$,this.$_attributes$,this.$page_id$,$meta72300__$1$$)},$app$main$data$workspace$tokens$application$update_fill_72299$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72300$},$app$main$data$workspace$tokens$application$update_fill_72299$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_fill_72299$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2620_temp__5825__auto__$jscomp$235$$,$state$jscomp$942$$){$_$jscomp$2620_temp__5825__auto__$jscomp$235$$=$APP.$app$main$data$workspace$tokens$application$value__GT_color$$(this.value);return $APP.$cljs$core$truth_$$($_$jscomp$2620_temp__5825__auto__$jscomp$235$$)?$APP.$app$main$data$workspace$colors$transform_fill$cljs$0core$0IFn$0_invoke$0arity$05$$($state$jscomp$942$$,
this.$shape_ids$,$_$jscomp$2620_temp__5825__auto__$jscomp$235$$,function($p1__72295_SHARP_$$,$p2__72296_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__72295_SHARP_$$,$APP.$cljs$cst$1634$fills$$,$app$common$types$fills$assoc$$,0,$p2__72296_SHARP_$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,this.$page_id$],null)):null});return new $app$main$data$workspace$tokens$application$update_fill_72299$$($value$jscomp$663$$,
$shape_ids$jscomp$29$$,$_attributes$jscomp$4$$,$page_id$jscomp$288$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$main$data$workspace$tokens$application$update_fill$$.$cljs$lang$maxFixedArity$=4;
$APP.$app$main$data$workspace$tokens$application$update_stroke_color$$=function $app$main$data$workspace$tokens$application$update_stroke_color$$($var_args$jscomp$1354$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_stroke_color$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_stroke_color$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$app$main$data$workspace$tokens$application$update_stroke_color$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$665$$,$shape_ids$jscomp$31$$,$attributes$jscomp$28$$){return $APP.$app$main$data$workspace$tokens$application$update_stroke_color$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$665$$,$shape_ids$jscomp$31$$,$attributes$jscomp$28$$,null)};
$APP.$app$main$data$workspace$tokens$application$update_stroke_color$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$666$$,$shape_ids$jscomp$32$$,$_attributes$jscomp$6$$,$page_id$jscomp$290$$){var $temp__5825__auto__$jscomp$236$$=$APP.$app$main$data$workspace$tokens$application$value__GT_color$$($value$jscomp$666$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$236$$)?$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($shape_ids$jscomp$32$$,
function($p1__72303_SHARP_$$){return $app$main$data$workspace$colors$update_shape_stroke_color$$($p1__72303_SHARP_$$,0,$temp__5825__auto__$jscomp$236$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$290$$,$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$3521$changed_sub_attr$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1739$stroke_color$$],null)],null)):null};
$APP.$app$main$data$workspace$tokens$application$update_stroke_color$$.$cljs$lang$maxFixedArity$=4;
var $app$main$data$workspace$tokens$application$update_shadow$$=function $app$main$data$workspace$tokens$application$update_shadow$$($var_args$jscomp$1355$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_shadow$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_shadow$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$data$workspace$tokens$application$update_shadow$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$668$$,$shape_ids$jscomp$33$$,$attributes$jscomp$29$$){return $app$main$data$workspace$tokens$application$update_shadow$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$668$$,$shape_ids$jscomp$33$$,$attributes$jscomp$29$$,null)};
$app$main$data$workspace$tokens$application$update_shadow$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$669$$,$shape_ids$jscomp$34$$,$_attributes$jscomp$7$$,$page_id$jscomp$291$$){if($APP.$cljs$core$sequential_QMARK_$$($value$jscomp$669$$)){var $shadows$jscomp$3$$=$app$main$data$workspace$tokens$application$value__GT_shadow$$($value$jscomp$669$$);return $APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($shape_ids$jscomp$34$$,function($p1__72310_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__72310_SHARP_$$,
$APP.$cljs$cst$1654$shadow$$,$shadows$jscomp$3$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3636$reg_objects_QMARK_$$,!0,$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$291$$,$APP.$cljs$cst$2645$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1654$shadow$$],null)],null))}return null};
$app$main$data$workspace$tokens$application$update_shadow$$.$cljs$lang$maxFixedArity$=4;
var $app$main$data$workspace$tokens$application$update_fill_stroke$$=function $app$main$data$workspace$tokens$application$update_fill_stroke$$($var_args$jscomp$1356$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_fill_stroke$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_fill_stroke$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$data$workspace$tokens$application$update_fill_stroke$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$670$$,$shape_ids$jscomp$35$$,$attributes$jscomp$30$$){return $app$main$data$workspace$tokens$application$update_fill_stroke$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$670$$,$shape_ids$jscomp$35$$,$attributes$jscomp$30$$,null)};
$app$main$data$workspace$tokens$application$update_fill_stroke$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$671$$,$shape_ids$jscomp$36$$,$attributes$jscomp$31$$,$page_id$jscomp$292$$){typeof $app$main$data$workspace$tokens$application$update_fill_stroke_72315$$==="undefined"&&($app$main$data$workspace$tokens$application$update_fill_stroke_72315$$=function($value$jscomp$672$$,$shape_ids$jscomp$37$$,$attributes$jscomp$32$$,$page_id$jscomp$293$$,$meta72316$$){this.value=$value$jscomp$672$$;
this.$shape_ids$=$shape_ids$jscomp$37$$;this.attributes=$attributes$jscomp$32$$;this.$page_id$=$page_id$jscomp$293$$;this.$meta72316$=$meta72316$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$update_fill_stroke_72315$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_fill_stroke_72315$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4630$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_fill_stroke$$},
$app$main$data$workspace$tokens$application$update_fill_stroke_72315$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72317$$,$meta72316__$1$$){return new $app$main$data$workspace$tokens$application$update_fill_stroke_72315$$(this.value,this.$shape_ids$,this.attributes,this.$page_id$,$meta72316__$1$$)},$app$main$data$workspace$tokens$application$update_fill_stroke_72315$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72316$},$app$main$data$workspace$tokens$application$update_fill_stroke_72315$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_fill_stroke_72315$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$truth_$$($APP.$cljs$cst$1403$fill$$.$cljs$core$IFn$_invoke$arity$1$(this.attributes))?$APP.$app$main$data$workspace$tokens$application$update_fill$$.$cljs$core$IFn$_invoke$arity$4$(this.value,this.$shape_ids$,this.attributes,this.$page_id$):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1739$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$(this.attributes))?
$APP.$app$main$data$workspace$tokens$application$update_stroke_color$$.$cljs$core$IFn$_invoke$arity$4$(this.value,this.$shape_ids$,this.attributes,this.$page_id$):null)});return new $app$main$data$workspace$tokens$application$update_fill_stroke_72315$$($value$jscomp$671$$,$shape_ids$jscomp$36$$,$attributes$jscomp$31$$,$page_id$jscomp$292$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$tokens$application$update_fill_stroke$$.$cljs$lang$maxFixedArity$=4;
$APP.$app$main$data$workspace$tokens$application$update_layout_item_margin$$=function $app$main$data$workspace$tokens$application$update_layout_item_margin$$($var_args$jscomp$1357$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_layout_item_margin$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_layout_item_margin$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],
arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$main$data$workspace$tokens$application$update_layout_item_margin$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$674$$,$shape_ids$jscomp$40$$,$attrs$jscomp$157$$){return $APP.$app$main$data$workspace$tokens$application$update_layout_item_margin$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$674$$,$shape_ids$jscomp$40$$,$attrs$jscomp$157$$,null)};
$APP.$app$main$data$workspace$tokens$application$update_layout_item_margin$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$675$$,$shape_ids$jscomp$41$$,$attrs$jscomp$158$$,$page_id$jscomp$296$$){typeof $app$main$data$workspace$tokens$application$update_layout_item_margin_72323$$==="undefined"&&($app$main$data$workspace$tokens$application$update_layout_item_margin_72323$$=function($value$jscomp$676$$,$shape_ids$jscomp$42$$,$attrs$jscomp$159$$,$page_id$jscomp$297$$,$meta72324$$){this.value=
$value$jscomp$676$$;this.$shape_ids$=$shape_ids$jscomp$42$$;this.$attrs$=$attrs$jscomp$159$$;this.$page_id$=$page_id$jscomp$297$$;this.$meta72324$=$meta72324$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$update_layout_item_margin_72323$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_layout_item_margin_72323$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4631$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_layout_item_margin$$},$app$main$data$workspace$tokens$application$update_layout_item_margin_72323$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72325$$,$meta72324__$1$$){return new $app$main$data$workspace$tokens$application$update_layout_item_margin_72323$$(this.value,this.$shape_ids$,this.$attrs$,this.$page_id$,$meta72324__$1$$)},$app$main$data$workspace$tokens$application$update_layout_item_margin_72323$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72324$},$app$main$data$workspace$tokens$application$update_layout_item_margin_72323$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_layout_item_margin_72323$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_inline_result$jscomp$1308__$jscomp$2622_or__5025__auto__$jscomp$inline_7340$$,$ids_with_layout_parent_state$jscomp$945$$){return typeof this.value==="number"?($JSCompiler_inline_result$jscomp$1308__$jscomp$2622_or__5025__auto__$jscomp$inline_7340$$=
this.$page_id$,$JSCompiler_inline_result$jscomp$1308__$jscomp$2622_or__5025__auto__$jscomp$inline_7340$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1308__$jscomp$2622_or__5025__auto__$jscomp$inline_7340$$)?$JSCompiler_inline_result$jscomp$1308__$jscomp$2622_or__5025__auto__$jscomp$inline_7340$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($ids_with_layout_parent_state$jscomp$945$$),$ids_with_layout_parent_state$jscomp$945$$=$app$main$data$workspace$tokens$application$shape_ids_with_layout_parent$$($ids_with_layout_parent_state$jscomp$945$$,
$JSCompiler_inline_result$jscomp$1308__$jscomp$2622_or__5025__auto__$jscomp$inline_7340$$,this.$shape_ids$),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$03$$($ids_with_layout_parent_state$jscomp$945$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1699$layout_item_margin$$,$APP.$cljs$core$zipmap$$(this.$attrs$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$(this.value))],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,this.$page_id$],null)))):null});return new $app$main$data$workspace$tokens$application$update_layout_item_margin_72323$$($value$jscomp$675$$,$shape_ids$jscomp$41$$,$attrs$jscomp$158$$,$page_id$jscomp$296$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$main$data$workspace$tokens$application$update_layout_item_margin$$.$cljs$lang$maxFixedArity$=4;
$APP.$app$main$data$workspace$tokens$application$update_layout_padding$$=function $app$main$data$workspace$tokens$application$update_layout_padding$$($var_args$jscomp$1358$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_layout_padding$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_layout_padding$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],
arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$app$main$data$workspace$tokens$application$update_layout_padding$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$677$$,$shape_ids$jscomp$43$$,$attrs$jscomp$160$$){return $APP.$app$main$data$workspace$tokens$application$update_layout_padding$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$677$$,$shape_ids$jscomp$43$$,$attrs$jscomp$160$$,null)};
$APP.$app$main$data$workspace$tokens$application$update_layout_padding$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$678$$,$shape_ids$jscomp$44$$,$attrs$jscomp$161$$,$page_id$jscomp$298$$){typeof $app$main$data$workspace$tokens$application$update_layout_padding_72331$$==="undefined"&&($app$main$data$workspace$tokens$application$update_layout_padding_72331$$=function($value$jscomp$679$$,$shape_ids$jscomp$45$$,$attrs$jscomp$162$$,$page_id$jscomp$299$$,$meta72332$$){this.value=$value$jscomp$679$$;
this.$shape_ids$=$shape_ids$jscomp$45$$;this.$attrs$=$attrs$jscomp$162$$;this.$page_id$=$page_id$jscomp$299$$;this.$meta72332$=$meta72332$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$update_layout_padding_72331$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_layout_padding_72331$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4632$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_layout_padding$$},
$app$main$data$workspace$tokens$application$update_layout_padding_72331$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72333$$,$meta72332__$1$$){return new $app$main$data$workspace$tokens$application$update_layout_padding_72331$$(this.value,this.$shape_ids$,this.$attrs$,this.$page_id$,$meta72332__$1$$)},$app$main$data$workspace$tokens$application$update_layout_padding_72331$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72332$},$app$main$data$workspace$tokens$application$update_layout_padding_72331$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_layout_padding_72331$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_inline_result$jscomp$1309__$jscomp$2623_or__5025__auto__$jscomp$inline_7342$$,$ids_with_layout_state$jscomp$946$$){return typeof this.value==="number"?($JSCompiler_inline_result$jscomp$1309__$jscomp$2623_or__5025__auto__$jscomp$inline_7342$$=this.$page_id$,$JSCompiler_inline_result$jscomp$1309__$jscomp$2623_or__5025__auto__$jscomp$inline_7342$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1309__$jscomp$2623_or__5025__auto__$jscomp$inline_7342$$)?$JSCompiler_inline_result$jscomp$1309__$jscomp$2623_or__5025__auto__$jscomp$inline_7342$$:$APP.$cljs$cst$1918$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($ids_with_layout_state$jscomp$946$$),$ids_with_layout_state$jscomp$946$$=$app$main$data$workspace$tokens$application$shape_ids_with_layout$$($ids_with_layout_state$jscomp$946$$,$JSCompiler_inline_result$jscomp$1309__$jscomp$2623_or__5025__auto__$jscomp$inline_7342$$,
this.$shape_ids$),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$03$$($ids_with_layout_state$jscomp$946$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$layout_padding$$,$APP.$cljs$core$zipmap$$(this.$attrs$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$(this.value))],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,this.$page_id$],
null)))):null});return new $app$main$data$workspace$tokens$application$update_layout_padding_72331$$($value$jscomp$678$$,$shape_ids$jscomp$44$$,$attrs$jscomp$161$$,$page_id$jscomp$298$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$main$data$workspace$tokens$application$update_layout_padding$$.$cljs$lang$maxFixedArity$=4;
$APP.$app$main$data$workspace$tokens$application$update_shape_position$$=function $app$main$data$workspace$tokens$application$update_shape_position$$($var_args$jscomp$1359$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_shape_position$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_shape_position$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],
arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$app$main$data$workspace$tokens$application$update_shape_position$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$680$$,$shape_ids$jscomp$46$$,$attributes$jscomp$34$$){return $APP.$app$main$data$workspace$tokens$application$update_shape_position$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$680$$,$shape_ids$jscomp$46$$,$attributes$jscomp$34$$,null)};
$APP.$app$main$data$workspace$tokens$application$update_shape_position$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$681$$,$shape_ids$jscomp$47$$,$attributes$jscomp$35$$,$page_id$jscomp$300$$){typeof $app$main$data$workspace$tokens$application$update_shape_position_72341$$==="undefined"&&($app$main$data$workspace$tokens$application$update_shape_position_72341$$=function($value$jscomp$682$$,$shape_ids$jscomp$48$$,$attributes$jscomp$36$$,$page_id$jscomp$301$$,$meta72342$$){this.value=$value$jscomp$682$$;
this.$shape_ids$=$shape_ids$jscomp$48$$;this.attributes=$attributes$jscomp$36$$;this.$page_id$=$page_id$jscomp$301$$;this.$meta72342$=$meta72342$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$update_shape_position_72341$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_shape_position_72341$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4633$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_shape_position$$},$app$main$data$workspace$tokens$application$update_shape_position_72341$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72343$$,$meta72342__$1$$){return new $app$main$data$workspace$tokens$application$update_shape_position_72341$$(this.value,this.$shape_ids$,this.attributes,this.$page_id$,$meta72342__$1$$)},$app$main$data$workspace$tokens$application$update_shape_position_72341$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72342$},$app$main$data$workspace$tokens$application$update_shape_position_72341$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_shape_position_72341$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2624$$,$state$jscomp$947$$){var $self__$jscomp$6466$$=this;if(typeof $self__$jscomp$6466$$.value==="number"){var $page_id__$1$jscomp$20$$=function(){var $or__5025__auto__$jscomp$881$$=
$self__$jscomp$6466$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$881$$)?$or__5025__auto__$jscomp$881$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$947$$,$APP.$cljs$cst$1918$current_page_id$$)}();return $APP.$beicon$v2$core$map$$(function($p1__72336_SHARP_$$){return $app$main$data$workspace$transforms$update_position$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__72336_SHARP_$$,$APP.$cljs$core$zipmap$$($self__$jscomp$6466$$.attributes,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$($self__$jscomp$6466$$.value)),
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,$page_id__$1$jscomp$20$$,$cljs$cst$3864$no_wasm_QMARK_$$,!0],null))},$APP.$beicon$v2$core$from$$($self__$jscomp$6466$$.$shape_ids$))}return null});return new $app$main$data$workspace$tokens$application$update_shape_position_72341$$($value$jscomp$681$$,$shape_ids$jscomp$47$$,$attributes$jscomp$35$$,$page_id$jscomp$300$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$app$main$data$workspace$tokens$application$update_shape_position$$.$cljs$lang$maxFixedArity$=4;
$APP.$app$main$data$workspace$tokens$application$update_layout_sizing_limits$$=function $app$main$data$workspace$tokens$application$update_layout_sizing_limits$$($var_args$jscomp$1360$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_layout_sizing_limits$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_layout_sizing_limits$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],
arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$main$data$workspace$tokens$application$update_layout_sizing_limits$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$685$$,$shape_ids$jscomp$51$$,$attributes$jscomp$39$$){return $APP.$app$main$data$workspace$tokens$application$update_layout_sizing_limits$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$685$$,$shape_ids$jscomp$51$$,$attributes$jscomp$39$$,null)};
$APP.$app$main$data$workspace$tokens$application$update_layout_sizing_limits$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$686$$,$shape_ids$jscomp$52$$,$attributes$jscomp$40$$,$page_id$jscomp$304$$){typeof $app$main$data$workspace$tokens$application$update_layout_sizing_limits_72350$$==="undefined"&&($app$main$data$workspace$tokens$application$update_layout_sizing_limits_72350$$=function($value$jscomp$687$$,$shape_ids$jscomp$53$$,$attributes$jscomp$41$$,$page_id$jscomp$305$$,$meta72351$$){this.value=
$value$jscomp$687$$;this.$shape_ids$=$shape_ids$jscomp$53$$;this.attributes=$attributes$jscomp$41$$;this.$page_id$=$page_id$jscomp$305$$;this.$meta72351$=$meta72351$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$update_layout_sizing_limits_72350$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_layout_sizing_limits_72350$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4635$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_update_layout_sizing_limits$$},$app$main$data$workspace$tokens$application$update_layout_sizing_limits_72350$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72352$$,$meta72351__$1$$){return new $app$main$data$workspace$tokens$application$update_layout_sizing_limits_72350$$(this.value,this.$shape_ids$,this.attributes,this.$page_id$,$meta72351__$1$$)},$app$main$data$workspace$tokens$application$update_layout_sizing_limits_72350$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72351$},$app$main$data$workspace$tokens$application$update_layout_sizing_limits_72350$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$update_layout_sizing_limits_72350$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){if(typeof this.value==="number"){var $props$jscomp$217$$=$APP.$cljs$core$select_keys$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1707$layout_item_min_w$$,
this.value,$APP.$cljs$cst$1705$layout_item_min_h$$,this.value,$APP.$cljs$cst$1706$layout_item_max_w$$,this.value,$APP.$cljs$cst$1704$layout_item_max_h$$,this.value],null),this.attributes);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$03$$(this.$shape_ids$,$props$jscomp$217$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2556$ignore_touched$$,!0,$APP.$cljs$cst$2043$page_id$$,this.$page_id$],null)))}return null});
return new $app$main$data$workspace$tokens$application$update_layout_sizing_limits_72350$$($value$jscomp$686$$,$shape_ids$jscomp$52$$,$attributes$jscomp$40$$,$page_id$jscomp$304$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$main$data$workspace$tokens$application$update_layout_sizing_limits$$.$cljs$lang$maxFixedArity$=4;
$APP.$app$main$data$workspace$tokens$application$update_line_height$$=function $app$main$data$workspace$tokens$application$update_line_height$$($var_args$jscomp$1361$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_line_height$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_line_height$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$app$main$data$workspace$tokens$application$update_line_height$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$688$$,$shape_ids$jscomp$56$$,$attributes$jscomp$42$$){return $APP.$app$main$data$workspace$tokens$application$update_line_height$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$688$$,$shape_ids$jscomp$56$$,$attributes$jscomp$42$$,null)};
$APP.$app$main$data$workspace$tokens$application$update_line_height$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$689$$,$shape_ids$jscomp$57$$,$_attributes$jscomp$8$$,$page_id$jscomp$308$$){return typeof $value$jscomp$689$$==="number"?$app$main$data$workspace$tokens$application$generate_text_shape_update$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1765$line_height$$,$value$jscomp$689$$],null),$shape_ids$jscomp$57$$,$page_id$jscomp$308$$):null};
$APP.$app$main$data$workspace$tokens$application$update_line_height$$.$cljs$lang$maxFixedArity$=4;
var $app$main$data$workspace$tokens$application$update_letter_spacing$$=function $app$main$data$workspace$tokens$application$update_letter_spacing$$($var_args$jscomp$1362$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_letter_spacing$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_letter_spacing$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],
arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$data$workspace$tokens$application$update_letter_spacing$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$690$$,$shape_ids$jscomp$58$$,$attributes$jscomp$43$$){return $app$main$data$workspace$tokens$application$update_letter_spacing$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$690$$,$shape_ids$jscomp$58$$,$attributes$jscomp$43$$,null)};
$app$main$data$workspace$tokens$application$update_letter_spacing$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$691$$,$shape_ids$jscomp$59$$,$_attributes$jscomp$9$$,$page_id$jscomp$309$$){return typeof $value$jscomp$691$$==="number"?$app$main$data$workspace$tokens$application$generate_text_shape_update$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$691$$)],null),$shape_ids$jscomp$59$$,
$page_id$jscomp$309$$):null};$app$main$data$workspace$tokens$application$update_letter_spacing$$.$cljs$lang$maxFixedArity$=4;
var $app$main$data$workspace$tokens$application$update_font_family$$=function $app$main$data$workspace$tokens$application$update_font_family$$($var_args$jscomp$1363$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_font_family$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_font_family$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$data$workspace$tokens$application$update_font_family$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$693$$,$shape_ids$jscomp$62$$,$attributes$jscomp$44$$){return $app$main$data$workspace$tokens$application$update_font_family$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$693$$,$shape_ids$jscomp$62$$,$attributes$jscomp$44$$,null)};
$app$main$data$workspace$tokens$application$update_font_family$$.$cljs$core$IFn$_invoke$arity$4$=function($temp__5825__auto__$jscomp$237_value$jscomp$694$$,$shape_ids$jscomp$63$$,$_attributes$jscomp$10$$,$page_id$jscomp$312$$){$temp__5825__auto__$jscomp$237_value$jscomp$694$$=$app$main$data$workspace$tokens$application$create_font_family_text_attrs$$($temp__5825__auto__$jscomp$237_value$jscomp$694$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$237_value$jscomp$694$$)?$app$main$data$workspace$tokens$application$generate_font_family_text_shape_update$$($temp__5825__auto__$jscomp$237_value$jscomp$694$$,
$shape_ids$jscomp$63$$,$page_id$jscomp$312$$,null):null};$app$main$data$workspace$tokens$application$update_font_family$$.$cljs$lang$maxFixedArity$=4;
var $app$main$data$workspace$tokens$application$update_font_family_interactive$$=function $app$main$data$workspace$tokens$application$update_font_family_interactive$$($var_args$jscomp$1364$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_font_family_interactive$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_font_family_interactive$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],
arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$main$data$workspace$tokens$application$update_font_family_interactive$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$695$$,$shape_ids$jscomp$64$$,$attributes$jscomp$45$$){return $app$main$data$workspace$tokens$application$update_font_family_interactive$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$695$$,$shape_ids$jscomp$64$$,$attributes$jscomp$45$$,null)};
$app$main$data$workspace$tokens$application$update_font_family_interactive$$.$cljs$core$IFn$_invoke$arity$4$=function($temp__5825__auto__$jscomp$238_value$jscomp$696$$,$shape_ids$jscomp$65$$,$_attributes$jscomp$11$$,$page_id$jscomp$313$$){$temp__5825__auto__$jscomp$238_value$jscomp$696$$=$app$main$data$workspace$tokens$application$create_font_family_text_attrs$$($temp__5825__auto__$jscomp$238_value$jscomp$696$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$238_value$jscomp$696$$)?$app$main$data$workspace$tokens$application$generate_font_family_text_shape_update$$($temp__5825__auto__$jscomp$238_value$jscomp$696$$,
$shape_ids$jscomp$65$$,$page_id$jscomp$313$$,$app$main$data$workspace$tokens$application$warn_font_variant_not_found_BANG_$$):null};$app$main$data$workspace$tokens$application$update_font_family_interactive$$.$cljs$lang$maxFixedArity$=4;
var $app$main$data$workspace$tokens$application$update_font_size$$=function $app$main$data$workspace$tokens$application$update_font_size$$($var_args$jscomp$1365$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_font_size$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_font_size$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$data$workspace$tokens$application$update_font_size$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$697$$,$shape_ids$jscomp$66$$,$attributes$jscomp$46$$){return $app$main$data$workspace$tokens$application$update_font_size$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$697$$,$shape_ids$jscomp$66$$,$attributes$jscomp$46$$,null)};
$app$main$data$workspace$tokens$application$update_font_size$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$698$$,$shape_ids$jscomp$67$$,$_attributes$jscomp$12$$,$page_id$jscomp$314$$){return typeof $value$jscomp$698$$==="number"?$app$main$data$workspace$tokens$application$generate_text_shape_update$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$698$$)],null),$shape_ids$jscomp$67$$,$page_id$jscomp$314$$):
null};$app$main$data$workspace$tokens$application$update_font_size$$.$cljs$lang$maxFixedArity$=4;
var $app$main$data$workspace$tokens$application$update_text_case$$=function $app$main$data$workspace$tokens$application$update_text_case$$($var_args$jscomp$1366$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_text_case$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_text_case$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$data$workspace$tokens$application$update_text_case$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$699$$,$shape_ids$jscomp$68$$,$attributes$jscomp$47$$){return $app$main$data$workspace$tokens$application$update_text_case$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$699$$,$shape_ids$jscomp$68$$,$attributes$jscomp$47$$,null)};
$app$main$data$workspace$tokens$application$update_text_case$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$700$$,$shape_ids$jscomp$69$$,$_attributes$jscomp$13$$,$page_id$jscomp$315$$){return typeof $value$jscomp$700$$==="string"?$app$main$data$workspace$tokens$application$generate_text_shape_update$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1769$text_transform$$,$value$jscomp$700$$],null),$shape_ids$jscomp$69$$,$page_id$jscomp$315$$):null};
$app$main$data$workspace$tokens$application$update_text_case$$.$cljs$lang$maxFixedArity$=4;
var $app$main$data$workspace$tokens$application$update_text_decoration$$=function $app$main$data$workspace$tokens$application$update_text_decoration$$($var_args$jscomp$1367$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_text_decoration$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_text_decoration$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],
arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$data$workspace$tokens$application$update_text_decoration$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$701$$,$shape_ids$jscomp$70$$,$attributes$jscomp$48$$){return $app$main$data$workspace$tokens$application$update_text_decoration$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$701$$,$shape_ids$jscomp$70$$,$attributes$jscomp$48$$,null)};
$app$main$data$workspace$tokens$application$update_text_decoration$$.$cljs$core$IFn$_invoke$arity$4$=function($JSCompiler_inline_result$jscomp$1312_value$jscomp$702$$,$JSCompiler_temp$jscomp$1311_shape_ids$jscomp$71$$,$_attributes$jscomp$14$$,$page_id$jscomp$316$$){if($APP.$cljs$core$truth_$$($app$common$types$token$valid_text_decoration$$($JSCompiler_inline_result$jscomp$1312_value$jscomp$702$$))){switch($JSCompiler_inline_result$jscomp$1312_value$jscomp$702$$){case "strike-through":$JSCompiler_inline_result$jscomp$1312_value$jscomp$702$$=
"line-through"}$JSCompiler_temp$jscomp$1311_shape_ids$jscomp$71$$=$app$main$data$workspace$tokens$application$generate_text_shape_update$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1768$text_decoration$$,$JSCompiler_inline_result$jscomp$1312_value$jscomp$702$$],null),$JSCompiler_temp$jscomp$1311_shape_ids$jscomp$71$$,$page_id$jscomp$316$$)}else $JSCompiler_temp$jscomp$1311_shape_ids$jscomp$71$$=null;return $JSCompiler_temp$jscomp$1311_shape_ids$jscomp$71$$};
$app$main$data$workspace$tokens$application$update_text_decoration$$.$cljs$lang$maxFixedArity$=4;
var $app$main$data$workspace$tokens$application$update_text_decoration_interactive$$=function $app$main$data$workspace$tokens$application$update_text_decoration_interactive$$($var_args$jscomp$1368$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_text_decoration_interactive$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_text_decoration_interactive$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],
arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$main$data$workspace$tokens$application$update_text_decoration_interactive$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$703$$,$shape_ids$jscomp$72$$,$attributes$jscomp$49$$){return $app$main$data$workspace$tokens$application$update_text_decoration_interactive$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$703$$,$shape_ids$jscomp$72$$,$attributes$jscomp$49$$,null)};
$app$main$data$workspace$tokens$application$update_text_decoration_interactive$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$704$$,$shape_ids$jscomp$73$$,$attributes$jscomp$50$$,$page_id$jscomp$317$$){return $APP.$cljs$core$truth_$$($app$common$types$token$valid_text_decoration$$($value$jscomp$704$$))?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4638$expand_text_more_options$$)),$app$main$data$workspace$tokens$application$update_text_decoration$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$704$$,
$shape_ids$jscomp$73$$,$attributes$jscomp$50$$,$page_id$jscomp$317$$)):null};$app$main$data$workspace$tokens$application$update_text_decoration_interactive$$.$cljs$lang$maxFixedArity$=4;
var $app$main$data$workspace$tokens$application$update_font_weight$$=function $app$main$data$workspace$tokens$application$update_font_weight$$($var_args$jscomp$1369$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_font_weight$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_font_weight$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$data$workspace$tokens$application$update_font_weight$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$705$$,$shape_ids$jscomp$76$$,$attributes$jscomp$51$$){return $app$main$data$workspace$tokens$application$update_font_weight$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$705$$,$shape_ids$jscomp$76$$,$attributes$jscomp$51$$,null)};
$app$main$data$workspace$tokens$application$update_font_weight$$.$cljs$core$IFn$_invoke$arity$4$=function($temp__5825__auto__$jscomp$239_value$jscomp$706$$,$shape_ids$jscomp$77$$,$_attributes$jscomp$15$$,$page_id$jscomp$320$$){$temp__5825__auto__$jscomp$239_value$jscomp$706$$=$app$common$types$token$valid_font_weight_variant$$($temp__5825__auto__$jscomp$239_value$jscomp$706$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$239_value$jscomp$706$$)?$app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update$$($temp__5825__auto__$jscomp$239_value$jscomp$706$$,
$shape_ids$jscomp$77$$,$page_id$jscomp$320$$,null):null};$app$main$data$workspace$tokens$application$update_font_weight$$.$cljs$lang$maxFixedArity$=4;
var $app$main$data$workspace$tokens$application$update_font_weight_interactive$$=function $app$main$data$workspace$tokens$application$update_font_weight_interactive$$($var_args$jscomp$1370$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_font_weight_interactive$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_font_weight_interactive$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],
arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$main$data$workspace$tokens$application$update_font_weight_interactive$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$707$$,$shape_ids$jscomp$78$$,$attributes$jscomp$52$$){return $app$main$data$workspace$tokens$application$update_font_weight_interactive$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$707$$,$shape_ids$jscomp$78$$,$attributes$jscomp$52$$,null)};
$app$main$data$workspace$tokens$application$update_font_weight_interactive$$.$cljs$core$IFn$_invoke$arity$4$=function($temp__5825__auto__$jscomp$240_value$jscomp$708$$,$shape_ids$jscomp$79$$,$_attributes$jscomp$16$$,$page_id$jscomp$321$$){$temp__5825__auto__$jscomp$240_value$jscomp$708$$=$app$common$types$token$valid_font_weight_variant$$($temp__5825__auto__$jscomp$240_value$jscomp$708$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$240_value$jscomp$708$$)?$app$main$data$workspace$tokens$application$generate_font_weight_text_shape_update$$($temp__5825__auto__$jscomp$240_value$jscomp$708$$,
$shape_ids$jscomp$79$$,$page_id$jscomp$321$$,$app$main$data$workspace$tokens$application$warn_font_variant_not_found_BANG_$$):null};$app$main$data$workspace$tokens$application$update_font_weight_interactive$$.$cljs$lang$maxFixedArity$=4;
$APP.$app$main$data$workspace$tokens$application$update_typography$$=function $app$main$data$workspace$tokens$application$update_typography$$($var_args$jscomp$1371$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$update_typography$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$update_typography$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$app$main$data$workspace$tokens$application$update_typography$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$709$$,$shape_ids$jscomp$80$$,$attributes$jscomp$53$$){return $APP.$app$main$data$workspace$tokens$application$update_typography$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$709$$,$shape_ids$jscomp$80$$,$attributes$jscomp$53$$,null)};
$APP.$app$main$data$workspace$tokens$application$update_typography$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$710$$,$shape_ids$jscomp$81$$,$attributes$jscomp$54$$,$page_id$jscomp$322$$){return $APP.$cljs$core$map_QMARK_$$($value$jscomp$710$$)?$APP.$beicon$v2$core$merge$$($app$main$data$workspace$tokens$application$apply_functions_map$$($value$jscomp$710$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_ids$jscomp$81$$,$attributes$jscomp$54$$,
$page_id$jscomp$322$$],null))):null};$APP.$app$main$data$workspace$tokens$application$update_typography$$.$cljs$lang$maxFixedArity$=4;
$APP.$app$main$data$workspace$tokens$application$apply_dimensions_token$$=function $app$main$data$workspace$tokens$application$apply_dimensions_token$$($var_args$jscomp$1373$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$apply_dimensions_token$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$apply_dimensions_token$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],
arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$main$data$workspace$tokens$application$apply_dimensions_token$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$715$$,$shape_ids$jscomp$86$$,$attributes$jscomp$59$$){return $APP.$app$main$data$workspace$tokens$application$apply_dimensions_token$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$715$$,$shape_ids$jscomp$86$$,$attributes$jscomp$59$$,null)};
$APP.$app$main$data$workspace$tokens$application$apply_dimensions_token$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$716$$,$shape_ids$jscomp$87$$,$attributes$jscomp$60$$,$page_id$jscomp$326$$){typeof $app$main$data$workspace$tokens$application$apply_dimensions_token_72494$$==="undefined"&&($app$main$data$workspace$tokens$application$apply_dimensions_token_72494$$=function($value$jscomp$717$$,$shape_ids$jscomp$88$$,$attributes$jscomp$61$$,$page_id$jscomp$327$$,$meta72495$$){this.value=
$value$jscomp$717$$;this.$shape_ids$=$shape_ids$jscomp$88$$;this.attributes=$attributes$jscomp$61$$;this.$page_id$=$page_id$jscomp$327$$;this.$meta72495$=$meta72495$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$apply_dimensions_token_72494$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_dimensions_token_72494$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4642$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_dimensions_token$$},$app$main$data$workspace$tokens$application$apply_dimensions_token_72494$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72496$$,$meta72495__$1$$){return new $app$main$data$workspace$tokens$application$apply_dimensions_token_72494$$(this.value,this.$shape_ids$,this.attributes,this.$page_id$,$meta72495__$1$$)},$app$main$data$workspace$tokens$application$apply_dimensions_token_72494$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72495$},$app$main$data$workspace$tokens$application$apply_dimensions_token_72494$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_dimensions_token_72494$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2633_actions$$,$state$jscomp$952$$){return typeof this.value==="number"?($_$jscomp$2633_actions$$=$app$main$data$workspace$tokens$application$attributes__GT_actions$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$260$value$$,this.value,$APP.$cljs$cst$4641$shape_ids$$,this.$shape_ids$,$APP.$cljs$cst$1993$attributes$$,this.attributes,$APP.$cljs$cst$2043$page_id$$,this.$page_id$,$APP.$cljs$cst$769$state$$,$state$jscomp$952$$],null)),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$beicon$v2$core$of$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__72476_SHARP_$$){return $p1__72476_SHARP_$$.$cljs$core$IFn$_invoke$arity$0$?$p1__72476_SHARP_$$.$cljs$core$IFn$_invoke$arity$0$():
$p1__72476_SHARP_$$()},$_$jscomp$2633_actions$$))):null});return new $app$main$data$workspace$tokens$application$apply_dimensions_token_72494$$($value$jscomp$716$$,$shape_ids$jscomp$87$$,$attributes$jscomp$60$$,$page_id$jscomp$326$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$app$main$data$workspace$tokens$application$apply_dimensions_token$$.$cljs$lang$maxFixedArity$=4;
var $app$main$data$workspace$tokens$application$apply_spacing_token$$=function $app$main$data$workspace$tokens$application$apply_spacing_token$$($var_args$jscomp$1374$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$apply_spacing_token$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$apply_spacing_token$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$data$workspace$tokens$application$apply_spacing_token$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$718$$,$shape_ids$jscomp$89$$,$attributes$jscomp$62$$){return $app$main$data$workspace$tokens$application$apply_spacing_token$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$718$$,$shape_ids$jscomp$89$$,$attributes$jscomp$62$$,null)};
$app$main$data$workspace$tokens$application$apply_spacing_token$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$719$$,$shape_ids$jscomp$90$$,$attributes$jscomp$63$$,$page_id$jscomp$328$$){typeof $app$main$data$workspace$tokens$application$apply_spacing_token_72514$$==="undefined"&&($app$main$data$workspace$tokens$application$apply_spacing_token_72514$$=function($value$jscomp$720$$,$shape_ids$jscomp$91$$,$attributes$jscomp$64$$,$page_id$jscomp$329$$,$meta72515$$){this.value=$value$jscomp$720$$;
this.$shape_ids$=$shape_ids$jscomp$91$$;this.attributes=$attributes$jscomp$64$$;this.$page_id$=$page_id$jscomp$329$$;this.$meta72515$=$meta72515$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$apply_spacing_token_72514$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_spacing_token_72514$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$4643$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_spacing_token$$},$app$main$data$workspace$tokens$application$apply_spacing_token_72514$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72516$$,$meta72515__$1$$){return new $app$main$data$workspace$tokens$application$apply_spacing_token_72514$$(this.value,this.$shape_ids$,this.attributes,this.$page_id$,$meta72515__$1$$)},$app$main$data$workspace$tokens$application$apply_spacing_token_72514$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72515$},$app$main$data$workspace$tokens$application$apply_spacing_token_72514$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_spacing_token_72514$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2634_spacing_attrs$$,$actions$jscomp$1_state$jscomp$953$$){$_$jscomp$2634_spacing_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
10,[$APP.$cljs$cst$1091$p2$$,null,$APP.$cljs$cst$1688$p4$$,null,$APP.$cljs$cst$1702$m3$$,null,$APP.$cljs$cst$1687$p3$$,null,$APP.$cljs$cst$1093$p1$$,null,$APP.$cljs$cst$1682$column_gap$$,null,$APP.$cljs$cst$1703$m4$$,null,$APP.$cljs$cst$1701$m2$$,null,$APP.$cljs$cst$1700$m1$$,null,$APP.$cljs$cst$1681$row_gap$$,null],null),null);return typeof this.value==="number"&&$APP.$cljs$core$set_QMARK_$$(this.attributes)&&$APP.$clojure$set$subset_QMARK_$$(this.attributes,$_$jscomp$2634_spacing_attrs$$)?($actions$jscomp$1_state$jscomp$953$$=
$app$main$data$workspace$tokens$application$attributes__GT_actions$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$260$value$$,this.value,$APP.$cljs$cst$4641$shape_ids$$,this.$shape_ids$,$APP.$cljs$cst$1993$attributes$$,this.attributes,$APP.$cljs$cst$2043$page_id$$,this.$page_id$,$APP.$cljs$cst$769$state$$,$actions$jscomp$1_state$jscomp$953$$],null)),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$beicon$v2$core$of$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__72506_SHARP_$$){return $p1__72506_SHARP_$$.$cljs$core$IFn$_invoke$arity$0$?
$p1__72506_SHARP_$$.$cljs$core$IFn$_invoke$arity$0$():$p1__72506_SHARP_$$()},$actions$jscomp$1_state$jscomp$953$$))):null});return new $app$main$data$workspace$tokens$application$apply_spacing_token_72514$$($value$jscomp$719$$,$shape_ids$jscomp$90$$,$attributes$jscomp$63$$,$page_id$jscomp$328$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$tokens$application$apply_spacing_token$$.$cljs$lang$maxFixedArity$=4;
var $app$main$data$workspace$tokens$application$apply_sizing_token$$=function $app$main$data$workspace$tokens$application$apply_sizing_token$$($var_args$jscomp$1375$$){switch(arguments.length){case 3:return $app$main$data$workspace$tokens$application$apply_sizing_token$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$tokens$application$apply_sizing_token$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$data$workspace$tokens$application$apply_sizing_token$$.$cljs$core$IFn$_invoke$arity$3$=function($value$jscomp$721$$,$shape_ids$jscomp$92$$,$attributes$jscomp$65$$){return $app$main$data$workspace$tokens$application$apply_sizing_token$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$721$$,$shape_ids$jscomp$92$$,$attributes$jscomp$65$$,null)};
$app$main$data$workspace$tokens$application$apply_sizing_token$$.$cljs$core$IFn$_invoke$arity$4$=function($value$jscomp$722$$,$shape_ids$jscomp$93$$,$attributes$jscomp$66$$,$page_id$jscomp$330$$){typeof $app$main$data$workspace$tokens$application$apply_sizing_token_72526$$==="undefined"&&($app$main$data$workspace$tokens$application$apply_sizing_token_72526$$=function($value$jscomp$723$$,$shape_ids$jscomp$94$$,$attributes$jscomp$67$$,$page_id$jscomp$331$$,$meta72527$$){this.value=$value$jscomp$723$$;
this.$shape_ids$=$shape_ids$jscomp$94$$;this.attributes=$attributes$jscomp$67$$;this.$page_id$=$page_id$jscomp$331$$;this.$meta72527$=$meta72527$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$apply_sizing_token_72526$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_sizing_token_72526$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4644$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_sizing_token$$},
$app$main$data$workspace$tokens$application$apply_sizing_token_72526$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72528$$,$meta72527__$1$$){return new $app$main$data$workspace$tokens$application$apply_sizing_token_72526$$(this.value,this.$shape_ids$,this.attributes,this.$page_id$,$meta72527__$1$$)},$app$main$data$workspace$tokens$application$apply_sizing_token_72526$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72527$},$app$main$data$workspace$tokens$application$apply_sizing_token_72526$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_sizing_token_72526$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2635_sizing_attrs$$,$actions$jscomp$2_state$jscomp$954$$){$_$jscomp$2635_sizing_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1986$max_height$$,null,$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$281$max_width$$,null,$APP.$cljs$cst$1522$height$$,null],null),
null);return typeof this.value==="number"&&$APP.$cljs$core$set_QMARK_$$(this.attributes)&&$APP.$clojure$set$subset_QMARK_$$(this.attributes,$_$jscomp$2635_sizing_attrs$$)?($actions$jscomp$2_state$jscomp$954$$=$app$main$data$workspace$tokens$application$attributes__GT_actions$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$260$value$$,this.value,$APP.$cljs$cst$4641$shape_ids$$,this.$shape_ids$,$APP.$cljs$cst$1993$attributes$$,this.attributes,$APP.$cljs$cst$2043$page_id$$,this.$page_id$,
$APP.$cljs$cst$769$state$$,$actions$jscomp$2_state$jscomp$954$$],null)),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$beicon$v2$core$of$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__72518_SHARP_$$){return $p1__72518_SHARP_$$.$cljs$core$IFn$_invoke$arity$0$?$p1__72518_SHARP_$$.$cljs$core$IFn$_invoke$arity$0$():$p1__72518_SHARP_$$()},$actions$jscomp$2_state$jscomp$954$$))):null});return new $app$main$data$workspace$tokens$application$apply_sizing_token_72526$$($value$jscomp$722$$,
$shape_ids$jscomp$93$$,$attributes$jscomp$66$$,$page_id$jscomp$330$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$tokens$application$apply_sizing_token$$.$cljs$lang$maxFixedArity$=4;
$app$main$data$workspace$tokens$application$attributes__GT_shape_update$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$app$common$types$token$stroke_width_keys$$,$app$common$types$token$border_radius_keys$$,$app$common$types$token$line_height_keys$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1522$height$$,null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1682$column_gap$$,null,$APP.$cljs$cst$1681$row_gap$$,null],null),null),$app$common$types$token$text_decoration_keys$$,$app$common$types$token$rotation_keys$$,$app$common$types$token$font_family_keys$$,$app$common$types$token$typography_token_keys$$,$app$common$types$token$color_keys$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1702$m3$$,null,$APP.$cljs$cst$1703$m4$$,null,$APP.$cljs$cst$1701$m2$$,null,$APP.$cljs$cst$1700$m1$$,
null],null),null),$app$common$types$token$font_weight_keys$$,$app$common$types$token$sizing_keys$$,$app$common$types$token$opacity_keys$$,$app$common$types$token$font_size_keys$$,$app$common$types$token$shadow_keys$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1511$y$$,null,$APP.$cljs$cst$1510$x$$,null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1706$layout_item_max_w$$,
null,$APP.$cljs$cst$1707$layout_item_min_w$$,null,$APP.$cljs$cst$1705$layout_item_min_h$$,null,$APP.$cljs$cst$1704$layout_item_max_h$$,null],null),null),new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1091$p2$$,null,$APP.$cljs$cst$1688$p4$$,null,$APP.$cljs$cst$1687$p3$$,null,$APP.$cljs$cst$1093$p1$$,null],null),null),$app$common$types$token$text_case_keys$$,$app$common$types$token$letter_spacing_keys$$],[$APP.$app$main$data$workspace$tokens$application$update_stroke_width$$,
$APP.$app$main$data$workspace$tokens$application$update_shape_radius_for_corners$$,$APP.$app$main$data$workspace$tokens$application$update_line_height$$,$APP.$app$main$data$workspace$tokens$application$apply_dimensions_token$$,$APP.$app$main$data$workspace$tokens$application$update_layout_gap$$,$app$main$data$workspace$tokens$application$update_text_decoration$$,$APP.$app$main$data$workspace$tokens$application$update_rotation$$,$app$main$data$workspace$tokens$application$update_font_family$$,$APP.$app$main$data$workspace$tokens$application$update_typography$$,
$app$main$data$workspace$tokens$application$update_fill_stroke$$,$APP.$app$main$data$workspace$tokens$application$update_layout_item_margin$$,$app$main$data$workspace$tokens$application$update_font_weight$$,$APP.$app$main$data$workspace$tokens$application$apply_dimensions_token$$,$app$main$data$workspace$tokens$application$update_opacity$$,$app$main$data$workspace$tokens$application$update_font_size$$,$app$main$data$workspace$tokens$application$update_shadow$$,$APP.$app$main$data$workspace$tokens$application$update_shape_position$$,
$APP.$app$main$data$workspace$tokens$application$update_layout_sizing_limits$$,$APP.$app$main$data$workspace$tokens$application$update_layout_padding$$,$app$main$data$workspace$tokens$application$update_text_case$$,$app$main$data$workspace$tokens$application$update_letter_spacing$$]);
$APP.$app$main$data$workspace$tokens$application$attr__GT_shape_update$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$138$$,$p__72538$$){var $attr_set$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72538$$,0,null),$update_fn$jscomp$44$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72538$$,1,null);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$138$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($k$jscomp$662$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$662$$,$update_fn$jscomp$44$$],null)},$attr_set$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$app$main$data$workspace$tokens$application$attributes__GT_shape_update$$);
$a$jscomp$inline_7350$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,"Border Radius",$APP.$cljs$cst$1993$attributes$$,$app$common$types$token$border_radius_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_shape_radius$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$4658$tokens_SLASH_border_radius$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Border Radius",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1982$border_radius$$],null)],null)],null)],null);
$xs$jscomp$inline_7351$$=$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1654$shadow$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,"Shadow",$APP.$cljs$cst$1993$attributes$$,$app$common$types$token$shadow_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$app$main$data$workspace$tokens$application$update_shadow$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$4660$tokens_SLASH_shadow$$,
$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Shadow",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1654$shadow$$],null)],null)],null)],null),$APP.$cljs$cst$1298$color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$939$title$$,"Color",$APP.$cljs$cst$1993$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1403$fill$$,null],null),null),$APP.$cljs$cst$4655$all_attributes$$,$app$common$types$token$color_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$app$main$data$workspace$tokens$application$update_fill_stroke$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$4661$tokens_SLASH_color$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2287$label$$,"Color",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1298$color$$],null)],null)],null)],null),$APP.$cljs$cst$1760$font_size$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,"Font Size",$APP.$cljs$cst$1993$attributes$$,$app$common$types$token$font_size_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$app$main$data$workspace$tokens$application$update_font_size$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,
$APP.$cljs$cst$4662$tokens_SLASH_font_size$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Font Size",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1760$font_size$$],null)],null)],null)],null),$APP.$cljs$cst$1766$letter_spacing$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,"Letter Spacing",$APP.$cljs$cst$1993$attributes$$,
$app$common$types$token$letter_spacing_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$app$main$data$workspace$tokens$application$update_letter_spacing$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$4663$tokens_SLASH_letter_spacing$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,
"Letter Spacing",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1766$letter_spacing$$],null)],null)],null)],null),$APP.$cljs$cst$1758$font_family$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,"Font Family",$APP.$cljs$cst$1993$attributes$$,$app$common$types$token$font_family_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$app$main$data$workspace$tokens$application$update_font_family_interactive$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,
$APP.$cljs$cst$4664$tokens_SLASH_font_family$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Font Family",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1758$font_family$$],null)],null)],null)],null),$APP.$cljs$cst$1979$text_case$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,"Text Case",$APP.$cljs$cst$1993$attributes$$,
$app$common$types$token$text_case_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$app$main$data$workspace$tokens$application$update_text_case$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$4665$tokens_SLASH_text_case$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Text Case",
$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1979$text_case$$],null)],null)],null)],null),$APP.$cljs$cst$1761$font_weight$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,"Font Weight",$APP.$cljs$cst$1993$attributes$$,$app$common$types$token$font_weight_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$app$main$data$workspace$tokens$application$update_font_weight_interactive$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,
$APP.$cljs$cst$4666$tokens_SLASH_font_weight$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Font Weight",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1761$font_weight$$],null)],null)],null)],null),$APP.$cljs$cst$1981$typography$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,"Typography",$APP.$cljs$cst$1993$attributes$$,
$app$common$types$token$typography_token_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_typography$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$4667$tokens_SLASH_typography$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,
"Typography",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1981$typography$$],null)],null)],null)],null),$APP.$cljs$cst$1768$text_decoration$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,"Text Decoration",$APP.$cljs$cst$1993$attributes$$,$app$common$types$token$text_decoration_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$app$main$data$workspace$tokens$application$update_text_decoration_interactive$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$4668$tokens_SLASH_text_decoration$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Text Decoration",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1768$text_decoration$$],null)],null)],null)],null),$APP.$cljs$cst$1655$stroke_width$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,"Stroke Width",
$APP.$cljs$cst$1993$attributes$$,$app$common$types$token$stroke_width_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_stroke_width$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$4669$tokens_SLASH_stroke_width$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2287$label$$,"Stroke Width",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1655$stroke_width$$],null)],null)],null)],null),$APP.$cljs$cst$1977$sizing$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$939$title$$,"Sizing",$APP.$cljs$cst$1993$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1522$height$$,null],null),null),$APP.$cljs$cst$4655$all_attributes$$,$app$common$types$token$sizing_keys$$,
$APP.$cljs$cst$4646$on_update_shape$$,$app$main$data$workspace$tokens$application$apply_sizing_token$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$4670$tokens_SLASH_sizing$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Sizing",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1977$sizing$$],
null)],null)],null)],null),$APP.$cljs$cst$1980$dimensions$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$939$title$$,"Dimensions",$APP.$cljs$cst$1993$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,null,$APP.$cljs$cst$1522$height$$,null],null),null),$APP.$cljs$cst$4655$all_attributes$$,$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$variadic$($app$common$types$token$spacing_keys$$,$app$common$types$token$sizing_keys$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$common$types$token$border_radius_keys$$,$app$common$types$token$axis_keys$$,$app$common$types$token$stroke_width_keys$$])),$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$apply_dimensions_token$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$4671$tokens_SLASH_dimensions$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Dimensions",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1980$dimensions$$],null)],null)],null)],null),$APP.$cljs$cst$1734$opacity$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,"Opacity",$APP.$cljs$cst$1993$attributes$$,$app$common$types$token$opacity_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$app$main$data$workspace$tokens$application$update_opacity$$,
$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$4672$tokens_SLASH_opacity$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Opacity",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1734$opacity$$],null)],null)],null)],null),$APP.$cljs$cst$1978$number$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$939$title$$,"Number",$APP.$cljs$cst$1993$attributes$$,$app$common$types$token$rotation_keys$$,$APP.$cljs$cst$4655$all_attributes$$,$app$common$types$token$number_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_rotation$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$4673$tokens_SLASH_number$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Number",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1978$number$$],null)],null)],null)],null),$APP.$cljs$cst$1788$rotation$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,"Rotation",$APP.$cljs$cst$1993$attributes$$,$app$common$types$token$rotation_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_rotation$$,
$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$4674$tokens_SLASH_rotation$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Rotation",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1788$rotation$$],null)],null)],null)],null),$APP.$cljs$cst$1983$spacing$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$939$title$$,"Spacing",$APP.$cljs$cst$1993$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1682$column_gap$$,null,$APP.$cljs$cst$1681$row_gap$$,null],null),null),$APP.$cljs$cst$4655$all_attributes$$,$app$common$types$token$spacing_keys$$,$APP.$cljs$cst$4646$on_update_shape$$,$app$main$data$workspace$tokens$application$apply_spacing_token$$,$APP.$cljs$cst$4550$modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$4675$tokens_SLASH_spacing$$,$APP.$cljs$cst$4659$fields$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"Spacing",$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1983$spacing$$],null)],null)],null)],null)]);
$APP.$app$main$data$workspace$tokens$application$token_properties$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$assoc$$,$APP.$linked$map$empty_linked_map$$,$APP.$cljs$cst$1982$border_radius$$,$a$jscomp$inline_7350$$,$xs$jscomp$inline_7351$$);$APP.$app$common$test_helpers$ids_map$idmap$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $clojure$data$diff_associative$$=function $clojure$data$diff_associative$$($var_args$jscomp$1376$$){switch(arguments.length){case 2:return $clojure$data$diff_associative$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $clojure$data$diff_associative$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$clojure$data$diff_associative$$.$cljs$core$IFn$_invoke$arity$2$=function($a$jscomp$401$$,$b$jscomp$322$$){return $clojure$data$diff_associative$$.$cljs$core$IFn$_invoke$arity$3$($a$jscomp$401$$,$b$jscomp$322$$,$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keys$$($a$jscomp$401$$),$APP.$cljs$core$keys$$($b$jscomp$322$$)))};
$clojure$data$diff_associative$$.$cljs$core$IFn$_invoke$arity$3$=function($a$jscomp$402$$,$b$jscomp$323$$,$ks$jscomp$61$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($diff1$$,$diff2$$){return $APP.$cljs$core$doall$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$merge$$,$diff1$$,$diff2$$))},new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,null,null],null),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($clojure$data$diff_associative_key$$,
$a$jscomp$402$$,$b$jscomp$323$$),$ks$jscomp$61$$))};$clojure$data$diff_associative$$.$cljs$lang$maxFixedArity$=3;$clojure$data$equality_partition$$["null"]=function(){return $cljs$cst$4681$atom$$};$clojure$data$equality_partition$$.string=function(){return $cljs$cst$4681$atom$$};$clojure$data$equality_partition$$.number=function(){return $cljs$cst$4681$atom$$};$clojure$data$equality_partition$$.array=function(){return $cljs$cst$720$sequential$$};$clojure$data$equality_partition$$["function"]=function(){return $cljs$cst$4681$atom$$};
$clojure$data$equality_partition$$["boolean"]=function(){return $cljs$cst$4681$atom$$};
$clojure$data$equality_partition$$._=function($x$jscomp$1225$$){return($x$jscomp$1225$$!=null?$x$jscomp$1225$$.$cljs$lang$protocol_mask$partition0$$&1024||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$1225$$.$cljs$core$IMap$$||($x$jscomp$1225$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IMap$$,$x$jscomp$1225$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$IMap$$,$x$jscomp$1225$$))?$APP.$cljs$cst$202$map$$:($x$jscomp$1225$$!=null?$x$jscomp$1225$$.$cljs$lang$protocol_mask$partition0$$&
4096||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$1225$$.$cljs$core$ISet$$||($x$jscomp$1225$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ISet$$,$x$jscomp$1225$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ISet$$,$x$jscomp$1225$$))?$APP.$cljs$cst$203$set$$:($x$jscomp$1225$$!=null?$x$jscomp$1225$$.$cljs$lang$protocol_mask$partition0$$&16777216||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$x$jscomp$1225$$.$cljs$core$ISequential$$||($x$jscomp$1225$$.$cljs$lang$protocol_mask$partition0$$?
0:$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ISequential$$,$x$jscomp$1225$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($cljs$core$ISequential$$,$x$jscomp$1225$$))?$cljs$cst$720$sequential$$:$cljs$cst$4681$atom$$};$clojure$data$diff_similar$$["null"]=function($a$jscomp$407$$,$b$jscomp$328$$){return $clojure$data$atom_diff$$($a$jscomp$407$$,$b$jscomp$328$$)};$clojure$data$diff_similar$$.string=function($a$jscomp$408$$,$b$jscomp$329$$){return $clojure$data$atom_diff$$($a$jscomp$408$$,$b$jscomp$329$$)};
$clojure$data$diff_similar$$.number=function($a$jscomp$409$$,$b$jscomp$330$$){return $clojure$data$atom_diff$$($a$jscomp$409$$,$b$jscomp$330$$)};$clojure$data$diff_similar$$.array=function($a$jscomp$410$$,$b$jscomp$331$$){return $clojure$data$diff_sequential$$($a$jscomp$410$$,$b$jscomp$331$$)};$clojure$data$diff_similar$$["function"]=function($a$jscomp$411$$,$b$jscomp$332$$){return $clojure$data$atom_diff$$($a$jscomp$411$$,$b$jscomp$332$$)};
$clojure$data$diff_similar$$["boolean"]=function($a$jscomp$412$$,$b$jscomp$333$$){return $clojure$data$atom_diff$$($a$jscomp$412$$,$b$jscomp$333$$)};
$clojure$data$diff_similar$$._=function($a$jscomp$413$$,$b$jscomp$334$$){var $fexpr__72078$$=function(){var $G__72079_G__72079__$1$$=$clojure$data$equality_partition$$($a$jscomp$413$$);$G__72079_G__72079__$1$$=$G__72079_G__72079__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__72079_G__72079__$1$$.$fqn$:null;switch($G__72079_G__72079__$1$$){case "atom":return $clojure$data$atom_diff$$;case "set":return $clojure$data$diff_set$$;case "sequential":return $clojure$data$diff_sequential$$;case "map":return $clojure$data$diff_associative$$;
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__72079_G__72079__$1$$)].join(""));}}();return $fexpr__72078$$.$cljs$core$IFn$_invoke$arity$2$?$fexpr__72078$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$413$$,$b$jscomp$334$$):$fexpr__72078$$($a$jscomp$413$$,$b$jscomp$334$$)};var $app$main$data$workspace$tokens$propagation$propagate_workspace_tokens_72716$$;$APP.$app$common$logging$loggers$$.set("app.main.data.workspace.tokens.propagation",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));
var $app$main$data$workspace$tokens$propagation$deep_merge$$=function $app$main$data$workspace$tokens$propagation$deep_merge$$($var_args$jscomp$1377$$){switch(arguments.length){case 2:return $app$main$data$workspace$tokens$propagation$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$105$$=[],$len__5749__auto___72721$$=arguments.length,$i__5750__auto___72726$$=0;;)if($i__5750__auto___72726$$<$len__5749__auto___72721$$)$args_arr__5774__auto__$jscomp$105$$.push(arguments[$i__5750__auto___72726$$]),
$i__5750__auto___72726$$+=1;else break;return $app$main$data$workspace$tokens$propagation$deep_merge$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$105$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$105$$.slice(2),0,null):null)}};
$app$main$data$workspace$tokens$propagation$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$=function($a$jscomp$415$$,$b$jscomp$336$$){return $APP.$cljs$core$map_QMARK_$$($a$jscomp$415$$)?$APP.$cljs$core$merge_with$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$propagation$deep_merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$a$jscomp$415$$,$b$jscomp$336$$])):$APP.$cljs$core$set_QMARK_$$($a$jscomp$415$$)?$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$415$$,
$b$jscomp$336$$):$b$jscomp$336$$};$app$main$data$workspace$tokens$propagation$deep_merge$$.$cljs$core$IFn$_invoke$arity$variadic$=function($a$jscomp$416$$,$b$jscomp$337$$,$rest$jscomp$20$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$data$workspace$tokens$propagation$deep_merge$$,$a$jscomp$416$$,$APP.$cljs$core$cons$$($b$jscomp$337$$,$rest$jscomp$20$$))};
$app$main$data$workspace$tokens$propagation$deep_merge$$.$cljs$lang$applyTo$=function($G__72646_seq72644$$){var $G__72645$$=$APP.$cljs$core$first$$($G__72646_seq72644$$),$seq72644__$1_seq72644__$2$$=$APP.$cljs$core$next$$($G__72646_seq72644$$);$G__72646_seq72644$$=$APP.$cljs$core$first$$($seq72644__$1_seq72644__$2$$);$seq72644__$1_seq72644__$2$$=$APP.$cljs$core$next$$($seq72644__$1_seq72644__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__72645$$,$G__72646_seq72644$$,$seq72644__$1_seq72644__$2$$)};
$app$main$data$workspace$tokens$propagation$deep_merge$$.$cljs$lang$maxFixedArity$=2;
var $app$main$data$workspace$tokens$propagation$attribute_actions_map$$=function($m$jscomp$219$$,$into_m$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$139$$,$p__72648$$){var $ks$jscomp$62$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72648$$,0,null),$action$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72648$$,1,null);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$139$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($k$jscomp$665$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$665$$,$action$$],null)},$ks$jscomp$62$$))},$into_m$$,$m$jscomp$219$$)}($app$main$data$workspace$tokens$application$attributes__GT_shape_update$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $app$main$data$workspace$tokens$library_edit$toggle_token_path_72785$$,$app$main$data$workspace$tokens$library_edit$create_token_theme_72791$$,$app$main$data$workspace$tokens$library_edit$update_token_theme_72794$$,$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active_72802$$,$app$main$data$workspace$tokens$library_edit$delete_token_theme_72805$$,$app$main$data$workspace$tokens$library_edit$create_token_set_72812$$,$app$main$data$workspace$tokens$library_edit$update_token_set_72827$$,
$app$main$data$workspace$tokens$library_edit$duplicate_token_set_72849$$,$app$main$data$workspace$tokens$library_edit$toggle_token_set_72862$$,$app$main$data$workspace$tokens$library_edit$delete_token_set_72880$$,$app$main$data$workspace$tokens$library_edit$create_token_and_set_72921$$,$app$main$data$workspace$tokens$library_edit$create_token_72935$$,$app$main$data$workspace$tokens$library_edit$update_token_72952$$,$app$main$data$workspace$tokens$library_edit$delete_token_72984$$,$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id_73046$$;var $app$main$ui$ds$tooltip$tooltip$active_tooltip$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$app$main$ui$ds$tooltip$tooltip$tooltip_registry$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$app$main$ui$ds$tooltip$tooltip$pending_tooltips$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($button_ref_props_72251$$){var $aria_label$jscomp$3$$=void 0,$children$jscomp$261$$=void 0,$tooltip_id$jscomp$5_variant$jscomp$17$$=void 0,$icon_size$$=void 0,$tooltip_placement$$=void 0,$props__$1$jscomp$38_type$jscomp$561$$=void 0,$icon$jscomp$6$$=void 0,$tooltip_class$jscomp$1$$=void 0,$class$$jscomp$13$$=void 0,$icon_class$jscomp$1$$=void 0,$props$jscomp$220$$=void 0;({"aria-label":$aria_label$jscomp$3$$,
children:$children$jscomp$261$$,variant:$tooltip_id$jscomp$5_variant$jscomp$17$$,iconSize:$icon_size$$,tooltipPlacement:$tooltip_placement$$,type:$props__$1$jscomp$38_type$jscomp$561$$,icon:$icon$jscomp$6$$,tooltipClass:$tooltip_class$jscomp$1$$,className:$class$$jscomp$13$$,iconClass:$icon_class$jscomp$1$$,...$props$jscomp$220$$}=$button_ref_props_72251$$);var $variant__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($tooltip_id$jscomp$5_variant$jscomp$17$$,"primary");$button_ref_props_72251$$=
(0,$APP.$rumext$v2$use_ref$$)(null);$tooltip_id$jscomp$5_variant$jscomp$17$$=(0,$APP.$rumext$v2$use_id$$)();$props__$1$jscomp$38_type$jscomp$561$$={...$props$jscomp$220$$,className:($class$$jscomp$13$$??"")+" main_ui_ds_buttons_icon_button__icon-button "+(($variant__$1$$==="primary"?"main_ui_ds_buttons_icon_button__icon-button-primary":"")+" "+($variant__$1$$==="secondary"?"main_ui_ds_buttons_icon_button__icon-button-secondary":"")+" "+($variant__$1$$==="ghost"?"main_ui_ds_buttons_icon_button__icon-button-ghost":
"")+" "+($variant__$1$$==="action"?"main_ui_ds_buttons_icon_button__icon-button-action":"")+" "+($variant__$1$$==="destructive"?"main_ui_ds_buttons_icon_button__icon-button-destructive":"")),ref:$button_ref_props_72251$$,type:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props__$1$jscomp$38_type$jscomp$561$$,"button"),"aria-labelledby":$tooltip_id$jscomp$5_variant$jscomp$17$$};return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$aria_label$jscomp$3$$,
className:$tooltip_class$jscomp$1$$,triggerRef:$button_ref_props_72251$$,placement:$tooltip_placement$$,id:$tooltip_id$jscomp$5_variant$jscomp$17$$,children:(0,$APP.$rumext$v2$create_element$$)("button",$props__$1$jscomp$38_type$jscomp$561$$,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon$jscomp$6$$,"aria-hidden":!0,className:$icon_class$jscomp$1$$,size:$icon_size$$}),$children$jscomp$261$$)})});$APP.$app$main$ui$ds$controls$utilities$input_field$input_field_STAR_$$=(0,$APP.$rumext$v2$forward_ref$$)(function($input_ref$jscomp$1_props_72247$$,$ref$jscomp$35$$){var $aria_label$jscomp$4$$=void 0,$data_option_focused$$=void 0,$max_length$jscomp$2_props__$1$jscomp$39$$=void 0,$tooltip_id$jscomp$6_variant$jscomp$18$$=void 0,$slot_end$$=void 0,$type$jscomp$563_type__$1$jscomp$10$$=void 0,$icon$jscomp$7$$=void 0,$hint_type$$=void 0,$input_wrapper_ref$$=void 0,$id$jscomp$800_inside_class$$=void 0,
$class$$jscomp$15$$=void 0,$slot_start$$=void 0,$has_hint$$=void 0,$on_icon_click_props$jscomp$222$$=void 0;({"aria-label":$aria_label$jscomp$4$$,"data-option-focused":$data_option_focused$$,maxLength:$max_length$jscomp$2_props__$1$jscomp$39$$,variant:$tooltip_id$jscomp$6_variant$jscomp$18$$,slotEnd:$slot_end$$,type:$type$jscomp$563_type__$1$jscomp$10$$,icon:$icon$jscomp$7$$,hintType:$hint_type$$,inputWrapperRef:$input_wrapper_ref$$,id:$id$jscomp$800_inside_class$$,className:$class$$jscomp$15$$,slotStart:$slot_start$$,
hasHint:$has_hint$$,...$on_icon_click_props$jscomp$222$$}=$input_ref$jscomp$1_props_72247$$);$input_ref$jscomp$1_props_72247$$=(0,$APP.$rumext$v2$use_ref$$)();$type$jscomp$563_type__$1$jscomp$10$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$563_type__$1$jscomp$10$$,"text");var $variant__$1$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($tooltip_id$jscomp$6_variant$jscomp$18$$,"dense");$tooltip_id$jscomp$6_variant$jscomp$18$$=(0,$APP.$rumext$v2$use_id$$)();
$max_length$jscomp$2_props__$1$jscomp$39$$={...$on_icon_click_props$jscomp$222$$,className:($class$$jscomp$15$$??"")+" main_ui_ds_controls_utilities_input_field__input "+($icon$jscomp$7$$!=null?"main_ui_ds_controls_utilities_input_field__input-with-icon":""),ref:$APP.$cljs$core$truth_$$($ref$jscomp$35$$)?$ref$jscomp$35$$:$input_ref$jscomp$1_props_72247$$,"aria-invalid":$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$564$$=$has_hint$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$564$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hint_type$$,"error"):$and__5023__auto__$jscomp$564$$}())?"true":null,"aria-describedby":$APP.$cljs$core$truth_$$($has_hint$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$800_inside_class$$),"-hint"].join(""):null,"aria-labelledby":$tooltip_id$jscomp$6_variant$jscomp$18$$,type:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$563_type__$1$jscomp$10$$,"text"),id:$id$jscomp$800_inside_class$$,maxLength:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($max_length$jscomp$2_props__$1$jscomp$39$$,
255)};$id$jscomp$800_inside_class$$="main_ui_ds_controls_utilities_input_field__input-wrapper "+($APP.$cljs$core$truth_$$($has_hint$$)?"main_ui_ds_controls_utilities_input_field__has-hint":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hint_type$$,"hint")?"main_ui_ds_controls_utilities_input_field__hint-type-hint":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hint_type$$,"warning")?"main_ui_ds_controls_utilities_input_field__hint-type-warning":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hint_type$$,
"error")?"main_ui_ds_controls_utilities_input_field__hint-type-error":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant__$1$jscomp$1$$,"seamless")?"main_ui_ds_controls_utilities_input_field__variant-seamless":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant__$1$jscomp$1$$,"dense")?"main_ui_ds_controls_utilities_input_field__variant-dense":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant__$1$jscomp$1$$,"comfortable")?"main_ui_ds_controls_utilities_input_field__variant-comfortable":
"");$on_icon_click_props$jscomp$222$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ref$jscomp$35$$)],function(){return $APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($ref$jscomp$35$$))});return(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$input_wrapper_ref$$,"data-option-focused":$data_option_focused$$,className:($id$jscomp$800_inside_class$$??"")+" "+($class$$jscomp$15$$??""),children:[$slot_start$$!=null?$slot_start$$:null,$icon$jscomp$7$$!=null?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:$icon$jscomp$7$$,className:"main_ui_ds_controls_utilities_input_field__icon",size:"s",onClick:$on_icon_click_props$jscomp$222$$}):null,$APP.$cljs$core$truth_$$($aria_label$jscomp$4$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$aria_label$jscomp$4$$,triggerRef:$APP.$cljs$core$truth_$$($ref$jscomp$35$$)?$ref$jscomp$35$$:$input_ref$jscomp$1_props_72247$$,className:"main_ui_ds_controls_utilities_input_field__tooltip-wrapper",id:$tooltip_id$jscomp$6_variant$jscomp$18$$,
children:(0,$APP.$rumext$v2$create_element$$)("input",$max_length$jscomp$2_props__$1$jscomp$39$$)}):(0,$APP.$rumext$v2$create_element$$)("input",$max_length$jscomp$2_props__$1$jscomp$39$$),$slot_end$$!=null?$slot_end$$:null]})});$APP.$app$main$ui$ds$controls$input$input_STAR_$$=(0,$APP.$rumext$v2$forward_ref$$)(function($id__$1$jscomp$11_props_72275$$,$ref$jscomp$36_ref__$1$$){var $hint_formated$$=void 0,$has_hint$jscomp$1_max_length$jscomp$3$$=void 0,$variant$jscomp$19_variant__$1$jscomp$2$$=void 0,$type$jscomp$564_type__$1$jscomp$11$$=void 0,$hint_type$jscomp$1$$=void 0,$is_optional$jscomp$1_is_optional__$1$jscomp$1$$=void 0,$hint_message$$=void 0,$label$jscomp$20$$=void 0,$id$jscomp$801$$=void 0,$class$$jscomp$17$$=void 0,
$props$jscomp$224_props__$1$jscomp$41$$=void 0;({hintFormated:$hint_formated$$,maxLength:$has_hint$jscomp$1_max_length$jscomp$3$$,variant:$variant$jscomp$19_variant__$1$jscomp$2$$,type:$type$jscomp$564_type__$1$jscomp$11$$,hintType:$hint_type$jscomp$1$$,isOptional:$is_optional$jscomp$1_is_optional__$1$jscomp$1$$,hintMessage:$hint_message$$,label:$label$jscomp$20$$,id:$id$jscomp$801$$,className:$class$$jscomp$17$$,...$props$jscomp$224_props__$1$jscomp$41$$}=$id__$1$jscomp$11_props_72275$$);$id__$1$jscomp$11_props_72275$$=
function(){var $or__5025__auto__$jscomp$904$$=$id$jscomp$801$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$904$$)?$or__5025__auto__$jscomp$904$$:(0,$APP.$rumext$v2$use_id$$)()}();$variant$jscomp$19_variant__$1$jscomp$2$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($variant$jscomp$19_variant__$1$jscomp$2$$,"dense");var $hint_class$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$565$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("error",
$hint_type$jscomp$1$$);return $and__5023__auto__$jscomp$565$$?$hint_formated$$:$and__5023__auto__$jscomp$565$$}())?"main_ui_ds_controls_input__hint-formated":"";$is_optional$jscomp$1_is_optional__$1$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($is_optional$jscomp$1_is_optional__$1$jscomp$1$$,!1);$type$jscomp$564_type__$1$jscomp$11$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$564_type__$1$jscomp$11$$,"text");var $max_length__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($has_hint$jscomp$1_max_length$jscomp$3$$,
255);$has_hint$jscomp$1_max_length$jscomp$3$$=$hint_message$$!=null&&!$APP.$cuerdas$core$blank_QMARK_$$($hint_message$$);var $has_label$$=!$APP.$cuerdas$core$blank_QMARK_$$($label$jscomp$20$$);$ref$jscomp$36_ref__$1$$=$APP.$cljs$core$truth_$$($ref$jscomp$36_ref__$1$$)?$ref$jscomp$36_ref__$1$$:(0,$APP.$rumext$v2$use_ref$$)();$props$jscomp$224_props__$1$jscomp$41$$={...$props$jscomp$224_props__$1$jscomp$41$$,ref:$ref$jscomp$36_ref__$1$$,type:$type$jscomp$564_type__$1$jscomp$11$$,id:$id__$1$jscomp$11_props_72275$$,
maxLength:$max_length__$1$$,hasHint:$has_hint$jscomp$1_max_length$jscomp$3$$,hintType:$hint_type$jscomp$1$$,variant:$variant$jscomp$19_variant__$1$jscomp$2$$};return(0,$APP.$rumext$v2$jsxs$$)("div",{className:($class$$jscomp$17$$??"")+" main_ui_ds_controls_input__input-wrapper "+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant$jscomp$19_variant__$1$jscomp$2$$,"dense")?"main_ui_ds_controls_input__variant-dense":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant$jscomp$19_variant__$1$jscomp$2$$,
"comfortable")?"main_ui_ds_controls_input__variant-comfortable":"")+" "+($has_hint$jscomp$1_max_length$jscomp$3$$?"main_ui_ds_controls_input__has-hint":"")),children:[$has_label$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$utilities$label$label_STAR_$$,{htmlFor:$id__$1$jscomp$11_props_72275$$,isOptional:$is_optional$jscomp$1_is_optional__$1$jscomp$1$$,children:$label$jscomp$20$$}):null,(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$utilities$input_field$input_field_STAR_$$,
$props$jscomp$224_props__$1$jscomp$41$$),$has_hint$jscomp$1_max_length$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$utilities$hint_message$hint_message_STAR_$$,{id:$id__$1$jscomp$11_props_72275$$,className:$hint_class$$,message:$hint_message$$,type:$hint_type$jscomp$1$$}):null]})});$goog$string$format$$.$demuxes_$={};
$goog$string$format$$.$demuxes_$.s=function($replacement$jscomp$19_value$jscomp$727$$,$flags$jscomp$36$$,$width$jscomp$165$$){return isNaN($width$jscomp$165$$)||$width$jscomp$165$$==""||$replacement$jscomp$19_value$jscomp$727$$.length>=Number($width$jscomp$165$$)?$replacement$jscomp$19_value$jscomp$727$$:$replacement$jscomp$19_value$jscomp$727$$=$flags$jscomp$36$$.indexOf("-",0)>-1?$replacement$jscomp$19_value$jscomp$727$$+$goog$string$repeat$$(" ",Number($width$jscomp$165$$)-$replacement$jscomp$19_value$jscomp$727$$.length):
$goog$string$repeat$$(" ",Number($width$jscomp$165$$)-$replacement$jscomp$19_value$jscomp$727$$.length)+$replacement$jscomp$19_value$jscomp$727$$};
$goog$string$format$$.$demuxes_$.f=function($padCount_value$jscomp$728$$,$flags$jscomp$37_paddingChar$$,$width$jscomp$166$$,$dotp$jscomp$2_replacement$jscomp$20$$,$precision$jscomp$23$$){$dotp$jscomp$2_replacement$jscomp$20$$=$padCount_value$jscomp$728$$.toString();isNaN($precision$jscomp$23$$)||$precision$jscomp$23$$==""||($dotp$jscomp$2_replacement$jscomp$20$$=parseFloat($padCount_value$jscomp$728$$).toFixed($precision$jscomp$23$$));let $sign$jscomp$12$$;$sign$jscomp$12$$=Number($padCount_value$jscomp$728$$)<
0?"-":$flags$jscomp$37_paddingChar$$.indexOf("+")>=0?"+":$flags$jscomp$37_paddingChar$$.indexOf(" ")>=0?" ":"";Number($padCount_value$jscomp$728$$)>=0&&($dotp$jscomp$2_replacement$jscomp$20$$=$sign$jscomp$12$$+$dotp$jscomp$2_replacement$jscomp$20$$);if(isNaN($width$jscomp$166$$)||$dotp$jscomp$2_replacement$jscomp$20$$.length>=Number($width$jscomp$166$$))return $dotp$jscomp$2_replacement$jscomp$20$$;$dotp$jscomp$2_replacement$jscomp$20$$=isNaN($precision$jscomp$23$$)?Math.abs(Number($padCount_value$jscomp$728$$)).toString():
Math.abs(Number($padCount_value$jscomp$728$$)).toFixed($precision$jscomp$23$$);$padCount_value$jscomp$728$$=Number($width$jscomp$166$$)-$dotp$jscomp$2_replacement$jscomp$20$$.length-$sign$jscomp$12$$.length;$flags$jscomp$37_paddingChar$$.indexOf("-",0)>=0?$dotp$jscomp$2_replacement$jscomp$20$$=$sign$jscomp$12$$+$dotp$jscomp$2_replacement$jscomp$20$$+$goog$string$repeat$$(" ",$padCount_value$jscomp$728$$):($flags$jscomp$37_paddingChar$$=$flags$jscomp$37_paddingChar$$.indexOf("0",0)>=0?"0":" ",$dotp$jscomp$2_replacement$jscomp$20$$=
$sign$jscomp$12$$+$goog$string$repeat$$($flags$jscomp$37_paddingChar$$,$padCount_value$jscomp$728$$)+$dotp$jscomp$2_replacement$jscomp$20$$);return $dotp$jscomp$2_replacement$jscomp$20$$};
$goog$string$format$$.$demuxes_$.d=function($value$jscomp$729$$,$flags$jscomp$38$$,$width$jscomp$167$$,$dotp$jscomp$3$$,$precision$jscomp$24$$,$type$jscomp$568$$,$offset$jscomp$189$$,$wholeString$jscomp$3$$){return $goog$string$format$$.$demuxes_$.f(parseInt($value$jscomp$729$$,10),$flags$jscomp$38$$,$width$jscomp$167$$,$dotp$jscomp$3$$,0,$type$jscomp$568$$,$offset$jscomp$189$$,$wholeString$jscomp$3$$)};$goog$string$format$$.$demuxes_$.i=$goog$string$format$$.$demuxes_$.d;
$goog$string$format$$.$demuxes_$.u=$goog$string$format$$.$demuxes_$.d;$APP.$app$main$ui$components$color_bullet$color_bullet$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($area$jscomp$4_props_72330$$){var $color$jscomp$119$$=$area$jscomp$4_props_72330$$.color,$mini$$=$area$jscomp$4_props_72330$$.mini,$on_click$jscomp$5$$=$area$jscomp$4_props_72330$$["on-click"];$area$jscomp$4_props_72330$$=$area$jscomp$4_props_72330$$.area;var $read_only_QMARK_$jscomp$4$$=$on_click$jscomp$5$$==null,$on_click__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$119$$),
$APP.$rumext$v2$adapt$$($on_click$jscomp$5$$)],function($event$jscomp$128$$){return $APP.$cljs$core$fn_QMARK_$$($on_click$jscomp$5$$)?$on_click$jscomp$5$$($color$jscomp$119$$,$event$jscomp$128$$):null});if($APP.$app$util$color$multiple_QMARK_$$($color$jscomp$119$$))return(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$on_click__$1$jscomp$1$$,title:$app$main$ui$components$color_bullet$color_title$$($color$jscomp$119$$),className:"main_ui_components_color_bullet__color-bullet main_ui_components_color_bullet__multiple"});
var $color__$1$jscomp$15$$=typeof $color$jscomp$119$$==="string"?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1298$color$$,$color$jscomp$119$$,$APP.$cljs$cst$1734$opacity$$,1],null):$color$jscomp$119$$,$id$jscomp$802$$=function(){var $or__5025__auto__$jscomp$908$$=$APP.$cljs$cst$1735$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$15$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$908$$)?$or__5025__auto__$jscomp$908$$:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$15$$)}(),
$gradient$jscomp$24$$=$APP.$cljs$cst$1724$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$15$$),$opacity$jscomp$41$$=$APP.$cljs$cst$1734$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$15$$),$image$jscomp$29$$=$APP.$cljs$cst$1612$image$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$15$$);return(0,$APP.$rumext$v2$jsx$$)("div",{role:"button","data-readonly":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($read_only_QMARK_$jscomp$4$$),onClick:$on_click__$1$jscomp$1$$,
title:$app$main$ui$components$color_bullet$color_title$$($color__$1$jscomp$15$$),className:"main_ui_components_color_bullet__color-bullet "+($APP.$cljs$core$truth_$$($mini$$)?"main_ui_components_color_bullet__mini":"")+" "+($id$jscomp$802$$!=null?"main_ui_components_color_bullet__is-library-color":"")+" "+($id$jscomp$802$$==null?"main_ui_components_color_bullet__is-not-library-color":"")+" "+($gradient$jscomp$24$$!=null?"main_ui_components_color_bullet__is-gradient":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($opacity$jscomp$41$$)?
1>$opacity$jscomp$41$$:$opacity$jscomp$41$$)?"main_ui_components_color_bullet__is-transparent":"")+" "+($APP.$cljs$core$truth_$$($area$jscomp$4_props_72330$$)?"main_ui_components_color_bullet__grid-area":"")+" "+($read_only_QMARK_$jscomp$4$$?"main_ui_components_color_bullet__read-only":""),children:$gradient$jscomp$24$$!=null?(0,$APP.$rumext$v2$jsx$$)("div",{style:{background:$app$util$color$color__GT_background$$($color__$1$jscomp$15$$)},className:"main_ui_components_color_bullet__color-bullet-wrapper"}):
$image$jscomp$29$$!=null?function(){var $uri$jscomp$101$$=$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($image$jscomp$29$$);return(0,$APP.$rumext$v2$jsx$$)("div",{style:{backgroundImage:"url("+($uri$jscomp$101$$??"")+")"},className:"main_ui_components_color_bullet__color-bullet-wrapper"})}():(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_components_color_bullet__color-bullet-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{background:$app$util$color$color__GT_background$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color__$1$jscomp$15$$,
$APP.$cljs$cst$1734$opacity$$,1))},className:"main_ui_components_color_bullet__color-bullet-left"}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{background:$app$util$color$color__GT_background$$($color__$1$jscomp$15$$)},className:"main_ui_components_color_bullet__color-bullet-right"})]})})});var $app$main$data$exports$assets$toggle_detail_visibililty_72381$$,$app$main$data$exports$assets$clear_export_state_72393$$,$app$main$data$exports$assets$show_workspace_export_dialog_72403$$,$app$main$data$exports$assets$show_viewer_export_dialog_72423$$,$app$main$data$exports$assets$initialize_export_status_72450$$,$app$main$data$exports$assets$update_export_status_72459$$,$app$main$data$exports$assets$request_simple_export_wasm_72472$$,$app$main$data$exports$assets$request_simple_export_72480$$,
$app$main$data$exports$assets$request_multiple_export_72510$$,$app$main$data$exports$assets$retry_last_export_72529$$;var $app$main$ui$shapes$text$html_text$render_node$$;
$app$main$ui$shapes$text$html_text$render_node$$=function $app$main$ui$shapes$text$html_text$render_node$$($props_72484$$){var $map__72485__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_72484$$,"node")),$type$jscomp$570$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72485__$1$$,$APP.$cljs$cst$139$type$$),$component$jscomp$97_text$jscomp$63$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72485__$1$$,$APP.$cljs$cst$1588$text$$),
$children$jscomp$267$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72485__$1$$,$APP.$cljs$cst$342$children$$),$code_QMARK_$jscomp$5$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_72484$$,"code?");if(typeof $component$jscomp$97_text$jscomp$63$$==="string")return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$text$html_text$render_text$$,$props_72484$$);$component$jscomp$97_text$jscomp$63$$=function(){switch($type$jscomp$570$$){case "root":return $app$main$ui$shapes$text$html_text$render_root$$;
case "paragraph-set":return $app$main$ui$shapes$text$html_text$render_paragraph_set$$;case "paragraph":return $app$main$ui$shapes$text$html_text$render_paragraph$$;default:return null}}();return $APP.$cljs$core$truth_$$($component$jscomp$97_text$jscomp$63$$)?(0,$APP.$rumext$v2$create_element$$)($component$jscomp$97_text$jscomp$63$$,$props_72484$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$35$$,$JSCompiler_temp_const$jscomp$1334_p__72487$$){var $JSCompiler_inline_result$jscomp$1336_index$jscomp$377_props__$1$jscomp$inline_7411$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1334_p__72487$$,0,null),$node$jscomp$353$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1334_p__72487$$,1,null);$JSCompiler_temp_const$jscomp$1334_p__72487$$=$out_arr__44124__auto__$jscomp$35$$.push;$JSCompiler_inline_result$jscomp$1336_index$jscomp$377_props__$1$jscomp$inline_7411$$=$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$clone$$($props_72484$$),
"node",$node$jscomp$353$$),"parent",$map__72485__$1$$),"index",$JSCompiler_inline_result$jscomp$1336_index$jscomp$377_props__$1$jscomp$inline_7411$$),"key",$JSCompiler_inline_result$jscomp$1336_index$jscomp$377_props__$1$jscomp$inline_7411$$),"code?",$code_QMARK_$jscomp$5$$);$JSCompiler_inline_result$jscomp$1336_index$jscomp$377_props__$1$jscomp$inline_7411$$=(0,$APP.$rumext$v2$create_element$$)($app$main$ui$shapes$text$html_text$render_node$$,$JSCompiler_inline_result$jscomp$1336_index$jscomp$377_props__$1$jscomp$inline_7411$$);
$JSCompiler_temp_const$jscomp$1334_p__72487$$.call($out_arr__44124__auto__$jscomp$35$$,$JSCompiler_inline_result$jscomp$1336_index$jscomp$377_props__$1$jscomp$inline_7411$$);return $out_arr__44124__auto__$jscomp$35$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($children$jscomp$267$$))):null};
$APP.$app$main$ui$shapes$text$html_text$text_shape$$=(0,$APP.$rumext$v2$forward_ref$$)(function($code_QMARK_$jscomp$6_props_72493$$,$ref$jscomp$37$$){var $shape$jscomp$785$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($code_QMARK_$jscomp$6_props_72493$$,"shape"),$grow_type$jscomp$8$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($code_QMARK_$jscomp$6_props_72493$$,"grow-type");$code_QMARK_$jscomp$6_props_72493$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($code_QMARK_$jscomp$6_props_72493$$,
"code?");var $content$jscomp$227_content__$1$jscomp$40_map__72497__$1$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$785$$),$id$jscomp$806$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$227_content__$1$jscomp$40_map__72497__$1$$,$APP.$cljs$cst$266$id$$),$x$jscomp$1226$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$227_content__$1$jscomp$40_map__72497__$1$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$448$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$227_content__$1$jscomp$40_map__72497__$1$$,
$APP.$cljs$cst$1511$y$$),$style$jscomp$53_width$jscomp$168$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$227_content__$1$jscomp$40_map__72497__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$146$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$227_content__$1$jscomp$40_map__72497__$1$$,$APP.$cljs$cst$1522$height$$);$content$jscomp$227_content__$1$jscomp$40_map__72497__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$227_content__$1$jscomp$40_map__72497__$1$$,
$APP.$cljs$cst$1637$content$$);$content$jscomp$227_content__$1$jscomp$40_map__72497__$1$$=$APP.$cljs$core$truth_$$($code_QMARK_$jscomp$6_props_72493$$)?$app$common$text$index_content$cljs$0core$0IFn$0_invoke$0arity$01$$($content$jscomp$227_content__$1$jscomp$40_map__72497__$1$$):$content$jscomp$227_content__$1$jscomp$40_map__72497__$1$$;$style$jscomp$53_width$jscomp$168$$=$APP.$cljs$core$truth_$$($code_QMARK_$jscomp$6_props_72493$$)?null:{position:"fixed",left:0,top:0,background:"white",width:$APP.$cljs$core$truth_$$(function(){var $fexpr__72500$$=
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2036$auto_width$$,null],null),null);return $fexpr__72500$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__72500$$.$cljs$core$IFn$_invoke$arity$1$($grow_type$jscomp$8$$):$fexpr__72500$$($grow_type$jscomp$8$$)}())?1E5:$style$jscomp$53_width$jscomp$168$$,height:$APP.$cljs$core$truth_$$(function(){var $fexpr__72501$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2035$auto_height$$,null,$APP.$cljs$cst$2036$auto_width$$,null],null),null);return $fexpr__72501$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__72501$$.$cljs$core$IFn$_invoke$arity$1$($grow_type$jscomp$8$$):$fexpr__72501$$($grow_type$jscomp$8$$)}())?1E5:$height$jscomp$146$$};return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"text-node-html",id:"html-text-node-"+($id$jscomp$806$$??""),ref:$ref$jscomp$37$$,"data-x":$x$jscomp$1226$$,"data-y":$y$jscomp$448$$,style:$style$jscomp$53_width$jscomp$168$$,
children:[$APP.$cljs$core$not$$($code_QMARK_$jscomp$6_props_72493$$)?(0,$APP.$rumext$v2$jsx$$)("style",{children:".text-node { background-clip: text;\n                             -webkit-background-clip: text; }"}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$text$html_text$render_node$$,{index:0,shape:$shape$jscomp$785$$,node:$content$jscomp$227_content__$1$jscomp$40_map__72497__$1$$,"code?":$code_QMARK_$jscomp$6_props_72493$$})]})});$APP.$app$util$code_gen$generate_style_code$$=function $app$util$code_gen$generate_style_code$$($var_args$jscomp$1386$$){switch(arguments.length){case 4:return $app$util$code_gen$generate_style_code$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);case 5:return $app$util$code_gen$generate_style_code$$.$cljs$core$IFn$_invoke$arity$5$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$app$util$code_gen$generate_style_code$$.$cljs$core$IFn$_invoke$arity$4$=function($objects$jscomp$684$$,$type$jscomp$573$$,$root_shapes$jscomp$2$$,$all_shapes$jscomp$3$$){return $APP.$app$util$code_gen$generate_style_code$$.$cljs$core$IFn$_invoke$arity$5$($objects$jscomp$684$$,$type$jscomp$573$$,$root_shapes$jscomp$2$$,$all_shapes$jscomp$3$$,null)};
$APP.$app$util$code_gen$generate_style_code$$.$cljs$core$IFn$_invoke$arity$5$=function($objects$jscomp$685$$,$generate_style_type$jscomp$574$$,$root_shapes$jscomp$3$$,$all_shapes$jscomp$4$$,$options$jscomp$584$$){a:switch($generate_style_type$jscomp$574$$){case "css":$generate_style_type$jscomp$574$$=$APP.$app$util$code_gen$style_css$generate_style$$;break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($generate_style_type$jscomp$574$$)].join(""));
}return $generate_style_type$jscomp$574$$.$cljs$core$IFn$_invoke$arity$4$?$generate_style_type$jscomp$574$$.$cljs$core$IFn$_invoke$arity$4$($objects$jscomp$685$$,$root_shapes$jscomp$3$$,$all_shapes$jscomp$4$$,$options$jscomp$584$$):$generate_style_type$jscomp$574$$($objects$jscomp$685$$,$root_shapes$jscomp$3$$,$all_shapes$jscomp$4$$,$options$jscomp$584$$)};$APP.$app$util$code_gen$generate_style_code$$.$cljs$lang$maxFixedArity$=5;var $app$main$data$preview$update_preview_72595$$,$app$main$data$preview$open_preview_selected_72602$$,$app$main$data$preview$update_preview_window$$=function $app$main$data$preview$update_preview_window$$($preview$jscomp$1$$,$code$jscomp$43$$,$width$jscomp$169$$,$height$jscomp$147$$){return $APP.$cljs$core$truth_$$($preview$jscomp$1$$)?$APP.$cljs$core$truth_$$($preview$jscomp$1$$.load)?$preview$jscomp$1$$.load($code$jscomp$43$$,$width$jscomp$169$$,$height$jscomp$147$$):$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$main$data$preview$update_preview_window$$.$cljs$core$IFn$_invoke$arity$4$?
$app$main$data$preview$update_preview_window$$.$cljs$core$IFn$_invoke$arity$4$($preview$jscomp$1$$,$code$jscomp$43$$,$width$jscomp$169$$,$height$jscomp$147$$):$app$main$data$preview$update_preview_window$$($preview$jscomp$1$$,$code$jscomp$43$$,$width$jscomp$169$$,$height$jscomp$147$$)}):null};var $app$main$data$workspace$text$shortcuts$selected_shapes_with_children$$;
$app$main$data$workspace$text$shortcuts$selected_shapes_with_children$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($map__72619__$1_p__72618_selected$jscomp$120_shapes$jscomp$139$$){$map__72619__$1_p__72618_selected$jscomp$120_shapes$jscomp$139$$=$APP.$cljs$core$__destructure_map$$($map__72619__$1_p__72618_selected$jscomp$120_shapes$jscomp$139$$);var $objects$jscomp$687$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72619__$1_p__72618_selected$jscomp$120_shapes$jscomp$139$$,$APP.$cljs$cst$1631$objects$$);
$map__72619__$1_p__72618_selected$jscomp$120_shapes$jscomp$139$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72619__$1_p__72618_selected$jscomp$120_shapes$jscomp$139$$,$APP.$cljs$cst$1921$selected$$);var $xform$jscomp$38$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nil_QMARK_$$),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__72617_SHARP_$$){return $APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$687$$,
$p1__72617_SHARP_$$)}));$map__72619__$1_p__72618_selected$jscomp$120_shapes$jscomp$139$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($map__72619__$1_p__72618_selected$jscomp$120_shapes$jscomp$139$$,$xform$jscomp$38$$,$map__72619__$1_p__72618_selected$jscomp$120_shapes$jscomp$139$$);return $APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$687$$)),$map__72619__$1_p__72618_selected$jscomp$120_shapes$jscomp$139$$)},
$APP.$cljs$core$deref$$(new $APP.$cljs$core$Var$$(function(){return $app$main$refs$selected_shapes_data$$},$cljs$cst$4781$app_DOT_main_DOT_refs_SLASH_selected_shapes_data$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1478$private$$,$APP.$cljs$cst$176$ns$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$218$end_column$$,$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$209$line$$,$APP.$cljs$cst$217$end_line$$,$APP.$cljs$cst$1479$arglists$$,$APP.$cljs$cst$1480$doc$$,$APP.$cljs$cst$171$test$$],
[!0,$cljs$cst$4782$app_DOT_main_DOT_refs$$,$cljs$cst$4783$selected_shapes_data$$,"app/main/refs.cljs",36,1,172,172,$APP.$cljs$core$List$EMPTY$$,null,$APP.$cljs$core$truth_$$($app$main$refs$selected_shapes_data$$)?$app$main$refs$selected_shapes_data$$.$cljs$lang$test$:null]))));
$APP.$app$main$data$workspace$text$shortcuts$shortcuts$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$4784$underline$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("U"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("u"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4786$text_editor$$],null),$APP.$cljs$cst$516$fn$$,
function(){return $app$main$data$workspace$text$shortcuts$update_attrs_when_no_readonly$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1768$text_decoration$$,"toggle-underline"],null))}],null),$APP.$cljs$cst$4787$line_through$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$($app$main$data$shortcuts$meta_shift$$("5")),$APP.$cljs$cst$1812$command$$,"alt+shift+5",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4786$text_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$text$shortcuts$update_attrs_when_no_readonly$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1768$text_decoration$$,"toggle-line-through"],null))}],null),$cljs$cst$4779$font_size_inc$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$("\x3e"),$APP.$cljs$cst$1812$command$$,
$APP.$app$main$data$shortcuts$c_mod$$("shift+."),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4786$text_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$text$shortcuts$update_attrs_when_no_readonly$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$4779$font_size_inc$$,!0],null))}],null),$cljs$cst$4780$font_size_dec$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$("\x3c"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+,"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4786$text_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$text$shortcuts$update_attrs_when_no_readonly$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$4780$font_size_dec$$,
!0],null))}],null),$cljs$cst$4788$bold$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("b"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("b"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4786$text_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$text$shortcuts$update_attrs_when_no_readonly$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1759$font_variant_id$$,"toggle-bold"],null))}],null),$cljs$cst$4789$italic$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("i"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("i"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4786$text_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$text$shortcuts$update_attrs_when_no_readonly$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1759$font_variant_id$$,"toggle-italic"],null))}],null)],null);var $app$main$data$workspace$shortcuts$esc_pressed_72632$$,$app$main$data$workspace$shortcuts$esc_pressed$$,$app$main$data$workspace$shortcuts$base_shortcuts$$,$app$main$data$workspace$shortcuts$debug_shortcuts$$,$app$main$data$workspace$shortcuts$opacity_shortcuts$$,$G__72652$jscomp$inline_7426$$;
typeof $app$main$data$workspace$shortcuts$esc_pressed_72632$$==="undefined"&&($app$main$data$workspace$shortcuts$esc_pressed_72632$$=function($meta72633$jscomp$inline_7419$$){this.$meta72633$=$meta72633$jscomp$inline_7419$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$shortcuts$esc_pressed_72632$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$4790$app_DOT_main_DOT_data_DOT_workspace_DOT_shortcuts_SLASH_esc_pressed$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72634$jscomp$inline_7420$$,$meta72633__$1$jscomp$inline_7421$$){return new $app$main$data$workspace$shortcuts$esc_pressed_72632$$($meta72633__$1$jscomp$inline_7421$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72633$},
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_inline_result$jscomp$10917__$jscomp$inline_7422_selection$jscomp$inline_12962$$,$state$jscomp$inline_7423$$){$JSCompiler_inline_result$jscomp$10917__$jscomp$inline_7422_selection$jscomp$inline_12962$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$inline_7423$$,
$APP.$cljs$cst$1920$workspace_local$$),$APP.$cljs$cst$1921$selected$$);$JSCompiler_inline_result$jscomp$10917__$jscomp$inline_7422_selection$jscomp$inline_12962$$=$APP.$cljs$core$empty_QMARK_$$($JSCompiler_inline_result$jscomp$10917__$jscomp$inline_7422_selection$jscomp$inline_12962$$)?$app$main$data$plugins$close_current_plugin$$():$app$main$data$workspace$deselect_all$$.$cljs$core$IFn$_invoke$arity$1$(!0);return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2169$interrupt$$,$JSCompiler_inline_result$jscomp$10917__$jscomp$inline_7422_selection$jscomp$inline_12962$$)});
$app$main$data$workspace$shortcuts$esc_pressed$$=new $app$main$data$workspace$shortcuts$esc_pressed_72632$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
$app$main$data$workspace$shortcuts$base_shortcuts$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$4791$duplicate$$,$APP.$cljs$cst$4792$escape$$,$APP.$cljs$cst$4793$find$$,$APP.$cljs$cst$2689$mask$$,$APP.$cljs$cst$4794$draw_frame$$,$APP.$cljs$cst$4795$bool_intersection$$,$cljs$cst$4796$clear_undo$$,$APP.$cljs$cst$4797$draw_ellipse$$,$APP.$cljs$cst$4798$copy$$,$cljs$cst$4799$open_comments$$,$cljs$cst$4800$toggle_layers$$,$cljs$cst$4801$zoom_lense_decrease$$,$cljs$cst$4802$start_measure$$,
$cljs$cst$4803$toggle_assets$$,$APP.$cljs$cst$4804$toggle_layout_flex$$,$APP.$cljs$cst$4805$add_comment$$,$APP.$cljs$cst$4806$fit_all$$,$cljs$cst$4807$toggle_lock_size$$,$APP.$cljs$cst$4808$toggle_colorpalette$$,$APP.$cljs$cst$1608$group$$,$cljs$cst$4809$open_dashboard$$,$APP.$cljs$cst$4810$h_distribute$$,$cljs$cst$4811$open_color_picker$$,$APP.$cljs$cst$4812$toggle_snap_ruler_guide$$,$APP.$cljs$cst$4813$draw_text$$,$APP.$cljs$cst$4814$align_left$$,$APP.$cljs$cst$4815$draw_rect$$,$APP.$cljs$cst$2210$snap_pixel_grid$$,
$APP.$cljs$cst$4816$draw_path$$,$cljs$cst$4817$open_inspect$$,$APP.$cljs$cst$4818$v_distribute$$,$cljs$cst$4819$paste_replace$$,$APP.$cljs$cst$4820$bring_front$$,$APP.$cljs$cst$1902$scale$$,$cljs$cst$4821$move_unit_down$$,$APP.$cljs$cst$3717$show_pixel_grid$$,$APP.$cljs$cst$4822$redo$$,$APP.$cljs$cst$4823$toggle_layout_grid$$,$cljs$cst$4824$select_next$$,$APP.$cljs$cst$4825$hide_ui$$,$APP.$cljs$cst$4826$toggle_guides$$,$cljs$cst$4827$move_fast_down$$,$APP.$cljs$cst$4828$bring_forward$$,$APP.$cljs$cst$4829$flip_horizontal$$,
$APP.$cljs$cst$4830$bool_union$$,$APP.$cljs$cst$4831$copy_props$$,$APP.$cljs$cst$1798$move$$,$APP.$cljs$cst$4832$bool_difference$$,$APP.$cljs$cst$4833$paste$$,$APP.$cljs$cst$4834$delete$$,$APP.$cljs$cst$4835$rename$$,$cljs$cst$4836$move_unit_up$$,$APP.$cljs$cst$4837$copy_link$$,$APP.$cljs$cst$4838$insert_image$$,$APP.$cljs$cst$4839$toggle_focus_mode$$,$APP.$cljs$cst$4840$flip_vertical$$,$APP.$cljs$cst$4841$decrease_zoom$$,$APP.$cljs$cst$4842$open_viewer$$,$APP.$cljs$cst$4843$select_all$$,$cljs$cst$4844$select_prev$$,
$APP.$cljs$cst$4845$toggle_history$$,$APP.$cljs$cst$4846$increase_zoom$$,$APP.$cljs$cst$4847$toggle_visibility$$,$APP.$cljs$cst$4848$toggle_snap_guides$$,$APP.$cljs$cst$4849$reset_zoom$$,$APP.$cljs$cst$4850$undo$$,$APP.$cljs$cst$4851$bool_exclude$$,$cljs$cst$4852$move_fast_right$$,$APP.$cljs$cst$4853$toggle_textpalette$$,$cljs$cst$4854$select_parent_layer$$,$APP.$cljs$cst$4855$bring_backward$$,$APP.$cljs$cst$3197$plugins$$,$APP.$cljs$cst$4856$zoom_selected$$,$cljs$cst$4857$move_unit_right$$,$cljs$cst$4858$move_fast_left$$,
$APP.$cljs$cst$4859$start_editing$$,$APP.$cljs$cst$4534$find_and_replace$$,$APP.$cljs$cst$4860$toggle_alignment$$,$APP.$cljs$cst$4861$ungroup$$,$APP.$cljs$cst$4862$artboard_selection$$,$cljs$cst$4863$zoom_lense_increase$$,$APP.$cljs$cst$4864$align_right$$,$APP.$cljs$cst$4865$align_hcenter$$,$APP.$cljs$cst$4866$unmask$$,$APP.$cljs$cst$4867$show_shortcuts$$,$APP.$cljs$cst$4868$toggle_lock$$,$APP.$cljs$cst$4869$create_component_variant$$,$APP.$cljs$cst$4125$export_shapes$$,$APP.$cljs$cst$4870$detach_component$$,
$APP.$cljs$cst$4871$toggle_rulers$$,$APP.$cljs$cst$4872$paste_props$$,$cljs$cst$4873$move_fast_up$$,$APP.$cljs$cst$4874$toggle_theme$$,$APP.$cljs$cst$4875$align_top$$,$APP.$cljs$cst$4876$thumbnail_set$$,$cljs$cst$4877$move_unit_left$$,$APP.$cljs$cst$4878$align_bottom$$,$cljs$cst$4879$stop_measure$$,$APP.$cljs$cst$4880$bring_back$$,$APP.$cljs$cst$4881$cut$$,$APP.$cljs$cst$4882$align_vcenter$$,$APP.$cljs$cst$4883$draw_curve$$],[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,
$APP.$app$main$data$shortcuts$meta$$("D"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("d"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$duplicate_or_add_variant$$()]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$esc$$(),$APP.$cljs$cst$1812$command$$,"escape",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$esc_pressed$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("F"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("f"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4793$find$$,
null))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("M"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("m"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$mask_group$$.$cljs$core$IFn$_invoke$arity$0$()]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"B",$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["b","a"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4886$tools$$,$APP.$cljs$cst$4887$basics$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$drawing$select_for_drawing$$($APP.$cljs$cst$1606$frame$$)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$($app$main$data$shortcuts$alt$$("I")),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("alt+i"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1811$shape$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([(0,$APP.$app$main$data$workspace$create_bool$$)($APP.$cljs$cst$2034$intersection$$)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("Q"),$APP.$cljs$cst$1812$command$$,"alt+q",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$undo$reinitialize_undo$$]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"E",$APP.$cljs$cst$1812$command$$,"e",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4886$tools$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$drawing$select_for_drawing$$($APP.$cljs$cst$1417$circle$$)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("C"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("c"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$clipboard$copy_selected$$())}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"G C",$APP.$cljs$cst$1812$command$$,"g c",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4888$navigation_workspace$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_viewer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1366$section$$,
$APP.$cljs$cst$3436$comments$$])))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("L"),$APP.$cljs$cst$1812$command$$,$app$main$data$shortcuts$a_mod$$("l"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4889$panels$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1615$layout$$,
$APP.$cljs$cst$3727$layers$$])))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("Z"),$APP.$cljs$cst$1812$command$$,"alt+z",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4890$zoom_workspace$$],null),$APP.$cljs$cst$516$fn$$,$APP.$cljs$core$identity$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$(""),
$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["alt","."],null),$APP.$cljs$cst$139$type$$,"keydown",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$toggle_distances_display$$(!0)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("I"),$APP.$cljs$cst$1812$command$$,$app$main$data$shortcuts$a_mod$$("i"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4889$panels$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1615$layout$$,
$APP.$cljs$cst$3718$assets$$])))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("A"),$APP.$cljs$cst$1812$command$$,"shift+a",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$with_meta$$($app$main$data$workspace$shape_layout$toggle_layout$$($APP.$cljs$cst$1660$flex$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:shortcuts"],null))]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"C",$APP.$cljs$cst$1812$command$$,"c",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4886$tools$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$drawing$select_for_drawing$$($APP.$cljs$cst$3436$comments$$))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("1"),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["shift+1","shift+num1"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4890$zoom_workspace$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_fit_all$$)}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("L"),$APP.$cljs$cst$1812$command$$,"shift+l",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4886$tools$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$toggle_proportion_lock$$()]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("P"),$APP.$cljs$cst$1812$command$$,$app$main$data$shortcuts$a_mod$$("p"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4889$panels$$],null),$APP.$cljs$cst$516$fn$$,function(){$APP.$app$main$ui$hooks$resize$last_resize_type$$=$APP.$cljs$cst$1563$bottom$$;return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3726$hide_palettes$$),
$APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3740$textpalette$$),$app$main$data$workspace$shortcuts$toggle_layout_flag$$($APP.$cljs$cst$3715$colorpalette$$)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("G"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("g"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$groups$group_selected$$()]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"G D",$APP.$cljs$cst$1812$command$$,"g d",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4888$navigation_workspace$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_recent$$())}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$($app$main$data$shortcuts$alt$$("H")),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+alt+h"),
$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4891$alignment$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$distribute_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1909$horizontal$$,null)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"I",$APP.$cljs$cst$1812$command$$,"i",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4886$tools$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$picker_for_selected_shape$$()]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$("G"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+g"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4892$main_menu$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$toggle_layout_flag$$($APP.$cljs$cst$3723$snap_ruler_guides$$))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"T",$APP.$cljs$cst$1812$command$$,"t",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4886$tools$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$texts$start_edit_if_selected$$,
$APP.$app$main$data$workspace$drawing$select_for_drawing$$($APP.$cljs$cst$1588$text$$)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("A"),$APP.$cljs$cst$1812$command$$,"alt+a",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4891$alignment$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$align_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3419$hleft$$,
null)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"R",$APP.$cljs$cst$1812$command$$,"r",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4886$tools$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$drawing$select_for_drawing$$($APP.$cljs$cst$1611$rect$$)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1812$command$$,",",$APP.$cljs$cst$2946$tooltip$$,",",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4892$main_menu$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$toggle_layout_flag$$($APP.$cljs$cst$2210$snap_pixel_grid$$))}],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"P",$APP.$cljs$cst$1812$command$$,"p",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4886$tools$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$drawing$select_for_drawing$$($APP.$cljs$cst$296$path$$)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"G I",$APP.$cljs$cst$1812$command$$,"g i",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4888$navigation_workspace$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_viewer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1366$section$$,
$APP.$cljs$cst$2672$inspect$$])))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$($app$main$data$shortcuts$alt$$("V")),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+alt+v"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4891$alignment$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$distribute_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1910$vertical$$,
null)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$($APP.$app$main$data$shortcuts$shift$$("V")),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+v"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$paste_from_clipboard$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$4103$replace_QMARK_$$,!0],null))]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$("↑"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+up"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$vertical_order_selected$$($APP.$cljs$cst$1562$top$$)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"K",$APP.$cljs$cst$1812$command$$,"k",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4886$tools$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$toggle_layout_flag$$($APP.$cljs$cst$3716$scale_text$$)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"↓",$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["down","alt+down"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$transforms$move_selected$$($APP.$cljs$cst$1953$down$$,
!1)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$(","),$APP.$cljs$cst$1812$command$$,"shift+,",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4892$main_menu$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$toggle_layout_flag$$($APP.$cljs$cst$3717$show_pixel_grid$$))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("Y"),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$shortcuts$c_mod$$("shift+z"),$APP.$app$main$data$shortcuts$c_mod$$("y")],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],
null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$undo$redo$$]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$("A"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+a"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$with_meta$$($app$main$data$workspace$shape_layout$toggle_layout$$($APP.$cljs$cst$1659$grid$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"workspace:shortcuts"],null))]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"tab",$APP.$cljs$cst$1812$command$$,"tab",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4888$navigation_workspace$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$selection$select_next_shape$$())}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"\\",$APP.$cljs$cst$1812$command$$,"\\",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4889$panels$$,$APP.$cljs$cst$4887$basics$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$toggle_layout_flag$$($APP.$cljs$cst$4825$hide_ui$$))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("'"),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$shortcuts$c_mod$$("'"),$APP.$app$main$data$shortcuts$c_mod$$("219")],null),$APP.$cljs$cst$4893$show_command$$,$APP.$app$main$data$shortcuts$c_mod$$("'"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4892$main_menu$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$toggle_layout_flag$$($APP.$cljs$cst$3725$display_guides$$))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("↓"),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["shift+down","shift+alt+down"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$transforms$move_selected$$($APP.$cljs$cst$1953$down$$,
!0)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("↑"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("up"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$vertical_order_selected$$($APP.$cljs$cst$1954$up$$)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("H"),$APP.$cljs$cst$1812$command$$,"shift+h",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$flip_horizontal_selected$$.$cljs$core$IFn$_invoke$arity$0$()]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$($app$main$data$shortcuts$alt$$("U")),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("alt+u"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1811$shape$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([(0,$APP.$app$main$data$workspace$create_bool$$)($APP.$cljs$cst$736$union$$)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$($app$main$data$shortcuts$alt$$("c")),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("alt+c"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$clipboard$copy_selected_props$$())}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"V",$APP.$cljs$cst$1812$command$$,"v",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4886$tools$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2169$interrupt$$]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$($app$main$data$shortcuts$alt$$("D")),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("alt+d"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1811$shape$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([(0,$APP.$app$main$data$workspace$create_bool$$)($APP.$cljs$cst$2025$difference$$)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("V"),$APP.$cljs$cst$2948$disabled$$,!0,$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("v"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,$APP.$cljs$core$constantly$$(null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$supr$$(),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["del","backspace"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$delete_selected$$()]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("N"),$APP.$cljs$cst$1812$command$$,"alt+n",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$start_rename_selected$$()]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"↑",$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["up","alt+up"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$transforms$move_selected$$($APP.$cljs$cst$1954$up$$,
!1)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$($app$main$data$shortcuts$alt$$("C")),$APP.$cljs$cst$1812$command$$,"shift+alt+c",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$clipboard$copy_link_to_clipboard$$())}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("K"),$APP.$cljs$cst$1812$command$$,"shift+k",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4886$tools$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$util$dom$click$$($APP.$goog$dom$getElement$$("image-upload"))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1812$command$$,
"f",$APP.$cljs$cst$2946$tooltip$$,"F",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4887$basics$$,$cljs$cst$4886$tools$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$toggle_focus_mode$$())}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("V"),
$APP.$cljs$cst$1812$command$$,"shift+v",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$flip_vertical_selected$$.$cljs$core$IFn$_invoke$arity$0$()]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"-",$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["-","_"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4890$zoom_workspace$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$decrease_zoom$$.$cljs$core$IFn$_invoke$arity$0$())}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"G V",$APP.$cljs$cst$1812$command$$,"g v",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4888$navigation_workspace$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_viewer$$())}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("A"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("a"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4892$main_menu$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$select_all$$())}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("tab"),$APP.$cljs$cst$1812$command$$,"shift+tab",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4888$navigation_workspace$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$selection$select_prev_shape$$())}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$($APP.$app$main$data$shortcuts$meta$$("H")),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$($app$main$data$shortcuts$a_mod$$("h")),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4889$panels$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([(0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$3719$document_history$$)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"+",$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["+","\x3d"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4890$zoom_workspace$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$increase_zoom$$.$cljs$core$IFn$_invoke$arity$0$())}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$("H"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+h"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4886$tools$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shapes$toggle_visibility_selected$$()]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$("'"),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$shortcuts$c_mod$$("shift+'"),$APP.$app$main$data$shortcuts$c_mod$$("shift+219")],null),$APP.$cljs$cst$4893$show_command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+'"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4892$main_menu$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$toggle_layout_flag$$($APP.$cljs$cst$3720$snap_guides$$))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("0"),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["shift+0","shift+num0"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4890$zoom_workspace$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$reset_zoom$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("Z"),$APP.$cljs$cst$1812$command$$,
$APP.$app$main$data$shortcuts$c_mod$$("z"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$undo$undo$$]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$($app$main$data$shortcuts$alt$$("E")),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("alt+e"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1811$shape$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([(0,$APP.$app$main$data$workspace$create_bool$$)($APP.$cljs$cst$2033$exclude$$)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("→"),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["shift+right","shift+alt+right"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$transforms$move_selected$$($APP.$cljs$cst$258$right$$,
!0)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("T"),$APP.$cljs$cst$1812$command$$,$app$main$data$shortcuts$a_mod$$("t"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4889$panels$$],null),$APP.$cljs$cst$516$fn$$,function(){$APP.$app$main$ui$hooks$resize$last_resize_type$$=$APP.$cljs$cst$1563$bottom$$;return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3726$hide_palettes$$),
$APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3715$colorpalette$$),$app$main$data$workspace$shortcuts$toggle_layout_flag$$($APP.$cljs$cst$3740$textpalette$$)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$($app$main$data$shortcuts$enter$$),$APP.$cljs$cst$1812$command$$,"shift+enter",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$4888$navigation_workspace$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$select_parent_layer$$()]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("↓"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("down"),
$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$vertical_order_selected$$($APP.$cljs$cst$1953$down$$)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$($app$main$data$shortcuts$alt$$("P")),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("alt+p"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4887$basics$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"plugins/runtime")?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2311$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"open-plugins-manager",$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:shortcuts"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4894$plugin_management$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)])):null}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("2"),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["shift+2","shift+num2","@",'"'],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4890$zoom_workspace$$],
null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_selected_shape$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"←",$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["left","alt+left"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$transforms$move_selected$$($APP.$cljs$cst$257$left$$,!1)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("←"),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["shift+left","shift+alt+left"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$transforms$move_selected$$($APP.$cljs$cst$257$left$$,
!0)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$enter$$(),$APP.$cljs$cst$1812$command$$,"enter",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$start_editing_selected$$()]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("H"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("h"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4534$find_and_replace$$,
null))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("\\"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("\\"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4892$main_menu$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$toggle_layout_flag$$($APP.$cljs$cst$3724$dynamic_alignment$$))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("G"),$APP.$cljs$cst$1812$command$$,"shift+g",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$groups$ungroup_selected$$()]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$($app$main$data$shortcuts$alt$$("G")),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("alt+g"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$shapes$create_artboard_from_selection$cljs$0core$0IFn$0_invoke$0arity$05$$(null,
null,null,null)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"Z",$APP.$cljs$cst$1812$command$$,"z",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4890$zoom_workspace$$],null),$APP.$cljs$cst$516$fn$$,$APP.$cljs$core$identity$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("D"),$APP.$cljs$cst$1812$command$$,
"alt+d",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4891$alignment$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$align_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3418$hright$$,null)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("H"),$APP.$cljs$cst$1812$command$$,"alt+h",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4891$alignment$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$align_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3417$hcenter$$,
null)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$("M"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+m"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$unmask_group$$.$cljs$core$IFn$_invoke$arity$0$()]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"?",$APP.$cljs$cst$1812$command$$,"?",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4892$main_menu$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$toggle_layout_flag$$($APP.$cljs$cst$2950$shortcuts$$))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$("L"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+l"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4886$tools$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shapes$toggle_lock_selected$$()]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("K"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("k"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$variants$add_component_or_variant$$()]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$("E"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+e"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4887$basics$$,$APP.$cljs$cst$4892$main_menu$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$exports$assets$show_workspace_export_dialog$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1786$origin$$,"workspace:shortcuts"],null)))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$("K"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+k"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$libraries$detach_selected_components$$]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$("R"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+r"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4892$main_menu$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$toggle_layout_flag$$($APP.$cljs$cst$2211$rulers$$))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$($app$main$data$shortcuts$alt$$("v")),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("alt+v"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$clipboard$paste_selected_props$$())}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("↑"),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["shift+up","shift+alt+up"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$transforms$move_selected$$($APP.$cljs$cst$1954$up$$,
!0)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("M"),$APP.$cljs$cst$1812$command$$,$app$main$data$shortcuts$a_mod$$("m"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4887$basics$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$profile$toggle_theme$$(),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:shortcut"],null)))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("W"),$APP.$cljs$cst$1812$command$$,"alt+w",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4891$alignment$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$align_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3415$vtop$$,
null)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("T"),$APP.$cljs$cst$1812$command$$,"shift+t",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4892$main_menu$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$toggle_file_thumbnail_selected$$())}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"→",$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["right","alt+right"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$transforms$move_selected$$($APP.$cljs$cst$258$right$$,
!1)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("S"),$APP.$cljs$cst$1812$command$$,"alt+s",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4891$alignment$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$align_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3416$vbottom$$,
null)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$(""),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["alt","."],null),$APP.$cljs$cst$139$type$$,"keyup",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$toggle_distances_display$$(!1)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$meta_shift$$("↓"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("shift+down"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$vertical_order_selected$$($APP.$cljs$cst$1563$bottom$$)]))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("X"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("x"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4884$edit$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$clipboard$copy_selected$$(),
$APP.$app$main$data$workspace$delete_selected$$()]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("V"),$APP.$cljs$cst$1812$command$$,"alt+v",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4891$alignment$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$align_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3420$vcenter$$,
null)]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("C"),$APP.$cljs$cst$1812$command$$,"shift+c",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4886$tools$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$drawing$select_for_drawing$$($APP.$cljs$cst$2052$curve$$)]))}],
null)]);
$app$main$data$workspace$shortcuts$debug_shortcuts$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$4895$preview_frame$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$($app$main$data$shortcuts$alt$$($app$main$data$shortcuts$enter$$)),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("alt+enter"),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$preview$open_preview_selected$$()]))}],null)],
null);
$app$main$data$workspace$shortcuts$opacity_shortcuts$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($n$jscomp$294$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$(["opacity-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$294$$)].join("")),new $APP.$cljs$core$PersistentArrayMap$$(null,4,
[$APP.$cljs$cst$2946$tooltip$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$294$$),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$294$$),["num",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$294$$)].join("")],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$4885$modify_layers$$],null),$APP.$cljs$cst$516$fn$$,function(){return $app$main$data$workspace$shortcuts$emit_when_no_readonly$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$layers$pressed_opacity$$($n$jscomp$294$$)]))}],null)],null)},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$(10)));
$G__72652$jscomp$inline_7426$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$base_shortcuts$$,$app$main$data$workspace$shortcuts$opacity_shortcuts$$,$APP.$app$main$data$workspace$text$shortcuts$shortcuts$$]));
$APP.$app$main$data$workspace$shortcuts$shortcuts$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__72652$jscomp$inline_7426$$,$app$main$data$workspace$shortcuts$debug_shortcuts$$])):$G__72652$jscomp$inline_7426$$;var $app$main$ui$components$context_menu_a11y$xf_COLON_options$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$some_QMARK_$$));$APP.$app$common$types$organization$organization__GT_team_keys$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$3256$organization_id$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$3257$organization_name$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3326$custom_photo$$,$cljs$cst$3327$organization_custom_photo$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3323$slug$$,$cljs$cst$3258$organization_slug$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3325$avatar_bg_url$$,$cljs$cst$3260$organization_avatar_bg_url$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3324$owner_id$$,$cljs$cst$3259$organization_owner_id$$],null)],null);$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Profile"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1569$created_at$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1737$modified_at$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$1139$app_DOT_common_DOT_time_SLASH_inst$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4902$is_default$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4903$is_pinned$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1080$count$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$4904$total_count$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$cljs$cst$958$app_DOT_common_DOT_schema_SLASH_int$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1927$team_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null));var $app$main$data$dashboard$project_created_72932$$,$app$main$data$dashboard$project_duplicated_72947$$,$app$main$data$dashboard$duplicate_project_72957$$,$app$main$data$dashboard$move_project_72974$$,$app$main$data$dashboard$toggle_project_pin_72981$$,$app$main$data$dashboard$rename_project_72989$$,$app$main$data$dashboard$delete_project_72998$$,$app$main$data$dashboard$file_created_73053$$,$app$main$data$dashboard$move_files_73082$$,$app$main$data$dashboard$clone_template_73096$$,$app$main$data$dashboard$create_element_73100$$;
$APP.$app$common$logging$loggers$$.set("app.main.data.dashboard",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));
$APP.$app$main$data$dashboard$check_search_params$$=$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$462$closed$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2516$search_term$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null)],null));$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$("title-medium title-small body-large headline-medium code-font body-small body-medium headline-large title-large headline-small display".split(" "));var $app$main$ui$workspace$plugins$close_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_plugins__close-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-close"})});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$$,$APP.$cljs$cst$4894$plugin_management$$,$app$main$ui$workspace$plugins$plugin_management_dialog$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$1$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$1$$,$APP.$cljs$cst$4993$plugin_permissions$$,$app$main$ui$workspace$plugins$plugins_permissions_dialog$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$2$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$2$$,$cljs$cst$3401$plugin_permissions_update$$,$app$main$ui$workspace$plugins$plugins_permissions_updated_dialog$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$3$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$3$$,$APP.$cljs$cst$4995$plugin_try_out$$,$app$main$ui$workspace$plugins$plugins_try_out_dialog$$)});var $app$main$ui$comments$ref_COLON_comments_local_options$$,$app$main$ui$comments$mentions_context$$,$app$main$ui$comments$r_mentions_split$$,$app$main$ui$comments$r_mentions$$,$app$main$ui$comments$r_url_split$$,$app$main$ui$comments$calculate_zoom_scale$$;$app$main$ui$comments$ref_COLON_comments_local_options$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$873$options$$,$APP.$app$main$refs$comments_local$$);$app$main$ui$comments$mentions_context$$=(0,$APP.$rumext$v2$create_context$$)(null);
$app$main$ui$comments$r_mentions_split$$=/@\[[^\]]*\]\([^\)]*\)/;$app$main$ui$comments$r_mentions$$=/@\[([^\]]*)\]\(([^\)]*)\)/;$app$main$ui$comments$r_url_split$$=/https?:\/\/[^\s\)\]]+[^\s\)\]\.,;:!?]/;
$APP.$app$main$ui$comments$comment_floating_thread_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($origin$jscomp$49_props_73389$$){var $pos$jscomp$128_viewport$jscomp$4$$=$origin$jscomp$49_props_73389$$.viewport,$pos_y$jscomp$1_zoom$jscomp$43$$=$origin$jscomp$49_props_73389$$.zoom,$max_height$jscomp$3_position_modifier$jscomp$1$$=$origin$jscomp$49_props_73389$$.positionModifier,$thread$jscomp$37$$=$origin$jscomp$49_props_73389$$.thread;$origin$jscomp$49_props_73389$$=$origin$jscomp$49_props_73389$$.origin;
var $ref$jscomp$38$$=(0,$APP.$rumext$v2$use_ref$$)(),$mentions_s$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subject$$()}),$thread_id$jscomp$14$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$37$$),$thread_pos$$=$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$37$$),$base_pos$jscomp$1_comments$jscomp$2_comments_ref_margin_x$jscomp$5$$=$max_height$jscomp$3_position_modifier$jscomp$1$$!=
null?$APP.$app$common$geom$point$transform$$($thread_pos$$,$max_height$jscomp$3_position_modifier$jscomp$1$$):$thread_pos$$;$max_height$jscomp$3_position_modifier$jscomp$1$$=$pos$jscomp$128_viewport$jscomp$4$$!=null?$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$128_viewport$jscomp$4$$)*.5|0:null;var $bubble_margin$jscomp$2_pos_x$jscomp$1$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(24,24);$pos$jscomp$128_viewport$jscomp$4$$=$app$main$ui$comments$offset_position$$($base_pos$jscomp$1_comments$jscomp$2_comments_ref_margin_x$jscomp$5$$,
$pos$jscomp$128_viewport$jscomp$4$$,$pos_y$jscomp$1_zoom$jscomp$43$$,$bubble_margin$jscomp$2_pos_x$jscomp$1$$);$base_pos$jscomp$1_comments$jscomp$2_comments_ref_margin_x$jscomp$5$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($bubble_margin$jscomp$2_pos_x$jscomp$1$$)*($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5006$h_dir$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$128_viewport$jscomp$4$$),$APP.$cljs$cst$257$left$$)?-1:1);var $first_comment_margin_y$jscomp$5$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($bubble_margin$jscomp$2_pos_x$jscomp$1$$)*
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5007$v_dir$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$128_viewport$jscomp$4$$),$APP.$cljs$cst$1562$top$$)?-1:1);$bubble_margin$jscomp$2_pos_x$jscomp$1$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$128_viewport$jscomp$4$$)*$pos_y$jscomp$1_zoom$jscomp$43$$+$base_pos$jscomp$1_comments$jscomp$2_comments_ref_margin_x$jscomp$5$$;$pos_y$jscomp$1_zoom$jscomp$43$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$128_viewport$jscomp$4$$)*
$pos_y$jscomp$1_zoom$jscomp$43$$-$first_comment_margin_y$jscomp$5$$;$base_pos$jscomp$1_comments$jscomp$2_comments_ref_margin_x$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($thread_id$jscomp$14$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3436$comments$$,$thread_id$jscomp$14$$],
null)),$APP.$app$main$store$state$$)});var $comments_map$$=$APP.$rumext$v2$deref$$($base_pos$jscomp$1_comments$jscomp$2_comments_ref_margin_x$jscomp$5$$);$base_pos$jscomp$1_comments$jscomp$2_comments_ref_margin_x$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($comments_map$$)],function(){return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1569$created_at$$,$APP.$cljs$core$vals$$($comments_map$$))});$first_comment_margin_y$jscomp$5$$=
$APP.$cljs$core$first$$($base_pos$jscomp$1_comments$jscomp$2_comments_ref_margin_x$jscomp$5$$);var $on_submit$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($thread$jscomp$37$$)],function($content$jscomp$236$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$add_comment$$($thread$jscomp$37$$,$content$jscomp$236$$))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($thread_id$jscomp$14$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$retrieve_comments$$($thread_id$jscomp$14$$))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($thread_id$jscomp$14$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$update_comment_thread_status$$($thread_id$jscomp$14$$))});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($thread_pos$$),
$APP.$rumext$v2$adapt$$($comments_map$$)],function(){var $temp__5825__auto__$jscomp$268$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$38$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$268$$)?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5825__auto__$jscomp$268$$,!1):null});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($app$main$ui$comments$mentions_context$$),{value:$mentions_s$jscomp$4$$,children:$first_comment_margin_y$jscomp$5$$!=
null?(0,$APP.$rumext$v2$jsxs$$)("div",{id:["thread-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($thread_id$jscomp$14$$)].join(""),style:{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($bubble_margin$jscomp$2_pos_x$jscomp$1$$),"px"].join(""),top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos_y$jscomp$1_zoom$jscomp$43$$),"px"].join(""),"--comment-height":[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($max_height$jscomp$3_position_modifier$jscomp$1$$),"px"].join("")},
onClick:$APP.$app$util$dom$stop_propagation$$,className:"main_ui_comments__floating-thread-wrapper main_ui_comments__cursor-auto "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5006$h_dir$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$128_viewport$jscomp$4$$),$APP.$cljs$cst$257$left$$)?"main_ui_comments__left":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5007$v_dir$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$128_viewport$jscomp$4$$),$APP.$cljs$cst$1562$top$$)?
"main_ui_comments__top":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__floating-thread-header",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_floating_thread_header_STAR_$$,{thread:$thread$jscomp$37$$,origin:$origin$jscomp$49_props_73389$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_comments__floating-thread-main",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_floating_thread_item_STAR_$$,{comment:$first_comment_margin_y$jscomp$5$$,
thread:$thread$jscomp$37$$}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$40$$,$item$jscomp$97$$){$out_arr__44124__auto__$jscomp$40$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_floating_thread_item_STAR_$$,{comment:$item$jscomp$97$$})},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$97$$)??"")));return $out_arr__44124__auto__$jscomp$40$$},
[],$APP.$cljs$core$rest$$($base_pos$jscomp$1_comments$jscomp$2_comments_ref_margin_x$jscomp$5$$))]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_reply_form_STAR_$$,{onSubmit:$on_submit$jscomp$6$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$mentions_panel_STAR_$$,{})]}):null})});
$app$main$ui$comments$calculate_zoom_scale$$=function $app$main$ui$comments$calculate_zoom_scale$$($position$jscomp$178$$,$zoom$jscomp$46$$,$threads$jscomp$8$$,$wl$jscomp$1$$){var $num_threads$$=$APP.$cljs$core$count$$($threads$jscomp$8$$),$grouped_threads$$=$APP.$app$main$ui$comments$group_bubbles$cljs$0core$0IFn$0_invoke$0arity$04$$($zoom$jscomp$46$$,$threads$jscomp$8$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$num_grouped_threads$$=$APP.$cljs$core$count$$($grouped_threads$$),
$scaled_zoom$$=$zoom$jscomp$46$$*1.75,$zoomed_wl$$=$app$main$data$workspace$zoom$impl_update_zoom$$($wl$jscomp$1$$,$position$jscomp$178$$,$scaled_zoom$$),$outside_vbox_QMARK_$$=$APP.$cljs$core$complement$$($app$main$ui$comments$inside_vbox_QMARK_$$);return $APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$931$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($num_threads$$,$num_grouped_threads$$);return $or__5025__auto__$jscomp$931$$?$or__5025__auto__$jscomp$931$$:$APP.$cljs$core$some$$(function($p1__73417_SHARP_$$){return $outside_vbox_QMARK_$$($p1__73417_SHARP_$$,
$zoomed_wl$$)},$grouped_threads$$)}())?$zoom$jscomp$46$$:$app$main$ui$comments$calculate_zoom_scale$$.$cljs$core$IFn$_invoke$arity$4$?$app$main$ui$comments$calculate_zoom_scale$$.$cljs$core$IFn$_invoke$arity$4$($position$jscomp$178$$,$scaled_zoom$$,$threads$jscomp$8$$,$zoomed_wl$$):$app$main$ui$comments$calculate_zoom_scale$$($position$jscomp$178$$,$scaled_zoom$$,$threads$jscomp$8$$,$zoomed_wl$$)};
$APP.$app$main$ui$comments$comment_floating_group_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($pos_x$jscomp$3_position_modifier$jscomp$2_props_73420$$){var $thread_group$jscomp$1$$=$pos_x$jscomp$3_position_modifier$jscomp$2_props_73420$$.threadGroup,$zoom$jscomp$47$$=$pos_x$jscomp$3_position_modifier$jscomp$2_props_73420$$.zoom;$pos_x$jscomp$3_position_modifier$jscomp$2_props_73420$$=$pos_x$jscomp$3_position_modifier$jscomp$2_props_73420$$.positionModifier;var $pos_y$jscomp$3_position$jscomp$179_positions$jscomp$2$$=
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$position$$,$thread_group$jscomp$1$$);$pos_y$jscomp$3_position$jscomp$179_positions$jscomp$2$$=$app$common$geom$point$center_points$$($pos_y$jscomp$3_position$jscomp$179_positions$jscomp$2$$);var $position__$1$jscomp$6$$=$pos_x$jscomp$3_position_modifier$jscomp$2_props_73420$$!=null?$APP.$app$common$geom$point$transform$$($pos_y$jscomp$3_position$jscomp$179_positions$jscomp$2$$,$pos_x$jscomp$3_position_modifier$jscomp$2_props_73420$$):
$pos_y$jscomp$3_position$jscomp$179_positions$jscomp$2$$;$pos_x$jscomp$3_position_modifier$jscomp$2_props_73420$$=$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($position__$1$jscomp$6$$)*$zoom$jscomp$47$$;$pos_y$jscomp$3_position$jscomp$179_positions$jscomp$2$$=$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($position__$1$jscomp$6$$)*$zoom$jscomp$47$$;var $unread_QMARK_$$=$APP.$cljs$core$some$$(function($p1__73419_SHARP_$$){return $APP.$cljs$cst$3428$count_unread_comments$$.$cljs$core$IFn$_invoke$arity$1$($p1__73419_SHARP_$$)>
0},$thread_group$jscomp$1$$),$num_threads$jscomp$1$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$count$$($thread_group$jscomp$1$$)),$test_id$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("-",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3426$seqn$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3426$seqn$$,$thread_group$jscomp$1$$))),$on_click$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($thread_group$jscomp$1$$),
$APP.$rumext$v2$adapt$$($position__$1$jscomp$6$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$47$$)],function(){var $centered_wl_scale_zoom$jscomp$1_wl$jscomp$2$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_local$$);$centered_wl_scale_zoom$jscomp$1_wl$jscomp$2$$=$app$main$data$workspace$viewport$calculate_centered_viewbox$$($centered_wl_scale_zoom$jscomp$1_wl$jscomp$2$$,$position__$1$jscomp$6$$);$centered_wl_scale_zoom$jscomp$1_wl$jscomp$2$$=$app$main$ui$comments$calculate_zoom_scale$$($position__$1$jscomp$6$$,
$zoom$jscomp$47$$,$thread_group$jscomp$1$$,$centered_wl_scale_zoom$jscomp$1_wl$jscomp$2$$)/$zoom$jscomp$47$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$viewport$update_viewport_position_center$$($position__$1$jscomp$6$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$zoom$set_zoom$cljs$0core$0IFn$0_invoke$0arity$02$$($position__$1$jscomp$6$$,$centered_wl_scale_zoom$jscomp$1_wl$jscomp$2$$)]))});
return(0,$APP.$rumext$v2$jsx$$)("div",{style:{top:""+($pos_y$jscomp$3_position$jscomp$179_positions$jscomp$2$$??"")+"px",left:""+($pos_x$jscomp$3_position_modifier$jscomp$2_props_73420$$??"")+"px"},onClick:$on_click$jscomp$8$$,className:"main_ui_comments__floating-preview-wrapper main_ui_comments__floating-preview-bubble",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_avatar_STAR_$$,{className:"main_ui_comments__avatar-lg",variant:$APP.$cljs$core$truth_$$($unread_QMARK_$$)?"unread":
"read","data-testid":"floating-thread-bubble-"+($test_id$$??""),children:$num_threads$jscomp$1$$})})});
$APP.$app$main$ui$comments$comment_floating_bubble_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($owner$jscomp$2_props_73428$$){var $is_open$$=$owner$jscomp$2_props_73428$$.isOpen,$zoom$jscomp$48$$=$owner$jscomp$2_props_73428$$.zoom,$pos_x$jscomp$4_position_modifier$jscomp$3$$=$owner$jscomp$2_props_73428$$.positionModifier,$on_click$jscomp$9$$=$owner$jscomp$2_props_73428$$.onClick,$thread$jscomp$38$$=$owner$jscomp$2_props_73428$$.thread,$origin$jscomp$50$$=$owner$jscomp$2_props_73428$$.origin;
$owner$jscomp$2_props_73428$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($thread$jscomp$38$$)],function(){return $APP.$app$main$data$comments$get_owner$$($thread$jscomp$38$$)});var $pos_y$jscomp$4_position$jscomp$180$$=$APP.$cljs$cst$1676$position$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$38$$),$position__$1$jscomp$7$$=$pos_x$jscomp$4_position_modifier$jscomp$3$$!=null?$APP.$app$common$geom$point$transform$$($pos_y$jscomp$4_position$jscomp$180$$,
$pos_x$jscomp$4_position_modifier$jscomp$3$$):$pos_y$jscomp$4_position$jscomp$180$$,$frame_id$jscomp$110$$=$APP.$cljs$cst$1607$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$38$$),$state$jscomp$1064$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$5008$is_hover$$,!1,$cljs$cst$5009$is_grabbing$$,!1,$cljs$cst$5010$new_position_x$$,null,$cljs$cst$5011$new_position_y$$,null,$APP.$cljs$cst$5012$new_frame_id$$,
$frame_id$jscomp$110$$],null)});$pos_x$jscomp$4_position_modifier$jscomp$3$$=$cljs$math$floor$$(function(){var $or__5025__auto__$jscomp$932$$=$cljs$cst$5010$new_position_x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1064$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$932$$)?$or__5025__auto__$jscomp$932$$:$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($position__$1$jscomp$7$$)}()*$zoom$jscomp$48$$);$pos_y$jscomp$4_position$jscomp$180$$=$cljs$math$floor$$(function(){var $or__5025__auto__$jscomp$933$$=
$cljs$cst$5011$new_position_y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1064$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$933$$)?$or__5025__auto__$jscomp$933$$:$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($position__$1$jscomp$7$$)}()*$zoom$jscomp$48$$);var $drag_QMARK_$$=(0,$APP.$rumext$v2$use_ref$$)(null),$was_open_QMARK_$$=(0,$APP.$rumext$v2$use_ref$$)(null),$dragging_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$start_ref$jscomp$1$$=
(0,$APP.$rumext$v2$use_ref$$)(null),$on_pointer_down$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($origin$jscomp$50$$),$APP.$rumext$v2$adapt$$($was_open_QMARK_$$),$APP.$rumext$v2$adapt$$($is_open$$),$APP.$rumext$v2$adapt$$($drag_QMARK_$$)],function($event$jscomp$161$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$50$$,$APP.$cljs$cst$1592$viewer$$)?($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1064$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5009$is_grabbing$$,!0),$APP.$rumext$v2$set_ref_val_BANG_$$($was_open_QMARK_$$,$is_open$$),$APP.$cljs$core$truth_$$($is_open$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$close_thread$$()),$APP.$rumext$v2$set_ref_val_BANG_$$($drag_QMARK_$$,!1),$APP.$app$util$dom$stop_propagation$$($event$jscomp$161$$),$APP.$app$util$dom$capture_pointer$$($event$jscomp$161$$),$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$1$$,
!0),$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$1$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$161$$))):null}),$on_pointer_up$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($origin$jscomp$50$$),$APP.$rumext$v2$adapt$$($thread$jscomp$38$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$select_keys$$($APP.$cljs$core$_deref$$($state$jscomp$1064$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5010$new_position_x$$,
$cljs$cst$5011$new_position_y$$,$APP.$cljs$cst$5012$new_frame_id$$],null)))],function($event$jscomp$162$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$50$$,$APP.$cljs$cst$1592$viewer$$)&&($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1064$$,$APP.$cljs$core$assoc$$,$cljs$cst$5009$is_grabbing$$,!1),$APP.$app$util$dom$stop_propagation$$($event$jscomp$162$$),$APP.$app$util$dom$release_pointer$$($event$jscomp$162$$),$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$1$$,
!1),$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$1$$,null),$cljs$cst$5010$new_position_x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1064$$))!=null&&$cljs$cst$5011$new_position_y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1064$$))!=null)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$comments$update_comment_thread_position$cljs$0core$0IFn$0_invoke$0arity$02$$($thread$jscomp$38$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5010$new_position_x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1064$$)),$cljs$cst$5011$new_position_y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1064$$))],null))),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$1064$$,$APP.$cljs$core$assoc$$,$cljs$cst$5010$new_position_x$$,null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5011$new_position_y$$,
null]))):null}),$on_pointer_move$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($origin$jscomp$50$$),$APP.$rumext$v2$adapt$$($drag_QMARK_$$),$APP.$rumext$v2$adapt$$($position__$1$jscomp$7$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$48$$)],function($delta_x_event$jscomp$163$$){if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$50$$,$APP.$cljs$cst$1592$viewer$$)&&($APP.$rumext$v2$set_ref_val_BANG_$$($drag_QMARK_$$,!0),$APP.$app$util$dom$stop_propagation$$($delta_x_event$jscomp$163$$),
$APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$1$$)))){var $delta_y_start_pt$$=$APP.$rumext$v2$ref_val$$($start_ref$jscomp$1$$),$current_pt$$=$APP.$app$util$dom$get_client_position$$($delta_x_event$jscomp$163$$);$delta_x_event$jscomp$163$$=($APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($current_pt$$)-$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($delta_y_start_pt$$))/$zoom$jscomp$48$$;$delta_y_start_pt$$=($APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($current_pt$$)-
$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($delta_y_start_pt$$))/$zoom$jscomp$48$$;return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$1064$$,$APP.$cljs$core$assoc$$,$cljs$cst$5010$new_position_x$$,$APP.$cljs$cst$1510$x$$.$cljs$core$IFn$_invoke$arity$1$($position__$1$jscomp$7$$)+$delta_x_event$jscomp$163$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5011$new_position_y$$,$APP.$cljs$cst$1511$y$$.$cljs$core$IFn$_invoke$arity$1$($position__$1$jscomp$7$$)+
$delta_y_start_pt$$]))}return null}),$on_pointer_enter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open$$)],function($event$jscomp$164$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$164$$);return $is_open$$===!1?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1064$$,$APP.$cljs$core$assoc$$,$cljs$cst$5008$is_hover$$,!0):null}),$on_pointer_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$165$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$165$$);
return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1064$$,$APP.$cljs$core$assoc$$,$cljs$cst$5008$is_hover$$,!1)}),$on_click_STAR_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($origin$jscomp$50$$),$APP.$rumext$v2$adapt$$($thread$jscomp$38$$),$APP.$rumext$v2$adapt$$($on_click$jscomp$9$$),$APP.$rumext$v2$adapt$$($was_open_QMARK_$$),$APP.$rumext$v2$adapt$$($drag_QMARK_$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$select_keys$$($APP.$cljs$core$_deref$$($state$jscomp$1064$$),
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5008$is_hover$$],null)))],function($and__5023__auto__$jscomp$inline_12971_event$jscomp$166_or__5025__auto__$jscomp$inline_12970$$){$APP.$app$util$dom$stop_propagation$$($and__5023__auto__$jscomp$inline_12971_event$jscomp$166_or__5025__auto__$jscomp$inline_12970$$);$and__5023__auto__$jscomp$inline_12971_event$jscomp$166_or__5025__auto__$jscomp$inline_12970$$=$APP.$rumext$v2$ref_val$$($was_open_QMARK_$$);
$and__5023__auto__$jscomp$inline_12971_event$jscomp$166_or__5025__auto__$jscomp$inline_12970$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_12971_event$jscomp$166_or__5025__auto__$jscomp$inline_12970$$)?$APP.$rumext$v2$ref_val$$($drag_QMARK_$$):$and__5023__auto__$jscomp$inline_12971_event$jscomp$166_or__5025__auto__$jscomp$inline_12970$$;$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_12971_event$jscomp$166_or__5025__auto__$jscomp$inline_12970$$)?$and__5023__auto__$jscomp$inline_12971_event$jscomp$166_or__5025__auto__$jscomp$inline_12970$$:
$APP.$cljs$core$not$$($APP.$rumext$v2$ref_val$$($was_open_QMARK_$$))&&$APP.$cljs$core$not$$($APP.$rumext$v2$ref_val$$($drag_QMARK_$$)))&&($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1064$$,$APP.$cljs$core$assoc$$,$cljs$cst$5008$is_hover$$,!1),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$open_thread$$($thread$jscomp$38$$)));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$50$$,$APP.$cljs$cst$1592$viewer$$)?
$on_click$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$38$$):$on_click$jscomp$9$$($thread$jscomp$38$$):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__floating-preview-wrapper "+($cljs$cst$5008$is_hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1064$$))===!1?"main_ui_comments__floating-preview-bubble":""),children:$APP.$cljs$core$truth_$$($cljs$cst$5008$is_hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1064$$)))?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__floating-thread-wrapper main_ui_comments__floating-preview-displacement "+($cljs$cst$5009$is_grabbing$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1064$$))===!1?"main_ui_comments__cursor-pointer":"")+" "+($cljs$cst$5009$is_grabbing$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1064$$))===!0?"main_ui_comments__cursor-grabbing":""),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__floating-thread-item-wrapper",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_comments__floating-thread-item",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_info_STAR_$$,{item:$thread$jscomp$38$$,profile:$owner$jscomp$2_props_73428$$})})})}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$comments$comment_avatar_STAR_$$,{image:$APP.$app$config$resolve_profile_photo_url$$($owner$jscomp$2_props_73428$$),className:"main_ui_comments__avatar-lg","data-testid":"floating-thread-bubble-"+($APP.$cljs$cst$3426$seqn$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$38$$)??
""),variant:$APP.$cljs$core$truth_$$($APP.$cljs$cst$3445$is_resolved$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$38$$))?"solved":$APP.$cljs$cst$3428$count_unread_comments$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$38$$)>0?"unread":"read"}),onPointerUp:$on_pointer_up$$,style:{top:""+($pos_y$jscomp$4_position$jscomp$180$$??"")+"px",left:""+($pos_x$jscomp$4_position_modifier$jscomp$3$$??"")+"px"},onClick:$on_click_STAR_$$,onPointerMove:$on_pointer_move$jscomp$1$$,onPointerDown:$on_pointer_down$jscomp$1$$,
onPointerLeave:$on_pointer_leave$$,onPointerEnter:$on_pointer_enter$$})});var $app$main$data$exports$files$export_files_73210$$,$app$main$data$exports$files$check_export_files$$;$APP.$app$main$data$exports$files$valid_types$$=$APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2124$all$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$735$merge$$,$cljs$cst$5014$detach$$]));
$app$main$data$exports$files$check_export_files$$=$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$720$sequential$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"Files"],null),new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"FileParam"],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2181$project_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2182$is_shared$$,$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$],null)],null)],null));var $app$main$data$workspace$versions$initialize_version_73323$$;$APP.$app$main$data$workspace$versions$default_state$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$109$status$$,$APP.$cljs$cst$5019$loading$$,$APP.$cljs$cst$142$data$$,null,$APP.$cljs$cst$2152$editing$$,null,$APP.$cljs$cst$5020$preview_id$$,null],null);var $app$main$data$nitrate$show_nitrate_popup_73339$$,$app$main$data$nitrate$leave_org_73378$$;
$APP.$app$main$data$nitrate$go_to_nitrate_cc$$=function $app$main$data$nitrate$go_to_nitrate_cc$$($var_args$jscomp$1394$$){switch(arguments.length){case 0:return $app$main$data$nitrate$go_to_nitrate_cc$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $app$main$data$nitrate$go_to_nitrate_cc$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$APP.$app$main$data$nitrate$go_to_nitrate_cc$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2462$href$$,"/control-center/"])))};
$APP.$app$main$data$nitrate$go_to_nitrate_cc$$.$cljs$core$IFn$_invoke$arity$1$=function($href$jscomp$12_organization_id$jscomp$5_p__73361$$){var $map__73362__$1_organization_slug$$=$APP.$cljs$core$__destructure_map$$($href$jscomp$12_organization_id$jscomp$5_p__73361$$);$href$jscomp$12_organization_id$jscomp$5_p__73361$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73362__$1_organization_slug$$,$APP.$cljs$cst$3256$organization_id$$);$map__73362__$1_organization_slug$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73362__$1_organization_slug$$,
$cljs$cst$3258$organization_slug$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($href$jscomp$12_organization_id$jscomp$5_p__73361$$)?$map__73362__$1_organization_slug$$:$href$jscomp$12_organization_id$jscomp$5_p__73361$$)?($href$jscomp$12_organization_id$jscomp$5_p__73361$$="/control-center/org/"+($app$common$uri$percent_encode$$.$cljs$core$IFn$_invoke$arity$1$($map__73362__$1_organization_slug$$)??"")+"/"+($app$common$uri$percent_encode$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($href$jscomp$12_organization_id$jscomp$5_p__73361$$))??
"")+"/people/",$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2462$href$$,$href$jscomp$12_organization_id$jscomp$5_p__73361$$])))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2462$href$$,
"/control-center/"])))};$APP.$app$main$data$nitrate$go_to_nitrate_cc$$.$cljs$lang$maxFixedArity$=1;$APP.$app$main$data$nitrate$go_to_subscription_url$$=$APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,"#/settings/subscriptions"]));$APP.$JSCompiler_prototypeAlias$$=$app$util$forms$t_app$0util$0forms73504$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73506$$,$meta73505__$1$$){return new $app$util$forms$t_app$0util$0forms73504$$(this.$internal_state$,this.$rerender_fn$,this.$wrap_update_fn$,this.$opts$,$meta73505__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73505$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IDeref$_deref$arity$1$=function(){return $APP.$rumext$v2$ref_val$$(this.$internal_state$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReset$_reset_BANG_$arity$2$=function($_$jscomp$2805_initial_73535_state_73537$$,$initial_errors_73536_new_value$jscomp$7$$){$initial_errors_73536_new_value$jscomp$7$$==null?($_$jscomp$2805_initial_73535_state_73537$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$(this.$internal_state$),$APP.$cljs$cst$5076$initial$$),$initial_errors_73536_new_value$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$(this.$internal_state$),
$APP.$cljs$cst$5077$initial_errors$$),$_$jscomp$2805_initial_73535_state_73537$$=$app$util$forms$make_initial_state$$($_$jscomp$2805_initial_73535_state_73537$$,$initial_errors_73536_new_value$jscomp$7$$),$APP.$rumext$v2$set_ref_val_BANG_$$(this.$internal_state$,$_$jscomp$2805_initial_73535_state_73537$$)):$APP.$rumext$v2$set_ref_val_BANG_$$(this.$internal_state$,$initial_errors_73536_new_value$jscomp$7$$);return this.$rerender_fn$.$cljs$core$IFn$_invoke$arity$0$?this.$rerender_fn$.$cljs$core$IFn$_invoke$arity$0$():
this.$rerender_fn$()};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$2$=function($JSCompiler_temp_const$jscomp$1351__$jscomp$2806$$,$JSCompiler_inline_result$jscomp$1352_f$jscomp$839_f__$1$jscomp$29$$){$JSCompiler_inline_result$jscomp$1352_f$jscomp$839_f__$1$jscomp$29$$=this.$wrap_update_fn$.$cljs$core$IFn$_invoke$arity$2$?this.$wrap_update_fn$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1352_f$jscomp$839_f__$1$jscomp$29$$,this.$opts$):this.$wrap_update_fn$($JSCompiler_inline_result$jscomp$1352_f$jscomp$839_f__$1$jscomp$29$$,this.$opts$);
$JSCompiler_temp_const$jscomp$1351__$jscomp$2806$$=this.$internal_state$;var $G__73511$jscomp$inline_7465$$=$APP.$rumext$v2$ref_val$$(this.$internal_state$);$JSCompiler_inline_result$jscomp$1352_f$jscomp$839_f__$1$jscomp$29$$=$JSCompiler_inline_result$jscomp$1352_f$jscomp$839_f__$1$jscomp$29$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$1352_f$jscomp$839_f__$1$jscomp$29$$.$cljs$core$IFn$_invoke$arity$1$($G__73511$jscomp$inline_7465$$):$JSCompiler_inline_result$jscomp$1352_f$jscomp$839_f__$1$jscomp$29$$($G__73511$jscomp$inline_7465$$);
$APP.$rumext$v2$set_ref_val_BANG_$$($JSCompiler_temp_const$jscomp$1351__$jscomp$2806$$,$JSCompiler_inline_result$jscomp$1352_f$jscomp$839_f__$1$jscomp$29$$);return this.$rerender_fn$.$cljs$core$IFn$_invoke$arity$0$?this.$rerender_fn$.$cljs$core$IFn$_invoke$arity$0$():this.$rerender_fn$()};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$3$=function($JSCompiler_temp_const$jscomp$1353__$jscomp$2807$$,$f$jscomp$840_f__$1$jscomp$30$$,$JSCompiler_inline_result$jscomp$1354_x$jscomp$1228$$){$f$jscomp$840_f__$1$jscomp$30$$=this.$wrap_update_fn$.$cljs$core$IFn$_invoke$arity$2$?this.$wrap_update_fn$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$840_f__$1$jscomp$30$$,this.$opts$):this.$wrap_update_fn$($f$jscomp$840_f__$1$jscomp$30$$,this.$opts$);$JSCompiler_temp_const$jscomp$1353__$jscomp$2807$$=
this.$internal_state$;var $G__73512$jscomp$inline_7467$$=$APP.$rumext$v2$ref_val$$(this.$internal_state$);$JSCompiler_inline_result$jscomp$1354_x$jscomp$1228$$=$f$jscomp$840_f__$1$jscomp$30$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$840_f__$1$jscomp$30$$.$cljs$core$IFn$_invoke$arity$2$($G__73512$jscomp$inline_7467$$,$JSCompiler_inline_result$jscomp$1354_x$jscomp$1228$$):$f$jscomp$840_f__$1$jscomp$30$$($G__73512$jscomp$inline_7467$$,$JSCompiler_inline_result$jscomp$1354_x$jscomp$1228$$);$APP.$rumext$v2$set_ref_val_BANG_$$($JSCompiler_temp_const$jscomp$1353__$jscomp$2807$$,
$JSCompiler_inline_result$jscomp$1354_x$jscomp$1228$$);return this.$rerender_fn$.$cljs$core$IFn$_invoke$arity$0$?this.$rerender_fn$.$cljs$core$IFn$_invoke$arity$0$():this.$rerender_fn$()};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$4$=function($JSCompiler_temp_const$jscomp$1355__$jscomp$2808$$,$f$jscomp$841_f__$1$jscomp$31$$,$JSCompiler_inline_result$jscomp$1356_x$jscomp$1229$$,$y$jscomp$450$$){$f$jscomp$841_f__$1$jscomp$31$$=this.$wrap_update_fn$.$cljs$core$IFn$_invoke$arity$2$?this.$wrap_update_fn$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$841_f__$1$jscomp$31$$,this.$opts$):this.$wrap_update_fn$($f$jscomp$841_f__$1$jscomp$31$$,this.$opts$);$JSCompiler_temp_const$jscomp$1355__$jscomp$2808$$=
this.$internal_state$;var $G__73514$jscomp$inline_7469$$=$APP.$rumext$v2$ref_val$$(this.$internal_state$);$JSCompiler_inline_result$jscomp$1356_x$jscomp$1229$$=$f$jscomp$841_f__$1$jscomp$31$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$841_f__$1$jscomp$31$$.$cljs$core$IFn$_invoke$arity$3$($G__73514$jscomp$inline_7469$$,$JSCompiler_inline_result$jscomp$1356_x$jscomp$1229$$,$y$jscomp$450$$):$f$jscomp$841_f__$1$jscomp$31$$($G__73514$jscomp$inline_7469$$,$JSCompiler_inline_result$jscomp$1356_x$jscomp$1229$$,
$y$jscomp$450$$);$APP.$rumext$v2$set_ref_val_BANG_$$($JSCompiler_temp_const$jscomp$1355__$jscomp$2808$$,$JSCompiler_inline_result$jscomp$1356_x$jscomp$1229$$);return this.$rerender_fn$.$cljs$core$IFn$_invoke$arity$0$?this.$rerender_fn$.$cljs$core$IFn$_invoke$arity$0$():this.$rerender_fn$()};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISwap$_swap_BANG_$arity$5$=function($_$jscomp$2809_f__$1$jscomp$32$$,$f$jscomp$842$$,$x$jscomp$1230$$,$y$jscomp$451$$,$more$jscomp$51$$){$_$jscomp$2809_f__$1$jscomp$32$$=this.$wrap_update_fn$.$cljs$core$IFn$_invoke$arity$2$?this.$wrap_update_fn$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$842$$,this.$opts$):this.$wrap_update_fn$($f$jscomp$842$$,this.$opts$);$APP.$rumext$v2$set_ref_val_BANG_$$(this.$internal_state$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($_$jscomp$2809_f__$1$jscomp$32$$,
$APP.$rumext$v2$ref_val$$(this.$internal_state$),$x$jscomp$1230$$,$y$jscomp$451$$,$more$jscomp$51$$));return this.$rerender_fn$.$cljs$core$IFn$_invoke$arity$0$?this.$rerender_fn$.$cljs$core$IFn$_invoke$arity$0$():this.$rerender_fn$()};$APP.$app$main$ui$components$forms$form_ctx$$=(0,$APP.$rumext$v2$create_context$$)(null);var $app$main$ui$dashboard$change_owner$schema_COLON_leave_modal_form$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"LeaveModalForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$3274$member_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null);
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$4$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$4$$,$cljs$cst$5100$leave_and_reassign$$,$app$main$ui$dashboard$change_owner$leave_and_reassign_modal$$)});
var $app$main$ui$dashboard$change_owner$leave_and_reassign_org_modal$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($all_valid_QMARK__initial_values_props_73599$$){var $map__73600$$=$APP.$rumext$v2$util$wrap_props$$($all_valid_QMARK__initial_values_props_73599$$),$map__73600__$1$$=$APP.$cljs$core$__destructure_map$$($map__73600$$),$profile$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73600__$1$$,$APP.$cljs$cst$1914$profile$$),$teams_to_transfer$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73600__$1$$,
$cljs$cst$5101$teams_to_transfer$$),$num_teams_to_delete$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73600__$1$$,$cljs$cst$5102$num_teams_to_delete$$),$accept$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73600__$1$$,$APP.$cljs$cst$924$accept$$),$schema$jscomp$242$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($teams_to_transfer$$)],function(){return $app$main$ui$dashboard$change_owner$make_leave_org_modal_form_schema$$($teams_to_transfer$$)}),
$team_fields$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($teams_to_transfer$$)],function(){return function $app$main$ui$dashboard$change_owner$leave_and_reassign_org_modal_$_iter__73613$$($s__73614$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $temp__5825__auto__$jscomp$277$$=$APP.$cljs$core$seq$$($s__73614$$);if($temp__5825__auto__$jscomp$277$$){var $s__73614__$2$$=$temp__5825__auto__$jscomp$277$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($s__73614__$2$$)){var $c__5501__auto__$jscomp$35$$=
$APP.$cljs$core$_chunked_first$$($s__73614__$2$$),$size__5502__auto__$jscomp$35$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$35$$),$b__73616$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$35$$);return function(){for(var $i__73615$$=0;;)if($i__73615$$<$size__5502__auto__$jscomp$35$$){var $team$jscomp$20$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$35$$,$i__73615$$);$APP.$cljs$core$chunk_append$$($b__73616$$,function(){var $default_member_id$jscomp$1_first_admin_members$jscomp$5$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$20$$,$APP.$cljs$cst$3264$members$$),$field_name$jscomp$1_filtered_members$jscomp$1_first_member$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($i__73615$jscomp$1$$,$members$jscomp$6$$,$team$jscomp$21$$,$c__5501__auto__$jscomp$36$$,$size__5502__auto__$jscomp$36$$,$b__73616$jscomp$1$$,$s__73614__$2$jscomp$1$$,$temp__5825__auto__$jscomp$278$$,$schema$jscomp$243$$,$map__73600$jscomp$1$$,$map__73600__$1$jscomp$1$$,
$props$jscomp$255$$,$profile$jscomp$37$$){return function($p1__73598_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($p1__73598_SHARP_$$),$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$37$$))}}($i__73615$$,$default_member_id$jscomp$1_first_admin_members$jscomp$5$$,$team$jscomp$20$$,$c__5501__auto__$jscomp$35$$,$size__5502__auto__$jscomp$35$$,$b__73616$$,$s__73614__$2$$,$temp__5825__auto__$jscomp$277$$,
$schema$jscomp$242$$,$map__73600$$,$map__73600__$1$$,$map__73600__$1$$,$profile$jscomp$36$$,$teams_to_transfer$$,$num_teams_to_delete$$,$accept$jscomp$8$$),$default_member_id$jscomp$1_first_admin_members$jscomp$5$$);$default_member_id$jscomp$1_first_admin_members$jscomp$5$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1597$is_admin$$,$field_name$jscomp$1_filtered_members$jscomp$1_first_member$$));$field_name$jscomp$1_filtered_members$jscomp$1_first_member$$=
$APP.$cljs$core$first$$($field_name$jscomp$1_filtered_members$jscomp$1_first_member$$);$default_member_id$jscomp$1_first_admin_members$jscomp$5$$=$APP.$cljs$core$truth_$$($default_member_id$jscomp$1_first_admin_members$jscomp$5$$)?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($default_member_id$jscomp$1_first_admin_members$jscomp$5$$)):$APP.$cljs$core$truth_$$($field_name$jscomp$1_filtered_members$jscomp$1_first_member$$)?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($field_name$jscomp$1_filtered_members$jscomp$1_first_member$$)):
"";$field_name$jscomp$1_filtered_members$jscomp$1_first_member$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$(["member-id-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$20$$))].join(""));return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2492$team$$,$team$jscomp$20$$,$cljs$cst$5103$field_name$$,$field_name$jscomp$1_filtered_members$jscomp$1_first_member$$,$cljs$cst$5104$default_member_id$$,
$default_member_id$jscomp$1_first_admin_members$jscomp$5$$],null)}());$i__73615$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__73616$$),$app$main$ui$dashboard$change_owner$leave_and_reassign_org_modal_$_iter__73613$$($APP.$cljs$core$_chunked_rest$$($s__73614__$2$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__73616$$),null)}var $team$jscomp$19$$=$APP.$cljs$core$first$$($s__73614__$2$$);return $APP.$cljs$core$cons$$(function(){var $default_member_id$jscomp$2_first_admin$jscomp$1_members$jscomp$7$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$19$$,$APP.$cljs$cst$3264$members$$),$field_name$jscomp$2_filtered_members$jscomp$2_first_member$jscomp$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($members$jscomp$8$$,$team$jscomp$22$$,$s__73614__$2$jscomp$2$$,$temp__5825__auto__$jscomp$279$$,$schema$jscomp$244$$,$map__73600$jscomp$2$$,$map__73600__$1$jscomp$2$$,$props$jscomp$256$$,$profile$jscomp$38$$){return function($p1__73598_SHARP_$jscomp$1$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($p1__73598_SHARP_$jscomp$1$$),
$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$38$$))}}($default_member_id$jscomp$2_first_admin$jscomp$1_members$jscomp$7$$,$team$jscomp$19$$,$s__73614__$2$$,$temp__5825__auto__$jscomp$277$$,$schema$jscomp$242$$,$map__73600$$,$map__73600__$1$$,$map__73600__$1$$,$profile$jscomp$36$$,$teams_to_transfer$$,$num_teams_to_delete$$,$accept$jscomp$8$$),$default_member_id$jscomp$2_first_admin$jscomp$1_members$jscomp$7$$);$default_member_id$jscomp$2_first_admin$jscomp$1_members$jscomp$7$$=
$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1597$is_admin$$,$field_name$jscomp$2_filtered_members$jscomp$2_first_member$jscomp$1$$));$field_name$jscomp$2_filtered_members$jscomp$2_first_member$jscomp$1$$=$APP.$cljs$core$first$$($field_name$jscomp$2_filtered_members$jscomp$2_first_member$jscomp$1$$);$default_member_id$jscomp$2_first_admin$jscomp$1_members$jscomp$7$$=$APP.$cljs$core$truth_$$($default_member_id$jscomp$2_first_admin$jscomp$1_members$jscomp$7$$)?
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($default_member_id$jscomp$2_first_admin$jscomp$1_members$jscomp$7$$)):$APP.$cljs$core$truth_$$($field_name$jscomp$2_filtered_members$jscomp$2_first_member$jscomp$1$$)?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($field_name$jscomp$2_filtered_members$jscomp$2_first_member$jscomp$1$$)):"";$field_name$jscomp$2_filtered_members$jscomp$2_first_member$jscomp$1$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$(["member-id-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$19$$))].join(""));return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2492$team$$,$team$jscomp$19$$,$cljs$cst$5103$field_name$$,$field_name$jscomp$2_filtered_members$jscomp$2_first_member$jscomp$1$$,$cljs$cst$5104$default_member_id$$,$default_member_id$jscomp$2_first_admin$jscomp$1_members$jscomp$7$$],
null)}(),$app$main$ui$dashboard$change_owner$leave_and_reassign_org_modal_$_iter__73613$$($APP.$cljs$core$rest$$($s__73614__$2$$)))}return null}},null,null)}($teams_to_transfer$$)});$all_valid_QMARK__initial_values_props_73599$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_fields$$)],function(){return $APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$03$$($cljs$cst$5103$field_name$$,$cljs$cst$5104$default_member_id$$,$team_fields$$)});var $form$jscomp$169$$=
$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$schema$jscomp$242$$,$APP.$cljs$cst$5076$initial$$,$all_valid_QMARK__initial_values_props_73599$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$schema$jscomp$242$$,$APP.$cljs$cst$5076$initial$$,$all_valid_QMARK__initial_values_props_73599$$);$all_valid_QMARK__initial_values_props_73599$$=$APP.$cljs$core$every_QMARK_$$(function($field_name$jscomp$3_map__73618__$1_p__73617_val$jscomp$190$$){$field_name$jscomp$3_map__73618__$1_p__73617_val$jscomp$190$$=
$APP.$cljs$core$__destructure_map$$($field_name$jscomp$3_map__73618__$1_p__73617_val$jscomp$190$$);$field_name$jscomp$3_map__73618__$1_p__73617_val$jscomp$190$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($field_name$jscomp$3_map__73618__$1_p__73617_val$jscomp$190$$,$cljs$cst$5103$field_name$$);$field_name$jscomp$3_map__73618__$1_p__73617_val$jscomp$190$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$169$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5074$clean_data$$,$field_name$jscomp$3_map__73618__$1_p__73617_val$jscomp$190$$],null));return!$APP.$cuerdas$core$blank_QMARK_$$($field_name$jscomp$3_map__73618__$1_p__73617_val$jscomp$190$$)},$team_fields$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_change_owner__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_change_owner__modal-org-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_change_owner__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_dashboard_change_owner__modal-org-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.before-leave-org.title")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_dashboard_change_owner__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_change_owner__modal-content",
children:[$num_teams_to_delete$$===0?(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_dashboard_change_owner__modal-org-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-org-and-reassign.hint")}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_dashboard_change_owner__modal-org-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-org-and-reassign.hint-delete")}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_dashboard_change_owner__modal-org-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-org-and-reassign.hint-promote")})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$form$$,{form:$form$jscomp$169$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_change_owner__teams-container",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$47$$,$p__73622_team$jscomp$24$$){var $default_member_id$jscomp$3_map__73623__$1$$=
$APP.$cljs$core$__destructure_map$$($p__73622_team$jscomp$24$$);$p__73622_team$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($default_member_id$jscomp$3_map__73623__$1$$,$APP.$cljs$cst$2492$team$$);var $field_name$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($default_member_id$jscomp$3_map__73623__$1$$,$cljs$cst$5103$field_name$$);$default_member_id$jscomp$3_map__73623__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($default_member_id$jscomp$3_map__73623__$1$$,
$cljs$cst$5104$default_member_id$$);$out_arr__44124__auto__$jscomp$47$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$change_owner$team_member_select_STAR_$$,{team:$p__73622_team$jscomp$24$$,profile:$profile$jscomp$36$$,form:$form$jscomp$169$$,fieldName:$field_name$jscomp$5$$,defaultMemberId:$default_member_id$jscomp$3_map__73623__$1$$}));return $out_arr__44124__auto__$jscomp$47$$},[],$team_fields$$)})})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_change_owner__modal-footer",
children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_change_owner__action-buttons",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel"),onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_dashboard_change_owner__cancel-button"}),(0,$APP.$rumext$v2$jsx$$)("input",{className:"accept-button main_ui_dashboard_change_owner__accept-btn "+(($all_valid_QMARK__initial_values_props_73599$$?
"main_ui_dashboard_change_owner__danger":"")+" "+($all_valid_QMARK__initial_values_props_73599$$?"":"disabled")),type:"button",disabled:!$all_valid_QMARK__initial_values_props_73599$$,value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-and-reassign.promote-and-leave"),onClick:function(){var $G__73621_teams_to_transfer__$1$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__73619_team$jscomp$23$$){var $field_name$jscomp$4_map__73620__$1_val$jscomp$191$$=$APP.$cljs$core$__destructure_map$$($p__73619_team$jscomp$23$$);
$p__73619_team$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($field_name$jscomp$4_map__73620__$1_val$jscomp$191$$,$APP.$cljs$cst$2492$team$$);$field_name$jscomp$4_map__73620__$1_val$jscomp$191$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($field_name$jscomp$4_map__73620__$1_val$jscomp$191$$,$cljs$cst$5103$field_name$$);$field_name$jscomp$4_map__73620__$1_val$jscomp$191$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$169$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5074$clean_data$$,$field_name$jscomp$4_map__73620__$1_val$jscomp$191$$],null));return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p__73619_team$jscomp$23$$),$cljs$cst$3296$reassign_to$$,$APP.$app$common$uuid$parse$$($field_name$jscomp$4_map__73620__$1_val$jscomp$191$$)],null)},$team_fields$$);$G__73621_teams_to_transfer__$1$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5101$teams_to_transfer$$,$G__73621_teams_to_transfer__$1$$],null);return $accept$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$?$accept$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$($G__73621_teams_to_transfer__$1$$):$accept$jscomp$8$$($G__73621_teams_to_transfer__$1$$)}})]})})]})})});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$5$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$5$$,$cljs$cst$5105$leave_and_reassign_org$$,$app$main$ui$dashboard$change_owner$leave_and_reassign_org_modal$$)});var $app$main$ui$dashboard$team_form$schema_COLON_team_form$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"TeamForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$app$common$types$team$schema_COLON_team_name$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3256$organization_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null)],null);
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$6$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$6$$,$cljs$cst$5107$team_form$$,$app$main$ui$dashboard$team_form$team_form_modal$$)});var $app$main$ui$ds$controls$shared$options_dropdown$xf_COLON_filter_blank_id$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__73629_SHARP_$$){return $APP.$cuerdas$core$blank_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__73629_SHARP_$$,$APP.$cljs$cst$266$id$$))}),$app$main$ui$ds$controls$shared$options_dropdown$xf_COLON_filter_non_blank_id$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__73630_SHARP_$$){return $APP.$cuerdas$core$blank_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__73630_SHARP_$$,
$APP.$cljs$cst$266$id$$))});var $app$main$ui$notifications$context_notification$neutral_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_notifications_context_notification__icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-msg-neutral"})}),$app$main$ui$notifications$context_notification$error_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_notifications_context_notification__icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-delete-text"})}),$app$main$ui$notifications$context_notification$success_icon$$=
(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_notifications_context_notification__icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-status-tick"})}),$app$main$ui$notifications$context_notification$info_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_notifications_context_notification__icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-help"})});var $app$main$ui$dashboard$team$arrow_icon$$,$app$main$ui$dashboard$team$menu_icon$$,$app$main$ui$dashboard$team$warning_icon$$,$app$main$ui$dashboard$team$success_icon$$,$app$main$ui$dashboard$team$schema_COLON_invite_member_form$$;$app$main$ui$dashboard$team$arrow_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_team__arrow-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-arrow"})});
$app$main$ui$dashboard$team$menu_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_team__menu-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-menu"})});$APP.$app$main$ui$dashboard$team$org_menu_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_team__org-menu-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-menu"})});
$app$main$ui$dashboard$team$warning_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_team__warning-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-msg-warning"})});$app$main$ui$dashboard$team$success_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_team__success-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-msg-success"})});
$APP.$app$main$ui$dashboard$team$image_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_team__image-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-img"})});$APP.$app$main$ui$dashboard$team$user_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_team__user-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-user"})});
$APP.$app$main$ui$dashboard$team$document_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_team__document-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-document"})});$APP.$app$main$ui$dashboard$team$group_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_team__group-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-group"})});
$APP.$app$main$ui$dashboard$team$header$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($on_nav_members_props_73651$$){var $section$jscomp$16_webhooks_section_QMARK_$$=$on_nav_members_props_73651$$.section,$team$jscomp$27$$=$on_nav_members_props_73651$$.team;$on_nav_members_props_73651$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_members$$())});
var $on_nav_settings$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_dashboard_settings$$())}),$on_nav_invitations$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_dashboard_invitations$$())}),$on_nav_webhooks$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_dashboard_webhooks$$())}),
$route$jscomp$8_settings_section_QMARK_$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$route$$),$invite_email$$=$APP.$cljs$cst$5122$invite_email$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2269$query_params$$.$cljs$core$IFn$_invoke$arity$1$($route$jscomp$8_settings_section_QMARK_$$)),$members_section_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$16_webhooks_section_QMARK_$$,$APP.$cljs$cst$5123$dashboard_team_members$$);$route$jscomp$8_settings_section_QMARK_$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$16_webhooks_section_QMARK_$$,$APP.$cljs$cst$5124$dashboard_team_settings$$);var $invitations_section_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$16_webhooks_section_QMARK_$$,$APP.$cljs$cst$5125$dashboard_team_invitations$$);$section$jscomp$16_webhooks_section_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$16_webhooks_section_QMARK_$$,$APP.$cljs$cst$5126$dashboard_team_webhooks$$);
var $permissions$jscomp$18$$=$APP.$cljs$cst$1722$permissions$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$27$$),$invitations$jscomp$4$$=$APP.$cljs$cst$3268$invitations$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$27$$),$on_invite_member$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$27$$),$APP.$rumext$v2$adapt$$($invite_email$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5127$invite_members$$,$APP.$cljs$cst$2492$team$$,$team$jscomp$27$$,$APP.$cljs$cst$1786$origin$$,$APP.$cljs$cst$2492$team$$,$APP.$cljs$cst$5122$invite_email$$,$invite_email$$],null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$27$$),$APP.$rumext$v2$adapt$$($invite_email$$)],function(){return $APP.$cljs$core$truth_$$($invite_email$$)?$on_invite_member$$.$cljs$core$IFn$_invoke$arity$0$?$on_invite_member$$.$cljs$core$IFn$_invoke$arity$0$():
$on_invite_member$$():null});return(0,$APP.$rumext$v2$jsxs$$)("header",{"data-testid":"dashboard-header",className:"main_ui_dashboard_team__dashboard-header main_ui_dashboard_team__team",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__dashboard-title",children:(0,$APP.$rumext$v2$jsx$$)("h1",{children:$members_section_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.members"):$route$jscomp$8_settings_section_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.settings"):
$invitations_section_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.invitations"):$section$jscomp$16_webhooks_section_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.webhooks"):null})}),(0,$APP.$rumext$v2$jsx$$)("nav",{className:"main_ui_dashboard_team__dashboard-header-menu",children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_dashboard_team__dashboard-header-options",children:[(0,$APP.$rumext$v2$jsx$$)("li",{className:$members_section_QMARK_$$?
"main_ui_dashboard_team__active":null,children:(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$on_nav_members_props_73651$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.members")})}),(0,$APP.$rumext$v2$jsx$$)("li",{className:$invitations_section_QMARK_$$?"main_ui_dashboard_team__active":null,children:(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$on_nav_invitations$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.invitations")})}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1215$webhooks$$)?(0,$APP.$rumext$v2$jsx$$)("li",{className:$section$jscomp$16_webhooks_section_QMARK_$$?"main_ui_dashboard_team__active":null,children:(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$on_nav_webhooks$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.webhooks")})}):null,(0,$APP.$rumext$v2$jsx$$)("li",{className:$route$jscomp$8_settings_section_QMARK_$$?"main_ui_dashboard_team__active":null,children:(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$on_nav_settings$$,
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.settings")})})]})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__dashboard-buttons",children:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$631_and__5023__auto____$1$jscomp$109$$=$invitations_section_QMARK_$$||$members_section_QMARK_$$;return $and__5023__auto__$jscomp$631_and__5023__auto____$1$jscomp$109$$?($and__5023__auto__$jscomp$631_and__5023__auto____$1$jscomp$109$$=$APP.$cljs$cst$1597$is_admin$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$18$$),
$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$631_and__5023__auto____$1$jscomp$109$$)?$APP.$cljs$core$not_empty$$($invitations$jscomp$4$$):$and__5023__auto__$jscomp$631_and__5023__auto____$1$jscomp$109$$):$and__5023__auto__$jscomp$631_and__5023__auto____$1$jscomp$109$$}())?(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$on_invite_member$$,"data-testid":"invite-member",className:"main_ui_dashboard_team__btn-secondary main_ui_dashboard_team__btn-small",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.invite-profile")}):
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__blank-space"})})]})});
$app$main$ui$dashboard$team$schema_COLON_invite_member_form$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"InviteMemberForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2490$role$$,$APP.$cljs$cst$221$keyword$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3290$emails$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$338$min$$,1],null),$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1927$team_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null)],null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$7$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$7$$,$APP.$cljs$cst$5127$invite_members$$,$app$main$ui$dashboard$team$invite_members_modal$$)});
$APP.$app$main$ui$dashboard$team$team_member_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($on_set_admin$jscomp$1_props_73722$$){var $profile$jscomp$42$$=$on_set_admin$jscomp$1_props_73722$$.profile,$member$jscomp$3$$=$on_set_admin$jscomp$1_props_73722$$.member,$team$jscomp$31$$=$on_set_admin$jscomp$1_props_73722$$.team,$on_leave_SINGLEQUOTE__total_members$$=$on_set_admin$jscomp$1_props_73722$$.totalMembers,$member_id$jscomp$6$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($member$jscomp$3$$);
$on_set_admin$jscomp$1_props_73722$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($member_id$jscomp$6$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$dashboard$team$set_role_BANG_$$,$member_id$jscomp$6$$,$cljs$cst$1593$admin$$));var $on_set_editor$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($member_id$jscomp$6$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$dashboard$team$set_role_BANG_$$,
$member_id$jscomp$6$$,$APP.$cljs$cst$1594$editor$$)),$on_set_viewer$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($member_id$jscomp$6$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$dashboard$team$set_role_BANG_$$,$member_id$jscomp$6$$,$APP.$cljs$cst$1592$viewer$$)),$owner_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$31$$,$APP.$cljs$cst$1722$permissions$$),
$APP.$cljs$cst$1598$is_owner$$),$on_set_owner$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($member$jscomp$3$$)],function($member__$1_params$jscomp$368$$){$member__$1_params$jscomp$368$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.promote-owner-confirm.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.promote-owner-confirm.message",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($member__$1_params$jscomp$368$$)])),$APP.$cljs$cst$5135$scd_message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.promote-owner-confirm.hint"),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.promote-owner-confirm.accept"),$APP.$cljs$cst$2479$on_accept$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$dashboard$team$set_role_BANG_$$,
$member_id$jscomp$6$$,$cljs$cst$1595$owner$$),$APP.$cljs$cst$2477$accept_style$$,$APP.$cljs$cst$2478$primary$$],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$($member__$1_params$jscomp$368$$))}),$on_success$jscomp$48$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1927$team_id$$,
$APP.$cljs$cst$205$default$$])))}),$on_error$jscomp$56$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__73731__$1_p__73730$$){$map__73731__$1_p__73730$$=$APP.$cljs$core$__destructure_map$$($map__73731__$1_p__73730$$);var $expr__73733$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73731__$1_p__73730$$,$APP.$cljs$cst$273$code$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5136$no_enough_members_for_leave$$,
$expr__73733$$):$APP.$cljs$core$_EQ_$$($cljs$cst$5136$no_enough_members_for_leave$$,$expr__73733$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.team-leave.insufficient-members"))):$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5137$member_does_not_exist$$,$expr__73733$$):$APP.$cljs$core$_EQ_$$($cljs$cst$5137$member_does_not_exist$$,
$expr__73733$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.team-leave.member-does-not-exists"))):$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5138$owner_cant_leave_team$$,$expr__73733$$):$APP.$cljs$core$_EQ_$$($cljs$cst$5138$owner_cant_leave_team$$,$expr__73733$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.team-leave.owner-cant-leave"))):
$APP.$beicon$v2$core$throw$0$$($map__73731__$1_p__73730$$)}),$on_delete_accepted$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$31$$),$APP.$rumext$v2$adapt$$($on_success$jscomp$48$$),$APP.$rumext$v2$adapt$$($on_error$jscomp$56$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$delete_team$$($APP.$cljs$core$with_meta$$($team$jscomp$31$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,
$on_success$jscomp$48$$,$APP.$cljs$cst$1295$on_error$$,$on_error$jscomp$56$$],null))))}),$on_leave_accepted$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_success$jscomp$48$$),$APP.$rumext$v2$adapt$$($on_error$jscomp$56$$)],function($member_id__$1_params$jscomp$369$$){var $G__73735$jscomp$inline_7506$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;$member_id__$1_params$jscomp$369$$=$APP.$cljs$core$uuid_QMARK_$$($member_id__$1_params$jscomp$369$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__73735$jscomp$inline_7506$$,
$cljs$cst$3296$reassign_to$$,$member_id__$1_params$jscomp$369$$):$G__73735$jscomp$inline_7506$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$leave_current_team$$($APP.$cljs$core$with_meta$$($member_id__$1_params$jscomp$369$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2488$on_success$$,$on_success$jscomp$48$$,$APP.$cljs$cst$1295$on_error$$,$on_error$jscomp$56$$],null))))}),$on_leave_and_close$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_delete_accepted$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-confirm.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.leave-and-close-confirm.message",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$31$$)])),$APP.$cljs$cst$5135$scd_message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-and-close-confirm.hint"),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-confirm.accept"),$APP.$cljs$cst$2479$on_accept$$,$on_delete_accepted$$],null)))}),$on_change_owner_and_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$42$$),
$APP.$rumext$v2$adapt$$($team$jscomp$31$$),$APP.$rumext$v2$adapt$$($on_leave_accepted$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$cljs$cst$5100$leave_and_reassign$$,
$APP.$cljs$cst$1914$profile$$,$profile$jscomp$42$$,$APP.$cljs$cst$2492$team$$,$team$jscomp$31$$,$APP.$cljs$cst$924$accept$$,$on_leave_accepted$$],null))]))}),$on_leave$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_leave_accepted$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-confirm.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-confirm.message"),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.leave-confirm.accept"),$APP.$cljs$cst$2479$on_accept$$,$on_leave_accepted$$],null)))}),$on_delete$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($member_id$jscomp$6$$)],
function(){var $params$jscomp$370$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-team-member-confirm.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-team-member-confirm.message"),$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-team-member-confirm.accept"),
$APP.$cljs$cst$2479$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$delete_member$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3274$member_id$$,$member_id$jscomp$6$$],null)))}],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$($params$jscomp$370$$))});$on_leave_SINGLEQUOTE__total_members$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$on_leave_SINGLEQUOTE__total_members$$)?$on_leave_and_close$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!0,$owner_QMARK_$jscomp$1$$)?$on_change_owner_and_leave$$:$on_leave$jscomp$1$$;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__table-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__field-name",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$member_info$$,{member:$member$jscomp$3$$,
profile:$profile$jscomp$42$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__field-roles",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$rol_info_STAR_$$,{member:$member$jscomp$3$$,team:$team$jscomp$31$$,onSetAdmin:$on_set_admin$jscomp$1_props_73722$$,onSetEditor:$on_set_editor$jscomp$1$$,onSetViewer:$on_set_viewer$jscomp$1$$,onSetOwner:$on_set_owner$jscomp$1$$,profile:$profile$jscomp$42$$})}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__field-actions",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$member_actions_STAR_$$,{member:$member$jscomp$3$$,profile:$profile$jscomp$42$$,team:$team$jscomp$31$$,onDelete:$on_delete$jscomp$3$$,onLeave:$on_leave_SINGLEQUOTE__total_members$$})})]})});
$APP.$app$main$ui$dashboard$team$invitation_row_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_73745_role$jscomp$16$$){function $is_selected_QMARK_$$($email__$1$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($selected$jscomp$128$$),$email__$1$$)}var $invitation$jscomp$1$$=$props_73745_role$jscomp$16$$.invitation,$team_id$jscomp$126$$=$props_73745_role$jscomp$16$$.teamId,$selected$jscomp$128$$=$props_73745_role$jscomp$16$$.selected,$can_invite$jscomp$1$$=
$props_73745_role$jscomp$16$$.canInvite,$on_select_change$$=$props_73745_role$jscomp$16$$.onSelectChange,$expired_QMARK_$jscomp$1_type$jscomp$593$$=$APP.$cljs$cst$5139$expired$$.$cljs$core$IFn$_invoke$arity$1$($invitation$jscomp$1$$),$email$jscomp$13$$=$APP.$cljs$cst$3183$email$$.$cljs$core$IFn$_invoke$arity$1$($invitation$jscomp$1$$);$props_73745_role$jscomp$16$$=$APP.$cljs$cst$2490$role$$.$cljs$core$IFn$_invoke$arity$1$($invitation$jscomp$1$$);var $status$jscomp$21$$=$APP.$cljs$core$truth_$$($expired_QMARK_$jscomp$1_type$jscomp$593$$)?
$APP.$cljs$cst$5139$expired$$:$APP.$cljs$cst$111$pending$$;$expired_QMARK_$jscomp$1_type$jscomp$593$$=$APP.$cljs$core$truth_$$($expired_QMARK_$jscomp$1_type$jscomp$593$$)?$APP.$cljs$cst$2343$warning$$:$APP.$cljs$cst$205$default$$;var $badge_content$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($status$jscomp$21$$,$APP.$cljs$cst$5139$expired$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.expired-invitation"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.pending-invitation"),
$on_change$jscomp$26$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select_change$$)],function($email__$1$jscomp$1_event$jscomp$200$$){$email__$1$jscomp$1_event$jscomp$200$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($email__$1$jscomp$1_event$jscomp$200$$),"attr");return $on_select_change$$.$cljs$core$IFn$_invoke$arity$1$?$on_select_change$$.$cljs$core$IFn$_invoke$arity$1$($email__$1$jscomp$1_event$jscomp$200$$):$on_select_change$$($email__$1$jscomp$1_event$jscomp$200$$)}),
$on_change_role$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($email$jscomp$13$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$126$$)],function($role__$1$jscomp$1$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$update_invitation_role$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3183$email$$,$email$jscomp$13$$,$APP.$cljs$cst$1927$team_id$$,$team_id$jscomp$126$$,$APP.$cljs$cst$2490$role$$,
$role__$1$jscomp$1$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2488$on_success$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$fetch_invitations$$())}],null))))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__table-row main_ui_dashboard_team__table-row-invitations",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__field-email",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__input-wrapper",children:(0,$APP.$rumext$v2$jsxs$$)("label",{children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__input-checkbox "+($is_selected_QMARK_$$($email$jscomp$13$$)?"checked":""),children:$APP.$app$main$ui$icons$status_tick$$}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"email-"+($email$jscomp$13$$??""),"data-attr":$email$jscomp$13$$,value:$email$jscomp$13$$,checked:$is_selected_QMARK_$$($email$jscomp$13$$),
onChange:$on_change$jscomp$26$$}),$email$jscomp$13$$]})})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__field-roles",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$invitation_role_selector_STAR_$$,{canInvite:$can_invite$jscomp$1$$,role:$props_73745_role$jscomp$16$$,status:$status$jscomp$21$$,onChange:$on_change_role$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__field-status",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$badge$badge_notification$$,{type:$expired_QMARK_$jscomp$1_type$jscomp$593$$,content:$badge_content$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__field-actions",children:$can_invite$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$invitation_actions_STAR_$$,{invitation:$invitation$jscomp$1$$,teamId:$team_id$jscomp$126$$}):null})]})});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$8$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$8$$,$APP.$cljs$cst$5141$invitation_modal$$,$app$main$ui$dashboard$team$invitation_modal$$)});
var $app$main$ui$dashboard$team$schema_COLON_organization_form$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SelectOrgForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5142$selected_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null);
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$9$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$9$$,$APP.$cljs$cst$5151$select_organization_modal$$,$app$main$ui$dashboard$team$select_organization_modal$$)});
var $app$main$ui$dashboard$team$schema_COLON_webhook_form$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"WebhookForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1579$uri$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$970$app_DOT_common_DOT_schema_SLASH_uri$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$339$max$$,4069,$APP.$cljs$cst$971$prefix$$,/^http[s]?:\/\//,$APP.$cljs$cst$945$error_SLASH_code$$,"errors.webhooks.invalid-uri"],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1726$mtype$$,$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null)],null),$app$main$ui$dashboard$team$valid_webhook_mtypes$$=new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"application/json",$APP.$cljs$cst$260$value$$,"application/json"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2287$label$$,"application/transit+json",$APP.$cljs$cst$260$value$$,"application/transit+json"],null)],null);
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$10$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$10$$,$APP.$cljs$cst$5154$webhook$$,$app$main$ui$dashboard$team$webhook_modal$$)});
$APP.$app$main$ui$dashboard$team$webhook_item_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($error_code$jscomp$1_props_73787$$){var $permissions$jscomp$24$$=$error_code$jscomp$1_props_73787$$.permissions,$webhook$jscomp$1$$=$error_code$jscomp$1_props_73787$$.webhook;$error_code$jscomp$1_props_73787$$=$cljs$cst$5156$error_code$$.$cljs$core$IFn$_invoke$arity$1$($webhook$jscomp$1$$);var $id$jscomp$880$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($webhook$jscomp$1$$),
$creator_id$$=$APP.$cljs$cst$2313$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($webhook$jscomp$1$$),$can_edit$jscomp$1_profile$jscomp$46$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$user_id$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($can_edit$jscomp$1_profile$jscomp$46$$);$can_edit$jscomp$1_profile$jscomp$46$$=function(){var $or__5025__auto__$jscomp$966$$=$APP.$cljs$cst$1596$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$24$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$966$$)?
$or__5025__auto__$jscomp$966$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($creator_id$$,$user_id$$)}();var $on_edit$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($webhook$jscomp$1$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5154$webhook$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5154$webhook$$,
$webhook$jscomp$1$$],null)))}),$on_delete_accepted$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$880$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$delete_webhook$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$id$jscomp$880$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2488$on_success$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$fetch_webhooks$$())}],
null))))}),$on_delete$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_delete_accepted$jscomp$1$$)],function(){var $params$jscomp$377$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2473$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-webhook.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-webhook.message"),
$APP.$cljs$cst$2476$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-webhook.accept"),$APP.$cljs$cst$2479$on_accept$$,$on_delete_accepted$jscomp$1$$],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$($params$jscomp$377$$))}),$last_delivery_text$$=$error_code$jscomp$1_props_73787$$==null?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webhooks.last-delivery.success"):
""+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.webhooks.last-delivery")??"")+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($error_code$jscomp$1_props_73787$$,"ssl-validation-error")?" "+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.webhooks.ssl-validation")??""):$APP.$cuerdas$core$starts_with_QMARK_$$($error_code$jscomp$1_props_73787$$,"unexpected-status")?" "+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.webhooks.unexpected-status",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($error_code$jscomp$1_props_73787$$,/:/)))]))??""):" "+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.webhooks.unexpected")??""));return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__table-row main_ui_dashboard_team__webhook-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{title:$last_delivery_text$$,className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__last-delivery",children:$error_code$jscomp$1_props_73787$$==null?$app$main$ui$dashboard$team$success_icon$$:$app$main$ui$dashboard$team$warning_icon$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__uri",children:(0,$APP.$rumext$v2$jsx$$)("div",{children:""+($APP.$cljs$cst$1579$uri$$.$cljs$core$IFn$_invoke$arity$1$($webhook$jscomp$1$$)??"")})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__active",children:(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$3315$is_active$$.$cljs$core$IFn$_invoke$arity$1$($webhook$jscomp$1$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.active"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.inactive")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__actions",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$webhook_actions_STAR_$$,{onEdit:$on_edit$jscomp$1$$,onDelete:$on_delete$jscomp$6$$,canEdit:$can_edit$jscomp$1_profile$jscomp$46$$})})]})});var $app$main$ui$workspace$shapes$circle_wrapper$$,$app$main$ui$workspace$shapes$image_wrapper$$,$app$main$ui$workspace$shapes$rect_wrapper$$,$app$main$ui$workspace$shapes$group_wrapper$$,$app$main$ui$workspace$shapes$svg_raw_wrapper$$,$app$main$ui$workspace$shapes$bool_wrapper$$,$app$main$ui$workspace$shapes$nested_frame_wrapper$$,$app$main$ui$workspace$shapes$root_frame_wrapper$$;$app$main$ui$workspace$shapes$circle_wrapper$$=$app$main$ui$workspace$shapes$common$generic_wrapper_factory$$($APP.$app$main$ui$shapes$circle$circle_shape$$);
$app$main$ui$workspace$shapes$image_wrapper$$=$app$main$ui$workspace$shapes$common$generic_wrapper_factory$$($APP.$app$main$ui$shapes$image$image_shape$$);$app$main$ui$workspace$shapes$rect_wrapper$$=$app$main$ui$workspace$shapes$common$generic_wrapper_factory$$($APP.$app$main$ui$shapes$rect$rect_shape$$);
$APP.$app$main$ui$workspace$shapes$root_shape$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_74668$$){var $objects$jscomp$694$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_74668$$,"objects"),$active_frames$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_74668$$,"active-frames"),$disable_thumbnails$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_74668$$,"disable-thumbnails"),$shapes$jscomp$144$$=
$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$694$$,$APP.$app$common$uuid$zero$$,null),$vbox$jscomp$33$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_vbox$$),$frame_overlap_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($vbox$jscomp$33$$),$APP.$rumext$v2$adapt$$($objects$jscomp$694$$)],function(){return function(){return $app$main$ui$workspace$shapes$make_is_frame_overlap$$($vbox$jscomp$33$$,
$objects$jscomp$694$$)}}),$shapes__$1$jscomp$16$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$144$$),$APP.$rumext$v2$adapt$$($vbox$jscomp$33$$),$APP.$rumext$v2$adapt$$($frame_overlap_QMARK_$$)],function(){return $vbox$jscomp$33$$!=null?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($frame_overlap_QMARK_$$,$shapes$jscomp$144$$):$shapes$jscomp$144$$});return(0,$APP.$rumext$v2$jsx$$)("g",{id:"shape-"+($APP.$app$common$uuid$zero$$??""),
children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$provider$$($app$main$ui$context$active_frames$$),{value:$active_frames$$,children:[function(){var $xform$jscomp$39$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$frame_shape_QMARK_$$),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__74667_SHARP_$$){return $APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$694$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__74667_SHARP_$$))}));return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$shapes$text$fontfaces$fontfaces_style$$,{shapes:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$xform$jscomp$39$$,$shapes__$1$jscomp$16$$)})}(),(0,$APP.$rumext$v2$jsx$$)("g",{className:"frame-children",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$59$$,$JSCompiler_inline_result$jscomp$1379_shape$jscomp$820$$){var $JSCompiler_temp_const$jscomp$1377$$=
$out_arr__44124__auto__$jscomp$59$$.push,$thumbnail_QMARK_$jscomp$inline_7721$$=$APP.$cljs$core$not$$($disable_thumbnails$$)&&!$APP.$cljs$core$contains_QMARK_$$($active_frames$$,$JSCompiler_inline_result$jscomp$1379_shape$jscomp$820$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1379_shape$jscomp$820$$,$APP.$cljs$cst$266$id$$));$JSCompiler_inline_result$jscomp$1379_shape$jscomp$820$$=(0,$APP.$rumext$v2$jsx$$)("g",{className:"ws-shape-wrapper",children:$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1379_shape$jscomp$820$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$root_frame_wrapper$$,{shape:$JSCompiler_inline_result$jscomp$1379_shape$jscomp$820$$,objects:$objects$jscomp$694$$,"thumbnail?":$thumbnail_QMARK_$jscomp$inline_7721$$}):(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$workspace$shapes$shape_wrapper$$,{shape:$JSCompiler_inline_result$jscomp$1379_shape$jscomp$820$$})},""+($JSCompiler_inline_result$jscomp$1379_shape$jscomp$820$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1379_shape$jscomp$820$$,
$APP.$cljs$cst$266$id$$)??""));$JSCompiler_temp_const$jscomp$1377$$.call($out_arr__44124__auto__$jscomp$59$$,$JSCompiler_inline_result$jscomp$1379_shape$jscomp$820$$);return $out_arr__44124__auto__$jscomp$59$$},[],$shapes__$1$jscomp$16$$)})]})})});
$APP.$app$main$ui$workspace$shapes$shape_wrapper$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($props_74677_shape$jscomp$821$$){$props_74677_shape$jscomp$821$$=$props_74677_shape$jscomp$821$$.shape;var $shape_type$jscomp$4$$=$props_74677_shape$jscomp$821$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_74677_shape$jscomp$821$$,$APP.$cljs$cst$139$type$$),$shape_id$jscomp$140_thumbnail_QMARK_$jscomp$9_wrapper_elem$$=$props_74677_shape$jscomp$821$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_74677_shape$jscomp$821$$,
$APP.$cljs$cst$266$id$$),$active_frames$jscomp$1_rawsvg_QMARK__wrapper_props$jscomp$4$$=$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($props_74677_shape$jscomp$821$$)?(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$context$active_frames$$):null;$shape_id$jscomp$140_thumbnail_QMARK_$jscomp$9_wrapper_elem$$=$active_frames$jscomp$1_rawsvg_QMARK__wrapper_props$jscomp$4$$!=null&&!$APP.$cljs$core$contains_QMARK_$$($active_frames$jscomp$1_rawsvg_QMARK__wrapper_props$jscomp$4$$,
$shape_id$jscomp$140_thumbnail_QMARK_$jscomp$9_wrapper_elem$$);var $props__$1$jscomp$61$$={shape:$props_74677_shape$jscomp$821$$,"thumbnail?":$shape_id$jscomp$140_thumbnail_QMARK_$jscomp$9_wrapper_elem$$};$shape_id$jscomp$140_thumbnail_QMARK_$jscomp$9_wrapper_elem$$=($active_frames$jscomp$1_rawsvg_QMARK__wrapper_props$jscomp$4$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$svg_raw$$,$shape_type$jscomp$4$$))?$APP.$rumext$v2$Fragment$$:"g";$active_frames$jscomp$1_rawsvg_QMARK__wrapper_props$jscomp$4$$=
$active_frames$jscomp$1_rawsvg_QMARK__wrapper_props$jscomp$4$$?{}:{className:"workspace-shape-wrapper"};return $props_74677_shape$jscomp$821$$==null||$APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($props_74677_shape$jscomp$821$$)?null:(0,$APP.$rumext$v2$create_element$$)($shape_id$jscomp$140_thumbnail_QMARK_$jscomp$9_wrapper_elem$$,$active_frames$jscomp$1_rawsvg_QMARK__wrapper_props$jscomp$4$$,function(){switch($shape_type$jscomp$4$$ instanceof $APP.$cljs$core$Keyword$$?$shape_type$jscomp$4$$.$fqn$:
null){case "path":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$shapes$path$path_wrapper$$,$props__$1$jscomp$61$$);case "text":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$shapes$text$text_wrapper$$,$props__$1$jscomp$61$$);case "group":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$shapes$group_wrapper$$,$props__$1$jscomp$61$$);case "rect":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$shapes$rect_wrapper$$,$props__$1$jscomp$61$$);
case "image":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$shapes$image_wrapper$$,$props__$1$jscomp$61$$);case "circle":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$shapes$circle_wrapper$$,$props__$1$jscomp$61$$);case "svg-raw":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$shapes$svg_raw_wrapper$$,$props__$1$jscomp$61$$);case "bool":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$shapes$bool_wrapper$$,$props__$1$jscomp$61$$);
case "frame":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$shapes$nested_frame_wrapper$$,$props__$1$jscomp$61$$);default:return null}}())},$app$main$ui$workspace$shapes$common$check_shape_props$$);
$app$main$ui$workspace$shapes$group_wrapper$$=function($shape_wrapper$jscomp$19$$){var $group_shape$jscomp$1$$=$APP.$app$main$ui$shapes$group$group_shape$$($shape_wrapper$jscomp$19$$);return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($props_73753_shape$jscomp$814$$){$props_73753_shape$jscomp$814$$=$props_73753_shape$jscomp$814$$.shape;var $shape_id$jscomp$137$$=$props_73753_shape$jscomp$814$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_73753_shape$jscomp$814$$,$APP.$cljs$cst$266$id$$),
$childs$jscomp$17_childs_STAR_$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$137$$)],function(){return $app$main$refs$children_objects$$($shape_id$jscomp$137$$)});$childs$jscomp$17_childs_STAR_$jscomp$1$$=$APP.$rumext$v2$deref$$($childs$jscomp$17_childs_STAR_$jscomp$1$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$app$main$ui$shapes$shape$shape_container$$,{shape:$props_73753_shape$jscomp$814$$,children:[(0,$APP.$rumext$v2$jsx$$)($group_shape$jscomp$1$$,
{shape:$props_73753_shape$jscomp$814$$,childs:$childs$jscomp$17_childs_STAR_$jscomp$1$$}),$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$debug$shape_debug$$,{shape:$props_73753_shape$jscomp$814$$}):null]})},$app$main$ui$workspace$shapes$common$check_shape_props$$)}($APP.$app$main$ui$workspace$shapes$shape_wrapper$$);
$app$main$ui$workspace$shapes$svg_raw_wrapper$$=function($shape_wrapper$jscomp$20$$){var $svg_raw_shape$jscomp$1$$=$APP.$app$main$ui$shapes$svg_raw$svg_raw_shape$$($shape_wrapper$jscomp$20$$);return function($p1__73775_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__73775_SHARP_$$,function($new_props_73778$$,$old_props_73779$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_73778$$.shape,$old_props_73779$$.shape)})}(function($childs$jscomp$18_childs_ref$jscomp$1_props_73776$$){var $shape$jscomp$817$$=
$childs$jscomp$18_childs_ref$jscomp$1_props_73776$$.shape;$childs$jscomp$18_childs_ref$jscomp$1_props_73776$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$817$$))],function(){return $app$main$refs$children_objects$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$817$$))});$childs$jscomp$18_childs_ref$jscomp$1_props_73776$$=$APP.$rumext$v2$deref$$($childs$jscomp$18_childs_ref$jscomp$1_props_73776$$);
var $svg_tag$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$817$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1637$content$$,$APP.$cljs$cst$78$tag$$],null));return $APP.$cljs$core$contains_QMARK_$$($app$common$svg$svg_group_safe_tags$$,$svg_tag$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$app$main$ui$shapes$shape$shape_container$$,{shape:$shape$jscomp$817$$,children:[(0,$APP.$rumext$v2$jsx$$)($svg_raw_shape$jscomp$1$$,
{shape:$shape$jscomp$817$$,childs:$childs$jscomp$18_childs_ref$jscomp$1_props_73776$$}),$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$debug$shape_debug$$,{shape:$shape$jscomp$817$$}):null]}):(0,$APP.$rumext$v2$jsx$$)($svg_raw_shape$jscomp$1$$,{shape:$shape$jscomp$817$$,childs:$childs$jscomp$18_childs_ref$jscomp$1_props_73776$$})})}($APP.$app$main$ui$workspace$shapes$shape_wrapper$$);
$app$main$ui$workspace$shapes$bool_wrapper$$=function($shape_wrapper$jscomp$15$$){var $bool_shape$jscomp$1$$=$APP.$app$main$ui$shapes$bool$bool_shape$$($shape_wrapper$jscomp$15$$);return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($props_73738_shape$jscomp$799_shape__$1$jscomp$65$$){$props_73738_shape$jscomp$799_shape__$1$jscomp$65$$=$props_73738_shape$jscomp$799_shape__$1$jscomp$65$$.shape;var $shape_id$jscomp$135$$=$props_73738_shape$jscomp$799_shape__$1$jscomp$65$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_73738_shape$jscomp$799_shape__$1$jscomp$65$$,
$APP.$cljs$cst$266$id$$),$child_sel_QMARK__child_sel_STAR_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$135$$)],function(){return $app$main$refs$is_child_selected_QMARK_$$($shape_id$jscomp$135$$)}),$childs$jscomp$15_childs_STAR_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$135$$)],function(){return $app$main$refs$select_bool_children$$($shape_id$jscomp$135$$)});$child_sel_QMARK__child_sel_STAR_$$=
$APP.$rumext$v2$deref$$($child_sel_QMARK__child_sel_STAR_$$);$childs$jscomp$15_childs_STAR_$$=$APP.$rumext$v2$deref$$($childs$jscomp$15_childs_STAR_$$);$props_73738_shape$jscomp$799_shape__$1$jscomp$65$$=$child_sel_QMARK__child_sel_STAR_$$?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($props_73738_shape$jscomp$799_shape__$1$jscomp$65$$,$APP.$cljs$cst$1637$content$$):$props_73738_shape$jscomp$799_shape__$1$jscomp$65$$;return(0,$APP.$rumext$v2$jsxs$$)($APP.$app$main$ui$shapes$shape$shape_container$$,
{shape:$props_73738_shape$jscomp$799_shape__$1$jscomp$65$$,children:[(0,$APP.$rumext$v2$jsx$$)($bool_shape$jscomp$1$$,{shape:$props_73738_shape$jscomp$799_shape__$1$jscomp$65$$,childs:$childs$jscomp$15_childs_STAR_$$}),$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$debug$shape_debug$$,{shape:$props_73738_shape$jscomp$799_shape__$1$jscomp$65$$}):null]})},$app$main$ui$workspace$shapes$common$check_shape_props$$)}($APP.$app$main$ui$workspace$shapes$shape_wrapper$$);
$app$main$ui$workspace$shapes$nested_frame_wrapper$$=function($shape_wrapper$jscomp$17$$){var $frame_shape$jscomp$5$$=$app$main$ui$workspace$shapes$frame$frame_shape_factory$$($shape_wrapper$jscomp$17$$);return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($props_74394_shape$jscomp$812$$){$props_74394_shape$jscomp$812$$=$props_74394_shape$jscomp$812$$.shape;var $objects$jscomp$691$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),
$frame_id$jscomp$111$$=$props_74394_shape$jscomp$812$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_74394_shape$jscomp$812$$,$APP.$cljs$cst$266$id$$),$node_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),$modifiers$jscomp$109_modifiers_STAR_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$111$$)],function(){return $app$main$refs$workspace_modifiers_by_frame_id$$($frame_id$jscomp$111$$)});$modifiers$jscomp$109_modifiers_STAR_$$=
$APP.$rumext$v2$deref$$($modifiers$jscomp$109_modifiers_STAR_$$);$APP.$app$main$ui$workspace$shapes$frame$dynamic_modifiers$use_dynamic_modifiers$$($objects$jscomp$691$$,$APP.$rumext$v2$ref_val$$($node_ref$jscomp$2$$),$modifiers$jscomp$109_modifiers_STAR_$$);return(0,$APP.$rumext$v2$jsx$$)($frame_shape$jscomp$5$$,{shape:$props_74394_shape$jscomp$812$$,ref:$node_ref$jscomp$2$$})},$app$main$ui$workspace$shapes$frame$check_props$$)}($APP.$app$main$ui$workspace$shapes$shape_wrapper$$);
$app$main$ui$workspace$shapes$root_frame_wrapper$$=function($shape_wrapper$jscomp$18$$){var $frame_shape$jscomp$6$$=$app$main$ui$workspace$shapes$frame$frame_shape_factory$$($shape_wrapper$jscomp$18$$);return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($objects$jscomp$692_props_74496$$){var $shape$jscomp$813$$=$objects$jscomp$692_props_74496$$.shape,$thumbnail_QMARK_$jscomp$7$$=$objects$jscomp$692_props_74496$$["thumbnail?"];$objects$jscomp$692_props_74496$$=$objects$jscomp$692_props_74496$$.objects;
var $file_id$jscomp$338$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$),$page_id$jscomp$347$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_page_id$$),$frame_id$jscomp$113$$=$shape$jscomp$813$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$813$$,$APP.$cljs$cst$266$id$$),$container_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$content_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$bounds$jscomp$73_height$jscomp$152$$=$APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$692_props_74496$$,
$shape$jscomp$813$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1911$ignore_margin_QMARK_$$,!1],null)),$x$jscomp$1235$$=$bounds$jscomp$73_height$jscomp$152$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$73_height$jscomp$152$$,$APP.$cljs$cst$1510$x$$),$y$jscomp$455$$=$bounds$jscomp$73_height$jscomp$152$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$73_height$jscomp$152$$,$APP.$cljs$cst$1511$y$$),$width$jscomp$175$$=$bounds$jscomp$73_height$jscomp$152$$?.width??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$73_height$jscomp$152$$,$APP.$cljs$cst$290$width$$);$bounds$jscomp$73_height$jscomp$152$$=$bounds$jscomp$73_height$jscomp$152$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$73_height$jscomp$152$$,$APP.$cljs$cst$1522$height$$);var $modifiers$jscomp$110_modifiers_ref_thumbnail_uri_STAR_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$338$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$347$$),
$APP.$rumext$v2$adapt$$($frame_id$jscomp$113$$)],function(){return $APP.$app$main$refs$workspace_thumbnail_by_id$$($APP.$app$common$thumbnails$fmt_object_id$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$338$$,$page_id$jscomp$347$$,$frame_id$jscomp$113$$,"frame"))}),$thumbnail_uri$jscomp$1$$=$APP.$rumext$v2$deref$$($modifiers$jscomp$110_modifiers_ref_thumbnail_uri_STAR_$$);$modifiers$jscomp$110_modifiers_ref_thumbnail_uri_STAR_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$113$$)],
function(){return $app$main$refs$workspace_modifiers_by_frame_id$$($frame_id$jscomp$113$$)});$modifiers$jscomp$110_modifiers_ref_thumbnail_uri_STAR_$$=$APP.$rumext$v2$deref$$($modifiers$jscomp$110_modifiers_ref_thumbnail_uri_STAR_$$);var $hidden_QMARK_$$=$APP.$cljs$cst$1620$hidden$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$813$$)===!0,$content_visible_QMARK_$$=!$thumbnail_QMARK_$jscomp$7$$||!$thumbnail_uri$jscomp$1$$,$tries_ref$$=(0,$APP.$rumext$v2$use_ref$$)(0),$imposter_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$imposter_loaded$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$task_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$on_load$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$rumext$v2$set_ref_val_BANG_$$($tries_ref$$,0);return $APP.$cljs$core$reset_BANG_$$($imposter_loaded$$,!0)}),$on_error$jscomp$60$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){function $retry_fn$$(){var $imposter$$=$APP.$rumext$v2$ref_val$$($imposter_ref$$);
return $imposter$$==null?null:$APP.$app$util$dom$set_attribute_BANG_$$($imposter$$,"href",$thumbnail_uri$jscomp$1$$)}var $new_tries$$=$APP.$rumext$v2$set_ref_val_BANG_$$($tries_ref$$,$APP.$rumext$v2$ref_val$$($tries_ref$$)+1),$delay_in_ms$$=Math.pow(2,$new_tries$$)*1E3;return $new_tries$$<8?$APP.$rumext$v2$set_ref_val_BANG_$$($task_ref$$,$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$($delay_in_ms$$,$retry_fn$$)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){$thumbnail_uri$jscomp$1$$==null&&$APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$thumbnails$update_thumbnail$$($file_id$jscomp$338$$,$page_id$jscomp$347$$,$frame_id$jscomp$113$$,"frame","root-frame"))});return function(){var $temp__5825__auto__$jscomp$288$$=$APP.$rumext$v2$ref_val$$($task_ref$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$288$$)?
$app$common$data$close_BANG_$$($temp__5825__auto__$jscomp$288$$):null}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($thumbnail_uri$jscomp$1$$)],function(){var $temp__5825__auto__$jscomp$289$$=$APP.$rumext$v2$ref_val$$($task_ref$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$289$$)?$app$common$data$close_BANG_$$($temp__5825__auto__$jscomp$289$$):null});$APP.$app$main$ui$workspace$shapes$frame$dynamic_modifiers$use_dynamic_modifiers$$($objects$jscomp$692_props_74496$$,
$APP.$rumext$v2$ref_val$$($content_ref$$),$modifiers$jscomp$110_modifiers_ref_thumbnail_uri_STAR_$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$app$main$ui$shapes$shape$shape_container$$,{shape:$shape$jscomp$813$$,children:[(0,$APP.$rumext$v2$jsxs$$)("g",{className:"frame-container",id:"frame-container-"+($frame_id$jscomp$113$$??""),opacity:$hidden_QMARK_$$?0:null,children:[!$content_visible_QMARK_$$&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($imposter_loaded$$))?(0,$APP.$rumext$v2$jsx$$)("g",{className:"frame-placeholder",
children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:$x$jscomp$1235$$,y:$y$jscomp$455$$,width:$width$jscomp$175$$,height:$bounds$jscomp$73_height$jscomp$152$$,fill:"url(#frame-placeholder-gradient)"})}):null,(0,$APP.$rumext$v2$jsxs$$)("g",{className:"frame-imposter",children:[(0,$APP.$rumext$v2$jsx$$)("image",{width:$width$jscomp$175$$,height:$bounds$jscomp$73_height$jscomp$152$$,className:"thumbnail-bitmap",x:$x$jscomp$1235$$,onError:$on_error$jscomp$60$$,href:$thumbnail_uri$jscomp$1$$,style:{display:$thumbnail_QMARK_$jscomp$7$$&&
$thumbnail_uri$jscomp$1$$?null:"none"},y:$y$jscomp$455$$,ref:$imposter_ref$$,onLoad:$on_load$jscomp$1$$}),$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$2229$thumbnails$$)?(0,$APP.$rumext$v2$jsx$$)("rect",{x:$x$jscomp$1235$$+2,y:$y$jscomp$455$$+2,width:$width$jscomp$175$$-4,height:$bounds$jscomp$73_height$jscomp$152$$-4,stroke:"#f0f",strokeWidth:2}):null]}),$content_visible_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("g",{className:"frame-content",id:"frame-content-"+($frame_id$jscomp$113$$??""),ref:$container_ref$jscomp$1$$,
children:(0,$APP.$rumext$v2$jsx$$)($frame_shape$jscomp$6$$,{shape:$shape$jscomp$813$$,ref:$content_ref$$})}):null]},"frame-container"),$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$debug$shape_debug$$,{shape:$shape$jscomp$813$$}):null]})},$app$main$ui$workspace$shapes$frame$check_props$$)}($APP.$app$main$ui$workspace$shapes$shape_wrapper$$);$APP.$app$util$theme$color_scheme_media_query$$=$APP.$app$util$globals$window$$.matchMedia("(prefers-color-scheme: dark)");var $app$main$ui$exports$assets$neutral_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_exports_assets__icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-msg-neutral"})}),$app$main$ui$exports$assets$error_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_exports_assets__icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-delete-text"})}),$app$main$ui$exports$assets$close_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,
className:"main_ui_exports_assets__close-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-close"})});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$11$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$11$$,$APP.$cljs$cst$4125$export_shapes$$,$app$main$ui$exports$assets$export_shapes_dialog$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$12$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$12$$,$APP.$cljs$cst$4760$export_frames$$,$app$main$ui$exports$assets$export_frames$$)});
$APP.$app$main$ui$exports$assets$progress_widget$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $state$jscomp$1089$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$export$0$$),$profile$jscomp$47$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$error_QMARK_$jscomp$1_theme$jscomp$12$$=function(){var $or__5025__auto__$jscomp$972$$=$APP.$cljs$cst$3184$theme$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$47$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$972$$)?
$or__5025__auto__$jscomp$972$$:"dark"}(),$background_clr_is_default_theme_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("dark",$error_QMARK_$jscomp$1_theme$jscomp$12$$);$error_QMARK_$jscomp$1_theme$jscomp$12$$=$APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1089$$);var $healthy_QMARK_$jscomp$2_title$jscomp$25$$=$cljs$cst$4764$healthy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1089$$),$detail_visible_QMARK_$$=$cljs$cst$4753$detail_visible$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1089$$),
$widget_visible_QMARK_$$=$cljs$cst$4755$widget_visible$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1089$$),$progress$$=$APP.$cljs$cst$2244$progress$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1089$$),$items$jscomp$52$$=$APP.$cljs$cst$1870$exports$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1089$$),$total$jscomp$17$$=function(){var $or__5025__auto__$jscomp$973$$=$APP.$cljs$cst$2328$total$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1089$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$973$$)?
$or__5025__auto__$jscomp$973$$:$APP.$cljs$core$count$$($items$jscomp$52$$)}(),$complete_QMARK__retry_last_operation$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($progress$$,$total$jscomp$17$$),$circ$$=2*Math.PI*12,$pct$jscomp$1$$=$total$jscomp$17$$===0?$circ$$:$circ$$-$progress$$/$total$jscomp$17$$*$circ$$,$pwidth$$=$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$1_theme$jscomp$12$$)?280:$progress$$*280/$total$jscomp$17$$,$color$jscomp$123$$=$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$1_theme$jscomp$12$$)?
"#ff3277":$APP.$cljs$core$truth_$$($healthy_QMARK_$jscomp$2_title$jscomp$25$$)?$background_clr_is_default_theme_QMARK_$$?"#7efff5":"#6911d4":$APP.$cljs$core$not$$($healthy_QMARK_$jscomp$2_title$jscomp$25$$)?"#fe4811":null;$background_clr_is_default_theme_QMARK_$$=$background_clr_is_default_theme_QMARK_$$?"#2e3434":"#eef0f2";$healthy_QMARK_$jscomp$2_title$jscomp$25$$=$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$1_theme$jscomp$12$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.exporting-object-error"):
$complete_QMARK__retry_last_operation$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.exporting-complete"):$APP.$cljs$core$truth_$$($healthy_QMARK_$jscomp$2_title$jscomp$25$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.exporting-object"):$APP.$cljs$core$not$$($healthy_QMARK_$jscomp$2_title$jscomp$25$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.exporting-object-slow"):null;$complete_QMARK__retry_last_operation$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$exports$assets$retry_last_export$$())});var $toggle_detail_visibility$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$exports$assets$toggle_detail_visibililty$$())});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($widget_visible_QMARK_$$)?
(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$toggle_detail_visibility$$,className:"main_ui_exports_assets__export-progress-widget",children:(0,$APP.$rumext$v2$jsxs$$)("svg",{width:"24",height:"24",children:[(0,$APP.$rumext$v2$jsx$$)("circle",{r:"10",cx:"12",cy:"12",fill:"transparent",stroke:$background_clr_is_default_theme_QMARK_$$,strokeWidth:"4"}),(0,$APP.$rumext$v2$jsx$$)("circle",{cy:"12",transform:"rotate(-90 12,12)",strokeDasharray:""+($circ$$??"")+" "+($circ$$??""),stroke:$color$jscomp$123$$,
style:{transition:"stroke-dashoffset 1s ease-in-out"},fill:"transparent",strokeWidth:"4",r:"10",strokeDashoffset:$pct$jscomp$1$$,cx:"12"})]})}):null,$APP.$cljs$core$truth_$$($detail_visible_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_assets__export-progress-modal "+($APP.$cljs$core$truth_$$($error_QMARK_$jscomp$1_theme$jscomp$12$$)?"main_ui_exports_assets__has-error":""),children:[$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$1_theme$jscomp$12$$)?$app$main$ui$exports$assets$error_icon$$:
$app$main$ui$exports$assets$neutral_icon$$,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_assets__export-progress-title",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_assets__title-text",children:$healthy_QMARK_$jscomp$2_title$jscomp$25$$}),$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$1_theme$jscomp$12$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$complete_QMARK__retry_last_operation$$,className:"main_ui_exports_assets__retry-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.retry")}):
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_exports_assets__progress",children:""+($progress$$??"")+" / "+($total$jscomp$17$$??"")})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$toggle_detail_visibility$$,className:"main_ui_exports_assets__progress-close-button",children:$app$main$ui$exports$assets$close_icon$$}),$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$1_theme$jscomp$12$$)?null:(0,$APP.$rumext$v2$jsx$$)("svg",{height:4,width:280,className:"main_ui_exports_assets__progress-bar",children:(0,$APP.$rumext$v2$jsxs$$)("g",
{children:[(0,$APP.$rumext$v2$jsx$$)("path",{d:"M0 0 L280 0",stroke:$background_clr_is_default_theme_QMARK_$$,strokeWidth:30}),(0,$APP.$rumext$v2$jsx$$)("path",{d:"M0 0 L280 0",stroke:$color$jscomp$123$$,strokeWidth:30,fill:"transparent",strokeDasharray:280,strokeDashoffset:280-$pwidth$$,style:{transition:"stroke-dashoffset 1s ease-in-out"}})]})})]}):null]})});$APP.$app$common$logging$loggers$$.set("app.common.files.repair",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1160$debug$$));
var $app$common$files$repair$repair_error$$=function(){var $method_table__5622__auto__$jscomp$21$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$21$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$21$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$21$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.common.files.repair",
"repair-error"),function($code$jscomp$50$$){return $code$jscomp$50$$},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$21$$,$method_table__5622__auto__$jscomp$21$$,$prefer_table__5623__auto__$jscomp$21$$,$method_cache__5624__auto__$jscomp$21$$,$cached_hierarchy__5625__auto__$jscomp$21$$)}();
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5162$invalid_geometry$$,function($_$jscomp$2821_map__73867__$1$$,$p__73866$$,$file_data$jscomp$75$$){$_$jscomp$2821_map__73867__$1$$=$APP.$cljs$core$__destructure_map$$($p__73866$$);var $shape$jscomp$823$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2821_map__73867__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$348$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2821_map__73867__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :invalid-geometry"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$823$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$823$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$348$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$348$$),$file_data$jscomp$75$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$823$$)],
null),function($shape__$1$jscomp$69$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e reset geometry"],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $app$common$types$shape$setup_rect$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$69$$,$APP.$cljs$cst$1510$x$$,0),$APP.$cljs$cst$1511$y$$,0),$APP.$cljs$cst$290$width$$,.01),$APP.$cljs$cst$1522$height$$,.01))})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5163$parent_not_found$$,function($_$jscomp$2822_map__73869__$1$$,$p__73868$$,$file_data$jscomp$76$$){$_$jscomp$2822_map__73869__$1$$=$APP.$cljs$core$__destructure_map$$($p__73868$$);var $shape$jscomp$824$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2822_map__73869__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$349$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2822_map__73869__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :parent-not-found"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$824$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$824$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$349$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$349$$),$file_data$jscomp$76$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$824$$)],
null),function($shape__$1$jscomp$70$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e set to "],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$,$APP.$app$common$uuid$zero$$],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$70$$,$APP.$cljs$cst$1619$parent_id$$,$APP.$app$common$uuid$zero$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5164$child_not_in_parent$$,function($_$jscomp$2823_map__73872__$1$$,$p__73871$$,$file_data$jscomp$77$$){$_$jscomp$2823_map__73872__$1$$=$APP.$cljs$core$__destructure_map$$($p__73871$$);var $shape$jscomp$825$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2823_map__73872__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$350$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2823_map__73872__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :child-not-in-parent"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$825$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$825$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$350$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$350$$),$file_data$jscomp$77$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$825$$)],
null),function($parent_shape$jscomp$3$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e add children to"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1619$parent_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent_shape$jscomp$3$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($parent_shape$jscomp$3$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$conj$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$825$$))})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5165$duplicated_children$$,function($_$jscomp$2824_map__73882__$1$$,$p__73881$$,$file_data$jscomp$78$$){$_$jscomp$2824_map__73882__$1$$=$APP.$cljs$core$__destructure_map$$($p__73881$$);var $shape$jscomp$826$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2824_map__73882__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$351$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2824_map__73882__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :duplicated-children"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$826$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$826$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$351$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$351$$),$file_data$jscomp$78$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$826$$)],
null),function($shape__$1$jscomp$71$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e remove duplicated children"],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$71$$,$APP.$cljs$cst$1614$shapes$$,$APP.$cljs$core$distinct$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5166$child_not_found$$,function($_$jscomp$2825_map__73885__$1$$,$p__73884$$,$file_data$jscomp$79$$){$_$jscomp$2825_map__73885__$1$$=$APP.$cljs$core$__destructure_map$$($p__73884$$);var $shape$jscomp$827$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2825_map__73885__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$352$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2825_map__73885__$1$$,
$APP.$cljs$cst$2043$page_id$$),$args$jscomp$255$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2825_map__73885__$1$$,$cljs$cst$578$args$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$275$hint$$,"repairing shape :child-not-found"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$827$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$827$$)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$352$$],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$352$$),$file_data$jscomp$79$$),new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$827$$)],null),function($parent_shape$jscomp$4$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$275$hint$$,"  -\x3e remove child"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5167$child_id$$,$cljs$cst$5167$child_id$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$255$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($parent_shape$jscomp$4$$,$APP.$cljs$cst$1614$shapes$$,function($shapes$jscomp$145$$){return $APP.$app$common$data$removev$$(function($p1__73883_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5167$child_id$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$255$$),
$p1__73883_SHARP_$$)},$shapes$jscomp$145$$)})})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5168$invalid_parent$$,function($_$jscomp$2826_args$jscomp$256_map__73887__$1$$,$p__73886$$,$file_data$jscomp$80$$){$_$jscomp$2826_args$jscomp$256_map__73887__$1$$=$APP.$cljs$core$__destructure_map$$($p__73886$$);var $shape$jscomp$828$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2826_args$jscomp$256_map__73887__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$353$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2826_args$jscomp$256_map__73887__$1$$,
$APP.$cljs$cst$2043$page_id$$);$_$jscomp$2826_args$jscomp$256_map__73887__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2826_args$jscomp$256_map__73887__$1$$,$cljs$cst$578$args$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :invalid-parent"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$828$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$828$$)],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$353$$],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$353$$),$file_data$jscomp$80$$),
$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2826_args$jscomp$256_map__73887__$1$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$828$$],null),null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2618$allow_altering_copies$$,!0],null))});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5169$frame_not_found$$,function($_$jscomp$2827_map__73895__$1$$,$p__73894$$,$file_data$jscomp$81$$){$_$jscomp$2827_map__73895__$1$$=$APP.$cljs$core$__destructure_map$$($p__73894$$);var $shape$jscomp$829$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2827_map__73895__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$354$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2827_map__73895__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :frame-not-found"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$829$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$829$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$354$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$354$$),$file_data$jscomp$81$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$829$$)],
null),function($shape__$1$jscomp$72$$){var $page$jscomp$112$$=$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$81$$,$page_id$jscomp$354$$),$frame$jscomp$43$$=$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$112$$),$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$72$$)),$frame_id$jscomp$114$$=function(){var $or__5025__auto__$jscomp$974$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$43$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$974$$)?$or__5025__auto__$jscomp$974$$:$APP.$app$common$uuid$zero$$}();$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,
"  -\x3e set to "],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$114$$],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$72$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$114$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5170$invalid_frame$$,function($_$jscomp$2828_map__73899__$1$$,$p__73898$$,$file_data$jscomp$82$$){$_$jscomp$2828_map__73899__$1$$=$APP.$cljs$core$__destructure_map$$($p__73898$$);var $shape$jscomp$830$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2828_map__73899__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$355$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2828_map__73899__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :invalid-frame"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$830$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$830$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$355$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$355$$),$file_data$jscomp$82$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$830$$)],
null),function($shape__$1$jscomp$73$$){var $page$jscomp$113$$=$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$82$$,$page_id$jscomp$355$$),$frame$jscomp$44$$=$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$113$$),$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$73$$)),$frame_id$jscomp$115$$=function(){var $or__5025__auto__$jscomp$975$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$44$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$975$$)?$or__5025__auto__$jscomp$975$$:$APP.$app$common$uuid$zero$$}();$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,
"  -\x3e set to "],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$115$$],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$73$$,$APP.$cljs$cst$1607$frame_id$$,$frame_id$jscomp$115$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5171$component_not_main$$,function($_$jscomp$2829_map__73906__$1$$,$p__73905$$,$file_data$jscomp$83$$){$_$jscomp$2829_map__73906__$1$$=$APP.$cljs$core$__destructure_map$$($p__73905$$);var $shape$jscomp$831$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2829_map__73906__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$356$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2829_map__73906__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :component-not-main"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$831$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$831$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$356$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$356$$),$file_data$jscomp$83$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$831$$)],
null),function($shape__$1$jscomp$74$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e set :main-instance"],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$74$$,$APP.$cljs$cst$2045$main_instance$$,!0)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5172$component_main_external$$,function($_$jscomp$2830_map__73912__$1$$,$p__73911$$,$file_data$jscomp$84$$){$_$jscomp$2830_map__73912__$1$$=$APP.$cljs$core$__destructure_map$$($p__73911$$);var $shape$jscomp$832$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2830_map__73912__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$357$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2830_map__73912__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :component-main-external"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$832$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$832$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$357$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$357$$),$file_data$jscomp$84$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$832$$)],
null),function($shape__$1$jscomp$75$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e set :component-file to local file"],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$75$$,$APP.$cljs$cst$1643$component_file$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$84$$))})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5173$component_not_found$$,function($_$jscomp$2831_map__73914__$1_page$jscomp$114_shape_ids$jscomp$105$$,$p__73913$$,$file_data$jscomp$85$$){$_$jscomp$2831_map__73914__$1_page$jscomp$114_shape_ids$jscomp$105$$=$APP.$cljs$core$__destructure_map$$($p__73913$$);var $shape$jscomp$833$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2831_map__73914__$1_page$jscomp$114_shape_ids$jscomp$105$$,
$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$358$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2831_map__73914__$1_page$jscomp$114_shape_ids$jscomp$105$$,$APP.$cljs$cst$2043$page_id$$);$_$jscomp$2831_map__73914__$1_page$jscomp$114_shape_ids$jscomp$105$$=$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$85$$,$page_id$jscomp$358$$);$_$jscomp$2831_map__73914__$1_page$jscomp$114_shape_ids$jscomp$105$$=$app$common$files$helpers$get_children_ids_with_self$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2831_map__73914__$1_page$jscomp$114_shape_ids$jscomp$105$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$833$$));$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :component-not-found"],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$833$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$833$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$358$$],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$358$$),$file_data$jscomp$85$$),$_$jscomp$2831_map__73914__$1_page$jscomp$114_shape_ids$jscomp$105$$,function($shape__$1$jscomp$76$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e detach shape"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$76$$)],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $app$common$types$component$detach_shape$$($shape__$1$jscomp$76$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5174$invalid_main_instance_id$$,function($_$jscomp$2832_component$jscomp$99_map__73917__$1$$,$p__73915$$,$file_data$jscomp$86$$){function $detach_shape$jscomp$1$$($shape__$1$jscomp$77$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e detach shape"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$77$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $app$common$types$component$detach_shape$$($shape__$1$jscomp$77$$)}
function $repair_component$$($component__$1$jscomp$2$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e assign main-instance-id"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component__$1$jscomp$2$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($component__$1$jscomp$2$$,$APP.$cljs$cst$2062$main_instance_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$834$$))}$_$jscomp$2832_component$jscomp$99_map__73917__$1$$=
$APP.$cljs$core$__destructure_map$$($p__73915$$);var $shape$jscomp$834$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2832_component$jscomp$99_map__73917__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$359$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2832_component$jscomp$99_map__73917__$1$$,$APP.$cljs$cst$2043$page_id$$);$_$jscomp$2832_component$jscomp$99_map__73917__$1$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($file_data$jscomp$86$$,
$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$834$$));$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :invalid-main-instance-id"],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$834$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$834$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$359$$],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $_$jscomp$2832_component$jscomp$99_map__73917__$1$$!=null&&$APP.$cljs$core$not$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2832_component$jscomp$99_map__73917__$1$$))?$APP.$app$common$files$changes_builder$update_component$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,
$page_id$jscomp$359$$),$file_data$jscomp$86$$),$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$834$$),$repair_component$$):$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$359$$),$file_data$jscomp$86$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$834$$)],null),$detach_shape$jscomp$1$$)});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5175$invalid_main_instance_page$$,function($_$jscomp$2833_map__73929__$1$$,$p__73928$$,$file_data$jscomp$87$$){$_$jscomp$2833_map__73929__$1$$=$APP.$cljs$core$__destructure_map$$($p__73928$$);var $shape$jscomp$835$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2833_map__73929__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$360$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2833_map__73929__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :invalid-main-instance-page"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$835$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$835$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$360$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_component$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$360$$),$file_data$jscomp$87$$),$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$835$$),function($component$jscomp$100$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e assign main-instance-page"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1627$component_id$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$100$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($component$jscomp$100$$,$APP.$cljs$cst$2063$main_instance_page$$,$page_id$jscomp$360$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5176$invalid_main_instance$$,function($_$jscomp$2834_map__73935__$1$$,$p__73934$$,$file_data$jscomp$88$$){$_$jscomp$2834_map__73935__$1$$=$APP.$cljs$core$__destructure_map$$($p__73934$$);var $shape$jscomp$836$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2834_map__73935__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$361$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2834_map__73935__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :invalid-main-instance"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$836$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$836$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$361$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$361$$),$file_data$jscomp$88$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$836$$)],
null),function($shape__$1$jscomp$78$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e CANNOT REPAIR THIS AUTOMATICALLY."],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1162$warn$$,!1);return $shape__$1$jscomp$78$$})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5177$component_main$$,function($_$jscomp$2835_map__73943__$1$$,$p__73942$$,$file_data$jscomp$89$$){$_$jscomp$2835_map__73943__$1$$=$APP.$cljs$core$__destructure_map$$($p__73942$$);var $shape$jscomp$837$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2835_map__73943__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$362$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2835_map__73943__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :component-main"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$837$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$837$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$362$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$362$$),$file_data$jscomp$89$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$837$$)],
null),function($shape__$1$jscomp$79$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e unset :main-instance"],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$79$$,$APP.$cljs$cst$2045$main_instance$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5178$should_be_component_root$$,function($_$jscomp$2836_map__73953__$1$$,$p__73952$$,$file_data$jscomp$90$$){$_$jscomp$2836_map__73953__$1$$=$APP.$cljs$core$__destructure_map$$($p__73952$$);var $shape$jscomp$838$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2836_map__73953__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$363$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2836_map__73953__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :should-be-component-root"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$838$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$838$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$363$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$363$$),$file_data$jscomp$90$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$838$$)],
null),function($shape__$1$jscomp$80$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e set :component-root"],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$80$$,$APP.$cljs$cst$2044$component_root$$,!0)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5179$should_not_be_component_root$$,function($_$jscomp$2837_map__73964__$1$$,$p__73963$$,$file_data$jscomp$91$$){$_$jscomp$2837_map__73964__$1$$=$APP.$cljs$core$__destructure_map$$($p__73963$$);var $shape$jscomp$839$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2837_map__73964__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$364$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2837_map__73964__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :should-not-be-component-root"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$839$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$839$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$364$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$364$$),$file_data$jscomp$91$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$839$$)],
null),function($shape__$1$jscomp$81$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e unset :component-root"],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$81$$,$APP.$cljs$cst$2044$component_root$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5180$ref_shape_not_found$$,function($_$jscomp$2838_map__73976__$1_page$jscomp$115_shape_ids$jscomp$106$$,$p__73975$$,$file_data$jscomp$92$$,$libraries$jscomp$101$$){function $reassign_shape$$($shape__$1$jscomp$82$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e reassign shape-ref to"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2047$shape_ref$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($matching_shape$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$82$$,
$APP.$cljs$cst$2047$shape_ref$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($matching_shape$$))}$_$jscomp$2838_map__73976__$1_page$jscomp$115_shape_ids$jscomp$106$$=$APP.$cljs$core$__destructure_map$$($p__73975$$);var $shape$jscomp$840$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2838_map__73976__$1_page$jscomp$115_shape_ids$jscomp$106$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$365$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2838_map__73976__$1_page$jscomp$115_shape_ids$jscomp$106$$,
$APP.$cljs$cst$2043$page_id$$),$matching_shape$$=function(){var $component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$=$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$92$$,$page_id$jscomp$365$$),$component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$=$APP.$app$common$types$container$get_component_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$),
$shape$jscomp$840$$),$component_file$jscomp$6_temp__5823__auto__$jscomp$202$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$92$$))?$file_data$jscomp$92$$:$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$101$$,
$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$)));$component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$=$APP.$cljs$core$truth_$$($component_file$jscomp$6_temp__5823__auto__$jscomp$202$$)?$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($component_file$jscomp$6_temp__5823__auto__$jscomp$202$$,
$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$),!0):null;$component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$=$app$common$types$file$get_component_shapes$$($file_data$jscomp$92$$,$component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$);
$component_file$jscomp$6_temp__5823__auto__$jscomp$202$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73969_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($p1__73969_SHARP_$$),$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$840$$))},$component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$);
if($APP.$cljs$core$truth_$$($component_file$jscomp$6_temp__5823__auto__$jscomp$202$$))return $component_file$jscomp$6_temp__5823__auto__$jscomp$202$$;var $temp__5825__auto__$jscomp$290$$=$APP.$app$common$types$container$get_shape$$($component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$,$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$840$$));if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$290$$)){$component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$=
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73970_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73970_SHARP_$$),$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto__$jscomp$290$$))},$component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$);if($APP.$cljs$core$truth_$$($component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$))return $component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$;
$component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$=$APP.$app$common$types$container$get_head_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$),$shape$jscomp$840$$);$component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$92$$))?$file_data$jscomp$92$$:$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$101$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$)));
$component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$=$APP.$cljs$core$truth_$$($component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$)?$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$03$$($component$jscomp$101_component_file__$1$jscomp$3_component_shapes_root_shape$jscomp$7_temp__5823__auto____$1$jscomp$13$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$),
!0):null;$component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$=$app$common$types$file$get_component_shapes$$($file_data$jscomp$92$$,$component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$);$component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73974_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73974_SHARP_$$),
$APP.$cljs$cst$2047$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto__$jscomp$290$$))},$component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$);return $APP.$cljs$core$truth_$$($component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$)?$component__$1$jscomp$3_component_shapes__$1_head_shape$jscomp$2_page$jscomp$116_temp__5823__auto____$2$jscomp$2$$:null}return null}();$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :ref-shape-not-found"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$840$$)],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$840$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$365$$],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);if($matching_shape$$!=null)return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,
$page_id$jscomp$365$$),$file_data$jscomp$92$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$840$$)],null),$reassign_shape$$);$_$jscomp$2838_map__73976__$1_page$jscomp$115_shape_ids$jscomp$106$$=$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$92$$,$page_id$jscomp$365$$);$_$jscomp$2838_map__73976__$1_page$jscomp$115_shape_ids$jscomp$106$$=$app$common$files$helpers$get_children_ids_with_self$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2838_map__73976__$1_page$jscomp$115_shape_ids$jscomp$106$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$840$$));return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$365$$),$file_data$jscomp$92$$),$_$jscomp$2838_map__73976__$1_page$jscomp$115_shape_ids$jscomp$106$$,function($shape__$1$jscomp$83$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e detach shape"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$83$$)],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $app$common$types$component$detach_shape$$($shape__$1$jscomp$83$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5181$ref_shape_is_not_head$$,function($_$jscomp$2839_map__73982__$1$$,$p__73981$$,$file_data$jscomp$93$$){$_$jscomp$2839_map__73982__$1$$=$APP.$cljs$core$__destructure_map$$($p__73981$$);var $shape$jscomp$841$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2839_map__73982__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$366$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2839_map__73982__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :shape-ref-is-not-head"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$841$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$841$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$366$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$366$$),$file_data$jscomp$93$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$841$$)],
null),function($shape__$1$jscomp$84$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e unhead shape"],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $app$common$types$component$unhead_shape$$($shape__$1$jscomp$84$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5182$component_id_mismatch$$,function($_$jscomp$2840_map__73990__$1$$,$p__73985$$,$file_data$jscomp$94$$){$_$jscomp$2840_map__73990__$1$$=$APP.$cljs$core$__destructure_map$$($p__73985$$);var $shape$jscomp$842$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2840_map__73990__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$367$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2840_map__73990__$1$$,
$APP.$cljs$cst$2043$page_id$$),$args$jscomp$257$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2840_map__73990__$1$$,$cljs$cst$578$args$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$275$hint$$,"repairing shape :component-id-mismatch"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$842$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$842$$)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$367$$],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$367$$),$file_data$jscomp$94$$),new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$842$$)],null),function($G__73999__$1_G__73999__$2_G__73999__$3_shape__$1$jscomp$85$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,["  -\x3e set component-id to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$257$$))].join("")],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,["  -\x3e set component-file to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$257$$))].join("")],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);$G__73999__$1_G__73999__$2_G__73999__$3_shape__$1$jscomp$85$$=
$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$257$$)!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__73999__$1_G__73999__$2_G__73999__$3_shape__$1$jscomp$85$$,$APP.$cljs$cst$1627$component_id$$,$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$257$$)):$G__73999__$1_G__73999__$2_G__73999__$3_shape__$1$jscomp$85$$;$G__73999__$1_G__73999__$2_G__73999__$3_shape__$1$jscomp$85$$=$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$257$$)==
null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__73999__$1_G__73999__$2_G__73999__$3_shape__$1$jscomp$85$$,$APP.$cljs$cst$1627$component_id$$):$G__73999__$1_G__73999__$2_G__73999__$3_shape__$1$jscomp$85$$;$G__73999__$1_G__73999__$2_G__73999__$3_shape__$1$jscomp$85$$=$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$257$$)!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__73999__$1_G__73999__$2_G__73999__$3_shape__$1$jscomp$85$$,$APP.$cljs$cst$1643$component_file$$,
$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$257$$)):$G__73999__$1_G__73999__$2_G__73999__$3_shape__$1$jscomp$85$$;return $APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$257$$)==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__73999__$1_G__73999__$2_G__73999__$3_shape__$1$jscomp$85$$,$APP.$cljs$cst$1643$component_file$$):$G__73999__$1_G__73999__$2_G__73999__$3_shape__$1$jscomp$85$$})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5183$ref_shape_is_head$$,function($_$jscomp$2841_map__74003__$1$$,$p__74001$$,$file_data$jscomp$95$$){$_$jscomp$2841_map__74003__$1$$=$APP.$cljs$core$__destructure_map$$($p__74001$$);var $shape$jscomp$843$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2841_map__74003__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$368$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2841_map__74003__$1$$,
$APP.$cljs$cst$2043$page_id$$),$args$jscomp$258$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2841_map__74003__$1$$,$cljs$cst$578$args$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$275$hint$$,"repairing shape :shape-ref-is-head"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$843$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$843$$)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$368$$],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$368$$),$file_data$jscomp$95$$),new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$843$$)],null),function($shape__$1$jscomp$86$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$275$hint$$,"  -\x3e reroot shape"],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $app$common$types$component$rehead_shape$$($shape__$1$jscomp$86$$,$APP.$cljs$cst$1643$component_file$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$258$$),$APP.$cljs$cst$1627$component_id$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$258$$))})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5184$shape_ref_cycle$$,function($_$jscomp$2842_map__74014__$1$$,$p__74013$$,$file_data$jscomp$96$$){$_$jscomp$2842_map__74014__$1$$=$APP.$cljs$core$__destructure_map$$($p__74013$$);var $shape$jscomp$844$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2842_map__74014__$1$$,$APP.$cljs$cst$1811$shape$$),$args$jscomp$259$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2842_map__74014__$1$$,
$cljs$cst$578$args$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing component :shape-ref-cycle"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$844$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$844$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_component$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,
null),$file_data$jscomp$96$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$844$$),function($component$jscomp$102$$){var $objects$jscomp$695$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$102$$),$to_detach$$=$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__74010_SHARP_$$){return $app$common$types$container$get_children_in_instance$$($objects$jscomp$695$$,
$p1__74010_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74009_SHARP_$$){return $APP.$app$common$types$container$get_head_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$695$$,$p1__74009_SHARP_$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74008_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$695$$,
$p1__74008_SHARP_$$)},$cljs$cst$5185$cycles_ids$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$259$$)))))]))));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($component$jscomp$102$$,$APP.$cljs$cst$1631$objects$$,function($objects__$1$jscomp$32$$){return $APP.$cljs$core$reduce_kv$$(function($acc$jscomp$147$$,$k$jscomp$668$$,$v$jscomp$626$$){return $APP.$cljs$core$contains_QMARK_$$($to_detach$$,$k$jscomp$668$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$147$$,
$k$jscomp$668$$,$app$common$types$component$detach_shape$$($v$jscomp$626$$)):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$147$$,$k$jscomp$668$$,$v$jscomp$626$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$objects__$1$jscomp$32$$)})})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5186$shape_ref_in_main$$,function($_$jscomp$2843_map__74023__$1$$,$p__74021$$,$file_data$jscomp$97$$){$_$jscomp$2843_map__74023__$1$$=$APP.$cljs$core$__destructure_map$$($p__74021$$);var $shape$jscomp$845$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2843_map__74023__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$369$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2843_map__74023__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :shape-ref-in-main"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$845$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$845$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$369$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$369$$),$file_data$jscomp$97$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$845$$)],
null),function($shape__$1$jscomp$87$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e unset :shape-ref"],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$87$$,$APP.$cljs$cst$2047$shape_ref$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5187$root_main_not_allowed$$,function($_$jscomp$2844_map__74035__$1$$,$p__74034$$,$file_data$jscomp$98$$){$_$jscomp$2844_map__74035__$1$$=$APP.$cljs$core$__destructure_map$$($p__74034$$);var $shape$jscomp$846$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2844_map__74035__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$370$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2844_map__74035__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :root-main-not-allowed"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$846$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$846$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$370$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$370$$),$file_data$jscomp$98$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$846$$)],
null),function($shape__$1$jscomp$88$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e unset :component-root"],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$88$$,$APP.$cljs$cst$2044$component_root$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5188$nested_main_not_allowed$$,function($_$jscomp$2845_map__74042__$1$$,$p__74041$$,$file_data$jscomp$99$$){$_$jscomp$2845_map__74042__$1$$=$APP.$cljs$core$__destructure_map$$($p__74041$$);var $shape$jscomp$847$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2845_map__74042__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$371$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2845_map__74042__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :nested-main-not-allowed"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$847$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$847$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$371$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$05$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$371$$),$file_data$jscomp$99$$),new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$847$$)],null),function($shape__$1$jscomp$89$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$275$hint$$,"  -\x3e set :component-root"],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$89$$,$APP.$cljs$cst$2044$component_root$$,!0)}),$APP.$app$common$uuid$zero$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$847$$],null),null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$2618$allow_altering_copies$$,
!0],null))});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5189$root_copy_not_allowed$$,function($_$jscomp$2846_map__74048__$1$$,$p__74047$$,$file_data$jscomp$100$$){$_$jscomp$2846_map__74048__$1$$=$APP.$cljs$core$__destructure_map$$($p__74047$$);var $shape$jscomp$848$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2846_map__74048__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$372$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2846_map__74048__$1$$,$APP.$cljs$cst$2043$page_id$$);
$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :root-copy-not-allowed"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$848$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$848$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$372$$],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$372$$),$file_data$jscomp$100$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$848$$)],
null),function($shape__$1$jscomp$90$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e unset :component-root"],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$90$$,$APP.$cljs$cst$2044$component_root$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5190$nested_copy_not_allowed$$,function($_$jscomp$2847_map__74053__$1$$,$p__74052$$,$file_data$jscomp$101$$){$_$jscomp$2847_map__74053__$1$$=$APP.$cljs$core$__destructure_map$$($p__74052$$);var $shape$jscomp$849$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2847_map__74053__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$373$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2847_map__74053__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :nested-copy-not-allowed"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$849$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$849$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$373$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$373$$),$file_data$jscomp$101$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$849$$)],
null),function($shape__$1$jscomp$91$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e set :component-root"],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$91$$,$APP.$cljs$cst$2044$component_root$$,!0)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5191$not_head_main_not_allowed$$,function($_$jscomp$2848_map__74058__$1$$,$p__74057$$,$file_data$jscomp$102$$){$_$jscomp$2848_map__74058__$1$$=$APP.$cljs$core$__destructure_map$$($p__74057$$);var $shape$jscomp$850$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2848_map__74058__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$374$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2848_map__74058__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :not-head-main-not-allowed"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$850$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$850$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$374$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$374$$),$file_data$jscomp$102$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$850$$)],
null),function($shape__$1$jscomp$92$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e detach shape"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$92$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $app$common$types$component$detach_shape$$($shape__$1$jscomp$92$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5192$not_head_copy_not_allowed$$,function($_$jscomp$2849_map__74060__$1$$,$p__74059$$,$file_data$jscomp$103$$){$_$jscomp$2849_map__74060__$1$$=$APP.$cljs$core$__destructure_map$$($p__74059$$);var $shape$jscomp$851$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2849_map__74060__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$375$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2849_map__74060__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :not-head-copy-not-allowed"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$851$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$851$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$375$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$375$$),$file_data$jscomp$103$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$851$$)],
null),function($shape__$1$jscomp$93$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e detach shape"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2543$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$93$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $app$common$types$component$detach_shape$$($shape__$1$jscomp$93$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5193$not_component_not_allowed$$,function($_$jscomp$2850_map__74070__$1$$,$p__74069$$,$file_data$jscomp$104$$){$_$jscomp$2850_map__74070__$1$$=$APP.$cljs$core$__destructure_map$$($p__74069$$);var $shape$jscomp$852$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2850_map__74070__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$376$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2850_map__74070__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :not-component-not-allowed"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$852$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$852$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$376$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$376$$),$file_data$jscomp$104$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$852$$)],
null),function($shape__$1$jscomp$94$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e CANNOT REPAIR THIS AUTOMATICALLY."],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1162$warn$$,!1);return $shape__$1$jscomp$94$$})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5194$instance_head_not_frame$$,function($_$jscomp$2851_map__74072__$1$$,$p__74071$$,$file_data$jscomp$105$$){$_$jscomp$2851_map__74072__$1$$=$APP.$cljs$core$__destructure_map$$($p__74071$$);var $shape$jscomp$853$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2851_map__74072__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$377$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2851_map__74072__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :instance-head-not-frame"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$853$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$853$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$377$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$377$$),$file_data$jscomp$105$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$853$$)],
null),function($shape__$1$jscomp$95$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e set :type :frame"],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape__$1$jscomp$95$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1606$frame$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1634$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$1875$hide_in_viewer$$,!0,$APP.$cljs$cst$1646$r1$$,0,$APP.$cljs$cst$1647$r2$$,0,$APP.$cljs$cst$1648$r3$$,0,$APP.$cljs$cst$1649$r4$$,0]))})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5195$component_nil_objects_not_allowed$$,function($_$jscomp$2852_map__74083__$1$$,$p__74082$$,$file_data$jscomp$106$$){$_$jscomp$2852_map__74083__$1$$=$APP.$cljs$core$__destructure_map$$($p__74082$$);var $component$jscomp$103$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2852_map__74083__$1$$,$APP.$cljs$cst$1811$shape$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing component :component-nil-objects-not-allowed"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$103$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$103$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_component$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$file_data$jscomp$106$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$103$$),function($component__$1$jscomp$4$$){if($APP.$cljs$core$truth_$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component__$1$jscomp$4$$)))return $APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e set :objects {}"],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($component__$1$jscomp$4$$,$APP.$cljs$cst$1631$objects$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e remove :objects"],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($component__$1$jscomp$4$$,$APP.$cljs$cst$1631$objects$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5196$non_deleted_component_cannot_have_objects$$,function($_$jscomp$2853_map__74091__$1$$,$p__74090$$,$file_data$jscomp$107$$){$_$jscomp$2853_map__74091__$1$$=$APP.$cljs$core$__destructure_map$$($p__74090$$);var $component$jscomp$104$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2853_map__74091__$1$$,$APP.$cljs$cst$1811$shape$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing component :non-deleted-component-cannot-have-objects"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$104$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$104$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_component$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$file_data$jscomp$107$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$104$$),function($component__$1$jscomp$5$$){return $APP.$cljs$core$not$$($APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component__$1$jscomp$5$$))?($APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e remove :objects"],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($component__$1$jscomp$5$$,$APP.$cljs$cst$1631$objects$$)):$component__$1$jscomp$5$$})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5197$invalid_text_touched$$,function($_$jscomp$2854_map__74098__$1$$,$p__74097$$,$file_data$jscomp$108$$){$_$jscomp$2854_map__74098__$1$$=$APP.$cljs$core$__destructure_map$$($p__74097$$);var $shape$jscomp$854$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2854_map__74098__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$378$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2854_map__74098__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :invalid-text-touched"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$854$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$854$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$378$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$378$$),$file_data$jscomp$108$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$854$$)],
null),function($shape__$1$jscomp$96$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e add :content-group to :touched-groups"],null)],null)}),null,
"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape__$1$jscomp$96$$,$APP.$cljs$cst$1626$touched$$,$app$common$types$component$set_touched_group$$,$cljs$cst$2070$content_group$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5198$misplaced_slot$$,function($_$jscomp$2855_map__74102__$1$$,$p__74101$$,$file_data$jscomp$109$$){$_$jscomp$2855_map__74102__$1$$=$APP.$cljs$core$__destructure_map$$($p__74101$$);var $shape$jscomp$855$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2855_map__74102__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$379$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2855_map__74102__$1$$,
$APP.$cljs$cst$2043$page_id$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :misplaced-slot"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$855$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$855$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$379$$],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$379$$),$file_data$jscomp$109$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$855$$)],
null),function($shape__$1$jscomp$97$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e remove swap-slot"],null)],null)}),null,"app.common.files.repair",
$APP.$cljs$cst$1160$debug$$,!1);return $app$common$types$component$remove_swap_slot$$($shape__$1$jscomp$97$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5199$duplicate_slot$$,function($_$jscomp$2856_child_with_duplicate_map__74109__$1$$,$p__74108$$,$file_data$jscomp$110$$){$_$jscomp$2856_child_with_duplicate_map__74109__$1$$=$APP.$cljs$core$__destructure_map$$($p__74108$$);var $shape$jscomp$856$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2856_child_with_duplicate_map__74109__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$380$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2856_child_with_duplicate_map__74109__$1$$,$APP.$cljs$cst$2043$page_id$$),$page$jscomp$117$$=$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$110$$,$page_id$jscomp$380$$),$childs$jscomp$19$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74107_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$117$$),$p1__74107_SHARP_$$)},
$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$856$$));$_$jscomp$2856_child_with_duplicate_map__74109__$1$$=function(){var $result$jscomp$324$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($duplicates$jscomp$1_p__74114$$,$item$jscomp$107$$){var $seen$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($duplicates$jscomp$1_p__74114$$,0,null);$duplicates$jscomp$1_p__74114$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($duplicates$jscomp$1_p__74114$$,
1,null);var $swap_slot$jscomp$6$$=$APP.$app$common$types$component$get_swap_slot$$($item$jscomp$107$$);return $APP.$cljs$core$contains_QMARK_$$($seen$jscomp$12$$,$swap_slot$jscomp$6$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$seen$jscomp$12$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($duplicates$jscomp$1_p__74114$$,$item$jscomp$107$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($seen$jscomp$12$$,$swap_slot$jscomp$6$$),$duplicates$jscomp$1_p__74114$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$childs$jscomp$19$$);return $APP.$cljs$core$second$$($result$jscomp$324$$)}();$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing shape :duplicated-slot"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$856$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$856$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$380$$],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,
$page_id$jscomp$380$$),$file_data$jscomp$110$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$_$jscomp$2856_child_with_duplicate_map__74109__$1$$),function($shape__$1$jscomp$98$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"  -\x3e remove swap-slot"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5167$child_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$98$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $app$common$types$component$remove_swap_slot$$($shape__$1$jscomp$98$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5200$component_duplicate_slot$$,function($_$jscomp$2857_childs_with_duplicate_main_shape$jscomp$3_map__74122__$1$$,$p__74121$$,$file_data$jscomp$111$$){$_$jscomp$2857_childs_with_duplicate_main_shape$jscomp$3_map__74122__$1$$=$APP.$cljs$core$__destructure_map$$($p__74121$$);var $shape$jscomp$857$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2857_childs_with_duplicate_main_shape$jscomp$3_map__74122__$1$$,
$APP.$cljs$cst$1811$shape$$);$_$jscomp$2857_childs_with_duplicate_main_shape$jscomp$3_map__74122__$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$857$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$objects$$,$APP.$cljs$cst$2062$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$857$$)],null));var $childs$jscomp$20$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74120_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$857$$),
$p1__74120_SHARP_$$)},$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2857_childs_with_duplicate_main_shape$jscomp$3_map__74122__$1$$));$_$jscomp$2857_childs_with_duplicate_main_shape$jscomp$3_map__74122__$1$$=function(){var $result$jscomp$325$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($duplicates$jscomp$2_p__74123$$,$item$jscomp$108$$){var $seen$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($duplicates$jscomp$2_p__74123$$,
0,null);$duplicates$jscomp$2_p__74123$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($duplicates$jscomp$2_p__74123$$,1,null);var $swap_slot$jscomp$7$$=$APP.$app$common$types$component$get_swap_slot$$($item$jscomp$108$$);return $APP.$cljs$core$contains_QMARK_$$($seen$jscomp$13$$,$swap_slot$jscomp$7$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$seen$jscomp$13$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($duplicates$jscomp$2_p__74123$$,
$item$jscomp$108$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($seen$jscomp$13$$,$swap_slot$jscomp$7$$),$duplicates$jscomp$2_p__74123$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$childs$jscomp$20$$);return $APP.$cljs$core$second$$($result$jscomp$325$$)}();
var $duplicated_ids$$=$APP.$cljs$core$set$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$_$jscomp$2857_childs_with_duplicate_main_shape$jscomp$3_map__74122__$1$$));$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repairing component :component-duplicated-slot"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$857$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$857$$)],
null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_component$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$file_data$jscomp$111$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$857$$),function($component$jscomp$105$$){var $objects$jscomp$696$$=$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$148$$,
$k$jscomp$669$$,$v$jscomp$627$$){return $APP.$cljs$core$contains_QMARK_$$($duplicated_ids$$,$k$jscomp$669$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$148$$,$k$jscomp$669$$,$app$common$types$component$remove_swap_slot$$($v$jscomp$627$$)):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$148$$,$k$jscomp$669$$,$v$jscomp$627$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$105$$));
return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($component$jscomp$105$$,$APP.$cljs$cst$1631$objects$$,$objects$jscomp$696$$)})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5201$missing_slot$$,function($_$jscomp$2858_map__74131__$1$$,$p__74130$$,$file_data$jscomp$112$$){$_$jscomp$2858_map__74131__$1$$=$APP.$cljs$core$__destructure_map$$($p__74130$$);var $shape$jscomp$858$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2858_map__74131__$1$$,$APP.$cljs$cst$1811$shape$$),$page_id$jscomp$381$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2858_map__74131__$1$$,
$APP.$cljs$cst$2043$page_id$$),$args$jscomp$260$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2858_map__74131__$1$$,$cljs$cst$578$args$$);$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$275$hint$$,"repairing shape :missing-slot"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$858$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$858$$)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$381$$],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$page_id$jscomp$381$$),$file_data$jscomp$112$$),new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$858$$)],null),function($shape__$1$jscomp$99$$){var $slot$$=$cljs$cst$5202$swap_slot$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$260$$);return $slot$$!=null?($APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,["  -\x3e set swap-slot to ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($slot$$)].join("")],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$1160$debug$$,!1),$app$common$types$component$set_swap_slot$$($shape__$1$jscomp$99$$,$slot$$)):$shape__$1$jscomp$99$$})});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5203$not_a_variant$$,function($_$jscomp$2859$$,$error$jscomp$127$$,$file$jscomp$91$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"Variant error code, we don't want to auto repair it for now"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$127$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$849$error$$,!1);return $file$jscomp$91$$});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5204$invalid_variant_id$$,function($_$jscomp$2860$$,$error$jscomp$128$$,$file$jscomp$92$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"Variant error code, we don't want to auto repair it for now"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$128$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$849$error$$,!1);return $file$jscomp$92$$});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5205$invalid_variant_properties$$,function($_$jscomp$2861$$,$error$jscomp$129$$,$file$jscomp$93$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"Variant error code, we don't want to auto repair it for now"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$129$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$849$error$$,!1);return $file$jscomp$93$$});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5206$variant_not_main$$,function($_$jscomp$2862$$,$error$jscomp$130$$,$file$jscomp$94$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"Variant error code, we don't want to auto repair it for now"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$130$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$849$error$$,!1);return $file$jscomp$94$$});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5207$parent_not_variant$$,function($_$jscomp$2863$$,$error$jscomp$131$$,$file$jscomp$95$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"Variant error code, we don't want to auto repair it for now"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$131$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$849$error$$,!1);return $file$jscomp$95$$});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5208$variant_bad_name$$,function($_$jscomp$2864$$,$error$jscomp$132$$,$file$jscomp$96$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"Variant error code, we don't want to auto repair it for now"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$132$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$849$error$$,!1);return $file$jscomp$96$$});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5209$variant_bad_variant_name$$,function($_$jscomp$2865$$,$error$jscomp$133$$,$file$jscomp$97$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"Variant error code, we don't want to auto repair it for now"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$133$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$849$error$$,!1);return $file$jscomp$97$$});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$cljs$cst$5210$variant_component_bad_name$$,function($_$jscomp$2866$$,$error$jscomp$134$$,$file$jscomp$98$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"Variant error code, we don't want to auto repair it for now"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$134$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$849$error$$,!1);return $file$jscomp$98$$});
$app$common$files$repair$repair_error$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function($_$jscomp$2867$$,$error$jscomp$135$$,$file$jscomp$99$$){$APP.$app$common$logging$enabled_QMARK_$$("app.common.files.repair",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"Unknown error code, don't know how to repair"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$135$$)],null)],null)}),null,"app.common.files.repair",$APP.$cljs$cst$849$error$$,!1);return $file$jscomp$99$$});$app$common$schema$check_fn$$(new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ValidationError"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$273$code$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!1],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,47,[$cljs$cst$5166$child_not_found$$,null,$cljs$cst$5174$invalid_main_instance_id$$,null,$cljs$cst$5175$invalid_main_instance_page$$,null,$cljs$cst$5198$misplaced_slot$$,null,$cljs$cst$5187$root_main_not_allowed$$,null,$cljs$cst$5178$should_be_component_root$$,null,$cljs$cst$5181$ref_shape_is_not_head$$,
null,$cljs$cst$5200$component_duplicate_slot$$,null,$cljs$cst$5191$not_head_main_not_allowed$$,null,$cljs$cst$5206$variant_not_main$$,null,$cljs$cst$5169$frame_not_found$$,null,$cljs$cst$5204$invalid_variant_id$$,null,$cljs$cst$5208$variant_bad_name$$,null,$cljs$cst$5180$ref_shape_not_found$$,null,$cljs$cst$5162$invalid_geometry$$,null,$cljs$cst$5163$parent_not_found$$,null,$cljs$cst$5165$duplicated_children$$,null,$cljs$cst$5184$shape_ref_cycle$$,null,$cljs$cst$5190$nested_copy_not_allowed$$,null,
$cljs$cst$5173$component_not_found$$,null,$cljs$cst$5172$component_main_external$$,null,$cljs$cst$5197$invalid_text_touched$$,null,$cljs$cst$5211$variant_component_bad_id$$,null,$cljs$cst$5195$component_nil_objects_not_allowed$$,null,$cljs$cst$5203$not_a_variant$$,null,$cljs$cst$5194$instance_head_not_frame$$,null,$cljs$cst$5171$component_not_main$$,null,$cljs$cst$5210$variant_component_bad_name$$,null,$cljs$cst$5209$variant_bad_variant_name$$,null,$cljs$cst$5205$invalid_variant_properties$$,null,
$cljs$cst$5201$missing_slot$$,null,$cljs$cst$5177$component_main$$,null,$cljs$cst$5189$root_copy_not_allowed$$,null,$cljs$cst$5164$child_not_in_parent$$,null,$cljs$cst$5170$invalid_frame$$,null,$cljs$cst$5196$non_deleted_component_cannot_have_objects$$,null,$cljs$cst$5179$should_not_be_component_root$$,null,$cljs$cst$5168$invalid_parent$$,null,$cljs$cst$5182$component_id_mismatch$$,null,$cljs$cst$5176$invalid_main_instance$$,null,$cljs$cst$5183$ref_shape_is_head$$,null,$cljs$cst$5193$not_component_not_allowed$$,
null,$cljs$cst$5192$not_head_copy_not_allowed$$,null,$cljs$cst$5207$parent_not_variant$$,null,$cljs$cst$5199$duplicate_slot$$,null,$cljs$cst$5188$nested_main_not_allowed$$,null,$cljs$cst$5186$shape_ref_in_main$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!1],null),$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1811$shape$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$202$map$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2543$shape_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$file_id$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2043$page_id$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null)],null)],null));var $app$common$files$validate$_STAR_errors_STAR_$$=null,$app$common$files$validate$_STAR_ref_shape_cache_STAR_$$=null,$app$common$files$validate$_STAR_children_sets_STAR_$$=null;var $app$main$data$dashboard$shortcuts$shortcuts_sidebar_navigation$$,$app$main$data$dashboard$shortcuts$shortcut_search$$,$app$main$data$dashboard$shortcuts$shortcut_create_new_project$$;
$APP.$app$main$data$dashboard$shortcuts$shortcuts$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4874$toggle_theme$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$app$main$data$shortcuts$alt$$("M"),$APP.$cljs$cst$1812$command$$,$app$main$data$shortcuts$a_mod$$("m"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5224$general_dashboard$$],null),$APP.$cljs$cst$516$fn$$,
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$profile$toggle_theme$$(),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2277$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard:shortcuts"],null)))}],null)],null);
$app$main$data$dashboard$shortcuts$shortcuts_sidebar_navigation$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5225$go_to_drafts$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"G D",$APP.$cljs$cst$1812$command$$,"g d",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5226$navigation_dashboard$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2181$project_id$$,
$APP.$cljs$cst$205$default$$])))}],null),$cljs$cst$5227$go_to_libs$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"G L",$APP.$cljs$cst$1812$command$$,"g l",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5226$navigation_dashboard$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_dashboard_libraries$$())}],
null)],null);
$app$main$data$dashboard$shortcuts$shortcut_search$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5228$go_to_search$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("F"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("f"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5226$navigation_dashboard$$],null),$APP.$cljs$cst$516$fn$$,
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_dashboard_search$$())}],null)],null);
$app$main$data$dashboard$shortcuts$shortcut_create_new_project$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5229$create_new_project$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"+",$APP.$cljs$cst$1812$command$$,"+",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5224$general_dashboard$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$create_element$$())}],
null)],null);$APP.$app$main$data$dashboard$shortcuts$shortcuts_dashboard$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$dashboard$shortcuts$shortcuts$$,$app$main$data$dashboard$shortcuts$shortcuts_sidebar_navigation$$]));
$APP.$app$main$data$dashboard$shortcuts$shortcuts_projects$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$dashboard$shortcuts$shortcuts$$,$app$main$data$dashboard$shortcuts$shortcuts_sidebar_navigation$$,$app$main$data$dashboard$shortcuts$shortcut_search$$,$app$main$data$dashboard$shortcuts$shortcut_create_new_project$$]));
$APP.$app$main$data$dashboard$shortcuts$shortcuts_drafts_libraries$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$dashboard$shortcuts$shortcuts$$,$app$main$data$dashboard$shortcuts$shortcuts_sidebar_navigation$$,$app$main$data$dashboard$shortcuts$shortcut_search$$]));var $app$main$data$viewer$update_zoom_querystring_74066$$,$app$main$data$viewer$increase_zoom_74074$$,$app$main$data$viewer$decrease_zoom_74087$$,$app$main$data$viewer$reset_zoom_74093$$,$app$main$data$viewer$zoom_to_fit_74104$$,$app$main$data$viewer$zoom_to_fill_74127$$,$app$main$data$viewer$toggle_zoom_style_74139$$,$app$main$data$viewer$toggle_fullscreen_74162$$,$app$main$data$viewer$toggle_thumbnails_panel_74195$$,$app$main$data$viewer$close_thumbnails_panel_74204$$,$app$main$data$viewer$select_prev_frame_74211$$,
$app$main$data$viewer$select_next_frame_74219$$,$app$main$data$viewer$select_first_frame_74224$$,$app$main$data$viewer$set_interactions_mode_74230$$,$app$main$data$viewer$flash_interactions_74253$$,$app$main$data$viewer$flash_done_74256$$,$app$main$data$viewer$set_nav_scroll_74261$$,$app$main$data$viewer$go_to_frame_by_index_74283$$,$app$main$data$viewer$go_to_frame_74300$$,$app$main$data$viewer$go_to_section_74318$$,$app$main$data$viewer$open_overlay_74345$$,$app$main$data$viewer$toggle_overlay_74419$$,
$app$main$data$viewer$close_overlay_74493$$,$app$main$data$viewer$select_all_74645$$,$app$main$data$viewer$go_to_dashboard_74678$$,$app$main$data$viewer$go_to_page_74682$$,$app$main$data$viewer$go_to_workspace_74687$$,$app$main$data$viewer$update_zoom_querystring$$;
$APP.$app$main$data$viewer$default_local_state$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$2196$zoom$$,$cljs$cst$5230$comments_mode$$,$APP.$cljs$cst$2234$fullscreen_QMARK_$$,$APP.$cljs$cst$1921$selected$$,$APP.$cljs$cst$2048$collapsed$$,$cljs$cst$3235$file_comments_users$$,$APP.$cljs$cst$5231$interactions_mode$$,$APP.$cljs$cst$2204$hover$$,$cljs$cst$5232$show_interactions$$,$APP.$cljs$cst$3237$share_id$$,$cljs$cst$5233$comments_show$$],[1,$APP.$cljs$cst$2124$all$$,!1,$APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$5234$show_on_click$$,null,!1,"",$cljs$cst$5235$unresolved$$]);
typeof $app$main$data$viewer$update_zoom_querystring_74066$$==="undefined"&&($app$main$data$viewer$update_zoom_querystring_74066$$=function($meta74067$jscomp$inline_7732$$){this.$meta74067$=$meta74067$jscomp$inline_7732$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$viewer$update_zoom_querystring_74066$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5250$app_DOT_main_DOT_data_DOT_viewer_SLASH_update_zoom_querystring$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74068$jscomp$inline_7733$$,$meta74067__$1$jscomp$inline_7734$$){return new $app$main$data$viewer$update_zoom_querystring_74066$$($meta74067__$1$jscomp$inline_7734$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74067$},
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$inline_7735_zoom_type$jscomp$inline_7737$$,$params$jscomp$inline_7738_state$jscomp$inline_7736$$){$_$jscomp$inline_7735_zoom_type$jscomp$inline_7737$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$inline_7738_state$jscomp$inline_7736$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2235$zoom_type$$],null));$params$jscomp$inline_7738_state$jscomp$inline_7736$$=$APP.$app$main$router$get_params$$($params$jscomp$inline_7738_state$jscomp$inline_7736$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1592$viewer$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($params$jscomp$inline_7738_state$jscomp$inline_7736$$,
$APP.$cljs$cst$2196$zoom$$,$_$jscomp$inline_7735_zoom_type$jscomp$inline_7737$$)))});$app$main$data$viewer$update_zoom_querystring$$=new $app$main$data$viewer$update_zoom_querystring_74066$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
typeof $app$main$data$viewer$increase_zoom_74074$$==="undefined"&&($app$main$data$viewer$increase_zoom_74074$$=function($meta74075$jscomp$inline_7740$$){this.$meta74075$=$meta74075$jscomp$inline_7740$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$viewer$increase_zoom_74074$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5251$app_DOT_main_DOT_data_DOT_viewer_SLASH_increase_zoom$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74076$jscomp$inline_7741$$,$meta74075__$1$jscomp$inline_7742$$){return new $app$main$data$viewer$increase_zoom_74074$$($meta74075__$1$jscomp$inline_7742$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74075$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_7743$$,$state$jscomp$inline_7744$$){return $APP.$app$common$data$dissoc_in$$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$inline_7744$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2196$zoom$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__74073_SHARP_$jscomp$inline_7745_x__5113__auto__$jscomp$inline_7746$$){$p1__74073_SHARP_$jscomp$inline_7745_x__5113__auto__$jscomp$inline_7746$$*=
1.3;return $p1__74073_SHARP_$jscomp$inline_7745_x__5113__auto__$jscomp$inline_7746$$<200?$p1__74073_SHARP_$jscomp$inline_7745_x__5113__auto__$jscomp$inline_7746$$:200},1)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2235$zoom_type$$],null))});$APP.$app$main$data$viewer$increase_zoom$$=new $app$main$data$viewer$increase_zoom_74074$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
typeof $app$main$data$viewer$decrease_zoom_74087$$==="undefined"&&($app$main$data$viewer$decrease_zoom_74087$$=function($meta74088$jscomp$inline_7748$$){this.$meta74088$=$meta74088$jscomp$inline_7748$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$viewer$decrease_zoom_74087$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5252$app_DOT_main_DOT_data_DOT_viewer_SLASH_decrease_zoom$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74089$jscomp$inline_7749$$,$meta74088__$1$jscomp$inline_7750$$){return new $app$main$data$viewer$decrease_zoom_74087$$($meta74088__$1$jscomp$inline_7750$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74088$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_7751$$,$state$jscomp$inline_7752$$){return $APP.$app$common$data$dissoc_in$$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$inline_7752$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2196$zoom$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__74086_SHARP_$jscomp$inline_7753_x__5110__auto__$jscomp$inline_7754$$){$p1__74086_SHARP_$jscomp$inline_7753_x__5110__auto__$jscomp$inline_7754$$/=
1.3;return $p1__74086_SHARP_$jscomp$inline_7753_x__5110__auto__$jscomp$inline_7754$$>.01?$p1__74086_SHARP_$jscomp$inline_7753_x__5110__auto__$jscomp$inline_7754$$:.01},1)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2235$zoom_type$$],null))});$APP.$app$main$data$viewer$decrease_zoom$$=new $app$main$data$viewer$decrease_zoom_74087$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $app$main$data$viewer$reset_zoom$$;
typeof $app$main$data$viewer$reset_zoom_74093$$==="undefined"&&($app$main$data$viewer$reset_zoom_74093$$=function($meta74094$jscomp$inline_7756$$){this.$meta74094$=$meta74094$jscomp$inline_7756$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$viewer$reset_zoom_74093$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5253$app_DOT_main_DOT_data_DOT_viewer_SLASH_reset_zoom$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74095$jscomp$inline_7757$$,$meta74094__$1$jscomp$inline_7758$$){return new $app$main$data$viewer$reset_zoom_74093$$($meta74094__$1$jscomp$inline_7758$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74094$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_7759$$,$state$jscomp$inline_7760$$){return $APP.$app$common$data$dissoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$inline_7760$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2196$zoom$$],null),1),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,
$APP.$cljs$cst$2235$zoom_type$$],null))});$app$main$data$viewer$reset_zoom$$=new $app$main$data$viewer$reset_zoom_74093$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
typeof $app$main$data$viewer$zoom_to_fit_74104$$==="undefined"&&($app$main$data$viewer$zoom_to_fit_74104$$=function($meta74105$jscomp$inline_7762$$){this.$meta74105$=$meta74105$jscomp$inline_7762$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$viewer$zoom_to_fit_74104$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5254$app_DOT_main_DOT_data_DOT_viewer_SLASH_zoom_to_fit$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74106$jscomp$inline_7763$$,$meta74105__$1$jscomp$inline_7764$$){return new $app$main$data$viewer$zoom_to_fit_74104$$($meta74105__$1$jscomp$inline_7764$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74105$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_7765_index__$1$jscomp$inline_7771_page_id$jscomp$inline_7768_wdiff$jscomp$inline_7774$$,$state$jscomp$inline_7766$$){var $params$jscomp$inline_7767$$=$APP.$app$main$router$get_params$$($state$jscomp$inline_7766$$);$_$jscomp$inline_7765_index__$1$jscomp$inline_7771_page_id$jscomp$inline_7768_wdiff$jscomp$inline_7774$$=function(){var $G__74118$jscomp$inline_7776$$=$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$inline_7767$$);
return $G__74118$jscomp$inline_7776$$==null?null:$APP.$app$common$uuid$parse$$($G__74118$jscomp$inline_7776$$)}();var $index$jscomp$inline_7769$$=function(){var $G__74119$jscomp$inline_7777$$=$APP.$app$main$router$get_query_param$$($params$jscomp$inline_7767$$,$APP.$cljs$cst$1795$index$$);return $G__74119$jscomp$inline_7777$$==null?null:$APP.$cljs$core$parse_long$$($G__74119$jscomp$inline_7777$$)}(),$frames$jscomp$inline_7770$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$inline_7766$$,
$APP.$cljs$cst$1592$viewer$$),$APP.$cljs$cst$2228$pages$$),$_$jscomp$inline_7765_index__$1$jscomp$inline_7771_page_id$jscomp$inline_7768_wdiff$jscomp$inline_7774$$),$APP.$cljs$cst$5241$frames$$);$_$jscomp$inline_7765_index__$1$jscomp$inline_7771_page_id$jscomp$inline_7768_wdiff$jscomp$inline_7774$$=function(){var $x__5113__auto__$jscomp$inline_7778$$=$APP.$cljs$core$truth_$$($index$jscomp$inline_7769$$)?$index$jscomp$inline_7769$$:0;var $y__5111__auto__$jscomp$inline_14521_y__5114__auto__$jscomp$inline_7779$$=
$APP.$cljs$core$count$$($frames$jscomp$inline_7770$$)-1;$y__5111__auto__$jscomp$inline_14521_y__5114__auto__$jscomp$inline_7779$$=0>$y__5111__auto__$jscomp$inline_14521_y__5114__auto__$jscomp$inline_7779$$?0:$y__5111__auto__$jscomp$inline_14521_y__5114__auto__$jscomp$inline_7779$$;return $x__5113__auto__$jscomp$inline_7778$$<$y__5111__auto__$jscomp$inline_14521_y__5114__auto__$jscomp$inline_7779$$?$x__5113__auto__$jscomp$inline_7778$$:$y__5111__auto__$jscomp$inline_14521_y__5114__auto__$jscomp$inline_7779$$}();
var $hdiff$jscomp$inline_7775_srect$jscomp$inline_7772$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($frames$jscomp$inline_7770$$,$_$jscomp$inline_7765_index__$1$jscomp$inline_7771_page_id$jscomp$inline_7768_wdiff$jscomp$inline_7774$$),$APP.$cljs$cst$1605$selrect$$),$osize$jscomp$inline_7773$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$inline_7766$$,$APP.$cljs$cst$2231$viewer_local$$),
$APP.$cljs$cst$5255$viewport_size$$);$_$jscomp$inline_7765_index__$1$jscomp$inline_7771_page_id$jscomp$inline_7768_wdiff$jscomp$inline_7774$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($osize$jscomp$inline_7773$$)/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($hdiff$jscomp$inline_7775_srect$jscomp$inline_7772$$);$hdiff$jscomp$inline_7775_srect$jscomp$inline_7772$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($osize$jscomp$inline_7773$$)/$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($hdiff$jscomp$inline_7775_srect$jscomp$inline_7772$$);
return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$inline_7766$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2196$zoom$$],null),$_$jscomp$inline_7765_index__$1$jscomp$inline_7771_page_id$jscomp$inline_7768_wdiff$jscomp$inline_7774$$<$hdiff$jscomp$inline_7775_srect$jscomp$inline_7772$$?$_$jscomp$inline_7765_index__$1$jscomp$inline_7771_page_id$jscomp$inline_7768_wdiff$jscomp$inline_7774$$:
$hdiff$jscomp$inline_7775_srect$jscomp$inline_7772$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2235$zoom_type$$],null),$cljs$cst$5256$fit$$)},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$viewer$update_zoom_querystring$$)});
$APP.$app$main$data$viewer$zoom_to_fit$$=new $app$main$data$viewer$zoom_to_fit_74104$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
typeof $app$main$data$viewer$zoom_to_fill_74127$$==="undefined"&&($app$main$data$viewer$zoom_to_fill_74127$$=function($meta74128$jscomp$inline_7782$$){this.$meta74128$=$meta74128$jscomp$inline_7782$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$viewer$zoom_to_fill_74127$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5257$app_DOT_main_DOT_data_DOT_viewer_SLASH_zoom_to_fill$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74129$jscomp$inline_7783$$,$meta74128__$1$jscomp$inline_7784$$){return new $app$main$data$viewer$zoom_to_fill_74127$$($meta74128__$1$jscomp$inline_7784$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74128$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_7785_index__$1$jscomp$inline_7791_page_id$jscomp$inline_7788_wdiff$jscomp$inline_7794$$,$state$jscomp$inline_7786$$){var $params$jscomp$inline_7787$$=$APP.$app$main$router$get_params$$($state$jscomp$inline_7786$$);$_$jscomp$inline_7785_index__$1$jscomp$inline_7791_page_id$jscomp$inline_7788_wdiff$jscomp$inline_7794$$=function(){var $G__74135$jscomp$inline_7796$$=$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$inline_7787$$);
return $G__74135$jscomp$inline_7796$$==null?null:$APP.$app$common$uuid$parse$$($G__74135$jscomp$inline_7796$$)}();var $index$jscomp$inline_7789$$=function(){var $G__74136$jscomp$inline_7797$$=$APP.$app$main$router$get_query_param$$($params$jscomp$inline_7787$$,$APP.$cljs$cst$1795$index$$);return $G__74136$jscomp$inline_7797$$==null?null:$APP.$cljs$core$parse_long$$($G__74136$jscomp$inline_7797$$)}(),$frames$jscomp$inline_7790$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$inline_7786$$,
$APP.$cljs$cst$1592$viewer$$),$APP.$cljs$cst$2228$pages$$),$_$jscomp$inline_7785_index__$1$jscomp$inline_7791_page_id$jscomp$inline_7788_wdiff$jscomp$inline_7794$$),$APP.$cljs$cst$5241$frames$$);$_$jscomp$inline_7785_index__$1$jscomp$inline_7791_page_id$jscomp$inline_7788_wdiff$jscomp$inline_7794$$=function(){var $x__5113__auto__$jscomp$inline_7798$$=$APP.$cljs$core$truth_$$($index$jscomp$inline_7789$$)?$index$jscomp$inline_7789$$:0;var $y__5111__auto__$jscomp$inline_14523_y__5114__auto__$jscomp$inline_7799$$=
$APP.$cljs$core$count$$($frames$jscomp$inline_7790$$)-1;$y__5111__auto__$jscomp$inline_14523_y__5114__auto__$jscomp$inline_7799$$=0>$y__5111__auto__$jscomp$inline_14523_y__5114__auto__$jscomp$inline_7799$$?0:$y__5111__auto__$jscomp$inline_14523_y__5114__auto__$jscomp$inline_7799$$;return $x__5113__auto__$jscomp$inline_7798$$<$y__5111__auto__$jscomp$inline_14523_y__5114__auto__$jscomp$inline_7799$$?$x__5113__auto__$jscomp$inline_7798$$:$y__5111__auto__$jscomp$inline_14523_y__5114__auto__$jscomp$inline_7799$$}();
var $hdiff$jscomp$inline_7795_srect$jscomp$inline_7792$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($frames$jscomp$inline_7790$$,$_$jscomp$inline_7785_index__$1$jscomp$inline_7791_page_id$jscomp$inline_7788_wdiff$jscomp$inline_7794$$),$APP.$cljs$cst$1605$selrect$$),$osize$jscomp$inline_7793$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$inline_7786$$,$APP.$cljs$cst$2231$viewer_local$$),
$APP.$cljs$cst$5255$viewport_size$$);$_$jscomp$inline_7785_index__$1$jscomp$inline_7791_page_id$jscomp$inline_7788_wdiff$jscomp$inline_7794$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($osize$jscomp$inline_7793$$)/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($hdiff$jscomp$inline_7795_srect$jscomp$inline_7792$$);$hdiff$jscomp$inline_7795_srect$jscomp$inline_7792$$=$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($osize$jscomp$inline_7793$$)/$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($hdiff$jscomp$inline_7795_srect$jscomp$inline_7792$$);
return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$inline_7786$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2196$zoom$$],null),$_$jscomp$inline_7785_index__$1$jscomp$inline_7791_page_id$jscomp$inline_7788_wdiff$jscomp$inline_7794$$>$hdiff$jscomp$inline_7795_srect$jscomp$inline_7792$$?$_$jscomp$inline_7785_index__$1$jscomp$inline_7791_page_id$jscomp$inline_7788_wdiff$jscomp$inline_7794$$:
$hdiff$jscomp$inline_7795_srect$jscomp$inline_7792$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2235$zoom_type$$],null),$APP.$cljs$cst$1403$fill$$)},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$viewer$update_zoom_querystring$$)});
$APP.$app$main$data$viewer$zoom_to_fill$$=new $app$main$data$viewer$zoom_to_fill_74127$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $app$main$data$viewer$toggle_zoom_style$$;
typeof $app$main$data$viewer$toggle_zoom_style_74139$$==="undefined"&&($app$main$data$viewer$toggle_zoom_style_74139$$=function($meta74140$jscomp$inline_7802$$){this.$meta74140$=$meta74140$jscomp$inline_7802$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$viewer$toggle_zoom_style_74139$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5258$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_zoom_style$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74141$jscomp$inline_7803$$,$meta74140__$1$jscomp$inline_7804$$){return new $app$main$data$viewer$toggle_zoom_style_74139$$($meta74140__$1$jscomp$inline_7804$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74140$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$inline_7805_zoom_type$jscomp$inline_7807$$,$state$jscomp$inline_7806$$){$_$jscomp$inline_7805_zoom_type$jscomp$inline_7807$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$inline_7806$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2235$zoom_type$$],
null));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$inline_7805_zoom_type$jscomp$inline_7807$$,$cljs$cst$5256$fit$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$viewer$zoom_to_fill$$):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$viewer$zoom_to_fit$$)});$app$main$data$viewer$toggle_zoom_style$$=new $app$main$data$viewer$toggle_zoom_style_74139$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $app$main$data$viewer$toggle_fullscreen$$;
typeof $app$main$data$viewer$toggle_fullscreen_74162$$==="undefined"&&($app$main$data$viewer$toggle_fullscreen_74162$$=function($meta74163$jscomp$inline_7809$$){this.$meta74163$=$meta74163$jscomp$inline_7809$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$viewer$toggle_fullscreen_74162$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5259$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_fullscreen$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74164$jscomp$inline_7810$$,$meta74163__$1$jscomp$inline_7811$$){return new $app$main$data$viewer$toggle_fullscreen_74162$$($meta74163__$1$jscomp$inline_7811$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74163$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_7812$$,$state$jscomp$inline_7813$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$inline_7813$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$2234$fullscreen_QMARK_$$],null),$APP.$cljs$core$not$$)});
$app$main$data$viewer$toggle_fullscreen$$=new $app$main$data$viewer$toggle_fullscreen_74162$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
typeof $app$main$data$viewer$toggle_thumbnails_panel_74195$$==="undefined"&&($app$main$data$viewer$toggle_thumbnails_panel_74195$$=function($meta74196$jscomp$inline_7815$$){this.$meta74196$=$meta74196$jscomp$inline_7815$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$viewer$toggle_thumbnails_panel_74195$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5262$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_thumbnails_panel$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74197$jscomp$inline_7816$$,$meta74196__$1$jscomp$inline_7817$$){return new $app$main$data$viewer$toggle_thumbnails_panel_74195$$($meta74196__$1$jscomp$inline_7817$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74196$},
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_7818$$,$state$jscomp$inline_7819$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$inline_7819$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$5263$show_thumbnails$$],
null),$APP.$cljs$core$not$$)});$APP.$app$main$data$viewer$toggle_thumbnails_panel$$=new $app$main$data$viewer$toggle_thumbnails_panel_74195$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
typeof $app$main$data$viewer$close_thumbnails_panel_74204$$==="undefined"&&($app$main$data$viewer$close_thumbnails_panel_74204$$=function($meta74205$jscomp$inline_7821$$){this.$meta74205$=$meta74205$jscomp$inline_7821$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$viewer$close_thumbnails_panel_74204$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5264$app_DOT_main_DOT_data_DOT_viewer_SLASH_close_thumbnails_panel$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74206$jscomp$inline_7822$$,$meta74205__$1$jscomp$inline_7823$$){return new $app$main$data$viewer$close_thumbnails_panel_74204$$($meta74205__$1$jscomp$inline_7823$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74205$},
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_7824$$,$state$jscomp$inline_7825$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$inline_7825$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$APP.$cljs$cst$5263$show_thumbnails$$],null),!1)});
$APP.$app$main$data$viewer$close_thumbnails_panel$$=new $app$main$data$viewer$close_thumbnails_panel_74204$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
typeof $app$main$data$viewer$select_prev_frame_74211$$==="undefined"&&($app$main$data$viewer$select_prev_frame_74211$$=function($meta74212$jscomp$inline_7829$$){this.$meta74212$=$meta74212$jscomp$inline_7829$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$viewer$select_prev_frame_74211$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5265$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_prev_frame$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74213$jscomp$inline_7830$$,$meta74212__$1$jscomp$inline_7831$$){return new $app$main$data$viewer$select_prev_frame_74211$$($meta74212__$1$jscomp$inline_7831$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74212$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_7832$$,$state$jscomp$inline_7833$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$inline_7833$$,$APP.$cljs$cst$5266$viewer_animations$$),$APP.$cljs$cst$2232$viewer_overlays$$,$APP.$cljs$core$PersistentVector$EMPTY$$)},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$inline_7834_params$jscomp$inline_7836$$,$G__74218$jscomp$inline_13045_index$jscomp$inline_7837_state$jscomp$inline_7835$$){$_$jscomp$inline_7834_params$jscomp$inline_7836$$=$APP.$app$main$router$get_params$$($G__74218$jscomp$inline_13045_index$jscomp$inline_7837_state$jscomp$inline_7835$$);$G__74218$jscomp$inline_13045_index$jscomp$inline_7837_state$jscomp$inline_7835$$=
$APP.$app$main$router$get_query_param$$($_$jscomp$inline_7834_params$jscomp$inline_7836$$,$APP.$cljs$cst$1795$index$$);$G__74218$jscomp$inline_13045_index$jscomp$inline_7837_state$jscomp$inline_7835$$=$G__74218$jscomp$inline_13045_index$jscomp$inline_7837_state$jscomp$inline_7835$$==null?null:$APP.$cljs$core$parse_long$$($G__74218$jscomp$inline_13045_index$jscomp$inline_7837_state$jscomp$inline_7835$$);return $G__74218$jscomp$inline_13045_index$jscomp$inline_7837_state$jscomp$inline_7835$$>0?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$comments$close_thread$$(),
$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1592$viewer$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$inline_7834_params$jscomp$inline_7836$$,$APP.$cljs$cst$1795$index$$,$G__74218$jscomp$inline_13045_index$jscomp$inline_7837_state$jscomp$inline_7835$$-1))):null});$APP.$app$main$data$viewer$select_prev_frame$$=new $app$main$data$viewer$select_prev_frame_74211$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
typeof $app$main$data$viewer$select_next_frame_74219$$==="undefined"&&($app$main$data$viewer$select_next_frame_74219$$=function($meta74220$jscomp$inline_7840$$){this.$meta74220$=$meta74220$jscomp$inline_7840$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$viewer$select_next_frame_74219$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5267$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_next_frame$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74221$jscomp$inline_7841$$,$meta74220__$1$jscomp$inline_7842$$){return new $app$main$data$viewer$select_next_frame_74219$$($meta74220__$1$jscomp$inline_7842$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74220$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_7843$$,$state$jscomp$inline_7844$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$inline_7844$$,$APP.$cljs$cst$5266$viewer_animations$$),$APP.$cljs$cst$2232$viewer_overlays$$,$APP.$cljs$core$PersistentVector$EMPTY$$)},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$inline_7845_index$jscomp$inline_7848$$,$state$jscomp$inline_7846_total$jscomp$inline_7850$$){var $params$jscomp$inline_7847$$=$APP.$app$main$router$get_params$$($state$jscomp$inline_7846_total$jscomp$inline_7850$$);$_$jscomp$inline_7845_index$jscomp$inline_7848$$=function(){var $G__74222$jscomp$inline_7851$$=$APP.$app$main$router$get_query_param$$($params$jscomp$inline_7847$$,
$APP.$cljs$cst$1795$index$$);return $G__74222$jscomp$inline_7851$$==null?null:$APP.$cljs$core$parse_long$$($G__74222$jscomp$inline_7851$$)}();var $page_id$jscomp$inline_7849$$=function(){var $G__74223__$1$jscomp$inline_7852$$=$params$jscomp$inline_7847$$==null?null:$APP.$cljs$cst$2043$page_id$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$inline_7847$$);return $G__74223__$1$jscomp$inline_7852$$==null?null:$APP.$app$common$uuid$parse$$($G__74223__$1$jscomp$inline_7852$$)}();$state$jscomp$inline_7846_total$jscomp$inline_7850$$=
$APP.$cljs$core$count$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$inline_7846_total$jscomp$inline_7850$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$2228$pages$$,$page_id$jscomp$inline_7849$$,$APP.$cljs$cst$5241$frames$$],null)));return $_$jscomp$inline_7845_index$jscomp$inline_7848$$<$state$jscomp$inline_7846_total$jscomp$inline_7850$$-1?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$comments$close_thread$$(),
$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1592$viewer$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($params$jscomp$inline_7847$$,$APP.$cljs$cst$1795$index$$,$_$jscomp$inline_7845_index$jscomp$inline_7848$$+1))):null});$APP.$app$main$data$viewer$select_next_frame$$=new $app$main$data$viewer$select_next_frame_74219$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
typeof $app$main$data$viewer$select_first_frame_74224$$==="undefined"&&($app$main$data$viewer$select_first_frame_74224$$=function($meta74225$jscomp$inline_7854$$){this.$meta74225$=$meta74225$jscomp$inline_7854$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$viewer$select_first_frame_74224$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5268$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_first_frame$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74226$jscomp$inline_7855$$,$meta74225__$1$jscomp$inline_7856$$){return new $app$main$data$viewer$select_first_frame_74224$$($meta74225__$1$jscomp$inline_7856$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74225$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$inline_7857_params$jscomp$inline_7859$$,$state$jscomp$inline_7858$$){$_$jscomp$inline_7857_params$jscomp$inline_7859$$=$APP.$app$main$router$get_params$$($state$jscomp$inline_7858$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$comments$close_thread$$(),$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1592$viewer$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$inline_7857_params$jscomp$inline_7859$$,
$APP.$cljs$cst$1795$index$$,0)))});$APP.$app$main$data$viewer$select_first_frame$$=new $app$main$data$viewer$select_first_frame_74224$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $app$main$data$viewer$flash_done$$;
typeof $app$main$data$viewer$flash_done_74256$$==="undefined"&&($app$main$data$viewer$flash_done_74256$$=function($meta74257$jscomp$inline_7861$$){this.$meta74257$=$meta74257$jscomp$inline_7861$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$APP.$JSCompiler_prototypeAlias$$=$app$main$data$viewer$flash_done_74256$$.prototype,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5271$app_DOT_main_DOT_data_DOT_viewer_SLASH_flash_done$$},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74258$jscomp$inline_7862$$,$meta74257__$1$jscomp$inline_7863$$){return new $app$main$data$viewer$flash_done_74256$$($meta74257__$1$jscomp$inline_7863$$)},$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74257$},$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$inline_7864$$,$state$jscomp$inline_7865$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$inline_7865$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2231$viewer_local$$,$cljs$cst$5232$show_interactions$$],null),!1)});$app$main$data$viewer$flash_done$$=new $app$main$data$viewer$flash_done_74256$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$APP.$app$main$data$viewer$shortcuts$shortcuts$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5299$open_interactions$$,$cljs$cst$4799$open_comments$$,$cljs$cst$4817$open_inspect$$,$cljs$cst$5300$prev_frame$$,$APP.$cljs$cst$4841$decrease_zoom$$,$cljs$cst$5301$toggle_fullscreen$$,$APP.$cljs$cst$4843$select_all$$,$APP.$cljs$cst$4846$increase_zoom$$,$APP.$cljs$cst$4849$reset_zoom$$,$cljs$cst$5302$next_frame$$,$cljs$cst$5303$toggle_zoom_style$$,$cljs$cst$5304$open_workspace$$],[new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2946$tooltip$$,"G V",$APP.$cljs$cst$1812$command$$,"g v",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5305$navigation_viewer$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$go_to_section$$($APP.$cljs$cst$2051$interactions$$))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,
"G C",$APP.$cljs$cst$1812$command$$,"g c",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5305$navigation_viewer$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$go_to_section$$($APP.$cljs$cst$3436$comments$$))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"G I",$APP.$cljs$cst$1812$command$$,
"g i",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5305$navigation_viewer$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$go_to_section$$($APP.$cljs$cst$2672$inspect$$))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"←",$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["left","up","shift+enter","pageup","shift+space"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5306$general_viewer$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$select_prev_frame$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,
"-",$APP.$cljs$cst$1812$command$$,"-",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5307$zoom_viewer$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$decrease_zoom$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("F"),$APP.$cljs$cst$1812$command$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["shift+f","alt+enter"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5307$zoom_viewer$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$toggle_fullscreen$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,
$APP.$app$main$data$shortcuts$meta$$("A"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("a"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5306$general_viewer$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$select_all$$())}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,
"+",$APP.$cljs$cst$1812$command$$,"+",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5307$zoom_viewer$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$increase_zoom$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("0"),$APP.$cljs$cst$1812$command$$,
"shift+0",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5307$zoom_viewer$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$reset_zoom$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"→",$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["right","down","enter","pagedown","space"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5306$general_viewer$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$select_next_frame$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"F",$APP.$cljs$cst$1812$command$$,"f",$APP.$cljs$cst$4785$subsections$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5307$zoom_viewer$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$toggle_zoom_style$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"G W",$APP.$cljs$cst$1812$command$$,"g w",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$5305$navigation_viewer$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_workspace$$())}],null)]);var $app$main$data$workspace$path$shortcuts$esc_pressed_74132$$;
$APP.$app$main$data$workspace$path$shortcuts$shortcuts$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$4792$escape$$,$APP.$cljs$cst$4806$fit_all$$,$cljs$cst$4821$move_unit_down$$,$APP.$cljs$cst$5308$join_nodes$$,$APP.$cljs$cst$4822$redo$$,$APP.$cljs$cst$5309$make_corner$$,$APP.$cljs$cst$5310$draw_nodes$$,$cljs$cst$4827$move_fast_down$$,$APP.$cljs$cst$5311$delete_node$$,$APP.$cljs$cst$5312$snap_nodes$$,$APP.$cljs$cst$5313$merge_nodes$$,$cljs$cst$4836$move_unit_up$$,$APP.$cljs$cst$4841$decrease_zoom$$,
$APP.$cljs$cst$4846$increase_zoom$$,$APP.$cljs$cst$4849$reset_zoom$$,$APP.$cljs$cst$4850$undo$$,$cljs$cst$4852$move_fast_right$$,$APP.$cljs$cst$4856$zoom_selected$$,$cljs$cst$4857$move_unit_right$$,$cljs$cst$4858$move_fast_left$$,$APP.$cljs$cst$5314$separate_nodes$$,$APP.$cljs$cst$5315$make_curve$$,$APP.$cljs$cst$5316$add_node$$,$cljs$cst$4873$move_fast_up$$,$cljs$cst$4877$move_unit_left$$,$APP.$cljs$cst$5317$move_nodes$$],[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,
$APP.$app$main$data$shortcuts$esc$$(),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["escape","enter","v"],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$shortcuts$esc_pressed$$())}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("1"),$APP.$cljs$cst$1812$command$$,
"shift+1",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_fit_all$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,"↓",$APP.$cljs$cst$1812$command$$,"down",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$edition$move_selected$$($APP.$cljs$cst$1953$down$$,!1))}],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"J",$APP.$cljs$cst$1812$command$$,"j",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5318$path_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$APP.$app$common$types$path$join_nodes$$))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("Y"),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$shortcuts$c_mod$$("shift+z"),$APP.$app$main$data$shortcuts$c_mod$$("y")],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$undo$redo_path$$())}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"X",$APP.$cljs$cst$1812$command$$,"x",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5318$path_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$make_corner$$.$cljs$core$IFn$_invoke$arity$0$())}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2946$tooltip$$,"P",$APP.$cljs$cst$1812$command$$,"p",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5318$path_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$drawing$change_edit_mode$$($APP.$cljs$cst$4224$draw$$))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,
$APP.$app$main$data$shortcuts$shift$$("↓"),$APP.$cljs$cst$1812$command$$,"shift+down",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$edition$move_selected$$($APP.$cljs$cst$1953$down$$,!0))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$supr$$(),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["del","backspace"],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5318$path_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$APP.$app$common$types$path$remove_nodes$$))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,
[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("'"),$APP.$cljs$cst$1812$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$shortcuts$c_mod$$("'"),$APP.$app$main$data$shortcuts$c_mod$$("219")],null),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5318$path_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$toggle_snap$$())}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("J"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("j"),$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5318$path_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$(null,
$APP.$app$common$types$path$merge_nodes$$))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,"↑",$APP.$cljs$cst$1812$command$$,"up",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$edition$move_selected$$($APP.$cljs$cst$1954$up$$,!1))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,"-",$APP.$cljs$cst$1812$command$$,"-",$APP.$cljs$cst$516$fn$$,
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$decrease_zoom$$.$cljs$core$IFn$_invoke$arity$1$(null))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,"+",$APP.$cljs$cst$1812$command$$,"+",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$increase_zoom$$.$cljs$core$IFn$_invoke$arity$1$(null))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("0"),$APP.$cljs$cst$1812$command$$,"shift+0",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$reset_zoom$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("Z"),$APP.$cljs$cst$1812$command$$,$APP.$app$main$data$shortcuts$c_mod$$("z"),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$undo$undo_path$$())}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("→"),$APP.$cljs$cst$1812$command$$,"shift+right",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$edition$move_selected$$($APP.$cljs$cst$258$right$$,!0))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("2"),$APP.$cljs$cst$1812$command$$,
"shift+2",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_selected_shape$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,"←",$APP.$cljs$cst$1812$command$$,"left",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$edition$move_selected$$($APP.$cljs$cst$257$left$$,!1))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("←"),$APP.$cljs$cst$1812$command$$,"shift+left",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$edition$move_selected$$($APP.$cljs$cst$257$left$$,!0))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"K",$APP.$cljs$cst$1812$command$$,"k",$APP.$cljs$cst$4785$subsections$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5318$path_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$APP.$app$common$types$path$separate_nodes$$))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"C",$APP.$cljs$cst$1812$command$$,
"c",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5318$path_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$make_curve$$.$cljs$core$IFn$_invoke$arity$0$())}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("+"),$APP.$cljs$cst$1812$command$$,
"shift++",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5318$path_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$add_node$$())}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("↑"),$APP.$cljs$cst$1812$command$$,"shift+up",
$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$edition$move_selected$$($APP.$cljs$cst$1954$up$$,!0))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2946$tooltip$$,"→",$APP.$cljs$cst$1812$command$$,"right",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$edition$move_selected$$($APP.$cljs$cst$258$right$$,
!1))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2946$tooltip$$,"M",$APP.$cljs$cst$1812$command$$,"m",$APP.$cljs$cst$4785$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5318$path_editor$$],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$drawing$change_edit_mode$$($APP.$cljs$cst$1798$move$$))}],null)]);var $debug$repair_current_file_74796$$,$debug$set_shape_ref_74799$$;$APP.$app$common$logging$loggers$$.set("debug",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1160$debug$$));
var $debug$set_logging$$=function $debug$set_logging$$($var_args$jscomp$1405$$){switch(arguments.length){case 1:return $debug$set_logging$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $debug$set_logging$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$goog$exportSymbol$$("debug.set_logging",$debug$set_logging$$);
$debug$set_logging$$.$cljs$core$IFn$_invoke$arity$1$=function($level$jscomp$61$$){return $APP.$app$common$logging$loggers$$.set($cljs$cst$5319$app$$,$APP.$app$common$logging$level__GT_int$$($APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($level$jscomp$61$$)))};$debug$set_logging$$.$cljs$core$IFn$_invoke$arity$2$=function($ns$jscomp$34$$,$level$jscomp$62$$){return $APP.$app$common$logging$loggers$$.set($APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($ns$jscomp$34$$),$APP.$app$common$logging$level__GT_int$$($APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($level$jscomp$62$$)))};
$debug$set_logging$$.$cljs$lang$maxFixedArity$=2;
$APP.$goog$exportSymbol$$("debug.toggle_debug",function($JSCompiler_temp$jscomp$1391_name$jscomp$423_option$jscomp$14$$){$JSCompiler_temp$jscomp$1391_name$jscomp$423_option$jscomp$14$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1391_name$jscomp$423_option$jscomp$14$$);if($APP.$app$util$debug$enabled_QMARK_$$($JSCompiler_temp$jscomp$1391_name$jscomp$423_option$jscomp$14$$))$JSCompiler_temp$jscomp$1391_name$jscomp$423_option$jscomp$14$$=$APP.$debug$disable_BANG_$$($JSCompiler_temp$jscomp$1391_name$jscomp$423_option$jscomp$14$$);
else{$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$debug$state$$,$APP.$cljs$core$conj$$,$JSCompiler_temp$jscomp$1391_name$jscomp$423_option$jscomp$14$$);switch($JSCompiler_temp$jscomp$1391_name$jscomp$423_option$jscomp$14$$ instanceof $APP.$cljs$core$Keyword$$?$JSCompiler_temp$jscomp$1391_name$jscomp$423_option$jscomp$14$$.$fqn$:null){case "events":$app$main$store$_STAR_debug_events_STAR_$$=!0;break;case "events-times":$app$main$store$_STAR_debug_events_time_STAR_$$=
!0}$JSCompiler_temp$jscomp$1391_name$jscomp$423_option$jscomp$14$$=$APP.$app$main$reinit$$()}return $JSCompiler_temp$jscomp$1391_name$jscomp$423_option$jscomp$14$$});$APP.$goog$exportSymbol$$("debug.debug_all",function(){$APP.$cljs$core$reset_BANG_$$($APP.$app$util$debug$state$$,$APP.$app$util$debug$options$$);return $APP.$app$main$reinit$$()});
$APP.$goog$exportSymbol$$("debug.debug_none",function(){$APP.$cljs$core$reset_BANG_$$($APP.$app$util$debug$state$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$app$main$reinit$$()});$APP.$goog$exportSymbol$$("debug.tap",$debug$tap$$);
var $debug$logjs$$=function $debug$logjs$$($var_args$jscomp$1406$$){switch(arguments.length){case 1:return $debug$logjs$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $debug$logjs$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$goog$exportSymbol$$("debug.logjs",$debug$logjs$$);
$debug$logjs$$.$cljs$core$IFn$_invoke$arity$1$=function($str$jscomp$95$$){return $debug$tap$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($debug$logjs$$,$str$jscomp$95$$))};$debug$logjs$$.$cljs$core$IFn$_invoke$arity$2$=function($str$jscomp$96$$,$val$jscomp$192$$){console.log($str$jscomp$96$$,$APP.$app$common$json$__GT_js$$($val$jscomp$192$$));return $val$jscomp$192$$};$debug$logjs$$.$cljs$lang$maxFixedArity$=2;
$APP.$goog$exportSymbol$$("debug.wasmRenderStats",function(){var $code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$=$APP.$app$render_wasm$wasm$internal_module$$;if($APP.$cljs$core$fn_QMARK_$$($APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$)?$code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$._render_stats:
null)){var $cause74722_fn_74721$$=$code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$._render_stats;try{return $cause74722_fn_74721$$()}catch($e74723$$){$cause74722_fn_74721$$=$e74723$$;$code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$=$code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$._read_error_code;
$code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$)?$code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$():null;$code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$,$APP.$cljs$cst$2971$wasm_critical$$);
var $hint__53000__auto__$jscomp$89$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$89$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_render_stats",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$89$$,
$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$89_code_num__52998__auto__$jscomp$89_module__$1$jscomp$1_read_code_fn__52997__auto__$jscomp$89$$],null),$cause74722_fn_74721$$);}}else return console.warn("[debug] render-wasm module not ready or missing _render_stats")});
$APP.$goog$exportSymbol$$("debug.wasmAtlasConsole",function(){var $code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$=$APP.$app$render_wasm$wasm$internal_module$$;if($APP.$cljs$core$fn_QMARK_$$($APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$)?$code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$._debug_atlas_console:
null)){var $cause74730_fn_74729$$=$code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$._debug_atlas_console;try{return $cause74730_fn_74729$$()}catch($e74731$$){$cause74730_fn_74729$$=$e74731$$;$code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$=$code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$._read_error_code;
$code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$)?$code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$():null;$code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$,$APP.$cljs$cst$2971$wasm_critical$$);
var $hint__53000__auto__$jscomp$90$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$90$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_debug_atlas_console",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53000__auto__$jscomp$90$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$90_code_num__52998__auto__$jscomp$90_module__$1$jscomp$2_read_code_fn__52997__auto__$jscomp$90$$],null),$cause74730_fn_74729$$);}}else return console.warn("[debug] render-wasm module not ready or missing _debug_atlas_console")});
$APP.$goog$exportSymbol$$("debug.wasmAtlasBase64",function(){var $module__$1$jscomp$3$$=$APP.$app$render_wasm$wasm$internal_module$$;if($APP.$cljs$core$fn_QMARK_$$($APP.$cljs$core$truth_$$($module__$1$jscomp$3$$)?$module__$1$jscomp$3$$._debug_atlas_base64:null)){var $ptr$jscomp$11$$=function(){var $cause74734_fn_74733$$=$module__$1$jscomp$3$$._debug_atlas_base64;try{return $cause74734_fn_74733$$()}catch($e74735$$){$cause74734_fn_74733$$=$e74735$$;var $code__52999__auto__$jscomp$91_code_num__52998__auto__$jscomp$91_read_code_fn__52997__auto__$jscomp$91$$=
$module__$1$jscomp$3$$._read_error_code;$code__52999__auto__$jscomp$91_code_num__52998__auto__$jscomp$91_read_code_fn__52997__auto__$jscomp$91$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$91_code_num__52998__auto__$jscomp$91_read_code_fn__52997__auto__$jscomp$91$$)?$code__52999__auto__$jscomp$91_code_num__52998__auto__$jscomp$91_read_code_fn__52997__auto__$jscomp$91$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$91_code_num__52998__auto__$jscomp$91_read_code_fn__52997__auto__$jscomp$91$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$91_code_num__52998__auto__$jscomp$91_read_code_fn__52997__auto__$jscomp$91$$():null;$code__52999__auto__$jscomp$91_code_num__52998__auto__$jscomp$91_read_code_fn__52997__auto__$jscomp$91$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$91_code_num__52998__auto__$jscomp$91_read_code_fn__52997__auto__$jscomp$91$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$91$$=["WASM Error (",
$APP.$app$common$data$name$$($code__52999__auto__$jscomp$91_code_num__52998__auto__$jscomp$91_read_code_fn__52997__auto__$jscomp$91$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$91$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_debug_atlas_base64",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$91$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$91_code_num__52998__auto__$jscomp$91_read_code_fn__52997__auto__$jscomp$91$$],
null),$cause74734_fn_74733$$);}}();return function(){var $or__5025__auto__$jscomp$983$$=$debug$wasm_read_len_prefixed_utf8$$($ptr$jscomp$11$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$983$$)?$or__5025__auto__$jscomp$983$$:""}()}console.warn("[debug] render-wasm module not ready or missing _debug_atlas_base64");return""});
$APP.$goog$exportSymbol$$("debug.wasmSurfaceConsole",function($cause74742_id$jscomp$908$$){var $code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$=$APP.$app$render_wasm$wasm$internal_module$$;if($APP.$cljs$core$fn_QMARK_$$($APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$)?$code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$._debug_surface_console:
null)){var $fn_74741_hint__53000__auto__$jscomp$92$$=$code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$._debug_surface_console;try{return $fn_74741_hint__53000__auto__$jscomp$92$$($cause74742_id$jscomp$908$$)}catch($e74743$$){throw $cause74742_id$jscomp$908$$=$e74743$$,$code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$=$code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$._read_error_code,
$code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$)?$code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$():null,$code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$,$APP.$cljs$cst$2971$wasm_critical$$),
$fn_74741_hint__53000__auto__$jscomp$92$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_74741_hint__53000__auto__$jscomp$92$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_debug_surface_console",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$fn_74741_hint__53000__auto__$jscomp$92$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$92_code_num__52998__auto__$jscomp$92_module__$1$jscomp$4_read_code_fn__52997__auto__$jscomp$92$$],null),$cause74742_id$jscomp$908$$);}}else return console.warn("[debug] render-wasm module not ready or missing _debug_surface_console")});
$APP.$goog$exportSymbol$$("debug.wasmCacheConsole",function(){var $code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$=$APP.$app$render_wasm$wasm$internal_module$$;if($APP.$cljs$core$fn_QMARK_$$($APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$)?$code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$._debug_cache_console:
null)){var $cause74746_fn_74745$$=$code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$._debug_cache_console;try{return $cause74746_fn_74745$$()}catch($e74747$$){$cause74746_fn_74745$$=$e74747$$;$code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$=$code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$._read_error_code;
$code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$)?$code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$():null;$code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$,$APP.$cljs$cst$2971$wasm_critical$$);
var $hint__53000__auto__$jscomp$93$$=["WASM Error (",$APP.$app$common$data$name$$($code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$93$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_debug_cache_console",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53000__auto__$jscomp$93$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$93_code_num__52998__auto__$jscomp$93_module__$1$jscomp$5_read_code_fn__52997__auto__$jscomp$93$$],null),$cause74746_fn_74745$$);}}else return console.warn("[debug] render-wasm module not ready or missing _debug_cache_console")});
$APP.$goog$exportSymbol$$("debug.wasmCacheBase64",function(){var $module__$1$jscomp$6$$=$APP.$app$render_wasm$wasm$internal_module$$;if($APP.$cljs$core$fn_QMARK_$$($APP.$cljs$core$truth_$$($module__$1$jscomp$6$$)?$module__$1$jscomp$6$$._debug_cache_base64:null)){var $ptr$jscomp$12$$=function(){var $cause74749_fn_74748$$=$module__$1$jscomp$6$$._debug_cache_base64;try{return $cause74749_fn_74748$$()}catch($e74750$$){$cause74749_fn_74748$$=$e74750$$;var $code__52999__auto__$jscomp$94_code_num__52998__auto__$jscomp$94_read_code_fn__52997__auto__$jscomp$94$$=
$module__$1$jscomp$6$$._read_error_code;$code__52999__auto__$jscomp$94_code_num__52998__auto__$jscomp$94_read_code_fn__52997__auto__$jscomp$94$$=$APP.$cljs$core$truth_$$($code__52999__auto__$jscomp$94_code_num__52998__auto__$jscomp$94_read_code_fn__52997__auto__$jscomp$94$$)?$code__52999__auto__$jscomp$94_code_num__52998__auto__$jscomp$94_read_code_fn__52997__auto__$jscomp$94$$.$cljs$core$IFn$_invoke$arity$0$?$code__52999__auto__$jscomp$94_code_num__52998__auto__$jscomp$94_read_code_fn__52997__auto__$jscomp$94$$.$cljs$core$IFn$_invoke$arity$0$():
$code__52999__auto__$jscomp$94_code_num__52998__auto__$jscomp$94_read_code_fn__52997__auto__$jscomp$94$$():null;$code__52999__auto__$jscomp$94_code_num__52998__auto__$jscomp$94_read_code_fn__52997__auto__$jscomp$94$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__52999__auto__$jscomp$94_code_num__52998__auto__$jscomp$94_read_code_fn__52997__auto__$jscomp$94$$,$APP.$cljs$cst$2971$wasm_critical$$);var $hint__53000__auto__$jscomp$94$$=["WASM Error (",
$APP.$app$common$data$name$$($code__52999__auto__$jscomp$94_code_num__52998__auto__$jscomp$94_read_code_fn__52997__auto__$jscomp$94$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53000__auto__$jscomp$94$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_debug_cache_base64",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2972$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53000__auto__$jscomp$94$$,$APP.$cljs$cst$273$code$$,$code__52999__auto__$jscomp$94_code_num__52998__auto__$jscomp$94_read_code_fn__52997__auto__$jscomp$94$$],
null),$cause74749_fn_74748$$);}}();return function(){var $or__5025__auto__$jscomp$984$$=$debug$wasm_read_len_prefixed_utf8$$($ptr$jscomp$12$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$984$$)?$or__5025__auto__$jscomp$984$$:""}()}console.warn("[debug] render-wasm module not ready or missing _debug_cache_base64");return""});typeof window!=="undefined"&&(window.dbg=$APP.$app$common$json$__GT_js$$,window.pp=$cljs$pprint$pprint$$);
$APP.$goog$exportSymbol$$("debug.fps",function(){var $last$jscomp$4$$=$APP.$cljs$core$volatile_BANG_$$(performance.now()),$avg$jscomp$1$$=$APP.$cljs$core$volatile_BANG_$$(0),$node$jscomp$381$$=$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$(document.createElement("div"),"id","fps"),"style","\n  background: black;\n  bottom: 10px;\n  color: white;\n  height: 20px;\n  padding-left: 8px;\n  position: absolute;\n  right: 10px;\n  width: 40px;\n  z-index: 99999;\n  opacity: 0.5;\n");
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(document,"body").appendChild($node$jscomp$381$$);return function $debug$fps_$_do_thing$$(){return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){var $cur$jscomp$11$$=performance.now(),$ts$jscomp$12_val$jscomp$193$$=1E3/($cur$jscomp$11$$-$APP.$cljs$core$_deref$$($last$jscomp$4$$));$ts$jscomp$12_val$jscomp$193$$=$APP.$cljs$core$_deref$$($avg$jscomp$1$$)+($ts$jscomp$12_val$jscomp$193$$-$APP.$cljs$core$_deref$$($avg$jscomp$1$$))*
.1;$APP.$app$util$object$set_BANG_$$($node$jscomp$381$$,"innerText",$ts$jscomp$12_val$jscomp$193$$);$APP.$cljs$core$_vreset_BANG_$$($last$jscomp$4$$,$cur$jscomp$11$$);$APP.$cljs$core$_vreset_BANG_$$($avg$jscomp$1$$,$ts$jscomp$12_val$jscomp$193$$);return $debug$fps_$_do_thing$$()})}()});$APP.$goog$exportSymbol$$("debug.dump_state",function(){$debug$logjs$$.$cljs$core$IFn$_invoke$arity$2$("state",$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return null});
$APP.$goog$exportSymbol$$("debug.dump_data",function(){var $fdata$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$APP.$cljs$cst$142$data$$);$debug$logjs$$.$cljs$core$IFn$_invoke$arity$2$("file-data",$fdata$jscomp$21$$);return null});
$APP.$goog$exportSymbol$$("debug.dump_buffer",function(){$debug$logjs$$.$cljs$core$IFn$_invoke$arity$2$("last-events",$APP.$cljs$core$_deref$$($app$main$store$last_events$$));return null});
$APP.$goog$exportSymbol$$("debug.get_state",function($path_74816_str_path$$){$path_74816_str_path$$=$APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$read_string$$,$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($path_74816_str_path$$," ")));console.log($APP.$cljs$core$clj__GT_js$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$path_74816_str_path$$)));return null});
$APP.$goog$exportSymbol$$("debug.dump_objects",function(){var $objects$jscomp$inline_7873_state$jscomp$inline_7872$$=$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$);$objects$jscomp$inline_7873_state$jscomp$inline_7872$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$inline_7873_state$jscomp$inline_7872$$);$debug$logjs$$.$cljs$core$IFn$_invoke$arity$2$("objects",$objects$jscomp$inline_7873_state$jscomp$inline_7872$$);return null});
$APP.$goog$exportSymbol$$("debug.dump_object",$APP.$debug$dump_object$$);
$APP.$goog$exportSymbol$$("debug.dump_selected",function(){var $objects$jscomp$706$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$result$jscomp$335$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74758_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$706$$,$p1__74758_SHARP_$$)},$debug$get_selected$$());$debug$logjs$$.$cljs$core$IFn$_invoke$arity$2$("selected",
$result$jscomp$335$$);return null});
$APP.$goog$exportSymbol$$("debug.dump_selected_edn",function(){var $objects$jscomp$707$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$result$jscomp$336$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74763_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$707$$,$p1__74763_SHARP_$$)},$debug$get_selected$$());$app$common$pprint$pprint$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($result$jscomp$336$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$255$length$$,30,$APP.$cljs$cst$284$level$$,30],null)]));return null});$APP.$goog$exportSymbol$$("debug.preview_selected",function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$preview$open_preview_selected$$())});
$APP.$goog$exportSymbol$$("debug.parent",function(){var $objects$jscomp$708_temp__5825__auto___74817$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$parent_id$jscomp$104_selected_id$jscomp$5$$=$APP.$cljs$core$first$$($app$main$data$helpers$get_selected_ids$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)));$parent_id$jscomp$104_selected_id$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$708_temp__5825__auto___74817$$,
$parent_id$jscomp$104_selected_id$jscomp$5$$),$APP.$cljs$cst$1619$parent_id$$);$objects$jscomp$708_temp__5825__auto___74817$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$708_temp__5825__auto___74817$$,$parent_id$jscomp$104_selected_id$jscomp$5$$);$APP.$cljs$core$truth_$$($objects$jscomp$708_temp__5825__auto___74817$$)&&console.log([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$708_temp__5825__auto___74817$$)),
" - ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$708_temp__5825__auto___74817$$))].join(""));return null});
$APP.$goog$exportSymbol$$("debug.frame",function(){var $objects$jscomp$709_temp__5825__auto___74819$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$frame_id$jscomp$131_selected_id$jscomp$6$$=$APP.$cljs$core$first$$($app$main$data$helpers$get_selected_ids$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)));$frame_id$jscomp$131_selected_id$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$709_temp__5825__auto___74819$$,
$frame_id$jscomp$131_selected_id$jscomp$6$$),$APP.$cljs$cst$1607$frame_id$$);$objects$jscomp$709_temp__5825__auto___74819$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$709_temp__5825__auto___74819$$,$frame_id$jscomp$131_selected_id$jscomp$6$$);$APP.$cljs$core$truth_$$($objects$jscomp$709_temp__5825__auto___74819$$)&&console.log([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$709_temp__5825__auto___74819$$)),
" - ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$709_temp__5825__auto___74819$$))].join(""));return null});
$APP.$goog$exportSymbol$$("debug.select_by_object_id",function($object_id$jscomp$29_vec__74766$$){$object_id$jscomp$29_vec__74766$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($object_id$jscomp$29_vec__74766$$,/\//);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($object_id$jscomp$29_vec__74766$$,0,null);var $page_id$jscomp$406$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($object_id$jscomp$29_vec__74766$$,1,null),$shape_id$jscomp$145$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($object_id$jscomp$29_vec__74766$$,
2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($object_id$jscomp$29_vec__74766$$,3,null);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2043$page_id$$,$APP.$app$common$uuid$parse$$($page_id$jscomp$406$$)])));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$uuid$parse$$($shape_id$jscomp$145$$)))});
$APP.$goog$exportSymbol$$("debug.select_by_id",function($shape_id$jscomp$146$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$uuid$parse$$($shape_id$jscomp$146$$)))});
var $debug$dump_tree$$=function $debug$dump_tree$$($var_args$jscomp$1408$$){switch(arguments.length){case 0:return $debug$dump_tree$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $debug$dump_tree$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $debug$dump_tree$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $debug$dump_tree$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$APP.$goog$exportSymbol$$("debug.dump_tree",$debug$dump_tree$$);$debug$dump_tree$$.$cljs$core$IFn$_invoke$arity$0$=function(){var $state$jscomp$inline_7875$$=$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$);return $debug$dump_tree_SINGLEQUOTE_$cljs$0core$0IFn$0_invoke$0arity$04$$($state$jscomp$inline_7875$$,!1,!1,!1)};
$debug$dump_tree$$.$cljs$core$IFn$_invoke$arity$1$=function($show_ids$jscomp$8$$){return $debug$dump_tree_SINGLEQUOTE_$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$show_ids$jscomp$8$$,!1,!1)};
$debug$dump_tree$$.$cljs$core$IFn$_invoke$arity$2$=function($show_ids$jscomp$9$$,$show_touched$jscomp$3$$){return $debug$dump_tree_SINGLEQUOTE_$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$show_ids$jscomp$9$$,$show_touched$jscomp$3$$,!1)};
$debug$dump_tree$$.$cljs$core$IFn$_invoke$arity$3$=function($show_ids$jscomp$10$$,$show_touched$jscomp$4$$,$show_modified$jscomp$2$$){return $debug$dump_tree_SINGLEQUOTE_$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$show_ids$jscomp$10$$,$show_touched$jscomp$4$$,$show_modified$jscomp$2$$)};$debug$dump_tree$$.$cljs$lang$maxFixedArity$=3;
var $debug$dump_subtree_SINGLEQUOTE_$$=function $debug$dump_subtree_SINGLEQUOTE_$$($var_args$jscomp$1409$$){switch(arguments.length){case 2:return $debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);case 5:return $debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$5$(arguments[0],
arguments[1],arguments[2],arguments[3],arguments[4]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$goog$exportSymbol$$("debug.dump_subtree_SINGLEQUOTE_",$debug$dump_subtree_SINGLEQUOTE_$$);
$debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$2$=function($state$jscomp$1154$$,$shape_id$jscomp$147$$){return $debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1154$$,$shape_id$jscomp$147$$,!1,!1,!1)};
$debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$3$=function($state$jscomp$1155$$,$shape_id$jscomp$148$$,$show_ids$jscomp$11$$){return $debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1155$$,$shape_id$jscomp$148$$,$show_ids$jscomp$11$$,!1,!1)};
$debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$4$=function($state$jscomp$1156$$,$shape_id$jscomp$149$$,$show_ids$jscomp$12$$,$show_touched$jscomp$5$$){return $debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1156$$,$shape_id$jscomp$149$$,$show_ids$jscomp$12$$,$show_touched$jscomp$5$$,!1)};
$debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$5$=function($shape_id__$1$jscomp$6_state$jscomp$1157$$,$shape_id$jscomp$150$$,$show_ids$jscomp$13$$,$show_touched$jscomp$6$$,$show_modified$jscomp$3$$){var $page_id$jscomp$408$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape_id__$1$jscomp$6_state$jscomp$1157$$,$APP.$cljs$cst$1918$current_page_id$$),$file$jscomp$148$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($shape_id__$1$jscomp$6_state$jscomp$1157$$),
$libraries$jscomp$128$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape_id__$1$jscomp$6_state$jscomp$1157$$,$APP.$cljs$cst$1916$files$$);$shape_id__$1$jscomp$6_state$jscomp$1157$$=$shape_id$jscomp$150$$!=null?$APP.$app$common$uuid$parse$$($shape_id$jscomp$150$$):$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($shape_id__$1$jscomp$6_state$jscomp$1157$$));return $shape_id__$1$jscomp$6_state$jscomp$1157$$!=null?$app$common$types$file$dump_subtree$$($file$jscomp$148$$,
$page_id$jscomp$408$$,$shape_id__$1$jscomp$6_state$jscomp$1157$$,$libraries$jscomp$128$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$2593$show_ids$$,$show_ids$jscomp$13$$,$cljs$cst$2594$show_touched$$,$show_touched$jscomp$6$$,$cljs$cst$2595$show_modified$$,$show_modified$jscomp$3$$],null)):$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["no selected shape"]))};
$debug$dump_subtree_SINGLEQUOTE_$$.$cljs$lang$maxFixedArity$=5;
$APP.$debug$dump_subtree$$=function $debug$dump_subtree$$($var_args$jscomp$1410$$){switch(arguments.length){case 1:return $debug$dump_subtree$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $debug$dump_subtree$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $debug$dump_subtree$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $debug$dump_subtree$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$goog$exportSymbol$$("debug.dump_subtree",$APP.$debug$dump_subtree$$);$APP.$debug$dump_subtree$$.$cljs$core$IFn$_invoke$arity$1$=function($shape_id$jscomp$151$$){return $debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$shape_id$jscomp$151$$)};
$APP.$debug$dump_subtree$$.$cljs$core$IFn$_invoke$arity$2$=function($shape_id$jscomp$152$$,$show_ids$jscomp$14$$){return $debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$shape_id$jscomp$152$$,$show_ids$jscomp$14$$,!1,!1)};
$APP.$debug$dump_subtree$$.$cljs$core$IFn$_invoke$arity$3$=function($shape_id$jscomp$153$$,$show_ids$jscomp$15$$,$show_touched$jscomp$7$$){return $debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$shape_id$jscomp$153$$,$show_ids$jscomp$15$$,$show_touched$jscomp$7$$,!1)};
$APP.$debug$dump_subtree$$.$cljs$core$IFn$_invoke$arity$4$=function($shape_id$jscomp$154$$,$show_ids$jscomp$16$$,$show_touched$jscomp$8$$,$show_modified$jscomp$4$$){return $debug$dump_subtree_SINGLEQUOTE_$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$shape_id$jscomp$154$$,$show_ids$jscomp$16$$,$show_touched$jscomp$8$$,$show_modified$jscomp$4$$)};$APP.$debug$dump_subtree$$.$cljs$lang$maxFixedArity$=4;$APP.$goog$exportSymbol$$("debug.apply_changes",$debug$apply_changes$$);
$APP.$goog$exportSymbol$$("debug.fetch_apply",function($url$jscomp$94$$){return $APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($promesa$protocols$_mcat$$($APP.$promesa$impl$promise$resolved$$(null),function(){return $promesa$protocols$_mcat$$($promesa$impl$coerce$$(fetch($url$jscomp$94$$)),function($response$jscomp$14$$){return $promesa$impl$coerce$$($response$jscomp$14$$.text())})}),$debug$apply_changes$$)});
$APP.$goog$exportSymbol$$("debug.reset_viewport",function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$zoom$reset_zoom$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$viewport$update_viewport_position$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1510$x$$,$APP.$cljs$core$constantly$$(0),$APP.$cljs$cst$1511$y$$,$APP.$cljs$core$constantly$$(0)],null))]))});
$APP.$goog$exportSymbol$$("debug.hide_ui",function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$4825$hide_ui$$))});
$APP.$goog$exportSymbol$$("debug.shortcuts",function(){function $print_shortcuts$$($shortcuts$jscomp$7$$){return console.table($APP.$cljs$core$clj__GT_js$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($command$jscomp$20_map__74786_map__74786__$1_p__74782$$){var $key$jscomp$395$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($command$jscomp$20_map__74786_map__74786__$1_p__74782$$,
0,null);$command$jscomp$20_map__74786_map__74786__$1_p__74782$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($command$jscomp$20_map__74786_map__74786__$1_p__74782$$,1,null);$command$jscomp$20_map__74786_map__74786__$1_p__74782$$=$APP.$cljs$core$__destructure_map$$($command$jscomp$20_map__74786_map__74786__$1_p__74782$$);$command$jscomp$20_map__74786_map__74786__$1_p__74782$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($command$jscomp$20_map__74786_map__74786__$1_p__74782$$,$APP.$cljs$cst$1812$command$$);
return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$data$name$$($key$jscomp$395$$),$APP.$cljs$core$vector_QMARK_$$($command$jscomp$20_map__74786_map__74786__$1_p__74782$$)?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" | ",$command$jscomp$20_map__74786_map__74786__$1_p__74782$$):$command$jscomp$20_map__74786_map__74786__$1_p__74782$$],null)},$shortcuts$jscomp$7$$))))}console.log("%c Dashboard","font-weight: bold; font-size: 1.25rem;");
$print_shortcuts$$($APP.$app$main$data$dashboard$shortcuts$shortcuts$$);console.log("%c Workspace","font-weight: bold; font-size: 1.25rem;");$print_shortcuts$$($APP.$app$main$data$workspace$shortcuts$shortcuts$$);console.log("%c Path","font-weight: bold; font-size: 1.25rem;");$print_shortcuts$$($APP.$app$main$data$workspace$path$shortcuts$shortcuts$$);console.log("%c Viewer","font-weight: bold; font-size: 1.25rem;");$print_shortcuts$$($APP.$app$main$data$viewer$shortcuts$shortcuts$$);return null});
$APP.$goog$exportSymbol$$("debug.nodeStats",function(){return{number:$APP.$cljs$core$count$$($app$util$dom$seq_nodes$$($APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$(".viewport .render-shapes")))}});
$APP.$goog$exportSymbol$$("debug.dump_modifiers",function(){var $objects$jscomp$711$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$modifiers$jscomp$111$$=$APP.$cljs$cst$1922$workspace_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));console.log($debug$modif__GT_js$$($modifiers$jscomp$111$$,$objects$jscomp$711$$));return null});
$APP.$goog$exportSymbol$$("debug.set_workspace_read_only",function($read_only_QMARK_$jscomp$7$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$common$set_workspace_read_only$$($read_only_QMARK_$jscomp$7$$))});
var $debug$validate$$=function $debug$validate$$($var_args$jscomp$1411$$){switch(arguments.length){case 0:return $debug$validate$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $debug$validate$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$goog$exportSymbol$$("debug.validate",$debug$validate$$);$debug$validate$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $debug$validate$$.$cljs$core$IFn$_invoke$arity$1$(null)};
$debug$validate$$.$cljs$core$IFn$_invoke$arity$1$=function($_STAR_errors_STAR__orig_val__74165$jscomp$inline_14533_shape_id$jscomp$155$$){var $file$jscomp$149$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$libraries$jscomp$129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$1916$files$$);try{var $temp__5823__auto__$jscomp$inline_13047$$=
$_STAR_errors_STAR__orig_val__74165$jscomp$inline_14533_shape_id$jscomp$155$$==null?null:$APP.$app$common$uuid$parse$$($_STAR_errors_STAR__orig_val__74165$jscomp$inline_14533_shape_id$jscomp$155$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_13047$$)){var $page$jscomp$inline_13048$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$149$$,$APP.$cljs$cst$142$data$$),
$APP.$cljs$cst$1630$pages_index$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$1918$current_page_id$$));$_STAR_errors_STAR__orig_val__74165$jscomp$inline_14533_shape_id$jscomp$155$$=$app$common$files$validate$_STAR_errors_STAR_$$;var $_STAR_ref_shape_cache_STAR__orig_val__74166$jscomp$inline_14534$$=$app$common$files$validate$_STAR_ref_shape_cache_STAR_$$,$_STAR_children_sets_STAR__orig_val__74167$jscomp$inline_14535$$=
$app$common$files$validate$_STAR_children_sets_STAR_$$,$_STAR_errors_STAR__temp_val__74168$jscomp$inline_14536$$=$APP.$cljs$core$volatile_BANG_$$($APP.$cljs$core$PersistentVector$EMPTY$$),$_STAR_ref_shape_cache_STAR__temp_val__74169$jscomp$inline_14537$$=$APP.$cljs$core$volatile_BANG_$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$_STAR_children_sets_STAR__temp_val__74170$jscomp$inline_14538$$=$app$common$files$validate$build_children_sets$$($APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$inline_13048$$));
$app$common$files$validate$_STAR_errors_STAR_$$=$_STAR_errors_STAR__temp_val__74168$jscomp$inline_14536$$;$app$common$files$validate$_STAR_ref_shape_cache_STAR_$$=$_STAR_ref_shape_cache_STAR__temp_val__74169$jscomp$inline_14537$$;$app$common$files$validate$_STAR_children_sets_STAR_$$=$_STAR_children_sets_STAR__temp_val__74170$jscomp$inline_14538$$;try{$app$common$files$validate$check_shape$$($temp__5823__auto__$jscomp$inline_13047$$,$file$jscomp$149$$,$page$jscomp$inline_13048$$,$libraries$jscomp$129$$);
var $JSCompiler_inline_result$jscomp$10925$$=$APP.$cljs$core$_deref$$($app$common$files$validate$_STAR_errors_STAR_$$)}finally{$app$common$files$validate$_STAR_children_sets_STAR_$$=$_STAR_children_sets_STAR__orig_val__74167$jscomp$inline_14535$$,$app$common$files$validate$_STAR_ref_shape_cache_STAR_$$=$_STAR_ref_shape_cache_STAR__orig_val__74166$jscomp$inline_14534$$,$app$common$files$validate$_STAR_errors_STAR_$$=$_STAR_errors_STAR__orig_val__74165$jscomp$inline_14533_shape_id$jscomp$155$$}}else $JSCompiler_inline_result$jscomp$10925$$=
$app$common$files$validate$validate_file$$($file$jscomp$149$$,$libraries$jscomp$129$$);return $APP.$cljs$core$clj__GT_js$$($APP.$cljs$core$group_by$$($APP.$cljs$cst$273$code$$,$JSCompiler_inline_result$jscomp$10925$$))}catch($e74793$$){return $APP.$app$common$exceptions$print_throwable$$($e74793$$)}};$debug$validate$$.$cljs$lang$maxFixedArity$=1;
$APP.$goog$exportSymbol$$("debug.validate_schema",function(){try{var $file$jscomp$150$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($file$jscomp$150$$,$APP.$cljs$cst$142$data$$,$app$common$types$file$check_file_data$$)}catch($e74795$$){return $APP.$app$common$exceptions$print_throwable$$($e74795$$)}});
$APP.$goog$exportSymbol$$("debug.repair",function($reload_QMARK_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function(){typeof $debug$repair_current_file_74796$$==="undefined"&&($debug$repair_current_file_74796$$=function($reload_QMARK_$jscomp$1$$,$meta74797$$){this.$reload_QMARK_$=$reload_QMARK_$jscomp$1$$;this.$meta74797$=$meta74797$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$debug$repair_current_file_74796$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$debug$repair_current_file_74796$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5320$debug_SLASH_repair_current_file$$},$debug$repair_current_file_74796$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74798$$,$meta74797__$1$$){return new $debug$repair_current_file_74796$$(this.$reload_QMARK_$,$meta74797__$1$$)},$debug$repair_current_file_74796$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74797$},
$debug$repair_current_file_74796$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$debug$repair_current_file_74796$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2937_features__$1$jscomp$29_params$jscomp$396$$,$changes$jscomp$327_libs_state$jscomp$1158$$){var $self__$jscomp$7288$$=this;$_$jscomp$2937_features__$1$jscomp$29_params$jscomp$396$$=$APP.$cljs$cst$227$features$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$327_libs_state$jscomp$1158$$);
var $sid$jscomp$3$$=$APP.$cljs$cst$2332$session_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$327_libs_state$jscomp$1158$$),$file$jscomp$151$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($changes$jscomp$327_libs_state$jscomp$1158$$);$changes$jscomp$327_libs_state$jscomp$1158$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$327_libs_state$jscomp$1158$$,$APP.$cljs$cst$1916$files$$);var $errors$jscomp$29$$=$app$common$files$validate$validate_file$$($file$jscomp$151$$,
$changes$jscomp$327_libs_state$jscomp$1158$$);(function(){$APP.$app$common$logging$enabled_QMARK_$$("debug",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"repair current file"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$count$$($errors$jscomp$29$$)],null)],null)}),null,"debug",$APP.$cljs$cst$1160$debug$$,!1);return null})();$changes$jscomp$327_libs_state$jscomp$1158$$=$app$common$files$repair$repair_file$$($file$jscomp$151$$,$changes$jscomp$327_libs_state$jscomp$1158$$,$errors$jscomp$29$$);$_$jscomp$2937_features__$1$jscomp$29_params$jscomp$396$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$266$id$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$151$$),$APP.$cljs$cst$2270$revn$$,$APP.$cljs$cst$2270$revn$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$151$$),$APP.$cljs$cst$2577$vern$$,$APP.$cljs$cst$2577$vern$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$151$$),$APP.$cljs$cst$2332$session_id$$,$sid$jscomp$3$$,$APP.$cljs$cst$3131$changes$$,$changes$jscomp$327_libs_state$jscomp$1158$$,$APP.$cljs$cst$227$features$$,$_$jscomp$2937_features__$1$jscomp$29_params$jscomp$396$$,$cljs$cst$5321$skip_validate$$,
!0],null);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function(){return $APP.$cljs$core$truth_$$($self__$jscomp$7288$$.$reload_QMARK_$)?$APP.$app$util$dom$reload_current_window$$.$cljs$core$IFn$_invoke$arity$0$():null},function($cause$jscomp$96$$){return $APP.$app$common$exceptions$print_throwable$$($cause$jscomp$96$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2265$update_file$$,$_$jscomp$2937_features__$1$jscomp$29_params$jscomp$396$$))});
return new $debug$repair_current_file_74796$$($reload_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)}())});$APP.$goog$exportSymbol$$("debug.fix_orphan_shapes",function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$fix_orphan_shapes$$())});$APP.$goog$exportSymbol$$("debug.find_components_norefs",function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$find_components_norefs$$())});
$APP.$goog$exportSymbol$$("debug.set_shape_ref",function($id$jscomp$911$$,$shape_ref$jscomp$2$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($debug$set_shape_ref_STAR_$$($id$jscomp$911$$,$shape_ref$jscomp$2$$))});$APP.$goog$exportSymbol$$("debug.network_averages",function(){return console.log($APP.$cljs$core$clj__GT_js$$($APP.$cljs$core$_deref$$($app$util$http$network_averages$$)))});
$APP.$goog$exportSymbol$$("debug.dbg",function($o$jscomp$271$$){return $app$common$pprint$pprint$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($o$jscomp$271$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$284$level$$,100,$APP.$cljs$cst$255$length$$,100],null)]))});var $app$main$ui$workspace$sidebar$layer_item$sidebar_hover_queue$$,$app$main$ui$workspace$sidebar$layer_item$sidebar_hover_pending_QMARK_$$;$app$main$ui$workspace$sidebar$layer_item$sidebar_hover_queue$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$381$enter$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,$cljs$cst$382$leave$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$],null));
$app$main$ui$workspace$sidebar$layer_item$sidebar_hover_pending_QMARK_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);
$APP.$app$main$ui$workspace$sidebar$layer_item$layer_item_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function $app$main$ui$workspace$sidebar$layer_item$layer_item_STAR_$$($expanded_iref_is_highlighted$jscomp$2_props_74720$$){var $render_children$$=$expanded_iref_is_highlighted$jscomp$2_props_74720$$.renderChildren??!0,$is_filtered$jscomp$1$$=$expanded_iref_is_highlighted$jscomp$2_props_74720$$.isFiltered,$selected$jscomp$134$$=$expanded_iref_is_highlighted$jscomp$2_props_74720$$.selected,
$dprops_index$jscomp$399$$=$expanded_iref_is_highlighted$jscomp$2_props_74720$$.index,$objects$jscomp$712$$=$expanded_iref_is_highlighted$jscomp$2_props_74720$$.objects,$item$jscomp$110$$=$expanded_iref_is_highlighted$jscomp$2_props_74720$$.item,$enable_drag_is_component_child$$=$expanded_iref_is_highlighted$jscomp$2_props_74720$$.isComponentChild,$highlighted$jscomp$2$$=$expanded_iref_is_highlighted$jscomp$2_props_74720$$.highlighted,$style$jscomp$60$$=$expanded_iref_is_highlighted$jscomp$2_props_74720$$.style,
$rename_id$jscomp$2$$=$expanded_iref_is_highlighted$jscomp$2_props_74720$$.renameId,$parent_size$jscomp$2$$=$expanded_iref_is_highlighted$jscomp$2_props_74720$$.parentSize,$is_sortable$$=$expanded_iref_is_highlighted$jscomp$2_props_74720$$.isSortable,$depth$jscomp$17_disable_drag$$=$expanded_iref_is_highlighted$jscomp$2_props_74720$$.depth,$id$jscomp$913$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$110$$,$APP.$cljs$cst$266$id$$),$blocked_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$110$$,
$APP.$cljs$cst$1623$blocked$$),$hidden_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$110$$,$APP.$cljs$cst$1620$hidden$$),$shapes$jscomp$150$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$110$$,$APP.$cljs$cst$1614$shapes$$),$shapes__$1$jscomp$17$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$150$$),$APP.$rumext$v2$adapt$$($objects$jscomp$712$$)],function(){for(var $G__74752_G__74755_counter$jscomp$3$$=
0,$G__74753_G__74756_shapes__$1$jscomp$18$$=$APP.$cljs$core$seq$$($shapes$jscomp$150$$),$G__74754_G__74757_result$jscomp$337$$=$APP.$cljs$core$List$EMPTY$$;;){var $obj$jscomp$210_temp__5823__auto__$jscomp$208_temp__5823__auto____$1$jscomp$14$$=$APP.$cljs$core$first$$($G__74753_G__74756_shapes__$1$jscomp$18$$);if($APP.$cljs$core$truth_$$($obj$jscomp$210_temp__5823__auto__$jscomp$208_temp__5823__auto____$1$jscomp$14$$))$obj$jscomp$210_temp__5823__auto__$jscomp$208_temp__5823__auto____$1$jscomp$14$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$712$$,$obj$jscomp$210_temp__5823__auto__$jscomp$208_temp__5823__auto____$1$jscomp$14$$),$APP.$cljs$core$truth_$$($obj$jscomp$210_temp__5823__auto__$jscomp$208_temp__5823__auto____$1$jscomp$14$$)?($obj$jscomp$210_temp__5823__auto__$jscomp$208_temp__5823__auto____$1$jscomp$14$$.__$__counter=$G__74752_G__74755_counter$jscomp$3$$,$G__74752_G__74755_counter$jscomp$3$$+=1,$G__74753_G__74756_shapes__$1$jscomp$18$$=$APP.$cljs$core$rest$$($G__74753_G__74756_shapes__$1$jscomp$18$$),
$G__74754_G__74757_result$jscomp$337$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__74754_G__74757_result$jscomp$337$$,$obj$jscomp$210_temp__5823__auto__$jscomp$208_temp__5823__auto____$1$jscomp$14$$)):($G__74752_G__74755_counter$jscomp$3$$+=1,$G__74753_G__74756_shapes__$1$jscomp$18$$=$APP.$cljs$core$rest$$($G__74753_G__74756_shapes__$1$jscomp$18$$));else return $APP.$cljs$core$not_empty$$($APP.$cljs$core$vec$$($G__74754_G__74757_result$jscomp$337$$))}}),$drag_disabled_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$drag_disabled_QMARK__dref_vec__74725$$=$APP.$cljs$core$_deref$$($drag_disabled_STAR_$$),$scroll_middle_ref$$=(0,$APP.$rumext$v2$use_ref$$)(!0);$expanded_iref_is_highlighted$jscomp$2_props_74720$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$913$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__74718_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__74718_SHARP_$$,
$APP.$cljs$cst$3547$expanded$$),$id$jscomp$913$$)},$APP.$app$main$refs$workspace_local$$)});var $is_expanded$jscomp$1$$=$APP.$rumext$v2$deref$$($expanded_iref_is_highlighted$jscomp$2_props_74720$$),$is_selected$jscomp$2$$=$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$134$$,$id$jscomp$913$$);$expanded_iref_is_highlighted$jscomp$2_props_74720$$=$APP.$cljs$core$contains_QMARK_$$($highlighted$jscomp$2$$,$id$jscomp$913$$);var $container_QMARK__on_tab_press$jscomp$2$$=$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$110$$)||
$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$110$$),$is_read_only$jscomp$1$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$root_board_QMARK_$jscomp$1$$=$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$110$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$110$$)),
$name_node_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$depth__$1$$=$depth$jscomp$17_disable_drag$$+1,$is_component_tree$jscomp$1$$=$enable_drag_is_component_child$$||$APP.$app$common$types$component$instance_root_QMARK_$$($item$jscomp$110$$)||$APP.$app$common$types$component$instance_head_QMARK_$$($item$jscomp$110$$);$enable_drag_is_component_child$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($drag_disabled_STAR_$$,!1)});$depth$jscomp$17_disable_drag$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($drag_disabled_STAR_$$,!0)});var $children_count_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$children_count$$=$APP.$cljs$core$_deref$$($children_count_STAR_$$),$lazy_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$observer_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$toggle_collapse$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_expanded$jscomp$1$$),
$APP.$rumext$v2$adapt$$($id$jscomp$913$$),$APP.$rumext$v2$adapt$$($objects$jscomp$712$$)],function($event$jscomp$206$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$206$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_expanded$jscomp$1$$)?$event$jscomp$206$$.shiftKey:$is_expanded$jscomp$1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$collapse$collapse_all$$()):$APP.$cljs$core$not$$($is_expanded$jscomp$1$$)&&$event$jscomp$206$$.altKey?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$collapse$expand_subtree$$($id$jscomp$913$$,$objects$jscomp$712$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$collapse$toggle_collapse$$($id$jscomp$913$$))}),$toggle_blocking$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$913$$),$APP.$rumext$v2$adapt$$($blocked_QMARK_$jscomp$2$$)],function($event$jscomp$207$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$207$$);
return $APP.$cljs$core$truth_$$($blocked_QMARK_$jscomp$2$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_shape_flags$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$913$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1623$blocked$$,!1],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$update_shape_flags$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$913$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1623$blocked$$,!0],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$selection$deselect_shape$$($id$jscomp$913$$)]))}),$toggle_visibility$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($hidden_QMARK_$jscomp$2$$)],function($event$jscomp$208$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$208$$);
return $APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$2$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_shape_flags$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$913$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1620$hidden$$,!1],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_shape_flags$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$913$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1620$hidden$$,!0],null)))}),$select_shape$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$913$$),$APP.$rumext$v2$adapt$$($is_filtered$jscomp$1$$),$APP.$rumext$v2$adapt$$($objects$jscomp$712$$)],function($event$jscomp$209$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$209$$);$APP.$rumext$v2$set_ref_val_BANG_$$($scroll_middle_ref$$,
!1);if($event$jscomp$209$$.shiftKey)return $APP.$cljs$core$truth_$$($is_filtered$jscomp$1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shift_select_shapes$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$913$$,$objects$jscomp$712$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shift_select_shapes$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$913$$));if($APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$209$$))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$913$$,
!0));$APP.$cljs$core$count$$($selected$jscomp$134$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$913$$))}),$on_pointer_enter$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$913$$)],function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$layer_item$sidebar_hover_queue$$,function($q$jscomp$37$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($q$jscomp$37$$,
$APP.$cljs$cst$381$enter$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$id$jscomp$913$$),$cljs$cst$382$leave$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$disj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$id$jscomp$913$$)});return $app$main$ui$workspace$sidebar$layer_item$schedule_sidebar_hover_flush$$()}),$on_pointer_leave$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$913$$)],
function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$layer_item$sidebar_hover_queue$$,function($q$jscomp$38$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($q$jscomp$38$$,$APP.$cljs$cst$381$enter$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$disj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$id$jscomp$913$$),$cljs$cst$382$leave$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,
$APP.$cljs$core$PersistentHashSet$EMPTY$$),$id$jscomp$913$$)});return $app$main$ui$workspace$sidebar$layer_item$schedule_sidebar_hover_flush$$()}),$on_context_menu$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($item$jscomp$110$$),$APP.$rumext$v2$adapt$$($is_read_only$jscomp$1$$)],function($event$jscomp$210_pos$jscomp$129$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$210_pos$jscomp$129$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$210_pos$jscomp$129$$);
if($APP.$cljs$core$truth_$$($is_read_only$jscomp$1$$))return null;$event$jscomp$210_pos$jscomp$129$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$210_pos$jscomp$129$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$show_shape_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1676$position$$,$event$jscomp$210_pos$jscomp$129$$,$APP.$cljs$cst$1811$shape$$,$item$jscomp$110$$],null)))}),$on_drag$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$913$$),
$APP.$rumext$v2$adapt$$($selected$jscomp$134$$)],function($id__$1$jscomp$17_map__74737__$1_p__74736$$){$id__$1$jscomp$17_map__74737__$1_p__74736$$=$APP.$cljs$core$__destructure_map$$($id__$1$jscomp$17_map__74737__$1_p__74736$$);$id__$1$jscomp$17_map__74737__$1_p__74736$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id__$1$jscomp$17_map__74737__$1_p__74736$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$contains_QMARK_$$($selected$jscomp$134$$,$id__$1$jscomp$17_map__74737__$1_p__74736$$)?
null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$1$($id__$1$jscomp$17_map__74737__$1_p__74736$$))}),$on_drop$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$913$$),$APP.$rumext$v2$adapt$$($objects$jscomp$712$$),$APP.$rumext$v2$adapt$$($is_expanded$jscomp$1$$),$APP.$rumext$v2$adapt$$($selected$jscomp$134$$)],function($side$jscomp$3_to_index$jscomp$16$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected$jscomp$134$$),
1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($selected$jscomp$134$$),$id$jscomp$913$$))return null;var $files$jscomp$25_parent_id__$1$jscomp$9$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$files$$),$shape$jscomp$897$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$712$$,$id$jscomp$913$$),$parent$jscomp$295_parent_id$jscomp$105_vec__74738$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($side$jscomp$3_to_index$jscomp$16$$,$APP.$cljs$cst$1667$center$$)?
$id$jscomp$913$$:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_expanded$jscomp$1$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($side$jscomp$3_to_index$jscomp$16$$,$APP.$cljs$cst$2952$bot$$)&&$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$897$$)):$is_expanded$jscomp$1$$)?$id$jscomp$913$$:$APP.$app$common$files$helpers$get_parent_id$$($objects$jscomp$712$$,$id$jscomp$913$$);$parent$jscomp$295_parent_id$jscomp$105_vec__74738$$=
$app$common$types$container$find_valid_parent_and_frame_ids$cljs$0core$0IFn$0_invoke$0arity$05$$($parent$jscomp$295_parent_id$jscomp$105_vec__74738$$,$objects$jscomp$712$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74719_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$712$$,$p1__74719_SHARP_$$)},$selected$jscomp$134$$),!1,$files$jscomp$25_parent_id__$1$jscomp$9$$);$files$jscomp$25_parent_id__$1$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($parent$jscomp$295_parent_id$jscomp$105_vec__74738$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($parent$jscomp$295_parent_id$jscomp$105_vec__74738$$,1,null);$parent$jscomp$295_parent_id$jscomp$105_vec__74738$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$712$$,$files$jscomp$25_parent_id__$1$jscomp$9$$);var $current_index$jscomp$5$$=$APP.$app$common$data$index_of$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$295_parent_id$jscomp$105_vec__74738$$),$id$jscomp$913$$);$side$jscomp$3_to_index$jscomp$16$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($side$jscomp$3_to_index$jscomp$16$$,$APP.$cljs$cst$1667$center$$)?0:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_expanded$jscomp$1$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($side$jscomp$3_to_index$jscomp$16$$,$APP.$cljs$cst$2952$bot$$)&&$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$897$$)):$is_expanded$jscomp$1$$)?$APP.$cljs$core$count$$($APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$295_parent_id$jscomp$105_vec__74738$$)):
$current_index$jscomp$5$$<0?null:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($side$jscomp$3_to_index$jscomp$16$$,$APP.$cljs$cst$1562$top$$)?$current_index$jscomp$5$$+1:$current_index$jscomp$5$$;return $side$jscomp$3_to_index$jscomp$16$$!=null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$relocate_selected_shapes$$($files$jscomp$25_parent_id__$1$jscomp$9$$,$side$jscomp$3_to_index$jscomp$16$$)):null}),$on_hold$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$913$$),
$APP.$rumext$v2$adapt$$($is_expanded$jscomp$1$$)],function(){return $APP.$cljs$core$truth_$$($is_expanded$jscomp$1$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$collapse$toggle_collapse$$($id$jscomp$913$$))}),$zoom_to_selected$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$211$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$211$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$211$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_selected_shape$$)});
$drag_disabled_QMARK__dref_vec__74725$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2954$data_type$$,"penpot/layer",$APP.$cljs$cst$2955$on_drop$$,$on_drop$jscomp$1$$,$APP.$cljs$cst$2956$on_drag$$,$on_drag$jscomp$1$$,$cljs$cst$2957$on_hold$$,$on_hold$jscomp$1$$,$APP.$cljs$cst$2948$disabled$$,$drag_disabled_QMARK__dref_vec__74725$$,$APP.$cljs$cst$2958$detect_center_QMARK_$$,$container_QMARK__on_tab_press$jscomp$2$$,
$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$110$$),$APP.$cljs$cst$1795$index$$,$dprops_index$jscomp$399$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$110$$)],null),$APP.$cljs$cst$2959$draggable_QMARK_$$,$is_sortable$$&&$APP.$cljs$core$not$$($is_read_only$jscomp$1$$)&&$APP.$cljs$core$not$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$712$$,
$item$jscomp$110$$))]));$dprops_index$jscomp$399$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drag_disabled_QMARK__dref_vec__74725$$,0,null);$drag_disabled_QMARK__dref_vec__74725$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drag_disabled_QMARK__dref_vec__74725$$,1,null);$container_QMARK__on_tab_press$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$913$$),$APP.$rumext$v2$adapt$$($objects$jscomp$712$$)],function($event$jscomp$212_shift_QMARK_$jscomp$31_target_id$$){$event$jscomp$212_shift_QMARK_$jscomp$31_target_id$$=
$event$jscomp$212_shift_QMARK_$jscomp$31_target_id$$.shiftKey;var $parent$jscomp$296_shape$jscomp$898_siblings$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$712$$,$id$jscomp$913$$);$parent$jscomp$296_shape$jscomp$898_siblings$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$712$$,$APP.$cljs$cst$1619$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$296_shape$jscomp$898_siblings$$));$parent$jscomp$296_shape$jscomp$898_siblings$$=$APP.$cljs$cst$1614$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$296_shape$jscomp$898_siblings$$);
var $pos$jscomp$130$$=$APP.$app$common$data$index_of$$($parent$jscomp$296_shape$jscomp$898_siblings$$,$id$jscomp$913$$);return $pos$jscomp$130$$!=null?($event$jscomp$212_shift_QMARK_$jscomp$31_target_id$$=$event$jscomp$212_shift_QMARK_$jscomp$31_target_id$$?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$296_shape$jscomp$898_siblings$$,$pos$jscomp$130$$+1):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$296_shape$jscomp$898_siblings$$,$pos$jscomp$130$$-1),
$event$jscomp$212_shift_QMARK_$jscomp$31_target_id$$!=null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$start_rename_shape$$($event$jscomp$212_shift_QMARK_$jscomp$31_target_id$$)):null):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_selected$jscomp$2$$),$APP.$rumext$v2$adapt$$($selected$jscomp$134$$)],function(){var $single_QMARK_$jscomp$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected$jscomp$134$$),
1),$node$jscomp$382$$=$APP.$rumext$v2$ref_val$$($name_node_ref$$),$scroll_node$jscomp$2$$=$APP.$app$util$dom$get_parent_with_data$$($node$jscomp$382$$,"scroll-container"),$parent_node$jscomp$1_scroll_to_middle_QMARK_$$=$app$util$dom$get_parent_at$$($node$jscomp$382$$),$first_child_node$$=$parent_node$jscomp$1_scroll_to_middle_QMARK_$$!=null?$parent_node$jscomp$1_scroll_to_middle_QMARK_$$.firstChild:null;$parent_node$jscomp$1_scroll_to_middle_QMARK_$$=$APP.$rumext$v2$ref_val$$($scroll_middle_ref$$);
var $subid$$=$single_QMARK_$jscomp$5$$&&$is_selected$jscomp$2$$&&$parent_node$jscomp$1_scroll_to_middle_QMARK_$$?$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(100,function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($node$jscomp$382$$)?$scroll_node$jscomp$2$$:$node$jscomp$382$$)?($APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($first_child_node$$,{block:"center",behavior:($node$jscomp$382$$!=null&&$scroll_node$jscomp$2$$!=
null?$APP.$cljs$core$abs$$($scroll_node$jscomp$2$$.scrollTop-$node$jscomp$382$$.offsetTop):0)/$scroll_node$jscomp$2$$.clientHeight>1?"instant":"smooth",inline:"start"}),$APP.$rumext$v2$set_ref_val_BANG_$$($scroll_middle_ref$$,!0)):null}):null;return function(){return $subid$$!=null?$APP.$beicon$v2$core$_dispose$$($subid$$):null}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_expanded$jscomp$1$$),$APP.$rumext$v2$adapt$$($shapes__$1$jscomp$17$$),$APP.$rumext$v2$adapt$$($selected$jscomp$134$$)],
function(){var $total$jscomp$19$$=$APP.$cljs$core$count$$($shapes__$1$jscomp$17$$);if($is_expanded$jscomp$1$$){var $min_count_74760_selected_child_render_idx_74759$$=$total$jscomp$19$$>50?$APP.$cljs$core$some$$(function($idx$jscomp$102_sel_id$$){$idx$jscomp$102_sel_id$$=$shapes__$1$jscomp$17$$.indexOf($idx$jscomp$102_sel_id$$);return $idx$jscomp$102_sel_id$$>=0?$idx$jscomp$102_sel_id$$:null},$selected$jscomp$134$$):null;$min_count_74760_selected_child_render_idx_74759$$=$APP.$cljs$core$truth_$$($min_count_74760_selected_child_render_idx_74759$$)?
$min_count_74760_selected_child_render_idx_74759$$+50:50;var $current_count_74761$$=$APP.$cljs$core$_deref$$($children_count_STAR_$$);$APP.$cljs$core$reset_BANG_$$($children_count_STAR_$$,Math.min($total$jscomp$19$$,Math.max($current_count_74761$$,50,$min_count_74760_selected_child_render_idx_74759$$)))}else $APP.$cljs$core$reset_BANG_$$($children_count_STAR_$$,0);return function(){var $temp__5825__auto__$jscomp$296$$=$APP.$rumext$v2$ref_val$$($observer_ref$jscomp$1$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$296$$)?
($temp__5825__auto__$jscomp$296$$.disconnect(),$APP.$rumext$v2$set_ref_val_BANG_$$($temp__5825__auto__$jscomp$296$$,null)):null}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($children_count$$),$APP.$rumext$v2$adapt$$($is_expanded$jscomp$1$$),$APP.$rumext$v2$adapt$$($shapes__$1$jscomp$17$$)],function(){var $total$jscomp$20$$=$APP.$cljs$core$count$$($shapes__$1$jscomp$17$$),$observer$jscomp$6_scroll_node$jscomp$3$$=$APP.$app$util$dom$get_parent_with_data$$($APP.$rumext$v2$ref_val$$($name_node_ref$$),
"scroll-container"),$lazy_node$$=$APP.$rumext$v2$ref_val$$($lazy_ref$$),$temp__5825__auto___74764$$=$APP.$rumext$v2$ref_val$$($observer_ref$jscomp$1$$);$APP.$cljs$core$truth_$$($temp__5825__auto___74764$$)&&($temp__5825__auto___74764$$.disconnect(),$APP.$rumext$v2$set_ref_val_BANG_$$($observer_ref$jscomp$1$$,null));return $is_expanded$jscomp$1$$&&$children_count$$<$total$jscomp$20$$&&$observer$jscomp$6_scroll_node$jscomp$3$$&&$lazy_node$$?($observer$jscomp$6_scroll_node$jscomp$3$$=new IntersectionObserver(function($entries$jscomp$24$$){var $and__5023__auto__$jscomp$inline_7877$$=
$entries$jscomp$24$$.length>0;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_7877$$?$entries$jscomp$24$$[0].isIntersecting:$and__5023__auto__$jscomp$inline_7877$$)?$APP.$cljs$core$reset_BANG_$$($children_count_STAR_$$,Math.min($total$jscomp$20$$,$children_count$$+50)):null},{root:$observer$jscomp$6_scroll_node$jscomp$3$$}),$observer$jscomp$6_scroll_node$jscomp$3$$.observe($lazy_node$$),$APP.$rumext$v2$set_ref_val_BANG_$$($observer_ref$jscomp$1$$,$observer$jscomp$6_scroll_node$jscomp$3$$)):
null});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$workspace$sidebar$layer_item$layer_item_inner_STAR_$$,{onToggleBlocking:$toggle_blocking$$,onToggleVisibility:$toggle_visibility$$,onSelectShape:$select_shape$$,children:$render_children$$&&$shapes__$1$jscomp$17$$&&$is_expanded$jscomp$1$$?(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"children-"+($id$jscomp$913$$??""),className:"main_ui_workspace_sidebar_layer_item__element-children "+($is_selected$jscomp$2$$?"main_ui_workspace_sidebar_layer_item__parent-selected":
"")+" "+($root_board_QMARK_$jscomp$1$$?"main_ui_workspace_sidebar_layer_item__sticky-children":""),children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$61$$,$item__$1$jscomp$2$$){$out_arr__44124__auto__$jscomp$61$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layer_item$layer_item_STAR_$$,{selected:$selected$jscomp$134$$,index:$item__$1$jscomp$2$$.__$__counter,isSortable:$is_sortable$$,parentSize:$parent_size$jscomp$2$$,highlighted:$highlighted$jscomp$2$$,
isComponentChild:$is_component_tree$jscomp$1$$,objects:$objects$jscomp$712$$,item:$item__$1$jscomp$2$$,depth:$depth__$1$$,renameId:$rename_id$jscomp$2$$},""+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item__$1$jscomp$2$$,$APP.$cljs$cst$266$id$$)??"")));return $out_arr__44124__auto__$jscomp$61$$},[],$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($children_count$$,$shapes__$1$jscomp$17$$)),$children_count$$<$APP.$cljs$core$count$$($shapes__$1$jscomp$17$$)?(0,$APP.$rumext$v2$jsx$$)("div",
{ref:$lazy_ref$$,className:"main_ui_workspace_sidebar_layer_item__lazy-load-sentinel"}):null]}):null,isComponentTree:$is_component_tree$jscomp$1$$,parentSize:$parent_size$jscomp$2$$,isExpanded:$is_expanded$jscomp$1$$,onDisableDrag:$depth$jscomp$17_disable_drag$$,onEnableDrag:$enable_drag_is_component_child$$,onContextMenu:$on_context_menu$jscomp$1$$,isFiltered:$is_filtered$jscomp$1$$,style:$style$jscomp$60$$,dndOver:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops_index$jscomp$399$$),
$APP.$cljs$cst$1667$center$$),item:$item$jscomp$110$$,dndOverTop:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops_index$jscomp$399$$),$APP.$cljs$cst$1562$top$$),isHighlighted:$expanded_iref_is_highlighted$jscomp$2_props_74720$$,onZoomToSelected:$zoom_to_selected$$,nameRef:$name_node_ref$$,ref:$drag_disabled_QMARK__dref_vec__74725$$,depth:$depth__$1$$,onTabPress:$container_QMARK__on_tab_press$jscomp$2$$,isSelected:$is_selected$jscomp$2$$,
onPointerLeave:$on_pointer_leave$jscomp$2$$,isReadOnly:$is_read_only$jscomp$1$$,dndOverBot:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2960$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops_index$jscomp$399$$),$APP.$cljs$cst$2952$bot$$),onPointerEnter:$on_pointer_enter$jscomp$2$$,renameId:$rename_id$jscomp$2$$,onToggleCollapse:$toggle_collapse$$})});var $app$main$ui$inspect$common$colors$file_colors_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2212$colors$$],null)),$APP.$app$main$store$state$$);var $app$main$ui$inspect$attributes$fill$properties$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2058$background$$,$APP.$cljs$cst$3779$background_color$$,$cljs$cst$5327$background_image$$],null);var $app$main$ui$inspect$attributes$geometry$properties$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1562$top$$,$APP.$cljs$cst$1982$border_radius$$,$APP.$cljs$cst$1289$transform$$],null);var $app$main$ui$inspect$attributes$layout$properties$$=new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1932$display$$,$APP.$cljs$cst$4090$flex_direction$$,$APP.$cljs$cst$4091$flex_wrap$$,$cljs$cst$4059$grid_template_rows$$,$cljs$cst$4070$grid_template_columns$$,$APP.$cljs$cst$4086$align_items$$,$APP.$cljs$cst$4087$align_content$$,$APP.$cljs$cst$4088$justify_items$$,$APP.$cljs$cst$4089$justify_content$$,$APP.$cljs$cst$1681$row_gap$$,$APP.$cljs$cst$1682$column_gap$$,
$APP.$cljs$cst$4065$gap$$,$cljs$cst$4073$padding_inline_start$$,$cljs$cst$4050$padding_inline_end$$,$cljs$cst$4052$padding_block_start$$,$cljs$cst$4056$padding_block_end$$],null);var $app$main$ui$inspect$attributes$layout_element$properties$$=new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1929$margin$$,$APP.$cljs$cst$1986$max_height$$,$cljs$cst$1988$min_height$$,$APP.$cljs$cst$281$max_width$$,$APP.$cljs$cst$1984$min_width$$,$APP.$cljs$cst$1677$align_self$$,$APP.$cljs$cst$1678$justify_self$$,$cljs$cst$4082$flex_shrink$$,$APP.$cljs$cst$1660$flex$$,$cljs$cst$4085$grid_column$$,$cljs$cst$4083$grid_row$$],null);var $app$main$ui$inspect$attributes$stroke$properties$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4049$border_style$$,$cljs$cst$4061$border_width$$],null);var $app$main$ui$inspect$attributes$svg$svg_attr$$=function $app$main$ui$inspect$attributes$svg$svg_attr$$($map__74874_map__74874__$1_props_74873_value$jscomp$760$$){$map__74874_map__74874__$1_props_74873_value$jscomp$760$$=$APP.$rumext$v2$util$wrap_props$$($map__74874_map__74874__$1_props_74873_value$jscomp$760$$);$map__74874_map__74874__$1_props_74873_value$jscomp$760$$=$APP.$cljs$core$__destructure_map$$($map__74874_map__74874__$1_props_74873_value$jscomp$760$$);var $attr$jscomp$60$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74874_map__74874__$1_props_74873_value$jscomp$760$$,
$APP.$cljs$cst$2599$attr$$);$map__74874_map__74874__$1_props_74873_value$jscomp$760$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74874_map__74874__$1_props_74873_value$jscomp$760$$,$APP.$cljs$cst$260$value$$);if($APP.$cljs$core$map_QMARK_$$($map__74874_map__74874__$1_props_74873_value$jscomp$760$$))return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_svg__attributes-subtitle",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{children:$APP.$app$common$data$name$$($attr$jscomp$60$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$app$main$ui$inspect$attributes$svg$map__GT_css$$($map__74874_map__74874__$1_props_74873_value$jscomp$760$$)})]}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$74$$,$attr_value$jscomp$2_p__74875$$){var $attr_key$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value$jscomp$2_p__74875$$,
0,null);$attr_value$jscomp$2_p__74875$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value$jscomp$2_p__74875$$,1,null);$out_arr__44124__auto__$jscomp$74$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$attributes$svg$svg_attr$$,{attr:$attr_key$jscomp$2$$,value:$attr_value$jscomp$2_p__74875$$},$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("svg-key-",$APP.$app$common$data$name$$($attr_key$jscomp$2$$))));return $out_arr__44124__auto__$jscomp$74$$},[],$map__74874_map__74874__$1_props_74873_value$jscomp$760$$)]});
var $attr_name$jscomp$1$$=function(){var $$__$1$jscomp$23_$__$2$jscomp$6_$__$3$jscomp$3$$=$APP.$app$common$data$name$$($attr$jscomp$60$$);$$__$1$jscomp$23_$__$2$jscomp$6_$__$3$jscomp$3$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($$__$1$jscomp$23_$__$2$jscomp$6_$__$3$jscomp$3$$,"-");$$__$1$jscomp$23_$__$2$jscomp$6_$__$3$jscomp$3$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$$__$1$jscomp$23_$__$2$jscomp$6_$__$3$jscomp$3$$);return $APP.$cuerdas$core$capital$$($$__$1$jscomp$23_$__$2$jscomp$6_$__$3$jscomp$3$$)}();
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_attributes_svg__svg-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-label",children:$attr_name$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"attr-value",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$copy_button$copy_button_STAR_$$,{data:$APP.$app$common$data$name$$($map__74874_map__74874__$1_props_74873_value$jscomp$760$$),className:"main_ui_inspect_attributes_svg__copy-btn-title",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_inspect_attributes_svg__button-children",children:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__74874_map__74874__$1_props_74873_value$jscomp$760$$)})})})]})};var $app$main$ui$inspect$common$typography$file_typographies_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1592$viewer$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2215$typographies$$],null)),$APP.$app$main$store$state$$);var $app$main$ui$inspect$attributes$visibility$properties$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1867$blend_mode$$,$cljs$cst$2933$visibility$$],null);var $app$main$ui$inspect$exports$exports$$=function($component$jscomp$3$$){var $eq_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$;return $shadow$js$shim$module$0react$$.memo($component$jscomp$3$$,function($JSCompiler_inline_result$jscomp$555_p1__44938_SHARP_$$,$p2__44939_SHARP_$$){a:{var $idx$jscomp$inline_4701_old_keys$jscomp$inline_4698$$=Object.keys($p2__44939_SHARP_$$),$new_keys$jscomp$inline_4699$$=Object.keys($JSCompiler_inline_result$jscomp$555_p1__44938_SHARP_$$),$new_keys_len$jscomp$inline_4700$$=
$new_keys$jscomp$inline_4699$$.length;if($idx$jscomp$inline_4701_old_keys$jscomp$inline_4698$$.length===$new_keys_len$jscomp$inline_4700$$){for($idx$jscomp$inline_4701_old_keys$jscomp$inline_4698$$=0;;){if($idx$jscomp$inline_4701_old_keys$jscomp$inline_4698$$<$new_keys_len$jscomp$inline_4700$$){var $key$jscomp$inline_4702_old_val$jscomp$inline_4704$$=$new_keys$jscomp$inline_4699$$[$idx$jscomp$inline_4701_old_keys$jscomp$inline_4698$$],$new_val$jscomp$inline_4703$$=$JSCompiler_inline_result$jscomp$555_p1__44938_SHARP_$$[$key$jscomp$inline_4702_old_val$jscomp$inline_4704$$];
$key$jscomp$inline_4702_old_val$jscomp$inline_4704$$=$p2__44939_SHARP_$$[$key$jscomp$inline_4702_old_val$jscomp$inline_4704$$];if($eq_QMARK_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$eq_QMARK_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($new_val$jscomp$inline_4703$$,$key$jscomp$inline_4702_old_val$jscomp$inline_4704$$):$eq_QMARK_$jscomp$1$$($new_val$jscomp$inline_4703$$,$key$jscomp$inline_4702_old_val$jscomp$inline_4704$$)){$idx$jscomp$inline_4701_old_keys$jscomp$inline_4698$$+=1;continue}else{$JSCompiler_inline_result$jscomp$555_p1__44938_SHARP_$$=
!1;break a}}else{$JSCompiler_inline_result$jscomp$555_p1__44938_SHARP_$$=!0;break a}break}$JSCompiler_inline_result$jscomp$555_p1__44938_SHARP_$$=void 0}else $JSCompiler_inline_result$jscomp$555_p1__44938_SHARP_$$=!1}return $JSCompiler_inline_result$jscomp$555_p1__44938_SHARP_$$})}(function($in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$){function $on_download$$($event$jscomp$214_exports__$2$jscomp$1$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$214_exports__$2$jscomp$1$$);
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$type$jscomp$598$$))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$exports$assets$show_viewer_export_dialog$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1614$shapes$$,$shapes$jscomp$162$$,$APP.$cljs$cst$1870$exports$$,$APP.$cljs$core$_deref$$($exports__$1$jscomp$12$$),$APP.$cljs$cst$725$name$$,$filename$jscomp$11$$,$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$409$$,
$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$355$$,$APP.$cljs$cst$3237$share_id$$,$share_id$jscomp$22$$],null)));var $defaults$jscomp$4$$=function(){var $G__74917$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2043$page_id$$,$page_id$jscomp$409$$,$APP.$cljs$cst$1644$file_id$$,$file_id$jscomp$355$$,$APP.$cljs$cst$725$name$$,$filename$jscomp$11$$,$APP.$cljs$cst$2272$object_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$162$$))],
null);return $APP.$cljs$core$truth_$$($share_id$jscomp$22$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__74917$$,$APP.$cljs$cst$3237$share_id$$,$share_id$jscomp$22$$):$G__74917$$}();$event$jscomp$214_exports__$2$jscomp$1$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74903_SHARP_$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__74903_SHARP_$$,$defaults$jscomp$4$$]))},
$APP.$cljs$core$_deref$$($exports__$1$jscomp$12$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$exports$assets$request_export$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1870$exports$$,$event$jscomp$214_exports__$2$jscomp$1$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$exports$assets$export_shapes_event$$($event$jscomp$214_exports__$2$jscomp$1$$,"viewer")]))}$in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$=
$APP.$rumext$v2$util$wrap_props$$($in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$);$in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$=$APP.$cljs$core$__destructure_map$$($in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$);var $shapes$jscomp$162$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$,$APP.$cljs$cst$1614$shapes$$),$page_id$jscomp$409$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$,$APP.$cljs$cst$2043$page_id$$),$file_id$jscomp$355$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$,$APP.$cljs$cst$1644$file_id$$),$share_id$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$,$APP.$cljs$cst$3237$share_id$$),
$type$jscomp$598$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$,$APP.$cljs$cst$139$type$$),$exports__$1$jscomp$12$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentVector$EMPTY$$);$in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$export$0$$);var $add_export_page$jscomp$152_vstate$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$viewer_data$$);
$add_export_page$jscomp$152_vstate$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($add_export_page$jscomp$152_vstate$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2228$pages$$,$page_id$jscomp$409$$],null));var $filename$jscomp$11$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$162$$),1)?function(){var $sname$jscomp$2$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$162$$)),
$suffix$jscomp$29$$=$APP.$cljs$cst$1371$suffix$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$_deref$$($exports__$1$jscomp$12$$)));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($APP.$cljs$core$_deref$$($exports__$1$jscomp$12$$)))&&$suffix$jscomp$29$$!=null?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sname$jscomp$2$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($suffix$jscomp$29$$)].join(""):$sname$jscomp$2$$}():
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($add_export_page$jscomp$152_vstate$$),$scale_enabled_QMARK_$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($G__74915_export$$jscomp$9$$){$G__74915_export$$jscomp$9$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__74915_export$$jscomp$9$$);var $fexpr__74914$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1534$png$$,null,$APP.$cljs$cst$1536$webp$$,
null,$APP.$cljs$cst$1535$jpeg$$,null],null),null);return $fexpr__74914$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__74914$$.$cljs$core$IFn$_invoke$arity$1$($G__74915_export$$jscomp$9$$):$fexpr__74914$$($G__74915_export$$jscomp$9$$)});$in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$=$APP.$cljs$cst$4762$in_progress$$.$cljs$core$IFn$_invoke$arity$1$($in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$);$add_export_page$jscomp$152_vstate$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$162$$)],
function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($exports__$1$jscomp$12$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1534$png$$,$APP.$cljs$cst$1371$suffix$$,"",$APP.$cljs$cst$1902$scale$$,1],null))});var $delete_export$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$162$$)],function($index$jscomp$400$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($exports__$1$jscomp$12$$,
function($before$jscomp$6_exports__$2$jscomp$2$$){var $after$jscomp$4_vec__74927$$=$cljs$core$split_at$$($index$jscomp$400$$,$before$jscomp$6_exports__$2$jscomp$2$$);$before$jscomp$6_exports__$2$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($after$jscomp$4_vec__74927$$,0,null);$after$jscomp$4_vec__74927$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($after$jscomp$4_vec__74927$$,1,null);return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($before$jscomp$6_exports__$2$jscomp$2$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$rest$$($after$jscomp$4_vec__74927$$)]))})}),$on_scale_change$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$162$$)],function($index$jscomp$401$$,$event$jscomp$215_scale$jscomp$32$$){$event$jscomp$215_scale$jscomp$32$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$215_scale$jscomp$32$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($exports__$1$jscomp$12$$,
$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$401$$,$APP.$cljs$cst$1902$scale$$],null),$event$jscomp$215_scale$jscomp$32$$)}),$on_suffix_change$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$162$$)],function($event$jscomp$216_index$jscomp$402$$){var $value$jscomp$763$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$216_index$jscomp$402$$);$event$jscomp$216_index$jscomp$402$$=
$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$216_index$jscomp$402$$),"value"));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($exports__$1$jscomp$12$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$event$jscomp$216_index$jscomp$402$$,$APP.$cljs$cst$1371$suffix$$],null),$value$jscomp$763$$)}),
$on_type_change$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$162$$)],function($index$jscomp$403$$,$event$jscomp$217_type__$1$jscomp$13$$){$event$jscomp$217_type__$1$jscomp$13$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$217_type__$1$jscomp$13$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($exports__$1$jscomp$12$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$403$$,$APP.$cljs$cst$139$type$$],null),$event$jscomp$217_type__$1$jscomp$13$$)}),$manage_key_down$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$218$$){var $esc_QMARK_$jscomp$1$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$218$$);return $APP.$cljs$core$truth_$$($esc_QMARK_$jscomp$1$$)?$APP.$app$util$dom$blur_BANG_$$($APP.$app$util$dom$get_target$$($event$jscomp$218$$)):
null}),$size_options$$=new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"0.5",$APP.$cljs$cst$2287$label$$,"0.5x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"0.75",$APP.$cljs$cst$2287$label$$,"0.75x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"1",$APP.$cljs$cst$2287$label$$,"1x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,"1.5",$APP.$cljs$cst$2287$label$$,"1.5x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"2",$APP.$cljs$cst$2287$label$$,"2x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"4",$APP.$cljs$cst$2287$label$$,"4x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"6",$APP.$cljs$cst$2287$label$$,"6x"],null)],null),$format_options$$=new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"png",$APP.$cljs$cst$2287$label$$,"PNG"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"jpeg",$APP.$cljs$cst$2287$label$$,"JPG"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"webp",$APP.$cljs$cst$2287$label$$,"WEBP"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"svg",
$APP.$cljs$cst$2287$label$$,"SVG"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"pdf",$APP.$cljs$cst$2287$label$$,"PDF"],null)],null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$162$$)],function(){return $APP.$cljs$core$reset_BANG_$$($exports__$1$jscomp$12$$,$APP.$cljs$core$vec$$($APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$flatten$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74908_SHARP_$$){return $APP.$cljs$cst$1870$exports$$.$cljs$core$IFn$_invoke$arity$2$($p1__74908_SHARP_$$,
$APP.$cljs$core$PersistentVector$EMPTY$$)},$shapes$jscomp$162$$)))))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_exports__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_exports__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!1,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.export"),className:"main_ui_inspect_exports__title-spacing-export-viewer",
children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$add_export_page$jscomp$152_vstate$$,className:"main_ui_inspect_exports__add-export",children:$APP.$app$main$ui$icons$add$$})})}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$exports__$1$jscomp$12$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_exports__multiple-exports",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_exports__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_exports__actions",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$cljs$core$List$EMPTY$$,className:"main_ui_inspect_exports__action-btn",children:$APP.$app$main$ui$icons$remove_icon$$})})]}):$APP.$cljs$core$seq$$($APP.$cljs$core$_deref$$($exports__$1$jscomp$12$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_exports__element-set-content",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$82$$,
$export$$jscomp$10_p__74941$$){var $index$jscomp$404$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($export$$jscomp$10_p__74941$$,0,null);$export$$jscomp$10_p__74941$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($export$$jscomp$10_p__74941$$,1,null);$out_arr__44124__auto__$jscomp$82$$.push((0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_exports__element-group",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_inspect_exports__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_inspect_exports__format-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$app$common$data$name$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($export$$jscomp$10_p__74941$$)),options:$format_options$$,"dropdown-class":"main_ui_inspect_exports__dropdown-upwards","on-change":$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_type_change$$,$index$jscomp$404$$)})}),$APP.$cljs$core$truth_$$($scale_enabled_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?
$scale_enabled_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($export$$jscomp$10_p__74941$$):$scale_enabled_QMARK_$$($export$$jscomp$10_p__74941$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_exports__size-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1902$scale$$.$cljs$core$IFn$_invoke$arity$1$($export$$jscomp$10_p__74941$$)),options:$size_options$$,"dropdown-class":"main_ui_inspect_exports__dropdown-upwards",
"on-change":$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_scale_change$$,$index$jscomp$404$$)})}):null,(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"suffix-export-input",className:"main_ui_inspect_exports__suffix-input",children:(0,$APP.$rumext$v2$jsx$$)("input",{id:"suffix-export-input",type:"text",value:$APP.$cljs$cst$1371$suffix$$.$cljs$core$IFn$_invoke$arity$1$($export$$jscomp$10_p__74941$$),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.export.suffix"),
"data-value":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$404$$),onChange:$on_suffix_change$$,onKeyDown:$manage_key_down$jscomp$1$$,className:"main_ui_inspect_exports__type-input"})})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($delete_export$$,$index$jscomp$404$$),className:"main_ui_inspect_exports__action-btn",children:$APP.$app$main$ui$icons$remove_icon$$})]},$index$jscomp$404$$));return $out_arr__44124__auto__$jscomp$82$$},
[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$_deref$$($exports__$1$jscomp$12$$)))}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1616$multiple$$,$exports__$1$jscomp$12$$)||$APP.$cljs$core$seq$$($APP.$cljs$core$_deref$$($exports__$1$jscomp$12$$))?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$cljs$core$truth_$$($in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$)?null:$on_download$$,disabled:$in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$,
className:"main_ui_inspect_exports__export-btn "+($APP.$cljs$core$truth_$$($in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$)?"main_ui_inspect_exports__btn-disabled":""),children:$APP.$cljs$core$truth_$$($in_progress_QMARK_$jscomp$1_map__74911_map__74911__$1_props_74910_xstate$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.exporting-object"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.export-object",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($shapes$jscomp$162$$))]))}):
null]})});var $app$main$ui$inspect$attributes$type__GT_options$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1616$multiple$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1653$blur$$,$cljs$cst$5329$layout_element$$],null),$APP.$cljs$cst$1606$frame$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$2933$visibility$$,$cljs$cst$5330$geometry$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1615$layout$$,$cljs$cst$5329$layout_element$$],null),$APP.$cljs$cst$1608$group$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2933$visibility$$,$cljs$cst$5330$geometry$$,$APP.$cljs$cst$1538$svg$$,$cljs$cst$5329$layout_element$$],null),$APP.$cljs$cst$1611$rect$$,
new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2933$visibility$$,$cljs$cst$5330$geometry$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1538$svg$$,$cljs$cst$5329$layout_element$$],null),$APP.$cljs$cst$1417$circle$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2933$visibility$$,$cljs$cst$5330$geometry$$,
$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1538$svg$$,$cljs$cst$5329$layout_element$$],null),$APP.$cljs$cst$296$path$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2933$visibility$$,$cljs$cst$5330$geometry$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1538$svg$$,$cljs$cst$5329$layout_element$$],
null),$APP.$cljs$cst$1588$text$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2933$visibility$$,$cljs$cst$5330$geometry$$,$APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$2903$stroke$$,$cljs$cst$5329$layout_element$$],null),$APP.$cljs$cst$1994$variant$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1994$variant$$,$cljs$cst$5330$geometry$$,
$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1615$layout$$,$cljs$cst$5329$layout_element$$],null)],null);var $app$main$ui$components$code_block$highlight_fn$$=new $APP.$cljs$core$Delay$$(function(){return $APP.$shadow$esm$load_by_name$$($cljs$cst$5331$app_DOT_util_DOT_code_highlight_SLASH_highlight_BANG_$$)});var $app$main$data$workspace$tokens$format$format_tokenscript_symbol$$;
$APP.$app$main$data$workspace$tokens$format$category_dictionary$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1511$y$$,$APP.$cljs$cst$1765$line_height$$,$APP.$cljs$cst$1977$sizing$$,$APP.$cljs$cst$2133$inset$$,$APP.$cljs$cst$1298$color$$,$APP.$cljs$cst$1760$font_size$$,$APP.$cljs$cst$1652$spread$$,$APP.$cljs$cst$1761$font_weight$$,$APP.$cljs$cst$1979$text_case$$,$APP.$cljs$cst$1651$offset_y$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1655$stroke_width$$,$APP.$cljs$cst$1650$offset_x$$,
$APP.$cljs$cst$1768$text_decoration$$,$APP.$cljs$cst$1766$letter_spacing$$,$APP.$cljs$cst$1510$x$$,$APP.$cljs$cst$1982$border_radius$$,$APP.$cljs$cst$1758$font_family$$,$APP.$cljs$cst$1983$spacing$$],"Y;Line Height;Sizing;Inner Shadow;Color;Font Size;Spread;Font Weight;Text Case;Y;Blur;Stroke Width;X;Text Decoration;Letter Spacing;X;Border Radius;Font Family;Spacing".split(";"));
$app$main$data$workspace$tokens$format$format_tokenscript_symbol$$=function $app$main$data$workspace$tokens$format$format_tokenscript_symbol$$($tokenscript_symbol$$){return $tokenscript_symbol$$ instanceof $APP.$shadow$js$shim$module$0$0penpot$0tokenscript$$.NumberWithUnitSymbol&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($tokenscript_symbol$$.unit,"rem")?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($tokenscript_symbol$$.value*16),"px"].join(""):$APP.$app$main$data$tokenscript$color_symbol_QMARK_$$($tokenscript_symbol$$)?
$APP.$app$main$data$tokenscript$color_symbol_QMARK_$$($tokenscript_symbol$$)?$tokenscript_symbol$$.to("hex").toString():null:$tokenscript_symbol$$ instanceof $APP.$shadow$js$shim$module$0$0penpot$0tokenscript$$.TokenSymbol&&$tokenscript_symbol$$.value instanceof Map?$app$main$data$workspace$tokens$format$format_map_entries$$($cljs$core$es6_iterator_seq$$($tokenscript_symbol$$.value.entries())):$tokenscript_symbol$$ instanceof $APP.$shadow$js$shim$module$0$0penpot$0tokenscript$$.TokenSymbol&&$tokenscript_symbol$$.value instanceof
Array?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$tokens$format$format_tokenscript_symbol$$,$tokenscript_symbol$$.value)):$tokenscript_symbol$$.toString()};
$APP.$app$main$data$workspace$tokens$format$format_token_value$$=function $app$main$data$workspace$tokens$format$format_token_value$$($token_value$jscomp$5$$){return $token_value$jscomp$5$$ instanceof $APP.$shadow$js$shim$module$0$0penpot$0tokenscript$$.BaseSymbolType?$app$main$data$workspace$tokens$format$format_tokenscript_symbol$$($token_value$jscomp$5$$):$APP.$cljs$core$map_QMARK_$$($token_value$jscomp$5$$)?$app$main$data$workspace$tokens$format$format_map_entries$$($token_value$jscomp$5$$):$APP.$cljs$core$sequential_QMARK_$$($token_value$jscomp$5$$)&&
$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$map_QMARK_$$,$token_value$jscomp$5$$)?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$tokens$format$format_token_value$$,$token_value$jscomp$5$$)):$APP.$cljs$core$sequential_QMARK_$$($token_value$jscomp$5$$)?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$token_value$jscomp$5$$):$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($token_value$jscomp$5$$)};var $app$main$ui$inspect$styles$panels$geometry$properties$$=new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1522$height$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1562$top$$,$cljs$cst$4072$border_start_start_radius$$,$cljs$cst$4063$border_start_end_radius$$,$cljs$cst$4054$border_end_start_radius$$,$cljs$cst$4068$border_end_end_radius$$,$APP.$cljs$cst$1289$transform$$],null),$app$main$ui$inspect$styles$panels$geometry$shape_prop__GT_border_radius_prop$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$4072$border_start_start_radius$$,$APP.$cljs$cst$1646$r1$$,$cljs$cst$4063$border_start_end_radius$$,$APP.$cljs$cst$1647$r2$$,$cljs$cst$4054$border_end_start_radius$$,$APP.$cljs$cst$1648$r3$$,$cljs$cst$4068$border_end_end_radius$$,$APP.$cljs$cst$1649$r4$$],null);var $app$main$ui$inspect$styles$panels$layout$properties$$=new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1932$display$$,$APP.$cljs$cst$4090$flex_direction$$,$APP.$cljs$cst$4091$flex_wrap$$,$cljs$cst$4059$grid_template_rows$$,$cljs$cst$4070$grid_template_columns$$,$APP.$cljs$cst$4086$align_items$$,$APP.$cljs$cst$4087$align_content$$,$APP.$cljs$cst$4088$justify_items$$,$APP.$cljs$cst$4089$justify_content$$,$APP.$cljs$cst$1681$row_gap$$,
$APP.$cljs$cst$1682$column_gap$$,$APP.$cljs$cst$4065$gap$$,$cljs$cst$4073$padding_inline_start$$,$cljs$cst$4050$padding_inline_end$$,$cljs$cst$4052$padding_block_start$$,$cljs$cst$4056$padding_block_end$$],null),$app$main$ui$inspect$styles$panels$layout$shape_prop__GT_padding_prop$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$4052$padding_block_start$$,$APP.$cljs$cst$1093$p1$$,$cljs$cst$4050$padding_inline_end$$,$APP.$cljs$cst$1091$p2$$,$cljs$cst$4056$padding_block_end$$,$APP.$cljs$cst$1687$p3$$,
$cljs$cst$4073$padding_inline_start$$,$APP.$cljs$cst$1688$p4$$],null);var $app$main$ui$inspect$styles$panels$layout_element$shape_prop__GT_margin_prop$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$cljs$cst$4062$margin_block_start$$,$APP.$cljs$cst$1700$m1$$,$cljs$cst$4053$margin_inline_end$$,$APP.$cljs$cst$1701$m2$$,$cljs$cst$4058$margin_block_end$$,$APP.$cljs$cst$1702$m3$$,$cljs$cst$4069$margin_inline_start$$,$APP.$cljs$cst$1703$m4$$,$cljs$cst$4055$max_block_size$$,$APP.$cljs$cst$1704$layout_item_max_h$$,$cljs$cst$4064$min_block_size$$,$APP.$cljs$cst$1705$layout_item_min_h$$,
$cljs$cst$4066$max_inline_size$$,$APP.$cljs$cst$1706$layout_item_max_w$$,$cljs$cst$4057$min_inline_size$$,$APP.$cljs$cst$1707$layout_item_min_w$$],null);var $app$main$ui$inspect$styles$panels$stroke$properties$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4067$border_color$$,$cljs$cst$4049$border_style$$,$cljs$cst$4061$border_width$$],null),$app$main$ui$inspect$styles$panels$stroke$shape_prop__GT_stroke_prop$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$4049$border_style$$,$APP.$cljs$cst$1866$stroke_style$$,$cljs$cst$4061$border_width$$,$APP.$cljs$cst$1655$stroke_width$$,
$cljs$cst$4067$border_color$$,$APP.$cljs$cst$1739$stroke_color$$],null);var $app$main$ui$inspect$styles$panels$visibility$properties$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1734$opacity$$,$APP.$cljs$cst$1867$blend_mode$$],null);var $app$main$ui$inspect$styles$layout_element_properties$$=new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$4062$margin_block_start$$,$cljs$cst$4058$margin_block_end$$,$cljs$cst$4069$margin_inline_start$$,$cljs$cst$4053$margin_inline_end$$,$cljs$cst$4055$max_block_size$$,$cljs$cst$4064$min_block_size$$,$cljs$cst$4066$max_inline_size$$,$cljs$cst$4057$min_inline_size$$,$APP.$cljs$cst$1677$align_self$$,$APP.$cljs$cst$1678$justify_self$$,$cljs$cst$4082$flex_shrink$$,
$APP.$cljs$cst$1660$flex$$,$cljs$cst$4085$grid_column$$,$cljs$cst$4083$grid_row$$],null),$app$main$ui$inspect$styles$type__GT_panel_group$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1616$multiple$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1653$blur$$,$cljs$cst$5329$layout_element$$],null),$APP.$cljs$cst$1606$frame$$,
new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2933$visibility$$,$cljs$cst$5330$geometry$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1615$layout$$,$cljs$cst$5329$layout_element$$],null),$APP.$cljs$cst$1608$group$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2933$visibility$$,$cljs$cst$5330$geometry$$,
$APP.$cljs$cst$1538$svg$$,$cljs$cst$5329$layout_element$$],null),$APP.$cljs$cst$1611$rect$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2933$visibility$$,$cljs$cst$5330$geometry$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1538$svg$$,$cljs$cst$5329$layout_element$$],null),$APP.$cljs$cst$1417$circle$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$2933$visibility$$,$cljs$cst$5330$geometry$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1538$svg$$,$cljs$cst$5329$layout_element$$],null),$APP.$cljs$cst$296$path$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2933$visibility$$,$cljs$cst$5330$geometry$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1653$blur$$,
$APP.$cljs$cst$1538$svg$$,$cljs$cst$5329$layout_element$$],null),$APP.$cljs$cst$1588$text$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$2933$visibility$$,$cljs$cst$5330$geometry$$,$APP.$cljs$cst$1588$text$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$2903$stroke$$,$cljs$cst$5329$layout_element$$],null),$APP.$cljs$cst$1994$variant$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1994$variant$$,$cljs$cst$5330$geometry$$,$APP.$cljs$cst$1403$fill$$,$APP.$cljs$cst$2903$stroke$$,$APP.$cljs$cst$1654$shadow$$,$APP.$cljs$cst$1653$blur$$,$APP.$cljs$cst$1615$layout$$,$cljs$cst$5329$layout_element$$],null)],null);$APP.$app$main$ui$forms$context$$=(0,$APP.$rumext$v2$create_context$$)(null);var $$jscomp$scope$1820006746$0$PIXEL_STEP$$=10,$$jscomp$scope$1820006746$1$LINE_HEIGHT$$=40,$$jscomp$scope$1820006746$2$PAGE_HEIGHT$$=800;var $app$main$ui$dashboard$import$0$import_entry_STAR_$$;$APP.$app$common$logging$loggers$$.set("app.main.ui.dashboard.import",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1160$debug$$));
$APP.$app$main$ui$dashboard$import$0$import_form$$=(0,$APP.$rumext$v2$forward_ref$$)(function($on_file_selected$jscomp$1_props_75151$$,$external_ref$$){$on_file_selected$jscomp$1_props_75151$$=$APP.$app$main$ui$dashboard$import$0$use_import_file$$($on_file_selected$jscomp$1_props_75151$$["project-id"],$on_file_selected$jscomp$1_props_75151$$["on-finish-import"]);return(0,$APP.$rumext$v2$jsx$$)("form",{className:"import-file","aria-hidden":"true",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$file_uploader$file_uploader$$,
{accept:".penpot,.zip",multi:!0,ref:$external_ref$$,"on-selected":$on_file_selected$jscomp$1_props_75151$$})})});
$app$main$ui$dashboard$import$0$import_entry_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($entry$jscomp$65_props_75162$$){var $editing_QMARK_$jscomp$2_edition$jscomp$4$$=$entry$jscomp$65_props_75162$$.edition,$can_be_deleted$$=$entry$jscomp$65_props_75162$$.canBeDeleted,$on_change$jscomp$32$$=$entry$jscomp$65_props_75162$$.onChange,$entries$jscomp$33$$=$entry$jscomp$65_props_75162$$.entries,$on_delete$jscomp$7$$=$entry$jscomp$65_props_75162$$.onDelete,$importing_QMARK_$$=$entry$jscomp$65_props_75162$$["importing?"],
$on_edit$jscomp$2$$=$entry$jscomp$65_props_75162$$.onEdit;$entry$jscomp$65_props_75162$$=$entry$jscomp$65_props_75162$$.entry;var $status$jscomp$24$$=$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$65_props_75162$$),$editable_QMARK_$jscomp$7_format$jscomp$42$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$65_props_75162$$),$loading_QMARK_$$=function(){var $or__5025__auto__$jscomp$1018_or__5025__auto____$1$jscomp$113$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5353$analyze$$,
$status$jscomp$24$$);return $or__5025__auto__$jscomp$1018_or__5025__auto____$1$jscomp$113$$?$or__5025__auto__$jscomp$1018_or__5025__auto____$1$jscomp$113$$:($or__5025__auto__$jscomp$1018_or__5025__auto____$1$jscomp$113$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5350$import_progress$$,$status$jscomp$24$$))?$or__5025__auto__$jscomp$1018_or__5025__auto____$1$jscomp$113$$:$APP.$cljs$core$truth_$$($importing_QMARK_$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5348$import_ready$$,
$status$jscomp$24$$):$importing_QMARK_$$}(),$analyze_error_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5349$analyze_error$$,$status$jscomp$24$$),$import_success_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5351$import_success$$,$status$jscomp$24$$),$import_error_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5352$import_error$$,$status$jscomp$24$$),$import_ready_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5348$import_ready$$,
$status$jscomp$24$$),$is_shared_QMARK_$$=$APP.$cljs$cst$3977$shared$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$65_props_75162$$),$progress$jscomp$1$$=$APP.$cljs$cst$2244$progress$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$65_props_75162$$),$file_id$jscomp$362$$=$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$65_props_75162$$);$editing_QMARK_$jscomp$2_edition$jscomp$4$$=$file_id$jscomp$362$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($editing_QMARK_$jscomp$2_edition$jscomp$4$$,
$file_id$jscomp$362$$);$editable_QMARK_$jscomp$7_format$jscomp$42$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2482$legacy_zip$$,$editable_QMARK_$jscomp$7_format$jscomp$42$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($status$jscomp$24$$,$cljs$cst$5348$import_ready$$);var $on_edit_key_press$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$225$$){var $JSCompiler_inline_result$jscomp$1459_or__5025__auto__$jscomp$inline_7977$$=
(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$225$$);$JSCompiler_inline_result$jscomp$1459_or__5025__auto__$jscomp$inline_7977$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1459_or__5025__auto__$jscomp$inline_7977$$)?$JSCompiler_inline_result$jscomp$1459_or__5025__auto__$jscomp$inline_7977$$:(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$225$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1459_or__5025__auto__$jscomp$inline_7977$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$225$$),
$APP.$app$util$dom$stop_propagation$$($event$jscomp$225$$),$APP.$app$util$dom$blur_BANG_$$($APP.$app$util$dom$get_target$$($event$jscomp$225$$))):null}),$on_edit_blur$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$362$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$32$$)],function($event$jscomp$226$$){var $value$jscomp$781$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$226$$);return $on_change$jscomp$32$$.$cljs$core$IFn$_invoke$arity$3$?
$on_change$jscomp$32$$.$cljs$core$IFn$_invoke$arity$3$($file_id$jscomp$362$$,$value$jscomp$781$$,$event$jscomp$226$$):$on_change$jscomp$32$$($file_id$jscomp$362$$,$value$jscomp$781$$,$event$jscomp$226$$)}),$on_edit_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$362$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$32$$)],function($event$jscomp$227$$){return $APP.$cljs$core$fn_QMARK_$$($on_edit$jscomp$2$$)?$on_edit$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?
$on_edit$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$362$$,$event$jscomp$227$$):$on_edit$jscomp$2$$($file_id$jscomp$362$$,$event$jscomp$227$$):null}),$on_delete_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$362$$),$APP.$rumext$v2$adapt$$($on_delete$jscomp$7$$)],function($event$jscomp$228$$){return $APP.$cljs$core$fn_QMARK_$$($on_delete$jscomp$7$$)?$on_delete$jscomp$7$$.$cljs$core$IFn$_invoke$arity$2$?$on_delete$jscomp$7$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$362$$,
$event$jscomp$228$$):$on_delete$jscomp$7$$($file_id$jscomp$362$$,$event$jscomp$228$$):null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_import__file-entry "+($APP.$cljs$core$truth_$$($loading_QMARK_$$)?"main_ui_dashboard_import__loading":"")+" "+($import_success_QMARK_$$?"main_ui_dashboard_import__success":"")+" "+($import_error_QMARK_$$||$analyze_error_QMARK_$$?"main_ui_dashboard_import__error":"")+" "+($import_ready_QMARK_$$&&!$editing_QMARK_$jscomp$2_edition$jscomp$4$$?
"main_ui_dashboard_import__editable":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_import__file-name",children:[$APP.$cljs$core$truth_$$($loading_QMARK_$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{width:16,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading")}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_import__file-icon "+($import_ready_QMARK_$$?"main_ui_dashboard_import__icon-fill":""),
children:$import_ready_QMARK_$$?$APP.$app$main$ui$icons$logo_icon$$:$import_error_QMARK_$$?$APP.$app$main$ui$icons$close$$:$import_success_QMARK_$$?$APP.$app$main$ui$icons$tick$$:$analyze_error_QMARK_$$?$APP.$app$main$ui$icons$close$$:null}),$editing_QMARK_$jscomp$2_edition$jscomp$4$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_import__file-name-edit",children:(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",autoFocus:!0,defaultValue:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$65_props_75162$$),
onKeyPress:$on_edit_key_press$$,onBlur:$on_edit_blur$$})}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_import__file-name-label",children:[$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$65_props_75162$$),$is_shared_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_import__icon",children:$APP.$app$main$ui$icons$library$$}):null]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_import__edit-entry-buttons",children:[$editable_QMARK_$jscomp$7_format$jscomp$42$$?
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_edit_SINGLEQUOTE_$$,children:$APP.$app$main$ui$icons$curve$$}):null,$can_be_deleted$$?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_delete_SINGLEQUOTE_$$,children:$app$main$ui$icons$delete$0$$}):null]})]}),$analyze_error_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_import__error-message",children:$APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$65_props_75162$$)!=null?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$65_props_75162$$)):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.analyze-error")}):$import_error_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_import__error-message",children:$APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$65_props_75162$$)!=null?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$65_props_75162$$)):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.error")}):
$import_success_QMARK_$$||$progress$jscomp$1$$==null?null:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_import__progress-message",children:$app$main$ui$dashboard$import$0$parse_progress_message$$($progress$jscomp$1$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_import__linked-libraries",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$100$$,$library_id$jscomp$51$$){$out_arr__44124__auto__$jscomp$100$$.push(function(){var $library_data$jscomp$35$$=
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__75161_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($library_id$jscomp$51$$,$APP.$cljs$cst$1644$file_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__75161_SHARP_$$))},$entries$jscomp$33$$),$error_QMARK_$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1020$$=$APP.$cljs$cst$2541$deleted$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$35$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1020$$)?
$or__5025__auto__$jscomp$1020$$:$cljs$cst$5352$import_error$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$35$$)}();return $library_data$jscomp$35$$!=null?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_import__linked-library",children:[$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$35$$),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_import__linked-library-tag "+($APP.$cljs$core$truth_$$($error_QMARK_$jscomp$2$$)?"main_ui_dashboard_import__error":
""),children:$app$main$ui$icons$detach$$})]},""+($library_id$jscomp$51$$??"")):null}());return $out_arr__44124__auto__$jscomp$100$$},[],$APP.$cljs$cst$5244$libraries$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$65_props_75162$$))})]})});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$13$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$13$$,$APP.$cljs$cst$5346$import$$,$app$main$ui$dashboard$import$0$import_dialog$$)});$APP.$cljs$core$set$$($APP.$cljs$core$list$$("empty-placeholder-1-right","marketing-file","loader","empty-placeholder-2-right","empty-placeholder-2-left","brand-google","marketing-arrows","brand-openid","marketing-exchange","brand-gitlab","brand-github","nitrate-welcome","penpot-logo-icon","penpot-logo","empty-placeholder-1-left","marketing-layers","logo-error-screen","logo-subscription","logo-subscription-light"));var $app$main$ui$dashboard$comments$comments_icon_svg$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_comments__comments-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-comments"})});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$14$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$14$$,$APP.$cljs$cst$5360$nitrate_activation_success$$,$app$main$ui$nitrate$nitrate_activation_success_modal$nitrate_activation_success_modal_STAR_$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$15$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$15$$,$APP.$cljs$cst$5363$nitrate_code_activation$$,$app$main$ui$nitrate$nitrate_code_activation_modal$nitrate_code_activation_modal_STAR_$$)});var $app$main$ui$nitrate$nitrate_form$schema_COLON_nitrate_form$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"NitrateForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3201$subscription$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5364$yearly$$,null,$APP.$cljs$cst$5365$monthly$$,null],null),null)],null)],null)],null);
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44691__auto__$jscomp$16$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44691__auto__$jscomp$16$$,$APP.$cljs$cst$5068$nitrate_form$$,$app$main$ui$nitrate$nitrate_form$nitrate_form_modal_STAR_$$)});var $app$main$ui$dashboard$sidebar$clear_search_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_sidebar__clear-search-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-delete-text"})}),$app$main$ui$dashboard$sidebar$search_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_sidebar__search-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-search"})}),$app$main$ui$dashboard$sidebar$tick_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",
{width:500,className:"main_ui_dashboard_sidebar__tick-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-tick"})}),$app$main$ui$dashboard$sidebar$add_icon$$,$app$main$ui$dashboard$sidebar$arrow_icon$$,$app$main$ui$dashboard$sidebar$menu_icon$$,$app$main$ui$dashboard$sidebar$org_menu_icon$$,$app$main$ui$dashboard$sidebar$org_menu_icon_open$$,$app$main$ui$dashboard$sidebar$pin_icon$$,$app$main$ui$dashboard$sidebar$exit_icon$$,$app$main$ui$dashboard$sidebar$add_org_icon$$,$app$main$ui$dashboard$sidebar$arrow_up_right_icon$$;
(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_sidebar__logo-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-logo"})});$app$main$ui$dashboard$sidebar$add_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_sidebar__add-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-add"})});
$app$main$ui$dashboard$sidebar$arrow_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_sidebar__arrow-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-arrow"})});$app$main$ui$dashboard$sidebar$menu_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_sidebar__menu-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-menu"})});
$app$main$ui$dashboard$sidebar$org_menu_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_sidebar__org-menu-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-menu"})});$app$main$ui$dashboard$sidebar$org_menu_icon_open$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_sidebar__org-menu-icon-open",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-menu"})});
$app$main$ui$dashboard$sidebar$pin_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_sidebar__pin-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-pin"})});$app$main$ui$dashboard$sidebar$exit_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_sidebar__exit-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-exit"})});
$app$main$ui$dashboard$sidebar$add_org_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_sidebar__add-org-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-add"})});$app$main$ui$dashboard$sidebar$arrow_up_right_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_sidebar__arrow-up-right-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-arrow-up-right"})});
$APP.$app$main$ui$dashboard$sidebar$sidebar_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_75329$$){var $profile$jscomp$60$$=$props_75329$$.profile,$team$jscomp$54$$=$props_75329$$.team;return(0,$APP.$rumext$v2$jsxs$$)("nav",{"data-testid":"dashboard-sidebar",className:"main_ui_dashboard_sidebar__dashboard-sidebar",children:[(0,$APP.$rumext$v2$create_element$$)($app$main$ui$dashboard$sidebar$sidebar_content_STAR_$$,$props_75329$$),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$dashboard$sidebar$profile_section_STAR_$$,
{profile:$profile$jscomp$60$$,team:$team$jscomp$54$$})]})});var $app$main$ui$auth$login$show_sso_login_buttons_QMARK_$$=$APP.$cljs$core$some$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$contains_QMARK_$$,$APP.$app$config$flags$$),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$1169$login_with_google$$,$cljs$cst$1173$login_with_github$$,$cljs$cst$1170$login_with_gitlab$$,$cljs$cst$1175$login_with_oidc$$],null)),$app$main$ui$auth$login$schema_COLON_login_form$$=new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"LoginForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3183$email$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$945$error_SLASH_code$$,
"errors.invalid-email"],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$751$password$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$338$min$$,1],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1134$invitation_token$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$338$min$$,1],null)],null)],null)],null);var $app$main$ui$auth$recovery_request$schema_COLON_recovery_request_form$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"RecoverRequestForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3183$email$$,$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$],null)],null);var $app$main$ui$auth$register$schema_COLON_register_form$$;
$app$main$ui$auth$register$schema_COLON_register_form$$=new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"RegisterForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$751$password$$,$APP.$cljs$cst$973$app_DOT_common_DOT_schema_SLASH_password$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1360$fullname$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,250],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3183$email$$,$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5387$accept_terms_and_privacy$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1231$terms_and_privacy_checkbox$$)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$cljs$cst$421$boolean$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,!0],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5386$accept_newsletter_updates$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1136$token$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null)],null);
$APP.$app$main$ui$auth$register$schema_COLON_register_validate_form$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"RegisterValidateForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1360$fullname$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,250],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5387$accept_terms_and_privacy$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$450$optional$$,!$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1231$terms_and_privacy_checkbox$$)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$cljs$cst$421$boolean$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$711$_EQ_$$,!0],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$5386$accept_newsletter_updates$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$421$boolean$$],null)],null);var $app$main$ui$viewer$comments$comments_menu$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function(){var $show_sidebar_QMARK__state$jscomp$1164$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comments_local$$),$cmode$jscomp$1$$=$APP.$cljs$cst$320$mode$$.$cljs$core$IFn$_invoke$arity$1$($show_sidebar_QMARK__state$jscomp$1164$$),$cshow$jscomp$1$$=$cljs$cst$3471$show$$.$cljs$core$IFn$_invoke$arity$1$($show_sidebar_QMARK__state$jscomp$1164$$);$show_sidebar_QMARK__state$jscomp$1164$$=$APP.$cljs$cst$5013$show_sidebar_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($show_sidebar_QMARK__state$jscomp$1164$$,
!1);var $show_dropdown_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$toggle_dropdown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_dropdown_QMARK_$jscomp$1$$,$APP.$cljs$core$not$$)}),$hide_dropdown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_dropdown_QMARK_$jscomp$1$$,!1)}),$update_mode$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$267_mode$jscomp$42$$){$event$jscomp$267_mode$jscomp$42$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$267_mode$jscomp$42$$),"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$update_filters$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$320$mode$$,
$event$jscomp$267_mode$jscomp$42$$],null)))}),$update_show$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$268_mode$jscomp$43_mode__$1$jscomp$1$$){$event$jscomp$268_mode$jscomp$43_mode__$1$jscomp$1$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$268_mode$jscomp$43_mode__$1$jscomp$1$$),"value"));$event$jscomp$268_mode$jscomp$43_mode__$1$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$111$pending$$,
$event$jscomp$268_mode$jscomp$43_mode__$1$jscomp$1$$)?$APP.$cljs$cst$2124$all$$:$APP.$cljs$cst$111$pending$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$update_filters$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$3471$show$$,$event$jscomp$268_mode$jscomp$43_mode__$1$jscomp$1$$],null)))}),$update_options$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$269_mode$jscomp$44$$){$event$jscomp$269_mode$jscomp$44$$=
$APP.$cljs$core$parse_boolean$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$269_mode$jscomp$44$$),"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$comments$update_options$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5013$show_sidebar_QMARK_$$,$APP.$cljs$core$not$$($event$jscomp$269_mode$jscomp$44$$)],null)))});return(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"viewer-comments-dropdown",
onClick:$toggle_dropdown$$,className:"main_ui_viewer_comments__view-options",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_comments__dropdown-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.comments")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_comments__icon-dropdown",children:$APP.$app$main$ui$icons$arrow$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$_deref$$($show_dropdown_QMARK_$jscomp$1$$),
"on-close":$hide_dropdown$$,children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_viewer_comments__dropdown",children:[(0,$APP.$rumext$v2$jsxs$$)("li",{"data-value":"all",onClick:$update_mode$jscomp$1$$,className:"main_ui_viewer_comments__dropdown-element "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2124$all$$,$cmode$jscomp$1$$)||$cmode$jscomp$1$$==null?"main_ui_viewer_comments__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_comments__label",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.show-all-comments")}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2124$all$$,$cmode$jscomp$1$$)||$cmode$jscomp$1$$==null?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_comments__icon",children:$APP.$app$main$ui$icons$tick$$}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-value":"yours",onClick:$update_mode$jscomp$1$$,className:"main_ui_viewer_comments__dropdown-element "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3479$yours$$,
$cmode$jscomp$1$$)?"main_ui_viewer_comments__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_comments__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.show-your-comments")}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$3479$yours$$,$cmode$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_comments__icon",children:$APP.$app$main$ui$icons$tick$$}):null]}),(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_viewer_comments__separator"}),
(0,$APP.$rumext$v2$jsxs$$)("li",{"data-value":$APP.$app$common$data$name$$($cshow$jscomp$1$$),onClick:$update_show$jscomp$1$$,className:"main_ui_viewer_comments__dropdown-element "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$111$pending$$,$cshow$jscomp$1$$)?"main_ui_viewer_comments__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_comments__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.hide-resolved-comments")}),
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$111$pending$$,$cshow$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_comments__icon",children:$APP.$app$main$ui$icons$tick$$}):null]}),(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_viewer_comments__separator"}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-value":""+($show_sidebar_QMARK__state$jscomp$1164$$??""),onClick:$update_options$$,className:"main_ui_viewer_comments__dropdown-element "+($APP.$cljs$core$truth_$$($show_sidebar_QMARK__state$jscomp$1164$$)?
"main_ui_viewer_comments__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_comments__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.show-comments-list")}),$APP.$cljs$core$truth_$$($show_sidebar_QMARK__state$jscomp$1164$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_comments__icon",children:$APP.$app$main$ui$icons$tick$$}):null]})]})})]})});var $app$main$ui$viewer$shapes$base_frame_ctx$$=(0,$APP.$rumext$v2$create_context$$)(null),$app$main$ui$viewer$shapes$frame_offset_ctx$$=(0,$APP.$rumext$v2$create_context$$)(null),$app$main$ui$viewer$shapes$ref_COLON_viewer_show_interactions$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5232$show_interactions$$,$APP.$app$main$refs$viewer_local$$),$app$main$ui$viewer$shapes$find_relative_to_base_frame$$=function $app$main$ui$viewer$shapes$find_relative_to_base_frame$$($G__75331_shape$jscomp$968$$,
$objects$jscomp$744$$,$overlays_ids$$,$base_frame$jscomp$1$$){if($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__75331_shape$jscomp$968$$))return $G__75331_shape$jscomp$968$$;if($APP.$cljs$core$empty_QMARK_$$($overlays_ids$$)||$G__75331_shape$jscomp$968$$==null||$APP.$app$common$files$helpers$root_QMARK_$$($G__75331_shape$jscomp$968$$))return $base_frame$jscomp$1$$;$G__75331_shape$jscomp$968$$=$app$common$files$helpers$get_parent$$($objects$jscomp$744$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__75331_shape$jscomp$968$$));
return $app$main$ui$viewer$shapes$find_relative_to_base_frame$$.$cljs$core$IFn$_invoke$arity$4$?$app$main$ui$viewer$shapes$find_relative_to_base_frame$$.$cljs$core$IFn$_invoke$arity$4$($G__75331_shape$jscomp$968$$,$objects$jscomp$744$$,$overlays_ids$$,$base_frame$jscomp$1$$):$app$main$ui$viewer$shapes$find_relative_to_base_frame$$($G__75331_shape$jscomp$968$$,$objects$jscomp$744$$,$overlays_ids$$,$base_frame$jscomp$1$$)};var $app$main$ui$viewer$interactions$viewport_svg$$,$app$main$ui$viewer$interactions$flows_menu_STAR_$$;
$app$main$ui$viewer$interactions$viewport_svg$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_75600$$){function $calculate_objects$$($ids$jscomp$271$$){return $APP.$app$main$ui$viewer$interactions$prepare_objects$$($frame__$1$jscomp$5$$,$size$jscomp$140$$,$delta$jscomp$57$$,$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$frame__$1$jscomp$5$$],null),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects__$1$jscomp$37$$),$ids$jscomp$271$$))))}var $page$jscomp$156_wrapper_fixed$$=$props_75600$$.page,$frame$jscomp$61_objects$jscomp$761_wrapper_not_fixed$$=$props_75600$$.frame,$base$jscomp$40_base__$1$jscomp$1$$=$props_75600$$.base,$offset$jscomp$195$$=$props_75600$$.offset,$size$jscomp$140$$=$props_75600$$.size,$fixed_QMARK_$$=$props_75600$$["fixed?"],$delta$jscomp$57$$=function(){var $or__5025__auto__$jscomp$1047$$=
$props_75600$$.delta;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1047$$)?$or__5025__auto__$jscomp$1047$$:$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0)}(),$vbox$jscomp$34$$=$APP.$cljs$cst$1925$vbox$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$140$$),$frame__$1$jscomp$5$$=$APP.$cljs$core$truth_$$($fixed_QMARK_$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($frame$jscomp$61_objects$jscomp$761_wrapper_not_fixed$$,$APP.$cljs$cst$1645$fixed_scroll$$,
!0):$frame$jscomp$61_objects$jscomp$761_wrapper_not_fixed$$;$frame$jscomp$61_objects$jscomp$761_wrapper_not_fixed$$=$APP.$cljs$cst$1631$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$156_wrapper_fixed$$);var $objects__$1$jscomp$37$$=$APP.$cljs$core$truth_$$($fixed_QMARK_$$)?$APP.$cljs$core$assoc_in$$($frame$jscomp$61_objects$jscomp$761_wrapper_not_fixed$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$5$$),
$APP.$cljs$cst$1645$fixed_scroll$$],null),!0):$frame$jscomp$61_objects$jscomp$761_wrapper_not_fixed$$,$fixed_ids$jscomp$1$$=$app$main$ui$viewer$interactions$get_fixed_ids$$($objects__$1$jscomp$37$$),$not_fixed_ids$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75586_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__75586_SHARP_$$,$APP.$app$common$uuid$zero$$)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($fixed_ids$jscomp$1$$),
$APP.$cljs$core$keys$$($objects__$1$jscomp$37$$))),$objects_fixed$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fixed_ids$jscomp$1$$),$APP.$rumext$v2$adapt$$($page$jscomp$156_wrapper_fixed$$),$APP.$rumext$v2$adapt$$($frame__$1$jscomp$5$$),$APP.$rumext$v2$adapt$$($size$jscomp$140$$),$APP.$rumext$v2$adapt$$($delta$jscomp$57$$)],function(){return $calculate_objects$$($fixed_ids$jscomp$1$$)}),$objects_not_fixed$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($not_fixed_ids$$),
$APP.$rumext$v2$adapt$$($page$jscomp$156_wrapper_fixed$$),$APP.$rumext$v2$adapt$$($frame__$1$jscomp$5$$),$APP.$rumext$v2$adapt$$($size$jscomp$140$$),$APP.$rumext$v2$adapt$$($delta$jscomp$57$$)],function(){return $calculate_objects$$($not_fixed_ids$$)}),$all_objects$jscomp$8$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects_fixed$$),$APP.$rumext$v2$adapt$$($objects_not_fixed$$)],function(){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$objects_fixed$$,
$objects_not_fixed$$]))});$page$jscomp$156_wrapper_fixed$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page$jscomp$156_wrapper_fixed$$),$APP.$rumext$v2$adapt$$($frame__$1$jscomp$5$$),$APP.$rumext$v2$adapt$$($size$jscomp$140$$)],function(){return $app$main$ui$viewer$shapes$frame_container_factory$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($objects_fixed$$,$cljs$cst$5397$app_DOT_main_DOT_ui_DOT_viewer_DOT_interactions_SLASH_fixed$$,!0),$all_objects$jscomp$8$$)});
$frame$jscomp$61_objects$jscomp$761_wrapper_not_fixed$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects_not_fixed$$)],function(){return $app$main$ui$viewer$shapes$frame_container_factory$$($objects_not_fixed$$,$all_objects$jscomp$8$$)});var $frame__$2$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($all_objects$jscomp$8$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$5$$));$base$jscomp$40_base__$1$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($all_objects$jscomp$8$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($base$jscomp$40_base__$1$jscomp$1$$));var $fixed_frame_non_delay_interactions$$=$APP.$cljs$core$filterv$$(function($p1__75591_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1557$event_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__75591_SHARP_$$),$APP.$cljs$cst$1935$after_delay$$)},$APP.$cljs$cst$2051$interactions$$.$cljs$core$IFn$_invoke$arity$1$($frame__$2$jscomp$2$$));
$fixed_frame_non_delay_interactions$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($frame__$2$jscomp$2$$,$APP.$cljs$cst$1634$fills$$),$APP.$cljs$cst$2051$interactions$$,$fixed_frame_non_delay_interactions$$);return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($app$main$ui$viewer$shapes$base_frame_ctx$$),{value:$base$jscomp$40_base__$1$jscomp$1$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($app$main$ui$viewer$shapes$frame_offset_ctx$$),
{value:$offset$jscomp$195$$,children:$APP.$cljs$core$truth_$$($fixed_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("svg",{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$140$$),xmlns:"http://www.w3.org/2000/svg",height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$140$$),className:"main_ui_viewer_interactions__fixed",children:(0,$APP.$rumext$v2$jsx$$)($frame$jscomp$61_objects$jscomp$761_wrapper_not_fixed$$,{shape:$frame__$2$jscomp$2$$,"view-box":$vbox$jscomp$34$$}),
viewBox:$vbox$jscomp$34$$,xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",version:"1.1"}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("svg",{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$140$$),xmlns:"http://www.w3.org/2000/svg",height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$140$$),className:"main_ui_viewer_interactions__fixed",children:(0,$APP.$rumext$v2$jsx$$)($page$jscomp$156_wrapper_fixed$$,
{shape:$fixed_frame_non_delay_interactions$$,"view-box":$vbox$jscomp$34$$}),viewBox:$vbox$jscomp$34$$,style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$140$$),height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$140$$),zIndex:1},xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",version:"1.1"}),(0,$APP.$rumext$v2$jsx$$)("svg",{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$140$$),xmlns:"http://www.w3.org/2000/svg",
height:$APP.$cljs$cst$1522$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$140$$),className:"main_ui_viewer_interactions__not-fixed",children:(0,$APP.$rumext$v2$jsx$$)($frame$jscomp$61_objects$jscomp$761_wrapper_not_fixed$$,{shape:$frame__$2$jscomp$2$$,"view-box":$vbox$jscomp$34$$}),viewBox:$vbox$jscomp$34$$,xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",version:"1.1"})]})})})});
$APP.$app$main$ui$viewer$interactions$viewport$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($fixed_QMARK_$jscomp$1_props_75611$$){var $mode$jscomp$45$$=$APP.$app$main$ui$hooks$use_equal_memo$$($fixed_QMARK_$jscomp$1_props_75611$$["interactions-mode"]),$offset$jscomp$196$$=$APP.$app$main$ui$hooks$use_equal_memo$$($fixed_QMARK_$jscomp$1_props_75611$$["frame-offset"]),$size$jscomp$141$$=$APP.$app$main$ui$hooks$use_equal_memo$$($fixed_QMARK_$jscomp$1_props_75611$$.size),$delta$jscomp$58$$=
$fixed_QMARK_$jscomp$1_props_75611$$.delta,$page$jscomp$157$$=$fixed_QMARK_$jscomp$1_props_75611$$.page,$frame$jscomp$62$$=$fixed_QMARK_$jscomp$1_props_75611$$.frame,$base$jscomp$41$$=$fixed_QMARK_$jscomp$1_props_75611$$["base-frame"];$fixed_QMARK_$jscomp$1_props_75611$$=$fixed_QMARK_$jscomp$1_props_75611$$["fixed?"];$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mode$jscomp$45$$)],function(){var $key1$jscomp$2$$=$APP.$goog$events$listen$$($APP.$goog$global$$,
"wheel",function($event$jscomp$275_event__$1$jscomp$3$$){return $APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$275_event__$1$jscomp$3$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$275_event__$1$jscomp$3$$),$event$jscomp$275_event__$1$jscomp$3$$=$event$jscomp$275_event__$1$jscomp$3$$.getBrowserEvent(),$event$jscomp$275_event__$1$jscomp$3$$.deltaY+$event$jscomp$275_event__$1$jscomp$3$$.deltaX>0?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$decrease_zoom$$):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$increase_zoom$$)):null},{passive:!1}),$key2$jscomp$2$$=$APP.$goog$events$listen$$($APP.$goog$global$$,"keydown",function($event$jscomp$276$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$276$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$close_thread$$()):null}),$key3$$=$APP.$goog$events$listen$$($APP.$goog$global$$,
"click",function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$45$$,$APP.$cljs$cst$5234$show_on_click$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$flash_interactions$$()):null});return function(){$APP.$goog$events$unlistenByKey$$($key1$jscomp$2$$);$APP.$goog$events$unlistenByKey$$($key2$jscomp$2$$);return $APP.$goog$events$unlistenByKey$$($key3$$)}});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$interactions$viewport_svg$$,
{page:$page$jscomp$157$$,frame:$frame$jscomp$62$$,base:$base$jscomp$41$$,offset:$offset$jscomp$196$$,size:$size$jscomp$141$$,delta:$delta$jscomp$58$$,"fixed?":$fixed_QMARK_$jscomp$1_props_75611$$})});
$app$main$ui$viewer$interactions$flows_menu_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($frames$jscomp$25_page$jscomp$158_props_75617_toggle_dropdown$jscomp$1$$){var $frame$jscomp$63_index$jscomp$405_show_dropdown_QMARK_$jscomp$2$$=$frames$jscomp$25_page$jscomp$158_props_75617_toggle_dropdown$jscomp$1$$.index;$frames$jscomp$25_page$jscomp$158_props_75617_toggle_dropdown$jscomp$1$$=$frames$jscomp$25_page$jscomp$158_props_75617_toggle_dropdown$jscomp$1$$.page;var $flows$jscomp$7$$=
$APP.$cljs$core$not_empty$$($APP.$cljs$cst$2056$flows$$.$cljs$core$IFn$_invoke$arity$1$($frames$jscomp$25_page$jscomp$158_props_75617_toggle_dropdown$jscomp$1$$));$frames$jscomp$25_page$jscomp$158_props_75617_toggle_dropdown$jscomp$1$$=$APP.$cljs$cst$5241$frames$$.$cljs$core$IFn$_invoke$arity$1$($frames$jscomp$25_page$jscomp$158_props_75617_toggle_dropdown$jscomp$1$$);$frame$jscomp$63_index$jscomp$405_show_dropdown_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frames$jscomp$25_page$jscomp$158_props_75617_toggle_dropdown$jscomp$1$$,
$frame$jscomp$63_index$jscomp$405_show_dropdown_QMARK_$jscomp$2$$);var $frame_id$jscomp$136$$=$frame$jscomp$63_index$jscomp$405_show_dropdown_QMARK_$jscomp$2$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$63_index$jscomp$405_show_dropdown_QMARK_$jscomp$2$$,$APP.$cljs$cst$266$id$$),$current_flow_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$common$types$page$get_frame_flow$$($flows$jscomp$7$$,$frame_id$jscomp$136$$)}),
$current_flow$$=$APP.$cljs$core$_deref$$($current_flow_STAR_$$),$show_dropdown_QMARK__STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$frame$jscomp$63_index$jscomp$405_show_dropdown_QMARK_$jscomp$2$$=$APP.$cljs$core$_deref$$($show_dropdown_QMARK__STAR_$$);$frames$jscomp$25_page$jscomp$158_props_75617_toggle_dropdown$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_dropdown_QMARK__STAR_$$,
$APP.$cljs$core$not$$)});var $hide_dropdown$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_dropdown_QMARK__STAR_$$,!1)}),$select_flow$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$277_flow$jscomp$5$$){$event$jscomp$277_flow$jscomp$5$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$277_flow$jscomp$5$$),"value"));
$APP.$cljs$core$reset_BANG_$$($current_flow_STAR_$$,$event$jscomp$277_flow$jscomp$5$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2053$starting_frame$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$277_flow$jscomp$5$$)))});return $APP.$cljs$core$truth_$$($flows$jscomp$7$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$frames$jscomp$25_page$jscomp$158_props_75617_toggle_dropdown$jscomp$1$$,
className:"main_ui_viewer_interactions__view-options",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_interactions__icon",children:$APP.$app$main$ui$icons$play$$}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_interactions__dropdown-title",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($current_flow$$)}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_interactions__icon-dropdown",children:$APP.$app$main$ui$icons$arrow$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,
{show:$frame$jscomp$63_index$jscomp$405_show_dropdown_QMARK_$jscomp$2$$,"on-close":$hide_dropdown$jscomp$1$$,children:(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_viewer_interactions__dropdown",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$108$$,$flow$jscomp$6_p__75618$$){var $flow_id$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flow$jscomp$6_p__75618$$,0,null);$flow$jscomp$6_p__75618$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flow$jscomp$6_p__75618$$,
1,null);$out_arr__44124__auto__$jscomp$108$$.push((0,$APP.$rumext$v2$jsxs$$)("li",{"data-value":$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$flow$jscomp$6_p__75618$$])),onClick:$select_flow$$,className:"main_ui_viewer_interactions__dropdown-element "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($flow_id$jscomp$11$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current_flow$$))?"main_ui_viewer_interactions__selected":
""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_interactions__label",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$6_p__75618$$)}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($flow_id$jscomp$11$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current_flow$$))?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_interactions__icon",children:$APP.$app$main$ui$icons$tick$$}):null]},"flow-"+($flow_id$jscomp$11$$??
"")));return $out_arr__44124__auto__$jscomp$108$$},[],$flows$jscomp$7$$)})})]}):null});var $app$main$ui$viewer$header$zoom_widget$$,$app$main$ui$viewer$header$penpot_logo_icon$$;$APP.$app$main$ui$viewer$header$fullscreen_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$1165$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1165$$,$APP.$cljs$cst$2231$viewer_local$$),$APP.$cljs$cst$2234$fullscreen_QMARK_$$)},$APP.$app$main$store$state$$);
$app$main$ui$viewer$header$zoom_widget$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($open_QMARK_$jscomp$8_props_75641$$){var $on_fullscreen$$=$open_QMARK_$jscomp$8_props_75641$$["on-fullscreen"],$on_zoom_reset$$=$open_QMARK_$jscomp$8_props_75641$$["on-zoom-reset"],$zoom$jscomp$62$$=$open_QMARK_$jscomp$8_props_75641$$.zoom,$on_zoom_fit$$=$open_QMARK_$jscomp$8_props_75641$$["on-zoom-fit"],$on_zoom_fill$$=$open_QMARK_$jscomp$8_props_75641$$["on-zoom-fill"],$on_decrease$$=$open_QMARK_$jscomp$8_props_75641$$["on-decrease"],
$on_increase$$=$open_QMARK_$jscomp$8_props_75641$$["on-increase"],$open_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$open_QMARK_$jscomp$8_props_75641$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$1$$);var $open_dropdown$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$279$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$279$$);return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$1$$,!0)}),$close_dropdown$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$280$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$280$$);return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$1$$,!1)}),$on_increase__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_increase$$)],function($event$jscomp$281$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$281$$);return $on_increase$$.$cljs$core$IFn$_invoke$arity$0$?$on_increase$$.$cljs$core$IFn$_invoke$arity$0$():
$on_increase$$()}),$on_decrease__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_decrease$$)],function($event$jscomp$282$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$282$$);return $on_decrease$$.$cljs$core$IFn$_invoke$arity$0$?$on_decrease$$.$cljs$core$IFn$_invoke$arity$0$():$on_decrease$$()});return(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$open_dropdown$jscomp$1$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.zoom"),
className:"main_ui_viewer_header__zoom-widget "+($APP.$cljs$core$truth_$$($open_QMARK_$jscomp$8_props_75641$$)?"main_ui_viewer_header__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_header__label",children:$APP.$app$main$ui$formats$format_percent$cljs$0core$0IFn$0_invoke$0arity$02$$($zoom$jscomp$62$$,null)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$open_QMARK_$jscomp$8_props_75641$$,"on-close":$close_dropdown$jscomp$1$$,children:(0,$APP.$rumext$v2$jsxs$$)("ul",
{className:"main_ui_viewer_header__dropdown",children:[(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_viewer_header__basic-zoom-bar",children:[(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_viewer_header__zoom-btns",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_decrease__$1$$,className:"main_ui_viewer_header__zoom-btn",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_header__zoom-icon",children:$APP.$app$main$ui$icons$remove_icon$$})}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_viewer_header__zoom-text",children:$APP.$app$main$ui$formats$format_percent$cljs$0core$0IFn$0_invoke$0arity$02$$($zoom$jscomp$62$$,null)}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_increase__$1$$,className:"main_ui_viewer_header__zoom-btn",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_header__zoom-icon",children:$APP.$app$main$ui$icons$add$$})})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_zoom_reset$$,className:"main_ui_viewer_header__reset-btn",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.reset-zoom")})]}),(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:$on_zoom_fit$$,className:"main_ui_viewer_header__zoom-option",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.zoom-fit"),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_header__shortcuts",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$109$$,$sc$jscomp$6$$){$out_arr__44124__auto__$jscomp$109$$.push((0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_viewer_header__shortcut-key",children:$sc$jscomp$6$$},"zoom-fit-"+($sc$jscomp$6$$??"")));return $out_arr__44124__auto__$jscomp$109$$},[],$APP.$app$main$data$shortcuts$split_sc$$($app$main$data$viewer$shortcuts$get_tooltip$$($cljs$cst$5303$toggle_zoom_style$$)))})]}),(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:$on_zoom_fill$$,className:"main_ui_viewer_header__zoom-option",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.zoom-fill"),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_viewer_header__shortcuts",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$110$$,$sc$jscomp$7$$){$out_arr__44124__auto__$jscomp$110$$.push((0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_header__shortcut-key",children:$sc$jscomp$7$$},"zoom-fill-"+($sc$jscomp$7$$??"")));return $out_arr__44124__auto__$jscomp$110$$},[],$APP.$app$main$data$shortcuts$split_sc$$($app$main$data$viewer$shortcuts$get_tooltip$$($cljs$cst$5303$toggle_zoom_style$$)))})]}),
(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:$on_fullscreen$$,className:"main_ui_viewer_header__zoom-option",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.zoom-full-screen"),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_header__shortcuts",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44124__auto__$jscomp$111$$,$sc$jscomp$8$$){$out_arr__44124__auto__$jscomp$111$$.push((0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_header__shortcut-key",
children:$sc$jscomp$8$$},"zoom-fullscreen-"+($sc$jscomp$8$$??"")));return $out_arr__44124__auto__$jscomp$111$$},[],$APP.$app$main$data$shortcuts$split_sc$$($app$main$data$viewer$shortcuts$get_tooltip$$($cljs$cst$5301$toggle_fullscreen$$)))})]})]})})]})});$app$main$ui$viewer$header$penpot_logo_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_viewer_header__logo-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-penpot-logo-icon"})});$APP.$app$main$ui$static$0$TimeoutError$$=$APP.$shadow$js$shim$module$0rxjs$$.TimeoutError;
//# sourceMappingURL=shared.js.map
